/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_Con__D5bLh9apHRqCO9aW2fQb0sNQ tyObject_Con__D5bLh9apHRqCO9aW2fQb0sNQ;
typedef struct tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
struct tyObject_Con__D5bLh9apHRqCO9aW2fQb0sNQ {
NIM_BOOL somethingTodo;
NI inFinally;
};
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ {
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* wasMovedLocs;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
NIM_BOOL hasReturn;
NIM_BOOL hasBreak;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* label;
tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ* parent;
};
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg {
NI id;
NimStringDesc* s;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* next;
NI h;
};
typedef NU8 tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
typedef NU tyArray__VqSA39cBDWnwnJySTumCdjw[8];
struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg {
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* next;
NI key;
tyArray__VqSA39cBDWnwnJySTumCdjw bits;
};
typedef NU8 tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg[9];
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInst;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg uniqueId;
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void, analyse__optimizer_170)(tyObject_Con__D5bLh9apHRqCO9aW2fQb0sNQ* c, tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ* b, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5319)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5281)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5326)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5324)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5275)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(void, wasMovedDestroyPair__optimizer_144)(tyObject_Con__D5bLh9apHRqCO9aW2fQb0sNQ* c, tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ* b, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* d);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, exprStructuralEquivalent__trees_56)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b, NIM_BOOL strictSymEquality);
static N_INLINE(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, skipAddr__ast_5230)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, del__closureiters_3582)(tySequence__IeU9azYSNIK3V9b36Ir6NZcw** x, NI i);
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canRaise__ast_5100)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* fn);
N_LIB_PRIVATE N_NIMCALL(void, returnStmt__optimizer_67)(tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ* b);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(void, invalidateWasMoved__optimizer_128)(tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x);
N_LIB_PRIVATE N_NIMCALL(void, nestedBlock__optimizer_17)(tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ* parent, tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ* Result);
static N_INLINE(void, mergeBasicBlockInfo__optimizer_78)(tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ* parent, tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ* this_0);
N_LIB_PRIVATE N_NIMCALL(void, intersect__optimizer_103)(tySequence__IeU9azYSNIK3V9b36Ir6NZcw** summary, tySequence__IeU9azYSNIK3V9b36Ir6NZcw* branch);
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(void, initPackedSet__pureZcollectionsZintsets_16)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, wasMovedTarget__optimizer_85)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* matches, tySequence__IeU9azYSNIK3V9b36Ir6NZcw* branch, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* moveTarget);
N_LIB_PRIVATE N_NIMCALL(void, incl__pureZcollectionsZintsets_55)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, skipTypes__ast_3723)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kinds);
N_LIB_PRIVATE N_NIMCALL(void, breakStmt__optimizer_43)(tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ* b, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, shallowCopy__ast_4414)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* src);
N_LIB_PRIVATE N_NIMCALL(void, opt__optimizer_350)(tyObject_Con__D5bLh9apHRqCO9aW2fQb0sNQ c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* parent, NI parentPos);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeI__ast_3320)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
extern TNimType NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_;
STRING_LITERAL(TM__oWufXaZyaVPOHSSzjwt0PQ_2, "=destroy", 8);
STRING_LITERAL(TM__oWufXaZyaVPOHSSzjwt0PQ_3, "=sink", 5);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__oWufXaZyaVPOHSSzjwt0PQ_4 = {
0x10, 0xa8, 0x90, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5228;
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5319)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5281)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5324)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5275((&gch__system_5228.zct), c);
}
static N_INLINE(void, decRef__system_5326)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5324(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5281(src);
		incRef__system_5319(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5281((*dest));
		decRef__system_5326(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, skipAddr__ast_5230)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64))) goto LA3_;
		result = (*n)._kind_6.sons->data[((NI) 0)];
	}
	goto LA1_;
	LA3_: ;
	{
		result = n;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, wasMovedDestroyPair__optimizer_144)(tyObject_Con__D5bLh9apHRqCO9aW2fQb0sNQ* c, tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ* b, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* d) {
	NI i;
	i = ((NI) 0);
	{
		while (1) {
			NI T3_;
			T3_ = ((*b).wasMovedLocs ? (*b).wasMovedLocs->Sup.len : 0);
			if (!(i < T3_)) goto LA2;
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T6_;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T7_;
				NIM_BOOL T8_;
				T6_ = NIM_NIL;
				T6_ = skipAddr__ast_5230((*(*b).wasMovedLocs->data[i])._kind_6.sons->data[((NI) 1)]);
				T7_ = NIM_NIL;
				T7_ = skipAddr__ast_5230((*d)._kind_6.sons->data[((NI) 1)]);
				T8_ = (NIM_BOOL)0;
				T8_ = exprStructuralEquivalent__trees_56(T6_, T7_, NIM_TRUE);
				if (!T8_) goto LA9_;
				(*(*b).wasMovedLocs->data[i]).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg) 0)) & 31);
				(*c).somethingTodo = NIM_TRUE;
				(*d).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg) 0)) & 31);
				del__closureiters_3582((&(*b).wasMovedLocs), ((NI) (i)));
			}
			goto LA4_;
			LA9_: ;
			{
				i += ((NI) 1);
			}
			LA4_: ;
		} LA2: ;
	}
}
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, returnStmt__optimizer_67)(tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ* b) {
	tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ* it;
	(*b).hasReturn = NIM_TRUE;
	it = b;
	{
		while (1) {
			if (!!((it == ((tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ*) NIM_NIL)))) goto LA2;
			unsureAsgnRef((void**) (&(*it).wasMovedLocs), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) setLengthSeqV2(((*it).wasMovedLocs)?&((*it).wasMovedLocs)->Sup:NIM_NIL, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) 0)));
			it = (*it).parent;
		} LA2: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, invalidateWasMoved__optimizer_128)(tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x) {
	NI i;
	i = ((NI) 0);
	{
		while (1) {
			NI T3_;
			T3_ = ((*c).wasMovedLocs ? (*c).wasMovedLocs->Sup.len : 0);
			if (!(i < T3_)) goto LA2;
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T6_;
				NIM_BOOL T7_;
				T6_ = NIM_NIL;
				T6_ = skipAddr__ast_5230((*(*c).wasMovedLocs->data[i])._kind_6.sons->data[((NI) 1)]);
				T7_ = (NIM_BOOL)0;
				T7_ = exprStructuralEquivalent__trees_56(T6_, x, NIM_TRUE);
				if (!T7_) goto LA8_;
				del__closureiters_3582((&(*c).wasMovedLocs), ((NI) (i)));
			}
			goto LA4_;
			LA8_: ;
			{
				i += ((NI) 1);
			}
			LA4_: ;
		} LA2: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, nestedBlock__optimizer_17)(tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ* parent, tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ* Result) {
	unsureAsgnRef((void**)&(*Result).wasMovedLocs, NIM_NIL);
	(*Result).kind = 0;
	(*Result).hasReturn = 0;
	(*Result).hasBreak = 0;
	unsureAsgnRef((void**)&(*Result).label, NIM_NIL);
	(*Result).parent = NIM_NIL;
	unsureAsgnRef((void**) (&(*Result).wasMovedLocs), NIM_NIL);
	(*Result).kind = kind;
	(*Result).hasReturn = NIM_FALSE;
	(*Result).hasBreak = NIM_FALSE;
	unsureAsgnRef((void**) (&(*Result).label), ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
	(*Result).parent = parent;
}
static N_INLINE(void, mergeBasicBlockInfo__optimizer_78)(tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ* parent, tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ* this_0) {
	{
		if (!(*this_0).hasReturn) goto LA3_;
		unsureAsgnRef((void**) (&(*parent).wasMovedLocs), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) setLengthSeqV2(((*parent).wasMovedLocs)?&((*parent).wasMovedLocs)->Sup:NIM_NIL, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) 0)));
		(*parent).hasReturn = NIM_TRUE;
	}
	LA3_: ;
}
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result) {
	initPackedSet__pureZcollectionsZintsets_16(Result);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, wasMovedTarget__optimizer_85)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* matches, tySequence__IeU9azYSNIK3V9b36Ir6NZcw* branch, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* moveTarget) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = NIM_FALSE;
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (branch ? branch->Sup.len : 0);
		colontmp_ = T2_;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				{
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T7_;
					NIM_BOOL T8_;
					T7_ = NIM_NIL;
					T7_ = skipAddr__ast_5230((*branch->data[i])._kind_6.sons->data[((NI) 1)]);
					T8_ = (NIM_BOOL)0;
					T8_ = exprStructuralEquivalent__trees_56(T7_, moveTarget, NIM_TRUE);
					if (!T8_) goto LA9_;
					result = NIM_TRUE;
					incl__pureZcollectionsZintsets_55(matches, i);
				}
				LA9_: ;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, intersect__optimizer_103)(tySequence__IeU9azYSNIK3V9b36Ir6NZcw** summary, tySequence__IeU9azYSNIK3V9b36Ir6NZcw* branch) {
	NI i;
	tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw matches;
	i = ((NI) 0);
	nimZeroMem((void*)(&matches), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
	initIntSet__pureZcollectionsZintsets_238((&matches));
	{
		while (1) {
			NI T3_;
			T3_ = ((*summary) ? (*summary)->Sup.len : 0);
			if (!(i < T3_)) goto LA2;
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T6_;
				NIM_BOOL T7_;
				T6_ = NIM_NIL;
				T6_ = skipAddr__ast_5230((*(*summary)->data[i])._kind_6.sons->data[((NI) 1)]);
				T7_ = (NIM_BOOL)0;
				T7_ = wasMovedTarget__optimizer_85((&matches), branch, T6_);
				if (!T7_) goto LA8_;
				i += ((NI) 1);
			}
			goto LA4_;
			LA8_: ;
			{
				del__closureiters_3582(summary, ((NI) (i)));
			}
			LA4_: ;
		} LA2: ;
	}
	{
		NI m;
		m = (NI)0;
		{
			if (!(matches.elems <= ((NI) 34))) goto LA14_;
			{
				NI i_2;
				NI i_3;
				i_2 = (NI)0;
				i_3 = ((NI) 0);
				{
					while (1) {
						NI T19_;
						if (!(i_3 < matches.elems)) goto LA18;
						i_2 = i_3;
						m = matches.a[(i_2)- 0];
						unsureAsgnRef((void**) (&(*summary)), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) incrSeqV3((TGenericSeq*)((*summary)), (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_)));
						T19_ = (*summary)->Sup.len++;
						asgnRef((void**) (&(*summary)->data[T19_]), branch->data[m]);
						i_3 += ((NI) 1);
					} LA18: ;
				}
			}
		}
		goto LA12_;
		LA14_: ;
		{
			tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* r;
			r = matches.head;
			{
				while (1) {
					NI i_4;
					if (!!((r == ((tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) NIM_NIL)))) goto LA22;
					i_4 = ((NI) 0);
					{
						while (1) {
							NU w;
							NI j;
							if (!(i_4 <= ((NI) 7))) goto LA24;
							w = (*r).bits[(i_4)- 0];
							j = ((NI) 0);
							{
								while (1) {
									if (!!((w == ((NU) 0)))) goto LA26;
									{
										NI T31_;
										NI T32_;
										if (!!(((NU)(w & ((NU) 1)) == ((NU) 0)))) goto LA29_;
										T31_ = (NI)0;
										T31_ = pluspercent___system_696((NI)((NU64)(i_4) << (NU64)(((NI) 6))), j);
										m = (NI)((NI)((NU64)((*r).key) << (NU64)(((NI) 9))) | T31_);
										unsureAsgnRef((void**) (&(*summary)), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) incrSeqV3((TGenericSeq*)((*summary)), (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_)));
										T32_ = (*summary)->Sup.len++;
										asgnRef((void**) (&(*summary)->data[T32_]), branch->data[m]);
									}
									LA29_: ;
									j += ((NI) 1);
									w = (NU)((NU64)(w) >> (NU64)(((NI) 1)));
								} LA26: ;
							}
							i_4 += ((NI) 1);
						} LA24: ;
					}
					r = (*r).next;
				} LA22: ;
			}
		}
		LA12_: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, breakStmt__optimizer_43)(tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ* b, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ* it;
	it = b;
	{
		while (1) {
			if (!!((it == ((tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ*) NIM_NIL)))) goto LA2;
			unsureAsgnRef((void**) (&(*it).wasMovedLocs), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) setLengthSeqV2(((*it).wasMovedLocs)?&((*it).wasMovedLocs)->Sup:NIM_NIL, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) 0)));
			(*it).hasBreak = NIM_TRUE;
			{
				if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA5_;
				{
					if (!((*it).label == (*n)._kind_4.sym)) goto LA9_;
					goto LA1;
				}
				LA9_: ;
			}
			goto LA3_;
			LA5_: ;
			{
				{
					if (!((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 96) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 112) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 127))) goto LA14_;
					goto LA1;
				}
				LA14_: ;
			}
			LA3_: ;
			it = (*it).parent;
		} LA2: ;
	} LA1: ;
}
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__ast_3155(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, analyse__optimizer_170)(tyObject_Con__D5bLh9apHRqCO9aW2fQb0sNQ* c, tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ* b, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
	{
		NIM_BOOL special;
		NIM_BOOL reverse;
		special = NIM_FALSE;
		reverse = NIM_FALSE;
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA4_;
			s = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
			{
				NI T10_;
				if (!((*s).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 150))) goto LA8_;
				unsureAsgnRef((void**) (&(*b).wasMovedLocs), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) incrSeqV3((TGenericSeq*)((*b).wasMovedLocs), (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_)));
				T10_ = (*b).wasMovedLocs->Sup.len++;
				asgnRef((void**) (&(*b).wasMovedLocs->data[T10_]), n);
				special = NIM_TRUE;
			}
			goto LA6_;
			LA8_: ;
			{
				if (!eqStrings((*(*s).name).s, ((NimStringDesc*) &TM__oWufXaZyaVPOHSSzjwt0PQ_2))) goto LA12_;
				{
					NIM_BOOL T16_;
					NIM_BOOL T18_;
					T16_ = (NIM_BOOL)0;
					T16_ = (((NI) 0) < (*c).inFinally);
					if (!(T16_)) goto LA17_;
					T18_ = (NIM_BOOL)0;
					T18_ = (*b).hasReturn;
					if (T18_) goto LA19_;
					T18_ = (*b).hasBreak;
					LA19_: ;
					T16_ = T18_;
					LA17_: ;
					if (!T16_) goto LA20_;
				}
				goto LA14_;
				LA20_: ;
				{
					wasMovedDestroyPair__optimizer_144(c, b, n);
				}
				LA14_: ;
				special = NIM_TRUE;
			}
			goto LA6_;
			LA12_: ;
			{
				if (!eqStrings((*(*s).name).s, ((NimStringDesc*) &TM__oWufXaZyaVPOHSSzjwt0PQ_3))) goto LA24_;
				reverse = NIM_TRUE;
			}
			goto LA6_;
			LA24_: ;
			LA6_: ;
		}
		LA4_: ;
		{
			if (!!(special)) goto LA28_;
			{
				if (!!(reverse)) goto LA32_;
				{
					NI i;
					NI colontmp_;
					NI i_2;
					i = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = len__ast_3155(n);
					i_2 = ((NI) 0);
					{
						while (1) {
							if (!(i_2 < colontmp_)) goto LA36;
							i = i_2;
							analyse__optimizer_170(c, b, (*n)._kind_6.sons->data[i]);
							i_2 += ((NI) 1);
						} LA36: ;
					}
				}
			}
			goto LA30_;
			LA32_: ;
			{
				{
					NI i_3;
					NI colontmp__2;
					NI T39_;
					NI res;
					i_3 = (NI)0;
					colontmp__2 = (NI)0;
					T39_ = (NI)0;
					T39_ = len__ast_3155(n);
					colontmp__2 = (NI)(T39_ - ((NI) 1));
					res = colontmp__2;
					{
						while (1) {
							if (!(((NI) 0) <= res)) goto LA41;
							i_3 = res;
							analyse__optimizer_170(c, b, (*n)._kind_6.sons->data[i_3]);
							res -= ((NI) 1);
						} LA41: ;
					}
				}
			}
			LA30_: ;
			{
				NIM_BOOL T44_;
				T44_ = (NIM_BOOL)0;
				T44_ = canRaise__ast_5100((*n)._kind_6.sons->data[((NI) 0)]);
				if (!T44_) goto LA45_;
				returnStmt__optimizer_67(b);
			}
			LA45_: ;
		}
		LA28_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		invalidateWasMoved__optimizer_128(b, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 4) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 98):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 81):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 80):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 82):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 83):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 51):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 52):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 101):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 102):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 121):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 116):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 118):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 90):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 125):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 158):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 132):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 123):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 122):
	{
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 73):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 74):
	{
		analyse__optimizer_170(c, b, (*n)._kind_6.sons->data[((NI) 1)]);
		analyse__optimizer_170(c, b, (*n)._kind_6.sons->data[((NI) 0)]);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 92):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 48):
	{
		NIM_BOOL isExhaustive;
		NI T51_;
		tySequence__IeU9azYSNIK3V9b36Ir6NZcw* wasMovedSet;
		T51_ = (NI)0;
		T51_ = len__ast_3155(n);
		isExhaustive = ((*(*n)._kind_6.sons->data[(NI)(T51_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 88) || (*(*n)._kind_6.sons->data[(NI)(T51_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 50));
		wasMovedSet = NIM_NIL;
		{
			NI i_4;
			NI colontmp__3;
			NI i_5;
			i_4 = (NI)0;
			colontmp__3 = (NI)0;
			colontmp__3 = len__ast_3155(n);
			i_5 = ((NI) 0);
			{
				while (1) {
					tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ branch;
					if (!(i_5 < colontmp__3)) goto LA54;
					i_4 = i_5;
					nimZeroMem((void*)(&branch), sizeof(tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ));
					nestedBlock__optimizer_17(b, (*(*n)._kind_6.sons->data[i_4]).kind, (&branch));
					analyse__optimizer_170(c, (&branch), (*n)._kind_6.sons->data[i_4]);
					mergeBasicBlockInfo__optimizer_78(b, (&branch));
					{
						if (!isExhaustive) goto LA57_;
						{
							if (!(i_4 == ((NI) 0))) goto LA61_;
							wasMovedSet = branch.wasMovedLocs;
							branch.wasMovedLocs = NIM_NIL;
						}
						goto LA59_;
						LA61_: ;
						{
							intersect__optimizer_103((&wasMovedSet), branch.wasMovedLocs);
						}
						LA59_: ;
					}
					LA57_: ;
					i_5 += ((NI) 1);
				} LA54: ;
			}
		}
		{
			NI i_6;
			NI colontmp__4;
			NI T65_;
			NI i_7;
			i_6 = (NI)0;
			colontmp__4 = (NI)0;
			T65_ = (wasMovedSet ? wasMovedSet->Sup.len : 0);
			colontmp__4 = T65_;
			i_7 = ((NI) 0);
			{
				while (1) {
					NI T68_;
					if (!(i_7 < colontmp__4)) goto LA67;
					i_6 = i_7;
					unsureAsgnRef((void**) (&(*b).wasMovedLocs), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) incrSeqV3((TGenericSeq*)((*b).wasMovedLocs), (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_)));
					T68_ = (*b).wasMovedLocs->Sup.len++;
					asgnRef((void**) (&(*b).wasMovedLocs->data[T68_]), wasMovedSet->data[i_6]);
					i_7 += ((NI) 1);
				} LA67: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 97):
	{
		NIM_BOOL isExhaustive_2;
		NIM_BOOL T70_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T71_;
		NI T73_;
		tySequence__IeU9azYSNIK3V9b36Ir6NZcw* wasMovedSet_2;
		T70_ = (NIM_BOOL)0;
		T71_ = NIM_NIL;
		T71_ = skipTypes__ast_3723((*(*n)._kind_6.sons->data[((NI) 0)]).typ, TM__oWufXaZyaVPOHSSzjwt0PQ_4);
		T70_ = !(((*T71_).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36) && (*T71_).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 39) || (*T71_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28)));
		if (T70_) goto LA72_;
		T73_ = (NI)0;
		T73_ = len__ast_3155(n);
		T70_ = ((*(*n)._kind_6.sons->data[(NI)(T73_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 88));
		LA72_: ;
		isExhaustive_2 = T70_;
		analyse__optimizer_170(c, b, (*n)._kind_6.sons->data[((NI) 0)]);
		wasMovedSet_2 = NIM_NIL;
		{
			NI i_8;
			NI colontmp__5;
			NI i_9;
			i_8 = (NI)0;
			colontmp__5 = (NI)0;
			colontmp__5 = len__ast_3155(n);
			i_9 = ((NI) 1);
			{
				while (1) {
					tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ branch_2;
					if (!(i_9 < colontmp__5)) goto LA76;
					i_8 = i_9;
					nimZeroMem((void*)(&branch_2), sizeof(tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ));
					nestedBlock__optimizer_17(b, (*(*n)._kind_6.sons->data[i_8]).kind, (&branch_2));
					analyse__optimizer_170(c, (&branch_2), (*n)._kind_6.sons->data[i_8]);
					mergeBasicBlockInfo__optimizer_78(b, (&branch_2));
					{
						if (!isExhaustive_2) goto LA79_;
						{
							if (!(i_8 == ((NI) 1))) goto LA83_;
							wasMovedSet_2 = branch_2.wasMovedLocs;
							branch_2.wasMovedLocs = NIM_NIL;
						}
						goto LA81_;
						LA83_: ;
						{
							intersect__optimizer_103((&wasMovedSet_2), branch_2.wasMovedLocs);
						}
						LA81_: ;
					}
					LA79_: ;
					i_9 += ((NI) 1);
				} LA76: ;
			}
		}
		{
			NI i_10;
			NI colontmp__6;
			NI T87_;
			NI i_11;
			i_10 = (NI)0;
			colontmp__6 = (NI)0;
			T87_ = (wasMovedSet_2 ? wasMovedSet_2->Sup.len : 0);
			colontmp__6 = T87_;
			i_11 = ((NI) 0);
			{
				while (1) {
					NI T90_;
					if (!(i_11 < colontmp__6)) goto LA89;
					i_10 = i_11;
					unsureAsgnRef((void**) (&(*b).wasMovedLocs), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) incrSeqV3((TGenericSeq*)((*b).wasMovedLocs), (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_)));
					T90_ = (*b).wasMovedLocs->Sup.len++;
					asgnRef((void**) (&(*b).wasMovedLocs->data[T90_]), wasMovedSet_2->data[i_10]);
					i_11 += ((NI) 1);
				} LA89: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 106):
	{
		{
			NI i_12;
			NI colontmp__7;
			NI i_13;
			i_12 = (NI)0;
			colontmp__7 = (NI)0;
			colontmp__7 = len__ast_3155(n);
			i_13 = ((NI) 0);
			{
				while (1) {
					tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ tryBody;
					if (!(i_13 < colontmp__7)) goto LA94;
					i_12 = i_13;
					nimZeroMem((void*)(&tryBody), sizeof(tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ));
					nestedBlock__optimizer_17(b, ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 106), (&tryBody));
					analyse__optimizer_170(c, (&tryBody), (*n)._kind_6.sons->data[i_12]);
					mergeBasicBlockInfo__optimizer_78(b, (&tryBody));
					i_13 += ((NI) 1);
				} LA94: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 96):
	{
		tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ loopBody;
		analyse__optimizer_170(c, b, (*n)._kind_6.sons->data[((NI) 0)]);
		nimZeroMem((void*)(&loopBody), sizeof(tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ));
		nestedBlock__optimizer_17(b, ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 96), (&loopBody));
		analyse__optimizer_170(c, (&loopBody), (*n)._kind_6.sons->data[((NI) 1)]);
		mergeBasicBlockInfo__optimizer_78(b, (&loopBody));
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 112):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 127):
	{
		tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ blockBody;
		nimZeroMem((void*)(&blockBody), sizeof(tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ));
		nestedBlock__optimizer_17(b, (*n).kind, (&blockBody));
		{
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA99_;
			blockBody.label = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		}
		LA99_: ;
		analyse__optimizer_170(c, (&blockBody), (*n)._kind_6.sons->data[((NI) 1)]);
		mergeBasicBlockInfo__optimizer_78(b, (&blockBody));
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 110):
	{
		breakStmt__optimizer_43(b, (*n)._kind_6.sons->data[((NI) 0)]);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 109):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 108):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child;
			child = NIM_NIL;
			{
				NI i_14;
				NI colontmp__8;
				NI i_15;
				i_14 = (NI)0;
				colontmp__8 = (NI)0;
				colontmp__8 = safeLen__ast_3148(n);
				i_15 = ((NI) 0);
				{
					while (1) {
						if (!(i_15 < colontmp__8)) goto LA106;
						i_14 = i_15;
						child = (*n)._kind_6.sons->data[i_14];
						analyse__optimizer_170(c, b, child);
						i_15 += ((NI) 1);
					} LA106: ;
				}
			}
		}
		returnStmt__optimizer_67(b);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 107):
	{
		(*c).inFinally += ((NI) 1);
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child_2;
			child_2 = NIM_NIL;
			{
				NI i_16;
				NI colontmp__9;
				NI i_17;
				i_16 = (NI)0;
				colontmp__9 = (NI)0;
				colontmp__9 = safeLen__ast_3148(n);
				i_17 = ((NI) 0);
				{
					while (1) {
						if (!(i_17 < colontmp__9)) goto LA111;
						i_16 = i_17;
						child_2 = (*n)._kind_6.sons->data[i_16];
						analyse__optimizer_170(c, b, child_2);
						i_17 += ((NI) 1);
					} LA111: ;
				}
			}
		}
		(*c).inFinally -= ((NI) 1);
	}
	break;
	default:
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child_3;
			child_3 = NIM_NIL;
			{
				NI i_18;
				NI colontmp__10;
				NI i_19;
				i_18 = (NI)0;
				colontmp__10 = (NI)0;
				colontmp__10 = safeLen__ast_3148(n);
				i_19 = ((NI) 0);
				{
					while (1) {
						if (!(i_19 < colontmp__10)) goto LA116;
						i_18 = i_19;
						child_3 = (*n)._kind_6.sons->data[i_18];
						analyse__optimizer_170(c, b, child_3);
						i_19 += ((NI) 1);
					} LA116: ;
				}
			}
		}
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, opt__optimizer_350)(tyObject_Con__D5bLh9apHRqCO9aW2fQb0sNQ c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* parent, NI parentPos) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
	{
		{
			if (!(((*n).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg) 0))&31U)))!=0)) goto LA4_;
			asgnRef((void**) (&(*parent)._kind_6.sons->data[parentPos]), newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1), (*n).info));
		}
		goto LA2_;
		LA4_: ;
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* xX60gensym39_;
			xX60gensym39_ = shallowCopy__ast_4414(n);
			{
				NI iX60gensym39_;
				NI colontmp_;
				NI i;
				iX60gensym39_ = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_3155(n);
				i = ((NI) 0);
				{
					while (1) {
						if (!(i < colontmp_)) goto LA9;
						iX60gensym39_ = i;
						opt__optimizer_350(c, (*n)._kind_6.sons->data[iX60gensym39_], xX60gensym39_, iX60gensym39_);
						i += ((NI) 1);
					} LA9: ;
				}
			}
			asgnRef((void**) (&(*parent)._kind_6.sons->data[parentPos]), xX60gensym39_);
		}
		LA2_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 98):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 81):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 80):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 82):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 83):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 51):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 52):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 101):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 102):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 121):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 116):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 118):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 90):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 125):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 158):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 132):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 123):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 122):
	{
		asgnRef((void**) (&(*parent)._kind_6.sons->data[parentPos]), n);
	}
	break;
	default:
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* xX60gensym43_;
		xX60gensym43_ = shallowCopy__ast_4414(n);
		{
			NI iX60gensym43_;
			NI colontmp__2;
			NI i_2;
			iX60gensym43_ = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp__2)) goto LA14;
					iX60gensym43_ = i_2;
					opt__optimizer_350(c, (*n)._kind_6.sons->data[iX60gensym43_], xX60gensym43_, iX60gensym43_);
					i_2 += ((NI) 1);
				} LA14: ;
			}
		}
		asgnRef((void**) (&(*parent)._kind_6.sons->data[parentPos]), xX60gensym43_);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, optimize__optimizer_390)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_Con__D5bLh9apHRqCO9aW2fQb0sNQ c;
	tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ b;
	result = NIM_NIL;
	nimZeroMem((void*)(&c), sizeof(tyObject_Con__D5bLh9apHRqCO9aW2fQb0sNQ));
	nimZeroMem((void*)(&b), sizeof(tyObject_BasicBlock__ASUA7Ptg5JB6xhNL7iXoQQ));
	analyse__optimizer_170((&c), (&b), n);
	{
		if (!c.somethingTodo) goto LA3_;
		result = shallowCopy__ast_4414(n);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA7;
					i = i_2;
					opt__optimizer_350(c, (*n)._kind_6.sons->data[i], result, i);
					i_2 += ((NI) 1);
				} LA7: ;
			}
		}
	}
	goto LA1_;
	LA3_: ;
	{
		result = n;
	}
	LA1_: ;
	return result;
}
