/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64
#define NIM_EmulateOverflowChecks

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyTuple__UV3llMMYFckfui8YMBuUZA tyTuple__UV3llMMYFckfui8YMBuUZA;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyTuple__i8UlBN9aCVE7Wxx7H9ckexjA tyTuple__i8UlBN9aCVE7Wxx7H9ckexjA;
typedef struct tyTuple__0c626sqvYlRHlzCEcJoxaA tyTuple__0c626sqvYlRHlzCEcJoxaA;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tyTuple__Q066krdfdsSnR5DaFMOk9bQ tyTuple__Q066krdfdsSnR5DaFMOk9bQ;
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyTuple__Qs8sDfUhU9bpCSJUdwfMJiA tyTuple__Qs8sDfUhU9bpCSJUdwfMJiA;
typedef struct tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g;
typedef struct tyTuple__NZDXyOL9bXdVfZI9bh9asxScA tyTuple__NZDXyOL9bXdVfZI9bh9asxScA;
typedef struct tyTuple__CWLiqluAXi3Y4RHZUwBh9bQ tyTuple__CWLiqluAXi3Y4RHZUwBh9bQ;
typedef struct tyTuple__vHUW1Tno3SvNzAormr6Geg tyTuple__vHUW1Tno3SvNzAormr6Geg;
typedef struct tyTuple__dQWEdGsliQQO27wHmA3anw tyTuple__dQWEdGsliQQO27wHmA3anw;
typedef struct tyTuple__kUfCoroaC0rOCxJlya5Mfg tyTuple__kUfCoroaC0rOCxJlya5Mfg;
typedef struct tyTuple__x06rJgrLAhZPc8rLiIC9c6A tyTuple__x06rJgrLAhZPc8rLiIC9c6A;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tyTuple__7q7q3E6Oj24ZNVJb9aonhAg;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyTuple__UV3llMMYFckfui8YMBuUZA {
NimStringDesc* Field0;
NimStringDesc* Field1;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct tyTuple__i8UlBN9aCVE7Wxx7H9ckexjA {
NimStringDesc* Field0;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw Field1;
NimStringDesc* Field2;
NimStringDesc* Field3;
NimStringDesc* Field4;
NI Field5;
};
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
struct tyTuple__0c626sqvYlRHlzCEcJoxaA {
NimStringDesc* Field0;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg Field1;
};
typedef NU8 tySet_tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw[37];
typedef NU16 tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw;
struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg {
NI32 module;
NI32 symId;
NI32 typeId_0;
NIM_BOOL sealed;
};
struct tyTuple__Q066krdfdsSnR5DaFMOk9bQ {
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field0;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field1;
};
struct tyTuple__Qs8sDfUhU9bpCSJUdwfMJiA {
NimStringDesc* Field0;
tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* Field1;
};
typedef NU8 tySet_tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A;
typedef NU8 tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A;
struct tyTuple__NZDXyOL9bXdVfZI9bh9asxScA {
NimStringDesc* Field0;
NimStringDesc* Field1;
tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* Field2;
};
struct tyTuple__CWLiqluAXi3Y4RHZUwBh9bQ {
NI Field0;
NI Field1;
NimStringDesc* Field2;
tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* Field3;
};
struct tyTuple__vHUW1Tno3SvNzAormr6Geg {
NI Field0;
NI Field1;
NI Field2;
NimStringDesc* Field3;
tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* Field4;
};
typedef NU16 tySet_tyEnum_FilePermission__Y2L2fCWnzUX27lSi9cRgTOQ;
struct tyTuple__dQWEdGsliQQO27wHmA3anw {
NimStringDesc* Field0;
tySet_tyEnum_FilePermission__Y2L2fCWnzUX27lSi9cRgTOQ Field1;
};
typedef NU8 tyEnum_FilePermission__Y2L2fCWnzUX27lSi9cRgTOQ;
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
struct tyTuple__kUfCoroaC0rOCxJlya5Mfg {
NimStringDesc* Field0;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw Field1;
};
typedef NU8 tyEnum_TJSTypeKind__tpKLAXT6CPyZ9cMNxf1ZsAQ;
struct tyTuple__x06rJgrLAhZPc8rLiIC9c6A {
NimStringDesc* Field0;
tyEnum_TJSTypeKind__tpKLAXT6CPyZ9cMNxf1ZsAQ Field1;
tyEnum_TJSTypeKind__tpKLAXT6CPyZ9cMNxf1ZsAQ Field2;
};
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
};
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_167)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__pureZos_449)(NimStringDesc** s, NimStringDesc* x);
static N_INLINE(void, addFloat__system_3130)(NimStringDesc** result, NF x);
N_LIB_PRIVATE N_NIMCALL(void, addFloatRoundtrip__system_3135)(NimStringDesc** result, NF x);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_164)(NimStringDesc** result, NU64 x);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__modulegraphs_3475)(NimStringDesc** s, NI32 x);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__ast_3247)(NimStringDesc** s, tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw x);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__vm_1553)(NimStringDesc** s, NI x);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__vm_1751)(NimStringDesc** s, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, collectionToString__importer_4672)(tySet_tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw x, NimStringDesc* prefix, NimStringDesc* separator, NimStringDesc* suffix);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__importer_4704)(NimStringDesc** s, tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw x);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__passaux_91)(NimStringDesc** s, NIM_BOOL x);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__injectdestructors_1880)(NimStringDesc** s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__stdZjsonutils_445)(NimStringDesc** s, tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, collectionToString__pureZjson_5362)(tySet_tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A x, NimStringDesc* prefix, NimStringDesc* separator, NimStringDesc* suffix);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__pureZjson_5394)(NimStringDesc** s, tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A x);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__extccomp_2092)(NimStringDesc** s, NI x);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__pureZos_947)(NimStringDesc** s, tySet_tyEnum_FilePermission__Y2L2fCWnzUX27lSi9cRgTOQ x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, collectionToString__pureZos_957)(tySet_tyEnum_FilePermission__Y2L2fCWnzUX27lSi9cRgTOQ x, NimStringDesc* prefix, NimStringDesc* separator, NimStringDesc* suffix);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__pureZos_989)(NimStringDesc** s, tyEnum_FilePermission__Y2L2fCWnzUX27lSi9cRgTOQ x);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__jsgen_3192)(NimStringDesc** s, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw x);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__jsgen_2695)(NimStringDesc** s, tyEnum_TJSTypeKind__tpKLAXT6CPyZ9cMNxf1ZsAQ x);
STRING_LITERAL(TM__n49a9aYp5BrbXv9a6OCpJYm0g_2, "(", 1);
STRING_LITERAL(TM__n49a9aYp5BrbXv9a6OCpJYm0g_3, ", ", 2);
STRING_LITERAL(TM__n49a9aYp5BrbXv9a6OCpJYm0g_4, ",", 1);
STRING_LITERAL(TM__n49a9aYp5BrbXv9a6OCpJYm0g_5, ")", 1);
STRING_LITERAL(TM__n49a9aYp5BrbXv9a6OCpJYm0g_6, "module", 6);
STRING_LITERAL(TM__n49a9aYp5BrbXv9a6OCpJYm0g_7, ": ", 2);
STRING_LITERAL(TM__n49a9aYp5BrbXv9a6OCpJYm0g_8, "item", 4);
STRING_LITERAL(TM__n49a9aYp5BrbXv9a6OCpJYm0g_9, "{", 1);
STRING_LITERAL(TM__n49a9aYp5BrbXv9a6OCpJYm0g_10, "}", 1);
STRING_LITERAL(TM__n49a9aYp5BrbXv9a6OCpJYm0g_11, "symId", 5);
STRING_LITERAL(TM__n49a9aYp5BrbXv9a6OCpJYm0g_12, "typeId", 6);
STRING_LITERAL(TM__n49a9aYp5BrbXv9a6OCpJYm0g_13, "sealed", 6);
STRING_LITERAL(TM__n49a9aYp5BrbXv9a6OCpJYm0g_14, "nil", 3);
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x) {
	addInt__stdZprivateZdigitsutils_167(result, ((NI64) (x)));
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___systemZdollars_3)(NI x) {
	NimStringDesc* result;
	result = NIM_NIL;
	addInt__stdZprivateZdigitsutils_189((&result), x);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___systemZdollars_6)(NI64 x) {
	NimStringDesc* result;
	result = NIM_NIL;
	addInt__stdZprivateZdigitsutils_167((&result), x);
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___pureZos_429)(tyTuple__UV3llMMYFckfui8YMBuUZA x) {
	NimStringDesc* result;
	NI count;
	result = NIM_NIL;
	result = copyString(((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_2));
	count = ((NI) 0);
	{
		if (!(((NI) 0) < count)) goto LA3_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA3_: ;
	count += ((NI) 1);
	addQuoted__pureZos_449((&result), x.Field0);
	{
		if (!(((NI) 0) < count)) goto LA7_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA7_: ;
	count += ((NI) 1);
	addQuoted__pureZos_449((&result), x.Field1);
	{
		if (!(count == ((NI) 1))) goto LA11_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA11_: ;
	result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_5));
	return result;
}
static N_INLINE(void, addFloat__system_3130)(NimStringDesc** result, NF x) {
	addFloatRoundtrip__system_3135(result, x);
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___system_3126)(NF x) {
	NimStringDesc* result;
	result = NIM_NIL;
	addFloat__system_3130((&result), x);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___systemZdollars_9)(NU64 x) {
	NimStringDesc* result;
	result = NIM_NIL;
	addInt__stdZprivateZdigitsutils_164((&result), x);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___modulegraphs_3455)(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg x) {
	NimStringDesc* result;
	NI count;
	result = NIM_NIL;
	result = copyString(((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_2));
	count = ((NI) 0);
	{
		if (!(((NI) 0) < count)) goto LA3_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA3_: ;
	result = resizeString(result, 6);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_6));
	result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_7));
	count += ((NI) 1);
	addQuoted__modulegraphs_3475((&result), x.module);
	{
		if (!(((NI) 0) < count)) goto LA7_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA7_: ;
	result = resizeString(result, 4);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_8));
	result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_7));
	count += ((NI) 1);
	addQuoted__modulegraphs_3475((&result), x.item);
	result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_5));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___vm_1475)(tyTuple__i8UlBN9aCVE7Wxx7H9ckexjA* x) {
	NimStringDesc* result;
	NI count;
	result = NIM_NIL;
	result = copyString(((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_2));
	count = ((NI) 0);
	{
		if (!(((NI) 0) < count)) goto LA3_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA3_: ;
	count += ((NI) 1);
	addQuoted__pureZos_449((&result), (*x).Field0);
	{
		if (!(((NI) 0) < count)) goto LA7_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA7_: ;
	count += ((NI) 1);
	addQuoted__ast_3247((&result), (*x).Field1);
	{
		if (!(((NI) 0) < count)) goto LA11_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA11_: ;
	count += ((NI) 1);
	addQuoted__pureZos_449((&result), (*x).Field2);
	{
		if (!(((NI) 0) < count)) goto LA15_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA15_: ;
	count += ((NI) 1);
	addQuoted__pureZos_449((&result), (*x).Field3);
	{
		if (!(((NI) 0) < count)) goto LA19_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA19_: ;
	count += ((NI) 1);
	addQuoted__pureZos_449((&result), (*x).Field4);
	{
		if (!(((NI) 0) < count)) goto LA23_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA23_: ;
	count += ((NI) 1);
	addQuoted__vm_1553((&result), (*x).Field5);
	{
		if (!(count == ((NI) 1))) goto LA27_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA27_: ;
	result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_5));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___vm_1717)(tyTuple__0c626sqvYlRHlzCEcJoxaA x) {
	NimStringDesc* result;
	NI count;
	result = NIM_NIL;
	result = copyString(((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_2));
	count = ((NI) 0);
	{
		if (!(((NI) 0) < count)) goto LA3_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA3_: ;
	count += ((NI) 1);
	addQuoted__pureZos_449((&result), x.Field0);
	{
		if (!(((NI) 0) < count)) goto LA7_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA7_: ;
	count += ((NI) 1);
	addQuoted__vm_1751((&result), x.Field1);
	{
		if (!(count == ((NI) 1))) goto LA11_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA11_: ;
	result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_5));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, collectionToString__importer_4672)(tySet_tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw x, NimStringDesc* prefix, NimStringDesc* separator, NimStringDesc* suffix) {
	NimStringDesc* result;
	NIM_BOOL firstElement;
	result = NIM_NIL;
	result = copyString(prefix);
	firstElement = NIM_TRUE;
	{
		tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw value;
		NI i;
		value = (tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw)0;
		i = ((NI) 0);
		{
			while (1) {
				if (!(i <= ((NI) 294))) goto LA3;
				{
					if (!((x[(NU)(((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) (i)))>>3] &(1U<<((NU)(((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) (i)))&7U)))!=0)) goto LA6_;
					value = ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) (i));
					{
						if (!firstElement) goto LA10_;
						firstElement = NIM_FALSE;
					}
					goto LA8_;
					LA10_: ;
					{
						result = resizeString(result, (separator ? separator->Sup.len : 0) + 0);
appendString(result, separator);
					}
					LA8_: ;
					addQuoted__importer_4704((&result), value);
				}
				LA6_: ;
				i += ((NI) 1);
			} LA3: ;
		}
	}
	result = resizeString(result, (suffix ? suffix->Sup.len : 0) + 0);
appendString(result, suffix);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___importer_4668)(tySet_tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw x) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = collectionToString__importer_4672(x, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_9), ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3), ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_10));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___passaux_38)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg x) {
	NimStringDesc* result;
	NI count;
	result = NIM_NIL;
	result = copyString(((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_2));
	count = ((NI) 0);
	{
		if (!(((NI) 0) < count)) goto LA3_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA3_: ;
	result = resizeString(result, 6);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_6));
	result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_7));
	count += ((NI) 1);
	addQuoted__modulegraphs_3475((&result), x.module);
	{
		if (!(((NI) 0) < count)) goto LA7_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA7_: ;
	result = resizeString(result, 5);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_11));
	result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_7));
	count += ((NI) 1);
	addQuoted__modulegraphs_3475((&result), x.symId);
	{
		if (!(((NI) 0) < count)) goto LA11_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA11_: ;
	result = resizeString(result, 6);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_12));
	result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_7));
	count += ((NI) 1);
	addQuoted__modulegraphs_3475((&result), x.typeId_0);
	{
		if (!(((NI) 0) < count)) goto LA15_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA15_: ;
	result = resizeString(result, 6);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_13));
	result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_7));
	count += ((NI) 1);
	addQuoted__passaux_91((&result), x.sealed);
	result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_5));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___injectdestructors_1854)(tyTuple__Q066krdfdsSnR5DaFMOk9bQ x) {
	NimStringDesc* result;
	NI count;
	result = NIM_NIL;
	result = copyString(((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_2));
	count = ((NI) 0);
	{
		if (!(((NI) 0) < count)) goto LA3_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA3_: ;
	count += ((NI) 1);
	{
		if (!(x.Field0 == 0)) goto LA7_;
		result = resizeString(result, 3);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_14));
	}
	goto LA5_;
	LA7_: ;
	{
		addQuoted__injectdestructors_1880((&result), x.Field0);
	}
	LA5_: ;
	{
		if (!(((NI) 0) < count)) goto LA12_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA12_: ;
	count += ((NI) 1);
	{
		if (!(x.Field1 == 0)) goto LA16_;
		result = resizeString(result, 3);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_14));
	}
	goto LA14_;
	LA16_: ;
	{
		addQuoted__injectdestructors_1880((&result), x.Field1);
	}
	LA14_: ;
	{
		if (!(count == ((NI) 1))) goto LA21_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA21_: ;
	result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_5));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___stdZjsonutils_408)(tyTuple__Qs8sDfUhU9bpCSJUdwfMJiA x) {
	NimStringDesc* result;
	NI count;
	result = NIM_NIL;
	result = copyString(((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_2));
	count = ((NI) 0);
	{
		if (!(((NI) 0) < count)) goto LA3_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA3_: ;
	count += ((NI) 1);
	addQuoted__pureZos_449((&result), x.Field0);
	{
		if (!(((NI) 0) < count)) goto LA7_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA7_: ;
	count += ((NI) 1);
	{
		if (!(x.Field1 == 0)) goto LA11_;
		result = resizeString(result, 3);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_14));
	}
	goto LA9_;
	LA11_: ;
	{
		addQuoted__stdZjsonutils_445((&result), x.Field1);
	}
	LA9_: ;
	{
		if (!(count == ((NI) 1))) goto LA16_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA16_: ;
	result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_5));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, collectionToString__pureZjson_5362)(tySet_tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A x, NimStringDesc* prefix, NimStringDesc* separator, NimStringDesc* suffix) {
	NimStringDesc* result;
	NIM_BOOL firstElement;
	result = NIM_NIL;
	result = copyString(prefix);
	firstElement = NIM_TRUE;
	{
		tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A value;
		NI i;
		value = (tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A)0;
		i = ((NI) 0);
		{
			while (1) {
				if (!(i <= ((NI) 6))) goto LA3;
				{
					if (!((x &((NU8)1<<((NU)(((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) (i)))&7U)))!=0)) goto LA6_;
					value = ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) (i));
					{
						if (!firstElement) goto LA10_;
						firstElement = NIM_FALSE;
					}
					goto LA8_;
					LA10_: ;
					{
						result = resizeString(result, (separator ? separator->Sup.len : 0) + 0);
appendString(result, separator);
					}
					LA8_: ;
					addQuoted__pureZjson_5394((&result), value);
				}
				LA6_: ;
				i += ((NI) 1);
			} LA3: ;
		}
	}
	result = resizeString(result, (suffix ? suffix->Sup.len : 0) + 0);
appendString(result, suffix);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___pureZjson_5358)(tySet_tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A x) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = collectionToString__pureZjson_5362(x, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_9), ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3), ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_10));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___stdZjsonutils_505)(tyTuple__NZDXyOL9bXdVfZI9bh9asxScA x) {
	NimStringDesc* result;
	NI count;
	result = NIM_NIL;
	result = copyString(((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_2));
	count = ((NI) 0);
	{
		if (!(((NI) 0) < count)) goto LA3_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA3_: ;
	count += ((NI) 1);
	addQuoted__pureZos_449((&result), x.Field0);
	{
		if (!(((NI) 0) < count)) goto LA7_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA7_: ;
	count += ((NI) 1);
	addQuoted__pureZos_449((&result), x.Field1);
	{
		if (!(((NI) 0) < count)) goto LA11_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA11_: ;
	count += ((NI) 1);
	{
		if (!(x.Field2 == 0)) goto LA15_;
		result = resizeString(result, 3);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_14));
	}
	goto LA13_;
	LA15_: ;
	{
		addQuoted__stdZjsonutils_445((&result), x.Field2);
	}
	LA13_: ;
	{
		if (!(count == ((NI) 1))) goto LA20_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA20_: ;
	result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_5));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___extccomp_2072)(tyTuple__CWLiqluAXi3Y4RHZUwBh9bQ* x) {
	NimStringDesc* result;
	NI count;
	result = NIM_NIL;
	result = copyString(((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_2));
	count = ((NI) 0);
	{
		if (!(((NI) 0) < count)) goto LA3_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA3_: ;
	count += ((NI) 1);
	addQuoted__extccomp_2092((&result), (*x).Field0);
	{
		if (!(((NI) 0) < count)) goto LA7_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA7_: ;
	count += ((NI) 1);
	addQuoted__extccomp_2092((&result), (*x).Field1);
	{
		if (!(((NI) 0) < count)) goto LA11_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA11_: ;
	count += ((NI) 1);
	addQuoted__pureZos_449((&result), (*x).Field2);
	{
		if (!(((NI) 0) < count)) goto LA15_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA15_: ;
	count += ((NI) 1);
	{
		if (!((*x).Field3 == 0)) goto LA19_;
		result = resizeString(result, 3);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_14));
	}
	goto LA17_;
	LA19_: ;
	{
		addQuoted__stdZjsonutils_445((&result), (*x).Field3);
	}
	LA17_: ;
	{
		if (!(count == ((NI) 1))) goto LA24_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA24_: ;
	result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_5));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___extccomp_2443)(tyTuple__vHUW1Tno3SvNzAormr6Geg* x) {
	NimStringDesc* result;
	NI count;
	result = NIM_NIL;
	result = copyString(((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_2));
	count = ((NI) 0);
	{
		if (!(((NI) 0) < count)) goto LA3_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA3_: ;
	count += ((NI) 1);
	addQuoted__extccomp_2092((&result), (*x).Field0);
	{
		if (!(((NI) 0) < count)) goto LA7_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA7_: ;
	count += ((NI) 1);
	addQuoted__extccomp_2092((&result), (*x).Field1);
	{
		if (!(((NI) 0) < count)) goto LA11_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA11_: ;
	count += ((NI) 1);
	addQuoted__extccomp_2092((&result), (*x).Field2);
	{
		if (!(((NI) 0) < count)) goto LA15_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA15_: ;
	count += ((NI) 1);
	addQuoted__pureZos_449((&result), (*x).Field3);
	{
		if (!(((NI) 0) < count)) goto LA19_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA19_: ;
	count += ((NI) 1);
	{
		if (!((*x).Field4 == 0)) goto LA23_;
		result = resizeString(result, 3);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_14));
	}
	goto LA21_;
	LA23_: ;
	{
		addQuoted__stdZjsonutils_445((&result), (*x).Field4);
	}
	LA21_: ;
	{
		if (!(count == ((NI) 1))) goto LA28_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA28_: ;
	result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_5));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, collectionToString__pureZos_957)(tySet_tyEnum_FilePermission__Y2L2fCWnzUX27lSi9cRgTOQ x, NimStringDesc* prefix, NimStringDesc* separator, NimStringDesc* suffix) {
	NimStringDesc* result;
	NIM_BOOL firstElement;
	result = NIM_NIL;
	result = copyString(prefix);
	firstElement = NIM_TRUE;
	{
		tyEnum_FilePermission__Y2L2fCWnzUX27lSi9cRgTOQ value;
		NI i;
		value = (tyEnum_FilePermission__Y2L2fCWnzUX27lSi9cRgTOQ)0;
		i = ((NI) 0);
		{
			while (1) {
				if (!(i <= ((NI) 8))) goto LA3;
				{
					if (!((x &((NU16)1<<((NU)(((tyEnum_FilePermission__Y2L2fCWnzUX27lSi9cRgTOQ) (i)))&15U)))!=0)) goto LA6_;
					value = ((tyEnum_FilePermission__Y2L2fCWnzUX27lSi9cRgTOQ) (i));
					{
						if (!firstElement) goto LA10_;
						firstElement = NIM_FALSE;
					}
					goto LA8_;
					LA10_: ;
					{
						result = resizeString(result, (separator ? separator->Sup.len : 0) + 0);
appendString(result, separator);
					}
					LA8_: ;
					addQuoted__pureZos_989((&result), value);
				}
				LA6_: ;
				i += ((NI) 1);
			} LA3: ;
		}
	}
	result = resizeString(result, (suffix ? suffix->Sup.len : 0) + 0);
appendString(result, suffix);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___pureZos_953)(tySet_tyEnum_FilePermission__Y2L2fCWnzUX27lSi9cRgTOQ x) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = collectionToString__pureZos_957(x, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_9), ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3), ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_10));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___pureZos_862)(tyTuple__dQWEdGsliQQO27wHmA3anw x) {
	NimStringDesc* result;
	NI count;
	result = NIM_NIL;
	result = copyString(((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_2));
	count = ((NI) 0);
	{
		if (!(((NI) 0) < count)) goto LA3_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA3_: ;
	count += ((NI) 1);
	addQuoted__pureZos_449((&result), x.Field0);
	{
		if (!(((NI) 0) < count)) goto LA7_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA7_: ;
	count += ((NI) 1);
	addQuoted__pureZos_947((&result), x.Field1);
	{
		if (!(count == ((NI) 1))) goto LA11_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA11_: ;
	result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_5));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___jsgen_3158)(tyTuple__kUfCoroaC0rOCxJlya5Mfg x) {
	NimStringDesc* result;
	NI count;
	result = NIM_NIL;
	result = copyString(((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_2));
	count = ((NI) 0);
	{
		if (!(((NI) 0) < count)) goto LA3_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA3_: ;
	count += ((NI) 1);
	addQuoted__pureZos_449((&result), x.Field0);
	{
		if (!(((NI) 0) < count)) goto LA7_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA7_: ;
	count += ((NI) 1);
	addQuoted__jsgen_3192((&result), x.Field1);
	{
		if (!(count == ((NI) 1))) goto LA11_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA11_: ;
	result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_5));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___jsgen_2661)(tyTuple__x06rJgrLAhZPc8rLiIC9c6A x) {
	NimStringDesc* result;
	NI count;
	result = NIM_NIL;
	result = copyString(((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_2));
	count = ((NI) 0);
	{
		if (!(((NI) 0) < count)) goto LA3_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA3_: ;
	count += ((NI) 1);
	addQuoted__pureZos_449((&result), x.Field0);
	{
		if (!(((NI) 0) < count)) goto LA7_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA7_: ;
	count += ((NI) 1);
	addQuoted__jsgen_2695((&result), x.Field1);
	{
		if (!(((NI) 0) < count)) goto LA11_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA11_: ;
	count += ((NI) 1);
	addQuoted__jsgen_2695((&result), x.Field2);
	{
		if (!(count == ((NI) 1))) goto LA15_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA15_: ;
	result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_5));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___docgen_1072)(tyTuple__kN8up2W6YKc5YA9avn5mV5w x) {
	NimStringDesc* result;
	NI count;
	result = NIM_NIL;
	result = copyString(((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_2));
	count = ((NI) 0);
	{
		if (!(((NI) 0) < count)) goto LA3_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA3_: ;
	count += ((NI) 1);
	addQuoted__pureZos_449((&result), x.Field0);
	{
		if (!(((NI) 0) < count)) goto LA7_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA7_: ;
	count += ((NI) 1);
	addQuoted__extccomp_2092((&result), x.Field1);
	{
		if (!(((NI) 0) < count)) goto LA11_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA11_: ;
	count += ((NI) 1);
	addQuoted__extccomp_2092((&result), x.Field2);
	{
		if (!(count == ((NI) 1))) goto LA15_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA15_: ;
	result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_5));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___nimpaths_29)(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg x) {
	NimStringDesc* result;
	NI count;
	result = NIM_NIL;
	result = copyString(((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_2));
	count = ((NI) 0);
	{
		if (!(((NI) 0) < count)) goto LA3_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA3_: ;
	count += ((NI) 1);
	addQuoted__pureZos_449((&result), x.Field0);
	{
		if (!(((NI) 0) < count)) goto LA7_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA7_: ;
	count += ((NI) 1);
	addQuoted__pureZos_449((&result), x.Field1);
	{
		if (!(((NI) 0) < count)) goto LA11_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	}
	LA11_: ;
	count += ((NI) 1);
	addQuoted__pureZos_449((&result), x.Field2);
	{
		if (!(count == ((NI) 1))) goto LA15_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA15_: ;
	result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_5));
	return result;
}
