/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64
#define NIM_EmulateOverflowChecks

#include "nimbase.h"
#include <string.h>
#include <dirent.h>
#include <setjmp.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <time.h>
#include <glob.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct tyObject_Table__76RYD1bLMjqZSa5FAewcnw tyObject_Table__76RYD1bLMjqZSa5FAewcnw;
typedef struct tySequence__6j25whH7XTBoIXcM0x1T7A tySequence__6j25whH7XTBoIXcM0x1T7A;
typedef struct Exception Exception;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tySequence__QbmGqFaLnb1IWWToREeaIA tySequence__QbmGqFaLnb1IWWToREeaIA;
typedef struct TSafePoint TSafePoint;
typedef struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tyTuple__7q7q3E6Oj24ZNVJb9aonhAg;
typedef struct tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw;
typedef struct tyTuple__UV3llMMYFckfui8YMBuUZA tyTuple__UV3llMMYFckfui8YMBuUZA;
typedef struct tyTuple__9cdgeqdY7FRioNKBoD6G66A tyTuple__9cdgeqdY7FRioNKBoD6G66A;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
typedef struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
struct tyObject_Table__76RYD1bLMjqZSa5FAewcnw {
tySequence__6j25whH7XTBoIXcM0x1T7A* data;
NI counter;
};
typedef NU8 tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw;
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__QbmGqFaLnb1IWWToREeaIA* trace;
Exception* up;
};
struct TSafePoint {
TSafePoint* prev;
NI status;
jmp_buf context;
};
typedef NIM_CHAR tyArray__dTlC27m9c9aWd5dvuePYanug[256];
struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
};
struct tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw {
NI a;
NI b;
};
struct tyTuple__UV3llMMYFckfui8YMBuUZA {
NimStringDesc* Field0;
NimStringDesc* Field1;
};
struct tyTuple__9cdgeqdY7FRioNKBoD6G66A {
NI Field0;
NimStringDesc* Field1;
tyTuple__UV3llMMYFckfui8YMBuUZA Field2;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NCSTRING tyUncheckedArray__nvS6J9clHMUMHfoZd8Ad2zg[1];
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA {
NCSTRING procname;
NI line;
NCSTRING filename;
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__6j25whH7XTBoIXcM0x1T7A {
  TGenericSeq Sup;
  tyTuple__9cdgeqdY7FRioNKBoD6G66A data[SEQ_DECL_SIZE];
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
struct tySequence__QbmGqFaLnb1IWWToREeaIA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA data[SEQ_DECL_SIZE];
};
static N_INLINE(NIM_BOOL, contains__nimblecmd_15)(NimStringDesc** a, NI aLen_0, NimStringDesc* item);
static N_INLINE(NI, find__nimblecmd_20)(NimStringDesc** a, NI aLen_0, NimStringDesc* item);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___options_4108)(NimStringDesc* x, NimStringDesc* y);
N_LIB_PRIVATE N_NIMCALL(void, insert__nimblecmd_47)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ** x, NimStringDesc* item, NI i);
N_LIB_PRIVATE N_NIMCALL(void, addPathRec__nimblecmd_2083)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* dir, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringDesc* s);
N_LIB_PRIVATE N_NOINLINE(void, raiseOSError__pureZos_405)(NI32 errorCode, NimStringDesc* additionalInfo);
N_LIB_PRIVATE N_NIMCALL(NI32, osLastError__pureZos_408)(void);
static N_INLINE(void, pushSafePoint)(TSafePoint* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, cstrToNimstr)(NCSTRING str);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
static N_INLINE(NimStringDesc*, slash___pureZos_121)(NimStringDesc* head, NimStringDesc* tail);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosjoinPath)(NimStringDesc* head, NimStringDesc* tail);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosdirExists)(NimStringDesc* dir);
N_LIB_PRIVATE N_NIMCALL(tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw, getSymlinkFileKind__pureZos_1218)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(void, addPackage__nimblecmd_206)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_Table__76RYD1bLMjqZSa5FAewcnw* packages, NimStringDesc* p, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, getPathVersionChecksum__nimblecmd_171)(NimStringDesc* p, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(NI, nsuRFindChar)(NimStringDesc* s, NIM_CHAR sub, NI start, NI last);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__system_7786)(NimStringDesc* s, NI first);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isValidSha1Hash__stdZsha49_940)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NI, nsuRFindStr)(NimStringDesc* s, NimStringDesc* sub, NI start, NI last);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__system_7774)(NimStringDesc* s, NI first, NI last);
static N_INLINE(NimStringDesc*, X5BX5D___pureZunicode_865)(NimStringDesc* s, tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw x);
N_NIMCALL(NimStringDesc*, mnewString)(NI len);
static N_INLINE(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw, dotdot___pureZunicode_840)(NI a, NI b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isValidVersion__nimblecmd_135)(NimStringDesc* v);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, newVersion__nimblecmd_107)(NimStringDesc* ver);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__systemZassertions_56)(NimStringDesc* msg);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___nimblecmd_146)(NimStringDesc* ver, NimStringDesc* ver2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isSpecial__nimblecmd_132)(NimStringDesc* ver);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuNormalize)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ*, nsuSplitChar)(NimStringDesc* s, NIM_CHAR sep, NI maxsplit);
N_LIB_PRIVATE N_NIMCALL(NI, npuParseInt)(NimStringDesc* s, NI* number, NI start);
N_LIB_PRIVATE N_NIMCALL(void, getOrDefault__nimblecmd_281)(tyObject_Table__76RYD1bLMjqZSa5FAewcnw t, NimStringDesc* key, tyTuple__UV3llMMYFckfui8YMBuUZA* Result);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__nimblecmd_623)(tyObject_Table__76RYD1bLMjqZSa5FAewcnw t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___nimblecmd_676)(tyObject_Table__76RYD1bLMjqZSa5FAewcnw* t, NimStringDesc* key, tyTuple__UV3llMMYFckfui8YMBuUZA val);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__6j25whH7XTBoIXcM0x1T7A)(void* p, NI op);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
static N_INLINE(void, popSafePoint)(void);
N_LIB_PRIVATE N_NIMCALL(void, nimLeaveFinally)(void);
N_LIB_PRIVATE N_NIMCALL(void, reraiseException)(void);
N_LIB_PRIVATE N_NIMCALL(NI, len__nimblecmd_1808)(tyObject_Table__76RYD1bLMjqZSa5FAewcnw t);
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_31)(NI hcode);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(void, addNimblePath__nimblecmd_2053)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* p, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
static N_INLINE(void, decRef__system_5347)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5345)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5296)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5302)(void* usr);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ*, nsuSplitLines)(NimStringDesc* s, NIM_BOOL keepEol);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, readFile__systemZio_469)(NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosisAbsolute)(NimStringDesc* path);
static N_INLINE(NI, find__nimblecmd_2108)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* a, NimStringDesc* item);
N_LIB_PRIVATE N_NIMCALL(void, delete__nimblecmd_2127)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ** x, NI i);
STRING_LITERAL(TM__Xve3Bgye29aQqSXx0rQYUzw_3, ".", 1);
STRING_LITERAL(TM__Xve3Bgye29aQqSXx0rQYUzw_4, "..", 2);
STRING_LITERAL(TM__Xve3Bgye29aQqSXx0rQYUzw_5, "-#", 2);
STRING_LITERAL(TM__Xve3Bgye29aQqSXx0rQYUzw_6, "nimblecmd.nim(26, 11) `ver.len == 0 or ver[0] in {\'#\', \'\\x00\'} + Digits` Wrong version: ", 88);
STRING_LITERAL(TM__Xve3Bgye29aQqSXx0rQYUzw_7, "#head", 5);
N_LIB_PRIVATE TNimType NTIkeyvaluepair__9cdgeqdY7FRioNKBoD6G66A_;
extern TNimType NTIint__rR5Bzr1D5krxoo1NcNyeMA_;
extern TNimType NTIstring__77mFvmsOLKik79ci2hXkHEg_;
N_LIB_PRIVATE TNimType NTItupleLversion58string_checksum58stringT__UV3llMMYFckfui8YMBuUZA_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__6j25whH7XTBoIXcM0x1T7A_;
STRING_LITERAL(TM__Xve3Bgye29aQqSXx0rQYUzw_10, "invalid package name: ", 22);
STRING_LITERAL(TM__Xve3Bgye29aQqSXx0rQYUzw_12, "/home/runner/work/nightlies/nightlies/nim/compiler/nimblecmd.nim", 64);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Xve3Bgye29aQqSXx0rQYUzw_11 = {((NimStringDesc*) &TM__Xve3Bgye29aQqSXx0rQYUzw_12),
((NI) 113),
((NI) 14)}
;
STRING_LITERAL(TM__Xve3Bgye29aQqSXx0rQYUzw_13, "*.nimble-link", 13);
extern TNimType NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Xve3Bgye29aQqSXx0rQYUzw_15 = {((NimStringDesc*) &TM__Xve3Bgye29aQqSXx0rQYUzw_12),
((NI) 139),
((NI) 11)}
;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5249;
static N_INLINE(NI, find__nimblecmd_20)(NimStringDesc** a, NI aLen_0, NimStringDesc* item) {
	NI result;
{	result = (NI)0;
	result = ((NI) 0);
	{
		NimStringDesc** i;
		NI i_2;
		i = (NimStringDesc**)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < aLen_0)) goto LA3;
				i = (&a[i_2]);
				{
					NIM_BOOL T6_;
					T6_ = (NIM_BOOL)0;
					T6_ = eqeq___options_4108((*i), item);
					if (!T6_) goto LA7_;
					goto BeforeRet_;
				}
				LA7_: ;
				result += ((NI) 1);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__nimblecmd_15)(NimStringDesc** a, NI aLen_0, NimStringDesc* item) {
	NIM_BOOL result;
	NI T1_;
{	result = (NIM_BOOL)0;
	T1_ = (NI)0;
	T1_ = find__nimblecmd_20(a, aLen_0, item);
	result = (((NI) 0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addPath__nimblecmd_11)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* path, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = contains__nimblecmd_15(((*conf).searchPaths) ? ((*conf).searchPaths->data) : NIM_NIL, ((*conf).searchPaths ? (*conf).searchPaths->Sup.len : 0), path);
		if (!!(T3_)) goto LA4_;
		insert__nimblecmd_47((&(*conf).searchPaths), path, ((NI) 0));
	}
	LA4_: ;
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringDesc* s) {
	NCSTRING result;
	result = (NCSTRING)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (s == ((NimStringDesc*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = ((*s).Sup.len == ((NI) 0));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = "";
	}
	goto LA1_;
	LA5_: ;
	{
		result = ((NCSTRING) ((*s).data));
	}
	LA1_: ;
	return result;
}
static N_INLINE(void, pushSafePoint)(TSafePoint* s) {
	(*s).prev = excHandler__system_2565;
	excHandler__system_2565 = s;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NimStringDesc*, slash___pureZos_121)(NimStringDesc* head, NimStringDesc* tail) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = nosjoinPath(head, tail);
	return result;
}
static N_INLINE(NimStringDesc*, X5BX5D___pureZunicode_865)(NimStringDesc* s, tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw x) {
	NimStringDesc* result;
	NI a;
	NI L;
	result = NIM_NIL;
	a = x.a;
	L = (NI)((NI)(x.b - a) + ((NI) 1));
	result = mnewString(((NI) (L)));
	{
		NI i;
		NI i_2;
		i = (NI)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < L)) goto LA3;
				i = i_2;
				result->data[i] = s->data[(NI)(i + a)];
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
static N_INLINE(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw, dotdot___pureZunicode_840)(NI a, NI b) {
	tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw));
	result.a = a;
	result.b = b;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, getPathVersionChecksum__nimblecmd_171)(NimStringDesc* p, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result) {
	NI checksumSeparatorIndex;
	NI versionSeparatorIndex;
	tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw T21_;
	unsureAsgnRef((void**)&(*Result).Field0, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).Field1, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).Field2, NIM_NIL);
	checksumSeparatorIndex = nsuRFindChar(p, 45, ((NI) 0), ((NI) -1));
	{
		if (!!((checksumSeparatorIndex == ((NI) -1)))) goto LA3_;
		unsureAsgnRef((void**) (&(*Result).Field2), substr__system_7786(p, (NI)(checksumSeparatorIndex + ((NI) 1))));
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = isValidSha1Hash__stdZsha49_940((*Result).Field2);
			if (!!(T7_)) goto LA8_;
			unsureAsgnRef((void**) (&(*Result).Field2), ((NimStringDesc*) NIM_NIL));
			checksumSeparatorIndex = (p ? p->Sup.len : 0);
		}
		LA8_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		checksumSeparatorIndex = (p ? p->Sup.len : 0);
	}
	LA1_: ;
	versionSeparatorIndex = nsuRFindStr(p, ((NimStringDesc*) &TM__Xve3Bgye29aQqSXx0rQYUzw_5), ((NI) 0), (NI)(checksumSeparatorIndex - ((NI) 1)));
	{
		if (!!((versionSeparatorIndex == ((NI) -1)))) goto LA13_;
		unsureAsgnRef((void**) (&(*Result).Field1), substr__system_7774(p, (NI)(versionSeparatorIndex + ((NI) 1)), (NI)(checksumSeparatorIndex - ((NI) 1))));
	}
	goto LA11_;
	LA13_: ;
	{
		versionSeparatorIndex = nsuRFindChar(p, 45, ((NI) 0), (NI)(checksumSeparatorIndex - ((NI) 1)));
		{
			if (!!((versionSeparatorIndex == ((NI) -1)))) goto LA18_;
			unsureAsgnRef((void**) (&(*Result).Field1), substr__system_7774(p, (NI)(versionSeparatorIndex + ((NI) 1)), (NI)(checksumSeparatorIndex - ((NI) 1))));
		}
		goto LA16_;
		LA18_: ;
		{
			versionSeparatorIndex = checksumSeparatorIndex;
		}
		LA16_: ;
	}
	LA11_: ;
	T21_ = dotdot___pureZunicode_840(((NI) 0), (NI)(versionSeparatorIndex - ((NI) 1)));
	unsureAsgnRef((void**) (&(*Result).Field0), X5BX5D___pureZunicode_865(p, T21_));
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isValidVersion__nimblecmd_135)(NimStringDesc* v) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		if (!(((NI) 0) < (v ? v->Sup.len : 0))) goto LA3_;
		{
			if (!(((NU8)(v->data[((NI) 0)])) == ((NU8)(35)) || ((NU8)(v->data[((NI) 0)])) >= ((NU8)(48)) && ((NU8)(v->data[((NI) 0)])) <= ((NU8)(57)))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, newVersion__nimblecmd_107)(NimStringDesc* ver) {
	NimStringDesc* result;
{	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		NimStringDesc* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((ver ? ver->Sup.len : 0) == ((NI) 0));
		if (T3_) goto LA4_;
		T3_ = (((NU8)(ver->data[((NI) 0)])) == ((NU8)(0)) || ((NU8)(ver->data[((NI) 0)])) == ((NU8)(35)) || ((NU8)(ver->data[((NI) 0)])) >= ((NU8)(48)) && ((NU8)(ver->data[((NI) 0)])) <= ((NU8)(57)));
		LA4_: ;
		if (!!(T3_)) goto LA5_;
		T7_ = NIM_NIL;
		T7_ = rawNewString((ver ? ver->Sup.len : 0) + 88);
appendString(T7_, ((NimStringDesc*) &TM__Xve3Bgye29aQqSXx0rQYUzw_6));
appendString(T7_, ver);
		failedAssertImpl__systemZassertions_56(T7_);
	}
	LA5_: ;
	result = copyString(ver);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isSpecial__nimblecmd_132)(NimStringDesc* ver) {
	NIM_BOOL result;
	NIM_BOOL T1_;
{	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (((NI) 0) < (ver ? ver->Sup.len : 0));
	if (!(T1_)) goto LA2_;
	T1_ = ((NU8)(ver->data[((NI) 0)]) == (NU8)(35));
	LA2_: ;
	result = T1_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___nimblecmd_146)(NimStringDesc* ver, NimStringDesc* ver2) {
	NIM_BOOL result;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ* sVer;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ* sVer2;
{	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isSpecial__nimblecmd_132(ver);
		if (T3_) goto LA4_;
		T3_ = isSpecial__nimblecmd_132(ver2);
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			NIM_BOOL T9_;
			NimStringDesc* T11_;
			NimStringDesc* T14_;
			T9_ = (NIM_BOOL)0;
			T9_ = isSpecial__nimblecmd_132(ver2);
			if (!(T9_)) goto LA10_;
			T11_ = NIM_NIL;
			T11_ = nsuNormalize(ver2);
			T9_ = eqStrings(T11_, ((NimStringDesc*) &TM__Xve3Bgye29aQqSXx0rQYUzw_7));
			LA10_: ;
			if (!T9_) goto LA12_;
			T14_ = NIM_NIL;
			T14_ = nsuNormalize(ver);
			result = !(eqStrings(T14_, ((NimStringDesc*) &TM__Xve3Bgye29aQqSXx0rQYUzw_7)));
			goto BeforeRet_;
		}
		LA12_: ;
		{
			NIM_BOOL T17_;
			NimStringDesc* T20_;
			T17_ = (NIM_BOOL)0;
			T17_ = isSpecial__nimblecmd_132(ver2);
			if (!!(T17_)) goto LA18_;
			T20_ = NIM_NIL;
			T20_ = nsuNormalize(ver);
			result = !(eqStrings(T20_, ((NimStringDesc*) &TM__Xve3Bgye29aQqSXx0rQYUzw_7)));
			goto BeforeRet_;
		}
		LA18_: ;
	}
	LA5_: ;
	sVer = nsuSplitChar(ver, 46, ((NI) -1));
	sVer2 = nsuSplitChar(ver2, 46, ((NI) -1));
	{
		NI i;
		NI colontmp_;
		NI T22_;
		NI T23_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T22_ = (sVer ? sVer->Sup.len : 0);
		T23_ = (sVer2 ? sVer2->Sup.len : 0);
		colontmp_ = ((T22_ >= T23_) ? T22_ : T23_);
		i_2 = ((NI) 0);
		{
			while (1) {
				NI sVerI;
				NI sVerI2;
				if (!(i_2 < colontmp_)) goto LA25;
				i = i_2;
				sVerI = ((NI) 0);
				{
					NI T28_;
					NI T31_;
					T28_ = (sVer ? sVer->Sup.len : 0);
					if (!(i < T28_)) goto LA29_;
					T31_ = (NI)0;
					T31_ = npuParseInt(sVer->data[i], (&sVerI), ((NI) 0));
					(void)(T31_);
				}
				LA29_: ;
				sVerI2 = ((NI) 0);
				{
					NI T34_;
					NI T37_;
					T34_ = (sVer2 ? sVer2->Sup.len : 0);
					if (!(i < T34_)) goto LA35_;
					T37_ = (NI)0;
					T37_ = npuParseInt(sVer2->data[i], (&sVerI2), ((NI) 0));
					(void)(T37_);
				}
				LA35_: ;
				{
					if (!(sVerI < sVerI2)) goto LA40_;
					result = NIM_TRUE;
					goto BeforeRet_;
				}
				goto LA38_;
				LA40_: ;
				{
					if (!(sVerI == sVerI2)) goto LA43_;
				}
				goto LA38_;
				LA43_: ;
				{
					result = NIM_FALSE;
					goto BeforeRet_;
				}
				LA38_: ;
				i_2 += ((NI) 1);
			} LA25: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_NIMCALL(void, Marker_tySequence__6j25whH7XTBoIXcM0x1T7A)(void* p, NI op) {
	tySequence__6j25whH7XTBoIXcM0x1T7A* a;
	NI T1_;
	a = (tySequence__6j25whH7XTBoIXcM0x1T7A*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field1, op);
	nimGCvisit((void*)a->data[T1_].Field2.Field0, op);
	nimGCvisit((void*)a->data[T1_].Field2.Field1, op);
	}
}
N_LIB_PRIVATE N_NIMCALL(void, addPackage__nimblecmd_206)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_Table__76RYD1bLMjqZSa5FAewcnw* packages, NimStringDesc* p, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T1_;
	NimStringDesc* name;
	NimStringDesc* ver;
	NimStringDesc* checksum;
	nimZeroMem((void*)(&T1_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	getPathVersionChecksum__nimblecmd_171(p, (&T1_));
	name = NIM_NIL;
	name = T1_.Field0;
	ver = NIM_NIL;
	ver = T1_.Field1;
	checksum = NIM_NIL;
	checksum = T1_.Field2;
	{
		NIM_BOOL T4_;
		NimStringDesc* version;
		T4_ = (NIM_BOOL)0;
		T4_ = isValidVersion__nimblecmd_135(ver);
		if (!T4_) goto LA5_;
		version = newVersion__nimblecmd_107(ver);
		{
			NIM_BOOL T9_;
			tyTuple__UV3llMMYFckfui8YMBuUZA T10_;
			NimStringDesc* T11_;
			NIM_BOOL T13_;
			T9_ = (NIM_BOOL)0;
			nimZeroMem((void*)(&T10_), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
			getOrDefault__nimblecmd_281((*packages), name, (&T10_));
			T11_ = NIM_NIL;
			T11_ = newVersion__nimblecmd_107(T10_.Field0);
			T9_ = lt___nimblecmd_146(T11_, version);
			if (T9_) goto LA12_;
			T13_ = (NIM_BOOL)0;
			T13_ = hasKey__nimblecmd_623((*packages), name);
			T9_ = !(T13_);
			LA12_: ;
			if (!T9_) goto LA14_;
			{
				NIM_BOOL T18_;
				tyTuple__UV3llMMYFckfui8YMBuUZA T21_;
				T18_ = (NIM_BOOL)0;
				T18_ = isValidSha1Hash__stdZsha49_940(checksum);
				if (!T18_) goto LA19_;
				nimZeroMem((void*)(&T21_), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
				T21_.Field0 = copyString(version);
				T21_.Field1 = copyString(checksum);
				X5BX5Deq___nimblecmd_676(packages, name, T21_);
			}
			goto LA16_;
			LA19_: ;
			{
				tyTuple__UV3llMMYFckfui8YMBuUZA T23_;
				nimZeroMem((void*)(&T23_), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
				T23_.Field0 = copyString(version);
				T23_.Field1 = ((NimStringDesc*) NIM_NIL);
				X5BX5Deq___nimblecmd_676(packages, name, T23_);
			}
			LA16_: ;
		}
		LA14_: ;
	}
	goto LA2_;
	LA5_: ;
	{
		NimStringDesc* T25_;
		T25_ = NIM_NIL;
		T25_ = rawNewString((p ? p->Sup.len : 0) + 22);
appendString(T25_, ((NimStringDesc*) &TM__Xve3Bgye29aQqSXx0rQYUzw_10));
appendString(T25_, p);
		liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T25_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__Xve3Bgye29aQqSXx0rQYUzw_11, NIM_FALSE);
	}
	LA2_: ;
}
static N_INLINE(void, popSafePoint)(void) {
	excHandler__system_2565 = (*excHandler__system_2565).prev;
}
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_31)(NI hcode) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = !((hcode == ((NI) 0)));
	return result;
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5345)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5296((&gch__system_5249.zct), c);
}
static N_INLINE(void, decRef__system_5347)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5345(c);
	}
	LA4_: ;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5302)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5302(p);
	decRef__system_5347(T1_);
}
N_LIB_PRIVATE N_NIMCALL(void, addNimblePath__nimblecmd_2053)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* p, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NimStringDesc* path;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimbleLinks;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ* resultX60gensym38_;
	path = copyString(p);
	resultX60gensym38_ = NIM_NIL;
	{
		NimStringDesc* xX60gensym38_;
		NimStringDesc* colontmp_;
		glob_t fX60gensym133_;
		NI resX60gensym133_;
		int T2_;
		TSafePoint TM__Xve3Bgye29aQqSXx0rQYUzw_14;
		xX60gensym38_ = NIM_NIL;
		colontmp_ = NIM_NIL;
		colontmp_ = slash___pureZos_121(p, ((NimStringDesc*) &TM__Xve3Bgye29aQqSXx0rQYUzw_13));
		nimZeroMem((void*)(&fX60gensym133_), sizeof(glob_t));
		resX60gensym133_ = (NI)0;
		fX60gensym133_.gl_offs = ((NI) 0);
		fX60gensym133_.gl_pathc = ((NI) 0);
		fX60gensym133_.gl_pathv = ((NCSTRING*) NIM_NIL);
		T2_ = (int)0;
		T2_ = glob(nimToCStringConv(colontmp_), ((int) 0), NIM_NIL, (&fX60gensym133_));
		resX60gensym133_ = ((NI) (T2_));
		pushSafePoint(&TM__Xve3Bgye29aQqSXx0rQYUzw_14);
		TM__Xve3Bgye29aQqSXx0rQYUzw_14.status = _setjmp(TM__Xve3Bgye29aQqSXx0rQYUzw_14.context);
		if (TM__Xve3Bgye29aQqSXx0rQYUzw_14.status == 0) {
		{
			if (!(resX60gensym133_ == ((NI) 0))) goto LA5_;
			{
				NI iX60gensym133_;
				NI colontmp__2;
				NI res;
				iX60gensym133_ = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = (NI)(fX60gensym133_.gl_pathc - ((NI) 1));
				res = ((NI) 0);
				{
					while (1) {
						NimStringDesc* pathX60gensym133_;
						if (!(res <= colontmp__2)) goto LA9;
						iX60gensym133_ = res;
						pathX60gensym133_ = cstrToNimstr(fX60gensym133_.gl_pathv[iX60gensym133_]);
						{
							NI T14_;
							NimStringDesc* T15_;
							if (!NIM_TRUE) goto LA12_;
							xX60gensym38_ = pathX60gensym133_;
							resultX60gensym38_ = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)(resultX60gensym38_), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_));
							T14_ = resultX60gensym38_->Sup.len++;
							T15_ = NIM_NIL;
							T15_ = resultX60gensym38_->data[T14_]; resultX60gensym38_->data[T14_] = copyStringRC1(xX60gensym38_);
							if (T15_) nimGCunrefNoCycle(T15_);
						}
						LA12_: ;
						res += ((NI) 1);
					} LA9: ;
				}
			}
		}
		LA5_: ;
		popSafePoint();
		}
		else {
			popSafePoint();
		}
		{
			globfree((&fX60gensym133_));
			if (TM__Xve3Bgye29aQqSXx0rQYUzw_14.status != 0) nimLeaveFinally();
		}
		if (TM__Xve3Bgye29aQqSXx0rQYUzw_14.status != 0) reraiseException();
	}
	nimbleLinks = resultX60gensym38_;
	{
		NI T20_;
		tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimbleLinkLines;
		NimStringDesc* T23_;
		T20_ = (nimbleLinks ? nimbleLinks->Sup.len : 0);
		if (!(((NI) 0) < T20_)) goto LA21_;
		T23_ = NIM_NIL;
		T23_ = readFile__systemZio_469(nimbleLinks->data[((NI) 0)]);
		nimbleLinkLines = nsuSplitLines(T23_, NIM_FALSE);
		path = copyString(nimbleLinkLines->data[((NI) 1)]);
		{
			NIM_BOOL T26_;
			T26_ = (NIM_BOOL)0;
			T26_ = nosisAbsolute(path);
			if (!!(T26_)) goto LA27_;
			path = slash___pureZos_121(p, path);
		}
		LA27_: ;
	}
	LA21_: ;
	{
		NIM_BOOL T31_;
		T31_ = (NIM_BOOL)0;
		T31_ = contains__nimblecmd_15(((*conf).searchPaths) ? ((*conf).searchPaths->data) : NIM_NIL, ((*conf).searchPaths ? (*conf).searchPaths->Sup.len : 0), path);
		if (!!(T31_)) goto LA32_;
		liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 88), path, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__Xve3Bgye29aQqSXx0rQYUzw_15, NIM_FALSE);
		insert__nimblecmd_47((&(*conf).lazyPaths), path, ((NI) 0));
	}
	LA32_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addPathRec__nimblecmd_2083)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* dir, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_Table__76RYD1bLMjqZSa5FAewcnw packages;
	NI pos;
	nimZeroMem((void*)(&packages), sizeof(tyObject_Table__76RYD1bLMjqZSa5FAewcnw));
	pos = (NI)((dir ? dir->Sup.len : 0) - ((NI) 1));
	{
		if (!(((NU8)(dir->data[pos])) == ((NU8)(47)) || ((NU8)(dir->data[pos])) == ((NU8)(47)))) goto LA3_;
		pos += ((NI) 1);
	}
	LA3_: ;
	{
		tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw k;
		NimStringDesc* p;
		DIR* d;
		k = (tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw)0;
		p = NIM_NIL;
		d = opendir(nimToCStringConv(dir));
		{
			if (!(d == ((DIR*) NIM_NIL))) goto LA8_;
			{
				NI32 T14_;
				if (!NIM_FALSE) goto LA12_;
				T14_ = (NI32)0;
				T14_ = osLastError__pureZos_408();
				raiseOSError__pureZos_405(T14_, dir);
			}
			LA12_: ;
		}
		goto LA6_;
		LA8_: ;
		{
			TSafePoint TM__Xve3Bgye29aQqSXx0rQYUzw_2;
			pushSafePoint(&TM__Xve3Bgye29aQqSXx0rQYUzw_2);
			TM__Xve3Bgye29aQqSXx0rQYUzw_2.status = _setjmp(TM__Xve3Bgye29aQqSXx0rQYUzw_2.context);
			if (TM__Xve3Bgye29aQqSXx0rQYUzw_2.status == 0) {
			{
				while (1) {
					{
						struct dirent* x;
						NimStringDesc* y;
						x = readdir(d);
						{
							if (!(x == ((struct dirent*) NIM_NIL))) goto LA21_;
							goto LA16;
						}
						LA21_: ;
						y = cstrToNimstr(((NCSTRING) ((*x).d_name)));
						{
							NIM_BOOL T25_;
							struct stat s;
							NimStringDesc* path;
							tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw k_2;
							T25_ = (NIM_BOOL)0;
							T25_ = !(eqStrings(y, ((NimStringDesc*) &TM__Xve3Bgye29aQqSXx0rQYUzw_3)));
							if (!(T25_)) goto LA26_;
							T25_ = !(eqStrings(y, ((NimStringDesc*) &TM__Xve3Bgye29aQqSXx0rQYUzw_4)));
							LA26_: ;
							if (!T25_) goto LA27_;
							nimZeroMem((void*)(&s), sizeof(struct stat));
							path = slash___pureZos_121(dir, y);
							{
								if (!NIM_TRUE) goto LA31_;
								y = copyString(path);
							}
							LA31_: ;
							k_2 = ((tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw) 0);
							switch ((*x).d_type) {
							case ((NI) 4):
							{
								k_2 = ((tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw) 2);
							}
							break;
							case ((NI) 10):
							{
								{
									NIM_BOOL T37_;
									T37_ = (NIM_BOOL)0;
									T37_ = nosdirExists(path);
									if (!T37_) goto LA38_;
									k_2 = ((tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw) 3);
								}
								goto LA35_;
								LA38_: ;
								{
									k_2 = ((tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw) 1);
								}
								LA35_: ;
							}
							break;
							case ((NI) 0):
							{
								{
									int T44_;
									T44_ = (int)0;
									T44_ = lstat(nimToCStringConv(path), (&s));
									if (!(T44_ < ((NI32) 0))) goto LA45_;
									goto LA18;
								}
								goto LA42_;
								LA45_: ;
								{
									NIM_BOOL T48_;
									T48_ = (NIM_BOOL)0;
									T48_ = S_ISDIR(s.st_mode);
									if (!T48_) goto LA49_;
									k_2 = ((tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw) 2);
								}
								goto LA42_;
								LA49_: ;
								{
									NIM_BOOL T52_;
									T52_ = (NIM_BOOL)0;
									T52_ = S_ISLNK(s.st_mode);
									if (!T52_) goto LA53_;
									k_2 = getSymlinkFileKind__pureZos_1218(path);
								}
								goto LA42_;
								LA53_: ;
								LA42_: ;
							}
							break;
							default:
							{
							}
							break;
							}
							k = k_2;
							p = y;
							{
								NIM_BOOL T58_;
								T58_ = (NIM_BOOL)0;
								T58_ = (k == ((tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw) 2));
								if (!(T58_)) goto LA59_;
								T58_ = !(((NU8)(p->data[pos]) == (NU8)(46)));
								LA59_: ;
								if (!T58_) goto LA60_;
								addPackage__nimblecmd_206(conf, (&packages), p, info);
							}
							LA60_: ;
						}
						LA27_: ;
					} LA18: ;
				}
			} LA16: ;
			popSafePoint();
			}
			else {
				popSafePoint();
			}
			{
				int T64_;
				T64_ = (int)0;
				T64_ = closedir(d);
				(void)(T64_);
				if (TM__Xve3Bgye29aQqSXx0rQYUzw_2.status != 0) nimLeaveFinally();
			}
			if (TM__Xve3Bgye29aQqSXx0rQYUzw_2.status != 0) reraiseException();
		}
		LA6_: ;
	}
	{
		NimStringDesc* p_2;
		p_2 = NIM_NIL;
		{
			NimStringDesc* key;
			tyTuple__UV3llMMYFckfui8YMBuUZA val;
			NI L;
			key = NIM_NIL;
			nimZeroMem((void*)(&val), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
			L = len__nimblecmd_1808(packages);
			{
				NI h;
				NI colontmp_;
				NI T68_;
				NI res;
				h = (NI)0;
				colontmp_ = (NI)0;
				T68_ = ((packages.data ? packages.data->Sup.len : 0)-1);
				colontmp_ = T68_;
				res = ((NI) 0);
				{
					while (1) {
						if (!(res <= colontmp_)) goto LA70;
						h = res;
						{
							NIM_BOOL T73_;
							NimStringDesc* res_2;
							T73_ = (NIM_BOOL)0;
							T73_ = isFilled__pureZcollectionsZtables_31(packages.data->data[h].Field0);
							if (!T73_) goto LA74_;
							key = packages.data->data[h].Field1;
							val.Field0 = packages.data->data[h].Field2.Field0;
							val.Field1 = packages.data->data[h].Field2.Field1;
							res_2 = copyString(key);
							{
								if (!!(((val.Field0 ? val.Field0->Sup.len : 0) == ((NI) 0)))) goto LA78_;
								res_2 = addChar(res_2, 45);
								res_2 = resizeString(res_2, (val.Field0 ? val.Field0->Sup.len : 0) + 0);
appendString(res_2, val.Field0);
							}
							LA78_: ;
							{
								if (!!(((val.Field1 ? val.Field1->Sup.len : 0) == ((NI) 0)))) goto LA82_;
								res_2 = addChar(res_2, 45);
								res_2 = resizeString(res_2, (val.Field1 ? val.Field1->Sup.len : 0) + 0);
appendString(res_2, val.Field1);
							}
							LA82_: ;
							p_2 = res_2;
							addNimblePath__nimblecmd_2053(conf, p_2, info);
						}
						LA74_: ;
						res += ((NI) 1);
					} LA70: ;
				}
			}
		}
	}
}
static N_INLINE(NI, find__nimblecmd_2108)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* a, NimStringDesc* item) {
	NI result;
{	result = (NI)0;
	result = ((NI) 0);
	{
		NimStringDesc** i;
		NI i_2;
		NI L;
		NI T2_;
		i = (NimStringDesc**)0;
		i_2 = ((NI) 0);
		T2_ = (a ? a->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i_2 < L)) goto LA4;
				i = (&a->data[i_2]);
				{
					NIM_BOOL T7_;
					T7_ = (NIM_BOOL)0;
					T7_ = eqeq___options_4108((*i), item);
					if (!T7_) goto LA8_;
					goto BeforeRet_;
				}
				LA8_: ;
				result += ((NI) 1);
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, nimblePath__nimblecmd_2104)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* path, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NI i;
	addPathRec__nimblecmd_2083(conf, path, info);
	addNimblePath__nimblecmd_2053(conf, path, info);
	i = find__nimblecmd_2108((*conf).nimblePaths, path);
	{
		if (!!((i == ((NI) -1)))) goto LA3_;
		delete__nimblecmd_2127((&(*conf).nimblePaths), ((NI) (i)));
	}
	LA3_: ;
	insert__nimblecmd_47((&(*conf).nimblePaths), path, ((NI) 0));
}
N_LIB_PRIVATE N_NIMCALL(void, atmnimblecmddotnim_DatInit000)(void) {
static TNimNode* TM__Xve3Bgye29aQqSXx0rQYUzw_8_3[3];
static TNimNode* TM__Xve3Bgye29aQqSXx0rQYUzw_9_2[2];
static TNimNode TM__Xve3Bgye29aQqSXx0rQYUzw_0[7];
NTIkeyvaluepair__9cdgeqdY7FRioNKBoD6G66A_.size = sizeof(tyTuple__9cdgeqdY7FRioNKBoD6G66A);
NTIkeyvaluepair__9cdgeqdY7FRioNKBoD6G66A_.align = NIM_ALIGNOF(tyTuple__9cdgeqdY7FRioNKBoD6G66A);
NTIkeyvaluepair__9cdgeqdY7FRioNKBoD6G66A_.kind = 18;
NTIkeyvaluepair__9cdgeqdY7FRioNKBoD6G66A_.base = 0;
NTIkeyvaluepair__9cdgeqdY7FRioNKBoD6G66A_.flags = 2;
TM__Xve3Bgye29aQqSXx0rQYUzw_8_3[0] = &TM__Xve3Bgye29aQqSXx0rQYUzw_0[1];
TM__Xve3Bgye29aQqSXx0rQYUzw_0[1].kind = 1;
TM__Xve3Bgye29aQqSXx0rQYUzw_0[1].offset = offsetof(tyTuple__9cdgeqdY7FRioNKBoD6G66A, Field0);
TM__Xve3Bgye29aQqSXx0rQYUzw_0[1].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__Xve3Bgye29aQqSXx0rQYUzw_0[1].name = "Field0";
TM__Xve3Bgye29aQqSXx0rQYUzw_8_3[1] = &TM__Xve3Bgye29aQqSXx0rQYUzw_0[2];
TM__Xve3Bgye29aQqSXx0rQYUzw_0[2].kind = 1;
TM__Xve3Bgye29aQqSXx0rQYUzw_0[2].offset = offsetof(tyTuple__9cdgeqdY7FRioNKBoD6G66A, Field1);
TM__Xve3Bgye29aQqSXx0rQYUzw_0[2].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__Xve3Bgye29aQqSXx0rQYUzw_0[2].name = "Field1";
TM__Xve3Bgye29aQqSXx0rQYUzw_8_3[2] = &TM__Xve3Bgye29aQqSXx0rQYUzw_0[3];
NTItupleLversion58string_checksum58stringT__UV3llMMYFckfui8YMBuUZA_.size = sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA);
NTItupleLversion58string_checksum58stringT__UV3llMMYFckfui8YMBuUZA_.align = NIM_ALIGNOF(tyTuple__UV3llMMYFckfui8YMBuUZA);
NTItupleLversion58string_checksum58stringT__UV3llMMYFckfui8YMBuUZA_.kind = 18;
NTItupleLversion58string_checksum58stringT__UV3llMMYFckfui8YMBuUZA_.base = 0;
NTItupleLversion58string_checksum58stringT__UV3llMMYFckfui8YMBuUZA_.flags = 2;
TM__Xve3Bgye29aQqSXx0rQYUzw_9_2[0] = &TM__Xve3Bgye29aQqSXx0rQYUzw_0[5];
TM__Xve3Bgye29aQqSXx0rQYUzw_0[5].kind = 1;
TM__Xve3Bgye29aQqSXx0rQYUzw_0[5].offset = offsetof(tyTuple__UV3llMMYFckfui8YMBuUZA, Field0);
TM__Xve3Bgye29aQqSXx0rQYUzw_0[5].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__Xve3Bgye29aQqSXx0rQYUzw_0[5].name = "Field0";
TM__Xve3Bgye29aQqSXx0rQYUzw_9_2[1] = &TM__Xve3Bgye29aQqSXx0rQYUzw_0[6];
TM__Xve3Bgye29aQqSXx0rQYUzw_0[6].kind = 1;
TM__Xve3Bgye29aQqSXx0rQYUzw_0[6].offset = offsetof(tyTuple__UV3llMMYFckfui8YMBuUZA, Field1);
TM__Xve3Bgye29aQqSXx0rQYUzw_0[6].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__Xve3Bgye29aQqSXx0rQYUzw_0[6].name = "Field1";
TM__Xve3Bgye29aQqSXx0rQYUzw_0[4].len = 2; TM__Xve3Bgye29aQqSXx0rQYUzw_0[4].kind = 2; TM__Xve3Bgye29aQqSXx0rQYUzw_0[4].sons = &TM__Xve3Bgye29aQqSXx0rQYUzw_9_2[0];
NTItupleLversion58string_checksum58stringT__UV3llMMYFckfui8YMBuUZA_.node = &TM__Xve3Bgye29aQqSXx0rQYUzw_0[4];
TM__Xve3Bgye29aQqSXx0rQYUzw_0[3].kind = 1;
TM__Xve3Bgye29aQqSXx0rQYUzw_0[3].offset = offsetof(tyTuple__9cdgeqdY7FRioNKBoD6G66A, Field2);
TM__Xve3Bgye29aQqSXx0rQYUzw_0[3].typ = (&NTItupleLversion58string_checksum58stringT__UV3llMMYFckfui8YMBuUZA_);
TM__Xve3Bgye29aQqSXx0rQYUzw_0[3].name = "Field2";
TM__Xve3Bgye29aQqSXx0rQYUzw_0[0].len = 3; TM__Xve3Bgye29aQqSXx0rQYUzw_0[0].kind = 2; TM__Xve3Bgye29aQqSXx0rQYUzw_0[0].sons = &TM__Xve3Bgye29aQqSXx0rQYUzw_8_3[0];
NTIkeyvaluepair__9cdgeqdY7FRioNKBoD6G66A_.node = &TM__Xve3Bgye29aQqSXx0rQYUzw_0[0];
NTIkeyvaluepairseq__6j25whH7XTBoIXcM0x1T7A_.size = sizeof(tySequence__6j25whH7XTBoIXcM0x1T7A*);
NTIkeyvaluepairseq__6j25whH7XTBoIXcM0x1T7A_.align = NIM_ALIGNOF(tySequence__6j25whH7XTBoIXcM0x1T7A*);
NTIkeyvaluepairseq__6j25whH7XTBoIXcM0x1T7A_.kind = 24;
NTIkeyvaluepairseq__6j25whH7XTBoIXcM0x1T7A_.base = (&NTIkeyvaluepair__9cdgeqdY7FRioNKBoD6G66A_);
NTIkeyvaluepairseq__6j25whH7XTBoIXcM0x1T7A_.flags = 2;
NTIkeyvaluepairseq__6j25whH7XTBoIXcM0x1T7A_.marker = Marker_tySequence__6j25whH7XTBoIXcM0x1T7A;
}

