/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 32

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU16 tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw;
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuNormalize)(NimStringDesc* s);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(NI, hashString)(NimStringDesc* s);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_2, "success", 7);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_3, "successx", 8);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_4, "cc", 2);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_5, "linetoolong", 11);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_6, "xdeclaredbutnotused", 19);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_7, "duplicatemoduleimport", 21);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_8, "xcannotraisey", 13);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_9, "convtobasenotneeded", 19);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_10, "convfromxtoitselfnotneeded", 26);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_11, "expralwaysx", 11);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_12, "quitcalled", 10);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_13, "processing", 10);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_14, "processingstmt", 14);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_15, "codebegin", 9);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_16, "codeend", 7);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_17, "conf", 4);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_18, "path", 4);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_19, "condtrue", 8);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_20, "condfalse", 9);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_21, "name", 4);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_22, "pattern", 7);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_23, "exec", 4);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_24, "link", 4);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_25, "dependency", 10);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_26, "source", 6);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_27, "performance", 11);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_28, "stacktrace", 10);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_29, "gcstats", 7);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_30, "globalvar", 9);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_31, "expandmacro", 11);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_32, "user", 4);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_33, "userraw", 7);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_34, "extendedcontext", 15);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_35, "msgorigin", 9);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_36, "declaredloc", 11);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_37, "cannotopenfile", 14);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_38, "octalescape", 11);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_39, "xisneverread", 12);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_40, "xmightnotbeeninit", 17);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_41, "deprecated", 10);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_42, "configdeprecated", 16);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_43, "dotlikeops", 10);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_44, "smalllshouldnotbeused", 21);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_45, "unknownmagic", 12);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_46, "redefinitionoflabel", 19);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_47, "unknownsubstitutionx", 20);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_48, "brokenlink", 10);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_49, "languagexnotsupported", 21);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_50, "fieldxnotsupported", 18);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_51, "warnrststyle", 12);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_52, "commentxignored", 15);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_53, "typelessparam", 13);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_54, "usebase", 7);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_55, "writetoforeignheap", 18);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_56, "unsafecode", 10);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_57, "unusedimport", 12);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_58, "inheritfromexception", 20);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_59, "eachidentistuple", 16);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_60, "unsafesetlen", 12);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_61, "unsafedefault", 13);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_62, "proveinit", 9);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_63, "provefield", 10);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_64, "proveindex", 10);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_65, "unreachableelse", 15);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_66, "unreachablecode", 15);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_67, "indexcheck", 10);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_68, "gcunsafe", 8);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_69, "gcunsafe2", 9);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_70, "uninit", 6);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_71, "gcmem", 5);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_72, "destructor", 10);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_73, "locklevel", 9);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_74, "resultshadowed", 14);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_75, "spacing", 7);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_76, "casetransition", 14);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_77, "cyclecreated", 12);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_78, "observablestores", 16);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_79, "strictnotnil", 12);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_80, "resultused", 10);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_81, "cannotopen", 10);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_82, "filechanged", 11);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_83, "enumconv", 8);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_84, "anyenumconv", 11);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_85, "holeenumconv", 12);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_86, "cstringconv", 11);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_87, "ptrtocstringconv", 16);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_88, "effect", 6);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_89, "bareexcept", 10);
STRING_LITERAL(TM__48S29b8u8ONh7ZDjWcviuGA_90, "castsizes", 9);
N_LIB_PRIVATE TNimType NTItspecialword__N2XsqTpO5IzOf2KmXwk4Dw_;
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ, findStr__commands_321)(NimStringDesc* s, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ default_0) {
	tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ result;
	NimStringDesc* T1_;
	result = (tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ)0;
	T1_ = NIM_NIL;
	T1_ = nsuNormalize(s);
	switch (hashString(T1_) & 63) {
	case 1: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_8))) goto LA8_;
break;
	case 2: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_9))) goto LA9_;
break;
	case 6: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_6))) goto LA6_;
break;
	case 10: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_4))) goto LA4_;
break;
	case 12: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_32))) goto LA32_;
break;
	case 14: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_33))) goto LA33_;
break;
	case 15: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_23))) goto LA23_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_35))) goto LA35_;
break;
	case 16: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_2))) goto LA2_;
break;
	case 20: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_21))) goto LA21_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_34))) goto LA34_;
break;
	case 25: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_3))) goto LA3_;
break;
	case 30: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_14))) goto LA14_;
break;
	case 32: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_26))) goto LA26_;
break;
	case 33: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_20))) goto LA20_;
break;
	case 40: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_25))) goto LA25_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_28))) goto LA28_;
break;
	case 41: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_30))) goto LA30_;
break;
	case 42: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_11))) goto LA11_;
break;
	case 43: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_7))) goto LA7_;
break;
	case 44: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_12))) goto LA12_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_29))) goto LA29_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_36))) goto LA36_;
break;
	case 47: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_13))) goto LA13_;
break;
	case 48: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_24))) goto LA24_;
break;
	case 49: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_15))) goto LA15_;
break;
	case 53: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_10))) goto LA10_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_18))) goto LA18_;
break;
	case 54: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_17))) goto LA17_;
break;
	case 56: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_16))) goto LA16_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_31))) goto LA31_;
break;
	case 57: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_22))) goto LA22_;
break;
	case 61: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_5))) goto LA5_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_19))) goto LA19_;
break;
	case 63: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_27))) goto LA27_;
break;
	}
	goto LA37_;
	LA2_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 72);
	}
	goto LA38_;
	LA3_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 73);
	}
	goto LA38_;
	LA4_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 74);
	}
	goto LA38_;
	LA5_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 75);
	}
	goto LA38_;
	LA6_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 76);
	}
	goto LA38_;
	LA7_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 77);
	}
	goto LA38_;
	LA8_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 78);
	}
	goto LA38_;
	LA9_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 79);
	}
	goto LA38_;
	LA10_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 80);
	}
	goto LA38_;
	LA11_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 81);
	}
	goto LA38_;
	LA12_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 82);
	}
	goto LA38_;
	LA13_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 83);
	}
	goto LA38_;
	LA14_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 84);
	}
	goto LA38_;
	LA15_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 85);
	}
	goto LA38_;
	LA16_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 86);
	}
	goto LA38_;
	LA17_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 87);
	}
	goto LA38_;
	LA18_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 88);
	}
	goto LA38_;
	LA19_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 89);
	}
	goto LA38_;
	LA20_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 90);
	}
	goto LA38_;
	LA21_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 91);
	}
	goto LA38_;
	LA22_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 92);
	}
	goto LA38_;
	LA23_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 93);
	}
	goto LA38_;
	LA24_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 94);
	}
	goto LA38_;
	LA25_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 95);
	}
	goto LA38_;
	LA26_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 96);
	}
	goto LA38_;
	LA27_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 97);
	}
	goto LA38_;
	LA28_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 98);
	}
	goto LA38_;
	LA29_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 99);
	}
	goto LA38_;
	LA30_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 100);
	}
	goto LA38_;
	LA31_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 101);
	}
	goto LA38_;
	LA32_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 102);
	}
	goto LA38_;
	LA33_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 103);
	}
	goto LA38_;
	LA34_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 104);
	}
	goto LA38_;
	LA35_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 105);
	}
	goto LA38_;
	LA36_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 106);
	}
	goto LA38_;
	LA37_: ;
	{
		result = default_0;
	}
	LA38_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ, findStr__commands_352)(NimStringDesc* s, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ default_0) {
	tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ result;
	NimStringDesc* T1_;
	result = (tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ)0;
	T1_ = NIM_NIL;
	T1_ = nsuNormalize(s);
	switch (hashString(T1_) & 63) {
	case 1: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_46))) goto LA11_;
break;
	case 7: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_51))) goto LA16_;
break;
	case 8: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_78))) goto LA43_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_86))) goto LA51_;
break;
	case 12: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_32))) goto LA56_;
break;
	case 15: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_61))) goto LA26_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_71))) goto LA36_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_72))) goto LA37_;
break;
	case 16: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_63))) goto LA28_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_64))) goto LA29_;
break;
	case 17: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_82))) goto LA47_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_85))) goto LA50_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_89))) goto LA54_;
break;
	case 18: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_58))) goto LA23_;
break;
	case 19: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_74))) goto LA39_;
break;
	case 21: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_62))) goto LA27_;
break;
	case 22: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_68))) goto LA33_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_83))) goto LA48_;
break;
	case 25: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_41))) goto LA6_;
break;
	case 27: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_73))) goto LA38_;
break;
	case 28: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_37))) goto LA2_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_39))) goto LA4_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_76))) goto LA41_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_81))) goto LA46_;
break;
	case 30: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_57))) goto LA22_;
break;
	case 31: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_40))) goto LA5_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_55))) goto LA20_;
break;
	case 32: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_65))) goto LA30_;
break;
	case 33: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_38))) goto LA3_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_66))) goto LA31_;
break;
	case 34: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_80))) goto LA45_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_90))) goto LA55_;
break;
	case 35: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_67))) goto LA32_;
break;
	case 36: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_59))) goto LA24_;
break;
	case 37: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_79))) goto LA44_;
break;
	case 39: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_44))) goto LA9_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_49))) goto LA14_;
break;
	case 41: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_70))) goto LA35_;
break;
	case 43: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_47))) goto LA12_;
break;
	case 46: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_42))) goto LA7_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_52))) goto LA17_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_53))) goto LA18_;
break;
	case 48: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_69))) goto LA34_;
break;
	case 50: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_43))) goto LA8_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_45))) goto LA10_;
break;
	case 51: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_88))) goto LA53_;
break;
	case 53: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_77))) goto LA42_;
break;
	case 57: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_50))) goto LA15_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_54))) goto LA19_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_60))) goto LA25_;
break;
	case 58: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_48))) goto LA13_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_87))) goto LA52_;
break;
	case 62: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_75))) goto LA40_;
break;
	case 63: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_56))) goto LA21_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__48S29b8u8ONh7ZDjWcviuGA_84))) goto LA49_;
break;
	}
	goto LA57_;
	LA2_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 17);
	}
	goto LA58_;
	LA3_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 18);
	}
	goto LA58_;
	LA4_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 19);
	}
	goto LA58_;
	LA5_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 20);
	}
	goto LA58_;
	LA6_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 21);
	}
	goto LA58_;
	LA7_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 22);
	}
	goto LA58_;
	LA8_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 23);
	}
	goto LA58_;
	LA9_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 24);
	}
	goto LA58_;
	LA10_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 25);
	}
	goto LA58_;
	LA11_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 26);
	}
	goto LA58_;
	LA12_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 27);
	}
	goto LA58_;
	LA13_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 28);
	}
	goto LA58_;
	LA14_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 29);
	}
	goto LA58_;
	LA15_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 30);
	}
	goto LA58_;
	LA16_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 31);
	}
	goto LA58_;
	LA17_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 32);
	}
	goto LA58_;
	LA18_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 33);
	}
	goto LA58_;
	LA19_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 34);
	}
	goto LA58_;
	LA20_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 35);
	}
	goto LA58_;
	LA21_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 36);
	}
	goto LA58_;
	LA22_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 37);
	}
	goto LA58_;
	LA23_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 38);
	}
	goto LA58_;
	LA24_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 39);
	}
	goto LA58_;
	LA25_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 40);
	}
	goto LA58_;
	LA26_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 41);
	}
	goto LA58_;
	LA27_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 42);
	}
	goto LA58_;
	LA28_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 43);
	}
	goto LA58_;
	LA29_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 44);
	}
	goto LA58_;
	LA30_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 45);
	}
	goto LA58_;
	LA31_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 46);
	}
	goto LA58_;
	LA32_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 47);
	}
	goto LA58_;
	LA33_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 48);
	}
	goto LA58_;
	LA34_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 49);
	}
	goto LA58_;
	LA35_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 50);
	}
	goto LA58_;
	LA36_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 51);
	}
	goto LA58_;
	LA37_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 52);
	}
	goto LA58_;
	LA38_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 53);
	}
	goto LA58_;
	LA39_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 54);
	}
	goto LA58_;
	LA40_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 55);
	}
	goto LA58_;
	LA41_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 56);
	}
	goto LA58_;
	LA42_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 57);
	}
	goto LA58_;
	LA43_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 58);
	}
	goto LA58_;
	LA44_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 59);
	}
	goto LA58_;
	LA45_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 60);
	}
	goto LA58_;
	LA46_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 61);
	}
	goto LA58_;
	LA47_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 62);
	}
	goto LA58_;
	LA48_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 63);
	}
	goto LA58_;
	LA49_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 64);
	}
	goto LA58_;
	LA50_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 65);
	}
	goto LA58_;
	LA51_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 66);
	}
	goto LA58_;
	LA52_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 67);
	}
	goto LA58_;
	LA53_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 68);
	}
	goto LA58_;
	LA54_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 69);
	}
	goto LA58_;
	LA55_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 70);
	}
	goto LA58_;
	LA56_: ;
	{
		result = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 71);
	}
	goto LA58_;
	LA57_: ;
	{
		result = default_0;
	}
	LA58_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, atmwordrecgdotnim_DatInit000)(void) {
static TNimNode* TM__48S29b8u8ONh7ZDjWcviuGA_91_295[295];
NI TM__48S29b8u8ONh7ZDjWcviuGA_93;
static char* NIM_CONST TM__48S29b8u8ONh7ZDjWcviuGA_92[295] = {
"", 
"addr", 
"and", 
"as", 
"asm", 
"bind", 
"block", 
"break", 
"case", 
"cast", 
"concept", 
"const", 
"continue", 
"converter", 
"defer", 
"discard", 
"distinct", 
"div", 
"do", 
"elif", 
"else", 
"end", 
"enum", 
"except", 
"export", 
"finally", 
"for", 
"from", 
"func", 
"if", 
"import", 
"in", 
"include", 
"interface", 
"is", 
"isnot", 
"iterator", 
"let", 
"macro", 
"method", 
"mixin", 
"mod", 
"nil", 
"not", 
"notin", 
"object", 
"of", 
"or", 
"out", 
"proc", 
"ptr", 
"raise", 
"ref", 
"return", 
"shl", 
"shr", 
"static", 
"template", 
"try", 
"tuple", 
"type", 
"using", 
"var", 
"when", 
"while", 
"xor", 
"yield", 
":", 
"::", 
"=", 
".", 
"..", 
"*", 
"-", 
"magic", 
"thread", 
"final", 
"profiler", 
"memtracker", 
"objchecks", 
"intdefine", 
"strdefine", 
"booldefine", 
"cursor", 
"noalias", 
"effectsOf", 
"uncheckedAssign", 
"immediate", 
"constructor", 
"destructor", 
"delegator", 
"override", 
"importcpp", 
"cppNonPod", 
"importobjc", 
"importCompilerProc", 
"importc", 
"importjs", 
"exportc", 
"exportcpp", 
"exportnims", 
"incompleteStruct", 
"completeStruct", 
"requiresInit", 
"align", 
"nodecl", 
"pure", 
"sideEffect", 
"header", 
"noSideEffect", 
"gcsafe", 
"noreturn", 
"nosinks", 
"merge", 
"lib", 
"dynlib", 
"compilerproc", 
"core", 
"procvar", 
"base", 
"used", 
"fatal", 
"error", 
"warning", 
"hint", 
"warningAsError", 
"hintAsError", 
"line", 
"push", 
"pop", 
"define", 
"undef", 
"lineDir", 
"stackTrace", 
"lineTrace", 
"link", 
"compile", 
"linksys", 
"deprecated", 
"varargs", 
"callconv", 
"debugger", 
"nimcall", 
"stdcall", 
"cdecl", 
"safecall", 
"syscall", 
"inline", 
"noinline", 
"fastcall", 
"thiscall", 
"closure", 
"noconv", 
"on", 
"off", 
"checks", 
"rangeChecks", 
"boundChecks", 
"overflowChecks", 
"nilChecks", 
"floatChecks", 
"nanChecks", 
"infChecks", 
"styleChecks", 
"staticBoundChecks", 
"nonReloadable", 
"executeOnReload", 
"assertions", 
"patterns", 
"trmacros", 
"sinkInference", 
"warnings", 
"hints", 
"optimization", 
"raises", 
"writes", 
"reads", 
"size", 
"effects", 
"tags", 
"requires", 
"ensures", 
"invariant", 
"assume", 
"assert", 
"deadCodeElim", 
"safecode", 
"package", 
"noforward", 
"reorder", 
"norewrite", 
"nodestroy", 
"pragma", 
"compileTime", 
"noinit", 
"passc", 
"passl", 
"localPassC", 
"borrow", 
"discardable", 
"fieldChecks", 
"subschar", 
"acyclic", 
"shallow", 
"unroll", 
"linearScanEnd", 
"computedGoto", 
"experimental", 
"doctype", 
"write", 
"gensym", 
"inject", 
"dirty", 
"inheritable", 
"threadvar", 
"emit", 
"asmNoStackFrame", 
"implicitStatic", 
"global", 
"codegenDecl", 
"unchecked", 
"guard", 
"locks", 
"partial", 
"explain", 
"liftlocals", 
"enforceNoRaises", 
"auto", 
"bool", 
"catch", 
"char", 
"class", 
"compl", 
"const_cast", 
"default", 
"delete", 
"double", 
"dynamic_cast", 
"explicit", 
"extern", 
"false", 
"float", 
"friend", 
"goto", 
"int", 
"long", 
"mutable", 
"namespace", 
"new", 
"operator", 
"private", 
"protected", 
"public", 
"register", 
"reinterpret_cast", 
"restrict", 
"short", 
"signed", 
"sizeof", 
"static_cast", 
"struct", 
"switch", 
"this", 
"throw", 
"true", 
"typedef", 
"typeid", 
"typeof", 
"typename", 
"union", 
"packed", 
"unsigned", 
"virtual", 
"void", 
"volatile", 
"wchar_t", 
"alignas", 
"alignof", 
"constexpr", 
"decltype", 
"nullptr", 
"noexcept", 
"thread_local", 
"static_assert", 
"char16_t", 
"char32_t", 
"stdin", 
"stdout", 
"stderr", 
"inout", 
"bycopy", 
"byref", 
"oneway", 
"bitsize", 
"all"};
static TNimNode TM__48S29b8u8ONh7ZDjWcviuGA_0[296];
NTItspecialword__N2XsqTpO5IzOf2KmXwk4Dw_.size = sizeof(tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw);
NTItspecialword__N2XsqTpO5IzOf2KmXwk4Dw_.align = NIM_ALIGNOF(tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw);
NTItspecialword__N2XsqTpO5IzOf2KmXwk4Dw_.kind = 14;
NTItspecialword__N2XsqTpO5IzOf2KmXwk4Dw_.base = 0;
NTItspecialword__N2XsqTpO5IzOf2KmXwk4Dw_.flags = 3;
for (TM__48S29b8u8ONh7ZDjWcviuGA_93 = 0; TM__48S29b8u8ONh7ZDjWcviuGA_93 < 295; TM__48S29b8u8ONh7ZDjWcviuGA_93++) {
TM__48S29b8u8ONh7ZDjWcviuGA_0[TM__48S29b8u8ONh7ZDjWcviuGA_93+0].kind = 1;
TM__48S29b8u8ONh7ZDjWcviuGA_0[TM__48S29b8u8ONh7ZDjWcviuGA_93+0].offset = TM__48S29b8u8ONh7ZDjWcviuGA_93;
TM__48S29b8u8ONh7ZDjWcviuGA_0[TM__48S29b8u8ONh7ZDjWcviuGA_93+0].name = TM__48S29b8u8ONh7ZDjWcviuGA_92[TM__48S29b8u8ONh7ZDjWcviuGA_93];
TM__48S29b8u8ONh7ZDjWcviuGA_91_295[TM__48S29b8u8ONh7ZDjWcviuGA_93] = &TM__48S29b8u8ONh7ZDjWcviuGA_0[TM__48S29b8u8ONh7ZDjWcviuGA_93+0];
}
TM__48S29b8u8ONh7ZDjWcviuGA_0[295].len = 295; TM__48S29b8u8ONh7ZDjWcviuGA_0[295].kind = 2; TM__48S29b8u8ONh7ZDjWcviuGA_0[295].sons = &TM__48S29b8u8ONh7ZDjWcviuGA_91_295[0];
NTItspecialword__N2XsqTpO5IzOf2KmXwk4Dw_.node = &TM__48S29b8u8ONh7ZDjWcviuGA_0[295];
}

