/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 32
#define NIM_EmulateOverflowChecks

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef NIM_BOOL tyArray__zl3qUQvo0CT9bJi9b5H7mRkw[65];
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
typedef NU8 tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q;
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
typedef NU8 tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow;
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInst;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg uniqueId;
};
typedef NU32 tySet_tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU8 tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU8 tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg[9];
typedef NU8 tyEnum_TDistinctCompare__UuPcvyG2RecjPyQDW4WlFw;
typedef NU8 tySet_tyEnum_TTypeCmpFlag__IRq9bqtrf9ctEUyeRMyvWy4Q;
typedef NU8 tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w;
typedef NU8 tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU16 tySet_tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA;
struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg {
NI id;
NimStringDesc* s;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* next;
NI h;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_TAliasRequest__7zQvSP68l08u9cyWRw1zgvg;
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
static N_INLINE(NIM_BOOL, isAtom__ast_4769)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow, isAssignable__parampatterns_334)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL isUnsafeAddr);
static N_INLINE(NIM_BOOL, dontInlineConstant__trees_420)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* orig, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* cnst);
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, skipTypes__ast_3723)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kinds);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, compareTypes__types_2714)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* x, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* y, tyEnum_TDistinctCompare__UuPcvyG2RecjPyQDW4WlFw cmp, tySet_tyEnum_TTypeCmpFlag__IRq9bqtrf9ctEUyeRMyvWy4Q flags);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag, getMagic__trees_137)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* op);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, lastSon__ast_4833)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w, checkForSideEffects__parampatterns_218)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NIM_BOOL, isRoutine__ast_4677)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeI__ast_3320)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_NIMCALL(NimStringDesc*, rawNewString)(NI cap);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5331)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5293)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5338)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5336)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5287)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(void, compileConstraints__parampatterns_67)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p, NimStringDesc** result, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, patternError__parampatterns_38)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderTree__renderer_46)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA renderFlags);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
static N_INLINE(void, add__parampatterns_41)(NimStringDesc** code, tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q op);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuNormalize)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NI, hashString)(NimStringDesc* s);
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_625)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_167)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_1441)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreStyle)(NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toHumanStr__ast_5170)(tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__IfESpe2yD3DScypV9a7z8Mg_2 = {
0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__IfESpe2yD3DScypV9a7z8Mg_3 = {
0x10, 0xa8, 0x00, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__IfESpe2yD3DScypV9a7z8Mg_4 = {
0x10, 0xa8, 0xe0, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__IfESpe2yD3DScypV9a7z8Mg_5, "illformed AST: ", 15);
STRING_LITERAL(TM__IfESpe2yD3DScypV9a7z8Mg_7, "/home/runner/work/nightlies/nightlies/nim/compiler/parampatterns.nim", 68);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__IfESpe2yD3DScypV9a7z8Mg_6 = {((NimStringDesc*) &TM__IfESpe2yD3DScypV9a7z8Mg_7),
((NI) 46),
((NI) 12)}
;
STRING_LITERAL(TM__IfESpe2yD3DScypV9a7z8Mg_8, "|", 1);
STRING_LITERAL(TM__IfESpe2yD3DScypV9a7z8Mg_9, "&", 1);
STRING_LITERAL(TM__IfESpe2yD3DScypV9a7z8Mg_10, "~", 1);
STRING_LITERAL(TM__IfESpe2yD3DScypV9a7z8Mg_11, "atom", 4);
STRING_LITERAL(TM__IfESpe2yD3DScypV9a7z8Mg_12, "lit", 3);
STRING_LITERAL(TM__IfESpe2yD3DScypV9a7z8Mg_13, "sym", 3);
STRING_LITERAL(TM__IfESpe2yD3DScypV9a7z8Mg_14, "ident", 5);
STRING_LITERAL(TM__IfESpe2yD3DScypV9a7z8Mg_15, "call", 4);
STRING_LITERAL(TM__IfESpe2yD3DScypV9a7z8Mg_16, "alias", 5);
STRING_LITERAL(TM__IfESpe2yD3DScypV9a7z8Mg_17, "noalias", 7);
STRING_LITERAL(TM__IfESpe2yD3DScypV9a7z8Mg_18, "lvalue", 6);
STRING_LITERAL(TM__IfESpe2yD3DScypV9a7z8Mg_19, "local", 5);
STRING_LITERAL(TM__IfESpe2yD3DScypV9a7z8Mg_20, "sideeffect", 10);
STRING_LITERAL(TM__IfESpe2yD3DScypV9a7z8Mg_21, "nosideeffect", 12);
STRING_LITERAL(TM__IfESpe2yD3DScypV9a7z8Mg_22, "(", 1);
STRING_LITERAL(TM__IfESpe2yD3DScypV9a7z8Mg_23, ", ", 2);
STRING_LITERAL(TM__IfESpe2yD3DScypV9a7z8Mg_24, ")", 1);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__IfESpe2yD3DScypV9a7z8Mg_25 = {((NimStringDesc*) &TM__IfESpe2yD3DScypV9a7z8Mg_7),
((NI) 101),
((NI) 21)}
;
extern NIM_CONST tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw unknownLineInfo__lineinfos_284;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__IfESpe2yD3DScypV9a7z8Mg_26 = {((NimStringDesc*) &TM__IfESpe2yD3DScypV9a7z8Mg_7),
((NI) 108),
((NI) 21)}
;
extern TNimType NTItnodekind__clSgDh22o9au33BrVH9bDQZw_;
STRING_LITERAL(TM__IfESpe2yD3DScypV9a7z8Mg_27, "parameter pattern too complex", 29);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__IfESpe2yD3DScypV9a7z8Mg_28 = {((NimStringDesc*) &TM__IfESpe2yD3DScypV9a7z8Mg_7),
((NI) 128),
((NI) 19)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__IfESpe2yD3DScypV9a7z8Mg_29 = {
0x10, 0xa9, 0x00, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5240;
static N_INLINE(NIM_BOOL, isAtom__ast_4769)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) <= (*n).kind);
	if (!(T1_)) goto LA2_;
	T1_ = ((*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23));
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(NIM_BOOL, dontInlineConstant__trees_420)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* orig, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* cnst) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NI T5_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = !(((*orig).kind == (*cnst).kind));
	if (!(T2_)) goto LA3_;
	T2_ = ((*cnst).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 39) || (*cnst).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 37) || (*cnst).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 160) || (*cnst).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41) || (*cnst).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 38));
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T5_ = (NI)0;
	T5_ = len__ast_3155(cnst);
	T1_ = (((*cnst).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 38)) < T5_);
	LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow, isAssignable__parampatterns_334)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL isUnsafeAddr) {
	tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow result;
	result = (tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow)0;
	result = ((tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow) 0);
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1):
	{
		{
			NIM_BOOL T4_;
			T4_ = (NIM_BOOL)0;
			T4_ = !(((*n).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
			if (!(T4_)) goto LA5_;
			T4_ = ((*(*n).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23));
			LA5_: ;
			if (!T4_) goto LA6_;
			result = ((tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow) 1);
		}
		LA6_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		tySet_tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kinds;
		{
			if (!isUnsafeAddr) goto LA11_;
			kinds = 2100008;
		}
		goto LA9_;
		LA11_: ;
		{
			kinds = 2336;
		}
		LA9_: ;
		{
			NIM_BOOL T16_;
			T16_ = (NIM_BOOL)0;
			T16_ = ((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			if (!(T16_)) goto LA17_;
			T16_ = ((*(*(*n)._kind_4.sym).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*(*(*n)._kind_4.sym).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46));
			LA17_: ;
			if (!T16_) goto LA18_;
			result = ((tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow) 1);
		}
		goto LA14_;
		LA18_: ;
		{
			NIM_BOOL T21_;
			T21_ = (NIM_BOOL)0;
			T21_ = isUnsafeAddr;
			if (!(T21_)) goto LA22_;
			T21_ = ((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			LA22_: ;
			if (!T21_) goto LA23_;
			result = ((tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow) 1);
		}
		goto LA14_;
		LA23_: ;
		{
			NIM_BOOL T26_;
			NIM_BOOL T27_;
			T26_ = (NIM_BOOL)0;
			T27_ = (NIM_BOOL)0;
			T27_ = isUnsafeAddr;
			if (!(T27_)) goto LA28_;
			T27_ = ((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 10));
			LA28_: ;
			T26_ = T27_;
			if (!(T26_)) goto LA29_;
			T26_ = dontInlineConstant__trees_420(n, (*(*n)._kind_4.sym).ast);
			LA29_: ;
			if (!T26_) goto LA30_;
			result = ((tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow) 1);
		}
		goto LA14_;
		LA30_: ;
		{
			if (!((kinds &((NU32)1<<((NU)((*(*n)._kind_4.sym).kind)&31U)))!=0)) goto LA33_;
			{
				NIM_BOOL T37_;
				NIM_BOOL T38_;
				T37_ = (NIM_BOOL)0;
				T38_ = (NIM_BOOL)0;
				T38_ = !((owner == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
				if (!(T38_)) goto LA39_;
				T38_ = (owner == (*(*n)._kind_4.sym).owner);
				LA39_: ;
				T37_ = T38_;
				if (!(T37_)) goto LA40_;
				T37_ = !((((*(*n)._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 3))&63U)))!=0));
				LA40_: ;
				if (!T37_) goto LA41_;
				result = ((tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow) 2);
			}
			goto LA35_;
			LA41_: ;
			{
				result = ((tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow) 1);
			}
			LA35_: ;
		}
		goto LA14_;
		LA33_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
			if (!((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 7))) goto LA45_;
			t = skipTypes__ast_3723((*(*n)._kind_4.sym).typ, TM__IfESpe2yD3DScypV9a7z8Mg_2);
			{
				if (!((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23))) goto LA49_;
				result = ((tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow) 5);
			}
			LA49_: ;
		}
		goto LA14_;
		LA45_: ;
		LA14_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t_2;
		t_2 = skipTypes__ast_3723((*(*n)._kind_6.sons->data[((NI) 0)]).typ, TM__IfESpe2yD3DScypV9a7z8Mg_3);
		{
			if (!((*t_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*t_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46) || (*t_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21) || (*t_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22))) goto LA54_;
			result = ((tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow) 1);
		}
		goto LA52_;
		LA54_: ;
		{
			NIM_BOOL T57_;
			T57_ = (NIM_BOOL)0;
			T57_ = isUnsafeAddr;
			if (!(T57_)) goto LA58_;
			T57_ = ((*t_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47));
			LA58_: ;
			if (!T57_) goto LA59_;
			result = ((tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow) 1);
		}
		goto LA52_;
		LA59_: ;
		{
			result = isAssignable__parampatterns_334(owner, (*n)._kind_6.sons->data[((NI) 0)], isUnsafeAddr);
		}
		LA52_: ;
		{
			NIM_BOOL T64_;
			NIM_BOOL T65_;
			T64_ = (NIM_BOOL)0;
			T65_ = (NIM_BOOL)0;
			T65_ = !((result == ((tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow) 0)));
			if (!(T65_)) goto LA66_;
			T65_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
			LA66_: ;
			T64_ = T65_;
			if (!(T64_)) goto LA67_;
			T64_ = (((*(*(*n)._kind_6.sons->data[((NI) 1)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 20))&63U)))!=0);
			LA67_: ;
			if (!T64_) goto LA68_;
			result = ((tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow) 3);
		}
		LA68_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t_3;
		t_3 = skipTypes__ast_3723((*(*n)._kind_6.sons->data[((NI) 0)]).typ, TM__IfESpe2yD3DScypV9a7z8Mg_3);
		{
			if (!((*t_3).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*t_3).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46) || (*t_3).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21) || (*t_3).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22))) goto LA73_;
			result = ((tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow) 1);
		}
		goto LA71_;
		LA73_: ;
		{
			NIM_BOOL T76_;
			T76_ = (NIM_BOOL)0;
			T76_ = isUnsafeAddr;
			if (!(T76_)) goto LA77_;
			T76_ = ((*t_3).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47));
			LA77_: ;
			if (!T76_) goto LA78_;
			result = ((tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow) 1);
		}
		goto LA71_;
		LA78_: ;
		{
			result = isAssignable__parampatterns_334(owner, (*n)._kind_6.sons->data[((NI) 0)], isUnsafeAddr);
		}
		LA71_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 60):
	{
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T84_;
			T84_ = NIM_NIL;
			T84_ = skipTypes__ast_3723((*n).typ, TM__IfESpe2yD3DScypV9a7z8Mg_4);
			if (!((*T84_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27) || (*T84_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18) || (*T84_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17))) goto LA85_;
			result = isAssignable__parampatterns_334(owner, (*n)._kind_6.sons->data[((NI) 1)], isUnsafeAddr);
		}
		goto LA82_;
		LA85_: ;
		{
			NIM_BOOL T88_;
			T88_ = (NIM_BOOL)0;
			T88_ = compareTypes__types_2714((*n).typ, (*(*n)._kind_6.sons->data[((NI) 1)]).typ, ((tyEnum_TDistinctCompare__UuPcvyG2RecjPyQDW4WlFw) 1), 0);
			if (!T88_) goto LA89_;
			result = isAssignable__parampatterns_334(owner, (*n)._kind_6.sons->data[((NI) 1)], isUnsafeAddr);
		}
		goto LA82_;
		LA89_: ;
		LA82_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n0;
		n0 = (*n)._kind_6.sons->data[((NI) 0)];
		{
			if (!((*(*n0).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47))) goto LA94_;
			{
				NIM_BOOL T98_;
				NIM_BOOL T100_;
				T98_ = (NIM_BOOL)0;
				T98_ = isUnsafeAddr;
				if (T98_) goto LA99_;
				T100_ = (NIM_BOOL)0;
				T100_ = ((*n0).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
				if (!(T100_)) goto LA101_;
				T100_ = ((*(*n0)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 11));
				LA101_: ;
				T98_ = T100_;
				LA99_: ;
				if (!T98_) goto LA102_;
				result = ((tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow) 1);
			}
			goto LA96_;
			LA102_: ;
			{
				result = ((tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow) 4);
			}
			LA96_: ;
		}
		goto LA92_;
		LA94_: ;
		{
			result = ((tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow) 1);
		}
		LA92_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 47):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64):
	{
		result = ((tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow) 1);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 67):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 66):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 46):
	{
		result = isAssignable__parampatterns_334(owner, (*n)._kind_6.sons->data[((NI) 0)], isUnsafeAddr);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
	{
		{
			tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag T111_;
			T111_ = (tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag)0;
			T111_ = getMagic__trees_137(n);
			if (!(T111_ == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 5) || T111_ == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 126))) goto LA112_;
			result = isAssignable__parampatterns_334(owner, (*n)._kind_6.sons->data[((NI) 1)], isUnsafeAddr);
		}
		goto LA109_;
		LA112_: ;
		{
			NIM_BOOL T115_;
			T115_ = (NIM_BOOL)0;
			T115_ = !(((*n).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
			if (!(T115_)) goto LA116_;
			T115_ = ((*(*n).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23));
			LA116_: ;
			if (!T115_) goto LA117_;
			result = ((tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow) 1);
		}
		goto LA109_;
		LA117_: ;
		{
			NIM_BOOL T120_;
			NIM_BOOL T121_;
			T120_ = (NIM_BOOL)0;
			T121_ = (NIM_BOOL)0;
			T121_ = isUnsafeAddr;
			if (!(T121_)) goto LA122_;
			T121_ = !(((*n).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
			LA122_: ;
			T120_ = T121_;
			if (!(T120_)) goto LA123_;
			T120_ = ((*(*n).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47));
			LA123_: ;
			if (!T120_) goto LA124_;
			result = ((tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow) 1);
		}
		goto LA109_;
		LA124_: ;
		LA109_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T131_;
			if (!!(((*n).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA129_;
			T131_ = NIM_NIL;
			T131_ = lastSon__ast_4833(n);
			result = isAssignable__parampatterns_334(owner, T131_, isUnsafeAddr);
		}
		LA129_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 143):
	{
		result = ((tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow) 1);
	}
	break;
	default:
	{
	}
	break;
	}
	return result;
}
static N_INLINE(NIM_BOOL, isRoutine__ast_4677)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((520192 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w, checkForSideEffects__parampatterns_218)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w result;
{	result = (tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* op;
		op = (*n)._kind_6.sons->data[((NI) 0)];
		{
			NIM_BOOL T4_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
			T4_ = (NIM_BOOL)0;
			T4_ = ((*op).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
			if (!(T4_)) goto LA5_;
			T4_ = isRoutine__ast_4677((*op)._kind_4.sym);
			LA5_: ;
			if (!T4_) goto LA6_;
			s = (*op)._kind_4.sym;
			{
				if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 13))&63U)))!=0)) goto LA10_;
				result = ((tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w) 1);
				goto BeforeRet_;
			}
			LA10_: ;
			result = ((tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w) 2);
		}
		goto LA2_;
		LA6_: ;
		{
			if (!(((*(*op).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 1))&63U)))!=0)) goto LA13_;
			result = ((tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w) 2);
		}
		goto LA2_;
		LA13_: ;
		{
			result = ((tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w) 1);
			goto BeforeRet_;
		}
		LA2_: ;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w ret;
					if (!(i_2 < colontmp_)) goto LA18;
					i = i_2;
					ret = checkForSideEffects__parampatterns_218((*n)._kind_6.sons->data[i]);
					{
						if (!(ret == ((tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w) 1))) goto LA21_;
						result = ret;
						goto BeforeRet_;
					}
					goto LA19_;
					LA21_: ;
					{
						NIM_BOOL T24_;
						T24_ = (NIM_BOOL)0;
						T24_ = (ret == ((tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w) 0));
						if (!(T24_)) goto LA25_;
						T24_ = (result == ((tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w) 2));
						LA25_: ;
						if (!T24_) goto LA26_;
						result = ((tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w) 0);
					}
					goto LA19_;
					LA26_: ;
					LA19_: ;
					i_2 += ((NI) 1);
				} LA18: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
	{
		result = ((tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w) 2);
	}
	break;
	default:
	{
		result = ((tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w) 2);
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3155(n);
			i_4 = ((NI) 0);
			{
				while (1) {
					tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w ret_2;
					if (!(i_4 < colontmp__2)) goto LA32;
					i_3 = i_4;
					ret_2 = checkForSideEffects__parampatterns_218((*n)._kind_6.sons->data[i_3]);
					{
						if (!(ret_2 == ((tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w) 1))) goto LA35_;
						result = ret_2;
						goto BeforeRet_;
					}
					goto LA33_;
					LA35_: ;
					{
						NIM_BOOL T38_;
						T38_ = (NIM_BOOL)0;
						T38_ = (ret_2 == ((tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w) 0));
						if (!(T38_)) goto LA39_;
						T38_ = (result == ((tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w) 2));
						LA39_: ;
						if (!T38_) goto LA40_;
						result = ((tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w) 0);
					}
					goto LA33_;
					LA40_: ;
					LA33_: ;
					i_4 += ((NI) 1);
				} LA32: ;
			}
		}
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, matchNodeKinds__parampatterns_505)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	tyArray__zl3qUQvo0CT9bJi9b5H7mRkw stack;
	NI sp;
	NimStringDesc* code;
	NI pc;
	result = (NIM_BOOL)0;
	stack[(((NI) 0))- 0] = NIM_TRUE;
	sp = ((NI) 1);
	code = (*p)._kind_3.strVal;
	pc = ((NI) 1);
	{
		while (1) {
			switch (((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) (((NU8)(code->data[pc]))))) {
			case ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 1):
			{
				goto LA1;
			}
			break;
			case ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 2):
			{
				NIM_BOOL T5_;
				T5_ = (NIM_BOOL)0;
				T5_ = stack[((NI)(sp - ((NI) 1)))- 0];
				if (T5_) goto LA6_;
				T5_ = stack[((NI)(sp - ((NI) 2)))- 0];
				LA6_: ;
				stack[((NI)(sp - ((NI) 2)))- 0] = T5_;
				sp -= ((NI) 1);
			}
			break;
			case ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 3):
			{
				NIM_BOOL T8_;
				T8_ = (NIM_BOOL)0;
				T8_ = stack[((NI)(sp - ((NI) 1)))- 0];
				if (!(T8_)) goto LA9_;
				T8_ = stack[((NI)(sp - ((NI) 2)))- 0];
				LA9_: ;
				stack[((NI)(sp - ((NI) 2)))- 0] = T8_;
				sp -= ((NI) 1);
			}
			break;
			case ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 4):
			{
				stack[((NI)(sp - ((NI) 1)))- 0] = !(stack[((NI)(sp - ((NI) 1)))- 0]);
			}
			break;
			case ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 5):
			{
				stack[(sp)- 0] = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
				sp += ((NI) 1);
			}
			break;
			case ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 6):
			{
				stack[(sp)- 0] = isAtom__ast_4769(n);
				sp += ((NI) 1);
			}
			break;
			case ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 7):
			{
				stack[(sp)- 0] = ((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23));
				sp += ((NI) 1);
			}
			break;
			case ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 8):
			{
				stack[(sp)- 0] = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2));
				sp += ((NI) 1);
			}
			break;
			case ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 9):
			{
				stack[(sp)- 0] = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32));
				sp += ((NI) 1);
			}
			break;
			case ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 10):
			{
				tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
				NIM_BOOL T17_;
				kind = ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) (((NU8)(code->data[(NI)(pc + ((NI) 1))]))));
				T17_ = (NIM_BOOL)0;
				T17_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
				if (!(T17_)) goto LA18_;
				T17_ = ((*(*n)._kind_4.sym).kind == kind);
				LA18_: ;
				stack[(sp)- 0] = T17_;
				sp += ((NI) 1);
				pc += ((NI) 1);
			}
			break;
			case ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 11):
			{
				tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind_2;
				kind_2 = ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) (((NU8)(code->data[(NI)(pc + ((NI) 1))]))));
				stack[(sp)- 0] = ((*n).kind == kind_2);
				sp += ((NI) 1);
				pc += ((NI) 1);
			}
			break;
			case ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 12):
			{
				tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow T21_;
				T21_ = (tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow)0;
				T21_ = isAssignable__parampatterns_334(((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL), n, NIM_FALSE);
				stack[(sp)- 0] = ((6 &((NU8)1<<((NU)(T21_)&7U)))!=0);
				sp += ((NI) 1);
			}
			break;
			case ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 13):
			{
				tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow T23_;
				T23_ = (tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow)0;
				T23_ = isAssignable__parampatterns_334(((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL), n, NIM_FALSE);
				stack[(sp)- 0] = (T23_ == ((tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow) 2));
				sp += ((NI) 1);
			}
			break;
			case ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 14):
			{
				tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w T25_;
				T25_ = (tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w)0;
				T25_ = checkForSideEffects__parampatterns_218(n);
				stack[(sp)- 0] = (T25_ == ((tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w) 1));
				sp += ((NI) 1);
			}
			break;
			case ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 15):
			{
				tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w T27_;
				T27_ = (tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w)0;
				T27_ = checkForSideEffects__parampatterns_218(n);
				stack[(sp)- 0] = !((T27_ == ((tyEnum_TSideEffectAnalysis__CeFjec9clk9bvOuWlkTbVq0w) 1)));
				sp += ((NI) 1);
			}
			break;
			}
			pc += ((NI) 1);
		}
	} LA1: ;
	result = stack[((NI)(sp - ((NI) 1)))- 0];
	return result;
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5331)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5293)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5336)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5287((&gch__system_5240.zct), c);
}
static N_INLINE(void, decRef__system_5338)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5336(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5293(src);
		incRef__system_5331(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5293((*dest));
		decRef__system_5338(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, patternError__parampatterns_38)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	T1_ = NIM_NIL;
	T2_ = NIM_NIL;
	T2_ = renderTree__renderer_46(n, 4);
	T1_ = rawNewString((T2_ ? T2_->Sup.len : 0) + 15);
appendString(T1_, ((NimStringDesc*) &TM__IfESpe2yD3DScypV9a7z8Mg_5));
appendString(T1_, T2_);
	liMessage__msgs_1128(conf, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T1_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__IfESpe2yD3DScypV9a7z8Mg_6, NIM_FALSE);
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, add__parampatterns_41)(NimStringDesc** code, tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q op) {
	unsureAsgnRef((void**) (&(*code)), addChar((*code), ((NIM_CHAR) (((NI) (op))))));
}
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x) {
	addInt__stdZprivateZdigitsutils_167(result, ((NI64) (x)));
}
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_625)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = resizeString(result, (info.Field0 ? info.Field0->Sup.len : 0) + 0);
appendString(result, info.Field0);
	{
		if (!(((NI) 0) < info.Field1)) goto LA3_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__IfESpe2yD3DScypV9a7z8Mg_22));
		addInt__stdZprivateZdigitsutils_189((&result), info.Field1);
		{
			if (!(((NI) 0) < (NI)(info.Field2 + ((NI) 1)))) goto LA7_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__IfESpe2yD3DScypV9a7z8Mg_23));
			addInt__stdZprivateZdigitsutils_189((&result), (NI)(info.Field2 + ((NI) 1)));
		}
		LA7_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__IfESpe2yD3DScypV9a7z8Mg_24));
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, compileConstraints__parampatterns_67)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p, NimStringDesc** result, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
{	switch ((*p).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
	{
		tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* op;
		{
			if (!!(((*(*p)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2)))) goto LA4_;
			patternError__parampatterns_38((*p)._kind_6.sons->data[((NI) 0)], conf);
			goto BeforeRet_;
		}
		LA4_: ;
		op = (*(*p)._kind_6.sons->data[((NI) 0)])._kind_5.ident;
		{
			NI T8_;
			T8_ = (NI)0;
			T8_ = len__ast_3155(p);
			if (!(T8_ == ((NI) 3))) goto LA9_;
			{
				NIM_BOOL T13_;
				T13_ = (NIM_BOOL)0;
				T13_ = eqStrings((*op).s, ((NimStringDesc*) &TM__IfESpe2yD3DScypV9a7z8Mg_8));
				if (T13_) goto LA14_;
				T13_ = ((*op).id == ((NI) 47));
				LA14_: ;
				if (!T13_) goto LA15_;
				compileConstraints__parampatterns_67((*p)._kind_6.sons->data[((NI) 1)], result, conf);
				compileConstraints__parampatterns_67((*p)._kind_6.sons->data[((NI) 2)], result, conf);
				add__parampatterns_41(result, ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 2));
			}
			goto LA11_;
			LA15_: ;
			{
				NIM_BOOL T18_;
				T18_ = (NIM_BOOL)0;
				T18_ = eqStrings((*op).s, ((NimStringDesc*) &TM__IfESpe2yD3DScypV9a7z8Mg_9));
				if (T18_) goto LA19_;
				T18_ = ((*op).id == ((NI) 2));
				LA19_: ;
				if (!T18_) goto LA20_;
				compileConstraints__parampatterns_67((*p)._kind_6.sons->data[((NI) 1)], result, conf);
				compileConstraints__parampatterns_67((*p)._kind_6.sons->data[((NI) 2)], result, conf);
				add__parampatterns_41(result, ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 3));
			}
			goto LA11_;
			LA20_: ;
			{
				patternError__parampatterns_38(p, conf);
			}
			LA11_: ;
		}
		goto LA6_;
		LA9_: ;
		{
			NIM_BOOL T24_;
			NI T25_;
			NIM_BOOL T27_;
			T24_ = (NIM_BOOL)0;
			T25_ = (NI)0;
			T25_ = len__ast_3155(p);
			T24_ = (T25_ == ((NI) 2));
			if (!(T24_)) goto LA26_;
			T27_ = (NIM_BOOL)0;
			T27_ = eqStrings((*op).s, ((NimStringDesc*) &TM__IfESpe2yD3DScypV9a7z8Mg_10));
			if (T27_) goto LA28_;
			T27_ = ((*op).id == ((NI) 43));
			LA28_: ;
			T24_ = T27_;
			LA26_: ;
			if (!T24_) goto LA29_;
			compileConstraints__parampatterns_67((*p)._kind_6.sons->data[((NI) 1)], result, conf);
			add__parampatterns_41(result, ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 4));
		}
		goto LA6_;
		LA29_: ;
		{
			patternError__parampatterns_38(p, conf);
		}
		LA6_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 53):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 37):
	{
		{
			NI T35_;
			T35_ = (NI)0;
			T35_ = len__ast_3155(p);
			if (!(T35_ == ((NI) 1))) goto LA36_;
			compileConstraints__parampatterns_67((*p)._kind_6.sons->data[((NI) 0)], result, conf);
		}
		goto LA33_;
		LA36_: ;
		{
			patternError__parampatterns_38(p, conf);
		}
		LA33_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	{
		NimStringDesc* spec;
		spec = nsuNormalize((*(*p)._kind_5.ident).s);
		switch (hashString(spec) & 15) {
		case 1: 
if (eqStrings(spec, ((NimStringDesc*) &TM__IfESpe2yD3DScypV9a7z8Mg_21))) goto LA50_;
break;
		case 3: 
if (eqStrings(spec, ((NimStringDesc*) &TM__IfESpe2yD3DScypV9a7z8Mg_17))) goto LA46_;
if (eqStrings(spec, ((NimStringDesc*) &TM__IfESpe2yD3DScypV9a7z8Mg_18))) goto LA47_;
if (eqStrings(spec, ((NimStringDesc*) &TM__IfESpe2yD3DScypV9a7z8Mg_20))) goto LA49_;
break;
		case 4: 
if (eqStrings(spec, ((NimStringDesc*) &TM__IfESpe2yD3DScypV9a7z8Mg_13))) goto LA42_;
break;
		case 6: 
if (eqStrings(spec, ((NimStringDesc*) &TM__IfESpe2yD3DScypV9a7z8Mg_14))) goto LA43_;
if (eqStrings(spec, ((NimStringDesc*) &TM__IfESpe2yD3DScypV9a7z8Mg_19))) goto LA48_;
break;
		case 11: 
if (eqStrings(spec, ((NimStringDesc*) &TM__IfESpe2yD3DScypV9a7z8Mg_11))) goto LA40_;
break;
		case 12: 
if (eqStrings(spec, ((NimStringDesc*) &TM__IfESpe2yD3DScypV9a7z8Mg_12))) goto LA41_;
break;
		case 13: 
if (eqStrings(spec, ((NimStringDesc*) &TM__IfESpe2yD3DScypV9a7z8Mg_15))) goto LA44_;
break;
		case 14: 
if (eqStrings(spec, ((NimStringDesc*) &TM__IfESpe2yD3DScypV9a7z8Mg_16))) goto LA45_;
break;
		}
		goto LA51_;
		LA40_: ;
		{
			add__parampatterns_41(result, ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 6));
		}
		goto LA52_;
		LA41_: ;
		{
			add__parampatterns_41(result, ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 7));
		}
		goto LA52_;
		LA42_: ;
		{
			add__parampatterns_41(result, ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 5));
		}
		goto LA52_;
		LA43_: ;
		{
			add__parampatterns_41(result, ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 8));
		}
		goto LA52_;
		LA44_: ;
		{
			add__parampatterns_41(result, ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 9));
		}
		goto LA52_;
		LA45_: ;
		{
			(*result)->data[((NI) 0)] = 2;
		}
		goto LA52_;
		LA46_: ;
		{
			(*result)->data[((NI) 0)] = 3;
		}
		goto LA52_;
		LA47_: ;
		{
			add__parampatterns_41(result, ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 12));
		}
		goto LA52_;
		LA48_: ;
		{
			add__parampatterns_41(result, ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 13));
		}
		goto LA52_;
		LA49_: ;
		{
			add__parampatterns_41(result, ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 14));
		}
		goto LA52_;
		LA50_: ;
		{
			add__parampatterns_41(result, ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 15));
		}
		goto LA52_;
		LA51_: ;
		{
			{
				NimStringDesc* argX60gensym13_;
				if (!NIM_FALSE) goto LA67_;
				argX60gensym13_ = toFileLineCol__msgs_625(TM__IfESpe2yD3DScypV9a7z8Mg_25);
				internalErrorImpl__msgs_1441(conf, unknownLineInfo__lineinfos_284, argX60gensym13_, TM__IfESpe2yD3DScypV9a7z8Mg_25);
			}
			LA67_: ;
			{
				tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw i;
				i = (tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw)0;
				{
					tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw v;
					NI res;
					v = (tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw)0;
					res = ((NI) 0);
					{
						while (1) {
							if (!(res <= ((NI) 25))) goto LA72;
							v = ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) (res));
							i = v;
							{
								NimStringDesc* T75_;
								NI T76_;
								T75_ = NIM_NIL;
								T75_ = toHumanStr__ast_5170(i);
								T76_ = (NI)0;
								T76_ = nsuCmpIgnoreStyle(T75_, spec);
								if (!(T76_ == ((NI) 0))) goto LA77_;
								add__parampatterns_41(result, ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 10));
								unsureAsgnRef((void**) (&(*result)), addChar((*result), ((NIM_CHAR) (((NI) (i))))));
								goto BeforeRet_;
							}
							LA77_: ;
							res += ((NI) 1);
						} LA72: ;
					}
				}
			}
			{
				NimStringDesc* argX60gensym15_;
				if (!NIM_FALSE) goto LA81_;
				argX60gensym15_ = toFileLineCol__msgs_625(TM__IfESpe2yD3DScypV9a7z8Mg_26);
				internalErrorImpl__msgs_1441(conf, unknownLineInfo__lineinfos_284, argX60gensym15_, TM__IfESpe2yD3DScypV9a7z8Mg_26);
			}
			LA81_: ;
			{
				tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw i_2;
				i_2 = (tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw)0;
				{
					tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw v_2;
					NI res_2;
					v_2 = (tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw)0;
					res_2 = ((NI) 0);
					{
						while (1) {
							if (!(res_2 <= ((NI) 164))) goto LA86;
							v_2 = ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) (res_2));
							i_2 = v_2;
							{
								NI T89_;
								T89_ = (NI)0;
								T89_ = nsuCmpIgnoreStyle(reprEnum((NI)i_2, (&NTItnodekind__clSgDh22o9au33BrVH9bDQZw_)), spec);
								if (!(T89_ == ((NI) 0))) goto LA90_;
								add__parampatterns_41(result, ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 11));
								unsureAsgnRef((void**) (&(*result)), addChar((*result), ((NIM_CHAR) (((NI) (i_2))))));
								goto BeforeRet_;
							}
							LA90_: ;
							res_2 += ((NI) 1);
						} LA86: ;
					}
				}
			}
			patternError__parampatterns_38(p, conf);
		}
		LA52_: ;
	}
	break;
	default:
	{
		patternError__parampatterns_38(p, conf);
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, semNodeKindConstraints__parampatterns_186)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI start) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20), (*n).info);
	asgnRef((void**) (&(*result)._kind_3.strVal), rawNewString(((NI) 10)));
	asgnRef((void**) (&(*result)._kind_3.strVal), addChar((*result)._kind_3.strVal, 1));
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__ast_3155(n);
		if (!(((NI) 2) <= T3_)) goto LA4_;
		{
			NI i;
			NI colontmp_;
			NI T7_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			T7_ = (NI)0;
			T7_ = len__ast_3155(n);
			colontmp_ = ((NI) (T7_));
			i_2 = start;
			{
				while (1) {
					if (!(((NI) (i_2)) < ((NI) (colontmp_)))) goto LA9;
					i = i_2;
					compileConstraints__parampatterns_67((*n)._kind_6.sons->data[i], (&(*result)._kind_3.strVal), conf);
					i_2 += ((NI) 1);
				} LA9: ;
			}
		}
		{
			if (!(((NI) 63) < ((*result)._kind_3.strVal ? (*result)._kind_3.strVal->Sup.len : 0))) goto LA12_;
			internalErrorImpl__msgs_1441(conf, (*n).info, ((NimStringDesc*) &TM__IfESpe2yD3DScypV9a7z8Mg_27), TM__IfESpe2yD3DScypV9a7z8Mg_28);
		}
		LA12_: ;
	}
	goto LA1_;
	LA4_: ;
	{
		patternError__parampatterns_38(n, conf);
	}
	LA1_: ;
	add__parampatterns_41((&(*result)._kind_3.strVal), ((tyEnum_TOpcode__0x9b86N0Y9bDJgfrj5z9by9b7Q) 1));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAliasRequest__7zQvSP68l08u9cyWRw1zgvg, whichAlias__parampatterns_48)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* p) {
	tyEnum_TAliasRequest__7zQvSP68l08u9cyWRw1zgvg result;
	result = (tyEnum_TAliasRequest__7zQvSP68l08u9cyWRw1zgvg)0;
	{
		if (!!(((*p).constraint == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA3_;
		result = ((tyEnum_TAliasRequest__7zQvSP68l08u9cyWRw1zgvg) (((NU8)((*(*p).constraint)._kind_3.strVal->data[((NI) 0)]))));
	}
	goto LA1_;
	LA3_: ;
	{
		result = ((tyEnum_TAliasRequest__7zQvSP68l08u9cyWRw1zgvg) 1);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, exprRoot__parampatterns_300)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
{	result = NIM_NIL;
	it = n;
	{
		while (1) {
			switch ((*it).kind) {
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
			{
				result = (*it)._kind_4.sym;
				goto BeforeRet_;
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 47):
			{
				{
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T7_;
					T7_ = NIM_NIL;
					T7_ = skipTypes__ast_3723((*(*it)._kind_6.sons->data[((NI) 0)]).typ, TM__IfESpe2yD3DScypV9a7z8Mg_29);
					if (!((*T7_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21) || (*T7_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22))) goto LA8_;
					goto LA1;
				}
				goto LA5_;
				LA8_: ;
				{
					it = (*it)._kind_6.sons->data[((NI) 0)];
				}
				LA5_: ;
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 67):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 66):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 46):
			{
				it = (*it)._kind_6.sons->data[((NI) 0)];
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 60):
			{
				it = (*it)._kind_6.sons->data[((NI) 1)];
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126):
			{
				{
					NIM_BOOL T16_;
					NI T17_;
					T16_ = (NIM_BOOL)0;
					T17_ = (NI)0;
					T17_ = len__ast_3155(it);
					T16_ = (((NI) 0) < T17_);
					if (!(T16_)) goto LA18_;
					T16_ = !(((*it).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
					LA18_: ;
					if (!T16_) goto LA19_;
					it = lastSon__ast_4833(it);
				}
				goto LA14_;
				LA19_: ;
				{
					goto LA1;
				}
				LA14_: ;
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
			{
				{
					NIM_BOOL T25_;
					NIM_BOOL T26_;
					NI T29_;
					T25_ = (NIM_BOOL)0;
					T26_ = (NIM_BOOL)0;
					T26_ = !(((*it).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
					if (!(T26_)) goto LA27_;
					T26_ = ((*(*it).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*(*it).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47));
					LA27_: ;
					T25_ = T26_;
					if (!(T25_)) goto LA28_;
					T29_ = (NI)0;
					T29_ = len__ast_3155(it);
					T25_ = (((NI) 1) < T29_);
					LA28_: ;
					if (!T25_) goto LA30_;
					it = (*it)._kind_6.sons->data[((NI) 1)];
				}
				goto LA23_;
				LA30_: ;
				{
					goto LA1;
				}
				LA23_: ;
			}
			break;
			default:
			{
				goto LA1;
			}
			break;
			}
		}
	} LA1: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isLValue__parampatterns_497)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow T1_;
	result = (NIM_BOOL)0;
	T1_ = (tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow)0;
	T1_ = isAssignable__parampatterns_334(((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL), n, NIM_FALSE);
	result = ((38 &((NU8)1<<((NU)(T1_)&7U)))!=0);
	return result;
}
