/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tySequence__wbHXzzfwTCmsKuzoRrgI3g tySequence__wbHXzzfwTCmsKuzoRrgI3g;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ;
typedef struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg;
typedef struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag;
typedef struct NimStringDesc NimStringDesc;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg;
typedef struct tySequence__4Murtwnm0Fyc7F9acrytEXw tySequence__4Murtwnm0Fyc7F9acrytEXw;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg tySequence__QnmOtn1Iv4LvxOXoMn8Rbg;
typedef struct tySequence__oKtVqsc9bQVCNyrijELM4OQ tySequence__oKtVqsc9bQVCNyrijELM4OQ;
typedef struct tySequence__qy6Iwdy00wN560qud54HTg tySequence__qy6Iwdy00wN560qud54HTg;
typedef struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ tySequence__k67v9bwvvQDmS1ynyGGUbeQ;
typedef struct tySequence__cLsClAAfd0MKkoBQVyvdvw tySequence__cLsClAAfd0MKkoBQVyvdvw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg tySequence__q9bTuOB0JXh1iZ3CSGdRLbg;
typedef struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw;
typedef struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ;
typedef struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA;
typedef struct tySequence__ed0C0uAUZPhvw3RAc5hfYg tySequence__ed0C0uAUZPhvw3RAc5hfYg;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ;
typedef struct tySequence__C3r8jsj9chA4sIlYfDN5aDw tySequence__C3r8jsj9chA4sIlYfDN5aDw;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyObject_AliveContext__OHV9brHwxGgyHI4IVd0uBGQ tyObject_AliveContext__OHV9brHwxGgyHI4IVd0uBGQ;
typedef struct tySequence__QAgH1SiSgaqLxO3mmFcEmQ tySequence__QAgH1SiSgaqLxO3mmFcEmQ;
typedef struct tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tyObject_Table__84yOtwIL9aCkCL60odYiF7g tyObject_Table__84yOtwIL9aCkCL60odYiF7g;
typedef struct tySequence__UuiPn6QjIiUTdSVwX2PZ6w tySequence__UuiPn6QjIiUTdSVwX2PZ6w;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA;
typedef struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ;
typedef struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA;
typedef struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA;
typedef struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA;
typedef struct tyTuple__VrKVnu7fux6g89cTtGzccuw tyTuple__VrKVnu7fux6g89cTtGzccuw;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw;
typedef struct tySequence__lo3S1lKyiPLhGGB9cBawd6A tySequence__lo3S1lKyiPLhGGB9cBawd6A;
typedef struct tyTuple__Ll5iolPASSzOEheeSNjmiw tyTuple__Ll5iolPASSzOEheeSNjmiw;
typedef struct tyTuple__9a3DhYVfcy14Fx42tD0lSEQ tyTuple__9a3DhYVfcy14Fx42tD0lSEQ;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__PsEhl3dzznmmJiLAuIXZOg tyTuple__PsEhl3dzznmmJiLAuIXZOg;
typedef struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w;
typedef struct tyTuple__Db8CrQifKGIsKc3w71w7Lw tyTuple__Db8CrQifKGIsKc3w71w7Lw;
typedef struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg;
typedef struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ;
typedef struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw tyTuple__FEYH9alRJhHD0uTKF2vnIqw;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg tyTuple__VUJ5Hjm4tKAResBsRHJvYg;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
struct TGenericSeq {
NI len;
NI reserved;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
typedef NU8 tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg;
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg {
tySequence__4Murtwnm0Fyc7F9acrytEXw* nodes;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ;
struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ {
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw {
tySequence__IHUFRsFxZNv7YydiUO2esQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
};
struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag {
NimStringDesc* definedSymbols;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA moduleFlags;
tySequence__PXIzfWocnrafGz5p3CP5LA* includes;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* imports;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg toReplay;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg topLevel;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg bodies;
tySequence__b89aLriiJnVTD186H6zNIgg* exports;
tySequence__b89aLriiJnVTD186H6zNIgg* hidden;
tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw* reexports;
tySequence__b89aLriiJnVTD186H6zNIgg* compilerProcs;
tySequence__48JTohSgTy339bRxHzUD8KA* converters;
tySequence__48JTohSgTy339bRxHzUD8KA* methods;
tySequence__48JTohSgTy339bRxHzUD8KA* trmacros;
tySequence__48JTohSgTy339bRxHzUD8KA* pureEnums;
tySequence__QnmOtn1Iv4LvxOXoMn8Rbg* macroUsages;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* typeInstCache;
tySequence__qy6Iwdy00wN560qud54HTg* procInstCache;
tySequence__k67v9bwvvQDmS1ynyGGUbeQ* attachedOps;
tySequence__cLsClAAfd0MKkoBQVyvdvw* methodsPerType;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* enumToStringProcs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* emittedTypeInfo;
tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ backendFlags;
tySequence__q9bTuOB0JXh1iZ3CSGdRLbg* syms;
tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw* types;
tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ strings;
tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw numbers;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA cfg;
};
struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ {
tySequence__C3r8jsj9chA4sIlYfDN5aDw* data;
NI counter;
};
struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg {
tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg status;
NIM_BOOL symsInit;
NIM_BOOL typesInit;
NIM_BOOL loadedButAliveSetChanged;
tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag fromDisk;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* syms;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* types;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ iface;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ ifaceHidden;
};
struct tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ {
NI lastModule;
NU32 lastLit;
NI32 lastFile;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
};
struct tyObject_Table__84yOtwIL9aCkCL60odYiF7g {
tySequence__UuiPn6QjIiUTdSVwX2PZ6w* data;
NI counter;
};
struct tyObject_AliveContext__OHV9brHwxGgyHI4IVd0uBGQ {
tySequence__QAgH1SiSgaqLxO3mmFcEmQ* stack;
tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ decoder;
NI thisModule;
tySequence__wbHXzzfwTCmsKuzoRrgI3g* alive;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tyObject_Table__84yOtwIL9aCkCL60odYiF7g compilerProcs;
};
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ {
NU32 module;
NI32 item;
};
struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA {
NU16 line;
NI16 col;
NU32 file;
};
struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA {
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
NI32 operand;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeId_0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
typedef NU8 tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ;
struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA {
tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
NU32 name;
NI32 path;
};
struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA {
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
NU32 name;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typ;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
NI32 ast;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ guard;
NI bitsize;
NI alignment;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
NU32 externalName;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw locFlags;
tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA annex;
NI32 constraint;
};
struct tyTuple__VrKVnu7fux6g89cTtGzccuw {
NI Field0;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ Field1;
NI Field2;
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
NI Field0;
NI Field1;
};
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg[9];
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw {
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* types;
NI32 n;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeInst;
NI32 nonUniqueId;
};
typedef NU8 tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU8 tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
struct tyTuple__Ll5iolPASSzOEheeSNjmiw {
NI Field0;
NI32 Field1;
};
struct tyTuple__9a3DhYVfcy14Fx42tD0lSEQ {
NI Field0;
NimStringDesc* Field1;
tyTuple__Ll5iolPASSzOEheeSNjmiw Field2;
};
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
NU32 Field0;
NimStringDesc* Field1;
};
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
NU32 Field0;
NI32 Field1;
};
struct tyTuple__PsEhl3dzznmmJiLAuIXZOg {
NU32 Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA Field1;
};
struct tyTuple__Db8CrQifKGIsKc3w71w7Lw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ key;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* concreteTypes;
};
typedef NU8 tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ;
struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ {
tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
NI Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg {
NI Field0;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* Field1;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* Field2;
};
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
struct tySequence__wbHXzzfwTCmsKuzoRrgI3g {
  TGenericSeq Sup;
  tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw data[SEQ_DECL_SIZE];
};
struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ {
  TGenericSeq Sup;
  tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg data[SEQ_DECL_SIZE];
};
struct tySequence__QAgH1SiSgaqLxO3mmFcEmQ {
  TGenericSeq Sup;
  tyTuple__VrKVnu7fux6g89cTtGzccuw data[SEQ_DECL_SIZE];
};
struct tySequence__UuiPn6QjIiUTdSVwX2PZ6w {
  TGenericSeq Sup;
  tyTuple__9a3DhYVfcy14Fx42tD0lSEQ data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  TGenericSeq Sup;
  tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE];
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  TGenericSeq Sup;
  NU32 data[SEQ_DECL_SIZE];
};
struct tySequence__4Murtwnm0Fyc7F9acrytEXw {
  TGenericSeq Sup;
  tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA data[SEQ_DECL_SIZE];
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  TGenericSeq Sup;
  tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE];
};
struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw {
  TGenericSeq Sup;
  tyTuple__PsEhl3dzznmmJiLAuIXZOg data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg {
  TGenericSeq Sup;
  tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w data[SEQ_DECL_SIZE];
};
struct tySequence__oKtVqsc9bQVCNyrijELM4OQ {
  TGenericSeq Sup;
  tyTuple__Db8CrQifKGIsKc3w71w7Lw data[SEQ_DECL_SIZE];
};
struct tySequence__qy6Iwdy00wN560qud54HTg {
  TGenericSeq Sup;
  tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg data[SEQ_DECL_SIZE];
};
struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ {
  TGenericSeq Sup;
  tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ data[SEQ_DECL_SIZE];
};
struct tySequence__cLsClAAfd0MKkoBQVyvdvw {
  TGenericSeq Sup;
  tyTuple__FEYH9alRJhHD0uTKF2vnIqw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg {
  TGenericSeq Sup;
  tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA data[SEQ_DECL_SIZE];
};
struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw {
  TGenericSeq Sup;
  tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw data[SEQ_DECL_SIZE];
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  TGenericSeq Sup;
  NI64 data[SEQ_DECL_SIZE];
};
struct tySequence__ed0C0uAUZPhvw3RAc5hfYg {
  TGenericSeq Sup;
  tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
struct tySequence__lo3S1lKyiPLhGGB9cBawd6A {
  TGenericSeq Sup;
  tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ data[SEQ_DECL_SIZE];
};
struct tySequence__C3r8jsj9chA4sIlYfDN5aDw {
  TGenericSeq Sup;
  tyTuple__VUJ5Hjm4tKAResBsRHJvYg data[SEQ_DECL_SIZE];
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(tySequence__wbHXzzfwTCmsKuzoRrgI3g*, newSeq__icZdce_1797)(NI len);
static N_INLINE(NI, len__icZpacked95ast_302)(tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree);
N_LIB_PRIVATE N_NIMCALL(void, aliveCode__icZdce_1720)(tyObject_AliveContext__OHV9brHwxGgyHI4IVd0uBGQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* g, tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree, NI n);
N_LIB_PRIVATE N_NIMCALL(void, followLater__icZdce_1505)(tyObject_AliveContext__OHV9brHwxGgyHI4IVd0uBGQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* g, NI module, NI32 item);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__astalgo_402)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(NI, ithSon__icZpacked95ast_544)(tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree, NI n, NI i);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
static N_NIMCALL(void, Marker_tySequence__QAgH1SiSgaqLxO3mmFcEmQ)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ, sons2__icZpacked95ast_507)(tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree, NI n);
N_LIB_PRIVATE N_NIMCALL(NI32, toFileIndexCached__icZic_5515)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* g, NI thisModule, NU32 f);
static N_INLINE(void, nextChild__icZpacked95ast_321)(tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree, NI* pos);
N_LIB_PRIVATE N_NIMCALL(void, rangeCheckAnalysis__icZdce_1700)(tyObject_AliveContext__OHV9brHwxGgyHI4IVd0uBGQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* g, tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree, NI n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg, loadTypeKind__icZdce_1679)(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ t, tyObject_AliveContext__OHV9brHwxGgyHI4IVd0uBGQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* g, tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg toSkip);
N_LIB_PRIVATE N_NIMCALL(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, translateId__icZic_8428)(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ id, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* g, NI thisModule, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config);
static N_INLINE(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ, X5BX5D___icZdce_1692)(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ* s, NI sLen_0, NI i);
static N_INLINE(NI, firstSon__icZpacked95ast_570)(NI n);
N_LIB_PRIVATE N_NIMCALL(void, requestCompilerProc__icZdce_1533)(tyObject_AliveContext__OHV9brHwxGgyHI4IVd0uBGQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* g, NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(tyTuple__Ll5iolPASSzOEheeSNjmiw*, X5BX5D___icZdce_1594)(tyObject_Table__84yOtwIL9aCkCL60odYiF7g* t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isExportedToC__icZdce_25)(tyObject_AliveContext__OHV9brHwxGgyHI4IVd0uBGQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* g, NI32 symId);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___icZdce_153)(tyObject_Table__84yOtwIL9aCkCL60odYiF7g* t, NimStringDesc* key, tyTuple__Ll5iolPASSzOEheeSNjmiw val);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__UuiPn6QjIiUTdSVwX2PZ6w)(void* p, NI op);
static N_INLINE(NimStringDesc**, X5BX5D___icZic_154)(tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ* t, NU32 litId);
static N_INLINE(NI, span__icZpacked95ast_503)(tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree, NI pos);
static N_INLINE(NIM_BOOL, isAtom__icZpacked95ast_215)(tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree, NI pos);
N_LIB_PRIVATE N_NIMCALL(void, followNow__icZdce_1763)(tyObject_AliveContext__OHV9brHwxGgyHI4IVd0uBGQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* g);
static N_INLINE(tyTuple__VrKVnu7fux6g89cTtGzccuw, pop__icZdce_1770)(tySequence__QAgH1SiSgaqLxO3mmFcEmQ** s);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE TNimType NTILint_toptions_nodeposT__VrKVnu7fux6g89cTtGzccuw_;
extern TNimType NTIint__rR5Bzr1D5krxoo1NcNyeMA_;
extern TNimType NTItoptions__JyE8ULWMsetkCt18l86VRw_;
N_LIB_PRIVATE TNimType NTIseqLLint_toptions_nodeposTT__QAgH1SiSgaqLxO3mmFcEmQ_;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__VOZez4W9a02yKrIR7zij6nQ_3 = {
0x10, 0xa9, 0x80, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__VOZez4W9a02yKrIR7zij6nQ_4 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
STRING_LITERAL(TM__VOZez4W9a02yKrIR7zij6nQ_5, "raiseRangeErrorNoArgs", 21);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__VOZez4W9a02yKrIR7zij6nQ_6 = {
0x10, 0xa9, 0x90, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__VOZez4W9a02yKrIR7zij6nQ_7, "raiseRangeErrorU", 16);
STRING_LITERAL(TM__VOZez4W9a02yKrIR7zij6nQ_8, "raiseRangeErrorF", 16);
STRING_LITERAL(TM__VOZez4W9a02yKrIR7zij6nQ_9, "raiseRangeErrorI", 16);
N_LIB_PRIVATE TNimType NTIkeyvaluepair__9a3DhYVfcy14Fx42tD0lSEQ_;
extern TNimType NTIstring__77mFvmsOLKik79ci2hXkHEg_;
N_LIB_PRIVATE TNimType NTILint_int5150T__Ll5iolPASSzOEheeSNjmiw_;
extern TNimType NTIint5150__sVg18TP9cLifHyygRe9cro9aA_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__UuiPn6QjIiUTdSVwX2PZ6w_;
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(NI, len__icZpacked95ast_302)(tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = (tree.nodes ? tree.nodes->Sup.len : 0);
	result = T1_;
	return result;
}
static N_NIMCALL(void, Marker_tySequence__QAgH1SiSgaqLxO3mmFcEmQ)(void* p, NI op) {
	tySequence__QAgH1SiSgaqLxO3mmFcEmQ* a;
	NI T1_;
	a = (tySequence__QAgH1SiSgaqLxO3mmFcEmQ*)p;
	T1_ = (NI)0;
}
N_LIB_PRIVATE N_NIMCALL(void, followLater__icZdce_1505)(tyObject_AliveContext__OHV9brHwxGgyHI4IVd0uBGQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* g, NI module, NI32 item) {
	{
		NIM_BOOL T3_;
		NI32 body;
		T3_ = (NIM_BOOL)0;
		T3_ = containsOrIncl__astalgo_402((&(*c).alive->data[module]), ((NI) (item)));
		if (!!(T3_)) goto LA4_;
		body = g->data[module].fromDisk.syms->data[item].ast;
		{
			tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ opt;
			tyTuple__VrKVnu7fux6g89cTtGzccuw T15_;
			NI T16_;
			if (!!((body == ((NI32) -1)))) goto LA8_;
			opt = g->data[module].fromDisk.syms->data[item].options;
			{
				NI T14_;
				if (!((520192 &((NU32)1<<((NU)(g->data[module].fromDisk.syms->data[item].kind)&31U)))!=0)) goto LA12_;
				T14_ = (NI)0;
				T14_ = ithSon__icZpacked95ast_544(g->data[module].fromDisk.bodies, ((NI) (body)), ((NI) 6));
				body = ((NI32) (T14_));
			}
			LA12_: ;
			T15_.Field0 = module;
			T15_.Field1 = opt;
			T15_.Field2 = ((NI) (body));
			unsureAsgnRef((void**) (&(*c).stack), (tySequence__QAgH1SiSgaqLxO3mmFcEmQ*) incrSeqV3((TGenericSeq*)((*c).stack), (&NTIseqLLint_toptions_nodeposTT__QAgH1SiSgaqLxO3mmFcEmQ_)));
			T16_ = (*c).stack->Sup.len++;
			(*c).stack->data[T16_] = T15_;
		}
		LA8_: ;
	}
	LA4_: ;
}
static N_INLINE(void, nextChild__icZpacked95ast_321)(tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree, NI* pos) {
	{
		if (!(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23) < tree.nodes->data[(*pos)].kind)) goto LA3_;
		(*pos) += ((NI) (tree.nodes->data[(*pos)].operand));
	}
	goto LA1_;
	LA3_: ;
	{
		(*pos) += ((NI) 1);
	}
	LA1_: ;
}
static N_INLINE(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ, X5BX5D___icZdce_1692)(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ* s, NI sLen_0, NI i) {
	tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ result;
	nimZeroMem((void*)(&result), sizeof(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ));
	result = s[(NI)(sLen_0 - i)];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg, loadTypeKind__icZdce_1679)(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ t, tyObject_AliveContext__OHV9brHwxGgyHI4IVd0uBGQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* g, tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg toSkip) {
	tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg result;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg t2;
	result = (tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg)0;
	t2 = translateId__icZic_8428(t, g, (*c).thisModule, (*c).decoder.config);
	result = g->data[t2.module].fromDisk.types->data[t2.item].kind;
	{
		while (1) {
			tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ T3_;
			if (!((toSkip[(NU)(result)>>3] &(1U<<((NU)(result)&7U)))!=0)) goto LA2;
			T3_ = X5BX5D___icZdce_1692((g->data[t2.module].fromDisk.types->data[t2.item].types) ? (g->data[t2.module].fromDisk.types->data[t2.item].types->data) : NIM_NIL, (g->data[t2.module].fromDisk.types->data[t2.item].types ? g->data[t2.module].fromDisk.types->data[t2.item].types->Sup.len : 0), ((NI) 1));
			t2 = translateId__icZic_8428(T3_, g, ((NI) (t2.module)), (*c).decoder.config);
			result = g->data[t2.module].fromDisk.types->data[t2.item].kind;
		} LA2: ;
	}
	return result;
}
static N_INLINE(NI, firstSon__icZpacked95ast_570)(NI n) {
	NI result;
	result = (NI)0;
	result = (NI)(n + ((NI) 1));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, requestCompilerProc__icZdce_1533)(tyObject_AliveContext__OHV9brHwxGgyHI4IVd0uBGQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* g, NimStringDesc* name) {
	tyTuple__Ll5iolPASSzOEheeSNjmiw* T1_;
	NI module;
	NI32 item;
	T1_ = (tyTuple__Ll5iolPASSzOEheeSNjmiw*)0;
	T1_ = X5BX5D___icZdce_1594((&(*c).compilerProcs), name);
	module = (*T1_).Field0;
	item = (*T1_).Field1;
	followLater__icZdce_1505(c, g, module, item);
}
N_LIB_PRIVATE N_NIMCALL(void, rangeCheckAnalysis__icZdce_1700)(tyObject_AliveContext__OHV9brHwxGgyHI4IVd0uBGQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* g, tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree, NI n) {
	tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg dest;
	dest = loadTypeKind__icZdce_1679(tree.nodes->data[n].typeId_0, (&(*c)), g, TM__VOZez4W9a02yKrIR7zij6nQ_3);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !((((*c).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 3))&31U)))!=0));
		if (T3_) goto LA4_;
		T3_ = (dest >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40) && dest <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44));
		LA4_: ;
		if (!T3_) goto LA5_;
	}
	goto LA1_;
	LA5_: ;
	{
		tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg n0t;
		NI T8_;
		T8_ = (NI)0;
		T8_ = firstSon__icZpacked95ast_570(n);
		n0t = loadTypeKind__icZdce_1679(tree.nodes->data[T8_].typeId_0, (&(*c)), g, TM__VOZez4W9a02yKrIR7zij6nQ_4);
		{
			if (!(n0t == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40) || n0t == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44))) goto LA11_;
			requestCompilerProc__icZdce_1533(c, g, ((NimStringDesc*) &TM__VOZez4W9a02yKrIR7zij6nQ_5));
		}
		goto LA9_;
		LA11_: ;
		{
			NimStringDesc* raiser;
			tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg T14_;
			T14_ = (tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg)0;
			T14_ = loadTypeKind__icZdce_1679(tree.nodes->data[n].typeId_0, (&(*c)), g, TM__VOZez4W9a02yKrIR7zij6nQ_6);
			switch (T14_) {
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2):
			{
				raiser = copyString(((NimStringDesc*) &TM__VOZez4W9a02yKrIR7zij6nQ_7));
			}
			break;
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 39):
			{
				raiser = copyString(((NimStringDesc*) &TM__VOZez4W9a02yKrIR7zij6nQ_8));
			}
			break;
			default:
			{
				raiser = copyString(((NimStringDesc*) &TM__VOZez4W9a02yKrIR7zij6nQ_9));
			}
			break;
			}
			requestCompilerProc__icZdce_1533(c, g, raiser);
		}
		LA9_: ;
	}
	LA1_: ;
}
static N_NIMCALL(void, Marker_tySequence__UuiPn6QjIiUTdSVwX2PZ6w)(void* p, NI op) {
	tySequence__UuiPn6QjIiUTdSVwX2PZ6w* a;
	NI T1_;
	a = (tySequence__UuiPn6QjIiUTdSVwX2PZ6w*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field1, op);
	}
}
static N_INLINE(NimStringDesc**, X5BX5D___icZic_154)(tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ* t, NU32 litId) {
	NimStringDesc** result;
	NI idx;
	result = (NimStringDesc**)0;
	idx = (NI)(((NI) (litId)) - ((NI) 256));
	result = (&(*t).vals->data[idx]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isExportedToC__icZdce_25)(tyObject_AliveContext__OHV9brHwxGgyHI4IVd0uBGQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* g, NI32 symId) {
	NIM_BOOL result;
	tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA* symPtr;
	tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
	result = (NIM_BOOL)0;
	symPtr = (&g->data[(*c).thisModule].fromDisk.syms->data[symId]);
	flags = (*symPtr).flags;
	{
		if (!!(((flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 28))&63U)))!=0))) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = !(((262272 & flags) == 0));
			if (T7_) goto LA8_;
			T7_ = ((*symPtr).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 14));
			LA8_: ;
			if (!T7_) goto LA9_;
			result = NIM_TRUE;
		}
		LA9_: ;
		{
			NimStringDesc** T15_;
			tyTuple__Ll5iolPASSzOEheeSNjmiw T16_;
			if (!((flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 18))&63U)))!=0)) goto LA13_;
			T15_ = (NimStringDesc**)0;
			T15_ = X5BX5D___icZic_154((&g->data[(*c).thisModule].fromDisk.strings), (*symPtr).name);
			T16_.Field0 = (*c).thisModule;
			T16_.Field1 = symId;
			X5BX5Deq___icZdce_153((&(*c).compilerProcs), (*T15_), T16_);
		}
		LA13_: ;
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, aliveCode__icZdce_1720)(tyObject_AliveContext__OHV9brHwxGgyHI4IVd0uBGQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* g, tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree, NI n) {
	switch (tree.nodes->data[n].kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 4) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
	{
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		followLater__icZdce_1505(c, g, (*c).thisModule, tree.nodes->data[n].operand);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 162):
	{
		tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ T4_;
		NI n1;
		NI n2;
		NU32 m;
		NI32 item;
		NI otherModule;
		NI32 T5_;
		T4_ = sons2__icZpacked95ast_507(tree, n);
		n1 = T4_.Field0;
		n2 = T4_.Field1;
		m = ((NU32) (tree.nodes->data[n1].operand));
		item = tree.nodes->data[n2].operand;
		T5_ = (NI32)0;
		T5_ = toFileIndexCached__icZic_5515((&(*c).decoder), g, (*c).thisModule, m);
		otherModule = ((NI) (T5_));
		followLater__icZdce_1505(c, g, otherModule, item);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 82):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 83):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 98):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 132):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 125):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 121):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 116):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 117):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 118):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 119):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 120):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 113):
	{
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 99):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 100):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 101):
	{
		{
			NI son;
			NI pos;
			NI last;
			son = (NI)0;
			pos = n;
			last = (NI)(pos + ((NI) (tree.nodes->data[pos].operand)));
			pos += ((NI) 1);
			{
				while (1) {
					if (!(pos < last)) goto LA10;
					son = pos;
					aliveCode__icZdce_1720(c, g, tree, son);
					nextChild__icZpacked95ast_321(tree, (&pos));
				} LA10: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 68):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 69):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 70):
	{
		rangeCheckAnalysis__icZdce_1700(c, g, tree, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 81):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 80):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84):
	{
		{
			NIM_BOOL T15_;
			NI T16_;
			NI T18_;
			NI32 item_2;
			NI T21_;
			T15_ = (NIM_BOOL)0;
			T16_ = (NI)0;
			T16_ = firstSon__icZpacked95ast_570(n);
			T15_ = (tree.nodes->data[T16_].kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
			if (!(T15_)) goto LA17_;
			T18_ = (NI)0;
			T18_ = ithSon__icZpacked95ast_544(tree, n, ((NI) 2));
			T15_ = (tree.nodes->data[T18_].kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1));
			LA17_: ;
			if (!T15_) goto LA19_;
			T21_ = (NI)0;
			T21_ = firstSon__icZpacked95ast_570(n);
			item_2 = tree.nodes->data[T21_].operand;
			{
				NIM_BOOL T24_;
				T24_ = (NIM_BOOL)0;
				T24_ = isExportedToC__icZdce_25(c, g, item_2);
				if (!T24_) goto LA25_;
				followLater__icZdce_1505(c, g, (*c).thisModule, item_2);
			}
			LA25_: ;
		}
		LA19_: ;
	}
	break;
	default:
	{
		{
			NI son_2;
			NI pos_2;
			NI last_2;
			son_2 = (NI)0;
			pos_2 = n;
			last_2 = (NI)(pos_2 + ((NI) (tree.nodes->data[pos_2].operand)));
			pos_2 += ((NI) 1);
			{
				while (1) {
					if (!(pos_2 < last_2)) goto LA30;
					son_2 = pos_2;
					aliveCode__icZdce_1720(c, g, tree, son_2);
					nextChild__icZpacked95ast_321(tree, (&pos_2));
				} LA30: ;
			}
		}
	}
	break;
	}
}
static N_INLINE(NIM_BOOL, isAtom__icZpacked95ast_215)(tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree, NI pos) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = (tree.nodes->data[pos].kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23));
	return result;
}
static N_INLINE(NI, span__icZpacked95ast_503)(tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree, NI pos) {
	NI result;
	result = (NI)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isAtom__icZpacked95ast_215(tree, pos);
		if (!T3_) goto LA4_;
		result = ((NI) 1);
	}
	goto LA1_;
	LA4_: ;
	{
		result = ((NI) (tree.nodes->data[pos].operand));
	}
	LA1_: ;
	return result;
}
static N_INLINE(tyTuple__VrKVnu7fux6g89cTtGzccuw, pop__icZdce_1770)(tySequence__QAgH1SiSgaqLxO3mmFcEmQ** s) {
	tyTuple__VrKVnu7fux6g89cTtGzccuw result;
	NI L;
	NI T1_;
	nimZeroMem((void*)(&result), sizeof(tyTuple__VrKVnu7fux6g89cTtGzccuw));
	T1_ = ((*s) ? (*s)->Sup.len : 0);
	L = (NI)(T1_ - ((NI) 1));
	result = (*s)->data[L];
	unsureAsgnRef((void**) (&(*s)), (tySequence__QAgH1SiSgaqLxO3mmFcEmQ*) setLengthSeqV2(((*s))?&((*s))->Sup:NIM_NIL, (&NTIseqLLint_toptions_nodeposTT__QAgH1SiSgaqLxO3mmFcEmQ_), ((NI) (L))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, followNow__icZdce_1763)(tyObject_AliveContext__OHV9brHwxGgyHI4IVd0uBGQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* g) {
	{
		while (1) {
			NI T3_;
			tyTuple__VrKVnu7fux6g89cTtGzccuw T4_;
			NI modId;
			tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ opt;
			NI ast;
			T3_ = ((*c).stack ? (*c).stack->Sup.len : 0);
			if (!(((NI) 0) < T3_)) goto LA2;
			T4_ = pop__icZdce_1770((&(*c).stack));
			modId = T4_.Field0;
			opt = T4_.Field1;
			ast = T4_.Field2;
			(*c).thisModule = modId;
			(*c).options = opt;
			aliveCode__icZdce_1720(c, g, g->data[modId].fromDisk.bodies, ast);
		} LA2: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(tySequence__wbHXzzfwTCmsKuzoRrgI3g*, computeAliveSyms__icZdce_1785)(tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* g, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	tySequence__wbHXzzfwTCmsKuzoRrgI3g* result;
	tyObject_AliveContext__OHV9brHwxGgyHI4IVd0uBGQ c;
	NI T1_;
	result = NIM_NIL;
	nimZeroMem((void*)(&c), sizeof(tyObject_AliveContext__OHV9brHwxGgyHI4IVd0uBGQ));
	nimZeroMem((void*)(&c), sizeof(tyObject_AliveContext__OHV9brHwxGgyHI4IVd0uBGQ));
	c.stack = NIM_NIL;
	nimZeroMem((void*)(&c.decoder), sizeof(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ));
	c.decoder.config = conf;
	c.thisModule = ((NI) -1);
	T1_ = (g ? g->Sup.len : 0);
	c.alive = newSeq__icZdce_1797(((NI) (T1_)));
	c.options = (*conf).options;
	{
		NI i;
		NI colontmp_;
		NI T3_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T3_ = ((g ? g->Sup.len : 0)-1);
		colontmp_ = T3_;
		res = colontmp_;
		{
			while (1) {
				if (!(((NI) 0) <= res)) goto LA5;
				i = res;
				{
					if (!!((g->data[i].status == ((tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg) 0)))) goto LA8_;
					c.thisModule = i;
					{
						NI p;
						tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg colontmp__2;
						NI p_2;
						p = (NI)0;
						nimZeroMem((void*)(&colontmp__2), sizeof(tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg));
						colontmp__2.nodes = g->data[i].fromDisk.topLevel.nodes;
						p_2 = ((NI) 0);
						{
							while (1) {
								NI T13_;
								NI s;
								T13_ = (NI)0;
								T13_ = len__icZpacked95ast_302(colontmp__2);
								if (!(p_2 < T13_)) goto LA12;
								p = p_2;
								aliveCode__icZdce_1720((&c), g, g->data[i].fromDisk.topLevel, p);
								s = span__icZpacked95ast_503(colontmp__2, p_2);
								p_2 += s;
							} LA12: ;
						}
					}
				}
				LA8_: ;
				res -= ((NI) 1);
			} LA5: ;
		}
	}
	followNow__icZdce_1763((&c), g);
	result = c.alive;
	c.alive = NIM_NIL;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, atmicatsdcedotnim_DatInit000)(void) {
static TNimNode* TM__VOZez4W9a02yKrIR7zij6nQ_2_3[3];
static TNimNode* TM__VOZez4W9a02yKrIR7zij6nQ_10_3[3];
static TNimNode* TM__VOZez4W9a02yKrIR7zij6nQ_11_2[2];
static TNimNode TM__VOZez4W9a02yKrIR7zij6nQ_0[11];
NTILint_toptions_nodeposT__VrKVnu7fux6g89cTtGzccuw_.size = sizeof(tyTuple__VrKVnu7fux6g89cTtGzccuw);
NTILint_toptions_nodeposT__VrKVnu7fux6g89cTtGzccuw_.align = NIM_ALIGNOF(tyTuple__VrKVnu7fux6g89cTtGzccuw);
NTILint_toptions_nodeposT__VrKVnu7fux6g89cTtGzccuw_.kind = 18;
NTILint_toptions_nodeposT__VrKVnu7fux6g89cTtGzccuw_.base = 0;
NTILint_toptions_nodeposT__VrKVnu7fux6g89cTtGzccuw_.flags = 3;
TM__VOZez4W9a02yKrIR7zij6nQ_2_3[0] = &TM__VOZez4W9a02yKrIR7zij6nQ_0[1];
TM__VOZez4W9a02yKrIR7zij6nQ_0[1].kind = 1;
TM__VOZez4W9a02yKrIR7zij6nQ_0[1].offset = offsetof(tyTuple__VrKVnu7fux6g89cTtGzccuw, Field0);
TM__VOZez4W9a02yKrIR7zij6nQ_0[1].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__VOZez4W9a02yKrIR7zij6nQ_0[1].name = "Field0";
TM__VOZez4W9a02yKrIR7zij6nQ_2_3[1] = &TM__VOZez4W9a02yKrIR7zij6nQ_0[2];
TM__VOZez4W9a02yKrIR7zij6nQ_0[2].kind = 1;
TM__VOZez4W9a02yKrIR7zij6nQ_0[2].offset = offsetof(tyTuple__VrKVnu7fux6g89cTtGzccuw, Field1);
TM__VOZez4W9a02yKrIR7zij6nQ_0[2].typ = (&NTItoptions__JyE8ULWMsetkCt18l86VRw_);
TM__VOZez4W9a02yKrIR7zij6nQ_0[2].name = "Field1";
TM__VOZez4W9a02yKrIR7zij6nQ_2_3[2] = &TM__VOZez4W9a02yKrIR7zij6nQ_0[3];
TM__VOZez4W9a02yKrIR7zij6nQ_0[3].kind = 1;
TM__VOZez4W9a02yKrIR7zij6nQ_0[3].offset = offsetof(tyTuple__VrKVnu7fux6g89cTtGzccuw, Field2);
TM__VOZez4W9a02yKrIR7zij6nQ_0[3].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__VOZez4W9a02yKrIR7zij6nQ_0[3].name = "Field2";
TM__VOZez4W9a02yKrIR7zij6nQ_0[0].len = 3; TM__VOZez4W9a02yKrIR7zij6nQ_0[0].kind = 2; TM__VOZez4W9a02yKrIR7zij6nQ_0[0].sons = &TM__VOZez4W9a02yKrIR7zij6nQ_2_3[0];
NTILint_toptions_nodeposT__VrKVnu7fux6g89cTtGzccuw_.node = &TM__VOZez4W9a02yKrIR7zij6nQ_0[0];
NTIseqLLint_toptions_nodeposTT__QAgH1SiSgaqLxO3mmFcEmQ_.size = sizeof(tySequence__QAgH1SiSgaqLxO3mmFcEmQ*);
NTIseqLLint_toptions_nodeposTT__QAgH1SiSgaqLxO3mmFcEmQ_.align = NIM_ALIGNOF(tySequence__QAgH1SiSgaqLxO3mmFcEmQ*);
NTIseqLLint_toptions_nodeposTT__QAgH1SiSgaqLxO3mmFcEmQ_.kind = 24;
NTIseqLLint_toptions_nodeposTT__QAgH1SiSgaqLxO3mmFcEmQ_.base = (&NTILint_toptions_nodeposT__VrKVnu7fux6g89cTtGzccuw_);
NTIseqLLint_toptions_nodeposTT__QAgH1SiSgaqLxO3mmFcEmQ_.flags = 2;
NTIseqLLint_toptions_nodeposTT__QAgH1SiSgaqLxO3mmFcEmQ_.marker = Marker_tySequence__QAgH1SiSgaqLxO3mmFcEmQ;
NTIkeyvaluepair__9a3DhYVfcy14Fx42tD0lSEQ_.size = sizeof(tyTuple__9a3DhYVfcy14Fx42tD0lSEQ);
NTIkeyvaluepair__9a3DhYVfcy14Fx42tD0lSEQ_.align = NIM_ALIGNOF(tyTuple__9a3DhYVfcy14Fx42tD0lSEQ);
NTIkeyvaluepair__9a3DhYVfcy14Fx42tD0lSEQ_.kind = 18;
NTIkeyvaluepair__9a3DhYVfcy14Fx42tD0lSEQ_.base = 0;
NTIkeyvaluepair__9a3DhYVfcy14Fx42tD0lSEQ_.flags = 2;
TM__VOZez4W9a02yKrIR7zij6nQ_10_3[0] = &TM__VOZez4W9a02yKrIR7zij6nQ_0[5];
TM__VOZez4W9a02yKrIR7zij6nQ_0[5].kind = 1;
TM__VOZez4W9a02yKrIR7zij6nQ_0[5].offset = offsetof(tyTuple__9a3DhYVfcy14Fx42tD0lSEQ, Field0);
TM__VOZez4W9a02yKrIR7zij6nQ_0[5].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__VOZez4W9a02yKrIR7zij6nQ_0[5].name = "Field0";
TM__VOZez4W9a02yKrIR7zij6nQ_10_3[1] = &TM__VOZez4W9a02yKrIR7zij6nQ_0[6];
TM__VOZez4W9a02yKrIR7zij6nQ_0[6].kind = 1;
TM__VOZez4W9a02yKrIR7zij6nQ_0[6].offset = offsetof(tyTuple__9a3DhYVfcy14Fx42tD0lSEQ, Field1);
TM__VOZez4W9a02yKrIR7zij6nQ_0[6].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__VOZez4W9a02yKrIR7zij6nQ_0[6].name = "Field1";
TM__VOZez4W9a02yKrIR7zij6nQ_10_3[2] = &TM__VOZez4W9a02yKrIR7zij6nQ_0[7];
NTILint_int5150T__Ll5iolPASSzOEheeSNjmiw_.size = sizeof(tyTuple__Ll5iolPASSzOEheeSNjmiw);
NTILint_int5150T__Ll5iolPASSzOEheeSNjmiw_.align = NIM_ALIGNOF(tyTuple__Ll5iolPASSzOEheeSNjmiw);
NTILint_int5150T__Ll5iolPASSzOEheeSNjmiw_.kind = 18;
NTILint_int5150T__Ll5iolPASSzOEheeSNjmiw_.base = 0;
NTILint_int5150T__Ll5iolPASSzOEheeSNjmiw_.flags = 3;
TM__VOZez4W9a02yKrIR7zij6nQ_11_2[0] = &TM__VOZez4W9a02yKrIR7zij6nQ_0[9];
TM__VOZez4W9a02yKrIR7zij6nQ_0[9].kind = 1;
TM__VOZez4W9a02yKrIR7zij6nQ_0[9].offset = offsetof(tyTuple__Ll5iolPASSzOEheeSNjmiw, Field0);
TM__VOZez4W9a02yKrIR7zij6nQ_0[9].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__VOZez4W9a02yKrIR7zij6nQ_0[9].name = "Field0";
TM__VOZez4W9a02yKrIR7zij6nQ_11_2[1] = &TM__VOZez4W9a02yKrIR7zij6nQ_0[10];
TM__VOZez4W9a02yKrIR7zij6nQ_0[10].kind = 1;
TM__VOZez4W9a02yKrIR7zij6nQ_0[10].offset = offsetof(tyTuple__Ll5iolPASSzOEheeSNjmiw, Field1);
TM__VOZez4W9a02yKrIR7zij6nQ_0[10].typ = (&NTIint5150__sVg18TP9cLifHyygRe9cro9aA_);
TM__VOZez4W9a02yKrIR7zij6nQ_0[10].name = "Field1";
TM__VOZez4W9a02yKrIR7zij6nQ_0[8].len = 2; TM__VOZez4W9a02yKrIR7zij6nQ_0[8].kind = 2; TM__VOZez4W9a02yKrIR7zij6nQ_0[8].sons = &TM__VOZez4W9a02yKrIR7zij6nQ_11_2[0];
NTILint_int5150T__Ll5iolPASSzOEheeSNjmiw_.node = &TM__VOZez4W9a02yKrIR7zij6nQ_0[8];
TM__VOZez4W9a02yKrIR7zij6nQ_0[7].kind = 1;
TM__VOZez4W9a02yKrIR7zij6nQ_0[7].offset = offsetof(tyTuple__9a3DhYVfcy14Fx42tD0lSEQ, Field2);
TM__VOZez4W9a02yKrIR7zij6nQ_0[7].typ = (&NTILint_int5150T__Ll5iolPASSzOEheeSNjmiw_);
TM__VOZez4W9a02yKrIR7zij6nQ_0[7].name = "Field2";
TM__VOZez4W9a02yKrIR7zij6nQ_0[4].len = 3; TM__VOZez4W9a02yKrIR7zij6nQ_0[4].kind = 2; TM__VOZez4W9a02yKrIR7zij6nQ_0[4].sons = &TM__VOZez4W9a02yKrIR7zij6nQ_10_3[0];
NTIkeyvaluepair__9a3DhYVfcy14Fx42tD0lSEQ_.node = &TM__VOZez4W9a02yKrIR7zij6nQ_0[4];
NTIkeyvaluepairseq__UuiPn6QjIiUTdSVwX2PZ6w_.size = sizeof(tySequence__UuiPn6QjIiUTdSVwX2PZ6w*);
NTIkeyvaluepairseq__UuiPn6QjIiUTdSVwX2PZ6w_.align = NIM_ALIGNOF(tySequence__UuiPn6QjIiUTdSVwX2PZ6w*);
NTIkeyvaluepairseq__UuiPn6QjIiUTdSVwX2PZ6w_.kind = 24;
NTIkeyvaluepairseq__UuiPn6QjIiUTdSVwX2PZ6w_.base = (&NTIkeyvaluepair__9a3DhYVfcy14Fx42tD0lSEQ_);
NTIkeyvaluepairseq__UuiPn6QjIiUTdSVwX2PZ6w_.flags = 2;
NTIkeyvaluepairseq__UuiPn6QjIiUTdSVwX2PZ6w_.marker = Marker_tySequence__UuiPn6QjIiUTdSVwX2PZ6w;
}

