/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tyObject_Table__gomBN9cF0n3KCLfQvSeVI7Q tyObject_Table__gomBN9cF0n3KCLfQvSeVI7Q;
typedef struct tySequence__OeT2uxU9cpZvGBACtO9b4xwQ tySequence__OeT2uxU9cpZvGBACtO9b4xwQ;
typedef struct tyTuple__usE1QHGQhF6zycm9bQm6MMA tyTuple__usE1QHGQhF6zycm9bQm6MMA;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA;
typedef struct tyObject_BaseLexer__1ErHTvYSm67JCofXisRUnA tyObject_BaseLexer__1ErHTvYSm67JCofXisRUnA;
typedef struct RootObj RootObj;
typedef struct tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg;
typedef struct tySequence__QAzA9aOtpCCvcxe8jjx2Rmw tySequence__QAzA9aOtpCCvcxe8jjx2Rmw;
typedef struct tyObject_StringStreamObj__0donmYG9cFGYrdaYfy8rp2g tyObject_StringStreamObj__0donmYG9cFGYrdaYfy8rp2g;
typedef struct tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_Table__gomBN9cF0n3KCLfQvSeVI7Q {
tySequence__OeT2uxU9cpZvGBACtO9b4xwQ* data;
NI counter;
};
struct tyTuple__usE1QHGQhF6zycm9bQm6MMA {
NI Field0;
NI64 Field1;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field2;
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct RootObj {
TNimType* m_type;
};
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
struct tyObject_BaseLexer__1ErHTvYSm67JCofXisRUnA {
  RootObj Sup;
NI bufpos;
NimStringDesc* buf;
tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg* input;
NI lineNumber;
NI sentinel;
NI lineStart;
NI offsetBase;
tySet_tyChar__nmiMWKVIe46vacnhAFrQvw refillChars;
};
typedef NU8 tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg;
typedef NU8 tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg;
typedef NU8 tyEnum_JsonError__9bOLqlKJO6K9b1fxRo9bWfh3w;
struct tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA {
  tyObject_BaseLexer__1ErHTvYSm67JCofXisRUnA Sup;
NimStringDesc* a;
tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg tok;
tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg kind;
tyEnum_JsonError__9bOLqlKJO6K9b1fxRo9bWfh3w err;
tySequence__QAzA9aOtpCCvcxe8jjx2Rmw* state;
NimStringDesc* filename;
NIM_BOOL rawStringLiterals;
};
typedef N_NIMCALL_PTR(void, tyProc__u1QtPTYUJu1ozpzb9a8xchw) (tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg* s);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__VytW5cBLp1DOuwAj9cjoj3Q) (tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg* s);
typedef N_NIMCALL_PTR(void, tyProc__nAUmmvz53fMDhkU9aQ4i60Q) (tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg* s, NI pos);
typedef N_NIMCALL_PTR(NI, tyProc__rvgAWCz6iG9cntloh2xzZmQ) (tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg* s);
typedef N_NIMCALL_PTR(NI, tyProc__sAr4e3JGOuIBVEZ29aGGKUQ) (tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg* s, NimStringDesc** buffer, tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw slice);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__7SoiV5lfjKUldz1ENKXq1w) (tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg* s, NimStringDesc** line);
typedef N_NIMCALL_PTR(NI, tyProc__mPF9ae7sAGGCOezlsIuH6Yg) (tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg* s, void* buffer, NI bufLen);
typedef N_NIMCALL_PTR(void, tyProc__1nrRaSRiXjiE9bnEpZhmOsA) (tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg* s, void* buffer, NI bufLen);
struct tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg {
  RootObj Sup;
tyProc__u1QtPTYUJu1ozpzb9a8xchw closeImpl;
tyProc__VytW5cBLp1DOuwAj9cjoj3Q atEndImpl;
tyProc__nAUmmvz53fMDhkU9aQ4i60Q setPositionImpl;
tyProc__rvgAWCz6iG9cntloh2xzZmQ getPositionImpl;
tyProc__sAr4e3JGOuIBVEZ29aGGKUQ readDataStrImpl;
tyProc__7SoiV5lfjKUldz1ENKXq1w readLineImpl;
tyProc__mPF9ae7sAGGCOezlsIuH6Yg readDataImpl;
tyProc__mPF9ae7sAGGCOezlsIuH6Yg peekDataImpl;
tyProc__1nrRaSRiXjiE9bnEpZhmOsA writeDataImpl;
tyProc__u1QtPTYUJu1ozpzb9a8xchw flushImpl;
};
struct tyObject_StringStreamObj__0donmYG9cFGYrdaYfy8rp2g {
  tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg Sup;
NimStringDesc* data;
NI pos;
};
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInst;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg uniqueId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg {
NI id;
NimStringDesc* s;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* next;
NI h;
};
typedef NU8 tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg;
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg {
NI32 module;
NI32 symId;
NI32 typeId_0;
NIM_BOOL sealed;
};
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
typedef NU8 tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw;
struct tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw {
NI a;
NI b;
};
struct tySequence__OeT2uxU9cpZvGBACtO9b4xwQ {
  TGenericSeq Sup;
  tyTuple__usE1QHGQhF6zycm9bQm6MMA data[SEQ_DECL_SIZE];
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__QAzA9aOtpCCvcxe8jjx2Rmw {
  TGenericSeq Sup;
  tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void, initTable__vmmarshal_1860)(NI initialSize, tyObject_Table__gomBN9cF0n3KCLfQvSeVI7Q* Result);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__OeT2uxU9cpZvGBACtO9b4xwQ)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, open__pureZparsejson_97)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my, tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg* input, NimStringDesc* filename, NIM_BOOL rawStringLiterals);
N_LIB_PRIVATE N_NIMCALL(tyObject_StringStreamObj__0donmYG9cFGYrdaYfy8rp2g*, newStringStream__pureZstreams_676)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(void, next__pureZparsejson_447)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, loadAny__vmmarshal_206)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* p, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_Table__gomBN9cF0n3KCLfQvSeVI7Q* tab, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
static N_INLINE(tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg, kind__pureZparsejson_185)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newIntNode__ast_3711)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, NI64 intVal);
N_LIB_PRIVATE N_NOINLINE(void, raiseParseErr__pureZparsejson_571)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* p, NimStringDesc* msg) __attribute__((noreturn));
static N_INLINE(NimStringDesc*, str__pureZparsejson_153)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
static N_INLINE(NI64, getInt__pureZparsejson_164)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my);
N_LIB_PRIVATE N_NIMCALL(NI64, nsuParseBiggestInt)(NimStringDesc* s);
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNode__ast_3289)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_4798)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, elemType__types_263)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
static N_INLINE(NI, len__ast_3990)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, typeToString__types_50)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg prefer);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
static N_INLINE(void, decRef__system_5318)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5316)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5267)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5273)(void* usr);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqRC1)(TNimType* typ, NI len);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5311)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*, getIdent__idents_152)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* ic, NimStringDesc* identifier);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, lookupInRecord__astalgo_84)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* field);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newSymNode__ast_3704)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, newSym__ast_3409)(tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw symKind, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg id, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options);
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextSymId__ast_3103)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, lastSon__ast_3731)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, getOrDefault__vmmarshal_446)(tyObject_Table__gomBN9cF0n3KCLfQvSeVI7Q t, NI64 key);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___systemZdollars_6)(NI64 x);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___vmmarshal_802)(tyObject_Table__gomBN9cF0n3KCLfQvSeVI7Q* t, NI64 key, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* val);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newStrNode__ast_3801)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, NimStringDesc* strVal);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newFloatNode__ast_3797)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, NF floatVal);
static N_INLINE(NF, getFloat__pureZparsejson_175)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my);
N_LIB_PRIVATE N_NIMCALL(NF, nsuParseFloat)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_1441)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
static N_INLINE(void, close__pureZparsejson_151)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my);
N_LIB_PRIVATE N_NIMCALL(void, close__pureZlexbase_14)(tyObject_BaseLexer__1ErHTvYSm67JCofXisRUnA* L);
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(void, initPackedSet__pureZcollectionsZintsets_16)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(void, storeAny__vmmarshal_54)(NimStringDesc** s, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* stored, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimBoolToStr)(NIM_BOOL x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, escapeJson__pureZjson_4374)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimCharToStr)(NIM_CHAR x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___systemZdollars_3)(NI x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, skipColon__ast_4949)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, storeObj__vmmarshal_60)(NimStringDesc** s, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* stored, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getField__vmmarshal_15)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI position);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, lastSon__ast_4833)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, copyNode__ast_4324)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* src);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__astalgo_402)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
static N_INLINE(NI, ptrToInt__vmmarshal_12)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___system_3126)(NF x);
N_LIB_PRIVATE TNimType NTIkeyvaluepair__usE1QHGQhF6zycm9bQm6MMA_;
extern TNimType NTIint__rR5Bzr1D5krxoo1NcNyeMA_;
extern TNimType NTIbiggestint__Aav8dQoMlCFnZRxA0IhTHQ_;
extern TNimType NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__OeT2uxU9cpZvGBACtO9b4xwQ_;
extern TNimType NTIjsonparser__w6FDVeQ36QibBeDgwddDMA_;
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_3, "unknown file", 12);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_4, "\'true\' or \'false\' expected for a bool", 37);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_5, "string of length 1 expected for a char", 38);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_6, "string expected for an enum", 27);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_7, "\'[\' expected for an array", 25);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_8, "\']\' end of array expected", 25);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_9, "\'[\' expected for a seq", 22);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_10, "\'{\' expected for an object", 26);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_11, "string expected for a field name", 32);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_12, "too many fields to tuple type ", 30);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_13, "\'}\' end of object expected", 26);
extern TNimType NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_;
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_14, "unknown field for object of type ", 33);
extern NIM_CONST tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw unknownLineInfo__lineinfos_284;
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_15, "\'[\' expected for a set", 22);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_16, "cannot load object with address ", 32);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_17, "index for ref type expected", 27);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_18, "\']\' end of ref-address pair expected", 36);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_19, "int for pointer type expected", 29);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_20, "string expected", 15);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_21, "int expected", 12);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_22, "float expected", 14);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_23, "cannot marshal at compile-time ", 31);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_25, "/home/runner/work/nightlies/nightlies/nim/compiler/vmmarshal.nim", 64);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BJX8XfdlwqKRXJxSDkJW8w_24 = {((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_25),
((NI) 282),
((NI) 18)}
;
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_26, "null", 4);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_27, "[", 1);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_28, ", ", 2);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_29, "]", 1);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_30, "{", 1);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_31, "\"Field", 6);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_32, "\": ", 3);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_33, "}", 1);
STRING_LITERAL(TM__BJX8XfdlwqKRXJxSDkJW8w_34, ": ", 2);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BJX8XfdlwqKRXJxSDkJW8w_35 = {((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_25),
((NI) 131),
((NI) 18)}
;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5220;
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_NIMCALL(void, Marker_tySequence__OeT2uxU9cpZvGBACtO9b4xwQ)(void* p, NI op) {
	tySequence__OeT2uxU9cpZvGBACtO9b4xwQ* a;
	NI T1_;
	a = (tySequence__OeT2uxU9cpZvGBACtO9b4xwQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field2, op);
	}
}
static N_INLINE(tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg, kind__pureZparsejson_185)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my) {
	tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg result;
{	result = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
	result = (*my).kind;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NimStringDesc*, str__pureZparsejson_153)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my) {
	NimStringDesc* result;
{	result = NIM_NIL;
	result = copyString((*my).a);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI64, getInt__pureZparsejson_164)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my) {
	NI64 result;
{	result = (NI64)0;
	result = nsuParseBiggestInt((*my).a);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__ast_3155(n);
	}
	LA1_: ;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, len__ast_3990)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n).sons ? (*n).sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5316)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5267((&gch__system_5220.zct), c);
}
static N_INLINE(void, decRef__system_5318)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5316(c);
	}
	LA4_: ;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5273)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5273(p);
	decRef__system_5318(T1_);
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5311)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5273(src);
		incRef__system_5311(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5273((*dest));
		decRef__system_5318(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextSymId__ast_3103)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x) {
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*x).symId += ((NI) 1);
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	result.module = (*x).module;
	result.item = (*x).symId;
	return result;
}
static N_INLINE(NF, getFloat__pureZparsejson_175)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my) {
	NF result;
{	result = (NF)0;
	result = nsuParseFloat((*my).a);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, loadAny__vmmarshal_206)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* p, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_Table__gomBN9cF0n3KCLfQvSeVI7Q* tab, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
{	result = NIM_NIL;
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 0):
	{
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1):
	{
		tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T3_;
		T3_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
		T3_ = kind__pureZparsejson_185((&(*p)));
		switch (T3_) {
		case ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 6):
		{
			result = newIntNode__ast_3711(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6), IL64(0));
		}
		break;
		case ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 5):
		{
			result = newIntNode__ast_3711(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6), IL64(1));
		}
		break;
		default:
		{
			raiseParseErr__pureZparsejson_571((&(*p)), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_4));
		}
		break;
		}
		next__pureZparsejson_447(p);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2):
	{
		{
			tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T10_;
			NimStringDesc* x;
			T10_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
			T10_ = kind__pureZparsejson_185((&(*p)));
			if (!(T10_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 2))) goto LA11_;
			x = str__pureZparsejson_153((&(*p)));
			{
				if (!((x ? x->Sup.len : 0) == ((NI) 1))) goto LA15_;
				result = newIntNode__ast_3711(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6), ((NI64) (((NU8)(x->data[((NI) 0)])))));
				next__pureZparsejson_447(p);
				goto BeforeRet_;
			}
			LA15_: ;
		}
		goto LA8_;
		LA11_: ;
		{
			tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T18_;
			NI64 T21_;
			T18_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
			T18_ = kind__pureZparsejson_185((&(*p)));
			if (!(T18_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 3))) goto LA19_;
			T21_ = (NI64)0;
			T21_ = getInt__pureZparsejson_164((&(*p)));
			result = newIntNode__ast_3711(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6), T21_);
			next__pureZparsejson_447(p);
			goto BeforeRet_;
		}
		goto LA8_;
		LA19_: ;
		LA8_: ;
		raiseParseErr__pureZparsejson_571((&(*p)), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_5));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14):
	{
		{
			tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T25_;
			T25_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
			T25_ = kind__pureZparsejson_185((&(*p)));
			if (!(T25_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 2))) goto LA26_;
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e;
				e = NIM_NIL;
				{
					NI i;
					NI colontmp_;
					NI i_2;
					i = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = safeLen__ast_3148((*t).n);
					i_2 = ((NI) 0);
					{
						while (1) {
							if (!(i_2 < colontmp_)) goto LA31;
							i = i_2;
							e = (*(*t).n)._kind_6.sons->data[i];
							{
								NimStringDesc* T34_;
								T34_ = NIM_NIL;
								T34_ = str__pureZparsejson_153((&(*p)));
								if (!eqStrings((*(*(*e)._kind_4.sym).name).s, T34_)) goto LA35_;
								result = newIntNode__ast_3711(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6), ((NI64) ((*(*e)._kind_4.sym).position)));
								next__pureZparsejson_447(p);
								goto BeforeRet_;
							}
							LA35_: ;
							i_2 += ((NI) 1);
						} LA31: ;
					}
				}
			}
		}
		LA26_: ;
		raiseParseErr__pureZparsejson_571((&(*p)), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_6));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
	{
		{
			tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T40_;
			T40_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
			T40_ = kind__pureZparsejson_185((&(*p)));
			if (!!((T40_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 10)))) goto LA41_;
			raiseParseErr__pureZparsejson_571((&(*p)), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_7));
		}
		LA41_: ;
		next__pureZparsejson_447(p);
		result = newNode__ast_3289(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41));
		{
			while (1) {
				NIM_BOOL T45_;
				tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T46_;
				tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T48_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T49_;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T50_;
				T45_ = (NIM_BOOL)0;
				T46_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
				T46_ = kind__pureZparsejson_185((&(*p)));
				T45_ = !((T46_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 11)));
				if (!(T45_)) goto LA47_;
				T48_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
				T48_ = kind__pureZparsejson_185((&(*p)));
				T45_ = !((T48_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 1)));
				LA47_: ;
				if (!T45_) goto LA44;
				T49_ = NIM_NIL;
				T49_ = elemType__types_263(t);
				T50_ = NIM_NIL;
				T50_ = loadAny__vmmarshal_206(p, T49_, tab, cache, conf, idgen);
				add__ast_4798(result, T50_);
			} LA44: ;
		}
		{
			tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T53_;
			T53_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
			T53_ = kind__pureZparsejson_185((&(*p)));
			if (!(T53_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 11))) goto LA54_;
			next__pureZparsejson_447(p);
		}
		goto LA51_;
		LA54_: ;
		{
			raiseParseErr__pureZparsejson_571((&(*p)), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_8));
		}
		LA51_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
	{
		tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T58_;
		T58_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
		T58_ = kind__pureZparsejson_185((&(*p)));
		switch (T58_) {
		case ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 7):
		{
			result = newNode__ast_3289(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23));
			next__pureZparsejson_447(p);
		}
		break;
		case ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 10):
		{
			next__pureZparsejson_447(p);
			result = newNode__ast_3289(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41));
			{
				while (1) {
					NIM_BOOL T63_;
					tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T64_;
					tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T66_;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T67_;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T68_;
					T63_ = (NIM_BOOL)0;
					T64_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
					T64_ = kind__pureZparsejson_185((&(*p)));
					T63_ = !((T64_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 11)));
					if (!(T63_)) goto LA65_;
					T66_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
					T66_ = kind__pureZparsejson_185((&(*p)));
					T63_ = !((T66_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 1)));
					LA65_: ;
					if (!T63_) goto LA62;
					T67_ = NIM_NIL;
					T67_ = elemType__types_263(t);
					T68_ = NIM_NIL;
					T68_ = loadAny__vmmarshal_206(p, T67_, tab, cache, conf, idgen);
					add__ast_4798(result, T68_);
				} LA62: ;
			}
			{
				tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T71_;
				T71_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
				T71_ = kind__pureZparsejson_185((&(*p)));
				if (!(T71_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 11))) goto LA72_;
				next__pureZparsejson_447(p);
			}
			goto LA69_;
			LA72_: ;
			{
				raiseParseErr__pureZparsejson_571((&(*p)), ((NimStringDesc*) NIM_NIL));
			}
			LA69_: ;
		}
		break;
		default:
		{
			raiseParseErr__pureZparsejson_571((&(*p)), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_9));
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18):
	{
		NI i_3;
		{
			tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T79_;
			T79_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
			T79_ = kind__pureZparsejson_185((&(*p)));
			if (!!((T79_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 8)))) goto LA80_;
			raiseParseErr__pureZparsejson_571((&(*p)), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_10));
		}
		LA80_: ;
		next__pureZparsejson_447(p);
		result = newNode__ast_3289(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 160));
		i_3 = ((NI) 0);
		{
			while (1) {
				NIM_BOOL T84_;
				tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T85_;
				tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T87_;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T100_;
				T84_ = (NIM_BOOL)0;
				T85_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
				T85_ = kind__pureZparsejson_185((&(*p)));
				T84_ = !((T85_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 9)));
				if (!(T84_)) goto LA86_;
				T87_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
				T87_ = kind__pureZparsejson_185((&(*p)));
				T84_ = !((T87_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 1)));
				LA86_: ;
				if (!T84_) goto LA83;
				{
					tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T90_;
					T90_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
					T90_ = kind__pureZparsejson_185((&(*p)));
					if (!!((T90_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 2)))) goto LA91_;
					raiseParseErr__pureZparsejson_571((&(*p)), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_11));
				}
				LA91_: ;
				next__pureZparsejson_447(p);
				{
					NI T95_;
					NimStringDesc* T98_;
					NimStringDesc* T99_;
					T95_ = (NI)0;
					T95_ = len__ast_3990(t);
					if (!(T95_ <= i_3)) goto LA96_;
					T98_ = NIM_NIL;
					T99_ = NIM_NIL;
					T99_ = typeToString__types_50(t, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
					T98_ = rawNewString((T99_ ? T99_->Sup.len : 0) + 30);
appendString(T98_, ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_12));
appendString(T98_, T99_);
					raiseParseErr__pureZparsejson_571((&(*p)), T98_);
				}
				LA96_: ;
				T100_ = NIM_NIL;
				T100_ = loadAny__vmmarshal_206(p, (*t).sons->data[i_3], tab, cache, conf, idgen);
				add__ast_4798(result, T100_);
				i_3 += ((NI) 1);
			} LA83: ;
		}
		{
			tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T103_;
			T103_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
			T103_ = kind__pureZparsejson_185((&(*p)));
			if (!(T103_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 9))) goto LA104_;
			next__pureZparsejson_447(p);
		}
		goto LA101_;
		LA104_: ;
		{
			raiseParseErr__pureZparsejson_571((&(*p)), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_13));
		}
		LA101_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17):
	{
		{
			tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T110_;
			T110_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
			T110_ = kind__pureZparsejson_185((&(*p)));
			if (!!((T110_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 8)))) goto LA111_;
			raiseParseErr__pureZparsejson_571((&(*p)), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_10));
		}
		LA111_: ;
		next__pureZparsejson_447(p);
		result = newNode__ast_3289(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 38));
		if ((*result)._kind_6.sons) { nimGCunrefNoCycle((*result)._kind_6.sons); (*result)._kind_6.sons = NIM_NIL; }
		(*result)._kind_6.sons = (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) newSeqRC1((&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), 1);
		asgnRef((void**) (&(*result)._kind_6.sons->data[0]), newNode__ast_3289(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)));
		{
			while (1) {
				NIM_BOOL T115_;
				tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T116_;
				tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T118_;
				tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
				NimStringDesc* T124_;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field;
				NI pos;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* fieldNode;
				tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T136_;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T137_;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T138_;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T139_;
				T115_ = (NIM_BOOL)0;
				T116_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
				T116_ = kind__pureZparsejson_185((&(*p)));
				T115_ = !((T116_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 9)));
				if (!(T115_)) goto LA117_;
				T118_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
				T118_ = kind__pureZparsejson_185((&(*p)));
				T115_ = !((T118_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 1)));
				LA117_: ;
				if (!T115_) goto LA114;
				{
					tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T121_;
					T121_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
					T121_ = kind__pureZparsejson_185((&(*p)));
					if (!!((T121_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 2)))) goto LA122_;
					raiseParseErr__pureZparsejson_571((&(*p)), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_11));
				}
				LA122_: ;
				T124_ = NIM_NIL;
				T124_ = str__pureZparsejson_153((&(*p)));
				ident = getIdent__idents_152(cache, T124_);
				field = lookupInRecord__astalgo_84((*t).n, ident);
				{
					NimStringDesc* T129_;
					NimStringDesc* T130_;
					if (!(field == 0)) goto LA127_;
					T129_ = NIM_NIL;
					T130_ = NIM_NIL;
					T130_ = typeToString__types_50(t, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
					T129_ = rawNewString((T130_ ? T130_->Sup.len : 0) + 33);
appendString(T129_, ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_14));
appendString(T129_, T130_);
					raiseParseErr__pureZparsejson_571((&(*p)), T129_);
				}
				LA127_: ;
				next__pureZparsejson_447(p);
				pos = (NI)((*field).position + ((NI) 1));
				{
					NI T133_;
					T133_ = (NI)0;
					T133_ = len__ast_3155(result);
					if (!(T133_ <= pos)) goto LA134_;
					asgnRef((void**) (&(*result)._kind_6.sons), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) setLengthSeqV2(((*result)._kind_6.sons)?&((*result)._kind_6.sons)->Sup:NIM_NIL, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) ((NI)(pos + ((NI) 1))))));
				}
				LA134_: ;
				fieldNode = newNode__ast_3289(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34));
				T136_ = nextSymId__ast_3103(idgen);
				T137_ = NIM_NIL;
				T137_ = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19), ident, T136_, ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL), unknownLineInfo__lineinfos_284, 0);
				T138_ = NIM_NIL;
				T138_ = newSymNode__ast_3704(T137_);
				add__ast_4798(fieldNode, T138_);
				T139_ = NIM_NIL;
				T139_ = loadAny__vmmarshal_206(p, (*field).typ, tab, cache, conf, idgen);
				add__ast_4798(fieldNode, T139_);
				asgnRef((void**) (&(*result)._kind_6.sons->data[pos]), fieldNode);
			} LA114: ;
		}
		{
			tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T142_;
			T142_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
			T142_ = kind__pureZparsejson_185((&(*p)));
			if (!(T142_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 9))) goto LA143_;
			next__pureZparsejson_447(p);
		}
		goto LA140_;
		LA143_: ;
		{
			raiseParseErr__pureZparsejson_571((&(*p)), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_13));
		}
		LA140_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 19):
	{
		{
			tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T149_;
			T149_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
			T149_ = kind__pureZparsejson_185((&(*p)));
			if (!!((T149_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 10)))) goto LA150_;
			raiseParseErr__pureZparsejson_571((&(*p)), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_15));
		}
		LA150_: ;
		next__pureZparsejson_447(p);
		result = newNode__ast_3289(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 39));
		{
			while (1) {
				NIM_BOOL T154_;
				tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T155_;
				tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T157_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T158_;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T159_;
				T154_ = (NIM_BOOL)0;
				T155_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
				T155_ = kind__pureZparsejson_185((&(*p)));
				T154_ = !((T155_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 11)));
				if (!(T154_)) goto LA156_;
				T157_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
				T157_ = kind__pureZparsejson_185((&(*p)));
				T154_ = !((T157_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 1)));
				LA156_: ;
				if (!T154_) goto LA153;
				T158_ = NIM_NIL;
				T158_ = lastSon__ast_3731(t);
				T159_ = NIM_NIL;
				T159_ = loadAny__vmmarshal_206(p, T158_, tab, cache, conf, idgen);
				add__ast_4798(result, T159_);
			} LA153: ;
		}
		{
			tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T162_;
			T162_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
			T162_ = kind__pureZparsejson_185((&(*p)));
			if (!(T162_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 11))) goto LA163_;
			next__pureZparsejson_447(p);
		}
		goto LA160_;
		LA163_: ;
		{
			raiseParseErr__pureZparsejson_571((&(*p)), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_8));
		}
		LA160_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22):
	{
		tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T167_;
		T167_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
		T167_ = kind__pureZparsejson_185((&(*p)));
		switch (T167_) {
		case ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 7):
		{
			result = newNode__ast_3289(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23));
			next__pureZparsejson_447(p);
		}
		break;
		case ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 3):
		{
			NI64 T170_;
			T170_ = (NI64)0;
			T170_ = getInt__pureZparsejson_164((&(*p)));
			result = getOrDefault__vmmarshal_446((*tab), T170_);
			{
				NimStringDesc* T175_;
				NI64 T176_;
				NimStringDesc* T177_;
				if (!(result == 0)) goto LA173_;
				T175_ = NIM_NIL;
				T176_ = (NI64)0;
				T176_ = getInt__pureZparsejson_164((&(*p)));
				T177_ = NIM_NIL;
				T177_ = dollar___systemZdollars_6(T176_);
				T175_ = rawNewString((T177_ ? T177_->Sup.len : 0) + 32);
appendString(T175_, ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_16));
appendString(T175_, T177_);
				raiseParseErr__pureZparsejson_571((&(*p)), T175_);
			}
			LA173_: ;
			next__pureZparsejson_447(p);
		}
		break;
		case ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 10):
		{
			next__pureZparsejson_447(p);
			{
				tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T181_;
				NI64 idx;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T184_;
				T181_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
				T181_ = kind__pureZparsejson_185((&(*p)));
				if (!(T181_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 3))) goto LA182_;
				idx = getInt__pureZparsejson_164((&(*p)));
				next__pureZparsejson_447(p);
				T184_ = NIM_NIL;
				T184_ = lastSon__ast_3731(t);
				result = loadAny__vmmarshal_206(p, T184_, tab, cache, conf, idgen);
				X5BX5Deq___vmmarshal_802(tab, idx, result);
			}
			goto LA179_;
			LA182_: ;
			{
				raiseParseErr__pureZparsejson_571((&(*p)), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_17));
			}
			LA179_: ;
			{
				tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T188_;
				T188_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
				T188_ = kind__pureZparsejson_185((&(*p)));
				if (!(T188_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 11))) goto LA189_;
				next__pureZparsejson_447(p);
			}
			goto LA186_;
			LA189_: ;
			{
				raiseParseErr__pureZparsejson_571((&(*p)), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_18));
			}
			LA186_: ;
		}
		break;
		default:
		{
			raiseParseErr__pureZparsejson_571((&(*p)), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_19));
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29):
	{
		tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T194_;
		T194_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
		T194_ = kind__pureZparsejson_185((&(*p)));
		switch (T194_) {
		case ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 7):
		{
			result = newNode__ast_3289(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23));
			next__pureZparsejson_447(p);
		}
		break;
		case ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 2):
		{
			NimStringDesc* T197_;
			T197_ = NIM_NIL;
			T197_ = str__pureZparsejson_153((&(*p)));
			result = newStrNode__ast_3801(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20), T197_);
			next__pureZparsejson_447(p);
		}
		break;
		default:
		{
			raiseParseErr__pureZparsejson_571((&(*p)), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_20));
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44):
	{
		{
			tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T202_;
			NI64 T205_;
			T202_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
			T202_ = kind__pureZparsejson_185((&(*p)));
			if (!(T202_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 3))) goto LA203_;
			T205_ = (NI64)0;
			T205_ = getInt__pureZparsejson_164((&(*p)));
			result = newIntNode__ast_3711(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6), T205_);
			next__pureZparsejson_447(p);
			goto BeforeRet_;
		}
		LA203_: ;
		raiseParseErr__pureZparsejson_571((&(*p)), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_21));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 39):
	{
		{
			tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg T209_;
			NF T212_;
			T209_ = (tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg)0;
			T209_ = kind__pureZparsejson_185((&(*p)));
			if (!(T209_ == ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 4))) goto LA210_;
			T212_ = (NF)0;
			T212_ = getFloat__pureZparsejson_175((&(*p)));
			result = newFloatNode__ast_3797(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 16), T212_);
			next__pureZparsejson_447(p);
			goto BeforeRet_;
		}
		LA210_: ;
		raiseParseErr__pureZparsejson_571((&(*p)), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_22));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 20):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 4):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T214_;
		T214_ = NIM_NIL;
		T214_ = lastSon__ast_3731(t);
		result = loadAny__vmmarshal_206(p, T214_, tab, cache, conf, idgen);
	}
	break;
	default:
	{
		NimStringDesc* T216_;
		NimStringDesc* T217_;
		T216_ = NIM_NIL;
		T217_ = NIM_NIL;
		T217_ = typeToString__types_50(t, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
		T216_ = rawNewString((T217_ ? T217_->Sup.len : 0) + 31);
appendString(T216_, ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_23));
appendString(T216_, T217_);
		internalErrorImpl__msgs_1441(conf, unknownLineInfo__lineinfos_284, T216_, TM__BJX8XfdlwqKRXJxSDkJW8w_24);
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, close__pureZparsejson_151)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my) {
	close__pureZlexbase_14(&my->Sup);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, loadAny__vmmarshal_1853)(NimStringDesc* s, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_Table__gomBN9cF0n3KCLfQvSeVI7Q tab;
	tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA p;
	tyObject_StringStreamObj__0donmYG9cFGYrdaYfy8rp2g* T1_;
	result = NIM_NIL;
	nimZeroMem((void*)(&tab), sizeof(tyObject_Table__gomBN9cF0n3KCLfQvSeVI7Q));
	initTable__vmmarshal_1860(((NI) 32), (&tab));
	nimZeroMem((void*)(&p), sizeof(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA));
	p.Sup.Sup.m_type = (&NTIjsonparser__w6FDVeQ36QibBeDgwddDMA_);
	T1_ = NIM_NIL;
	T1_ = newStringStream__pureZstreams_676(s);
	open__pureZparsejson_97((&p), &T1_->Sup, ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_3), NIM_FALSE);
	next__pureZparsejson_447((&p));
	result = loadAny__vmmarshal_206((&p), t, (&tab), cache, conf, idgen);
	close__pureZparsejson_151((&p));
	return result;
}
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result) {
	initPackedSet__pureZcollectionsZintsets_16(Result);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getField__vmmarshal_15)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI position) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
{	result = NIM_NIL;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 138):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					result = getField__vmmarshal_15((*n)._kind_6.sons->data[i], position);
					{
						if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA7_;
						goto BeforeRet_;
					}
					LA7_: ;
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 139):
	{
		result = getField__vmmarshal_15((*n)._kind_6.sons->data[((NI) 0)], position);
		{
			if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA12_;
			goto BeforeRet_;
		}
		LA12_: ;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3155(n);
			i_4 = ((NI) 1);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA16;
					i_3 = i_4;
					switch ((*(*n)._kind_6.sons->data[i_3]).kind) {
					case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 85):
					case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 88):
					{
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T18_;
						T18_ = NIM_NIL;
						T18_ = lastSon__ast_4833((*n)._kind_6.sons->data[i_3]);
						result = getField__vmmarshal_15(T18_, position);
						{
							if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA21_;
							goto BeforeRet_;
						}
						LA21_: ;
					}
					break;
					default:
					{
					}
					break;
					}
					i_4 += ((NI) 1);
				} LA16: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		{
			if (!((*(*n)._kind_4.sym).position == position)) goto LA27_;
			result = (*n)._kind_4.sym;
		}
		LA27_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, storeObj__vmmarshal_60)(NimStringDesc** s, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* stored, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NI start;
	start = ((NI) 1);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(x);
		i_2 = start;
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					if (!(start < i)) goto LA6_;
					unsureAsgnRef((void**) (&(*s)), resizeString((*s), 2));
appendString((*s), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_28));
				}
				LA6_: ;
				it = (*x)._kind_6.sons->data[i];
				{
					if (!((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34))) goto LA10_;
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field;
						NimStringDesc* T16_;
						if (!((*(*it)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA14_;
						field = (*(*it)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
						T16_ = NIM_NIL;
						T16_ = escapeJson__pureZjson_4374((*(*field).name).s);
						unsureAsgnRef((void**) (&(*s)), resizeString((*s), (T16_ ? T16_->Sup.len : 0) + 0));
appendString((*s), T16_);
						unsureAsgnRef((void**) (&(*s)), resizeString((*s), 2));
appendString((*s), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_34));
						storeAny__vmmarshal_54(s, (*field).typ, (*it)._kind_6.sons->data[((NI) 1)], stored, conf);
					}
					LA14_: ;
				}
				goto LA8_;
				LA10_: ;
				{
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field_2;
					NimStringDesc* T20_;
					if (!!(((*typ).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA18_;
					field_2 = getField__vmmarshal_15((*typ).n, i);
					T20_ = NIM_NIL;
					T20_ = escapeJson__pureZjson_4374((*(*field_2).name).s);
					unsureAsgnRef((void**) (&(*s)), resizeString((*s), (T20_ ? T20_->Sup.len : 0) + 0));
appendString((*s), T20_);
					unsureAsgnRef((void**) (&(*s)), resizeString((*s), 2));
appendString((*s), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_34));
					storeAny__vmmarshal_54(s, (*field_2).typ, it, stored, conf);
				}
				goto LA8_;
				LA18_: ;
				LA8_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
static N_INLINE(NI, ptrToInt__vmmarshal_12)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x) {
	NI result;
	result = (NI)0;
	result = ((NI) (x));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, storeAny__vmmarshal_54)(NimStringDesc** s, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* stored, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 0):
	{
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1):
	{
		NimStringDesc* T3_;
		T3_ = NIM_NIL;
		T3_ = nimBoolToStr(!(((*a)._kind_1.intVal == IL64(0))));
		unsureAsgnRef((void**) (&(*s)), resizeString((*s), (T3_ ? T3_->Sup.len : 0) + 0));
appendString((*s), T3_);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2):
	{
		NIM_CHAR ch;
		ch = ((NIM_CHAR) ((*a)._kind_1.intVal));
		{
			NimStringDesc* T9_;
			NimStringDesc* T10_;
			if (!((NU8)(ch) < (NU8)(128))) goto LA7_;
			T9_ = NIM_NIL;
			T9_ = nimCharToStr(ch);
			T10_ = NIM_NIL;
			T10_ = escapeJson__pureZjson_4374(T9_);
			unsureAsgnRef((void**) (&(*s)), resizeString((*s), (T10_ ? T10_->Sup.len : 0) + 0));
appendString((*s), T10_);
		}
		goto LA5_;
		LA7_: ;
		{
			NimStringDesc* T12_;
			T12_ = NIM_NIL;
			T12_ = dollar___systemZdollars_3(((NI) (((NU8)(ch)))));
			unsureAsgnRef((void**) (&(*s)), resizeString((*s), (T12_ ? T12_->Sup.len : 0) + 0));
appendString((*s), T12_);
		}
		LA5_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
	{
		{
			NIM_BOOL T16_;
			T16_ = (NIM_BOOL)0;
			T16_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24));
			if (!(T16_)) goto LA17_;
			T16_ = ((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23));
			LA17_: ;
			if (!T16_) goto LA18_;
			unsureAsgnRef((void**) (&(*s)), resizeString((*s), 4));
appendString((*s), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_26));
		}
		goto LA14_;
		LA18_: ;
		{
			unsureAsgnRef((void**) (&(*s)), resizeString((*s), 1));
appendString((*s), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_27));
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_3155(a);
				i_2 = ((NI) 0);
				{
					while (1) {
						tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T28_;
						if (!(i_2 < colontmp_)) goto LA23;
						i = i_2;
						{
							if (!(((NI) 0) < i)) goto LA26_;
							unsureAsgnRef((void**) (&(*s)), resizeString((*s), 2));
appendString((*s), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_28));
						}
						LA26_: ;
						T28_ = NIM_NIL;
						T28_ = elemType__types_263(t);
						storeAny__vmmarshal_54(s, T28_, (*a)._kind_6.sons->data[i], stored, conf);
						i_2 += ((NI) 1);
					} LA23: ;
				}
			}
			unsureAsgnRef((void**) (&(*s)), resizeString((*s), 1));
appendString((*s), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_29));
		}
		LA14_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18):
	{
		unsureAsgnRef((void**) (&(*s)), resizeString((*s), 1));
appendString((*s), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_30));
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3990(t);
			i_4 = ((NI) 0);
			{
				while (1) {
					NimStringDesc* T37_;
					NimStringDesc* T38_;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T39_;
					if (!(i_4 < colontmp__2)) goto LA32;
					i_3 = i_4;
					{
						if (!(((NI) 0) < i_3)) goto LA35_;
						unsureAsgnRef((void**) (&(*s)), resizeString((*s), 2));
appendString((*s), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_28));
					}
					LA35_: ;
					T37_ = NIM_NIL;
					T38_ = NIM_NIL;
					T38_ = dollar___systemZdollars_3(i_3);
					T37_ = rawNewString((T38_ ? T38_->Sup.len : 0) + 6);
appendString(T37_, ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_31));
appendString(T37_, T38_);
					unsureAsgnRef((void**) (&(*s)), resizeString((*s), (T37_ ? T37_->Sup.len : 0) + 0));
appendString((*s), T37_);
					unsureAsgnRef((void**) (&(*s)), resizeString((*s), 3));
appendString((*s), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_32));
					T39_ = NIM_NIL;
					T39_ = skipColon__ast_4949((*a)._kind_6.sons->data[i_3]);
					storeAny__vmmarshal_54(s, (*t).sons->data[i_3], T39_, stored, conf);
					i_4 += ((NI) 1);
				} LA32: ;
			}
		}
		unsureAsgnRef((void**) (&(*s)), resizeString((*s), 1));
appendString((*s), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_33));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17):
	{
		unsureAsgnRef((void**) (&(*s)), resizeString((*s), 1));
appendString((*s), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_30));
		storeObj__vmmarshal_60(s, t, a, stored, conf);
		unsureAsgnRef((void**) (&(*s)), resizeString((*s), 1));
appendString((*s), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_33));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 19):
	{
		unsureAsgnRef((void**) (&(*s)), resizeString((*s), 1));
appendString((*s), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_27));
		{
			NI i_5;
			NI colontmp__3;
			NI i_6;
			i_5 = (NI)0;
			colontmp__3 = (NI)0;
			colontmp__3 = len__ast_3155(a);
			i_6 = ((NI) 0);
			{
				while (1) {
					if (!(i_6 < colontmp__3)) goto LA44;
					i_5 = i_6;
					{
						if (!(((NI) 0) < i_5)) goto LA47_;
						unsureAsgnRef((void**) (&(*s)), resizeString((*s), 2));
appendString((*s), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_28));
					}
					LA47_: ;
					{
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x;
						tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T53_;
						if (!((*(*a)._kind_6.sons->data[i_5]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 44))) goto LA51_;
						x = copyNode__ast_4324((*(*a)._kind_6.sons->data[i_5])._kind_6.sons->data[((NI) 0)]);
						T53_ = NIM_NIL;
						T53_ = lastSon__ast_3731(t);
						storeAny__vmmarshal_54(s, T53_, x, stored, conf);
						(*x)._kind_1.intVal += ((NI) 1);
						{
							while (1) {
								tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T56_;
								if (!((*x)._kind_1.intVal <= (*(*(*a)._kind_6.sons->data[i_5])._kind_6.sons->data[((NI) 1)])._kind_1.intVal)) goto LA55;
								unsureAsgnRef((void**) (&(*s)), resizeString((*s), 2));
appendString((*s), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_28));
								T56_ = NIM_NIL;
								T56_ = lastSon__ast_3731(t);
								storeAny__vmmarshal_54(s, T56_, x, stored, conf);
								(*x)._kind_1.intVal += ((NI) 1);
							} LA55: ;
						}
					}
					goto LA49_;
					LA51_: ;
					{
						tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T58_;
						T58_ = NIM_NIL;
						T58_ = lastSon__ast_3731(t);
						storeAny__vmmarshal_54(s, T58_, (*a)._kind_6.sons->data[i_5], stored, conf);
					}
					LA49_: ;
					i_6 += ((NI) 1);
				} LA44: ;
			}
		}
		unsureAsgnRef((void**) (&(*s)), resizeString((*s), 1));
appendString((*s), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_29));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 20):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 4):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T60_;
		T60_ = NIM_NIL;
		T60_ = lastSon__ast_3731(t);
		storeAny__vmmarshal_54(s, T60_, a, stored, conf);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e;
			e = NIM_NIL;
			{
				NI i_7;
				NI colontmp__4;
				NI i_8;
				i_7 = (NI)0;
				colontmp__4 = (NI)0;
				colontmp__4 = safeLen__ast_3148((*t).n);
				i_8 = ((NI) 0);
				{
					while (1) {
						if (!(i_8 < colontmp__4)) goto LA65;
						i_7 = i_8;
						e = (*(*t).n)._kind_6.sons->data[i_7];
						{
							NimStringDesc* T70_;
							if (!(((NI64) ((*(*e)._kind_4.sym).position)) == (*a)._kind_1.intVal)) goto LA68_;
							T70_ = NIM_NIL;
							T70_ = escapeJson__pureZjson_4374((*(*(*e)._kind_4.sym).name).s);
							unsureAsgnRef((void**) (&(*s)), resizeString((*s), (T70_ ? T70_->Sup.len : 0) + 0));
appendString((*s), T70_);
							goto LA62;
						}
						LA68_: ;
						i_8 += ((NI) 1);
					} LA65: ;
				}
			}
		} LA62: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x_2;
		x_2 = a;
		{
			NIM_BOOL T74_;
			T74_ = (NIM_BOOL)0;
			T74_ = (x_2 == 0);
			if (T74_) goto LA75_;
			T74_ = ((*x_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23));
			LA75_: ;
			if (!T74_) goto LA76_;
			unsureAsgnRef((void**) (&(*s)), resizeString((*s), 4));
appendString((*s), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_26));
		}
		goto LA72_;
		LA76_: ;
		{
			NI T79_;
			NIM_BOOL T80_;
			NI T83_;
			NimStringDesc* T84_;
			T79_ = (NI)0;
			T79_ = ptrToInt__vmmarshal_12(x_2);
			T80_ = (NIM_BOOL)0;
			T80_ = containsOrIncl__astalgo_402(stored, T79_);
			if (!T80_) goto LA81_;
			T83_ = (NI)0;
			T83_ = ptrToInt__vmmarshal_12(x_2);
			T84_ = NIM_NIL;
			T84_ = dollar___systemZdollars_3(T83_);
			unsureAsgnRef((void**) (&(*s)), resizeString((*s), (T84_ ? T84_->Sup.len : 0) + 0));
appendString((*s), T84_);
		}
		goto LA72_;
		LA81_: ;
		{
			NI T86_;
			NimStringDesc* T87_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T88_;
			unsureAsgnRef((void**) (&(*s)), resizeString((*s), 1));
appendString((*s), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_27));
			T86_ = (NI)0;
			T86_ = ptrToInt__vmmarshal_12(x_2);
			T87_ = NIM_NIL;
			T87_ = dollar___systemZdollars_3(T86_);
			unsureAsgnRef((void**) (&(*s)), resizeString((*s), (T87_ ? T87_->Sup.len : 0) + 0));
appendString((*s), T87_);
			unsureAsgnRef((void**) (&(*s)), resizeString((*s), 2));
appendString((*s), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_28));
			T88_ = NIM_NIL;
			T88_ = lastSon__ast_3731(t);
			storeAny__vmmarshal_54(s, T88_, a, stored, conf);
			unsureAsgnRef((void**) (&(*s)), resizeString((*s), 1));
appendString((*s), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_29));
		}
		LA72_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29):
	{
		{
			if (!((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA92_;
			unsureAsgnRef((void**) (&(*s)), resizeString((*s), 4));
appendString((*s), ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_26));
		}
		goto LA90_;
		LA92_: ;
		{
			NimStringDesc* T95_;
			T95_ = NIM_NIL;
			T95_ = escapeJson__pureZjson_4374((*a)._kind_3.strVal);
			unsureAsgnRef((void**) (&(*s)), resizeString((*s), (T95_ ? T95_->Sup.len : 0) + 0));
appendString((*s), T95_);
		}
		LA90_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44):
	{
		NimStringDesc* T97_;
		T97_ = NIM_NIL;
		T97_ = dollar___systemZdollars_6((*a)._kind_1.intVal);
		unsureAsgnRef((void**) (&(*s)), resizeString((*s), (T97_ ? T97_->Sup.len : 0) + 0));
appendString((*s), T97_);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 39):
	{
		NimStringDesc* T99_;
		T99_ = NIM_NIL;
		T99_ = dollar___system_3126((*a)._kind_2.floatVal);
		unsureAsgnRef((void**) (&(*s)), resizeString((*s), (T99_ ? T99_->Sup.len : 0) + 0));
appendString((*s), T99_);
	}
	break;
	default:
	{
		NimStringDesc* T101_;
		NimStringDesc* T102_;
		T101_ = NIM_NIL;
		T102_ = NIM_NIL;
		T102_ = typeToString__types_50(t, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
		T101_ = rawNewString((T102_ ? T102_->Sup.len : 0) + 31);
appendString(T101_, ((NimStringDesc*) &TM__BJX8XfdlwqKRXJxSDkJW8w_23));
appendString(T101_, T102_);
		internalErrorImpl__msgs_1441(conf, (*a).info, T101_, TM__BJX8XfdlwqKRXJxSDkJW8w_35);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, storeAny__vmmarshal_200)(NimStringDesc** s, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw stored;
	nimZeroMem((void*)(&stored), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
	initIntSet__pureZcollectionsZintsets_238((&stored));
	storeAny__vmmarshal_54(s, t, a, (&stored), conf);
}
N_LIB_PRIVATE N_NIMCALL(void, atmvmmarshaldotnim_DatInit000)(void) {
static TNimNode* TM__BJX8XfdlwqKRXJxSDkJW8w_2_3[3];
static TNimNode TM__BJX8XfdlwqKRXJxSDkJW8w_0[4];
NTIkeyvaluepair__usE1QHGQhF6zycm9bQm6MMA_.size = sizeof(tyTuple__usE1QHGQhF6zycm9bQm6MMA);
NTIkeyvaluepair__usE1QHGQhF6zycm9bQm6MMA_.align = NIM_ALIGNOF(tyTuple__usE1QHGQhF6zycm9bQm6MMA);
NTIkeyvaluepair__usE1QHGQhF6zycm9bQm6MMA_.kind = 18;
NTIkeyvaluepair__usE1QHGQhF6zycm9bQm6MMA_.base = 0;
NTIkeyvaluepair__usE1QHGQhF6zycm9bQm6MMA_.flags = 2;
TM__BJX8XfdlwqKRXJxSDkJW8w_2_3[0] = &TM__BJX8XfdlwqKRXJxSDkJW8w_0[1];
TM__BJX8XfdlwqKRXJxSDkJW8w_0[1].kind = 1;
TM__BJX8XfdlwqKRXJxSDkJW8w_0[1].offset = offsetof(tyTuple__usE1QHGQhF6zycm9bQm6MMA, Field0);
TM__BJX8XfdlwqKRXJxSDkJW8w_0[1].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__BJX8XfdlwqKRXJxSDkJW8w_0[1].name = "Field0";
TM__BJX8XfdlwqKRXJxSDkJW8w_2_3[1] = &TM__BJX8XfdlwqKRXJxSDkJW8w_0[2];
TM__BJX8XfdlwqKRXJxSDkJW8w_0[2].kind = 1;
TM__BJX8XfdlwqKRXJxSDkJW8w_0[2].offset = offsetof(tyTuple__usE1QHGQhF6zycm9bQm6MMA, Field1);
TM__BJX8XfdlwqKRXJxSDkJW8w_0[2].typ = (&NTIbiggestint__Aav8dQoMlCFnZRxA0IhTHQ_);
TM__BJX8XfdlwqKRXJxSDkJW8w_0[2].name = "Field1";
TM__BJX8XfdlwqKRXJxSDkJW8w_2_3[2] = &TM__BJX8XfdlwqKRXJxSDkJW8w_0[3];
TM__BJX8XfdlwqKRXJxSDkJW8w_0[3].kind = 1;
TM__BJX8XfdlwqKRXJxSDkJW8w_0[3].offset = offsetof(tyTuple__usE1QHGQhF6zycm9bQm6MMA, Field2);
TM__BJX8XfdlwqKRXJxSDkJW8w_0[3].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__BJX8XfdlwqKRXJxSDkJW8w_0[3].name = "Field2";
TM__BJX8XfdlwqKRXJxSDkJW8w_0[0].len = 3; TM__BJX8XfdlwqKRXJxSDkJW8w_0[0].kind = 2; TM__BJX8XfdlwqKRXJxSDkJW8w_0[0].sons = &TM__BJX8XfdlwqKRXJxSDkJW8w_2_3[0];
NTIkeyvaluepair__usE1QHGQhF6zycm9bQm6MMA_.node = &TM__BJX8XfdlwqKRXJxSDkJW8w_0[0];
NTIkeyvaluepairseq__OeT2uxU9cpZvGBACtO9b4xwQ_.size = sizeof(tySequence__OeT2uxU9cpZvGBACtO9b4xwQ*);
NTIkeyvaluepairseq__OeT2uxU9cpZvGBACtO9b4xwQ_.align = NIM_ALIGNOF(tySequence__OeT2uxU9cpZvGBACtO9b4xwQ*);
NTIkeyvaluepairseq__OeT2uxU9cpZvGBACtO9b4xwQ_.kind = 24;
NTIkeyvaluepairseq__OeT2uxU9cpZvGBACtO9b4xwQ_.base = (&NTIkeyvaluepair__usE1QHGQhF6zycm9bQm6MMA_);
NTIkeyvaluepairseq__OeT2uxU9cpZvGBACtO9b4xwQ_.flags = 2;
NTIkeyvaluepairseq__OeT2uxU9cpZvGBACtO9b4xwQ_.marker = Marker_tySequence__OeT2uxU9cpZvGBACtO9b4xwQ;
}

