/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_OptParser__Sj2pYlEalgMxSDrjh9cml3w tyObject_OptParser__Sj2pYlEalgMxSDrjh9cml3w;
typedef struct RootObj RootObj;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw;
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct RootObj {
TNimType* m_type;
};
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
typedef NU8 tyEnum_CmdLineKind__9aoMk7Iv3Zzg24yOE69bmFEA;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_OptParser__Sj2pYlEalgMxSDrjh9cml3w {
  RootObj Sup;
NI pos;
NIM_BOOL inShortState;
NIM_BOOL allowWhitespaceAfterColon;
tySet_tyChar__nmiMWKVIe46vacnhAFrQvw shortNoVal;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* longNoVal;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cmds;
NI idx;
tyEnum_CmdLineKind__9aoMk7Iv3Zzg24yOE69bmFEA kind;
NimStringDesc* key;
NimStringDesc* val;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
struct tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw {
NI a;
NI b;
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(void, genericSeqAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ*, nosparseCmdLine)(NimStringDesc* c);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ*, newSeq__systemZio_501)(NI len);
N_LIB_PRIVATE N_NIMCALL(NI, paramCount__pureZos_1526)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, paramStr__pureZos_1520)(NI i);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5319)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5281)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5326)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5324)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5275)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, setLengthStr)(NimStringDesc* s, NI newLen);
N_LIB_PRIVATE N_NIMCALL(void, handleShortOption__pureZparseopt_127)(tyObject_OptParser__Sj2pYlEalgMxSDrjh9cml3w* p, NimStringDesc* cmd);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
static N_INLINE(NI, cardSet)(NU8* s, NI len);
static N_INLINE(NI, cardSetImpl__system_3591)(NU8* s, NI len);
static N_INLINE(NI, countBits64)(NU64 n);
static N_INLINE(NI, countSetBitsImpl__systemZcountbits95impl_61)(NU64 x);
N_CDECL(int, __builtin_popcountll)(unsigned long long x);
static N_INLINE(NI, countBits32)(NU32 n);
static N_INLINE(NI, countSetBitsImpl__systemZcountbits95impl_26)(NU32 x);
N_CDECL(int, __builtin_popcount)(unsigned int x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__system_7767)(NimStringDesc* s, NI first);
N_LIB_PRIVATE N_NIMCALL(NI, parseWord__pureZparseopt_25)(NimStringDesc* s, NI i, NimStringDesc** w, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw delim);
static N_INLINE(NIM_BOOL, contains__stdZenumutils_44)(NimStringDesc** a, NI aLen_0, NimStringDesc* item);
static N_INLINE(NI, find__stdZenumutils_49)(NimStringDesc** a, NI aLen_0, NimStringDesc* item);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, quoteShellCommand__pureZos_601)(NimStringDesc** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ*, X5BX5D___pureZparseopt_275)(NimStringDesc** s, NI sLen_0, tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw x);
static N_INLINE(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw, dotdot___stdZenumutils_90)(NI a, NI b);
extern TNimType NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_;
N_LIB_PRIVATE TNimType NTIoptparser__Sj2pYlEalgMxSDrjh9cml3w_;
extern TNimType NTIint__rR5Bzr1D5krxoo1NcNyeMA_;
extern TNimType NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_;
extern TNimType NTIchar__nmiMWKVIe46vacnhAFrQvw_;
N_LIB_PRIVATE TNimType NTIsetLcharT__HDqWPvEAxZK51ZcfaeQEdg_;
extern TNimType NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_;
N_LIB_PRIVATE TNimType NTIcmdlinekind__9aoMk7Iv3Zzg24yOE69bmFEA_;
extern TNimType NTIstring__77mFvmsOLKik79ci2hXkHEg_;
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__GYgvYKeHVTEls0AcywABHQ_6 = {
0x00, 0x02, 0x00, 0x00, 0x01, 0x00, 0x00, 0x24,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5228;
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5319)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5281)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5324)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5275((&gch__system_5228.zct), c);
}
static N_INLINE(void, decRef__system_5326)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5324(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5281(src);
		incRef__system_5319(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5281((*dest));
		decRef__system_5326(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(void, initOptParser__pureZparseopt_51)(NimStringDesc* cmdline, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw shortNoVal, tySequence__sM4lkSb7zS6F7OVMvW9cffQ* longNoVal, NIM_BOOL allowWhitespaceAfterColon, tyObject_OptParser__Sj2pYlEalgMxSDrjh9cml3w* Result) {
	(*Result).pos = 0;
	(*Result).inShortState = 0;
	(*Result).allowWhitespaceAfterColon = 0;
	nimZeroMem((*Result).shortNoVal, sizeof(tySet_tyChar__nmiMWKVIe46vacnhAFrQvw));
	unsureAsgnRef((void**)&(*Result).longNoVal, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).cmds, NIM_NIL);
	(*Result).idx = 0;
	(*Result).kind = 0;
	unsureAsgnRef((void**)&(*Result).key, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).val, NIM_NIL);
	(*Result).Sup.m_type = (&NTIoptparser__Sj2pYlEalgMxSDrjh9cml3w_);
	(*Result).pos = ((NI) 0);
	(*Result).idx = ((NI) 0);
	(*Result).inShortState = NIM_FALSE;
	nimCopyMem((void*)(*Result).shortNoVal, (NIM_CONST void*)shortNoVal, 32);
	genericSeqAssign((&(*Result).longNoVal), longNoVal, (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_));
	(*Result).allowWhitespaceAfterColon = allowWhitespaceAfterColon;
	{
		if (!!(((cmdline ? cmdline->Sup.len : 0) == 0))) goto LA3_;
		unsureAsgnRef((void**) (&(*Result).cmds), nosparseCmdLine(cmdline));
	}
	goto LA1_;
	LA3_: ;
	{
		NI T6_;
		T6_ = (NI)0;
		T6_ = paramCount__pureZos_1526();
		unsureAsgnRef((void**) (&(*Result).cmds), newSeq__systemZio_501(((NI) (T6_))));
		{
			NI i;
			NI colontmp_;
			NI res;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = paramCount__pureZos_1526();
			res = ((NI) 1);
			{
				while (1) {
					if (!(res <= colontmp_)) goto LA9;
					i = res;
					asgnRef((void**) (&(*Result).cmds->data[(NI)(i - ((NI) 1))]), paramStr__pureZos_1520(i));
					res += ((NI) 1);
				} LA9: ;
			}
		}
	}
	LA1_: ;
	(*Result).kind = ((tyEnum_CmdLineKind__9aoMk7Iv3Zzg24yOE69bmFEA) 0);
	unsureAsgnRef((void**) (&(*Result).key), ((NimStringDesc*) NIM_NIL));
	unsureAsgnRef((void**) (&(*Result).val), ((NimStringDesc*) NIM_NIL));
}
static N_INLINE(NI, countSetBitsImpl__systemZcountbits95impl_61)(NU64 x) {
	NI result;
	int T1_;
	result = (NI)0;
	T1_ = (int)0;
	T1_ = __builtin_popcountll(x);
	result = ((NI) (T1_));
	return result;
}
static N_INLINE(NI, countBits64)(NU64 n) {
	NI result;
	result = (NI)0;
	result = countSetBitsImpl__systemZcountbits95impl_61(n);
	return result;
}
static N_INLINE(NI, countSetBitsImpl__systemZcountbits95impl_26)(NU32 x) {
	NI result;
	int T1_;
	result = (NI)0;
	T1_ = (int)0;
	T1_ = __builtin_popcount(x);
	result = ((NI) (T1_));
	return result;
}
static N_INLINE(NI, countBits32)(NU32 n) {
	NI result;
	result = (NI)0;
	result = countSetBitsImpl__systemZcountbits95impl_26(n);
	return result;
}
static N_INLINE(NI, cardSetImpl__system_3591)(NU8* s, NI len) {
	NI result;
	NI i;
	result = (NI)0;
	i = ((NI) 0);
	result = ((NI) 0);
	{
		while (1) {
			NI T3_;
			if (!(i < (NI)(len - ((NI) 8)))) goto LA2;
			T3_ = (NI)0;
			T3_ = countBits64((*((NU64*) ((&s[i])))));
			result += T3_;
			i += ((NI) 8);
		} LA2: ;
	}
	{
		while (1) {
			NI T6_;
			if (!(i < len)) goto LA5;
			T6_ = (NI)0;
			T6_ = countBits32(((NU32) (s[i])));
			result += T6_;
			i += ((NI) 1);
		} LA5: ;
	}
	return result;
}
static N_INLINE(NI, cardSet)(NU8* s, NI len) {
	NI result;
	result = (NI)0;
	result = cardSetImpl__system_3591(s, len);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, handleShortOption__pureZparseopt_127)(tyObject_OptParser__Sj2pYlEalgMxSDrjh9cml3w* p, NimStringDesc* cmd) {
	NI i;
	i = (*p).pos;
	(*p).kind = ((tyEnum_CmdLineKind__9aoMk7Iv3Zzg24yOE69bmFEA) 3);
	{
		if (!(i < (cmd ? cmd->Sup.len : 0))) goto LA3_;
		unsureAsgnRef((void**) (&(*p).key), addChar((*p).key, cmd->data[i]));
		i += ((NI) 1);
	}
	LA3_: ;
	(*p).inShortState = NIM_TRUE;
	{
		while (1) {
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = (i < (cmd ? cmd->Sup.len : 0));
			if (!(T7_)) goto LA8_;
			T7_ = (((NU8)(cmd->data[i])) == ((NU8)(9)) || ((NU8)(cmd->data[i])) == ((NU8)(32)));
			LA8_: ;
			if (!T7_) goto LA6;
			i += ((NI) 1);
			(*p).inShortState = NIM_FALSE;
		} LA6: ;
	}
	{
		NIM_BOOL T11_;
		NIM_BOOL T13_;
		NIM_BOOL T15_;
		T11_ = (NIM_BOOL)0;
		T11_ = (i < (cmd ? cmd->Sup.len : 0));
		if (!(T11_)) goto LA12_;
		T13_ = (NIM_BOOL)0;
		T13_ = (((NU8)(cmd->data[i])) == ((NU8)(58)) || ((NU8)(cmd->data[i])) == ((NU8)(61)));
		if (T13_) goto LA14_;
		T15_ = (NIM_BOOL)0;
		T15_ = (((NI) 0) < cardSet((*p).shortNoVal, 32));
		if (!(T15_)) goto LA16_;
		T15_ = !((((*p).shortNoVal[(NU)(((NU8)((*p).key->data[((NI) 0)])))>>3] &(1U<<((NU)(((NU8)((*p).key->data[((NI) 0)])))&7U)))!=0));
		LA16_: ;
		T13_ = T15_;
		LA14_: ;
		T11_ = T13_;
		LA12_: ;
		if (!T11_) goto LA17_;
		{
			NIM_BOOL T21_;
			T21_ = (NIM_BOOL)0;
			T21_ = (i < (cmd ? cmd->Sup.len : 0));
			if (!(T21_)) goto LA22_;
			T21_ = (((NU8)(cmd->data[i])) == ((NU8)(58)) || ((NU8)(cmd->data[i])) == ((NU8)(61)));
			LA22_: ;
			if (!T21_) goto LA23_;
			i += ((NI) 1);
		}
		LA23_: ;
		(*p).inShortState = NIM_FALSE;
		{
			while (1) {
				NIM_BOOL T27_;
				T27_ = (NIM_BOOL)0;
				T27_ = (i < (cmd ? cmd->Sup.len : 0));
				if (!(T27_)) goto LA28_;
				T27_ = (((NU8)(cmd->data[i])) == ((NU8)(9)) || ((NU8)(cmd->data[i])) == ((NU8)(32)));
				LA28_: ;
				if (!T27_) goto LA26;
				i += ((NI) 1);
			} LA26: ;
		}
		unsureAsgnRef((void**) (&(*p).val), substr__system_7767(cmd, i));
		(*p).pos = ((NI) 0);
		(*p).idx += ((NI) 1);
	}
	goto LA9_;
	LA17_: ;
	{
		(*p).pos = i;
	}
	LA9_: ;
	{
		if (!((cmd ? cmd->Sup.len : 0) <= i)) goto LA32_;
		(*p).inShortState = NIM_FALSE;
		(*p).pos = ((NI) 0);
		(*p).idx += ((NI) 1);
	}
	LA32_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, parseWord__pureZparseopt_25)(NimStringDesc* s, NI i, NimStringDesc** w, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw delim) {
	NI result;
	result = (NI)0;
	result = i;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (result < (s ? s->Sup.len : 0));
		if (!(T3_)) goto LA4_;
		T3_ = ((NU8)(s->data[result]) == (NU8)(34));
		LA4_: ;
		if (!T3_) goto LA5_;
		result += ((NI) 1);
		{
			while (1) {
				if (!(result < (s ? s->Sup.len : 0))) goto LA8;
				{
					if (!((NU8)(s->data[result]) == (NU8)(34))) goto LA11_;
					result += ((NI) 1);
					goto LA7;
				}
				LA11_: ;
				unsureAsgnRef((void**) (&(*w)), addChar((*w), s->data[result]));
				result += ((NI) 1);
			} LA8: ;
		} LA7: ;
	}
	goto LA1_;
	LA5_: ;
	{
		{
			while (1) {
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = (result < (s ? s->Sup.len : 0));
				if (!(T16_)) goto LA17_;
				T16_ = !(((delim[(NU)(((NU8)(s->data[result])))>>3] &(1U<<((NU)(((NU8)(s->data[result])))&7U)))!=0));
				LA17_: ;
				if (!T16_) goto LA15;
				unsureAsgnRef((void**) (&(*w)), addChar((*w), s->data[result]));
				result += ((NI) 1);
			} LA15: ;
		}
	}
	LA1_: ;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, find__stdZenumutils_49)(NimStringDesc** a, NI aLen_0, NimStringDesc* item) {
	NI result;
{	result = (NI)0;
	result = ((NI) 0);
	{
		NimStringDesc** i;
		NI i_2;
		i = (NimStringDesc**)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < aLen_0)) goto LA3;
				i = (&a[i_2]);
				{
					if (!eqStrings((*i), item)) goto LA6_;
					goto BeforeRet_;
				}
				LA6_: ;
				result += ((NI) 1);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__stdZenumutils_44)(NimStringDesc** a, NI aLen_0, NimStringDesc* item) {
	NIM_BOOL result;
	NI T1_;
{	result = (NIM_BOOL)0;
	T1_ = (NI)0;
	T1_ = find__stdZenumutils_49(a, aLen_0, item);
	result = (((NI) 0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, nponext)(tyObject_OptParser__Sj2pYlEalgMxSDrjh9cml3w* p) {
	NI i;
{	{
		NI T3_;
		T3_ = ((*p).cmds ? (*p).cmds->Sup.len : 0);
		if (!(T3_ <= (*p).idx)) goto LA4_;
		(*p).kind = ((tyEnum_CmdLineKind__9aoMk7Iv3Zzg24yOE69bmFEA) 0);
		goto BeforeRet_;
	}
	LA4_: ;
	i = (*p).pos;
	{
		while (1) {
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = (i < ((*p).cmds->data[(*p).idx] ? (*p).cmds->data[(*p).idx]->Sup.len : 0));
			if (!(T8_)) goto LA9_;
			T8_ = (((NU8)((*p).cmds->data[(*p).idx]->data[i])) == ((NU8)(9)) || ((NU8)((*p).cmds->data[(*p).idx]->data[i])) == ((NU8)(32)));
			LA9_: ;
			if (!T8_) goto LA7;
			i += ((NI) 1);
		} LA7: ;
	}
	(*p).pos = i;
	unsureAsgnRef((void**) (&(*p).key), setLengthStr((*p).key, ((NI) 0)));
	unsureAsgnRef((void**) (&(*p).val), setLengthStr((*p).val, ((NI) 0)));
	{
		if (!(*p).inShortState) goto LA12_;
		(*p).inShortState = NIM_FALSE;
		{
			if (!(((*p).cmds->data[(*p).idx] ? (*p).cmds->data[(*p).idx]->Sup.len : 0) <= i)) goto LA16_;
			(*p).idx += ((NI) 1);
			(*p).pos = ((NI) 0);
			{
				NI T20_;
				T20_ = ((*p).cmds ? (*p).cmds->Sup.len : 0);
				if (!(T20_ <= (*p).idx)) goto LA21_;
				(*p).kind = ((tyEnum_CmdLineKind__9aoMk7Iv3Zzg24yOE69bmFEA) 0);
				goto BeforeRet_;
			}
			LA21_: ;
		}
		goto LA14_;
		LA16_: ;
		{
			handleShortOption__pureZparseopt_127(p, (*p).cmds->data[(*p).idx]);
			goto BeforeRet_;
		}
		LA14_: ;
	}
	LA12_: ;
	{
		NIM_BOOL T26_;
		T26_ = (NIM_BOOL)0;
		T26_ = (i < ((*p).cmds->data[(*p).idx] ? (*p).cmds->data[(*p).idx]->Sup.len : 0));
		if (!(T26_)) goto LA27_;
		T26_ = ((NU8)((*p).cmds->data[(*p).idx]->data[i]) == (NU8)(45));
		LA27_: ;
		if (!T26_) goto LA28_;
		i += ((NI) 1);
		{
			NIM_BOOL T32_;
			T32_ = (NIM_BOOL)0;
			T32_ = (i < ((*p).cmds->data[(*p).idx] ? (*p).cmds->data[(*p).idx]->Sup.len : 0));
			if (!(T32_)) goto LA33_;
			T32_ = ((NU8)((*p).cmds->data[(*p).idx]->data[i]) == (NU8)(45));
			LA33_: ;
			if (!T32_) goto LA34_;
			(*p).kind = ((tyEnum_CmdLineKind__9aoMk7Iv3Zzg24yOE69bmFEA) 2);
			i += ((NI) 1);
			i = parseWord__pureZparseopt_25((*p).cmds->data[(*p).idx], i, (&(*p).key), TM__GYgvYKeHVTEls0AcywABHQ_6);
			{
				while (1) {
					NIM_BOOL T38_;
					T38_ = (NIM_BOOL)0;
					T38_ = (i < ((*p).cmds->data[(*p).idx] ? (*p).cmds->data[(*p).idx]->Sup.len : 0));
					if (!(T38_)) goto LA39_;
					T38_ = (((NU8)((*p).cmds->data[(*p).idx]->data[i])) == ((NU8)(9)) || ((NU8)((*p).cmds->data[(*p).idx]->data[i])) == ((NU8)(32)));
					LA39_: ;
					if (!T38_) goto LA37;
					i += ((NI) 1);
				} LA37: ;
			}
			{
				NIM_BOOL T42_;
				T42_ = (NIM_BOOL)0;
				T42_ = (i < ((*p).cmds->data[(*p).idx] ? (*p).cmds->data[(*p).idx]->Sup.len : 0));
				if (!(T42_)) goto LA43_;
				T42_ = (((NU8)((*p).cmds->data[(*p).idx]->data[i])) == ((NU8)(58)) || ((NU8)((*p).cmds->data[(*p).idx]->data[i])) == ((NU8)(61)));
				LA43_: ;
				if (!T42_) goto LA44_;
				i += ((NI) 1);
				{
					while (1) {
						NIM_BOOL T48_;
						T48_ = (NIM_BOOL)0;
						T48_ = (i < ((*p).cmds->data[(*p).idx] ? (*p).cmds->data[(*p).idx]->Sup.len : 0));
						if (!(T48_)) goto LA49_;
						T48_ = (((NU8)((*p).cmds->data[(*p).idx]->data[i])) == ((NU8)(9)) || ((NU8)((*p).cmds->data[(*p).idx]->data[i])) == ((NU8)(32)));
						LA49_: ;
						if (!T48_) goto LA47;
						i += ((NI) 1);
					} LA47: ;
				}
				{
					NIM_BOOL T52_;
					NIM_BOOL T53_;
					NI T55_;
					T52_ = (NIM_BOOL)0;
					T53_ = (NIM_BOOL)0;
					T53_ = (((*p).cmds->data[(*p).idx] ? (*p).cmds->data[(*p).idx]->Sup.len : 0) <= i);
					if (!(T53_)) goto LA54_;
					T55_ = ((*p).cmds ? (*p).cmds->Sup.len : 0);
					T53_ = ((*p).idx < T55_);
					LA54_: ;
					T52_ = T53_;
					if (!(T52_)) goto LA56_;
					T52_ = (*p).allowWhitespaceAfterColon;
					LA56_: ;
					if (!T52_) goto LA57_;
					(*p).idx += ((NI) 1);
					i = ((NI) 0);
				}
				LA57_: ;
				{
					NI T61_;
					T61_ = ((*p).cmds ? (*p).cmds->Sup.len : 0);
					if (!((*p).idx < T61_)) goto LA62_;
					unsureAsgnRef((void**) (&(*p).val), substr__system_7767((*p).cmds->data[(*p).idx], i));
				}
				LA62_: ;
			}
			goto LA40_;
			LA44_: ;
			{
				NIM_BOOL T65_;
				NIM_BOOL T66_;
				NI T67_;
				NIM_BOOL T69_;
				NI T71_;
				T65_ = (NIM_BOOL)0;
				T66_ = (NIM_BOOL)0;
				T67_ = ((*p).longNoVal ? (*p).longNoVal->Sup.len : 0);
				T66_ = (((NI) 0) < T67_);
				if (!(T66_)) goto LA68_;
				T69_ = (NIM_BOOL)0;
				T69_ = contains__stdZenumutils_44(((*p).longNoVal) ? ((*p).longNoVal->data) : NIM_NIL, ((*p).longNoVal ? (*p).longNoVal->Sup.len : 0), (*p).key);
				T66_ = !(T69_);
				LA68_: ;
				T65_ = T66_;
				if (!(T65_)) goto LA70_;
				T71_ = ((*p).cmds ? (*p).cmds->Sup.len : 0);
				T65_ = ((NI)((*p).idx + ((NI) 1)) < T71_);
				LA70_: ;
				if (!T65_) goto LA72_;
				unsureAsgnRef((void**) (&(*p).val), copyString((*p).cmds->data[(NI)((*p).idx + ((NI) 1))]));
				(*p).idx += ((NI) 1);
			}
			goto LA40_;
			LA72_: ;
			{
				unsureAsgnRef((void**) (&(*p).val), ((NimStringDesc*) NIM_NIL));
			}
			LA40_: ;
			(*p).idx += ((NI) 1);
			(*p).pos = ((NI) 0);
		}
		goto LA30_;
		LA34_: ;
		{
			(*p).pos = i;
			handleShortOption__pureZparseopt_127(p, (*p).cmds->data[(*p).idx]);
		}
		LA30_: ;
	}
	goto LA24_;
	LA28_: ;
	{
		(*p).kind = ((tyEnum_CmdLineKind__9aoMk7Iv3Zzg24yOE69bmFEA) 1);
		unsureAsgnRef((void**) (&(*p).key), copyString((*p).cmds->data[(*p).idx]));
		(*p).idx += ((NI) 1);
		(*p).pos = ((NI) 0);
	}
	LA24_: ;
	}BeforeRet_: ;
}
static N_INLINE(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw, dotdot___stdZenumutils_90)(NI a, NI b) {
	tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw));
	result.a = a;
	result.b = b;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, npocmdLineRest)(tyObject_OptParser__Sj2pYlEalgMxSDrjh9cml3w* p) {
	NimStringDesc* result;
	tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw T1_;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ* T2_;
	result = NIM_NIL;
	T1_ = dotdot___stdZenumutils_90((*p).idx, ((NI) 1));
	T2_ = NIM_NIL;
	T2_ = X5BX5D___pureZparseopt_275(((*p).cmds) ? ((*p).cmds->data) : NIM_NIL, ((*p).cmds ? (*p).cmds->Sup.len : 0), T1_);
	result = quoteShellCommand__pureZos_601((T2_) ? (T2_->data) : NIM_NIL, (T2_ ? T2_->Sup.len : 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, atmdotdotatslibatspureatsparseoptdotnim_DatInit000)(void) {
static TNimNode* TM__GYgvYKeHVTEls0AcywABHQ_2_10[10];
static TNimNode* TM__GYgvYKeHVTEls0AcywABHQ_3_4[4];
NI TM__GYgvYKeHVTEls0AcywABHQ_5;
static char* NIM_CONST TM__GYgvYKeHVTEls0AcywABHQ_4[4] = {
"cmdEnd", 
"cmdArgument", 
"cmdLongOption", 
"cmdShortOption"};
static TNimNode TM__GYgvYKeHVTEls0AcywABHQ_0[17];
NTIoptparser__Sj2pYlEalgMxSDrjh9cml3w_.size = sizeof(tyObject_OptParser__Sj2pYlEalgMxSDrjh9cml3w);
NTIoptparser__Sj2pYlEalgMxSDrjh9cml3w_.align = NIM_ALIGNOF(tyObject_OptParser__Sj2pYlEalgMxSDrjh9cml3w);
NTIoptparser__Sj2pYlEalgMxSDrjh9cml3w_.kind = 17;
NTIoptparser__Sj2pYlEalgMxSDrjh9cml3w_.base = (&NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_);
TM__GYgvYKeHVTEls0AcywABHQ_2_10[0] = &TM__GYgvYKeHVTEls0AcywABHQ_0[1];
TM__GYgvYKeHVTEls0AcywABHQ_0[1].kind = 1;
TM__GYgvYKeHVTEls0AcywABHQ_0[1].offset = offsetof(tyObject_OptParser__Sj2pYlEalgMxSDrjh9cml3w, pos);
TM__GYgvYKeHVTEls0AcywABHQ_0[1].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__GYgvYKeHVTEls0AcywABHQ_0[1].name = "pos";
TM__GYgvYKeHVTEls0AcywABHQ_2_10[1] = &TM__GYgvYKeHVTEls0AcywABHQ_0[2];
TM__GYgvYKeHVTEls0AcywABHQ_0[2].kind = 1;
TM__GYgvYKeHVTEls0AcywABHQ_0[2].offset = offsetof(tyObject_OptParser__Sj2pYlEalgMxSDrjh9cml3w, inShortState);
TM__GYgvYKeHVTEls0AcywABHQ_0[2].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__GYgvYKeHVTEls0AcywABHQ_0[2].name = "inShortState";
TM__GYgvYKeHVTEls0AcywABHQ_2_10[2] = &TM__GYgvYKeHVTEls0AcywABHQ_0[3];
TM__GYgvYKeHVTEls0AcywABHQ_0[3].kind = 1;
TM__GYgvYKeHVTEls0AcywABHQ_0[3].offset = offsetof(tyObject_OptParser__Sj2pYlEalgMxSDrjh9cml3w, allowWhitespaceAfterColon);
TM__GYgvYKeHVTEls0AcywABHQ_0[3].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__GYgvYKeHVTEls0AcywABHQ_0[3].name = "allowWhitespaceAfterColon";
TM__GYgvYKeHVTEls0AcywABHQ_2_10[3] = &TM__GYgvYKeHVTEls0AcywABHQ_0[4];
NTIsetLcharT__HDqWPvEAxZK51ZcfaeQEdg_.size = sizeof(tySet_tyChar__nmiMWKVIe46vacnhAFrQvw);
NTIsetLcharT__HDqWPvEAxZK51ZcfaeQEdg_.align = NIM_ALIGNOF(tySet_tyChar__nmiMWKVIe46vacnhAFrQvw);
NTIsetLcharT__HDqWPvEAxZK51ZcfaeQEdg_.kind = 19;
NTIsetLcharT__HDqWPvEAxZK51ZcfaeQEdg_.base = (&NTIchar__nmiMWKVIe46vacnhAFrQvw_);
NTIsetLcharT__HDqWPvEAxZK51ZcfaeQEdg_.flags = 3;
TM__GYgvYKeHVTEls0AcywABHQ_0[5].len = 0; TM__GYgvYKeHVTEls0AcywABHQ_0[5].kind = 0;
NTIsetLcharT__HDqWPvEAxZK51ZcfaeQEdg_.node = &TM__GYgvYKeHVTEls0AcywABHQ_0[5];
TM__GYgvYKeHVTEls0AcywABHQ_0[4].kind = 1;
TM__GYgvYKeHVTEls0AcywABHQ_0[4].offset = offsetof(tyObject_OptParser__Sj2pYlEalgMxSDrjh9cml3w, shortNoVal);
TM__GYgvYKeHVTEls0AcywABHQ_0[4].typ = (&NTIsetLcharT__HDqWPvEAxZK51ZcfaeQEdg_);
TM__GYgvYKeHVTEls0AcywABHQ_0[4].name = "shortNoVal";
TM__GYgvYKeHVTEls0AcywABHQ_2_10[4] = &TM__GYgvYKeHVTEls0AcywABHQ_0[6];
TM__GYgvYKeHVTEls0AcywABHQ_0[6].kind = 1;
TM__GYgvYKeHVTEls0AcywABHQ_0[6].offset = offsetof(tyObject_OptParser__Sj2pYlEalgMxSDrjh9cml3w, longNoVal);
TM__GYgvYKeHVTEls0AcywABHQ_0[6].typ = (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__GYgvYKeHVTEls0AcywABHQ_0[6].name = "longNoVal";
TM__GYgvYKeHVTEls0AcywABHQ_2_10[5] = &TM__GYgvYKeHVTEls0AcywABHQ_0[7];
TM__GYgvYKeHVTEls0AcywABHQ_0[7].kind = 1;
TM__GYgvYKeHVTEls0AcywABHQ_0[7].offset = offsetof(tyObject_OptParser__Sj2pYlEalgMxSDrjh9cml3w, cmds);
TM__GYgvYKeHVTEls0AcywABHQ_0[7].typ = (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__GYgvYKeHVTEls0AcywABHQ_0[7].name = "cmds";
TM__GYgvYKeHVTEls0AcywABHQ_2_10[6] = &TM__GYgvYKeHVTEls0AcywABHQ_0[8];
TM__GYgvYKeHVTEls0AcywABHQ_0[8].kind = 1;
TM__GYgvYKeHVTEls0AcywABHQ_0[8].offset = offsetof(tyObject_OptParser__Sj2pYlEalgMxSDrjh9cml3w, idx);
TM__GYgvYKeHVTEls0AcywABHQ_0[8].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__GYgvYKeHVTEls0AcywABHQ_0[8].name = "idx";
TM__GYgvYKeHVTEls0AcywABHQ_2_10[7] = &TM__GYgvYKeHVTEls0AcywABHQ_0[9];
NTIcmdlinekind__9aoMk7Iv3Zzg24yOE69bmFEA_.size = sizeof(tyEnum_CmdLineKind__9aoMk7Iv3Zzg24yOE69bmFEA);
NTIcmdlinekind__9aoMk7Iv3Zzg24yOE69bmFEA_.align = NIM_ALIGNOF(tyEnum_CmdLineKind__9aoMk7Iv3Zzg24yOE69bmFEA);
NTIcmdlinekind__9aoMk7Iv3Zzg24yOE69bmFEA_.kind = 14;
NTIcmdlinekind__9aoMk7Iv3Zzg24yOE69bmFEA_.base = 0;
NTIcmdlinekind__9aoMk7Iv3Zzg24yOE69bmFEA_.flags = 3;
for (TM__GYgvYKeHVTEls0AcywABHQ_5 = 0; TM__GYgvYKeHVTEls0AcywABHQ_5 < 4; TM__GYgvYKeHVTEls0AcywABHQ_5++) {
TM__GYgvYKeHVTEls0AcywABHQ_0[TM__GYgvYKeHVTEls0AcywABHQ_5+10].kind = 1;
TM__GYgvYKeHVTEls0AcywABHQ_0[TM__GYgvYKeHVTEls0AcywABHQ_5+10].offset = TM__GYgvYKeHVTEls0AcywABHQ_5;
TM__GYgvYKeHVTEls0AcywABHQ_0[TM__GYgvYKeHVTEls0AcywABHQ_5+10].name = TM__GYgvYKeHVTEls0AcywABHQ_4[TM__GYgvYKeHVTEls0AcywABHQ_5];
TM__GYgvYKeHVTEls0AcywABHQ_3_4[TM__GYgvYKeHVTEls0AcywABHQ_5] = &TM__GYgvYKeHVTEls0AcywABHQ_0[TM__GYgvYKeHVTEls0AcywABHQ_5+10];
}
TM__GYgvYKeHVTEls0AcywABHQ_0[14].len = 4; TM__GYgvYKeHVTEls0AcywABHQ_0[14].kind = 2; TM__GYgvYKeHVTEls0AcywABHQ_0[14].sons = &TM__GYgvYKeHVTEls0AcywABHQ_3_4[0];
NTIcmdlinekind__9aoMk7Iv3Zzg24yOE69bmFEA_.node = &TM__GYgvYKeHVTEls0AcywABHQ_0[14];
TM__GYgvYKeHVTEls0AcywABHQ_0[9].kind = 1;
TM__GYgvYKeHVTEls0AcywABHQ_0[9].offset = offsetof(tyObject_OptParser__Sj2pYlEalgMxSDrjh9cml3w, kind);
TM__GYgvYKeHVTEls0AcywABHQ_0[9].typ = (&NTIcmdlinekind__9aoMk7Iv3Zzg24yOE69bmFEA_);
TM__GYgvYKeHVTEls0AcywABHQ_0[9].name = "kind";
TM__GYgvYKeHVTEls0AcywABHQ_2_10[8] = &TM__GYgvYKeHVTEls0AcywABHQ_0[15];
TM__GYgvYKeHVTEls0AcywABHQ_0[15].kind = 1;
TM__GYgvYKeHVTEls0AcywABHQ_0[15].offset = offsetof(tyObject_OptParser__Sj2pYlEalgMxSDrjh9cml3w, key);
TM__GYgvYKeHVTEls0AcywABHQ_0[15].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__GYgvYKeHVTEls0AcywABHQ_0[15].name = "key";
TM__GYgvYKeHVTEls0AcywABHQ_2_10[9] = &TM__GYgvYKeHVTEls0AcywABHQ_0[16];
TM__GYgvYKeHVTEls0AcywABHQ_0[16].kind = 1;
TM__GYgvYKeHVTEls0AcywABHQ_0[16].offset = offsetof(tyObject_OptParser__Sj2pYlEalgMxSDrjh9cml3w, val);
TM__GYgvYKeHVTEls0AcywABHQ_0[16].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__GYgvYKeHVTEls0AcywABHQ_0[16].name = "val";
TM__GYgvYKeHVTEls0AcywABHQ_0[0].len = 10; TM__GYgvYKeHVTEls0AcywABHQ_0[0].kind = 2; TM__GYgvYKeHVTEls0AcywABHQ_0[0].sons = &TM__GYgvYKeHVTEls0AcywABHQ_2_10[0];
NTIoptparser__Sj2pYlEalgMxSDrjh9cml3w_.node = &TM__GYgvYKeHVTEls0AcywABHQ_0[0];
}

