/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU tyArray__VqSA39cBDWnwnJySTumCdjw[8];
struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg {
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* next;
NI key;
tyArray__VqSA39cBDWnwnJySTumCdjw bits;
};
struct TGenericSeq {
NI len;
NI reserved;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tyRef__B9cHSi2RoKQf06mMZC9crTyQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__q9cq1Li6c1nMjHpacEbCj0g)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(void*, newSeq)(TNimType* typ, NI len);
static N_INLINE(void, bitincl__pureZcollectionsZintsets_98)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*, intSetPut__pureZcollectionsZintsets_107)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* t, NI key);
static N_INLINE(NI, nextTry__stdZpackedsets_41)(NI h, NI maxHash, NI* perturb);
static N_INLINE(NIM_BOOL, mustRehash__pureZcollectionsZintsets_118)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* t);
N_LIB_PRIVATE N_NIMCALL(void, intSetEnlarge__pureZcollectionsZintsets_126)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* t);
N_LIB_PRIVATE N_NIMCALL(void, intSetRawInsert__pureZcollectionsZintsets_145)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* t, tySequence__q9cq1Li6c1nMjHpacEbCj0g** data, tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* desc);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5311)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5273)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5318)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5316)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5267)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void*, newObj)(TNimType* typ, NI size);
N_LIB_PRIVATE N_NIMCALL(void, incl__pureZcollectionsZintsets_55)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*, packedSetGet__astalgo_433)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* t, NI key);
N_LIB_PRIVATE N_NIMCALL(void, exclImpl__reorder_277)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(void, initPackedSet__pureZcollectionsZintsets_16)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__astalgo_3489)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(void, excl__reorder_273)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(void, assign__types_3993)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* dest, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* src);
N_LIB_PRIVATE N_NIMCALL(void, incl__importer_1492)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* other);
N_LIB_PRIVATE TNimType NTIpackedset__THXDbzJSs2hcC9a33en2pdw_;
extern TNimType NTIint__rR5Bzr1D5krxoo1NcNyeMA_;
N_LIB_PRIVATE TNimType NTItrunk58objecttype__2fEZuM4UuXkgO9bDnaMLLWg_;
N_LIB_PRIVATE TNimType NTIbitscalar__hMQEc0FMry7Up7EoPki79aA_;
N_LIB_PRIVATE TNimType NTIarrayL48OO55_bitscalarT__VqSA39cBDWnwnJySTumCdjw_;
N_LIB_PRIVATE TNimType NTItrunk__B9cHSi2RoKQf06mMZC9crTyQ_;
N_LIB_PRIVATE TNimType NTItrunkseq__q9cq1Li6c1nMjHpacEbCj0g_;
N_LIB_PRIVATE TNimType NTIarrayL48OO5151_intT__emiAJ8okywrJw7ZHLzlXbQ_;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5220;
static N_NIMCALL(void, Marker_tyRef__B9cHSi2RoKQf06mMZC9crTyQ)(void* p, NI op) {
	tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* a;
	NI T1_;
	a = (tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*)p;
	nimGCvisit((void*)(*a).next, op);
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__q9cq1Li6c1nMjHpacEbCj0g)(void* p, NI op) {
	tySequence__q9cq1Li6c1nMjHpacEbCj0g* a;
	NI T1_;
	a = (tySequence__q9cq1Li6c1nMjHpacEbCj0g*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_], op);
	}
}
N_LIB_PRIVATE N_NIMCALL(void, initPackedSet__pureZcollectionsZintsets_16)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result) {
	NI T1_;
	(*Result).elems = 0;
	(*Result).counter = 0;
	(*Result).max = 0;
	unsureAsgnRef((void**)&(*Result).head, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).data, NIM_NIL);
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < 34; T1_++) {
	(*Result).a[T1_] = 0;
	}
	(*Result).elems = ((NI) 0);
	(*Result).counter = ((NI) 0);
	(*Result).max = ((NI) 0);
	unsureAsgnRef((void**) (&(*Result).head), ((tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) NIM_NIL));
	unsureAsgnRef((void**) (&(*Result).data), NIM_NIL);
}
static N_INLINE(NI, nextTry__stdZpackedsets_41)(NI h, NI maxHash, NI* perturb) {
	NI result;
	NU perturb2;
	result = (NI)0;
	perturb2 = (NU)((NU64)(((NU) ((*perturb)))) >> (NU64)(((NI) 5)));
	(*perturb) = ((NI) (perturb2));
	result = (NI)((NI)((NI)((NI)(((NI) 5) * h) + ((NI) 1)) + (*perturb)) & maxHash);
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__pureZcollectionsZintsets_118)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* t) {
	NIM_BOOL result;
	NI length;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	length = (NI)((*t).max + ((NI) 1));
	T1_ = (NIM_BOOL)0;
	T1_ = ((NI)(length * ((NI) 2)) < (NI)((*t).counter * ((NI) 3)));
	if (T1_) goto LA2_;
	T1_ = ((NI)(length - (*t).counter) < ((NI) 4));
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5311)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5273)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5316)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5267((&gch__system_5220.zct), c);
}
static N_INLINE(void, decRef__system_5318)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5316(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5273(src);
		incRef__system_5311(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5273((*dest));
		decRef__system_5318(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(void, intSetRawInsert__pureZcollectionsZintsets_145)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* t, tySequence__q9cq1Li6c1nMjHpacEbCj0g** data, tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* desc) {
	NI h;
	NI perturb;
	h = (NI)((*desc).key & (*t).max);
	perturb = (*desc).key;
	{
		while (1) {
			if (!!(((*data)->data[h] == ((tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) NIM_NIL)))) goto LA2;
			h = nextTry__stdZpackedsets_41(h, (*t).max, (&perturb));
		} LA2: ;
	}
	asgnRef((void**) (&(*data)->data[h]), desc);
}
N_LIB_PRIVATE N_NIMCALL(void, intSetEnlarge__pureZcollectionsZintsets_126)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* t) {
	tySequence__q9cq1Li6c1nMjHpacEbCj0g* n;
	NI oldMax;
	tySequence__q9cq1Li6c1nMjHpacEbCj0g* T8_;
	n = NIM_NIL;
	oldMax = (*t).max;
	(*t).max = (NI)((NI)((NI)((*t).max + ((NI) 1)) * ((NI) 2)) - ((NI) 1));
	n = (tySequence__q9cq1Li6c1nMjHpacEbCj0g*) newSeq((&NTItrunkseq__q9cq1Li6c1nMjHpacEbCj0g_), ((NI) ((NI)((*t).max + ((NI) 1)))));
	{
		NI i;
		NI res;
		i = (NI)0;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= oldMax)) goto LA3;
				i = res;
				{
					if (!!(((*t).data->data[i] == ((tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) NIM_NIL)))) goto LA6_;
					intSetRawInsert__pureZcollectionsZintsets_145((&(*t)), (&n), (*t).data->data[i]);
				}
				LA6_: ;
				res += ((NI) 1);
			} LA3: ;
		}
	}
	T8_ = NIM_NIL;
	T8_ = (*t).data;
	unsureAsgnRef((void**) (&(*t).data), n);
	n = T8_;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*, intSetPut__pureZcollectionsZintsets_107)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* t, NI key) {
	tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* result;
	NI h;
	NI perturb;
{	result = NIM_NIL;
	h = (NI)(key & (*t).max);
	perturb = key;
	{
		while (1) {
			if (!!(((*t).data->data[h] == ((tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) NIM_NIL)))) goto LA2;
			{
				if (!((*(*t).data->data[h]).key == key)) goto LA5_;
				result = (*t).data->data[h];
				goto BeforeRet_;
			}
			LA5_: ;
			h = nextTry__stdZpackedsets_41(h, (*t).max, (&perturb));
		} LA2: ;
	}
	{
		NIM_BOOL T9_;
		T9_ = (NIM_BOOL)0;
		T9_ = mustRehash__pureZcollectionsZintsets_118((&(*t)));
		if (!T9_) goto LA10_;
		intSetEnlarge__pureZcollectionsZintsets_126(t);
	}
	LA10_: ;
	(*t).counter += ((NI) 1);
	h = (NI)(key & (*t).max);
	perturb = key;
	{
		while (1) {
			if (!!(((*t).data->data[h] == ((tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) NIM_NIL)))) goto LA13;
			h = nextTry__stdZpackedsets_41(h, (*t).max, (&perturb));
		} LA13: ;
	}
	result = (tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) newObj((&NTItrunk__B9cHSi2RoKQf06mMZC9crTyQ_), sizeof(tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg));
	asgnRef((void**) (&(*result).next), (*t).head);
	(*result).key = key;
	unsureAsgnRef((void**) (&(*t).head), result);
	asgnRef((void**) (&(*t).data->data[h]), result);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, bitincl__pureZcollectionsZintsets_98)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key) {
	tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* ret;
	tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* t;
	NI u;
	ret = NIM_NIL;
	t = intSetPut__pureZcollectionsZintsets_107(s, (NI)((NI64)(key) >> (NU64)(((NI) 9))));
	u = (NI)(key & ((NI) 511));
	(*t).bits[((NI)((NI64)(u) >> (NU64)(((NI) 6))))- 0] = (NU)((*t).bits[((NI)((NI64)(u) >> (NU64)(((NI) 6))))- 0] | (NU)((NU64)(((NU) 1)) << (NU64)((NI)(u & ((NI) 63)))));
}
N_LIB_PRIVATE N_NIMCALL(void, incl__pureZcollectionsZintsets_55)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key) {
{	{
		if (!((*s).elems <= ((NI) 34))) goto LA3_;
		{
			NI i;
			NI i_2;
			i = (NI)0;
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < (*s).elems)) goto LA7;
					i = i_2;
					{
						if (!((*s).a[(i)- 0] == key)) goto LA10_;
						goto BeforeRet_;
					}
					LA10_: ;
					i_2 += ((NI) 1);
				} LA7: ;
			}
		}
		{
			if (!((*s).elems < ((NI) 34))) goto LA14_;
			(*s).a[((*s).elems)- 0] = key;
			(*s).elems += ((NI) 1);
			goto BeforeRet_;
		}
		LA14_: ;
		unsureAsgnRef((void**) (&(*s).data), (tySequence__q9cq1Li6c1nMjHpacEbCj0g*) newSeq((&NTItrunkseq__q9cq1Li6c1nMjHpacEbCj0g_), ((NI) 8)));
		(*s).max = ((NI) 7);
		{
			NI i_3;
			NI i_4;
			i_3 = (NI)0;
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < (*s).elems)) goto LA18;
					i_3 = i_4;
					bitincl__pureZcollectionsZintsets_98(s, (*s).a[(i_3)- 0]);
					i_4 += ((NI) 1);
				} LA18: ;
			}
		}
		(*s).elems = ((NI) 35);
	}
	LA3_: ;
	bitincl__pureZcollectionsZintsets_98(s, key);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*, packedSetGet__astalgo_433)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* t, NI key) {
	tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* result;
	NI h;
	NI perturb;
{	result = NIM_NIL;
	h = (NI)(key & (*t).max);
	perturb = key;
	{
		while (1) {
			if (!!(((*t).data->data[h] == ((tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) NIM_NIL)))) goto LA2;
			{
				if (!((*(*t).data->data[h]).key == key)) goto LA5_;
				result = (*t).data->data[h];
				goto BeforeRet_;
			}
			LA5_: ;
			h = nextTry__stdZpackedsets_41(h, (*t).max, (&perturb));
		} LA2: ;
	}
	result = ((tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) NIM_NIL);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__astalgo_402)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		if (!((*s).elems <= ((NI) 34))) goto LA3_;
		{
			NI i;
			NI i_2;
			i = (NI)0;
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < (*s).elems)) goto LA7;
					i = i_2;
					{
						if (!((*s).a[(i)- 0] == key)) goto LA10_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA10_: ;
					i_2 += ((NI) 1);
				} LA7: ;
			}
		}
		incl__pureZcollectionsZintsets_55(s, key);
		result = NIM_FALSE;
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* t;
		t = packedSetGet__astalgo_433((&(*s)), (NI)((NI64)(key) >> (NU64)(((NI) 9))));
		{
			NI u;
			if (!!((t == ((tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) NIM_NIL)))) goto LA15_;
			u = (NI)(key & ((NI) 511));
			result = !(((NU)((*t).bits[((NI)((NI64)(u) >> (NU64)(((NI) 6))))- 0] & (NU)((NU64)(((NU) 1)) << (NU64)((NI)(u & ((NI) 63))))) == ((NU) 0)));
			{
				if (!!(result)) goto LA19_;
				(*t).bits[((NI)((NI64)(u) >> (NU64)(((NI) 6))))- 0] = (NU)((*t).bits[((NI)((NI64)(u) >> (NU64)(((NI) 6))))- 0] | (NU)((NU64)(((NU) 1)) << (NU64)((NI)(u & ((NI) 63)))));
			}
			LA19_: ;
		}
		goto LA13_;
		LA15_: ;
		{
			incl__pureZcollectionsZintsets_55(s, key);
			result = NIM_FALSE;
		}
		LA13_: ;
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, exclImpl__reorder_277)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key) {
{	{
		if (!((*s).elems <= ((NI) 34))) goto LA3_;
		{
			NI i;
			NI i_2;
			i = (NI)0;
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < (*s).elems)) goto LA7;
					i = i_2;
					{
						if (!((*s).a[(i)- 0] == key)) goto LA10_;
						(*s).a[(i)- 0] = (*s).a[((NI)((*s).elems - ((NI) 1)))- 0];
						(*s).elems -= ((NI) 1);
						goto BeforeRet_;
					}
					LA10_: ;
					i_2 += ((NI) 1);
				} LA7: ;
			}
		}
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* t;
		t = packedSetGet__astalgo_433((&(*s)), (NI)((NI64)(key) >> (NU64)(((NI) 9))));
		{
			NI u;
			if (!!((t == ((tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) NIM_NIL)))) goto LA15_;
			u = (NI)(key & ((NI) 511));
			(*t).bits[((NI)((NI64)(u) >> (NU64)(((NI) 6))))- 0] = (NU)((*t).bits[((NI)((NI64)(u) >> (NU64)(((NI) 6))))- 0] & (NU)((NU64) ~((NU)((NU64)(((NU) 1)) << (NU64)((NI)(u & ((NI) 63)))))));
		}
		LA15_: ;
	}
	LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, excl__reorder_273)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key) {
	exclImpl__reorder_277(s, key);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__astalgo_3489)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		if (!((*s).elems <= ((NI) 34))) goto LA3_;
		{
			NI i;
			NI i_2;
			i = (NI)0;
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < (*s).elems)) goto LA7;
					i = i_2;
					{
						if (!((*s).a[(i)- 0] == key)) goto LA10_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA10_: ;
					i_2 += ((NI) 1);
				} LA7: ;
			}
		}
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* t;
		t = packedSetGet__astalgo_433(s, (NI)((NI64)(key) >> (NU64)(((NI) 9))));
		{
			NI u;
			if (!!((t == ((tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) NIM_NIL)))) goto LA15_;
			u = (NI)(key & ((NI) 511));
			result = !(((NU)((*t).bits[((NI)((NI64)(u) >> (NU64)(((NI) 6))))- 0] & (NU)((NU64)(((NU) 1)) << (NU64)((NI)(u & ((NI) 63))))) == ((NU) 0)));
		}
		goto LA13_;
		LA15_: ;
		{
			result = NIM_FALSE;
		}
		LA13_: ;
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
N_LIB_PRIVATE N_NIMCALL(void, assign__types_3993)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* dest, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* src) {
	{
		if (!((*src).elems <= ((NI) 34))) goto LA3_;
		unsureAsgnRef((void**) (&(*dest).data), NIM_NIL);
		(*dest).max = ((NI) 0);
		(*dest).counter = (*src).counter;
		unsureAsgnRef((void**) (&(*dest).head), ((tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) NIM_NIL));
		(*dest).elems = (*src).elems;
		nimCopyMem((void*)(*dest).a, (NIM_CONST void*)(*src).a, sizeof(tyArray__emiAJ8okywrJw7ZHLzlXbQ));
	}
	goto LA1_;
	LA3_: ;
	{
		NI T6_;
		tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* it;
		(*dest).counter = (*src).counter;
		(*dest).max = (*src).max;
		(*dest).elems = (*src).elems;
		T6_ = ((*src).data ? (*src).data->Sup.len : 0);
		unsureAsgnRef((void**) (&(*dest).data), (tySequence__q9cq1Li6c1nMjHpacEbCj0g*) newSeq((&NTItrunkseq__q9cq1Li6c1nMjHpacEbCj0g_), ((NI) (T6_))));
		it = (*src).head;
		{
			while (1) {
				NI h;
				NI perturb;
				tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* n;
				if (!!((it == ((tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) NIM_NIL)))) goto LA8;
				h = (NI)((*it).key & (*dest).max);
				perturb = (*it).key;
				{
					while (1) {
						if (!!(((*dest).data->data[h] == ((tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) NIM_NIL)))) goto LA10;
						h = nextTry__stdZpackedsets_41(h, (*dest).max, (&perturb));
					} LA10: ;
				}
				n = NIM_NIL;
				n = (tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) newObj((&NTItrunk__B9cHSi2RoKQf06mMZC9crTyQ_), sizeof(tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg));
				asgnRef((void**) (&(*n).next), (*dest).head);
				(*n).key = (*it).key;
				nimCopyMem((void*)(*n).bits, (NIM_CONST void*)(*it).bits, sizeof(tyArray__VqSA39cBDWnwnJySTumCdjw));
				unsureAsgnRef((void**) (&(*dest).head), n);
				asgnRef((void**) (&(*dest).data->data[h]), n);
				it = (*it).next;
			} LA8: ;
		}
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, difference__sem_4267)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s1, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s2, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result) {
	initPackedSet__pureZcollectionsZintsets_16(Result);
	{
		NI item;
		item = (NI)0;
		{
			if (!((*s1).elems <= ((NI) 34))) goto LA4_;
			{
				NI i;
				NI i_2;
				i = (NI)0;
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < (*s1).elems)) goto LA8;
						i = i_2;
						item = (*s1).a[(i)- 0];
						{
							NIM_BOOL T11_;
							T11_ = (NIM_BOOL)0;
							T11_ = contains__astalgo_3489(s2, item);
							if (!!(T11_)) goto LA12_;
							incl__pureZcollectionsZintsets_55(Result, item);
						}
						LA12_: ;
						i_2 += ((NI) 1);
					} LA8: ;
				}
			}
		}
		goto LA2_;
		LA4_: ;
		{
			tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* r;
			r = (*s1).head;
			{
				while (1) {
					NI i_3;
					if (!!((r == ((tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) NIM_NIL)))) goto LA16;
					i_3 = ((NI) 0);
					{
						while (1) {
							NU w;
							NI j;
							if (!(i_3 <= ((NI) 7))) goto LA18;
							w = (*r).bits[(i_3)- 0];
							j = ((NI) 0);
							{
								while (1) {
									if (!!((w == ((NU) 0)))) goto LA20;
									{
										NI T25_;
										if (!!(((NU)(w & ((NU) 1)) == ((NU) 0)))) goto LA23_;
										T25_ = (NI)0;
										T25_ = pluspercent___system_696((NI)((NU64)(i_3) << (NU64)(((NI) 6))), j);
										item = (NI)((NI)((NU64)((*r).key) << (NU64)(((NI) 9))) | T25_);
										{
											NIM_BOOL T28_;
											T28_ = (NIM_BOOL)0;
											T28_ = contains__astalgo_3489(s2, item);
											if (!!(T28_)) goto LA29_;
											incl__pureZcollectionsZintsets_55(Result, item);
										}
										LA29_: ;
									}
									LA23_: ;
									j += ((NI) 1);
									w = (NU)((NU64)(w) >> (NU64)(((NI) 1)));
								} LA20: ;
							}
							i_3 += ((NI) 1);
						} LA18: ;
					}
					r = (*r).next;
				} LA16: ;
			}
		}
		LA2_: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, incl__importer_1492)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* other) {
	{
		NI item;
		item = (NI)0;
		{
			if (!((*other).elems <= ((NI) 34))) goto LA4_;
			{
				NI i;
				NI i_2;
				i = (NI)0;
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < (*other).elems)) goto LA8;
						i = i_2;
						item = (*other).a[(i)- 0];
						incl__pureZcollectionsZintsets_55(s, item);
						i_2 += ((NI) 1);
					} LA8: ;
				}
			}
		}
		goto LA2_;
		LA4_: ;
		{
			tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* r;
			r = (*other).head;
			{
				while (1) {
					NI i_3;
					if (!!((r == ((tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) NIM_NIL)))) goto LA11;
					i_3 = ((NI) 0);
					{
						while (1) {
							NU w;
							NI j;
							if (!(i_3 <= ((NI) 7))) goto LA13;
							w = (*r).bits[(i_3)- 0];
							j = ((NI) 0);
							{
								while (1) {
									if (!!((w == ((NU) 0)))) goto LA15;
									{
										NI T20_;
										if (!!(((NU)(w & ((NU) 1)) == ((NU) 0)))) goto LA18_;
										T20_ = (NI)0;
										T20_ = pluspercent___system_696((NI)((NU64)(i_3) << (NU64)(((NI) 6))), j);
										item = (NI)((NI)((NU64)((*r).key) << (NU64)(((NI) 9))) | T20_);
										incl__pureZcollectionsZintsets_55(s, item);
									}
									LA18_: ;
									j += ((NI) 1);
									w = (NU)((NU64)(w) >> (NU64)(((NI) 1)));
								} LA15: ;
							}
							i_3 += ((NI) 1);
						} LA13: ;
					}
					r = (*r).next;
				} LA11: ;
			}
		}
		LA2_: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, excl__injectdestructors_2012)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* other) {
	{
		NI item;
		item = (NI)0;
		{
			if (!((*other).elems <= ((NI) 34))) goto LA4_;
			{
				NI i;
				NI i_2;
				i = (NI)0;
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < (*other).elems)) goto LA8;
						i = i_2;
						item = (*other).a[(i)- 0];
						excl__reorder_273(s, item);
						i_2 += ((NI) 1);
					} LA8: ;
				}
			}
		}
		goto LA2_;
		LA4_: ;
		{
			tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* r;
			r = (*other).head;
			{
				while (1) {
					NI i_3;
					if (!!((r == ((tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) NIM_NIL)))) goto LA11;
					i_3 = ((NI) 0);
					{
						while (1) {
							NU w;
							NI j;
							if (!(i_3 <= ((NI) 7))) goto LA13;
							w = (*r).bits[(i_3)- 0];
							j = ((NI) 0);
							{
								while (1) {
									if (!!((w == ((NU) 0)))) goto LA15;
									{
										NI T20_;
										if (!!(((NU)(w & ((NU) 1)) == ((NU) 0)))) goto LA18_;
										T20_ = (NI)0;
										T20_ = pluspercent___system_696((NI)((NU64)(i_3) << (NU64)(((NI) 6))), j);
										item = (NI)((NI)((NU64)((*r).key) << (NU64)(((NI) 9))) | T20_);
										excl__reorder_273(s, item);
									}
									LA18_: ;
									j += ((NI) 1);
									w = (NU)((NU64)(w) >> (NU64)(((NI) 1)));
								} LA15: ;
							}
							i_3 += ((NI) 1);
						} LA13: ;
					}
					r = (*r).next;
				} LA11: ;
			}
		}
		LA2_: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, union__injectdestructors_4127)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s1, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s2, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result) {
	NI T1_;
	(*Result).elems = 0;
	(*Result).counter = 0;
	(*Result).max = 0;
	unsureAsgnRef((void**)&(*Result).head, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).data, NIM_NIL);
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < 34; T1_++) {
	(*Result).a[T1_] = 0;
	}
	assign__types_3993(Result, s1);
	incl__importer_1492(Result, s2);
}
N_LIB_PRIVATE N_NIMCALL(void, atmdotdotatslibatsstdatspackedsetsdotnim_DatInit000)(void) {
static TNimNode* TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_2_6[6];
static TNimNode* TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_3_3[3];
static TNimNode TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[11];
NTIpackedset__THXDbzJSs2hcC9a33en2pdw_.size = sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw);
NTIpackedset__THXDbzJSs2hcC9a33en2pdw_.align = NIM_ALIGNOF(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw);
NTIpackedset__THXDbzJSs2hcC9a33en2pdw_.kind = 18;
NTIpackedset__THXDbzJSs2hcC9a33en2pdw_.base = 0;
NTIpackedset__THXDbzJSs2hcC9a33en2pdw_.flags = 2;
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_2_6[0] = &TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[1];
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[1].kind = 1;
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[1].offset = offsetof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw, elems);
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[1].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[1].name = "elems";
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_2_6[1] = &TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[2];
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[2].kind = 1;
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[2].offset = offsetof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw, counter);
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[2].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[2].name = "counter";
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_2_6[2] = &TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[3];
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[3].kind = 1;
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[3].offset = offsetof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw, max);
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[3].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[3].name = "max";
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_2_6[3] = &TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[4];
NTItrunk58objecttype__2fEZuM4UuXkgO9bDnaMLLWg_.size = sizeof(tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg);
NTItrunk58objecttype__2fEZuM4UuXkgO9bDnaMLLWg_.align = NIM_ALIGNOF(tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg);
NTItrunk58objecttype__2fEZuM4UuXkgO9bDnaMLLWg_.kind = 18;
NTItrunk58objecttype__2fEZuM4UuXkgO9bDnaMLLWg_.base = 0;
NTItrunk58objecttype__2fEZuM4UuXkgO9bDnaMLLWg_.flags = 2;
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_3_3[0] = &TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[6];
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[6].kind = 1;
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[6].offset = offsetof(tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg, next);
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[6].typ = (&NTItrunk__B9cHSi2RoKQf06mMZC9crTyQ_);
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[6].name = "next";
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_3_3[1] = &TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[7];
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[7].kind = 1;
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[7].offset = offsetof(tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg, key);
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[7].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[7].name = "key";
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_3_3[2] = &TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[8];
NTIbitscalar__hMQEc0FMry7Up7EoPki79aA_.size = sizeof(NU);
NTIbitscalar__hMQEc0FMry7Up7EoPki79aA_.align = NIM_ALIGNOF(NU);
NTIbitscalar__hMQEc0FMry7Up7EoPki79aA_.kind = 40;
NTIbitscalar__hMQEc0FMry7Up7EoPki79aA_.base = 0;
NTIbitscalar__hMQEc0FMry7Up7EoPki79aA_.flags = 3;
NTIarrayL48OO55_bitscalarT__VqSA39cBDWnwnJySTumCdjw_.size = sizeof(tyArray__VqSA39cBDWnwnJySTumCdjw);
NTIarrayL48OO55_bitscalarT__VqSA39cBDWnwnJySTumCdjw_.align = NIM_ALIGNOF(tyArray__VqSA39cBDWnwnJySTumCdjw);
NTIarrayL48OO55_bitscalarT__VqSA39cBDWnwnJySTumCdjw_.kind = 16;
NTIarrayL48OO55_bitscalarT__VqSA39cBDWnwnJySTumCdjw_.base = (&NTIbitscalar__hMQEc0FMry7Up7EoPki79aA_);
NTIarrayL48OO55_bitscalarT__VqSA39cBDWnwnJySTumCdjw_.flags = 3;
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[8].kind = 1;
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[8].offset = offsetof(tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg, bits);
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[8].typ = (&NTIarrayL48OO55_bitscalarT__VqSA39cBDWnwnJySTumCdjw_);
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[8].name = "bits";
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[5].len = 3; TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[5].kind = 2; TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[5].sons = &TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_3_3[0];
NTItrunk58objecttype__2fEZuM4UuXkgO9bDnaMLLWg_.node = &TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[5];
NTItrunk__B9cHSi2RoKQf06mMZC9crTyQ_.size = sizeof(tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*);
NTItrunk__B9cHSi2RoKQf06mMZC9crTyQ_.align = NIM_ALIGNOF(tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*);
NTItrunk__B9cHSi2RoKQf06mMZC9crTyQ_.kind = 22;
NTItrunk__B9cHSi2RoKQf06mMZC9crTyQ_.base = (&NTItrunk58objecttype__2fEZuM4UuXkgO9bDnaMLLWg_);
NTItrunk__B9cHSi2RoKQf06mMZC9crTyQ_.flags = 2;
NTItrunk__B9cHSi2RoKQf06mMZC9crTyQ_.marker = Marker_tyRef__B9cHSi2RoKQf06mMZC9crTyQ;
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[4].kind = 1;
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[4].offset = offsetof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw, head);
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[4].typ = (&NTItrunk__B9cHSi2RoKQf06mMZC9crTyQ_);
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[4].name = "head";
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_2_6[4] = &TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[9];
NTItrunkseq__q9cq1Li6c1nMjHpacEbCj0g_.size = sizeof(tySequence__q9cq1Li6c1nMjHpacEbCj0g*);
NTItrunkseq__q9cq1Li6c1nMjHpacEbCj0g_.align = NIM_ALIGNOF(tySequence__q9cq1Li6c1nMjHpacEbCj0g*);
NTItrunkseq__q9cq1Li6c1nMjHpacEbCj0g_.kind = 24;
NTItrunkseq__q9cq1Li6c1nMjHpacEbCj0g_.base = (&NTItrunk__B9cHSi2RoKQf06mMZC9crTyQ_);
NTItrunkseq__q9cq1Li6c1nMjHpacEbCj0g_.flags = 2;
NTItrunkseq__q9cq1Li6c1nMjHpacEbCj0g_.marker = Marker_tySequence__q9cq1Li6c1nMjHpacEbCj0g;
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[9].kind = 1;
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[9].offset = offsetof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw, data);
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[9].typ = (&NTItrunkseq__q9cq1Li6c1nMjHpacEbCj0g_);
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[9].name = "data";
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_2_6[5] = &TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[10];
NTIarrayL48OO5151_intT__emiAJ8okywrJw7ZHLzlXbQ_.size = sizeof(tyArray__emiAJ8okywrJw7ZHLzlXbQ);
NTIarrayL48OO5151_intT__emiAJ8okywrJw7ZHLzlXbQ_.align = NIM_ALIGNOF(tyArray__emiAJ8okywrJw7ZHLzlXbQ);
NTIarrayL48OO5151_intT__emiAJ8okywrJw7ZHLzlXbQ_.kind = 16;
NTIarrayL48OO5151_intT__emiAJ8okywrJw7ZHLzlXbQ_.base = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
NTIarrayL48OO5151_intT__emiAJ8okywrJw7ZHLzlXbQ_.flags = 3;
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[10].kind = 1;
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[10].offset = offsetof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw, a);
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[10].typ = (&NTIarrayL48OO5151_intT__emiAJ8okywrJw7ZHLzlXbQ_);
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[10].name = "a";
TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[0].len = 6; TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[0].kind = 2; TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[0].sons = &TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_2_6[0];
NTIpackedset__THXDbzJSs2hcC9a33en2pdw_.node = &TM__9aZRcAiZ7ZPzeP9b8C7SWi9bQ_0[0];
}

