/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <stdio.h>
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_NdiFile__ZdQ0n9cikYC2TzROZ1EnTOA tyObject_NdiFile__ZdQ0n9cikYC2TzROZ1EnTOA;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tySequence__ed0C0uAUZPhvw3RAc5hfYg tySequence__ed0C0uAUZPhvw3RAc5hfYg;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct RootObj RootObj;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_NdiFile__ZdQ0n9cikYC2TzROZ1EnTOA {
NIM_BOOL enabled;
FILE* f;
NimStringDesc* buf;
NimStringDesc* filename;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* syms;
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w;
struct RootObj {
TNimType* m_type;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
typedef NimStringDesc* tyArray__Re75IspeoxXy2oCZHwcRrA[2];
struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg {
NI id;
NimStringDesc* s;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* next;
NI h;
};
typedef NimStringDesc* tyArray__sMpvt1sOxOJ3LFGulnbeMQ[4];
struct tySequence__ed0C0uAUZPhvw3RAc5hfYg {
  TGenericSeq Sup;
  tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* data[SEQ_DECL_SIZE];
};
static N_INLINE(NIM_BOOL, isEmpty__options_4492)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_NIMCALL(NimStringDesc*, rawNewString)(NI cap);
N_LIB_PRIVATE N_NIMCALL(FILE*, open__systemZio_430)(NimStringDesc* filename, tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w mode, NI bufSize);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__systemZassertions_56)(NimStringDesc* msg);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(void, doWrite__ndi_12)(tyObject_NdiFile__ZdQ0n9cikYC2TzROZ1EnTOA* f, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, setLengthStr)(NimStringDesc* s, NI newLen);
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_167)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(void, write__systemZio_304)(FILE* f, NimStringDesc** a, NI aLen_0);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void, writeRope__ropes_237)(FILE* f, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r);
static N_INLINE(void, writeLine__msgs_442)(FILE* f, NimStringDesc** x, NI xLen_0);
N_LIB_PRIVATE N_NIMCALL(void, write__systemZio_205)(FILE* f, NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPath__msgs_548)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(void, close__systemZio_217)(FILE* f);
N_LIB_PRIVATE N_NIMCALL(void, reset__ndi_47)(tySequence__ed0C0uAUZPhvw3RAc5hfYg** obj);
N_LIB_PRIVATE N_NIMCALL(void, reset__ndi_55)(NimStringDesc** obj);
N_LIB_PRIVATE TNimType NTIndifile__ZdQ0n9cikYC2TzROZ1EnTOA_;
extern TNimType NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_;
extern TNimType NTIfile__dk9aLikxD1GCAjU8N55Nb7A_;
extern TNimType NTIstring__77mFvmsOLKik79ci2hXkHEg_;
extern TNimType NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_;
STRING_LITERAL(TM__9bjXlRg9ajY35u7ap75QbU6A_3, "ndi.nim(44, 14) `f.f != nil` ", 29);
STRING_LITERAL(TM__9bjXlRg9ajY35u7ap75QbU6A_4, "\011", 1);
STRING_LITERAL(TM__9bjXlRg9ajY35u7ap75QbU6A_5, "\012", 1);
static N_INLINE(NIM_BOOL, isEmpty__options_4492)(NimStringDesc* x) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((x ? x->Sup.len : 0) == ((NI) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, open__ndi_24)(tyObject_NdiFile__ZdQ0n9cikYC2TzROZ1EnTOA* f, NimStringDesc* filename, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = isEmpty__options_4492(filename);
	(*f).enabled = !(T1_);
	{
		if (!(*f).enabled) goto LA4_;
		unsureAsgnRef((void**) (&(*f).filename), copyString(filename));
		unsureAsgnRef((void**) (&(*f).buf), rawNewString(((NI) 20)));
	}
	LA4_: ;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x) {
	addInt__stdZprivateZdigitsutils_167(result, ((NI64) (x)));
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(void, writeLine__msgs_442)(FILE* f, NimStringDesc** x, NI xLen_0) {
	{
		NimStringDesc** i;
		NI i_2;
		i = (NimStringDesc**)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < xLen_0)) goto LA3;
				i = (&x[i_2]);
				write__systemZio_205(f, (*i));
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	write__systemZio_205(f, ((NimStringDesc*) &TM__9bjXlRg9ajY35u7ap75QbU6A_5));
}
N_LIB_PRIVATE N_NIMCALL(void, doWrite__ndi_12)(tyObject_NdiFile__ZdQ0n9cikYC2TzROZ1EnTOA* f, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	tyArray__Re75IspeoxXy2oCZHwcRrA T1_;
	tyArray__sMpvt1sOxOJ3LFGulnbeMQ T2_;
	unsureAsgnRef((void**) (&(*f).buf), setLengthStr((*f).buf, ((NI) 0)));
	addInt__stdZprivateZdigitsutils_189((&(*f).buf), ((NI) ((*s).info.line)));
	unsureAsgnRef((void**) (&(*f).buf), resizeString((*f).buf, 1));
appendString((*f).buf, ((NimStringDesc*) &TM__9bjXlRg9ajY35u7ap75QbU6A_4));
	addInt__stdZprivateZdigitsutils_189((&(*f).buf), ((NI) ((*s).info.col)));
	nimZeroMem((void*)T1_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
	T1_[0] = copyString((*(*s).name).s);
	T1_[1] = copyString(((NimStringDesc*) &TM__9bjXlRg9ajY35u7ap75QbU6A_4));
	write__systemZio_304((*f).f, T1_, 2);
	writeRope__ropes_237((*f).f, (*s).loc.r);
	nimZeroMem((void*)T2_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
	T2_[0] = copyString(((NimStringDesc*) &TM__9bjXlRg9ajY35u7ap75QbU6A_4));
	T2_[1] = toFullPath__msgs_548(conf, (*s).info.fileIndex);
	T2_[2] = copyString(((NimStringDesc*) &TM__9bjXlRg9ajY35u7ap75QbU6A_4));
	T2_[3] = copyString((*f).buf);
	writeLine__msgs_442((*f).f, T2_, 4);
}
N_LIB_PRIVATE N_NIMCALL(void, close__ndi_31)(tyObject_NdiFile__ZdQ0n9cikYC2TzROZ1EnTOA* f, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	{
		if (!(*f).enabled) goto LA3_;
		(*f).f = open__systemZio_430((*f).filename, ((tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w) 1), ((NI) 8000));
		{
			NimStringDesc* T9_;
			if (!!(!(((*f).f == ((FILE*) NIM_NIL))))) goto LA7_;
			T9_ = NIM_NIL;
			T9_ = rawNewString(((*f).filename ? (*f).filename->Sup.len : 0) + 29);
appendString(T9_, ((NimStringDesc*) &TM__9bjXlRg9ajY35u7ap75QbU6A_3));
appendString(T9_, (*f).filename);
			failedAssertImpl__systemZassertions_56(T9_);
		}
		LA7_: ;
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw** s;
			NI i;
			NI L;
			NI T11_;
			s = (tyObject_TSym__3r34mwqcVmg5JFNmiaVncw**)0;
			i = ((NI) 0);
			T11_ = ((*f).syms ? (*f).syms->Sup.len : 0);
			L = T11_;
			{
				while (1) {
					if (!(i < L)) goto LA13;
					s = &(*f).syms->data[i];
					doWrite__ndi_12(f, (*s), conf);
					i += ((NI) 1);
				} LA13: ;
			}
		}
		close__systemZio_217((*f).f);
		reset__ndi_47((&(*f).syms));
		reset__ndi_55((&(*f).filename));
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, atmndidotnim_DatInit000)(void) {
static TNimNode* TM__9bjXlRg9ajY35u7ap75QbU6A_2_5[5];
static TNimNode TM__9bjXlRg9ajY35u7ap75QbU6A_0[6];
NTIndifile__ZdQ0n9cikYC2TzROZ1EnTOA_.size = sizeof(tyObject_NdiFile__ZdQ0n9cikYC2TzROZ1EnTOA);
NTIndifile__ZdQ0n9cikYC2TzROZ1EnTOA_.align = NIM_ALIGNOF(tyObject_NdiFile__ZdQ0n9cikYC2TzROZ1EnTOA);
NTIndifile__ZdQ0n9cikYC2TzROZ1EnTOA_.kind = 18;
NTIndifile__ZdQ0n9cikYC2TzROZ1EnTOA_.base = 0;
NTIndifile__ZdQ0n9cikYC2TzROZ1EnTOA_.flags = 2;
TM__9bjXlRg9ajY35u7ap75QbU6A_2_5[0] = &TM__9bjXlRg9ajY35u7ap75QbU6A_0[1];
TM__9bjXlRg9ajY35u7ap75QbU6A_0[1].kind = 1;
TM__9bjXlRg9ajY35u7ap75QbU6A_0[1].offset = offsetof(tyObject_NdiFile__ZdQ0n9cikYC2TzROZ1EnTOA, enabled);
TM__9bjXlRg9ajY35u7ap75QbU6A_0[1].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__9bjXlRg9ajY35u7ap75QbU6A_0[1].name = "enabled";
TM__9bjXlRg9ajY35u7ap75QbU6A_2_5[1] = &TM__9bjXlRg9ajY35u7ap75QbU6A_0[2];
TM__9bjXlRg9ajY35u7ap75QbU6A_0[2].kind = 1;
TM__9bjXlRg9ajY35u7ap75QbU6A_0[2].offset = offsetof(tyObject_NdiFile__ZdQ0n9cikYC2TzROZ1EnTOA, f);
TM__9bjXlRg9ajY35u7ap75QbU6A_0[2].typ = (&NTIfile__dk9aLikxD1GCAjU8N55Nb7A_);
TM__9bjXlRg9ajY35u7ap75QbU6A_0[2].name = "f";
TM__9bjXlRg9ajY35u7ap75QbU6A_2_5[2] = &TM__9bjXlRg9ajY35u7ap75QbU6A_0[3];
TM__9bjXlRg9ajY35u7ap75QbU6A_0[3].kind = 1;
TM__9bjXlRg9ajY35u7ap75QbU6A_0[3].offset = offsetof(tyObject_NdiFile__ZdQ0n9cikYC2TzROZ1EnTOA, buf);
TM__9bjXlRg9ajY35u7ap75QbU6A_0[3].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__9bjXlRg9ajY35u7ap75QbU6A_0[3].name = "buf";
TM__9bjXlRg9ajY35u7ap75QbU6A_2_5[3] = &TM__9bjXlRg9ajY35u7ap75QbU6A_0[4];
TM__9bjXlRg9ajY35u7ap75QbU6A_0[4].kind = 1;
TM__9bjXlRg9ajY35u7ap75QbU6A_0[4].offset = offsetof(tyObject_NdiFile__ZdQ0n9cikYC2TzROZ1EnTOA, filename);
TM__9bjXlRg9ajY35u7ap75QbU6A_0[4].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__9bjXlRg9ajY35u7ap75QbU6A_0[4].name = "filename";
TM__9bjXlRg9ajY35u7ap75QbU6A_2_5[4] = &TM__9bjXlRg9ajY35u7ap75QbU6A_0[5];
TM__9bjXlRg9ajY35u7ap75QbU6A_0[5].kind = 1;
TM__9bjXlRg9ajY35u7ap75QbU6A_0[5].offset = offsetof(tyObject_NdiFile__ZdQ0n9cikYC2TzROZ1EnTOA, syms);
TM__9bjXlRg9ajY35u7ap75QbU6A_0[5].typ = (&NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_);
TM__9bjXlRg9ajY35u7ap75QbU6A_0[5].name = "syms";
TM__9bjXlRg9ajY35u7ap75QbU6A_0[0].len = 5; TM__9bjXlRg9ajY35u7ap75QbU6A_0[0].kind = 2; TM__9bjXlRg9ajY35u7ap75QbU6A_0[0].sons = &TM__9bjXlRg9ajY35u7ap75QbU6A_2_5[0];
NTIndifile__ZdQ0n9cikYC2TzROZ1EnTOA_.node = &TM__9bjXlRg9ajY35u7ap75QbU6A_0[0];
}

