/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_Profiler__vPk6nUD8QeNW2bHH4WZfpw tyObject_Profiler__vPk6nUD8QeNW2bHH4WZfpw;
typedef struct tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ;
typedef struct tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ;
typedef struct tyObject_Table__aP9cMXsPundL60Bltc8zw8Q tyObject_Table__aP9cMXsPundL60Bltc8zw8Q;
typedef struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tySequence__YdLNCDKYeipzJx3I8Xw82Q tySequence__YdLNCDKYeipzJx3I8Xw82Q;
typedef struct tySequence__Gl8s23LA3EFz4kIlya9ameg tySequence__Gl8s23LA3EFz4kIlya9ameg;
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tySequence__eJWcQvhuN2q0rM6THoByqQ tySequence__eJWcQvhuN2q0rM6THoByqQ;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg;
typedef struct tySequence__ztPIC2M9bqhs0KjYuE9c9cN8g tySequence__ztPIC2M9bqhs0KjYuE9c9cN8g;
typedef struct tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg;
typedef struct tySequence__E8pi9b5QNahsURYzXMjh3qw tySequence__E8pi9b5QNahsURYzXMjh3qw;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct tySequence__qoz9b2fDIpsvVqgQYTLWcFA tySequence__qoz9b2fDIpsvVqgQYTLWcFA;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tyObject_ProfileInfo__xU9aXXjWWQtDqNY2yZecQYw tyObject_ProfileInfo__xU9aXXjWWQtDqNY2yZecQYw;
typedef struct tySequence__Ou09axLmOh3clXcvEh9agsPw tySequence__Ou09axLmOh3clXcvEh9agsPw;
typedef struct tyTuple__tqJ79cmISx6IHad2jnF54pA tyTuple__tqJ79cmISx6IHad2jnF54pA;
typedef struct tyTuple__5pg9aIYdyrJM6GlDgyTDumg tyTuple__5pg9aIYdyrJM6GlDgyTDumg;
typedef struct tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA;
typedef struct tyTuple__0y4YQo9b9byJ83c0H89bBtdRw tyTuple__0y4YQo9b9byJ83c0H89bBtdRw;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
typedef struct tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA;
struct tyObject_Profiler__vPk6nUD8QeNW2bHH4WZfpw {
NF tEnter;
tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ* tos;
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw {
  RootObj Sup;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
};
typedef NU8 tyEnum_TEvalMode__iWSxkwmhTDY7fh9aYmp69akQ;
typedef NU8 tySet_tyEnum_TSandboxFlag__6jKj8dTCDIUGegA1P2RahA;
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg {
tySequence__E8pi9b5QNahsURYzXMjh3qw* data;
NI counter;
};
struct tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ {
  tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw Sup;
tySequence__YdLNCDKYeipzJx3I8Xw82Q* code;
tySequence__Gl8s23LA3EFz4kIlya9ameg* debug;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* globals;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constants;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* types;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* currentExceptionA;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* currentExceptionB;
NI exceptionInstr;
tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw* prc;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* callsite;
tyEnum_TEvalMode__iWSxkwmhTDY7fh9aYmp69akQ mode;
tySet_tyEnum_TSandboxFlag__6jKj8dTCDIUGegA1P2RahA features;
NIM_BOOL traceActive;
NI loopIterations;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw comesFromHeuristic;
tySequence__eJWcQvhuN2q0rM6THoByqQ* callbacks;
NimStringDesc* errorFlag;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph;
NI oldErrorCount;
tyObject_Profiler__vPk6nUD8QeNW2bHH4WZfpw profiler;
NI* templInstCounter;
tySequence__ztPIC2M9bqhs0KjYuE9c9cN8g* vmstateDiff;
tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg procToCodePos;
};
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg {
tyObject_Table__aP9cMXsPundL60Bltc8zw8Q* data;
};
struct tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc;
tySequence__qoz9b2fDIpsvVqgQYTLWcFA* slots;
tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ* next;
NI comesFrom;
tySequence__qwqHTkRvwhrRyENtudHQ7g* safePoints;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
struct tyObject_ProfileInfo__xU9aXXjWWQtDqNY2yZecQYw {
NF time;
NI count;
};
typedef NimStringDesc* tyArray__nHXaesL0DJZHyVS07ARPRA[1];
struct tyObject_Table__aP9cMXsPundL60Bltc8zw8Q {
tySequence__Ou09axLmOh3clXcvEh9agsPw* data;
NI counter;
};
struct tyTuple__tqJ79cmISx6IHad2jnF54pA {
NI Field0;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field1;
tyObject_ProfileInfo__xU9aXXjWWQtDqNY2yZecQYw Field2;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* args, void* ClE_0);
void* ClE_0;
} tyProc__vkuGXw0bPP9b9cpazTHQY9bqg;
struct tyTuple__5pg9aIYdyrJM6GlDgyTDumg {
NimStringDesc* Field0;
tyProc__vkuGXw0bPP9b9cpazTHQY9bqg Field1;
};
struct tyTuple__0y4YQo9b9byJ83c0H89bBtdRw {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field0;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field1;
};
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
typedef NU8 tyEnum_TRegisterKind__drcwtBjsw5cM6mbg9chBM9bg;
struct tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA {
tyEnum_TRegisterKind__drcwtBjsw5cM6mbg9chBM9bg kind;
union{
NI64 intVal;
NF floatVal;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* node;
tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA* regAddr;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** nodeAddr;
};
};
struct tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA {
NI ra;
NI rb;
NI rc;
tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA* slots;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* currentException;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw currentLineInfo;
};
struct tySequence__YdLNCDKYeipzJx3I8Xw82Q {
  TGenericSeq Sup;
  NU64 data[SEQ_DECL_SIZE];
};
struct tySequence__Gl8s23LA3EFz4kIlya9ameg {
  TGenericSeq Sup;
  tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
struct tySequence__eJWcQvhuN2q0rM6THoByqQ {
  TGenericSeq Sup;
  tyTuple__5pg9aIYdyrJM6GlDgyTDumg data[SEQ_DECL_SIZE];
};
struct tySequence__ztPIC2M9bqhs0KjYuE9c9cN8g {
  TGenericSeq Sup;
  tyTuple__0y4YQo9b9byJ83c0H89bBtdRw data[SEQ_DECL_SIZE];
};
struct tySequence__E8pi9b5QNahsURYzXMjh3qw {
  TGenericSeq Sup;
  tyTuple__47w2DboNEPf69aPgubZdd7Q data[SEQ_DECL_SIZE];
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
struct tySequence__qoz9b2fDIpsvVqgQYTLWcFA {
  TGenericSeq Sup;
  tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA data[SEQ_DECL_SIZE];
};
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  TGenericSeq Sup;
  NI data[SEQ_DECL_SIZE];
};
struct tySequence__Ou09axLmOh3clXcvEh9agsPw {
  TGenericSeq Sup;
  tyTuple__tqJ79cmISx6IHad2jnF54pA data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(NF, cpuTime__pureZtimes_3614)(void);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__vmprofiler_82)(tyObject_Table__aP9cMXsPundL60Bltc8zw8Q* t, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw key);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___vmprofiler_270)(tyObject_Table__aP9cMXsPundL60Bltc8zw8Q* t, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw key, tyObject_ProfileInfo__xU9aXXjWWQtDqNY2yZecQYw val);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
static N_INLINE(void, pluseq___pureZstrutils_2099)(NF* x, NF y);
N_LIB_PRIVATE N_NIMCALL(tyObject_ProfileInfo__xU9aXXjWWQtDqNY2yZecQYw*, X5BX5D___vmprofiler_428)(tyObject_Table__aP9cMXsPundL60Bltc8zw8Q* t, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw key);
N_LIB_PRIVATE N_NIMCALL(void, echoBinSafe)(NimStringDesc** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NI, len__vmprofiler_758)(tyObject_Table__aP9cMXsPundL60Bltc8zw8Q* t);
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_31)(NI hcode);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuAlignString)(NimStringDesc* s, NI count, NIM_CHAR padding);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___systemZdollars_3)(NI x);
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_629)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toMsgFilename__msgs_612)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_167)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(void, del__vmprofiler_1033)(tyObject_Table__aP9cMXsPundL60Bltc8zw8Q* t, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw key);
STRING_LITERAL(TM__Ai9anooT0gIYA9c9b30PXqgdQ_3, "\012prof:     \302\265s    #instr  location", 34);
static NIM_CONST tyArray__nHXaesL0DJZHyVS07ARPRA TM__Ai9anooT0gIYA9c9b30PXqgdQ_2 = {((NimStringDesc*) &TM__Ai9anooT0gIYA9c9b30PXqgdQ_3)}
;
STRING_LITERAL(TM__Ai9anooT0gIYA9c9b30PXqgdQ_4, "  ", 2);
STRING_LITERAL(TM__Ai9anooT0gIYA9c9b30PXqgdQ_5, "(", 1);
STRING_LITERAL(TM__Ai9anooT0gIYA9c9b30PXqgdQ_6, ", ", 2);
STRING_LITERAL(TM__Ai9anooT0gIYA9c9b30PXqgdQ_7, ")", 1);
STRING_LITERAL(TM__Ai9anooT0gIYA9c9b30PXqgdQ_8, "\012", 1);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(void, pluseq___pureZstrutils_2099)(NF* x, NF y) {
	(*x) = ((NF)((*x)) + (NF)(y));
}
N_LIB_PRIVATE N_NOINLINE(void, leaveImpl__vmprofiler_25)(tyObject_Profiler__vPk6nUD8QeNW2bHH4WZfpw* prof, tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ* c) {
	NF tLeave;
	tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ* tos;
	tyObject_Table__aP9cMXsPundL60Bltc8zw8Q* data;
	tLeave = cpuTime__pureZtimes_3614();
	tos = (*prof).tos;
	data = (*(*(*c).config).vmProfileData).data;
	{
		while (1) {
			if (!!((tos == ((tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ*) NIM_NIL)))) goto LA2;
			{
				tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw li;
				tyObject_ProfileInfo__xU9aXXjWWQtDqNY2yZecQYw* T13_;
				if (!!(((*tos).prc == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA5_;
				li = (*(*tos).prc).info;
				{
					NIM_BOOL T9_;
					tyObject_ProfileInfo__xU9aXXjWWQtDqNY2yZecQYw T12_;
					T9_ = (NIM_BOOL)0;
					T9_ = contains__vmprofiler_82(data, li);
					if (!!(T9_)) goto LA10_;
					nimZeroMem((void*)(&T12_), sizeof(tyObject_ProfileInfo__xU9aXXjWWQtDqNY2yZecQYw));
					X5BX5Deq___vmprofiler_270(data, li, T12_);
				}
				LA10_: ;
				T13_ = (tyObject_ProfileInfo__xU9aXXjWWQtDqNY2yZecQYw*)0;
				T13_ = X5BX5D___vmprofiler_428(data, li);
				pluseq___pureZstrutils_2099((&(*T13_).time), ((NF)(tLeave) - (NF)((*prof).tEnter)));
				{
					tyObject_ProfileInfo__xU9aXXjWWQtDqNY2yZecQYw* T18_;
					if (!(tos == (*prof).tos)) goto LA16_;
					T18_ = (tyObject_ProfileInfo__xU9aXXjWWQtDqNY2yZecQYw*)0;
					T18_ = X5BX5D___vmprofiler_428(data, li);
					(*T18_).count += ((NI) 1);
				}
				LA16_: ;
			}
			LA5_: ;
			tos = (*tos).next;
		} LA2: ;
	}
}
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_31)(NI hcode) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = !((hcode == ((NI) 0)));
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x) {
	addInt__stdZprivateZdigitsutils_167(result, ((NI64) (x)));
}
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_629)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = toMsgFilename__msgs_612(conf, info.fileIndex);
	result = resizeString(result, (T1_ ? T1_->Sup.len : 0) + 0);
appendString(result, T1_);
	{
		if (!(((NI) 0) < ((NI) (info.line)))) goto LA4_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__Ai9anooT0gIYA9c9b30PXqgdQ_5));
		addInt__stdZprivateZdigitsutils_189((&result), ((NI) (info.line)));
		{
			if (!(((NI) 0) < (NI)(((NI) (info.col)) + ((NI) 1)))) goto LA8_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__Ai9anooT0gIYA9c9b30PXqgdQ_6));
			addInt__stdZprivateZdigitsutils_189((&result), (NI)(((NI) (info.col)) + ((NI) 1)));
		}
		LA8_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__Ai9anooT0gIYA9c9b30PXqgdQ_7));
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dump__vmprofiler_697)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* pd) {
	NimStringDesc* result;
	tyObject_Table__aP9cMXsPundL60Bltc8zw8Q* data;
	result = NIM_NIL;
	data = (*pd).data;
	echoBinSafe(TM__Ai9anooT0gIYA9c9b30PXqgdQ_2, 1);
	{
		NI i;
		NI i_2;
		i = (NI)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				NF tMax;
				tyObject_ProfileInfo__xU9aXXjWWQtDqNY2yZecQYw infoMax;
				tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw flMax;
				NimStringDesc* T22_;
				NimStringDesc* T23_;
				NimStringDesc* T24_;
				NimStringDesc* T25_;
				NimStringDesc* T26_;
				NimStringDesc* T27_;
				if (!(i_2 < ((NI) 32))) goto LA3;
				i = i_2;
				tMax = (NF)0;
				nimZeroMem((void*)(&infoMax), sizeof(tyObject_ProfileInfo__xU9aXXjWWQtDqNY2yZecQYw));
				nimZeroMem((void*)(&flMax), sizeof(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw));
				{
					tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw fl;
					tyObject_ProfileInfo__xU9aXXjWWQtDqNY2yZecQYw info;
					NI L;
					nimZeroMem((void*)(&fl), sizeof(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw));
					nimZeroMem((void*)(&info), sizeof(tyObject_ProfileInfo__xU9aXXjWWQtDqNY2yZecQYw));
					L = len__vmprofiler_758(data);
					{
						NI h;
						NI colontmp_;
						NI T6_;
						NI res;
						h = (NI)0;
						colontmp_ = (NI)0;
						T6_ = (((*data).data ? (*data).data->Sup.len : 0)-1);
						colontmp_ = T6_;
						res = ((NI) 0);
						{
							while (1) {
								if (!(res <= colontmp_)) goto LA8;
								h = res;
								{
									NIM_BOOL T11_;
									T11_ = (NIM_BOOL)0;
									T11_ = isFilled__pureZcollectionsZtables_31((*data).data->data[h].Field0);
									if (!T11_) goto LA12_;
									fl = (*data).data->data[h].Field1;
									info = (*data).data->data[h].Field2;
									{
										if (!(infoMax.time < info.time)) goto LA16_;
										infoMax = info;
										flMax = fl;
									}
									LA16_: ;
								}
								LA12_: ;
								res += ((NI) 1);
							} LA8: ;
						}
					}
				}
				{
					if (!(infoMax.count == ((NI) 0))) goto LA20_;
					goto LA1;
				}
				LA20_: ;
				T22_ = NIM_NIL;
				T23_ = NIM_NIL;
				T23_ = dollar___systemZdollars_3(((NI) (((NF)(infoMax.time) * (NF)(1000000.0)))));
				T24_ = NIM_NIL;
				T24_ = nsuAlignString(T23_, ((NI) 10), 32);
				T25_ = NIM_NIL;
				T25_ = dollar___systemZdollars_3(infoMax.count);
				T26_ = NIM_NIL;
				T26_ = nsuAlignString(T25_, ((NI) 10), 32);
				T27_ = NIM_NIL;
				T27_ = toFileLineCol__msgs_629(conf, flMax);
				T22_ = rawNewString((T24_ ? T24_->Sup.len : 0) + (T26_ ? T26_->Sup.len : 0) + (T27_ ? T27_->Sup.len : 0) + 5);
appendString(T22_, ((NimStringDesc*) &TM__Ai9anooT0gIYA9c9b30PXqgdQ_4));
appendString(T22_, T24_);
appendString(T22_, T26_);
appendString(T22_, ((NimStringDesc*) &TM__Ai9anooT0gIYA9c9b30PXqgdQ_4));
appendString(T22_, T27_);
appendString(T22_, ((NimStringDesc*) &TM__Ai9anooT0gIYA9c9b30PXqgdQ_8));
				result = resizeString(result, (T22_ ? T22_->Sup.len : 0) + 0);
appendString(result, T22_);
				del__vmprofiler_1033(data, flMax);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	} LA1: ;
	return result;
}
