/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 32
#define NIM_EmulateOverflowChecks

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef NU8 tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA;
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInst;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg uniqueId;
};
typedef NU8 tyEnum_TDistinctCompare__UuPcvyG2RecjPyQDW4WlFw;
typedef NU8 tySet_tyEnum_TTypeCmpFlag__IRq9bqtrf9ctEUyeRMyvWy4Q;
typedef NU8 tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg[9];
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA, isPartOf__aliases_124)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* b);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(void, initPackedSet__pureZcollectionsZintsets_16)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA, isPartOfAux__aliases_13)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* b, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* marker);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__astalgo_402)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, compareTypes__types_2714)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* x, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* y, tyEnum_TDistinctCompare__UuPcvyG2RecjPyQDW4WlFw cmp, tySet_tyEnum_TTypeCmpFlag__IRq9bqtrf9ctEUyeRMyvWy4Q flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, skipTypes__ast_3723)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kinds);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA, isPartOfAux__aliases_17)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* b, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* marker);
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, lastSon__ast_4833)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, lastSon__ast_3731)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n);
static N_INLINE(NI, len__ast_3990)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA, isPartOf__aliases_129)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDeepConstExpr__trees_171)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL preventInheritance);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameValue__astalgo_119)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__070zgHAEsZhDDk2M26YTLA_2 = {
0x10, 0x09, 0xe0, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result) {
	initPackedSet__pureZcollectionsZintsets_16(Result);
}
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA, isPartOfAux__aliases_17)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* b, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* marker) {
	tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA result;
{	result = (tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA)0;
	result = ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 0);
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 138):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					result = isPartOfAux__aliases_17((*n)._kind_6.sons->data[i], b, marker);
					{
						if (!(result == ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 2))) goto LA7_;
						goto BeforeRet_;
					}
					LA7_: ;
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 139):
	{
		result = isPartOfAux__aliases_17((*n)._kind_6.sons->data[((NI) 0)], b, marker);
		{
			if (!(result == ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 2))) goto LA12_;
			goto BeforeRet_;
		}
		LA12_: ;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3155(n);
			i_4 = ((NI) 1);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA16;
					i_3 = i_4;
					switch ((*(*n)._kind_6.sons->data[i_3]).kind) {
					case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 85):
					case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 88):
					{
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T18_;
						T18_ = NIM_NIL;
						T18_ = lastSon__ast_4833((*n)._kind_6.sons->data[i_3]);
						result = isPartOfAux__aliases_17(T18_, b, marker);
						{
							if (!(result == ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 2))) goto LA21_;
							goto BeforeRet_;
						}
						LA21_: ;
					}
					break;
					default:
					{
					}
					break;
					}
					i_4 += ((NI) 1);
				} LA16: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		result = isPartOfAux__aliases_13((*(*n)._kind_4.sym).typ, b, marker);
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, len__ast_3990)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n).sons ? (*n).sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA, isPartOfAux__aliases_13)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* b, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* marker) {
	tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA result;
{	result = (tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA)0;
	result = ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 0);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (a == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = (b == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
		LA4_: ;
		if (!T3_) goto LA5_;
		goto BeforeRet_;
	}
	LA5_: ;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* xX60gensym7_;
		NIM_BOOL T9_;
		xX60gensym7_ = a;
		T9_ = (NIM_BOOL)0;
		T9_ = containsOrIncl__astalgo_402(marker, (NI)((NI)((NU32)(((NI) ((*xX60gensym7_).Sup.itemId.module))) << (NU32)(((NI) 20))) + ((NI) ((*xX60gensym7_).Sup.itemId.item))));
		if (!T9_) goto LA10_;
		goto BeforeRet_;
	}
	LA10_: ;
	{
		NIM_BOOL T14_;
		T14_ = (NIM_BOOL)0;
		T14_ = compareTypes__types_2714(a, b, ((tyEnum_TDistinctCompare__UuPcvyG2RecjPyQDW4WlFw) 1), 0);
		if (!T14_) goto LA15_;
		result = ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 2);
		goto BeforeRet_;
	}
	LA15_: ;
	switch ((*a).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17):
	{
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T22_;
			if (!!(((*a).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA20_;
			T22_ = NIM_NIL;
			T22_ = skipTypes__ast_3723((*a).sons->data[((NI) 0)], TM__070zgHAEsZhDDk2M26YTLA_2);
			result = isPartOfAux__aliases_13(T22_, b, marker);
		}
		LA20_: ;
		{
			if (!(result == ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 0))) goto LA25_;
			result = isPartOfAux__aliases_17((*a).n, b, marker);
		}
		LA25_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 13):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 4):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T28_;
		T28_ = NIM_NIL;
		T28_ = lastSon__ast_3731(a);
		result = isPartOfAux__aliases_13(T28_, b, marker);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 19):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3990(a);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA32;
					i = i_2;
					result = isPartOfAux__aliases_13((*a).sons->data[i], b, marker);
					{
						if (!(result == ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 2))) goto LA35_;
						goto BeforeRet_;
					}
					LA35_: ;
					i_2 += ((NI) 1);
				} LA32: ;
			}
		}
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA, isPartOf__aliases_124)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* b) {
	tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA result;
	tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw marker;
	result = (tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA)0;
	nimZeroMem((void*)(&marker), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
	initIntSet__pureZcollectionsZintsets_238((&marker));
	result = isPartOfAux__aliases_13(b, a, (&marker));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA, isPartOf__aliases_129)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b) {
	tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA result;
	result = (tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA)0;
	{
		if (!((*a).kind == (*b).kind)) goto LA3_;
		switch ((*a).kind) {
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
		{
			{
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym12_;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym13_;
				xX60gensym12_ = (*a)._kind_4.sym;
				xX60gensym13_ = (*b)._kind_4.sym;
				if (!((NI)((NI)((NU32)(((NI) ((*xX60gensym12_).Sup.itemId.module))) << (NU32)(((NI) 20))) + ((NI) ((*xX60gensym12_).Sup.itemId.item))) == (NI)((NI)((NU32)(((NI) ((*xX60gensym13_).Sup.itemId.module))) << (NU32)(((NI) 20))) + ((NI) ((*xX60gensym13_).Sup.itemId.item))))) goto LA8_;
				result = ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 2);
			}
			goto LA6_;
			LA8_: ;
			{
				NIM_BOOL T11_;
				T11_ = (NIM_BOOL)0;
				T11_ = ((12576 &((NU32)1<<((NU)((*(*a)._kind_4.sym).kind)&31U)))!=0);
				if (T11_) goto LA12_;
				T11_ = ((12576 &((NU32)1<<((NU)((*(*b)._kind_4.sym).kind)&31U)))!=0);
				LA12_: ;
				if (!T11_) goto LA13_;
				result = ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 0);
			}
			goto LA6_;
			LA13_: ;
			{
				{
					tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA T18_;
					T18_ = (tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA)0;
					T18_ = isPartOf__aliases_124((*(*a)._kind_4.sym).typ, (*(*b)._kind_4.sym).typ);
					if (!!((T18_ == ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 0)))) goto LA19_;
					result = ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 1);
				}
				LA19_: ;
			}
			LA6_: ;
		}
		break;
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42):
		{
			result = isPartOf__aliases_129((*a)._kind_6.sons->data[((NI) 0)], (*b)._kind_6.sons->data[((NI) 0)]);
			{
				NIM_BOOL T24_;
				NI T25_;
				NI T27_;
				T24_ = (NIM_BOOL)0;
				T25_ = (NI)0;
				T25_ = len__ast_3155(a);
				T24_ = (((NI) 2) <= T25_);
				if (!(T24_)) goto LA26_;
				T27_ = (NI)0;
				T27_ = len__ast_3155(b);
				T24_ = (((NI) 2) <= T27_);
				LA26_: ;
				if (!T24_) goto LA28_;
				{
					NIM_BOOL T32_;
					NIM_BOOL T33_;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* y;
					T32_ = (NIM_BOOL)0;
					T33_ = (NIM_BOOL)0;
					T33_ = (result == ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 2));
					if (!(T33_)) goto LA34_;
					T33_ = isDeepConstExpr__trees_171((*a)._kind_6.sons->data[((NI) 1)], NIM_FALSE);
					LA34_: ;
					T32_ = T33_;
					if (!(T32_)) goto LA35_;
					T32_ = isDeepConstExpr__trees_171((*b)._kind_6.sons->data[((NI) 1)], NIM_FALSE);
					LA35_: ;
					if (!T32_) goto LA36_;
					{
						if (!((*(*a)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58))) goto LA40_;
						x = (*(*a)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 1)];
					}
					goto LA38_;
					LA40_: ;
					{
						x = (*a)._kind_6.sons->data[((NI) 1)];
					}
					LA38_: ;
					{
						if (!((*(*b)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58))) goto LA45_;
						y = (*(*b)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 1)];
					}
					goto LA43_;
					LA45_: ;
					{
						y = (*b)._kind_6.sons->data[((NI) 1)];
					}
					LA43_: ;
					{
						NIM_BOOL T50_;
						T50_ = (NIM_BOOL)0;
						T50_ = sameValue__astalgo_119(x, y);
						if (!T50_) goto LA51_;
						result = ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 2);
					}
					goto LA48_;
					LA51_: ;
					{
						result = ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 0);
					}
					LA48_: ;
				}
				LA36_: ;
			}
			goto LA22_;
			LA28_: ;
			{
				{
					if (!!((result == ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 2)))) goto LA57_;
					{
						tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA T61_;
						T61_ = (tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA)0;
						T61_ = isPartOf__aliases_124((*a).typ, (*b).typ);
						if (!!((T61_ == ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 0)))) goto LA62_;
						result = ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 1);
					}
					LA62_: ;
				}
				LA57_: ;
			}
			LA22_: ;
		}
		break;
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45):
		{
			result = isPartOf__aliases_129((*a)._kind_6.sons->data[((NI) 0)], (*b)._kind_6.sons->data[((NI) 0)]);
			{
				if (!!((result == ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 0)))) goto LA67_;
				{
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym38_;
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym40_;
					xX60gensym38_ = (*(*a)._kind_6.sons->data[((NI) 1)])._kind_4.sym;
					xX60gensym40_ = (*(*b)._kind_6.sons->data[((NI) 1)])._kind_4.sym;
					if (!!(((NI)((NI)((NU32)(((NI) ((*xX60gensym38_).Sup.itemId.module))) << (NU32)(((NI) 20))) + ((NI) ((*xX60gensym38_).Sup.itemId.item))) == (NI)((NI)((NU32)(((NI) ((*xX60gensym40_).Sup.itemId.module))) << (NU32)(((NI) 20))) + ((NI) ((*xX60gensym40_).Sup.itemId.item)))))) goto LA71_;
					result = ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 0);
				}
				LA71_: ;
			}
			LA67_: ;
		}
		break;
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65):
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 47):
		{
			result = isPartOf__aliases_129((*a)._kind_6.sons->data[((NI) 0)], (*b)._kind_6.sons->data[((NI) 0)]);
			{
				if (!!((result == ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 2)))) goto LA76_;
				{
					tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA T80_;
					T80_ = (tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA)0;
					T80_ = isPartOf__aliases_124((*a).typ, (*b).typ);
					if (!!((T80_ == ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 0)))) goto LA81_;
					result = ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 1);
				}
				LA81_: ;
			}
			LA76_: ;
		}
		break;
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58):
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59):
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 60):
		{
			result = isPartOf__aliases_129((*a)._kind_6.sons->data[((NI) 1)], (*b)._kind_6.sons->data[((NI) 1)]);
		}
		break;
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 67):
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 66):
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 46):
		{
			result = isPartOf__aliases_129((*a)._kind_6.sons->data[((NI) 0)], (*b)._kind_6.sons->data[((NI) 0)]);
		}
		break;
		default:
		{
		}
		break;
		}
	}
	goto LA1_;
	LA3_: ;
	{
		switch ((*b).kind) {
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42):
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 46):
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64):
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 66) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 67):
		{
			result = isPartOf__aliases_129(a, (*b)._kind_6.sons->data[((NI) 0)]);
		}
		break;
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 47):
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65):
		{
			{
				tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA T91_;
				T91_ = (tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA)0;
				T91_ = isPartOf__aliases_124((*a).typ, (*b).typ);
				if (!!((T91_ == ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 0)))) goto LA92_;
				result = isPartOf__aliases_129(a, (*b)._kind_6.sons->data[((NI) 0)]);
				{
					if (!(result == ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 0))) goto LA96_;
					result = ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 1);
				}
				LA96_: ;
			}
			LA92_: ;
		}
		break;
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 60):
		{
			result = isPartOf__aliases_129(a, (*b)._kind_6.sons->data[((NI) 1)]);
		}
		break;
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
		{
			switch ((*a).kind) {
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 46):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 66) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 67):
			{
				result = isPartOf__aliases_129((*a)._kind_6.sons->data[((NI) 0)], b);
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 60):
			{
				result = isPartOf__aliases_129((*a)._kind_6.sons->data[((NI) 1)], b);
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 47):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65):
			{
				{
					tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA T105_;
					T105_ = (tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA)0;
					T105_ = isPartOf__aliases_124((*a).typ, (*b).typ);
					if (!!((T105_ == ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 0)))) goto LA106_;
					result = isPartOf__aliases_129((*a)._kind_6.sons->data[((NI) 0)], b);
					{
						if (!(result == ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 0))) goto LA110_;
						result = ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 1);
					}
					LA110_: ;
				}
				LA106_: ;
			}
			break;
			default:
			{
			}
			break;
			}
		}
		break;
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 38):
		{
			result = ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 0);
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_3155(b);
				i_2 = ((NI) 1);
				{
					while (1) {
						tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA res;
						if (!(i_2 < colontmp_)) goto LA116;
						i = i_2;
						res = isPartOf__aliases_129(a, (*(*b)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 1)]);
						{
							if (!!((res == ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 0)))) goto LA119_;
							result = res;
							{
								if (!(res == ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 2))) goto LA123_;
								goto LA114;
							}
							LA123_: ;
						}
						LA119_: ;
						i_2 += ((NI) 1);
					} LA116: ;
				}
			} LA114: ;
		}
		break;
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
		{
			result = ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 0);
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = len__ast_3155(b);
				i_4 = ((NI) 1);
				{
					while (1) {
						tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA res_2;
						if (!(i_4 < colontmp__2)) goto LA128;
						i_3 = i_4;
						res_2 = isPartOf__aliases_129(a, (*b)._kind_6.sons->data[i_3]);
						{
							if (!!((res_2 == ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 0)))) goto LA131_;
							result = res_2;
							{
								if (!(res_2 == ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 2))) goto LA135_;
								goto LA126;
							}
							LA135_: ;
						}
						LA131_: ;
						i_4 += ((NI) 1);
					} LA128: ;
				}
			} LA126: ;
		}
		break;
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41):
		{
			{
				NI T140_;
				T140_ = (NI)0;
				T140_ = len__ast_3155(b);
				if (!(((NI) 0) < T140_)) goto LA141_;
				result = isPartOf__aliases_129(a, (*b)._kind_6.sons->data[((NI) 0)]);
			}
			LA141_: ;
		}
		break;
		default:
		{
		}
		break;
		}
	}
	LA1_: ;
	return result;
}
