/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64
#define NIM_EmulateOverflowChecks

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU8 tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
N_LIB_PRIVATE N_NIMCALL(void, nstPut)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, NimStringDesc* key, NimStringDesc* val);
N_LIB_PRIVATE N_NIMCALL(void, del__pureZstrtabs_356)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(void, defineSymbol__condsyms_4)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols, NimStringDesc* symbol, NimStringDesc* value);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_2, "nimhygiene", 10);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_3, "true", 4);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_4, "niminheritable", 14);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_5, "nimmixin", 8);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_6, "nimeffects", 10);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_7, "nimbabel", 8);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_8, "nimcomputedgoto", 15);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_9, "nimunion", 8);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_10, "nimnewshared", 12);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_11, "nimNewTypedesc", 14);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_12, "nimrequiresnimframe", 19);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_13, "nimparsebiggestfloatmagic", 25);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_14, "nimalias", 8);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_15, "nimlocks", 8);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_16, "nimnode", 7);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_17, "nimvarargstyped", 15);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_18, "nimtypedescfixed", 16);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_19, "nimKnowsNimvm", 13);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_20, "nimArrIdx", 9);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_21, "nimHasalignOf", 13);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_22, "nimDistros", 10);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_23, "nimHasCppDefine", 15);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_24, "nimGenericInOutFlags", 20);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_25, "nimNoArrayToCstringConversion", 29);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_26, "nimHasRunnableExamples", 22);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_27, "nimNewDot", 9);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_28, "nimHasNilChecks", 15);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_29, "nimSymKind", 10);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_30, "nimVmEqIdent", 12);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_31, "nimNoNil", 8);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_32, "nimNoZeroTerminator", 19);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_33, "nimNotNil", 9);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_34, "nimVmExportFixed", 16);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_35, "nimHasSymOwnerInMacro", 21);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_36, "nimNewRuntime", 13);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_37, "nimIncrSeqV3", 12);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_38, "nimAshr", 7);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_39, "nimNoNilSeqs", 12);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_40, "nimNoNilSeqs2", 13);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_41, "nimHasUserErrors", 16);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_42, "nimUncheckedArrayTyp", 20);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_43, "nimHasTypeof", 12);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_44, "nimErrorProcCanHaveBody", 23);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_45, "nimHasInstantiationOfInMacro", 28);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_46, "nimHasHotCodeReloading", 22);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_47, "nimHasNilSeqs", 13);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_48, "nimHasSignatureHashInMacro", 26);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_49, "nimHasDefault", 13);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_50, "nimMacrosSizealignof", 20);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_51, "nimNoZeroExtendMagic", 20);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_52, "nimMacrosGetNodeId", 18);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_53, "nimHas", 6);
extern TNimType NTIfeature__T2jOg7rgtA4lKTKRASHfHw_;
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_54, "nimHasWarning", 13);
extern TNimType NTItmsgkind__J0cVyqzpFKvufCivtQUgHQ_;
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_55, "nimHasHint", 10);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_56, "nimFixedOwned", 13);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_57, "nimHasStyleChecks", 17);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_58, "nimToOpenArrayCString", 21);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_59, "nimHasUsed", 10);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_60, "nimFixedForwardGeneric", 22);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_61, "nimnomagic64", 12);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_62, "nimNewShiftOps", 14);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_63, "nimHasCursor", 12);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_64, "nimAlignPragma", 14);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_65, "nimHasExceptionsQuery", 21);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_66, "nimHasIsNamedTuple", 18);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_67, "nimHashOrdinalFixed", 19);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_68, "nimHasSinkInference", 19);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_69, "nimNewIntegerOps", 16);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_70, "nimHasInvariant", 15);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_71, "nimHasStacktraceMsgs", 20);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_72, "nimDoesntTrackDefects", 21);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_73, "nimHasLentIterators", 19);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_74, "nimHasDeclaredMagic", 19);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_75, "nimHasStacktracesModule", 23);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_76, "nimHasEffectTraitsModule", 24);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_77, "nimHasCastPragmaBlocks", 22);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_78, "nimHasDeclaredLocs", 18);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_79, "nimHasJsBigIntBackend", 21);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_80, "nimHasWarningAsError", 20);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_81, "nimHasHintAsError", 17);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_82, "nimHasSpellSuggest", 18);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_83, "nimHasCustomLiterals", 20);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_84, "nimHasUnifiedTuple", 18);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_85, "nimHasIterable", 14);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_86, "nimHasTypeofVoid", 16);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_87, "nimHasDragonBox", 15);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_88, "nimHasHintAll", 13);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_89, "nimHasTrace", 11);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_90, "nimHasEffectsOf", 15);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_91, "nimHasEnforceNoRaises", 21);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_92, "nimHasWarnBareExcept", 20);
STRING_LITERAL(TM__9cXbbi8LuWedlpH77PUxfew_93, "nimHasTopDownInference", 22);
N_LIB_PRIVATE N_NIMCALL(void, defineSymbol__condsyms_4)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols, NimStringDesc* symbol, NimStringDesc* value) {
	nstPut(symbols, symbol, value);
}
N_LIB_PRIVATE N_NIMCALL(void, undefSymbol__condsyms_8)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols, NimStringDesc* symbol) {
	del__pureZstrtabs_356(symbols, symbol);
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, initDefines__condsyms_18)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols) {
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_2), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_4), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_5), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_6), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_7), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_8), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_9), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_10), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_11), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_12), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_13), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_14), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_15), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_16), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_17), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_18), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_19), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_20), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_21), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_22), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_23), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_24), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_25), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_26), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_27), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_28), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_29), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_30), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_31), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_32), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_33), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_34), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_35), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_36), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_37), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_38), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_39), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_40), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_41), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_42), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_43), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_44), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_45), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_46), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_47), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_48), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_49), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_50), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_51), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_52), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	{
		tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw f;
		f = (tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw)0;
		{
			tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw v;
			NI res;
			v = (tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw)0;
			res = ((NI) 0);
			{
				while (1) {
					NimStringDesc* T5_;
					if (!(res <= ((NI) 18))) goto LA4;
					v = ((tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw) (res));
					f = v;
					T5_ = NIM_NIL;
					T5_ = rawNewString((reprEnum((NI)f, (&NTIfeature__T2jOg7rgtA4lKTKRASHfHw_)) ? reprEnum((NI)f, (&NTIfeature__T2jOg7rgtA4lKTKRASHfHw_))->Sup.len : 0) + 6);
appendString(T5_, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_53));
appendString(T5_, reprEnum((NI)f, (&NTIfeature__T2jOg7rgtA4lKTKRASHfHw_)));
					defineSymbol__condsyms_4(symbols, T5_, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
					res += ((NI) 1);
				} LA4: ;
			}
		}
	}
	{
		tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ s;
		NI res_2;
		s = (tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ)0;
		res_2 = ((NI) 17);
		{
			while (1) {
				NimStringDesc* T9_;
				if (!(res_2 <= ((NI) 71))) goto LA8;
				s = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) (res_2));
				T9_ = NIM_NIL;
				T9_ = rawNewString((reprEnum((NI)s, (&NTItmsgkind__J0cVyqzpFKvufCivtQUgHQ_)) ? reprEnum((NI)s, (&NTItmsgkind__J0cVyqzpFKvufCivtQUgHQ_))->Sup.len : 0) + 13);
appendString(T9_, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_54));
appendString(T9_, reprEnum((NI)s, (&NTItmsgkind__J0cVyqzpFKvufCivtQUgHQ_)));
				defineSymbol__condsyms_4(symbols, T9_, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
				res_2 += ((NI) 1);
			} LA8: ;
		}
	}
	{
		tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ s_2;
		NI res_3;
		s_2 = (tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ)0;
		res_3 = ((NI) 72);
		{
			while (1) {
				NimStringDesc* T13_;
				if (!(res_3 <= ((NI) 106))) goto LA12;
				s_2 = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) (res_3));
				T13_ = NIM_NIL;
				T13_ = rawNewString((reprEnum((NI)s_2, (&NTItmsgkind__J0cVyqzpFKvufCivtQUgHQ_)) ? reprEnum((NI)s_2, (&NTItmsgkind__J0cVyqzpFKvufCivtQUgHQ_))->Sup.len : 0) + 10);
appendString(T13_, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_55));
appendString(T13_, reprEnum((NI)s_2, (&NTItmsgkind__J0cVyqzpFKvufCivtQUgHQ_)));
				defineSymbol__condsyms_4(symbols, T13_, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
				res_3 += ((NI) 1);
			} LA12: ;
		}
	}
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_56), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_57), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_58), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_59), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_60), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_61), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_62), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_63), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_64), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_65), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_66), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_67), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_68), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_69), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_70), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_71), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_72), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_73), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_74), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_75), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_76), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_77), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_78), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_79), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_80), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_81), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_82), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_83), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_84), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_85), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_86), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_87), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_88), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_89), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_90), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_91), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_92), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
	defineSymbol__condsyms_4(symbols, ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_93), ((NimStringDesc*) &TM__9cXbbi8LuWedlpH77PUxfew_3));
}
