/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA;
typedef struct tyObject_BaseLexer__1ErHTvYSm67JCofXisRUnA tyObject_BaseLexer__1ErHTvYSm67JCofXisRUnA;
typedef struct RootObj RootObj;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg;
typedef struct tySequence__QAzA9aOtpCCvcxe8jjx2Rmw tySequence__QAzA9aOtpCCvcxe8jjx2Rmw;
typedef struct tyObject_JsonParsingError__NU6evZgl0moxP0OmxpI1zw tyObject_JsonParsingError__NU6evZgl0moxP0OmxpI1zw;
typedef struct tyObject_ValueError__5lcTdgqMq62cNGRwBb0thA tyObject_ValueError__5lcTdgqMq62cNGRwBb0thA;
typedef struct tyObject_CatchableError__8K3kdpxrBD9aI27J0kpSCpQ tyObject_CatchableError__8K3kdpxrBD9aI27J0kpSCpQ;
typedef struct Exception Exception;
typedef struct tySequence__QbmGqFaLnb1IWWToREeaIA tySequence__QbmGqFaLnb1IWWToREeaIA;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyObject_JsonKindError__AoNiOfrNmMaOu0Lc0TiKiQ tyObject_JsonKindError__AoNiOfrNmMaOu0Lc0TiKiQ;
typedef struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA;
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct RootObj {
TNimType* m_type;
};
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
struct tyObject_BaseLexer__1ErHTvYSm67JCofXisRUnA {
  RootObj Sup;
NI bufpos;
NimStringDesc* buf;
tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg* input;
NI lineNumber;
NI sentinel;
NI lineStart;
NI offsetBase;
tySet_tyChar__nmiMWKVIe46vacnhAFrQvw refillChars;
};
typedef NU8 tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg;
typedef NU8 tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg;
typedef NU8 tyEnum_JsonError__9bOLqlKJO6K9b1fxRo9bWfh3w;
struct tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA {
  tyObject_BaseLexer__1ErHTvYSm67JCofXisRUnA Sup;
NimStringDesc* a;
tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg tok;
tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg kind;
tyEnum_JsonError__9bOLqlKJO6K9b1fxRo9bWfh3w err;
tySequence__QAzA9aOtpCCvcxe8jjx2Rmw* state;
NimStringDesc* filename;
NIM_BOOL rawStringLiterals;
};
typedef NU8 tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw;
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__QbmGqFaLnb1IWWToREeaIA* trace;
Exception* up;
};
struct tyObject_CatchableError__8K3kdpxrBD9aI27J0kpSCpQ {
  Exception Sup;
};
struct tyObject_ValueError__5lcTdgqMq62cNGRwBb0thA {
  tyObject_CatchableError__8K3kdpxrBD9aI27J0kpSCpQ Sup;
};
struct tyObject_JsonParsingError__NU6evZgl0moxP0OmxpI1zw {
  tyObject_ValueError__5lcTdgqMq62cNGRwBb0thA Sup;
};
typedef NimStringDesc* tyArray__sMpvt1sOxOJ3LFGulnbeMQ[4];
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
struct tyObject_JsonKindError__AoNiOfrNmMaOu0Lc0TiKiQ {
  tyObject_ValueError__5lcTdgqMq62cNGRwBb0thA Sup;
};
typedef NimStringDesc* tyArray__MzuM2Of6Ritt5ckTQTXD6Q[14];
struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA {
NCSTRING procname;
NI line;
NCSTRING filename;
};
struct tySequence__QAzA9aOtpCCvcxe8jjx2Rmw {
  TGenericSeq Sup;
  tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw data[SEQ_DECL_SIZE];
};
struct tySequence__QbmGqFaLnb1IWWToREeaIA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA data[SEQ_DECL_SIZE];
};
static N_NIMCALL(void, Marker_tySequence__QAzA9aOtpCCvcxe8jjx2Rmw)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, open__pureZlexbase_122)(tyObject_BaseLexer__1ErHTvYSm67JCofXisRUnA* L, tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg* input, NI bufLen, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw refillChars);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(void*, newSeq)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg, getTok__pureZparsejson_416)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, setLengthStr)(NimStringDesc* s, NI newLen);
N_LIB_PRIVATE N_NIMCALL(void, skip__pureZparsejson_315)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my);
N_LIB_PRIVATE N_NIMCALL(NI, handleCR__pureZlexbase_79)(tyObject_BaseLexer__1ErHTvYSm67JCofXisRUnA* L, NI pos);
N_LIB_PRIVATE N_NIMCALL(NI, handleLF__pureZlexbase_90)(tyObject_BaseLexer__1ErHTvYSm67JCofXisRUnA* L, NI pos);
N_LIB_PRIVATE N_NIMCALL(void, parseNumber__pureZparsejson_346)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__pureZstrutils_1631)(NimStringDesc* s, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg, parseString__pureZparsejson_224)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my);
N_LIB_PRIVATE N_NIMCALL(NI, parseEscapedUTF16__pureZparsejson_211)(NCSTRING buf, NI* pos);
static N_INLINE(NIM_BOOL, handleHexChar__stdZprivateZdecode95helpers_1)(NIM_CHAR c, NI* x);
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nuctoUTF8)(NI32 c);
N_LIB_PRIVATE N_NIMCALL(void, parseName__pureZparsejson_401)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
static N_INLINE(tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw, pop__pureZparsejson_495)(tySequence__QAzA9aOtpCCvcxe8jjx2Rmw** s);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(void, next__pureZparsejson_447)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tyRef__LTVOROkmKLfX9b9aJ3xTF1yQ)(void* p, NI op);
N_LIB_PRIVATE N_NOINLINE(void*, newObj)(TNimType* typ, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, errorMsgExpected__pureZparsejson_207)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my, NimStringDesc* e);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___systemZdollars_3)(NI x);
static N_INLINE(NI, getLine__pureZparsejson_191)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my);
static N_INLINE(NI, getColumn__pureZparsejson_188)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my);
N_LIB_PRIVATE N_NIMCALL(NI, getColNumber__pureZlexbase_137)(tyObject_BaseLexer__1ErHTvYSm67JCofXisRUnA* L, NI pos);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5319)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5281)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5326)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5324)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5275)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(void, raiseExceptionEx)(Exception* e, NCSTRING ename, NCSTRING procname, NCSTRING filename, NI line);
static N_NIMCALL(void, Marker_tyRef__yYt4rn61ispQzTJd12bbFw)(void* p, NI op);
N_LIB_PRIVATE N_NOINLINE(void, raiseParseErr__pureZparsejson_571)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* p, NimStringDesc* msg) __attribute__((noreturn));
extern TNimType NTIbaselexer__1ErHTvYSm67JCofXisRUnA_;
N_LIB_PRIVATE TNimType NTIjsonparser__w6FDVeQ36QibBeDgwddDMA_;
extern TNimType NTIstring__77mFvmsOLKik79ci2hXkHEg_;
N_LIB_PRIVATE TNimType NTItokkind__C8Hu9bDXSJDTgDmOq9aRd9agg_;
N_LIB_PRIVATE TNimType NTIjsoneventkind__eElE9akd9bXwK3AkFXF85u9bg_;
N_LIB_PRIVATE TNimType NTIjsonerror__9bOLqlKJO6K9b1fxRo9bWfh3w_;
N_LIB_PRIVATE TNimType NTIparserstate__j5a0nuXg6IWyAxXC7BJVBw_;
N_LIB_PRIVATE TNimType NTIseqLparserstateT__QAzA9aOtpCCvcxe8jjx2Rmw_;
extern TNimType NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_;
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__nIinruGrC8EPIfjL3PuTvA_15 = {
0x00, 0x24, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_16, "0.", 2);
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__nIinruGrC8EPIfjL3PuTvA_17 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00,
0x20, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_18, "null", 4);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_19, "true", 4);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_20, "false", 5);
extern TNimType NTIvalueerror__5lcTdgqMq62cNGRwBb0thA_;
N_LIB_PRIVATE TNimType NTIjsonparsingerror__NU6evZgl0moxP0OmxpI1zw_;
N_LIB_PRIVATE TNimType NTIrefjsonparsingerror__LTVOROkmKLfX9b9aJ3xTF1yQ_;
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_21, "$1($2, $3) Error: $4", 20);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_22, " expected", 9);
N_LIB_PRIVATE TNimType NTIjsonkinderror__AoNiOfrNmMaOu0Lc0TiKiQ_;
N_LIB_PRIVATE TNimType NTIrefjsonkinderror__yYt4rn61ispQzTJd12bbFw_;
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_23, "invalid token", 13);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_24, "EOF", 3);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_25, "string literal", 14);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_26, "int literal", 11);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_27, "float literal", 13);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_28, "{", 1);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_29, "}", 1);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_30, "[", 1);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_31, "]", 1);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_32, ":", 1);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_33, ",", 1);
N_LIB_PRIVATE NIM_CONST tyArray__MzuM2Of6Ritt5ckTQTXD6Q tokToStr__pureZparsejson_78 = {((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_23),
((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_24),
((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_25),
((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_26),
((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_27),
((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_19),
((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_20),
((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_18),
((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_28),
((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_29),
((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_30),
((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_31),
((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_32),
((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_33)}
;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5228;
static N_NIMCALL(void, Marker_tySequence__QAzA9aOtpCCvcxe8jjx2Rmw)(void* p, NI op) {
	tySequence__QAzA9aOtpCCvcxe8jjx2Rmw* a;
	NI T1_;
	a = (tySequence__QAzA9aOtpCCvcxe8jjx2Rmw*)p;
	T1_ = (NI)0;
}
N_LIB_PRIVATE N_NIMCALL(void, open__pureZparsejson_97)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my, tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg* input, NimStringDesc* filename, NIM_BOOL rawStringLiterals) {
	open__pureZlexbase_122(&my->Sup, input, ((NI) 8192), TM__nIinruGrC8EPIfjL3PuTvA_15);
	unsureAsgnRef((void**) (&(*my).filename), copyString(filename));
	unsureAsgnRef((void**) (&(*my).state), (tySequence__QAzA9aOtpCCvcxe8jjx2Rmw*) newSeq((&NTIseqLparserstateT__QAzA9aOtpCCvcxe8jjx2Rmw_), 1));
	(*my).state->data[0] = ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 1);
	(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 0);
	unsureAsgnRef((void**) (&(*my).a), ((NimStringDesc*) NIM_NIL));
	(*my).rawStringLiterals = rawStringLiterals;
}
N_LIB_PRIVATE N_NIMCALL(void, skip__pureZparsejson_315)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my) {
	NI pos;
	pos = (*my).Sup.bufpos;
	{
		while (1) {
			switch (((NU8)((*my).Sup.buf->data[pos]))) {
			case 47:
			{
				{
					if (!((NU8)((*my).Sup.buf->data[(NI)(pos + ((NI) 1))]) == (NU8)(47))) goto LA6_;
					pos += ((NI) 2);
					{
						while (1) {
							switch (((NU8)((*my).Sup.buf->data[pos]))) {
							case 0:
							{
								goto LA8;
							}
							break;
							case 13:
							{
								pos = handleCR__pureZlexbase_79(&my->Sup, pos);
								goto LA8;
							}
							break;
							case 10:
							{
								pos = handleLF__pureZlexbase_90(&my->Sup, pos);
								goto LA8;
							}
							break;
							default:
							{
								pos += ((NI) 1);
							}
							break;
							}
						}
					} LA8: ;
				}
				goto LA4_;
				LA6_: ;
				{
					if (!((NU8)((*my).Sup.buf->data[(NI)(pos + ((NI) 1))]) == (NU8)(42))) goto LA15_;
					pos += ((NI) 2);
					{
						while (1) {
							switch (((NU8)((*my).Sup.buf->data[pos]))) {
							case 0:
							{
								(*my).err = ((tyEnum_JsonError__9bOLqlKJO6K9b1fxRo9bWfh3w) 8);
								goto LA17;
							}
							break;
							case 13:
							{
								pos = handleCR__pureZlexbase_79(&my->Sup, pos);
							}
							break;
							case 10:
							{
								pos = handleLF__pureZlexbase_90(&my->Sup, pos);
							}
							break;
							case 42:
							{
								pos += ((NI) 1);
								{
									if (!((NU8)((*my).Sup.buf->data[pos]) == (NU8)(47))) goto LA25_;
									pos += ((NI) 1);
									goto LA17;
								}
								LA25_: ;
							}
							break;
							default:
							{
								pos += ((NI) 1);
							}
							break;
							}
						}
					} LA17: ;
				}
				goto LA4_;
				LA15_: ;
				{
					goto LA1;
				}
				LA4_: ;
			}
			break;
			case 32:
			case 9:
			{
				pos += ((NI) 1);
			}
			break;
			case 13:
			{
				pos = handleCR__pureZlexbase_79(&my->Sup, pos);
			}
			break;
			case 10:
			{
				pos = handleLF__pureZlexbase_90(&my->Sup, pos);
			}
			break;
			default:
			{
				goto LA1;
			}
			break;
			}
		}
	} LA1: ;
	(*my).Sup.bufpos = pos;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, parseNumber__pureZparsejson_346)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my) {
	NI pos;
	pos = (*my).Sup.bufpos;
	{
		if (!((NU8)((*my).Sup.buf->data[pos]) == (NU8)(45))) goto LA3_;
		unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 45));
		pos += ((NI) 1);
	}
	LA3_: ;
	{
		if (!((NU8)((*my).Sup.buf->data[pos]) == (NU8)(46))) goto LA7_;
		unsureAsgnRef((void**) (&(*my).a), resizeString((*my).a, 2));
appendString((*my).a, ((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_16));
		pos += ((NI) 1);
	}
	goto LA5_;
	LA7_: ;
	{
		{
			while (1) {
				if (!(((NU8)((*my).Sup.buf->data[pos])) >= ((NU8)(48)) && ((NU8)((*my).Sup.buf->data[pos])) <= ((NU8)(57)))) goto LA11;
				unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, (*my).Sup.buf->data[pos]));
				pos += ((NI) 1);
			} LA11: ;
		}
		{
			if (!((NU8)((*my).Sup.buf->data[pos]) == (NU8)(46))) goto LA14_;
			unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 46));
			pos += ((NI) 1);
		}
		LA14_: ;
	}
	LA5_: ;
	{
		while (1) {
			if (!(((NU8)((*my).Sup.buf->data[pos])) >= ((NU8)(48)) && ((NU8)((*my).Sup.buf->data[pos])) <= ((NU8)(57)))) goto LA17;
			unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, (*my).Sup.buf->data[pos]));
			pos += ((NI) 1);
		} LA17: ;
	}
	{
		if (!(((NU8)((*my).Sup.buf->data[pos])) == ((NU8)(69)) || ((NU8)((*my).Sup.buf->data[pos])) == ((NU8)(101)))) goto LA20_;
		unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, (*my).Sup.buf->data[pos]));
		pos += ((NI) 1);
		{
			if (!(((NU8)((*my).Sup.buf->data[pos])) == ((NU8)(43)) || ((NU8)((*my).Sup.buf->data[pos])) == ((NU8)(45)))) goto LA24_;
			unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, (*my).Sup.buf->data[pos]));
			pos += ((NI) 1);
		}
		LA24_: ;
		{
			while (1) {
				if (!(((NU8)((*my).Sup.buf->data[pos])) >= ((NU8)(48)) && ((NU8)((*my).Sup.buf->data[pos])) <= ((NU8)(57)))) goto LA27;
				unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, (*my).Sup.buf->data[pos]));
				pos += ((NI) 1);
			} LA27: ;
		}
	}
	LA20_: ;
	(*my).Sup.bufpos = pos;
}
static N_INLINE(NIM_BOOL, handleHexChar__stdZprivateZdecode95helpers_1)(NIM_CHAR c, NI* x) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = NIM_TRUE;
	switch (((NU8)(c))) {
	case 48 ... 57:
	{
		(*x) = (NI)((NI)((NU64)((*x)) << (NU64)(((NI) 4))) | (NI)(((NU8)(c)) - ((NI) 48)));
	}
	break;
	case 97 ... 102:
	{
		(*x) = (NI)((NI)((NU64)((*x)) << (NU64)(((NI) 4))) | (NI)((NI)(((NU8)(c)) - ((NI) 97)) + ((NI) 10)));
	}
	break;
	case 65 ... 70:
	{
		(*x) = (NI)((NI)((NU64)((*x)) << (NU64)(((NI) 4))) | (NI)((NI)(((NU8)(c)) - ((NI) 65)) + ((NI) 10)));
	}
	break;
	default:
	{
		result = NIM_FALSE;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, parseEscapedUTF16__pureZparsejson_211)(NCSTRING buf, NI* pos) {
	NI result;
{	result = (NI)0;
	result = ((NI) 0);
	{
		NI _;
		NI res;
		_ = (NI)0;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= ((NI) 3))) goto LA3;
				_ = res;
				{
					NIM_BOOL T6_;
					T6_ = (NIM_BOOL)0;
					T6_ = handleHexChar__stdZprivateZdecode95helpers_1(buf[(*pos)], (&result));
					if (!T6_) goto LA7_;
					(*pos) += ((NI) 1);
				}
				goto LA4_;
				LA7_: ;
				{
					result = ((NI) -1);
					goto BeforeRet_;
				}
				LA4_: ;
				res += ((NI) 1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringDesc* s) {
	NCSTRING result;
	result = (NCSTRING)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (s == ((NimStringDesc*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = ((*s).Sup.len == ((NI) 0));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = "";
	}
	goto LA1_;
	LA5_: ;
	{
		result = ((NCSTRING) ((*s).data));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg, parseString__pureZparsejson_224)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my) {
	tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg result;
	NI pos;
	result = (tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg)0;
	result = ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 2);
	pos = (NI)((*my).Sup.bufpos + ((NI) 1));
	{
		if (!(*my).rawStringLiterals) goto LA3_;
		unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 34));
	}
	LA3_: ;
	{
		while (1) {
			switch (((NU8)((*my).Sup.buf->data[pos]))) {
			case 0:
			{
				(*my).err = ((tyEnum_JsonError__9bOLqlKJO6K9b1fxRo9bWfh3w) 7);
				result = ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 0);
				goto LA5;
			}
			break;
			case 34:
			{
				{
					if (!(*my).rawStringLiterals) goto LA11_;
					unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 34));
				}
				LA11_: ;
				pos += ((NI) 1);
				goto LA5;
			}
			break;
			case 92:
			{
				{
					if (!(*my).rawStringLiterals) goto LA16_;
					unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 92));
				}
				LA16_: ;
				switch (((NU8)((*my).Sup.buf->data[(NI)(pos + ((NI) 1))]))) {
				case 92:
				case 34:
				case 39:
				case 47:
				{
					unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, (*my).Sup.buf->data[(NI)(pos + ((NI) 1))]));
					pos += ((NI) 2);
				}
				break;
				case 98:
				{
					unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 8));
					pos += ((NI) 2);
				}
				break;
				case 102:
				{
					unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 12));
					pos += ((NI) 2);
				}
				break;
				case 110:
				{
					unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 10));
					pos += ((NI) 2);
				}
				break;
				case 114:
				{
					unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 13));
					pos += ((NI) 2);
				}
				break;
				case 116:
				{
					unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 9));
					pos += ((NI) 2);
				}
				break;
				case 118:
				{
					unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 11));
					pos += ((NI) 2);
				}
				break;
				case 117:
				{
					NI pos2;
					NI r;
					{
						if (!(*my).rawStringLiterals) goto LA28_;
						unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 117));
					}
					LA28_: ;
					pos += ((NI) 2);
					pos2 = pos;
					r = parseEscapedUTF16__pureZparsejson_211(nimToCStringConv((*my).Sup.buf), (&pos));
					{
						if (!(r < ((NI) 0))) goto LA32_;
						(*my).err = ((tyEnum_JsonError__9bOLqlKJO6K9b1fxRo9bWfh3w) 1);
						goto LA5;
					}
					LA32_: ;
					{
						NI s;
						if (!((NI)(r & ((NI) 64512)) == ((NI) 55296))) goto LA36_;
						{
							NIM_BOOL T40_;
							T40_ = (NIM_BOOL)0;
							T40_ = !(((NU8)((*my).Sup.buf->data[pos]) == (NU8)(92)));
							if (T40_) goto LA41_;
							T40_ = !(((NU8)((*my).Sup.buf->data[(NI)(pos + ((NI) 1))]) == (NU8)(117)));
							LA41_: ;
							if (!T40_) goto LA42_;
							(*my).err = ((tyEnum_JsonError__9bOLqlKJO6K9b1fxRo9bWfh3w) 1);
							goto LA5;
						}
						LA42_: ;
						pos += ((NI) 2);
						s = parseEscapedUTF16__pureZparsejson_211(nimToCStringConv((*my).Sup.buf), (&pos));
						{
							NIM_BOOL T46_;
							T46_ = (NIM_BOOL)0;
							T46_ = ((NI)(s & ((NI) 64512)) == ((NI) 56320));
							if (!(T46_)) goto LA47_;
							T46_ = (((NI) 0) < s);
							LA47_: ;
							if (!T46_) goto LA48_;
							r = (NI)(((NI) 65536) + (NI)((NI)((NU64)((NI)(r - ((NI) 55296))) << (NU64)(((NI) 10))) | (NI)(s - ((NI) 56320))));
						}
						goto LA44_;
						LA48_: ;
						{
							(*my).err = ((tyEnum_JsonError__9bOLqlKJO6K9b1fxRo9bWfh3w) 1);
							goto LA5;
						}
						LA44_: ;
					}
					LA36_: ;
					{
						NI length;
						if (!(*my).rawStringLiterals) goto LA53_;
						length = (NI)(pos - pos2);
						{
							NI i;
							NI res;
							i = (NI)0;
							res = ((NI) 1);
							{
								while (1) {
									if (!(res <= length)) goto LA57;
									i = res;
									{
										if (!(((NU8)((*my).Sup.buf->data[pos2])) >= ((NU8)(48)) && ((NU8)((*my).Sup.buf->data[pos2])) <= ((NU8)(57)) || ((NU8)((*my).Sup.buf->data[pos2])) >= ((NU8)(65)) && ((NU8)((*my).Sup.buf->data[pos2])) <= ((NU8)(70)) || ((NU8)((*my).Sup.buf->data[pos2])) >= ((NU8)(97)) && ((NU8)((*my).Sup.buf->data[pos2])) <= ((NU8)(102)))) goto LA60_;
										unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, (*my).Sup.buf->data[pos2]));
										pos2 += ((NI) 1);
									}
									goto LA58_;
									LA60_: ;
									{
										goto LA55;
									}
									LA58_: ;
									res += ((NI) 1);
								} LA57: ;
							}
						} LA55: ;
					}
					goto LA51_;
					LA53_: ;
					{
						NimStringDesc* T64_;
						T64_ = NIM_NIL;
						T64_ = nuctoUTF8(((NI32) (r)));
						unsureAsgnRef((void**) (&(*my).a), resizeString((*my).a, (T64_ ? T64_->Sup.len : 0) + 0));
appendString((*my).a, T64_);
					}
					LA51_: ;
				}
				break;
				default:
				{
					unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, (*my).Sup.buf->data[pos]));
					pos += ((NI) 1);
				}
				break;
				}
			}
			break;
			case 13:
			{
				pos = handleCR__pureZlexbase_79(&my->Sup, pos);
				unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 13));
			}
			break;
			case 10:
			{
				pos = handleLF__pureZlexbase_90(&my->Sup, pos);
				unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 10));
			}
			break;
			default:
			{
				unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, (*my).Sup.buf->data[pos]));
				pos += ((NI) 1);
			}
			break;
			}
		}
	} LA5: ;
	(*my).Sup.bufpos = pos;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, parseName__pureZparsejson_401)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my) {
	NI pos;
	pos = (*my).Sup.bufpos;
	{
		if (!(((NU8)((*my).Sup.buf->data[pos])) >= ((NU8)(97)) && ((NU8)((*my).Sup.buf->data[pos])) <= ((NU8)(122)) || ((NU8)((*my).Sup.buf->data[pos])) >= ((NU8)(65)) && ((NU8)((*my).Sup.buf->data[pos])) <= ((NU8)(90)) || ((NU8)((*my).Sup.buf->data[pos])) == ((NU8)(95)))) goto LA3_;
		{
			while (1) {
				if (!(((NU8)((*my).Sup.buf->data[pos])) >= ((NU8)(97)) && ((NU8)((*my).Sup.buf->data[pos])) <= ((NU8)(122)) || ((NU8)((*my).Sup.buf->data[pos])) >= ((NU8)(65)) && ((NU8)((*my).Sup.buf->data[pos])) <= ((NU8)(90)) || ((NU8)((*my).Sup.buf->data[pos])) >= ((NU8)(48)) && ((NU8)((*my).Sup.buf->data[pos])) <= ((NU8)(57)) || ((NU8)((*my).Sup.buf->data[pos])) == ((NU8)(95)))) goto LA6;
				unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, (*my).Sup.buf->data[pos]));
				pos += ((NI) 1);
			} LA6: ;
		}
	}
	LA3_: ;
	(*my).Sup.bufpos = pos;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg, getTok__pureZparsejson_416)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my) {
	tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg result;
	result = (tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg)0;
	unsureAsgnRef((void**) (&(*my).a), setLengthStr((*my).a, ((NI) 0)));
	skip__pureZparsejson_315(my);
	switch (((NU8)((*my).Sup.buf->data[(*my).Sup.bufpos]))) {
	case 45:
	case 46:
	case 48 ... 57:
	{
		parseNumber__pureZparsejson_346(my);
		{
			NIM_BOOL T4_;
			T4_ = (NIM_BOOL)0;
			T4_ = contains__pureZstrutils_1631((*my).a, TM__nIinruGrC8EPIfjL3PuTvA_17);
			if (!T4_) goto LA5_;
			result = ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 4);
		}
		goto LA2_;
		LA5_: ;
		{
			result = ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 3);
		}
		LA2_: ;
	}
	break;
	case 34:
	{
		result = parseString__pureZparsejson_224(my);
	}
	break;
	case 91:
	{
		(*my).Sup.bufpos += ((NI) 1);
		result = ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 10);
	}
	break;
	case 123:
	{
		(*my).Sup.bufpos += ((NI) 1);
		result = ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 8);
	}
	break;
	case 93:
	{
		(*my).Sup.bufpos += ((NI) 1);
		result = ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 11);
	}
	break;
	case 125:
	{
		(*my).Sup.bufpos += ((NI) 1);
		result = ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 9);
	}
	break;
	case 44:
	{
		(*my).Sup.bufpos += ((NI) 1);
		result = ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 13);
	}
	break;
	case 58:
	{
		(*my).Sup.bufpos += ((NI) 1);
		result = ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 12);
	}
	break;
	case 0:
	{
		result = ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 1);
	}
	break;
	case 97 ... 122:
	case 65 ... 90:
	case 95:
	{
		parseName__pureZparsejson_401(my);
		if (eqStrings((*my).a, ((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_18))) goto LA17_;
		if (eqStrings((*my).a, ((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_19))) goto LA18_;
		if (eqStrings((*my).a, ((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_20))) goto LA19_;
		goto LA20_;
		LA17_: ;
		{
			result = ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 7);
		}
		goto LA21_;
		LA18_: ;
		{
			result = ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 5);
		}
		goto LA21_;
		LA19_: ;
		{
			result = ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 6);
		}
		goto LA21_;
		LA20_: ;
		{
			result = ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 0);
		}
		LA21_: ;
	}
	break;
	default:
	{
		(*my).Sup.bufpos += ((NI) 1);
		result = ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 0);
	}
	break;
	}
	(*my).tok = result;
	return result;
}
static N_INLINE(tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw, pop__pureZparsejson_495)(tySequence__QAzA9aOtpCCvcxe8jjx2Rmw** s) {
	tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw result;
	NI L;
	NI T1_;
	result = (tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw)0;
	T1_ = ((*s) ? (*s)->Sup.len : 0);
	L = (NI)(T1_ - ((NI) 1));
	result = (*s)->data[L];
	unsureAsgnRef((void**) (&(*s)), (tySequence__QAzA9aOtpCCvcxe8jjx2Rmw*) setLengthSeqV2(((*s))?&((*s))->Sup:NIM_NIL, (&NTIseqLparserstateT__QAzA9aOtpCCvcxe8jjx2Rmw_), ((NI) (L))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, next__pureZparsejson_447)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my) {
	tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg tk;
	NI i;
	NI T1_;
	tk = getTok__pureZparsejson_416(my);
	T1_ = ((*my).state ? (*my).state->Sup.len : 0);
	i = (NI)(T1_ - ((NI) 1));
	switch ((*my).state->data[i]) {
	case ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 0):
	{
		{
			if (!(tk == ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 1))) goto LA5_;
			(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 1);
		}
		goto LA3_;
		LA5_: ;
		{
			(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 0);
			(*my).err = ((tyEnum_JsonError__9bOLqlKJO6K9b1fxRo9bWfh3w) 9);
		}
		LA3_: ;
	}
	break;
	case ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 1):
	{
		switch (tk) {
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 2):
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 3):
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 4):
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 5):
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 6):
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 7):
		{
			(*my).state->data[i] = ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 0);
			(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) (tk));
		}
		break;
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 10):
		{
			NI T11_;
			unsureAsgnRef((void**) (&(*my).state), (tySequence__QAzA9aOtpCCvcxe8jjx2Rmw*) incrSeqV3((TGenericSeq*)((*my).state), (&NTIseqLparserstateT__QAzA9aOtpCCvcxe8jjx2Rmw_)));
			T11_ = (*my).state->Sup.len++;
			(*my).state->data[T11_] = ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 3);
			(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 10);
		}
		break;
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 8):
		{
			NI T13_;
			unsureAsgnRef((void**) (&(*my).state), (tySequence__QAzA9aOtpCCvcxe8jjx2Rmw*) incrSeqV3((TGenericSeq*)((*my).state), (&NTIseqLparserstateT__QAzA9aOtpCCvcxe8jjx2Rmw_)));
			T13_ = (*my).state->Sup.len++;
			(*my).state->data[T13_] = ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 2);
			(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 8);
		}
		break;
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 1):
		{
			(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 1);
		}
		break;
		default:
		{
			(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 0);
			(*my).err = ((tyEnum_JsonError__9bOLqlKJO6K9b1fxRo9bWfh3w) 9);
		}
		break;
		}
	}
	break;
	case ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 2):
	{
		switch (tk) {
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 2):
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 3):
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 4):
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 5):
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 6):
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 7):
		{
			NI T18_;
			unsureAsgnRef((void**) (&(*my).state), (tySequence__QAzA9aOtpCCvcxe8jjx2Rmw*) incrSeqV3((TGenericSeq*)((*my).state), (&NTIseqLparserstateT__QAzA9aOtpCCvcxe8jjx2Rmw_)));
			T18_ = (*my).state->Sup.len++;
			(*my).state->data[T18_] = ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 6);
			(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) (tk));
		}
		break;
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 10):
		{
			NI T20_;
			NI T21_;
			unsureAsgnRef((void**) (&(*my).state), (tySequence__QAzA9aOtpCCvcxe8jjx2Rmw*) incrSeqV3((TGenericSeq*)((*my).state), (&NTIseqLparserstateT__QAzA9aOtpCCvcxe8jjx2Rmw_)));
			T20_ = (*my).state->Sup.len++;
			(*my).state->data[T20_] = ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 6);
			unsureAsgnRef((void**) (&(*my).state), (tySequence__QAzA9aOtpCCvcxe8jjx2Rmw*) incrSeqV3((TGenericSeq*)((*my).state), (&NTIseqLparserstateT__QAzA9aOtpCCvcxe8jjx2Rmw_)));
			T21_ = (*my).state->Sup.len++;
			(*my).state->data[T21_] = ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 3);
			(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 10);
		}
		break;
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 8):
		{
			NI T23_;
			NI T24_;
			unsureAsgnRef((void**) (&(*my).state), (tySequence__QAzA9aOtpCCvcxe8jjx2Rmw*) incrSeqV3((TGenericSeq*)((*my).state), (&NTIseqLparserstateT__QAzA9aOtpCCvcxe8jjx2Rmw_)));
			T23_ = (*my).state->Sup.len++;
			(*my).state->data[T23_] = ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 6);
			unsureAsgnRef((void**) (&(*my).state), (tySequence__QAzA9aOtpCCvcxe8jjx2Rmw*) incrSeqV3((TGenericSeq*)((*my).state), (&NTIseqLparserstateT__QAzA9aOtpCCvcxe8jjx2Rmw_)));
			T24_ = (*my).state->Sup.len++;
			(*my).state->data[T24_] = ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 2);
			(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 8);
		}
		break;
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 9):
		{
			tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw T26_;
			(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 9);
			T26_ = (tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw)0;
			T26_ = pop__pureZparsejson_495((&(*my).state));
			(void)(T26_);
		}
		break;
		default:
		{
			(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 0);
			(*my).err = ((tyEnum_JsonError__9bOLqlKJO6K9b1fxRo9bWfh3w) 6);
		}
		break;
		}
	}
	break;
	case ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 3):
	{
		switch (tk) {
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 2):
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 3):
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 4):
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 5):
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 6):
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 7):
		{
			NI T30_;
			unsureAsgnRef((void**) (&(*my).state), (tySequence__QAzA9aOtpCCvcxe8jjx2Rmw*) incrSeqV3((TGenericSeq*)((*my).state), (&NTIseqLparserstateT__QAzA9aOtpCCvcxe8jjx2Rmw_)));
			T30_ = (*my).state->Sup.len++;
			(*my).state->data[T30_] = ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 4);
			(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) (tk));
		}
		break;
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 10):
		{
			NI T32_;
			NI T33_;
			unsureAsgnRef((void**) (&(*my).state), (tySequence__QAzA9aOtpCCvcxe8jjx2Rmw*) incrSeqV3((TGenericSeq*)((*my).state), (&NTIseqLparserstateT__QAzA9aOtpCCvcxe8jjx2Rmw_)));
			T32_ = (*my).state->Sup.len++;
			(*my).state->data[T32_] = ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 4);
			unsureAsgnRef((void**) (&(*my).state), (tySequence__QAzA9aOtpCCvcxe8jjx2Rmw*) incrSeqV3((TGenericSeq*)((*my).state), (&NTIseqLparserstateT__QAzA9aOtpCCvcxe8jjx2Rmw_)));
			T33_ = (*my).state->Sup.len++;
			(*my).state->data[T33_] = ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 3);
			(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 10);
		}
		break;
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 8):
		{
			NI T35_;
			NI T36_;
			unsureAsgnRef((void**) (&(*my).state), (tySequence__QAzA9aOtpCCvcxe8jjx2Rmw*) incrSeqV3((TGenericSeq*)((*my).state), (&NTIseqLparserstateT__QAzA9aOtpCCvcxe8jjx2Rmw_)));
			T35_ = (*my).state->Sup.len++;
			(*my).state->data[T35_] = ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 4);
			unsureAsgnRef((void**) (&(*my).state), (tySequence__QAzA9aOtpCCvcxe8jjx2Rmw*) incrSeqV3((TGenericSeq*)((*my).state), (&NTIseqLparserstateT__QAzA9aOtpCCvcxe8jjx2Rmw_)));
			T36_ = (*my).state->Sup.len++;
			(*my).state->data[T36_] = ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 2);
			(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 8);
		}
		break;
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 11):
		{
			tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw T38_;
			(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 11);
			T38_ = (tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw)0;
			T38_ = pop__pureZparsejson_495((&(*my).state));
			(void)(T38_);
		}
		break;
		default:
		{
			(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 0);
			(*my).err = ((tyEnum_JsonError__9bOLqlKJO6K9b1fxRo9bWfh3w) 5);
		}
		break;
		}
	}
	break;
	case ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 4):
	{
		switch (tk) {
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 13):
		{
			tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw T42_;
			T42_ = (tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw)0;
			T42_ = pop__pureZparsejson_495((&(*my).state));
			(void)(T42_);
			next__pureZparsejson_447(my);
		}
		break;
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 11):
		{
			tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw T44_;
			tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw T45_;
			(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 11);
			T44_ = (tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw)0;
			T44_ = pop__pureZparsejson_495((&(*my).state));
			(void)(T44_);
			T45_ = (tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw)0;
			T45_ = pop__pureZparsejson_495((&(*my).state));
			(void)(T45_);
		}
		break;
		default:
		{
			(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 0);
			(*my).err = ((tyEnum_JsonError__9bOLqlKJO6K9b1fxRo9bWfh3w) 5);
		}
		break;
		}
	}
	break;
	case ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 5):
	{
		switch (tk) {
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 13):
		{
			tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw T49_;
			T49_ = (tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw)0;
			T49_ = pop__pureZparsejson_495((&(*my).state));
			(void)(T49_);
			next__pureZparsejson_447(my);
		}
		break;
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 9):
		{
			tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw T51_;
			tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw T52_;
			(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 9);
			T51_ = (tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw)0;
			T51_ = pop__pureZparsejson_495((&(*my).state));
			(void)(T51_);
			T52_ = (tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw)0;
			T52_ = pop__pureZparsejson_495((&(*my).state));
			(void)(T52_);
		}
		break;
		default:
		{
			(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 0);
			(*my).err = ((tyEnum_JsonError__9bOLqlKJO6K9b1fxRo9bWfh3w) 6);
		}
		break;
		}
	}
	break;
	case ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 6):
	{
		switch (tk) {
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 12):
		{
			(*my).state->data[i] = ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 7);
			next__pureZparsejson_447(my);
		}
		break;
		default:
		{
			(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 0);
			(*my).err = ((tyEnum_JsonError__9bOLqlKJO6K9b1fxRo9bWfh3w) 3);
		}
		break;
		}
	}
	break;
	case ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 7):
	{
		switch (tk) {
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 2):
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 3):
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 4):
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 5):
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 6):
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 7):
		{
			(*my).state->data[i] = ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 5);
			(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) (tk));
		}
		break;
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 10):
		{
			NI T60_;
			(*my).state->data[i] = ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 5);
			unsureAsgnRef((void**) (&(*my).state), (tySequence__QAzA9aOtpCCvcxe8jjx2Rmw*) incrSeqV3((TGenericSeq*)((*my).state), (&NTIseqLparserstateT__QAzA9aOtpCCvcxe8jjx2Rmw_)));
			T60_ = (*my).state->Sup.len++;
			(*my).state->data[T60_] = ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 3);
			(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 10);
		}
		break;
		case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 8):
		{
			NI T62_;
			(*my).state->data[i] = ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 5);
			unsureAsgnRef((void**) (&(*my).state), (tySequence__QAzA9aOtpCCvcxe8jjx2Rmw*) incrSeqV3((TGenericSeq*)((*my).state), (&NTIseqLparserstateT__QAzA9aOtpCCvcxe8jjx2Rmw_)));
			T62_ = (*my).state->Sup.len++;
			(*my).state->data[T62_] = ((tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw) 2);
			(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 8);
		}
		break;
		default:
		{
			(*my).kind = ((tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg) 0);
			(*my).err = ((tyEnum_JsonError__9bOLqlKJO6K9b1fxRo9bWfh3w) 10);
		}
		break;
		}
	}
	break;
	}
}
static N_NIMCALL(void, Marker_tyRef__LTVOROkmKLfX9b9aJ3xTF1yQ)(void* p, NI op) {
	tyObject_JsonParsingError__NU6evZgl0moxP0OmxpI1zw* a;
	a = (tyObject_JsonParsingError__NU6evZgl0moxP0OmxpI1zw*)p;
	nimGCvisit((void*)(*a).Sup.Sup.Sup.parent, op);
	nimGCvisit((void*)(*a).Sup.Sup.Sup.message, op);
	nimGCvisit((void*)(*a).Sup.Sup.Sup.trace, op);
	nimGCvisit((void*)(*a).Sup.Sup.Sup.up, op);
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(NI, getLine__pureZparsejson_191)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my) {
	NI result;
	result = (NI)0;
	result = (*my).Sup.lineNumber;
	return result;
}
static N_INLINE(NI, getColumn__pureZparsejson_188)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my) {
	NI result;
	result = (NI)0;
	result = getColNumber__pureZlexbase_137((&(*my).Sup), (*my).Sup.bufpos);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, errorMsgExpected__pureZparsejson_207)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my, NimStringDesc* e) {
	NimStringDesc* result;
	tyArray__sMpvt1sOxOJ3LFGulnbeMQ T1_;
	NI T2_;
	NI T3_;
	NimStringDesc* T4_;
	result = NIM_NIL;
	nimZeroMem((void*)T1_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
	T1_[0] = copyString((*my).filename);
	T2_ = (NI)0;
	T2_ = getLine__pureZparsejson_191(my);
	T1_[1] = dollar___systemZdollars_3(T2_);
	T3_ = (NI)0;
	T3_ = getColumn__pureZparsejson_188(my);
	T1_[2] = dollar___systemZdollars_3(T3_);
	T4_ = NIM_NIL;
	T4_ = rawNewString((e ? e->Sup.len : 0) + 9);
appendString(T4_, e);
appendString(T4_, ((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_22));
	T1_[3] = T4_;
	result = nsuFormatOpenArray(((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_21), T1_, 4);
	return result;
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5319)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5281)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5324)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5275((&gch__system_5228.zct), c);
}
static N_INLINE(void, decRef__system_5326)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5324(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5281(src);
		incRef__system_5319(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5281((*dest));
		decRef__system_5326(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NOINLINE(void, raiseParseErr__pureZparsejson_571)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* p, NimStringDesc* msg) {
	tyObject_JsonParsingError__NU6evZgl0moxP0OmxpI1zw* T1_;
	T1_ = NIM_NIL;
	T1_ = (tyObject_JsonParsingError__NU6evZgl0moxP0OmxpI1zw*) newObj((&NTIrefjsonparsingerror__LTVOROkmKLfX9b9aJ3xTF1yQ_), sizeof(tyObject_JsonParsingError__NU6evZgl0moxP0OmxpI1zw));
	(*T1_).Sup.Sup.Sup.Sup.m_type = (&NTIjsonparsingerror__NU6evZgl0moxP0OmxpI1zw_);
	(*T1_).Sup.Sup.Sup.name = "JsonParsingError";
	asgnRef((void**) (&(*T1_).Sup.Sup.Sup.message), errorMsgExpected__pureZparsejson_207(p, msg));
	asgnRef((void**) (&(*T1_).Sup.Sup.Sup.parent), ((Exception*) NIM_NIL));
	raiseExceptionEx((Exception*)T1_, "JsonParsingError", "raiseParseErr", "parsejson.nim", 515);
}
static N_NIMCALL(void, Marker_tyRef__yYt4rn61ispQzTJd12bbFw)(void* p, NI op) {
	tyObject_JsonKindError__AoNiOfrNmMaOu0Lc0TiKiQ* a;
	a = (tyObject_JsonKindError__AoNiOfrNmMaOu0Lc0TiKiQ*)p;
	nimGCvisit((void*)(*a).Sup.Sup.Sup.parent, op);
	nimGCvisit((void*)(*a).Sup.Sup.Sup.message, op);
	nimGCvisit((void*)(*a).Sup.Sup.Sup.trace, op);
	nimGCvisit((void*)(*a).Sup.Sup.Sup.up, op);
}
N_LIB_PRIVATE N_NIMCALL(void, eat__pureZparsejson_593)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* p, tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg tok) {
	{
		tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg T5_;
		if (!((*p).tok == tok)) goto LA3_;
		T5_ = (tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg)0;
		T5_ = getTok__pureZparsejson_416(p);
		(void)(T5_);
	}
	goto LA1_;
	LA3_: ;
	{
		raiseParseErr__pureZparsejson_571((&(*p)), tokToStr__pureZparsejson_78[(tok)- 0]);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, atmdotdotatslibatspureatsparsejsondotnim_DatInit000)(void) {
static TNimNode* TM__nIinruGrC8EPIfjL3PuTvA_2_7[7];
static TNimNode* TM__nIinruGrC8EPIfjL3PuTvA_3_14[14];
NI TM__nIinruGrC8EPIfjL3PuTvA_5;
static char* NIM_CONST TM__nIinruGrC8EPIfjL3PuTvA_4[14] = {
"tkError", 
"tkEof", 
"tkString", 
"tkInt", 
"tkFloat", 
"tkTrue", 
"tkFalse", 
"tkNull", 
"tkCurlyLe", 
"tkCurlyRi", 
"tkBracketLe", 
"tkBracketRi", 
"tkColon", 
"tkComma"};
static TNimNode* TM__nIinruGrC8EPIfjL3PuTvA_6_12[12];
NI TM__nIinruGrC8EPIfjL3PuTvA_8;
static char* NIM_CONST TM__nIinruGrC8EPIfjL3PuTvA_7[12] = {
"jsonError", 
"jsonEof", 
"jsonString", 
"jsonInt", 
"jsonFloat", 
"jsonTrue", 
"jsonFalse", 
"jsonNull", 
"jsonObjectStart", 
"jsonObjectEnd", 
"jsonArrayStart", 
"jsonArrayEnd"};
static TNimNode* TM__nIinruGrC8EPIfjL3PuTvA_9_11[11];
NI TM__nIinruGrC8EPIfjL3PuTvA_11;
static char* NIM_CONST TM__nIinruGrC8EPIfjL3PuTvA_10[11] = {
"errNone", 
"errInvalidToken", 
"errStringExpected", 
"errColonExpected", 
"errCommaExpected", 
"errBracketRiExpected", 
"errCurlyRiExpected", 
"errQuoteExpected", 
"errEOC_Expected", 
"errEofExpected", 
"errExprExpected"};
static TNimNode* TM__nIinruGrC8EPIfjL3PuTvA_12_8[8];
NI TM__nIinruGrC8EPIfjL3PuTvA_14;
static char* NIM_CONST TM__nIinruGrC8EPIfjL3PuTvA_13[8] = {
"stateEof", 
"stateStart", 
"stateObject", 
"stateArray", 
"stateExpectArrayComma", 
"stateExpectObjectComma", 
"stateExpectColon", 
"stateExpectValue"};
static TNimNode TM__nIinruGrC8EPIfjL3PuTvA_0[59];
NTIjsonparser__w6FDVeQ36QibBeDgwddDMA_.size = sizeof(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA);
NTIjsonparser__w6FDVeQ36QibBeDgwddDMA_.align = NIM_ALIGNOF(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA);
NTIjsonparser__w6FDVeQ36QibBeDgwddDMA_.kind = 17;
NTIjsonparser__w6FDVeQ36QibBeDgwddDMA_.base = (&NTIbaselexer__1ErHTvYSm67JCofXisRUnA_);
TM__nIinruGrC8EPIfjL3PuTvA_2_7[0] = &TM__nIinruGrC8EPIfjL3PuTvA_0[1];
TM__nIinruGrC8EPIfjL3PuTvA_0[1].kind = 1;
TM__nIinruGrC8EPIfjL3PuTvA_0[1].offset = offsetof(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA, a);
TM__nIinruGrC8EPIfjL3PuTvA_0[1].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__nIinruGrC8EPIfjL3PuTvA_0[1].name = "a";
TM__nIinruGrC8EPIfjL3PuTvA_2_7[1] = &TM__nIinruGrC8EPIfjL3PuTvA_0[2];
NTItokkind__C8Hu9bDXSJDTgDmOq9aRd9agg_.size = sizeof(tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg);
NTItokkind__C8Hu9bDXSJDTgDmOq9aRd9agg_.align = NIM_ALIGNOF(tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg);
NTItokkind__C8Hu9bDXSJDTgDmOq9aRd9agg_.kind = 14;
NTItokkind__C8Hu9bDXSJDTgDmOq9aRd9agg_.base = 0;
NTItokkind__C8Hu9bDXSJDTgDmOq9aRd9agg_.flags = 3;
for (TM__nIinruGrC8EPIfjL3PuTvA_5 = 0; TM__nIinruGrC8EPIfjL3PuTvA_5 < 14; TM__nIinruGrC8EPIfjL3PuTvA_5++) {
TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_5+3].kind = 1;
TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_5+3].offset = TM__nIinruGrC8EPIfjL3PuTvA_5;
TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_5+3].name = TM__nIinruGrC8EPIfjL3PuTvA_4[TM__nIinruGrC8EPIfjL3PuTvA_5];
TM__nIinruGrC8EPIfjL3PuTvA_3_14[TM__nIinruGrC8EPIfjL3PuTvA_5] = &TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_5+3];
}
TM__nIinruGrC8EPIfjL3PuTvA_0[17].len = 14; TM__nIinruGrC8EPIfjL3PuTvA_0[17].kind = 2; TM__nIinruGrC8EPIfjL3PuTvA_0[17].sons = &TM__nIinruGrC8EPIfjL3PuTvA_3_14[0];
NTItokkind__C8Hu9bDXSJDTgDmOq9aRd9agg_.node = &TM__nIinruGrC8EPIfjL3PuTvA_0[17];
TM__nIinruGrC8EPIfjL3PuTvA_0[2].kind = 1;
TM__nIinruGrC8EPIfjL3PuTvA_0[2].offset = offsetof(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA, tok);
TM__nIinruGrC8EPIfjL3PuTvA_0[2].typ = (&NTItokkind__C8Hu9bDXSJDTgDmOq9aRd9agg_);
TM__nIinruGrC8EPIfjL3PuTvA_0[2].name = "tok";
TM__nIinruGrC8EPIfjL3PuTvA_2_7[2] = &TM__nIinruGrC8EPIfjL3PuTvA_0[18];
NTIjsoneventkind__eElE9akd9bXwK3AkFXF85u9bg_.size = sizeof(tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg);
NTIjsoneventkind__eElE9akd9bXwK3AkFXF85u9bg_.align = NIM_ALIGNOF(tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg);
NTIjsoneventkind__eElE9akd9bXwK3AkFXF85u9bg_.kind = 14;
NTIjsoneventkind__eElE9akd9bXwK3AkFXF85u9bg_.base = 0;
NTIjsoneventkind__eElE9akd9bXwK3AkFXF85u9bg_.flags = 3;
for (TM__nIinruGrC8EPIfjL3PuTvA_8 = 0; TM__nIinruGrC8EPIfjL3PuTvA_8 < 12; TM__nIinruGrC8EPIfjL3PuTvA_8++) {
TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_8+19].kind = 1;
TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_8+19].offset = TM__nIinruGrC8EPIfjL3PuTvA_8;
TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_8+19].name = TM__nIinruGrC8EPIfjL3PuTvA_7[TM__nIinruGrC8EPIfjL3PuTvA_8];
TM__nIinruGrC8EPIfjL3PuTvA_6_12[TM__nIinruGrC8EPIfjL3PuTvA_8] = &TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_8+19];
}
TM__nIinruGrC8EPIfjL3PuTvA_0[31].len = 12; TM__nIinruGrC8EPIfjL3PuTvA_0[31].kind = 2; TM__nIinruGrC8EPIfjL3PuTvA_0[31].sons = &TM__nIinruGrC8EPIfjL3PuTvA_6_12[0];
NTIjsoneventkind__eElE9akd9bXwK3AkFXF85u9bg_.node = &TM__nIinruGrC8EPIfjL3PuTvA_0[31];
TM__nIinruGrC8EPIfjL3PuTvA_0[18].kind = 1;
TM__nIinruGrC8EPIfjL3PuTvA_0[18].offset = offsetof(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA, kind);
TM__nIinruGrC8EPIfjL3PuTvA_0[18].typ = (&NTIjsoneventkind__eElE9akd9bXwK3AkFXF85u9bg_);
TM__nIinruGrC8EPIfjL3PuTvA_0[18].name = "kind";
TM__nIinruGrC8EPIfjL3PuTvA_2_7[3] = &TM__nIinruGrC8EPIfjL3PuTvA_0[32];
NTIjsonerror__9bOLqlKJO6K9b1fxRo9bWfh3w_.size = sizeof(tyEnum_JsonError__9bOLqlKJO6K9b1fxRo9bWfh3w);
NTIjsonerror__9bOLqlKJO6K9b1fxRo9bWfh3w_.align = NIM_ALIGNOF(tyEnum_JsonError__9bOLqlKJO6K9b1fxRo9bWfh3w);
NTIjsonerror__9bOLqlKJO6K9b1fxRo9bWfh3w_.kind = 14;
NTIjsonerror__9bOLqlKJO6K9b1fxRo9bWfh3w_.base = 0;
NTIjsonerror__9bOLqlKJO6K9b1fxRo9bWfh3w_.flags = 3;
for (TM__nIinruGrC8EPIfjL3PuTvA_11 = 0; TM__nIinruGrC8EPIfjL3PuTvA_11 < 11; TM__nIinruGrC8EPIfjL3PuTvA_11++) {
TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_11+33].kind = 1;
TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_11+33].offset = TM__nIinruGrC8EPIfjL3PuTvA_11;
TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_11+33].name = TM__nIinruGrC8EPIfjL3PuTvA_10[TM__nIinruGrC8EPIfjL3PuTvA_11];
TM__nIinruGrC8EPIfjL3PuTvA_9_11[TM__nIinruGrC8EPIfjL3PuTvA_11] = &TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_11+33];
}
TM__nIinruGrC8EPIfjL3PuTvA_0[44].len = 11; TM__nIinruGrC8EPIfjL3PuTvA_0[44].kind = 2; TM__nIinruGrC8EPIfjL3PuTvA_0[44].sons = &TM__nIinruGrC8EPIfjL3PuTvA_9_11[0];
NTIjsonerror__9bOLqlKJO6K9b1fxRo9bWfh3w_.node = &TM__nIinruGrC8EPIfjL3PuTvA_0[44];
TM__nIinruGrC8EPIfjL3PuTvA_0[32].kind = 1;
TM__nIinruGrC8EPIfjL3PuTvA_0[32].offset = offsetof(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA, err);
TM__nIinruGrC8EPIfjL3PuTvA_0[32].typ = (&NTIjsonerror__9bOLqlKJO6K9b1fxRo9bWfh3w_);
TM__nIinruGrC8EPIfjL3PuTvA_0[32].name = "err";
TM__nIinruGrC8EPIfjL3PuTvA_2_7[4] = &TM__nIinruGrC8EPIfjL3PuTvA_0[45];
NTIparserstate__j5a0nuXg6IWyAxXC7BJVBw_.size = sizeof(tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw);
NTIparserstate__j5a0nuXg6IWyAxXC7BJVBw_.align = NIM_ALIGNOF(tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw);
NTIparserstate__j5a0nuXg6IWyAxXC7BJVBw_.kind = 14;
NTIparserstate__j5a0nuXg6IWyAxXC7BJVBw_.base = 0;
NTIparserstate__j5a0nuXg6IWyAxXC7BJVBw_.flags = 3;
for (TM__nIinruGrC8EPIfjL3PuTvA_14 = 0; TM__nIinruGrC8EPIfjL3PuTvA_14 < 8; TM__nIinruGrC8EPIfjL3PuTvA_14++) {
TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_14+46].kind = 1;
TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_14+46].offset = TM__nIinruGrC8EPIfjL3PuTvA_14;
TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_14+46].name = TM__nIinruGrC8EPIfjL3PuTvA_13[TM__nIinruGrC8EPIfjL3PuTvA_14];
TM__nIinruGrC8EPIfjL3PuTvA_12_8[TM__nIinruGrC8EPIfjL3PuTvA_14] = &TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_14+46];
}
TM__nIinruGrC8EPIfjL3PuTvA_0[54].len = 8; TM__nIinruGrC8EPIfjL3PuTvA_0[54].kind = 2; TM__nIinruGrC8EPIfjL3PuTvA_0[54].sons = &TM__nIinruGrC8EPIfjL3PuTvA_12_8[0];
NTIparserstate__j5a0nuXg6IWyAxXC7BJVBw_.node = &TM__nIinruGrC8EPIfjL3PuTvA_0[54];
NTIseqLparserstateT__QAzA9aOtpCCvcxe8jjx2Rmw_.size = sizeof(tySequence__QAzA9aOtpCCvcxe8jjx2Rmw*);
NTIseqLparserstateT__QAzA9aOtpCCvcxe8jjx2Rmw_.align = NIM_ALIGNOF(tySequence__QAzA9aOtpCCvcxe8jjx2Rmw*);
NTIseqLparserstateT__QAzA9aOtpCCvcxe8jjx2Rmw_.kind = 24;
NTIseqLparserstateT__QAzA9aOtpCCvcxe8jjx2Rmw_.base = (&NTIparserstate__j5a0nuXg6IWyAxXC7BJVBw_);
NTIseqLparserstateT__QAzA9aOtpCCvcxe8jjx2Rmw_.flags = 2;
NTIseqLparserstateT__QAzA9aOtpCCvcxe8jjx2Rmw_.marker = Marker_tySequence__QAzA9aOtpCCvcxe8jjx2Rmw;
TM__nIinruGrC8EPIfjL3PuTvA_0[45].kind = 1;
TM__nIinruGrC8EPIfjL3PuTvA_0[45].offset = offsetof(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA, state);
TM__nIinruGrC8EPIfjL3PuTvA_0[45].typ = (&NTIseqLparserstateT__QAzA9aOtpCCvcxe8jjx2Rmw_);
TM__nIinruGrC8EPIfjL3PuTvA_0[45].name = "state";
TM__nIinruGrC8EPIfjL3PuTvA_2_7[5] = &TM__nIinruGrC8EPIfjL3PuTvA_0[55];
TM__nIinruGrC8EPIfjL3PuTvA_0[55].kind = 1;
TM__nIinruGrC8EPIfjL3PuTvA_0[55].offset = offsetof(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA, filename);
TM__nIinruGrC8EPIfjL3PuTvA_0[55].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__nIinruGrC8EPIfjL3PuTvA_0[55].name = "filename";
TM__nIinruGrC8EPIfjL3PuTvA_2_7[6] = &TM__nIinruGrC8EPIfjL3PuTvA_0[56];
TM__nIinruGrC8EPIfjL3PuTvA_0[56].kind = 1;
TM__nIinruGrC8EPIfjL3PuTvA_0[56].offset = offsetof(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA, rawStringLiterals);
TM__nIinruGrC8EPIfjL3PuTvA_0[56].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__nIinruGrC8EPIfjL3PuTvA_0[56].name = "rawStringLiterals";
TM__nIinruGrC8EPIfjL3PuTvA_0[0].len = 7; TM__nIinruGrC8EPIfjL3PuTvA_0[0].kind = 2; TM__nIinruGrC8EPIfjL3PuTvA_0[0].sons = &TM__nIinruGrC8EPIfjL3PuTvA_2_7[0];
NTIjsonparser__w6FDVeQ36QibBeDgwddDMA_.node = &TM__nIinruGrC8EPIfjL3PuTvA_0[0];
NTIjsonparsingerror__NU6evZgl0moxP0OmxpI1zw_.size = sizeof(tyObject_JsonParsingError__NU6evZgl0moxP0OmxpI1zw);
NTIjsonparsingerror__NU6evZgl0moxP0OmxpI1zw_.align = NIM_ALIGNOF(tyObject_JsonParsingError__NU6evZgl0moxP0OmxpI1zw);
NTIjsonparsingerror__NU6evZgl0moxP0OmxpI1zw_.kind = 17;
NTIjsonparsingerror__NU6evZgl0moxP0OmxpI1zw_.base = (&NTIvalueerror__5lcTdgqMq62cNGRwBb0thA_);
TM__nIinruGrC8EPIfjL3PuTvA_0[57].len = 0; TM__nIinruGrC8EPIfjL3PuTvA_0[57].kind = 2;
NTIjsonparsingerror__NU6evZgl0moxP0OmxpI1zw_.node = &TM__nIinruGrC8EPIfjL3PuTvA_0[57];
NTIrefjsonparsingerror__LTVOROkmKLfX9b9aJ3xTF1yQ_.size = sizeof(tyObject_JsonParsingError__NU6evZgl0moxP0OmxpI1zw*);
NTIrefjsonparsingerror__LTVOROkmKLfX9b9aJ3xTF1yQ_.align = NIM_ALIGNOF(tyObject_JsonParsingError__NU6evZgl0moxP0OmxpI1zw*);
NTIrefjsonparsingerror__LTVOROkmKLfX9b9aJ3xTF1yQ_.kind = 22;
NTIrefjsonparsingerror__LTVOROkmKLfX9b9aJ3xTF1yQ_.base = (&NTIjsonparsingerror__NU6evZgl0moxP0OmxpI1zw_);
NTIrefjsonparsingerror__LTVOROkmKLfX9b9aJ3xTF1yQ_.marker = Marker_tyRef__LTVOROkmKLfX9b9aJ3xTF1yQ;
NTIjsonkinderror__AoNiOfrNmMaOu0Lc0TiKiQ_.size = sizeof(tyObject_JsonKindError__AoNiOfrNmMaOu0Lc0TiKiQ);
NTIjsonkinderror__AoNiOfrNmMaOu0Lc0TiKiQ_.align = NIM_ALIGNOF(tyObject_JsonKindError__AoNiOfrNmMaOu0Lc0TiKiQ);
NTIjsonkinderror__AoNiOfrNmMaOu0Lc0TiKiQ_.kind = 17;
NTIjsonkinderror__AoNiOfrNmMaOu0Lc0TiKiQ_.base = (&NTIvalueerror__5lcTdgqMq62cNGRwBb0thA_);
TM__nIinruGrC8EPIfjL3PuTvA_0[58].len = 0; TM__nIinruGrC8EPIfjL3PuTvA_0[58].kind = 2;
NTIjsonkinderror__AoNiOfrNmMaOu0Lc0TiKiQ_.node = &TM__nIinruGrC8EPIfjL3PuTvA_0[58];
NTIrefjsonkinderror__yYt4rn61ispQzTJd12bbFw_.size = sizeof(tyObject_JsonKindError__AoNiOfrNmMaOu0Lc0TiKiQ*);
NTIrefjsonkinderror__yYt4rn61ispQzTJd12bbFw_.align = NIM_ALIGNOF(tyObject_JsonKindError__AoNiOfrNmMaOu0Lc0TiKiQ*);
NTIrefjsonkinderror__yYt4rn61ispQzTJd12bbFw_.kind = 22;
NTIrefjsonkinderror__yYt4rn61ispQzTJd12bbFw_.base = (&NTIjsonkinderror__AoNiOfrNmMaOu0Lc0TiKiQ_);
NTIrefjsonkinderror__yYt4rn61ispQzTJd12bbFw_.marker = Marker_tyRef__yYt4rn61ispQzTJd12bbFw;
}

