/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct RootObj RootObj;
typedef struct tySequence__xv3aaFd3JCw8NbmALHiezQ tySequence__xv3aaFd3JCw8NbmALHiezQ;
typedef struct tyTuple__sPaDkVPSC0MkcoXCxPH9ccA tyTuple__sPaDkVPSC0MkcoXCxPH9ccA;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyObject_KeyError__oKfiLNynQGoDF9bUMQFYNdw tyObject_KeyError__oKfiLNynQGoDF9bUMQFYNdw;
typedef struct tyObject_ValueError__5lcTdgqMq62cNGRwBb0thA tyObject_ValueError__5lcTdgqMq62cNGRwBb0thA;
typedef struct tyObject_CatchableError__8K3kdpxrBD9aI27J0kpSCpQ tyObject_CatchableError__8K3kdpxrBD9aI27J0kpSCpQ;
typedef struct Exception Exception;
typedef struct tySequence__QbmGqFaLnb1IWWToREeaIA tySequence__QbmGqFaLnb1IWWToREeaIA;
typedef struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA;
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct RootObj {
TNimType* m_type;
};
typedef NU8 tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA;
struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA {
  RootObj Sup;
NI counter;
tySequence__xv3aaFd3JCw8NbmALHiezQ* data;
tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA mode;
};
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyTuple__sPaDkVPSC0MkcoXCxPH9ccA {
NimStringDesc* Field0;
NimStringDesc* Field1;
NIM_BOOL Field2;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__QbmGqFaLnb1IWWToREeaIA* trace;
Exception* up;
};
struct tyObject_CatchableError__8K3kdpxrBD9aI27J0kpSCpQ {
  Exception Sup;
};
struct tyObject_ValueError__5lcTdgqMq62cNGRwBb0thA {
  tyObject_CatchableError__8K3kdpxrBD9aI27J0kpSCpQ Sup;
};
struct tyObject_KeyError__oKfiLNynQGoDF9bUMQFYNdw {
  tyObject_ValueError__5lcTdgqMq62cNGRwBb0thA Sup;
};
typedef NU8 tySet_tyEnum_FormatFlag__twRMOL2LpNvl9aEjgVDqNrg;
typedef NU8 tyEnum_FormatFlag__twRMOL2LpNvl9aEjgVDqNrg;
struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA {
NCSTRING procname;
NI line;
NCSTRING filename;
};
struct tySequence__xv3aaFd3JCw8NbmALHiezQ {
  TGenericSeq Sup;
  tyTuple__sPaDkVPSC0MkcoXCxPH9ccA data[SEQ_DECL_SIZE];
};
struct tySequence__QbmGqFaLnb1IWWToREeaIA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__xv3aaFd3JCw8NbmALHiezQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__frXcOWngaP9adxeuIUa3iBg)(void* p, NI op);
N_LIB_PRIVATE N_NOINLINE(void*, newObj)(TNimType* typ, NI size);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
static N_INLINE(void, decRef__system_5318)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5316)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5267)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5273)(void* usr);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqRC1)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(NI, rawGet__pureZstrtabs_121)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(NI, myhash__pureZstrtabs_101)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(NI, hash__pureZhashes_279)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NI, hashIgnoreCase__pureZhashes_353)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NI, hashIgnoreStyle__pureZhashes_290)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, myCmp__pureZstrtabs_105)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(NI, cmp__system_1549)(NimStringDesc* x, NimStringDesc* y);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreCase)(NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreStyle)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NI, nextTry__pureZstrtabs_117)(NI h, NI maxHash);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5311)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
N_LIB_PRIVATE N_NIMCALL(void, raiseExceptionEx)(Exception* e, NCSTRING ename, NCSTRING procname, NCSTRING filename, NI line);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, mustRehash__pureZstrtabs_110)(NI length, NI counter);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__pureZstrtabs_199)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t);
N_LIB_PRIVATE N_NIMCALL(void*, newSeq)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__pureZstrtabs_187)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, tySequence__xv3aaFd3JCw8NbmALHiezQ** data, NimStringDesc* key, NimStringDesc* val);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getValue__pureZstrtabs_317)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, tySet_tyEnum_FormatFlag__twRMOL2LpNvl9aEjgVDqNrg flags, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsthasKey)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getOrDefault__pureZstrtabs_173)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, NimStringDesc* key, NimStringDesc* default_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getEnv__pureZos_418)(NimStringDesc* key, NimStringDesc* default_0);
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(void, raiseFormatException__pureZstrtabs_314)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__system_7745)(NimStringDesc* s, NI first, NI last);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
extern TNimType NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_;
N_LIB_PRIVATE TNimType NTIstringtableobj__9aYeizX9bryvlooxqmPkPxqA_;
extern TNimType NTIint__rR5Bzr1D5krxoo1NcNyeMA_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__sPaDkVPSC0MkcoXCxPH9ccA_;
extern TNimType NTIstring__77mFvmsOLKik79ci2hXkHEg_;
extern TNimType NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__xv3aaFd3JCw8NbmALHiezQ_;
N_LIB_PRIVATE TNimType NTIstringtablemode__aFE1syNIcJw6kweUNHC9cQA_;
N_LIB_PRIVATE TNimType NTIstringtableref__frXcOWngaP9adxeuIUa3iBg_;
extern TNimType NTIrefkeyerror__pZq9a89chzDPcYZo9bViSdp9aQ_;
extern TNimType NTIkeyerror__oKfiLNynQGoDF9bUMQFYNdw_;
STRING_LITERAL(TM__ZT9crccxweoChVXn9cHcxIXQ_7, "key not found: ", 15);
extern TNimType NTIrefvalueerror__MdotPfdEWddcwl4HcVVgeQ_;
extern TNimType NTIvalueerror__5lcTdgqMq62cNGRwBb0thA_;
STRING_LITERAL(TM__ZT9crccxweoChVXn9cHcxIXQ_8, "format string: key not found: ", 30);
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5220;
static N_NIMCALL(void, Marker_tySequence__xv3aaFd3JCw8NbmALHiezQ)(void* p, NI op) {
	tySequence__xv3aaFd3JCw8NbmALHiezQ* a;
	NI T1_;
	a = (tySequence__xv3aaFd3JCw8NbmALHiezQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field0, op);
	nimGCvisit((void*)a->data[T1_].Field1, op);
	}
}
static N_NIMCALL(void, Marker_tyRef__frXcOWngaP9adxeuIUa3iBg)(void* p, NI op) {
	tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* a;
	a = (tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA*)p;
	nimGCvisit((void*)(*a).data, op);
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5316)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5267((&gch__system_5220.zct), c);
}
static N_INLINE(void, decRef__system_5318)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5316(c);
	}
	LA4_: ;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5273)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5273(p);
	decRef__system_5318(T1_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA*, nstnewStringTable)(tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA mode) {
	tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* result;
	result = NIM_NIL;
	result = (tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA*) newObj((&NTIstringtableref__frXcOWngaP9adxeuIUa3iBg_), sizeof(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA));
	(*result).Sup.m_type = (&NTIstringtableobj__9aYeizX9bryvlooxqmPkPxqA_);
	(*result).mode = mode;
	(*result).counter = ((NI) 0);
	if ((*result).data) { nimGCunrefNoCycle((*result).data); (*result).data = NIM_NIL; }
	(*result).data = (tySequence__xv3aaFd3JCw8NbmALHiezQ*) newSeqRC1((&NTIkeyvaluepairseq__xv3aaFd3JCw8NbmALHiezQ_), ((NI) 64));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, myhash__pureZstrtabs_101)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, NimStringDesc* key) {
	NI result;
	result = (NI)0;
	switch ((*t).mode) {
	case ((tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA) 0):
	{
		result = hash__pureZhashes_279(key);
	}
	break;
	case ((tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA) 1):
	{
		result = hashIgnoreCase__pureZhashes_353(key);
	}
	break;
	case ((tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA) 2):
	{
		result = hashIgnoreStyle__pureZhashes_290(key);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, myCmp__pureZstrtabs_105)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	switch ((*t).mode) {
	case ((tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA) 0):
	{
		NI T2_;
		T2_ = (NI)0;
		T2_ = cmp__system_1549(a, b);
		result = (T2_ == ((NI) 0));
	}
	break;
	case ((tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA) 1):
	{
		NI T4_;
		T4_ = (NI)0;
		T4_ = nsuCmpIgnoreCase(a, b);
		result = (T4_ == ((NI) 0));
	}
	break;
	case ((tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA) 2):
	{
		NI T6_;
		T6_ = (NI)0;
		T6_ = nsuCmpIgnoreStyle(a, b);
		result = (T6_ == ((NI) 0));
	}
	break;
	}
	return result;
}
static N_INLINE(NI, nextTry__pureZstrtabs_117)(NI h, NI maxHash) {
	NI result;
	result = (NI)0;
	result = (NI)((NI)(h + ((NI) 1)) & maxHash);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, rawGet__pureZstrtabs_121)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, NimStringDesc* key) {
	NI result;
	NI h;
	NI T1_;
	NI T2_;
{	result = (NI)0;
	T1_ = (NI)0;
	T1_ = myhash__pureZstrtabs_101(t, key);
	T2_ = (((*t).data ? (*t).data->Sup.len : 0)-1);
	h = (NI)(T1_ & T2_);
	{
		while (1) {
			NI T10_;
			if (!(*t).data->data[h].Field2) goto LA4;
			{
				NIM_BOOL T7_;
				T7_ = (NIM_BOOL)0;
				T7_ = myCmp__pureZstrtabs_105(t, (*t).data->data[h].Field0, key);
				if (!T7_) goto LA8_;
				result = h;
				goto BeforeRet_;
			}
			LA8_: ;
			T10_ = (((*t).data ? (*t).data->Sup.len : 0)-1);
			h = nextTry__pureZstrtabs_117(h, T10_);
		} LA4: ;
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsthasKey)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, NimStringDesc* key) {
	NIM_BOOL result;
	NI T1_;
	result = (NIM_BOOL)0;
	T1_ = (NI)0;
	T1_ = rawGet__pureZstrtabs_121(t, key);
	result = (((NI) 0) <= T1_);
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5311)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5273(src);
		incRef__system_5311(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5273((*dest));
		decRef__system_5318(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc**, nstTake)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, NimStringDesc* key) {
	NimStringDesc** result;
	NI indexX60gensym3_;
	result = (NimStringDesc**)0;
	indexX60gensym3_ = rawGet__pureZstrtabs_121(t, key);
	{
		if (!(((NI) 0) <= indexX60gensym3_)) goto LA3_;
		result = (&(*t).data->data[indexX60gensym3_].Field1);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_KeyError__oKfiLNynQGoDF9bUMQFYNdw* T6_;
		NimStringDesc* T7_;
		T6_ = NIM_NIL;
		T6_ = (tyObject_KeyError__oKfiLNynQGoDF9bUMQFYNdw*) newObj((&NTIrefkeyerror__pZq9a89chzDPcYZo9bViSdp9aQ_), sizeof(tyObject_KeyError__oKfiLNynQGoDF9bUMQFYNdw));
		(*T6_).Sup.Sup.Sup.Sup.m_type = (&NTIkeyerror__oKfiLNynQGoDF9bUMQFYNdw_);
		(*T6_).Sup.Sup.Sup.name = "KeyError";
		T7_ = NIM_NIL;
		T7_ = rawNewString((key ? key->Sup.len : 0) + 15);
appendString(T7_, ((NimStringDesc*) &TM__ZT9crccxweoChVXn9cHcxIXQ_7));
appendString(T7_, key);
		asgnRef((void**) (&(*T6_).Sup.Sup.Sup.message), T7_);
		asgnRef((void**) (&(*T6_).Sup.Sup.Sup.parent), ((Exception*) NIM_NIL));
		raiseExceptionEx((Exception*)T6_, "KeyError", "[]", "strtabs.nim", 144);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, mustRehash__pureZstrtabs_110)(NI length, NI counter) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((NI)(length * ((NI) 2)) < (NI)(counter * ((NI) 3)));
	if (T1_) goto LA2_;
	T1_ = ((NI)(length - counter) < ((NI) 4));
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__pureZstrtabs_187)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, tySequence__xv3aaFd3JCw8NbmALHiezQ** data, NimStringDesc* key, NimStringDesc* val) {
	NI h;
	NI T1_;
	NI T2_;
	NimStringDesc* T6_;
	NimStringDesc* T7_;
	T1_ = (NI)0;
	T1_ = myhash__pureZstrtabs_101(t, key);
	T2_ = (((*data) ? (*data)->Sup.len : 0)-1);
	h = (NI)(T1_ & T2_);
	{
		while (1) {
			NI T5_;
			if (!(*data)->data[h].Field2) goto LA4;
			T5_ = (((*data) ? (*data)->Sup.len : 0)-1);
			h = nextTry__pureZstrtabs_117(h, T5_);
		} LA4: ;
	}
	T6_ = NIM_NIL;
	T6_ = (*data)->data[h].Field0; (*data)->data[h].Field0 = copyStringRC1(key);
	if (T6_) nimGCunrefNoCycle(T6_);
	T7_ = NIM_NIL;
	T7_ = (*data)->data[h].Field1; (*data)->data[h].Field1 = copyStringRC1(val);
	if (T7_) nimGCunrefNoCycle(T7_);
	(*data)->data[h].Field2 = NIM_TRUE;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__pureZstrtabs_199)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t) {
	tySequence__xv3aaFd3JCw8NbmALHiezQ* n;
	NI T1_;
	tySequence__xv3aaFd3JCw8NbmALHiezQ* T12_;
	n = NIM_NIL;
	T1_ = ((*t).data ? (*t).data->Sup.len : 0);
	n = (tySequence__xv3aaFd3JCw8NbmALHiezQ*) newSeq((&NTIkeyvaluepairseq__xv3aaFd3JCw8NbmALHiezQ_), ((NI) ((NI)(T1_ * ((NI) 2)))));
	{
		NI i;
		NI colontmp_;
		NI T3_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T3_ = (((*t).data ? (*t).data->Sup.len : 0)-1);
		colontmp_ = T3_;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA5;
				i = res;
				{
					NimStringDesc* T10_;
					NimStringDesc* T11_;
					if (!(*t).data->data[i].Field2) goto LA8_;
					T10_ = NIM_NIL;
					T10_ = (*t).data->data[i].Field0;
					asgnRef((void**) (&(*t).data->data[i].Field0), NIM_NIL);
					T11_ = NIM_NIL;
					T11_ = (*t).data->data[i].Field1;
					asgnRef((void**) (&(*t).data->data[i].Field1), NIM_NIL);
					rawInsert__pureZstrtabs_187(t, (&n), T10_, T11_);
				}
				LA8_: ;
				res += ((NI) 1);
			} LA5: ;
		}
	}
	T12_ = NIM_NIL;
	T12_ = (*t).data;
	asgnRef((void**) (&(*t).data), n);
	n = T12_;
}
N_LIB_PRIVATE N_NIMCALL(void, nstPut)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, NimStringDesc* key, NimStringDesc* val) {
	NI index;
	index = rawGet__pureZstrtabs_121(t, key);
	{
		NimStringDesc* T5_;
		if (!(((NI) 0) <= index)) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = (*t).data->data[index].Field1; (*t).data->data[index].Field1 = copyStringRC1(val);
		if (T5_) nimGCunrefNoCycle(T5_);
	}
	goto LA1_;
	LA3_: ;
	{
		{
			NI T9_;
			NIM_BOOL T10_;
			T9_ = ((*t).data ? (*t).data->Sup.len : 0);
			T10_ = (NIM_BOOL)0;
			T10_ = mustRehash__pureZstrtabs_110(T9_, (*t).counter);
			if (!T10_) goto LA11_;
			enlarge__pureZstrtabs_199(t);
		}
		LA11_: ;
		rawInsert__pureZstrtabs_187(t, (&(*t).data), key, val);
		(*t).counter += ((NI) 1);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, del__pureZstrtabs_356)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, NimStringDesc* key) {
	NI i;
	NI msk;
	NI T1_;
	i = rawGet__pureZstrtabs_121(t, key);
	T1_ = (((*t).data ? (*t).data->Sup.len : 0)-1);
	msk = T1_;
	{
		if (!(((NI) 0) <= i)) goto LA4_;
		(*t).counter -= ((NI) 1);
		{
			{
				while (1) {
					NI j;
					NI r;
					j = i;
					r = j;
					(*t).data->data[i].Field2 = NIM_FALSE;
					asgnRef((void**) (&(*t).data->data[i].Field0), ((NimStringDesc*) NIM_NIL));
					asgnRef((void**) (&(*t).data->data[i].Field1), ((NimStringDesc*) NIM_NIL));
					{
						while (1) {
							NI T15_;
							i = (NI)((NI)(i + ((NI) 1)) & msk);
							{
								if (!!((*t).data->data[i].Field2)) goto LA13_;
								goto LA6;
							}
							LA13_: ;
							T15_ = (NI)0;
							T15_ = myhash__pureZstrtabs_101(t, (*t).data->data[i].Field0);
							r = (NI)(T15_ & msk);
							{
								NIM_BOOL T18_;
								NIM_BOOL T19_;
								NIM_BOOL T20_;
								NIM_BOOL T23_;
								NIM_BOOL T26_;
								T18_ = (NIM_BOOL)0;
								T19_ = (NIM_BOOL)0;
								T20_ = (NIM_BOOL)0;
								T20_ = (r <= i);
								if (!(T20_)) goto LA21_;
								T20_ = (j < r);
								LA21_: ;
								T19_ = T20_;
								if (T19_) goto LA22_;
								T23_ = (NIM_BOOL)0;
								T23_ = (j < r);
								if (!(T23_)) goto LA24_;
								T23_ = (i < j);
								LA24_: ;
								T19_ = T23_;
								LA22_: ;
								T18_ = T19_;
								if (T18_) goto LA25_;
								T26_ = (NIM_BOOL)0;
								T26_ = (i < j);
								if (!(T26_)) goto LA27_;
								T26_ = (r <= i);
								LA27_: ;
								T18_ = T26_;
								LA25_: ;
								if (!!(T18_)) goto LA28_;
								goto LA9;
							}
							LA28_: ;
						}
					} LA9: ;
					asgnRef((void**) (&(*t).data->data[j].Field0), (*t).data->data[i].Field0);
					asgnRef((void**) (&(*t).data->data[j].Field1), (*t).data->data[i].Field1);
					(*t).data->data[j].Field2 = (*t).data->data[i].Field2;
				}
			}
		} LA6: ;
	}
	LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, nstlen)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t) {
	NI result;
	result = (NI)0;
	result = (*t).counter;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getOrDefault__pureZstrtabs_173)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, NimStringDesc* key, NimStringDesc* default_0) {
	NimStringDesc* result;
	NI index;
	result = NIM_NIL;
	index = rawGet__pureZstrtabs_121(t, key);
	{
		if (!(((NI) 0) <= index)) goto LA3_;
		result = copyString((*t).data->data[index].Field1);
	}
	goto LA1_;
	LA3_: ;
	{
		result = copyString(default_0);
	}
	LA1_: ;
	return result;
}
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c) {
	(*dest).data[(*dest).Sup.len] = c;
	(*dest).data[(NI)((*dest).Sup.len + ((NI) 1))] = 0;
	(*dest).Sup.len += ((NI) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, raiseFormatException__pureZstrtabs_314)(NimStringDesc* s) {
	tyObject_ValueError__5lcTdgqMq62cNGRwBb0thA* T1_;
	NimStringDesc* T2_;
	T1_ = NIM_NIL;
	T1_ = (tyObject_ValueError__5lcTdgqMq62cNGRwBb0thA*) newObj((&NTIrefvalueerror__MdotPfdEWddcwl4HcVVgeQ_), sizeof(tyObject_ValueError__5lcTdgqMq62cNGRwBb0thA));
	(*T1_).Sup.Sup.Sup.m_type = (&NTIvalueerror__5lcTdgqMq62cNGRwBb0thA_);
	(*T1_).Sup.Sup.name = "ValueError";
	T2_ = NIM_NIL;
	T2_ = rawNewString((s ? s->Sup.len : 0) + 30);
appendString(T2_, ((NimStringDesc*) &TM__ZT9crccxweoChVXn9cHcxIXQ_8));
appendString(T2_, s);
	asgnRef((void**) (&(*T1_).Sup.Sup.message), T2_);
	asgnRef((void**) (&(*T1_).Sup.Sup.parent), ((Exception*) NIM_NIL));
	raiseExceptionEx((Exception*)T1_, "ValueError", "raiseFormatException", "strtabs.nim", 299);
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getValue__pureZstrtabs_317)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, tySet_tyEnum_FormatFlag__twRMOL2LpNvl9aEjgVDqNrg flags, NimStringDesc* key) {
	NimStringDesc* result;
{	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nsthasKey(t, key);
		if (!T3_) goto LA4_;
		result = getOrDefault__pureZstrtabs_173(t, key, ((NimStringDesc*) NIM_NIL));
		goto BeforeRet_;
	}
	LA4_: ;
	{
		if (!((flags &((NU8)1<<((NU)(((tyEnum_FormatFlag__twRMOL2LpNvl9aEjgVDqNrg) 0))&7U)))!=0)) goto LA8_;
		result = getEnv__pureZos_418(key, ((NimStringDesc*) NIM_NIL));
	}
	goto LA6_;
	LA8_: ;
	{
		result = ((NimStringDesc*) NIM_NIL);
	}
	LA6_: ;
	{
		if (!((result ? result->Sup.len : 0) == ((NI) 0))) goto LA13_;
		{
			NimStringDesc* T19_;
			if (!((flags &((NU8)1<<((NU)(((tyEnum_FormatFlag__twRMOL2LpNvl9aEjgVDqNrg) 2))&7U)))!=0)) goto LA17_;
			T19_ = NIM_NIL;
			T19_ = rawNewString((key ? key->Sup.len : 0) + 1);
appendChar(T19_, 36);
appendString(T19_, key);
			result = T19_;
		}
		goto LA15_;
		LA17_: ;
		{
			if (!!(((flags &((NU8)1<<((NU)(((tyEnum_FormatFlag__twRMOL2LpNvl9aEjgVDqNrg) 1))&7U)))!=0))) goto LA21_;
			raiseFormatException__pureZstrtabs_314(key);
		}
		goto LA15_;
		LA21_: ;
		LA15_: ;
	}
	LA13_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nstFormat)(NimStringDesc* f, tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, tySet_tyEnum_FormatFlag__twRMOL2LpNvl9aEjgVDqNrg flags) {
	NimStringDesc* result;
	NI i;
	result = NIM_NIL;
	result = ((NimStringDesc*) NIM_NIL);
	i = ((NI) 0);
	{
		while (1) {
			if (!(i < (f ? f->Sup.len : 0))) goto LA2;
			{
				if (!((NU8)(f->data[i]) == (NU8)(36))) goto LA5_;
				switch (((NU8)(f->data[(NI)(i + ((NI) 1))]))) {
				case 36:
				{
					result = addChar(result, 36);
					i += ((NI) 2);
				}
				break;
				case 123:
				{
					NI j;
					NimStringDesc* T13_;
					NimStringDesc* T14_;
					j = (NI)(i + ((NI) 1));
					{
						while (1) {
							NIM_BOOL T11_;
							T11_ = (NIM_BOOL)0;
							T11_ = (j < (f ? f->Sup.len : 0));
							if (!(T11_)) goto LA12_;
							T11_ = !(((NU8)(f->data[j]) == (NU8)(125)));
							LA12_: ;
							if (!T11_) goto LA10;
							j += ((NI) 1);
						} LA10: ;
					}
					T13_ = NIM_NIL;
					T13_ = substr__system_7745(f, (NI)(i + ((NI) 2)), (NI)(j - ((NI) 1)));
					T14_ = NIM_NIL;
					T14_ = getValue__pureZstrtabs_317(t, flags, T13_);
					result = resizeString(result, (T14_ ? T14_->Sup.len : 0) + 0);
appendString(result, T14_);
					i = (NI)(j + ((NI) 1));
				}
				break;
				case 97 ... 122:
				case 65 ... 90:
				case 128 ... 255:
				case 95:
				{
					NI j_2;
					NimStringDesc* T20_;
					NimStringDesc* T21_;
					j_2 = (NI)(i + ((NI) 1));
					{
						while (1) {
							NIM_BOOL T18_;
							T18_ = (NIM_BOOL)0;
							T18_ = (j_2 < (f ? f->Sup.len : 0));
							if (!(T18_)) goto LA19_;
							T18_ = (((NU8)(f->data[j_2])) >= ((NU8)(97)) && ((NU8)(f->data[j_2])) <= ((NU8)(122)) || ((NU8)(f->data[j_2])) >= ((NU8)(65)) && ((NU8)(f->data[j_2])) <= ((NU8)(90)) || ((NU8)(f->data[j_2])) >= ((NU8)(48)) && ((NU8)(f->data[j_2])) <= ((NU8)(57)) || ((NU8)(f->data[j_2])) == ((NU8)(95)) || ((NU8)(f->data[j_2])) >= ((NU8)(128)) && ((NU8)(f->data[j_2])) <= ((NU8)(255)));
							LA19_: ;
							if (!T18_) goto LA17;
							j_2 += ((NI) 1);
						} LA17: ;
					}
					T20_ = NIM_NIL;
					T20_ = substr__system_7745(f, (NI)(i + ((NI) 1)), (NI)(j_2 - ((NI) 1)));
					T21_ = NIM_NIL;
					T21_ = getValue__pureZstrtabs_317(t, flags, T20_);
					result = resizeString(result, (T21_ ? T21_->Sup.len : 0) + 0);
appendString(result, T21_);
					i = j_2;
				}
				break;
				default:
				{
					result = addChar(result, f->data[i]);
					i += ((NI) 1);
				}
				break;
				}
			}
			goto LA3_;
			LA5_: ;
			{
				result = addChar(result, f->data[i]);
				i += ((NI) 1);
			}
			LA3_: ;
		} LA2: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, atmdotdotatslibatspureatsstrtabsdotnim_DatInit000)(void) {
static TNimNode* TM__ZT9crccxweoChVXn9cHcxIXQ_2_3[3];
static TNimNode* TM__ZT9crccxweoChVXn9cHcxIXQ_3_3[3];
static TNimNode* TM__ZT9crccxweoChVXn9cHcxIXQ_4_3[3];
NI TM__ZT9crccxweoChVXn9cHcxIXQ_6;
static char* NIM_CONST TM__ZT9crccxweoChVXn9cHcxIXQ_5[3] = {
"modeCaseSensitive", 
"modeCaseInsensitive", 
"modeStyleInsensitive"};
static TNimNode TM__ZT9crccxweoChVXn9cHcxIXQ_0[12];
NTIstringtableobj__9aYeizX9bryvlooxqmPkPxqA_.size = sizeof(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA);
NTIstringtableobj__9aYeizX9bryvlooxqmPkPxqA_.align = NIM_ALIGNOF(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA);
NTIstringtableobj__9aYeizX9bryvlooxqmPkPxqA_.kind = 17;
NTIstringtableobj__9aYeizX9bryvlooxqmPkPxqA_.base = (&NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_);
TM__ZT9crccxweoChVXn9cHcxIXQ_2_3[0] = &TM__ZT9crccxweoChVXn9cHcxIXQ_0[1];
TM__ZT9crccxweoChVXn9cHcxIXQ_0[1].kind = 1;
TM__ZT9crccxweoChVXn9cHcxIXQ_0[1].offset = offsetof(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA, counter);
TM__ZT9crccxweoChVXn9cHcxIXQ_0[1].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZT9crccxweoChVXn9cHcxIXQ_0[1].name = "counter";
TM__ZT9crccxweoChVXn9cHcxIXQ_2_3[1] = &TM__ZT9crccxweoChVXn9cHcxIXQ_0[2];
NTIkeyvaluepair__sPaDkVPSC0MkcoXCxPH9ccA_.size = sizeof(tyTuple__sPaDkVPSC0MkcoXCxPH9ccA);
NTIkeyvaluepair__sPaDkVPSC0MkcoXCxPH9ccA_.align = NIM_ALIGNOF(tyTuple__sPaDkVPSC0MkcoXCxPH9ccA);
NTIkeyvaluepair__sPaDkVPSC0MkcoXCxPH9ccA_.kind = 18;
NTIkeyvaluepair__sPaDkVPSC0MkcoXCxPH9ccA_.base = 0;
NTIkeyvaluepair__sPaDkVPSC0MkcoXCxPH9ccA_.flags = 2;
TM__ZT9crccxweoChVXn9cHcxIXQ_3_3[0] = &TM__ZT9crccxweoChVXn9cHcxIXQ_0[4];
TM__ZT9crccxweoChVXn9cHcxIXQ_0[4].kind = 1;
TM__ZT9crccxweoChVXn9cHcxIXQ_0[4].offset = offsetof(tyTuple__sPaDkVPSC0MkcoXCxPH9ccA, Field0);
TM__ZT9crccxweoChVXn9cHcxIXQ_0[4].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZT9crccxweoChVXn9cHcxIXQ_0[4].name = "Field0";
TM__ZT9crccxweoChVXn9cHcxIXQ_3_3[1] = &TM__ZT9crccxweoChVXn9cHcxIXQ_0[5];
TM__ZT9crccxweoChVXn9cHcxIXQ_0[5].kind = 1;
TM__ZT9crccxweoChVXn9cHcxIXQ_0[5].offset = offsetof(tyTuple__sPaDkVPSC0MkcoXCxPH9ccA, Field1);
TM__ZT9crccxweoChVXn9cHcxIXQ_0[5].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZT9crccxweoChVXn9cHcxIXQ_0[5].name = "Field1";
TM__ZT9crccxweoChVXn9cHcxIXQ_3_3[2] = &TM__ZT9crccxweoChVXn9cHcxIXQ_0[6];
TM__ZT9crccxweoChVXn9cHcxIXQ_0[6].kind = 1;
TM__ZT9crccxweoChVXn9cHcxIXQ_0[6].offset = offsetof(tyTuple__sPaDkVPSC0MkcoXCxPH9ccA, Field2);
TM__ZT9crccxweoChVXn9cHcxIXQ_0[6].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__ZT9crccxweoChVXn9cHcxIXQ_0[6].name = "Field2";
TM__ZT9crccxweoChVXn9cHcxIXQ_0[3].len = 3; TM__ZT9crccxweoChVXn9cHcxIXQ_0[3].kind = 2; TM__ZT9crccxweoChVXn9cHcxIXQ_0[3].sons = &TM__ZT9crccxweoChVXn9cHcxIXQ_3_3[0];
NTIkeyvaluepair__sPaDkVPSC0MkcoXCxPH9ccA_.node = &TM__ZT9crccxweoChVXn9cHcxIXQ_0[3];
NTIkeyvaluepairseq__xv3aaFd3JCw8NbmALHiezQ_.size = sizeof(tySequence__xv3aaFd3JCw8NbmALHiezQ*);
NTIkeyvaluepairseq__xv3aaFd3JCw8NbmALHiezQ_.align = NIM_ALIGNOF(tySequence__xv3aaFd3JCw8NbmALHiezQ*);
NTIkeyvaluepairseq__xv3aaFd3JCw8NbmALHiezQ_.kind = 24;
NTIkeyvaluepairseq__xv3aaFd3JCw8NbmALHiezQ_.base = (&NTIkeyvaluepair__sPaDkVPSC0MkcoXCxPH9ccA_);
NTIkeyvaluepairseq__xv3aaFd3JCw8NbmALHiezQ_.flags = 2;
NTIkeyvaluepairseq__xv3aaFd3JCw8NbmALHiezQ_.marker = Marker_tySequence__xv3aaFd3JCw8NbmALHiezQ;
TM__ZT9crccxweoChVXn9cHcxIXQ_0[2].kind = 1;
TM__ZT9crccxweoChVXn9cHcxIXQ_0[2].offset = offsetof(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA, data);
TM__ZT9crccxweoChVXn9cHcxIXQ_0[2].typ = (&NTIkeyvaluepairseq__xv3aaFd3JCw8NbmALHiezQ_);
TM__ZT9crccxweoChVXn9cHcxIXQ_0[2].name = "data";
TM__ZT9crccxweoChVXn9cHcxIXQ_2_3[2] = &TM__ZT9crccxweoChVXn9cHcxIXQ_0[7];
NTIstringtablemode__aFE1syNIcJw6kweUNHC9cQA_.size = sizeof(tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA);
NTIstringtablemode__aFE1syNIcJw6kweUNHC9cQA_.align = NIM_ALIGNOF(tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA);
NTIstringtablemode__aFE1syNIcJw6kweUNHC9cQA_.kind = 14;
NTIstringtablemode__aFE1syNIcJw6kweUNHC9cQA_.base = 0;
NTIstringtablemode__aFE1syNIcJw6kweUNHC9cQA_.flags = 3;
for (TM__ZT9crccxweoChVXn9cHcxIXQ_6 = 0; TM__ZT9crccxweoChVXn9cHcxIXQ_6 < 3; TM__ZT9crccxweoChVXn9cHcxIXQ_6++) {
TM__ZT9crccxweoChVXn9cHcxIXQ_0[TM__ZT9crccxweoChVXn9cHcxIXQ_6+8].kind = 1;
TM__ZT9crccxweoChVXn9cHcxIXQ_0[TM__ZT9crccxweoChVXn9cHcxIXQ_6+8].offset = TM__ZT9crccxweoChVXn9cHcxIXQ_6;
TM__ZT9crccxweoChVXn9cHcxIXQ_0[TM__ZT9crccxweoChVXn9cHcxIXQ_6+8].name = TM__ZT9crccxweoChVXn9cHcxIXQ_5[TM__ZT9crccxweoChVXn9cHcxIXQ_6];
TM__ZT9crccxweoChVXn9cHcxIXQ_4_3[TM__ZT9crccxweoChVXn9cHcxIXQ_6] = &TM__ZT9crccxweoChVXn9cHcxIXQ_0[TM__ZT9crccxweoChVXn9cHcxIXQ_6+8];
}
TM__ZT9crccxweoChVXn9cHcxIXQ_0[11].len = 3; TM__ZT9crccxweoChVXn9cHcxIXQ_0[11].kind = 2; TM__ZT9crccxweoChVXn9cHcxIXQ_0[11].sons = &TM__ZT9crccxweoChVXn9cHcxIXQ_4_3[0];
NTIstringtablemode__aFE1syNIcJw6kweUNHC9cQA_.node = &TM__ZT9crccxweoChVXn9cHcxIXQ_0[11];
TM__ZT9crccxweoChVXn9cHcxIXQ_0[7].kind = 1;
TM__ZT9crccxweoChVXn9cHcxIXQ_0[7].offset = offsetof(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA, mode);
TM__ZT9crccxweoChVXn9cHcxIXQ_0[7].typ = (&NTIstringtablemode__aFE1syNIcJw6kweUNHC9cQA_);
TM__ZT9crccxweoChVXn9cHcxIXQ_0[7].name = "mode";
TM__ZT9crccxweoChVXn9cHcxIXQ_0[0].len = 3; TM__ZT9crccxweoChVXn9cHcxIXQ_0[0].kind = 2; TM__ZT9crccxweoChVXn9cHcxIXQ_0[0].sons = &TM__ZT9crccxweoChVXn9cHcxIXQ_2_3[0];
NTIstringtableobj__9aYeizX9bryvlooxqmPkPxqA_.node = &TM__ZT9crccxweoChVXn9cHcxIXQ_0[0];
NTIstringtableref__frXcOWngaP9adxeuIUa3iBg_.size = sizeof(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA*);
NTIstringtableref__frXcOWngaP9adxeuIUa3iBg_.align = NIM_ALIGNOF(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA*);
NTIstringtableref__frXcOWngaP9adxeuIUa3iBg_.kind = 22;
NTIstringtableref__frXcOWngaP9adxeuIUa3iBg_.base = (&NTIstringtableobj__9aYeizX9bryvlooxqmPkPxqA_);
NTIstringtableref__frXcOWngaP9adxeuIUa3iBg_.marker = Marker_tyRef__frXcOWngaP9adxeuIUa3iBg;
}

