/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 32

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw;
typedef struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ;
typedef struct tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA;
typedef struct tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA;
typedef struct tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw;
typedef struct tySequence__ed0C0uAUZPhvw3RAc5hfYg tySequence__ed0C0uAUZPhvw3RAc5hfYg;
typedef struct tySequence__vvBerF0axaNtu9aMA2gnsrA tySequence__vvBerF0axaNtu9aMA2gnsrA;
typedef struct tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ;
typedef struct tySequence__ZQPym9bf1jM5qaSn7LUXMKA tySequence__ZQPym9bf1jM5qaSn7LUXMKA;
typedef struct tySequence__9c3OY0aBmSBgwdsnBAPf4Ag tySequence__9c3OY0aBmSBgwdsnBAPf4Ag;
typedef struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw;
typedef struct tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ;
typedef struct tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg;
typedef struct tySequence__Jhh6ks9carRtwV9aOuM8yMNw tySequence__Jhh6ks9carRtwV9aOuM8yMNw;
typedef struct tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw tySequence__Bis5AbpONWcIRrPyPJS8Yw;
typedef struct tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg;
typedef struct tySequence__E8pi9b5QNahsURYzXMjh3qw tySequence__E8pi9b5QNahsURYzXMjh3qw;
typedef struct tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg;
typedef struct tySequence__XDpbjnuseLNZDGLBQ2Qzow tySequence__XDpbjnuseLNZDGLBQ2Qzow;
typedef struct tyObject_Table__cBohObSCAwRxvYFXQHv2wA tyObject_Table__cBohObSCAwRxvYFXQHv2wA;
typedef struct tySequence__QqvaCqCpEE1QmQZbcZLi5A tySequence__QqvaCqCpEE1QmQZbcZLi5A;
typedef struct tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg;
typedef struct tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q;
typedef struct tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w;
typedef struct tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA;
typedef struct tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg;
typedef struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ tyTuple__NAaJgGVgNmlGoqmiWxdOHQ;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tyTuple__VbApVidEWCFLq9a29bPtaS7A tyTuple__VbApVidEWCFLq9a29bPtaS7A;
typedef struct tySequence__k7EQb9bN3Uhl608xoPGMRJA tySequence__k7EQb9bN3Uhl608xoPGMRJA;
typedef struct tyTuple__toqrUPSdp8zSxOdlxMJj9cA tyTuple__toqrUPSdp8zSxOdlxMJj9cA;
typedef struct tyTuple__EbsafWGli8bW2GRJQ9apsjA tyTuple__EbsafWGli8bW2GRJQ9apsjA;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
typedef NU8 tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ;
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInst;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg uniqueId;
};
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU8 tySet_tyEnum_TTypeAllowedFlag__Onpom0WAnwwvAeCSboHTQA;
typedef NU8 tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg[9];
struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw {
  RootObj Sup;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__aaEwD7wUZoIxDUprFEbfMQ[38];
struct tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ {
NI counter;
tySequence__ZQPym9bf1jM5qaSn7LUXMKA* data;
};
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__q9caIJqxIEVMlKzDKc7PN3A) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* expectedType);
typedef NU32 tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__Kiet6YwcQwPvcQYHHEqqqQ) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* expectedType);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__PSlVV9bxpH9avY5YrjCD5uqA) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__8k9afYvvfaH1tjWAwlISb0A) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, void* ClE_0);
void* ClE_0;
} tyProc__9bnYcX9avusKBraL3FJXBwJw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__uojbiMfaKLMuGW9bbomtTBg) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
typedef NU32 tySet_tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__bqRyngJC8bSPcUqqn9bn73w) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nOrig, tySet_tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw filter, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags);
typedef N_NIMCALL_PTR(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, tyProc__F6LocU8y66ng5Ra4XoVWJA) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* prev);
typedef struct {
N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, void* ClE_0);
void* ClE_0;
} tyProc__Nc9aAsBDTkr61wP9a9cnds8Og;
typedef struct {
N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fn, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, void* ClE_0);
void* ClE_0;
} tyProc__z8FaSv6eEIc72FZ9c9cBcaGg;
struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw {
NI counter;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* data;
};
typedef NU8 tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ;
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__9aa59awckKpa9areOQSBOwSeQ) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* dc, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ op, NI col);
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
struct tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ {
tySequence__Bis5AbpONWcIRrPyPJS8Yw* data;
NI counter;
};
struct tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg {
tySequence__E8pi9b5QNahsURYzXMjh3qw* data;
NI counter;
};
struct tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg {
tySequence__XDpbjnuseLNZDGLBQ2Qzow* data;
NI counter;
};
struct tyObject_Table__cBohObSCAwRxvYFXQHv2wA {
tySequence__QqvaCqCpEE1QmQZbcZLi5A* data;
NI counter;
};
struct tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw {
  tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw Sup;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* enforceVoidContext;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* voidType;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* currentScope;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* moduleScope;
tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA* imports;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* topLevelScope;
tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA* p;
tyArray__aaEwD7wUZoIxDUprFEbfMQ intTypeCache;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* nilTypeCache;
tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw* matchedConcept;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* friendModules;
NI instCounter;
NI* templInstCounter;
NI inGenericContext;
NI inStaticContext;
NI inUnrolledContext;
NI compilesContextId;
NI compilesContextIdGenerator;
NI inGenericInst;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* converters;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* patterns;
tySequence__vvBerF0axaNtu9aMA2gnsrA* optionStack;
tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ symMapping;
tySequence__9c3OY0aBmSBgwdsnBAPf4Ag* libs;
tyProc__q9caIJqxIEVMlKzDKc7PN3A semConstExpr;
tyProc__Kiet6YwcQwPvcQYHHEqqqQ semExpr;
tyProc__PSlVV9bxpH9avY5YrjCD5uqA semTryExpr;
tyProc__q9caIJqxIEVMlKzDKc7PN3A semTryConstExpr;
tyProc__8k9afYvvfaH1tjWAwlISb0A computeRequiresInit;
tyProc__9bnYcX9avusKBraL3FJXBwJw hasUnresolvedArgs;
tyProc__PSlVV9bxpH9avY5YrjCD5uqA semOperand;
tyProc__uojbiMfaKLMuGW9bbomtTBg semConstBoolExpr;
tyProc__bqRyngJC8bSPcUqqn9bn73w semOverloadedCall;
tyProc__F6LocU8y66ng5Ra4XoVWJA semTypeNode;
tyProc__Nc9aAsBDTkr61wP9a9cnds8Og semInferredLambda;
tyProc__z8FaSv6eEIc72FZ9c9cBcaGg semGenerateInstance;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw includedFiles;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw pureEnumFields;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw userPragmas;
tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ* evalContext;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw unknownIdents;
tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ* generics;
NI topStmts;
NI lastGenericIdx;
NI hloLoopDetector;
NI inParallelStmt;
tyProc__9aa59awckKpa9areOQSBOwSeQ instTypeBoundOp;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* selfName;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw signatures;
NimStringDesc* recursiveDep;
NIM_BOOL suggestionsMade;
NIM_BOOL isAmbiguous;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
NI inTypeContext;
NI inConceptDecl;
tySequence__Jhh6ks9carRtwV9aOuM8yMNw* unusedImports;
tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ exportIndirections;
tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg importModuleMap;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastTLineInfo;
tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg sideEffects;
NI inUncheckedAssignSection;
tyObject_Table__cBohObSCAwRxvYFXQHv2wA importModuleLookup;
};
typedef NU8 tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tyEnum_TTypeAllowedFlag__Onpom0WAnwwvAeCSboHTQA;
typedef NU8 tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
typedef NU8 tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ;
struct tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m;
tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ mode;
union{
struct {tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw imported;
} _mode_2;
struct {tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw exceptSet;
} _mode_3;
};
};
struct tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA {
tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* key;
RootObj* val;
};
struct tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* genericSym;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field0;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field1;
};
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
NI Field0;
NI Field1;
};
struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ {
NI Field0;
tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ Field1;
};
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
struct tyTuple__toqrUPSdp8zSxOdlxMJj9cA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
struct tyTuple__VbApVidEWCFLq9a29bPtaS7A {
NI Field0;
NI Field1;
tySequence__k7EQb9bN3Uhl608xoPGMRJA* Field2;
};
struct tyTuple__EbsafWGli8bW2GRJQ9apsjA {
NI Field0;
NI Field1;
tySequence__qwqHTkRvwhrRyENtudHQ7g* Field2;
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA {
  TGenericSeq Sup;
  tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg data[SEQ_DECL_SIZE];
};
struct tySequence__ed0C0uAUZPhvw3RAc5hfYg {
  TGenericSeq Sup;
  tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* data[SEQ_DECL_SIZE];
};
struct tySequence__vvBerF0axaNtu9aMA2gnsrA {
  TGenericSeq Sup;
  tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q* data[SEQ_DECL_SIZE];
};
struct tySequence__ZQPym9bf1jM5qaSn7LUXMKA {
  TGenericSeq Sup;
  tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA data[SEQ_DECL_SIZE];
};
struct tySequence__9c3OY0aBmSBgwdsnBAPf4Ag {
  TGenericSeq Sup;
  tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* data[SEQ_DECL_SIZE];
};
struct tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ {
  TGenericSeq Sup;
  tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w data[SEQ_DECL_SIZE];
};
struct tySequence__Jhh6ks9carRtwV9aOuM8yMNw {
  TGenericSeq Sup;
  tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg data[SEQ_DECL_SIZE];
};
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw {
  TGenericSeq Sup;
  tyTuple__NAaJgGVgNmlGoqmiWxdOHQ data[SEQ_DECL_SIZE];
};
struct tySequence__E8pi9b5QNahsURYzXMjh3qw {
  TGenericSeq Sup;
  tyTuple__47w2DboNEPf69aPgubZdd7Q data[SEQ_DECL_SIZE];
};
struct tySequence__k7EQb9bN3Uhl608xoPGMRJA {
  TGenericSeq Sup;
  tyTuple__toqrUPSdp8zSxOdlxMJj9cA data[SEQ_DECL_SIZE];
};
struct tySequence__XDpbjnuseLNZDGLBQ2Qzow {
  TGenericSeq Sup;
  tyTuple__VbApVidEWCFLq9a29bPtaS7A data[SEQ_DECL_SIZE];
};
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  TGenericSeq Sup;
  NI data[SEQ_DECL_SIZE];
};
struct tySequence__QqvaCqCpEE1QmQZbcZLi5A {
  TGenericSeq Sup;
  tyTuple__EbsafWGli8bW2GRJQ9apsjA data[SEQ_DECL_SIZE];
};
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(void, initPackedSet__pureZcollectionsZintsets_16)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ, classifyViewTypeAux__typeallowed_518)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* marker, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__astalgo_402)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, lastSon__ast_3731)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n);
static N_INLINE(NI, len__ast_3990)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n);
static N_INLINE(void, combine__typeallowed_501)(tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ* dest, tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ b);
N_LIB_PRIVATE N_NIMCALL(tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ, classifyViewTypeNode__typeallowed_521)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* marker, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, lastSon__ast_4833)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ, classifyViewType__typeallowed_579)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, typeAllowedAux__typeallowed_20)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* marker, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tySet_tyEnum_TTypeAllowedFlag__Onpom0WAnwwvAeCSboHTQA flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, skipTypes__ast_3723)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kinds);
static N_INLINE(NIM_BOOL, isInlineIterator__ast_4990)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, typeAllowedNode__typeallowed_26)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* marker, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tySet_tyEnum_TTypeAllowedFlag__Onpom0WAnwwvAeCSboHTQA flags);
N_LIB_PRIVATE N_NIMCALL(tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ, directViewType__typeallowed_583)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__YJ7SkRGD9a7VPW7Vt3UFhMw_2 = {
0x10, 0xa8, 0x00, 0x00, 0x00, 0x20, 0x80, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__YJ7SkRGD9a7VPW7Vt3UFhMw_3 = {
0x10, 0xa8, 0x00, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__YJ7SkRGD9a7VPW7Vt3UFhMw_4 = {
0x10, 0xa9, 0x00, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result) {
	initPackedSet__pureZcollectionsZintsets_16(Result);
}
static N_INLINE(NI, len__ast_3990)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n).sons ? (*n).sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(void, combine__typeallowed_501)(tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ* dest, tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ b) {
	switch ((*dest)) {
	case ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 0):
	case ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 2):
	{
		(*dest) = b;
	}
	break;
	case ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 1):
	{
		{
			if (!(b == ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 2))) goto LA5_;
			(*dest) = b;
		}
		LA5_: ;
	}
	break;
	}
}
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__ast_3155(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ, classifyViewTypeNode__typeallowed_521)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* marker, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ result;
	result = (tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		result = classifyViewTypeAux__typeallowed_518(marker, (*n).typ);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 85):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T3_;
		T3_ = NIM_NIL;
		T3_ = lastSon__ast_4833(n);
		result = classifyViewTypeNode__typeallowed_521(marker, T3_);
	}
	break;
	default:
	{
		result = ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 0);
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child;
			child = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ T9_;
						if (!(i_2 < colontmp_)) goto LA8;
						i = i_2;
						child = (*n)._kind_6.sons->data[i];
						T9_ = (tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ)0;
						T9_ = classifyViewTypeNode__typeallowed_521(marker, child);
						combine__typeallowed_501((&result), T9_);
						{
							if (!(result == ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 2))) goto LA12_;
							goto LA5;
						}
						LA12_: ;
						i_2 += ((NI) 1);
					} LA8: ;
				}
			}
		} LA5: ;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ, classifyViewTypeAux__typeallowed_518)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* marker, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ result;
{	result = (tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ)0;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* xX60gensym88_;
		NIM_BOOL T3_;
		xX60gensym88_ = t;
		T3_ = (NIM_BOOL)0;
		T3_ = containsOrIncl__astalgo_402(marker, (NI)((NI)((NU32)(((NI) ((*xX60gensym88_).Sup.itemId.module))) << (NU32)(((NI) 20))) + ((NI) ((*xX60gensym88_).Sup.itemId.item))));
		if (!T3_) goto LA4_;
		result = ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 0);
		goto BeforeRet_;
	}
	LA4_: ;
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23):
	{
		result = ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 2);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48):
	{
		result = ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 1);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 13):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 4):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 55):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 49):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T9_;
		T9_ = NIM_NIL;
		T9_ = lastSon__ast_3731(t);
		result = classifyViewTypeAux__typeallowed_518(marker, T9_);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 61):
	{
		{
			NI T13_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T16_;
			T13_ = (NI)0;
			T13_ = len__ast_3990(t);
			if (!(((NI) 0) < T13_)) goto LA14_;
			T16_ = NIM_NIL;
			T16_ = lastSon__ast_3731(t);
			result = classifyViewTypeAux__typeallowed_518(marker, T16_);
		}
		goto LA11_;
		LA14_: ;
		{
			result = ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 0);
		}
		LA11_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18):
	{
		result = ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 0);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3990(t);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ T22_;
					if (!(i_2 < colontmp_)) goto LA21;
					i = i_2;
					T22_ = (tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ)0;
					T22_ = classifyViewTypeAux__typeallowed_518(marker, (*t).sons->data[i]);
					combine__typeallowed_501((&result), T22_);
					{
						if (!(result == ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 2))) goto LA25_;
						goto LA19;
					}
					LA25_: ;
					i_2 += ((NI) 1);
				} LA21: ;
			}
		} LA19: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17):
	{
		result = ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 0);
		{
			if (!!(((*t).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA30_;
			result = classifyViewTypeNode__typeallowed_521(marker, (*t).n);
		}
		LA30_: ;
		{
			tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ T36_;
			if (!!(((*t).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA34_;
			T36_ = (tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ)0;
			T36_ = classifyViewTypeAux__typeallowed_518(marker, (*t).sons->data[((NI) 0)]);
			combine__typeallowed_501((&result), T36_);
		}
		LA34_: ;
	}
	break;
	default:
	{
		result = ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 0);
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ, classifyViewType__typeallowed_579)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ result;
	tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw marker;
	result = (tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ)0;
	nimZeroMem((void*)(&marker), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
	initIntSet__pureZcollectionsZintsets_238((&marker));
	result = classifyViewTypeAux__typeallowed_518((&marker), t);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, requiresInit__typeallowed_593)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ T3_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = !((((*t).flags & 917504) == 0));
	if (T1_) goto LA2_;
	T3_ = (tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ)0;
	T3_ = classifyViewType__typeallowed_579(t);
	T1_ = !((T3_ == ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 0)));
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(NIM_BOOL, isInlineIterator__ast_4990)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25));
	if (!(T2_)) goto LA3_;
	T2_ = (((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 15))&63U)))!=0);
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = !(((*typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9)));
	LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, typeAllowedNode__typeallowed_26)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* marker, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tySet_tyEnum_TTypeAllowedFlag__Onpom0WAnwwvAeCSboHTQA flags) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	result = NIM_NIL;
	{
		if (!!((n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA3_;
		result = typeAllowedAux__typeallowed_20(marker, (*n).typ, kind, c, flags);
		{
			if (!(result == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA7_;
			switch ((*n).kind) {
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
			{
			}
			break;
			default:
			{
				{
					NI i;
					NI colontmp_;
					NI i_2;
					i = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = len__ast_3155(n);
					i_2 = ((NI) 0);
					{
						while (1) {
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
							if (!(i_2 < colontmp_)) goto LA13;
							i = i_2;
							it = (*n)._kind_6.sons->data[i];
							result = typeAllowedNode__typeallowed_26(marker, it, kind, c, flags);
							{
								if (!!((result == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA16_;
								goto LA11;
							}
							LA16_: ;
							i_2 += ((NI) 1);
						} LA13: ;
					}
				} LA11: ;
			}
			break;
			}
		}
		LA7_: ;
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, typeAllowedAux__typeallowed_20)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* marker, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tySet_tyEnum_TTypeAllowedFlag__Onpom0WAnwwvAeCSboHTQA flags) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
{	result = NIM_NIL;
	result = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL);
	{
		if (!(typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA3_;
		result = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL);
		goto BeforeRet_;
	}
	LA3_: ;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* xX60gensym6_;
		NIM_BOOL T7_;
		xX60gensym6_ = typ;
		T7_ = (NIM_BOOL)0;
		T7_ = containsOrIncl__astalgo_402(marker, (NI)((NI)((NU32)(((NI) ((*xX60gensym6_).Sup.itemId.module))) << (NU32)(((NI) 20))) + ((NI) ((*xX60gensym6_).Sup.itemId.item))));
		if (!T7_) goto LA8_;
		result = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL);
		goto BeforeRet_;
	}
	LA8_: ;
	t = skipTypes__ast_3723(typ, TM__YJ7SkRGD9a7VPW7Vt3UFhMw_2);
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47):
	{
		{
			NIM_BOOL T13_;
			T13_ = (NIM_BOOL)0;
			T13_ = ((13312 &((NU32)1<<((NU)(kind)&31U)))!=0);
			if (!(T13_)) goto LA14_;
			T13_ = !((((*c).features &((NU32)1<<((NU)(((tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw) 13))&31U)))!=0));
			LA14_: ;
			if (!T13_) goto LA15_;
			result = t;
		}
		goto LA11_;
		LA15_: ;
		{
			if (!((flags &((NU8)1<<((NU)(((tyEnum_TTypeAllowedFlag__Onpom0WAnwwvAeCSboHTQA) 3))&7U)))!=0)) goto LA18_;
			result = t;
		}
		goto LA11_;
		LA18_: ;
		{
			NIM_BOOL T21_;
			NIM_BOOL T23_;
			NIM_BOOL T24_;
			NIM_BOOL T27_;
			T21_ = (NIM_BOOL)0;
			T21_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47));
			if (!(T21_)) goto LA22_;
			T23_ = (NIM_BOOL)0;
			T24_ = (NIM_BOOL)0;
			T24_ = !((kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 11)));
			if (!(T24_)) goto LA25_;
			T24_ = !((((*c).features &((NU32)1<<((NU)(((tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw) 13))&31U)))!=0));
			LA25_: ;
			T23_ = T24_;
			if (T23_) goto LA26_;
			T27_ = (NIM_BOOL)0;
			T27_ = (kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			if (!(T27_)) goto LA28_;
			T27_ = ((129 & flags) == 0);
			LA28_: ;
			T23_ = T27_;
			LA26_: ;
			T21_ = T23_;
			LA22_: ;
			if (!T21_) goto LA29_;
			result = t;
		}
		goto LA11_;
		LA29_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t2;
			t2 = skipTypes__ast_3723((*t).sons->data[((NI) 0)], TM__YJ7SkRGD9a7VPW7Vt3UFhMw_2);
			switch ((*t2).kind) {
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47):
			{
				{
					if (!!(((flags &((NU8)1<<((NU)(((tyEnum_TTypeAllowedFlag__Onpom0WAnwwvAeCSboHTQA) 1))&7U)))!=0))) goto LA35_;
					result = t2;
				}
				LA35_: ;
			}
			break;
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27):
			{
				{
					NIM_BOOL T40_;
					NIM_BOOL T41_;
					T40_ = (NIM_BOOL)0;
					T41_ = (NIM_BOOL)0;
					T41_ = !((kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3)));
					if (!(T41_)) goto LA42_;
					T41_ = !((((*c).features &((NU32)1<<((NU)(((tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw) 13))&31U)))!=0));
					LA42_: ;
					T40_ = T41_;
					if (T40_) goto LA43_;
					T40_ = ((flags &((NU8)1<<((NU)(((tyEnum_TTypeAllowedFlag__Onpom0WAnwwvAeCSboHTQA) 3))&7U)))!=0);
					LA43_: ;
					if (!T40_) goto LA44_;
					result = t;
				}
				goto LA38_;
				LA44_: ;
				{
					result = typeAllowedAux__typeallowed_20(marker, (*t2).sons->data[((NI) 0)], kind, c, (flags | 8));
				}
				LA38_: ;
			}
			break;
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 49):
			{
				{
					NIM_BOOL T50_;
					T50_ = (NIM_BOOL)0;
					T50_ = !((kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3)));
					if (!(T50_)) goto LA51_;
					T50_ = !((((*c).features &((NU32)1<<((NU)(((tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw) 13))&31U)))!=0));
					LA51_: ;
					if (!T50_) goto LA52_;
					result = t;
				}
				goto LA48_;
				LA52_: ;
				{
					result = typeAllowedAux__typeallowed_20(marker, (*t2).sons->data[((NI) 0)], kind, c, flags);
				}
				LA48_: ;
			}
			break;
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46):
			{
				result = t;
			}
			break;
			default:
			{
				{
					NIM_BOOL T59_;
					T59_ = (NIM_BOOL)0;
					T59_ = !(((2056 &((NU32)1<<((NU)(kind)&31U)))!=0));
					if (!(T59_)) goto LA60_;
					T59_ = !((((*c).features &((NU32)1<<((NU)(((tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw) 13))&31U)))!=0));
					LA60_: ;
					if (!T59_) goto LA61_;
					result = t;
				}
				goto LA57_;
				LA61_: ;
				{
					result = typeAllowedAux__typeallowed_20(marker, t2, kind, c, flags);
				}
				LA57_: ;
			}
			break;
			}
		}
		LA11_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25):
	{
		{
			NIM_BOOL T67_;
			T67_ = (NIM_BOOL)0;
			T67_ = ((1792 &((NU32)1<<((NU)(kind)&31U)))!=0);
			if (!(T67_)) goto LA68_;
			T67_ = ((flags &((NU8)1<<((NU)(((tyEnum_TTypeAllowedFlag__Onpom0WAnwwvAeCSboHTQA) 5))&7U)))!=0);
			LA68_: ;
			if (!T67_) goto LA69_;
			result = t;
		}
		goto LA65_;
		LA69_: ;
		{
			tySet_tyEnum_TTypeAllowedFlag__Onpom0WAnwwvAeCSboHTQA f;
			{
				NIM_BOOL T74_;
				T74_ = (NIM_BOOL)0;
				T74_ = isInlineIterator__ast_4990(typ);
				if (!(T74_)) goto LA75_;
				T74_ = ((3848 &((NU32)1<<((NU)(kind)&31U)))!=0);
				LA75_: ;
				if (!T74_) goto LA76_;
				result = t;
			}
			LA76_: ;
			{
				if (!((12288 &((NU32)1<<((NU)(kind)&31U)))!=0)) goto LA80_;
				f = (flags | 16);
			}
			goto LA78_;
			LA80_: ;
			{
				f = flags;
			}
			LA78_: ;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_3990(t);
				i_2 = ((NI) 1);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA85;
						i = i_2;
						{
							if (!!((result == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA88_;
							goto LA83;
						}
						LA88_: ;
						result = typeAllowedAux__typeallowed_20(marker, (*t).sons->data[i], ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3), c, (f & ~ 8));
						i_2 += ((NI) 1);
					} LA85: ;
				}
			} LA83: ;
			{
				NIM_BOOL T92_;
				T92_ = (NIM_BOOL)0;
				T92_ = (result == 0);
				if (!(T92_)) goto LA93_;
				T92_ = !(((*t).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
				LA93_: ;
				if (!T92_) goto LA94_;
				result = typeAllowedAux__typeallowed_20(marker, (*t).sons->data[((NI) 0)], ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 11), c, flags);
			}
			LA94_: ;
		}
		LA65_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8):
	{
		{
			NIM_BOOL T99_;
			T99_ = (NIM_BOOL)0;
			T99_ = ((1792 &((NU32)1<<((NU)(kind)&31U)))!=0);
			if (!(T99_)) goto LA100_;
			T99_ = ((flags &((NU8)1<<((NU)(((tyEnum_TTypeAllowedFlag__Onpom0WAnwwvAeCSboHTQA) 6))&7U)))!=0);
			LA100_: ;
			if (!T99_) goto LA101_;
			result = t;
		}
		goto LA97_;
		LA101_: ;
		{
			result = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL);
		}
		LA97_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 6):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 7):
	{
		{
			NIM_BOOL T107_;
			T107_ = (NIM_BOOL)0;
			T107_ = !(((2056 &((NU32)1<<((NU)(kind)&31U)))!=0));
			if (T107_) goto LA108_;
			T107_ = ((flags &((NU8)1<<((NU)(((tyEnum_TTypeAllowedFlag__Onpom0WAnwwvAeCSboHTQA) 4))&7U)))!=0);
			LA108_: ;
			if (!T107_) goto LA109_;
			result = t;
		}
		LA109_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 64):
	{
		{
			NIM_BOOL T114_;
			T114_ = (NIM_BOOL)0;
			T114_ = !(((8 &((NU32)1<<((NU)(kind)&31U)))!=0));
			if (T114_) goto LA115_;
			T114_ = ((flags &((NU8)1<<((NU)(((tyEnum_TTypeAllowedFlag__Onpom0WAnwwvAeCSboHTQA) 4))&7U)))!=0);
			LA115_: ;
			if (!T114_) goto LA116_;
			result = t;
		}
		LA116_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60):
	{
		{
			if (!!(((8 &((NU32)1<<((NU)(kind)&31U)))!=0))) goto LA121_;
			result = t;
		}
		LA121_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 63):
	{
		{
			if (!!(((flags &((NU8)1<<((NU)(((tyEnum_TTypeAllowedFlag__Onpom0WAnwwvAeCSboHTQA) 0))&7U)))!=0))) goto LA126_;
			result = t;
		}
		LA126_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 51) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 54):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 56) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 59):
	{
		{
			NIM_BOOL T131_;
			T131_ = (NIM_BOOL)0;
			T131_ = (((*t).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 25))&63U)))!=0);
			if (T131_) goto LA132_;
			T131_ = ((flags &((NU8)1<<((NU)(((tyEnum_TTypeAllowedFlag__Onpom0WAnwwvAeCSboHTQA) 2))&7U)))!=0);
			LA132_: ;
			if (!T131_) goto LA133_;
		}
		goto LA129_;
		LA133_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T138_;
			if (!(((*t).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 10))&63U)))!=0)) goto LA136_;
			T138_ = NIM_NIL;
			T138_ = lastSon__ast_3731(t);
			result = typeAllowedAux__typeallowed_20(marker, T138_, kind, c, flags);
		}
		goto LA129_;
		LA136_: ;
		{
			if (!!(((2056 &((NU32)1<<((NU)(kind)&31U)))!=0))) goto LA140_;
			result = t;
		}
		goto LA129_;
		LA140_: ;
		LA129_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 10):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 9):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 0):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 30):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 61):
	{
		result = t;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 5):
	{
		{
			NIM_BOOL T146_;
			T146_ = (NIM_BOOL)0;
			T146_ = !((kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 10)));
			if (!(T146_)) goto LA147_;
			T146_ = !((kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3)));
			LA147_: ;
			if (!T146_) goto LA148_;
			result = t;
		}
		LA148_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 26):
	{
		result = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 15):
	{
		{
			if (!!((kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3)))) goto LA154_;
			result = t;
		}
		LA154_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 13):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 4):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 55):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T157_;
		T157_ = NIM_NIL;
		T157_ = lastSon__ast_3731(t);
		result = typeAllowedAux__typeallowed_20(marker, T157_, kind, c, flags);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 20):
	{
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T161_;
			T161_ = NIM_NIL;
			T161_ = skipTypes__ast_3723((*t).sons->data[((NI) 0)], TM__YJ7SkRGD9a7VPW7Vt3UFhMw_3);
			if (!!(((*T161_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2) || (*T161_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14) || (*T161_).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) && (*T161_).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 39) || (*T161_).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) && (*T161_).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44) || (*T161_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 20)))) goto LA162_;
			result = t;
		}
		LA162_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27):
	{
		{
			NIM_BOOL T167_;
			NIM_BOOL T168_;
			T167_ = (NIM_BOOL)0;
			T168_ = (NIM_BOOL)0;
			T168_ = !((kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3)));
			if (T168_) goto LA169_;
			T168_ = ((flags &((NU8)1<<((NU)(((tyEnum_TTypeAllowedFlag__Onpom0WAnwwvAeCSboHTQA) 3))&7U)))!=0);
			LA169_: ;
			T167_ = T168_;
			if (!(T167_)) goto LA170_;
			T167_ = !((((*c).features &((NU32)1<<((NU)(((tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw) 13))&31U)))!=0));
			LA170_: ;
			if (!T167_) goto LA171_;
			result = t;
		}
		goto LA165_;
		LA171_: ;
		{
			result = typeAllowedAux__typeallowed_20(marker, (*t).sons->data[((NI) 0)], kind, c, (flags | 8));
		}
		LA165_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48):
	{
		{
			NIM_BOOL T177_;
			T177_ = (NIM_BOOL)0;
			T177_ = !((kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3)));
			if (T177_) goto LA178_;
			T177_ = ((flags &((NU8)1<<((NU)(((tyEnum_TTypeAllowedFlag__Onpom0WAnwwvAeCSboHTQA) 3))&7U)))!=0);
			LA178_: ;
			if (!T177_) goto LA179_;
			result = t;
		}
		goto LA175_;
		LA179_: ;
		{
			result = typeAllowedAux__typeallowed_20(marker, (*t).sons->data[((NI) 0)], kind, c, (flags | 8));
		}
		LA175_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46):
	{
		{
			NIM_BOOL T185_;
			NIM_BOOL T186_;
			T185_ = (NIM_BOOL)0;
			T186_ = (NIM_BOOL)0;
			T186_ = !((kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3)));
			if (T186_) goto LA187_;
			T186_ = ((flags &((NU8)1<<((NU)(((tyEnum_TTypeAllowedFlag__Onpom0WAnwwvAeCSboHTQA) 3))&7U)))!=0);
			LA187_: ;
			T185_ = T186_;
			if (T185_) goto LA188_;
			T185_ = ((*(*t).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46) || (*(*t).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47) || (*(*t).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23));
			LA188_: ;
			if (!T185_) goto LA189_;
			result = t;
		}
		goto LA183_;
		LA189_: ;
		{
			result = typeAllowedAux__typeallowed_20(marker, (*t).sons->data[((NI) 0)], kind, c, flags);
		}
		LA183_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 49):
	{
		{
			NIM_BOOL T195_;
			T195_ = (NIM_BOOL)0;
			T195_ = !((kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3)));
			if (!(T195_)) goto LA196_;
			T195_ = !(((flags &((NU8)1<<((NU)(((tyEnum_TTypeAllowedFlag__Onpom0WAnwwvAeCSboHTQA) 1))&7U)))!=0));
			LA196_: ;
			if (!T195_) goto LA197_;
			result = t;
		}
		goto LA193_;
		LA197_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T200_;
			T200_ = NIM_NIL;
			T200_ = lastSon__ast_3731(t);
			result = typeAllowedAux__typeallowed_20(marker, T200_, kind, c, (flags & ~ 2));
		}
		LA193_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
	{
		{
			if (!!(((*(*t).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 3)))) goto LA204_;
			result = typeAllowedAux__typeallowed_20(marker, (*t).sons->data[((NI) 0)], kind, c, (flags | 2));
		}
		goto LA202_;
		LA204_: ;
		{
			if (!((768 &((NU32)1<<((NU)(kind)&31U)))!=0)) goto LA207_;
			result = (*t).sons->data[((NI) 0)];
		}
		goto LA202_;
		LA207_: ;
		LA202_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
	{
		{
			if (!((*(*t).sons->data[((NI) 1)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8))) goto LA212_;
			result = (*t).sons->data[((NI) 1)];
		}
		goto LA210_;
		LA212_: ;
		{
			if (!!(((*(*t).sons->data[((NI) 1)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 3)))) goto LA215_;
			result = typeAllowedAux__typeallowed_20(marker, (*t).sons->data[((NI) 1)], kind, c, flags);
		}
		goto LA210_;
		LA215_: ;
		{
			if (!((768 &((NU32)1<<((NU)(kind)&31U)))!=0)) goto LA218_;
			result = (*t).sons->data[((NI) 1)];
		}
		goto LA210_;
		LA218_: ;
		LA210_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22):
	{
		{
			if (!(kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 10))) goto LA223_;
			result = t;
		}
		goto LA221_;
		LA223_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T226_;
			T226_ = NIM_NIL;
			T226_ = lastSon__ast_3731(t);
			result = typeAllowedAux__typeallowed_20(marker, T226_, kind, c, (flags | 2));
		}
		LA221_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T228_;
		T228_ = NIM_NIL;
		T228_ = lastSon__ast_3731(t);
		result = typeAllowedAux__typeallowed_20(marker, T228_, kind, c, (flags | 2));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 19):
	{
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3990(t);
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA232;
					i_3 = i_4;
					result = typeAllowedAux__typeallowed_20(marker, (*t).sons->data[i_3], kind, c, flags);
					{
						if (!!((result == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA235_;
						goto LA230;
					}
					LA235_: ;
					i_4 += ((NI) 1);
				} LA232: ;
			}
		} LA230: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18):
	{
		{
			NIM_BOOL T240_;
			NIM_BOOL T241_;
			T240_ = (NIM_BOOL)0;
			T241_ = (NIM_BOOL)0;
			T241_ = ((13312 &((NU32)1<<((NU)(kind)&31U)))!=0);
			if (!(T241_)) goto LA242_;
			T241_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17));
			LA242_: ;
			T240_ = T241_;
			if (!(T240_)) goto LA243_;
			T240_ = !(((*t).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
			LA243_: ;
			if (!T240_) goto LA244_;
			result = t;
		}
		goto LA238_;
		LA244_: ;
		{
			tySet_tyEnum_TTypeAllowedFlag__Onpom0WAnwwvAeCSboHTQA flags_2;
			flags_2 = (flags | 1);
			{
				NI i_5;
				NI colontmp__3;
				NI i_6;
				i_5 = (NI)0;
				colontmp__3 = (NI)0;
				colontmp__3 = len__ast_3990(t);
				i_6 = ((NI) 0);
				{
					while (1) {
						if (!(i_6 < colontmp__3)) goto LA249;
						i_5 = i_6;
						result = typeAllowedAux__typeallowed_20(marker, (*t).sons->data[i_5], kind, c, flags_2);
						{
							if (!!((result == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA252_;
							goto LA247;
						}
						LA252_: ;
						i_6 += ((NI) 1);
					} LA249: ;
				}
			} LA247: ;
			{
				NIM_BOOL T256_;
				T256_ = (NIM_BOOL)0;
				T256_ = (result == 0);
				if (!(T256_)) goto LA257_;
				T256_ = !(((*t).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
				LA257_: ;
				if (!T256_) goto LA258_;
				result = typeAllowedNode__typeallowed_26(marker, (*t).n, kind, c, flags_2);
			}
			LA258_: ;
		}
		LA238_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 3):
	{
		{
			if (!((768 &((NU32)1<<((NU)(kind)&31U)))!=0)) goto LA263_;
			result = t;
		}
		LA263_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 50):
	{
		result = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45):
	{
		{
			NIM_BOOL T269_;
			NI T270_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T272_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T275_;
			T269_ = (NIM_BOOL)0;
			T270_ = (NI)0;
			T270_ = len__ast_3990(t);
			T269_ = (T270_ == ((NI) 1));
			if (!(T269_)) goto LA271_;
			T272_ = NIM_NIL;
			T272_ = skipTypes__ast_3723((*t).sons->data[((NI) 0)], TM__YJ7SkRGD9a7VPW7Vt3UFhMw_4);
			T269_ = ((*T272_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22) || (*T272_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21) || (*T272_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25));
			LA271_: ;
			if (!T269_) goto LA273_;
			T275_ = NIM_NIL;
			T275_ = lastSon__ast_3731(t);
			result = typeAllowedAux__typeallowed_20(marker, T275_, kind, c, (flags | 2));
		}
		goto LA267_;
		LA273_: ;
		{
			result = t;
		}
		LA267_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 62):
	{
		{
			if (!!((kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3)))) goto LA280_;
			result = t;
		}
		goto LA278_;
		LA280_: ;
		{
			result = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL);
		}
		LA278_: ;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, typeAllowed__typeallowed_487)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tySet_tyEnum_TTypeAllowedFlag__Onpom0WAnwwvAeCSboHTQA flags) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw marker;
	result = NIM_NIL;
	nimZeroMem((void*)(&marker), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
	initIntSet__pureZcollectionsZintsets_238((&marker));
	result = typeAllowedAux__typeallowed_20((&marker), t, kind, c, flags);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ, directViewType__typeallowed_583)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ result;
	result = (tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ)0;
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23):
	{
		result = ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 2);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27):
	{
		result = ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 1);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 4):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 13):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 15):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 55):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T4_;
		T4_ = NIM_NIL;
		T4_ = lastSon__ast_3731(t);
		result = directViewType__typeallowed_583(T4_);
	}
	break;
	default:
	{
		result = ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 0);
	}
	break;
	}
	return result;
}
