/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 32

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct NimStringDesc NimStringDesc;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw tySequence__Bis5AbpONWcIRrPyPJS8Yw;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ tyTuple__NAaJgGVgNmlGoqmiWxdOHQ;
typedef struct tyObject_HashSet__zVZZy9cn25qKcaABhU9aN2vw tyObject_HashSet__zVZZy9cn25qKcaABhU9aN2vw;
typedef struct tySequence__nueg5spSfGVW7EdegG2fTw tySequence__nueg5spSfGVW7EdegG2fTw;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tyTuple__QJASEmMHDLGFAvbisAV7AA tyTuple__QJASEmMHDLGFAvbisAV7AA;
typedef struct tyObject_HashSet__4M9cdYsKLFZugenKrKIlmiA tyObject_HashSet__4M9cdYsKLFZugenKrKIlmiA;
typedef struct tySequence__387YteDgSUbs69cJAUWxHOA tySequence__387YteDgSUbs69cJAUWxHOA;
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyTuple__FMW2STq9c4aUT0G5x9aeTpkw tyTuple__FMW2STq9c4aUT0G5x9aeTpkw;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_HashSet__KYwZ0vHsYO0DQEC4qpQkAQ tyObject_HashSet__KYwZ0vHsYO0DQEC4qpQkAQ;
typedef struct tySequence__WPcy3bORPBFlmk2KIq2pbQ tySequence__WPcy3bORPBFlmk2KIq2pbQ;
typedef struct tyTuple__a1QJSSO0LTGR9bFH59c2xGCA tyTuple__a1QJSSO0LTGR9bFH59c2xGCA;
typedef struct tyObject_HashSet__rOalG16fHtjsOOJNJ8viBg tyObject_HashSet__rOalG16fHtjsOOJNJ8viBg;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tySequence__Mh5ToiAHng5Z72oMQ0yKVg tySequence__Mh5ToiAHng5Z72oMQ0yKVg;
typedef struct tyTuple__s6BysGQTy8rDa2etv8FeyA tyTuple__s6BysGQTy8rDa2etv8FeyA;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
struct tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ {
tySequence__Bis5AbpONWcIRrPyPJS8Yw* data;
NI counter;
};
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
NI Field0;
NI Field1;
};
struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ {
NI Field0;
tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ Field1;
};
struct tyObject_HashSet__zVZZy9cn25qKcaABhU9aN2vw {
tySequence__nueg5spSfGVW7EdegG2fTw* data;
NI counter;
};
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
struct tyTuple__QJASEmMHDLGFAvbisAV7AA {
NI Field0;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field1;
};
struct tyObject_HashSet__4M9cdYsKLFZugenKrKIlmiA {
tySequence__387YteDgSUbs69cJAUWxHOA* data;
NI counter;
};
struct tyTuple__FMW2STq9c4aUT0G5x9aeTpkw {
NI Field0;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field1;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyObject_HashSet__KYwZ0vHsYO0DQEC4qpQkAQ {
tySequence__WPcy3bORPBFlmk2KIq2pbQ* data;
NI counter;
};
struct tyTuple__a1QJSSO0LTGR9bFH59c2xGCA {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_HashSet__rOalG16fHtjsOOJNJ8viBg {
tySequence__Mh5ToiAHng5Z72oMQ0yKVg* data;
NI counter;
};
struct tyTuple__s6BysGQTy8rDa2etv8FeyA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__nueg5spSfGVW7EdegG2fTw {
  TGenericSeq Sup;
  tyTuple__QJASEmMHDLGFAvbisAV7AA data[SEQ_DECL_SIZE];
};
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw {
  TGenericSeq Sup;
  tyTuple__NAaJgGVgNmlGoqmiWxdOHQ data[SEQ_DECL_SIZE];
};
struct tySequence__387YteDgSUbs69cJAUWxHOA {
  TGenericSeq Sup;
  tyTuple__FMW2STq9c4aUT0G5x9aeTpkw data[SEQ_DECL_SIZE];
};
struct tySequence__WPcy3bORPBFlmk2KIq2pbQ {
  TGenericSeq Sup;
  tyTuple__a1QJSSO0LTGR9bFH59c2xGCA data[SEQ_DECL_SIZE];
};
struct tySequence__Mh5ToiAHng5Z72oMQ0yKVg {
  TGenericSeq Sup;
  tyTuple__s6BysGQTy8rDa2etv8FeyA data[SEQ_DECL_SIZE];
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(void, init__options_2343)(tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw* s, NI initialSize);
static N_INLINE(NI, slotsNeeded__pureZcollectionsZsets_49)(NI count);
N_LIB_PRIVATE N_NIMCALL(NI, nextPowerOfTwo__pureZmath_177)(NI x);
N_LIB_PRIVATE N_NIMCALL(void*, newSeq)(TNimType* typ, NI len);
static N_INLINE(NI, rawGet__options_2639)(tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw t, NimStringDesc* key, NI* hc);
N_LIB_PRIVATE N_NIMCALL(NI, hash__pureZhashes_279)(NimStringDesc* x);
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZsets_38)(NI hcode);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
static N_INLINE(NI, nextTry__pureZcollectionsZsets_41)(NI h, NI maxHash);
static N_INLINE(NIM_BOOL, mustRehash__options_2892)(tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw t);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__options_3084)(tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw* s);
static N_INLINE(NI, rawGetKnownHC__options_3335)(tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw t, NimStringDesc* key, NI hc);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__options_3697)(tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw* s, tySequence__4eRCaZmrYLLw2k30GPTiMw** data, NimStringDesc* key, NI hc, NI h);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
static N_INLINE(void, decRef__system_5309)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5307)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5258)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5264)(void* usr);
static N_INLINE(NI, rawGet__sigmatch_5801)(tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ t, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ key, NI* hc);
N_LIB_PRIVATE N_NIMCALL(NI, hash__sigmatch_5808)(tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ x);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___sigmatch_6056)(tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ x, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ y);
static N_INLINE(NI, rawGet__nilcheck_4345)(tyObject_HashSet__zVZZy9cn25qKcaABhU9aN2vw t, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw key, NI* hc);
N_LIB_PRIVATE N_NIMCALL(NI, hash__lineinfos_233)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw i);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___msgs_1003)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw a, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw b);
static N_INLINE(NIM_BOOL, mustRehash__nilcheck_4720)(tyObject_HashSet__zVZZy9cn25qKcaABhU9aN2vw t);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__nilcheck_4912)(tyObject_HashSet__zVZZy9cn25qKcaABhU9aN2vw* s);
static N_INLINE(NI, rawGetKnownHC__nilcheck_5163)(tyObject_HashSet__zVZZy9cn25qKcaABhU9aN2vw t, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw key, NI hc);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__nilcheck_5525)(tyObject_HashSet__zVZZy9cn25qKcaABhU9aN2vw* s, tySequence__nueg5spSfGVW7EdegG2fTw** data, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw key, NI hc, NI h);
static N_INLINE(NIM_BOOL, mustRehash__importer_333)(tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ t);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__importer_525)(tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ* s);
static N_INLINE(NI, rawGetKnownHC__importer_776)(tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ t, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ key, NI hc);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__importer_1142)(tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ* s, tySequence__Bis5AbpONWcIRrPyPJS8Yw** data, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ key, NI hc, NI h);
static N_INLINE(NI, rawGet__injectdestructors_2482)(tyObject_HashSet__4M9cdYsKLFZugenKrKIlmiA t, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* key, NI* hc);
N_LIB_PRIVATE N_NIMCALL(NI, hash__injectdestructors_118)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NIM_BOOL, mustRehash__injectdestructors_2730)(tyObject_HashSet__4M9cdYsKLFZugenKrKIlmiA t);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__injectdestructors_2922)(tyObject_HashSet__4M9cdYsKLFZugenKrKIlmiA* s);
static N_INLINE(NI, rawGetKnownHC__injectdestructors_3173)(tyObject_HashSet__4M9cdYsKLFZugenKrKIlmiA t, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* key, NI hc);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__injectdestructors_3539)(tyObject_HashSet__4M9cdYsKLFZugenKrKIlmiA* s, tySequence__387YteDgSUbs69cJAUWxHOA** data, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* key, NI hc, NI h);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5302)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
N_LIB_PRIVATE N_NIMCALL(NI, len__injectdestructors_2169)(tyObject_HashSet__4M9cdYsKLFZugenKrKIlmiA s);
N_LIB_PRIVATE N_NIMCALL(void, incl__injectdestructors_2395)(tyObject_HashSet__4M9cdYsKLFZugenKrKIlmiA* s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* key);
static N_INLINE(NI, rawGet__cgen_4259)(tyObject_HashSet__KYwZ0vHsYO0DQEC4qpQkAQ t, tyArray__qtqsWM5aXmcpMIVmvq3kAA key, NI* hc);
N_LIB_PRIVATE N_NIMCALL(NI, hash__modulegraphs_9001)(tyArray__qtqsWM5aXmcpMIVmvq3kAA u);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___modulegraphs_8997)(tyArray__qtqsWM5aXmcpMIVmvq3kAA a, tyArray__qtqsWM5aXmcpMIVmvq3kAA b);
static N_INLINE(NIM_BOOL, mustRehash__cgen_4521)(tyObject_HashSet__KYwZ0vHsYO0DQEC4qpQkAQ t);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__cgen_4713)(tyObject_HashSet__KYwZ0vHsYO0DQEC4qpQkAQ* s);
static N_INLINE(NI, rawGetKnownHC__cgen_4964)(tyObject_HashSet__KYwZ0vHsYO0DQEC4qpQkAQ t, tyArray__qtqsWM5aXmcpMIVmvq3kAA key, NI hc);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__cgen_5326)(tyObject_HashSet__KYwZ0vHsYO0DQEC4qpQkAQ* s, tySequence__WPcy3bORPBFlmk2KIq2pbQ** data, tyArray__qtqsWM5aXmcpMIVmvq3kAA key, NI hc, NI h);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
static N_INLINE(NI, rawGet__icZintegrity_112)(tyObject_HashSet__rOalG16fHtjsOOJNJ8viBg t, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg key, NI* hc);
N_LIB_PRIVATE N_NIMCALL(NI, hash__ast_781)(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg x);
static N_INLINE(NIM_BOOL, eqeq___ast_777)(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg a, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg b);
static N_INLINE(NIM_BOOL, mustRehash__icZintegrity_189)(tyObject_HashSet__rOalG16fHtjsOOJNJ8viBg t);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__icZintegrity_267)(tyObject_HashSet__rOalG16fHtjsOOJNJ8viBg* s);
static N_INLINE(NI, rawGetKnownHC__icZintegrity_333)(tyObject_HashSet__rOalG16fHtjsOOJNJ8viBg t, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg key, NI hc);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__icZintegrity_412)(tyObject_HashSet__rOalG16fHtjsOOJNJ8viBg* s, tySequence__Mh5ToiAHng5Z72oMQ0yKVg** data, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg key, NI hc, NI h);
extern TNimType NTIkeyvaluepairseq__4eRCaZmrYLLw2k30GPTiMw_;
extern TNimType NTIkeyvaluepairseq__nueg5spSfGVW7EdegG2fTw_;
extern TNimType NTIkeyvaluepairseq__Bis5AbpONWcIRrPyPJS8Yw_;
extern TNimType NTIkeyvaluepairseq__387YteDgSUbs69cJAUWxHOA_;
extern TNimType NTIkeyvaluepairseq__WPcy3bORPBFlmk2KIq2pbQ_;
extern TNimType NTIkeyvaluepairseq__Mh5ToiAHng5Z72oMQ0yKVg_;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5211;
static N_INLINE(NI, slotsNeeded__pureZcollectionsZsets_49)(NI count) {
	NI result;
	result = (NI)0;
	result = nextPowerOfTwo__pureZmath_177((NI)((NI)((NI)(((NI) (count)) * ((NI) 3)) / ((NI) 2)) + ((NI) 4)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, init__options_2343)(tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw* s, NI initialSize) {
	NI correctSizeX60gensym32_;
	correctSizeX60gensym32_ = slotsNeeded__pureZcollectionsZsets_49(((NI) (initialSize)));
	(*s).counter = ((NI) 0);
	unsureAsgnRef((void**) (&(*s).data), (tySequence__4eRCaZmrYLLw2k30GPTiMw*) newSeq((&NTIkeyvaluepairseq__4eRCaZmrYLLw2k30GPTiMw_), ((NI) (correctSizeX60gensym32_))));
}
N_LIB_PRIVATE N_NIMCALL(void, initHashSet__options_2335)(NI initialSize, tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw* Result) {
	unsureAsgnRef((void**)&(*Result).data, NIM_NIL);
	(*Result).counter = 0;
	init__options_2343(Result, initialSize);
}
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZsets_38)(NI hcode) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = !((hcode == ((NI) 0)));
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, nextTry__pureZcollectionsZsets_41)(NI h, NI maxHash) {
	NI result;
	result = (NI)0;
	result = (NI)((NI)(h + ((NI) 1)) & maxHash);
	return result;
}
static N_INLINE(NI, rawGet__options_2639)(tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw t, NimStringDesc* key, NI* hc) {
	NI result;
	NI h;
	NI T10_;
{	result = (NI)0;
	(*hc) = hash__pureZhashes_279(key);
	{
		if (!((*hc) == ((NI) 0))) goto LA3_;
		(*hc) = ((NI) 314159265);
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (t.data ? t.data->Sup.len : 0);
		if (!(T7_ == ((NI) 0))) goto LA8_;
		result = ((NI) -1);
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)((*hc) & T10_);
	{
		while (1) {
			NIM_BOOL T13_;
			NI T20_;
			T13_ = (NIM_BOOL)0;
			T13_ = isFilled__pureZcollectionsZsets_38(t.data->data[h].Field0);
			if (!T13_) goto LA12;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = (t.data->data[h].Field0 == (*hc));
				if (!(T16_)) goto LA17_;
				T16_ = eqStrings(t.data->data[h].Field1, key);
				LA17_: ;
				if (!T16_) goto LA18_;
				result = h;
				goto BeforeRet_;
			}
			LA18_: ;
			T20_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__pureZcollectionsZsets_41(h, T20_);
		} LA12: ;
	}
	result = (NI)(((NI) -1) - h);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__options_2892)(tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (t.data ? t.data->Sup.len : 0);
	T1_ = ((NI)(T2_ * ((NI) 2)) < (NI)(t.counter * ((NI) 3)));
	if (T1_) goto LA3_;
	T4_ = (t.data ? t.data->Sup.len : 0);
	T1_ = ((NI)(T4_ - t.counter) < ((NI) 4));
	LA3_: ;
	result = T1_;
	return result;
}
static N_INLINE(NI, rawGetKnownHC__options_3335)(tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw t, NimStringDesc* key, NI hc) {
	NI result;
	NI h;
	NI T6_;
{	result = (NI)0;
	{
		NI T3_;
		T3_ = (t.data ? t.data->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		result = ((NI) -1);
		goto BeforeRet_;
	}
	LA4_: ;
	T6_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)(hc & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZsets_38(t.data->data[h].Field0);
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t.data->data[h].Field0 == hc);
				if (!(T12_)) goto LA13_;
				T12_ = eqStrings(t.data->data[h].Field1, key);
				LA13_: ;
				if (!T12_) goto LA14_;
				result = h;
				goto BeforeRet_;
			}
			LA14_: ;
			T16_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__pureZcollectionsZsets_41(h, T16_);
		} LA8: ;
	}
	result = (NI)(((NI) -1) - h);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5307)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5258((&gch__system_5211.zct), c);
}
static N_INLINE(void, decRef__system_5309)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5307(c);
	}
	LA4_: ;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5264)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5264(p);
	decRef__system_5309(T1_);
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__options_3697)(tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw* s, tySequence__4eRCaZmrYLLw2k30GPTiMw** data, NimStringDesc* key, NI hc, NI h) {
	NimStringDesc* T6_;
	{
		NI T3_;
		NI correctSizeX60gensym43_;
		T3_ = ((*data) ? (*data)->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		correctSizeX60gensym43_ = slotsNeeded__pureZcollectionsZsets_49(((NI) 64));
		(*s).counter = ((NI) 0);
		unsureAsgnRef((void**) (&(*s).data), (tySequence__4eRCaZmrYLLw2k30GPTiMw*) newSeq((&NTIkeyvaluepairseq__4eRCaZmrYLLw2k30GPTiMw_), ((NI) (correctSizeX60gensym43_))));
	}
	LA4_: ;
	T6_ = NIM_NIL;
	T6_ = (*data)->data[h].Field1; (*data)->data[h].Field1 = copyStringRC1(key);
	if (T6_) nimGCunrefNoCycle(T6_);
	(*data)->data[h].Field0 = hc;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__options_3084)(tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw* s) {
	tySequence__4eRCaZmrYLLw2k30GPTiMw* n;
	NI T1_;
	tySequence__4eRCaZmrYLLw2k30GPTiMw* T2_;
	n = NIM_NIL;
	T1_ = ((*s).data ? (*s).data->Sup.len : 0);
	n = (tySequence__4eRCaZmrYLLw2k30GPTiMw*) newSeq((&NTIkeyvaluepairseq__4eRCaZmrYLLw2k30GPTiMw_), ((NI) ((NI)(T1_ * ((NI) 2)))));
	T2_ = NIM_NIL;
	T2_ = (*s).data;
	unsureAsgnRef((void**) (&(*s).data), n);
	n = T2_;
	{
		NI i;
		NI colontmp_;
		NI T4_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T4_ = ((n ? n->Sup.len : 0)-1);
		colontmp_ = T4_;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA6;
				i = res;
				{
					NIM_BOOL T9_;
					NI j;
					NI T12_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZsets_38(n->data[i].Field0);
					if (!T9_) goto LA10_;
					T12_ = (NI)0;
					T12_ = rawGetKnownHC__options_3335((*s), n->data[i].Field1, n->data[i].Field0);
					j = (NI)(((NI) -1) - T12_);
					rawInsert__options_3697(s, (&(*s).data), n->data[i].Field1, n->data[i].Field0, j);
				}
				LA10_: ;
				res += ((NI) 1);
			} LA6: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, incl__options_2552)(tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw* s, NimStringDesc* key) {
	NI hc;
	NI index;
	{
		NI T3_;
		NI correctSizeX60gensym34_;
		T3_ = ((*s).data ? (*s).data->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		correctSizeX60gensym34_ = slotsNeeded__pureZcollectionsZsets_49(((NI) 64));
		(*s).counter = ((NI) 0);
		unsureAsgnRef((void**) (&(*s).data), (tySequence__4eRCaZmrYLLw2k30GPTiMw*) newSeq((&NTIkeyvaluepairseq__4eRCaZmrYLLw2k30GPTiMw_), ((NI) (correctSizeX60gensym34_))));
	}
	LA4_: ;
	hc = (NI)0;
	index = rawGet__options_2639((*s), key, (&hc));
	{
		if (!(index < ((NI) 0))) goto LA8_;
		{
			NIM_BOOL T12_;
			T12_ = (NIM_BOOL)0;
			T12_ = mustRehash__options_2892((*s));
			if (!T12_) goto LA13_;
			enlarge__options_3084(s);
			index = rawGetKnownHC__options_3335((*s), key, hc);
		}
		LA13_: ;
		rawInsert__options_3697(s, (&(*s).data), key, hc, (NI)(((NI) -1) - index));
		(*s).counter += ((NI) 1);
	}
	LA8_: ;
}
static N_INLINE(NI, rawGet__sigmatch_5801)(tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ t, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ key, NI* hc) {
	NI result;
	NI h;
	NI T10_;
{	result = (NI)0;
	(*hc) = hash__sigmatch_5808(key);
	{
		if (!((*hc) == ((NI) 0))) goto LA3_;
		(*hc) = ((NI) 314159265);
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (t.data ? t.data->Sup.len : 0);
		if (!(T7_ == ((NI) 0))) goto LA8_;
		result = ((NI) -1);
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)((*hc) & T10_);
	{
		while (1) {
			NIM_BOOL T13_;
			NI T20_;
			T13_ = (NIM_BOOL)0;
			T13_ = isFilled__pureZcollectionsZsets_38(t.data->data[h].Field0);
			if (!T13_) goto LA12;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = (t.data->data[h].Field0 == (*hc));
				if (!(T16_)) goto LA17_;
				T16_ = eqeq___sigmatch_6056(t.data->data[h].Field1, key);
				LA17_: ;
				if (!T16_) goto LA18_;
				result = h;
				goto BeforeRet_;
			}
			LA18_: ;
			T20_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__pureZcollectionsZsets_41(h, T20_);
		} LA12: ;
	}
	result = (NI)(((NI) -1) - h);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__sigmatch_5788)(tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ s, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ key) {
	NIM_BOOL result;
	NI hc;
	NI index;
	result = (NIM_BOOL)0;
	hc = (NI)0;
	index = rawGet__sigmatch_5801(s, key, (&hc));
	result = (((NI) 0) <= index);
	return result;
}
static N_INLINE(NI, rawGet__nilcheck_4345)(tyObject_HashSet__zVZZy9cn25qKcaABhU9aN2vw t, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw key, NI* hc) {
	NI result;
	NI h;
	NI T10_;
{	result = (NI)0;
	(*hc) = hash__lineinfos_233(key);
	{
		if (!((*hc) == ((NI) 0))) goto LA3_;
		(*hc) = ((NI) 314159265);
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (t.data ? t.data->Sup.len : 0);
		if (!(T7_ == ((NI) 0))) goto LA8_;
		result = ((NI) -1);
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)((*hc) & T10_);
	{
		while (1) {
			NIM_BOOL T13_;
			NI T20_;
			T13_ = (NIM_BOOL)0;
			T13_ = isFilled__pureZcollectionsZsets_38(t.data->data[h].Field0);
			if (!T13_) goto LA12;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = (t.data->data[h].Field0 == (*hc));
				if (!(T16_)) goto LA17_;
				T16_ = eqeq___msgs_1003(t.data->data[h].Field1, key);
				LA17_: ;
				if (!T16_) goto LA18_;
				result = h;
				goto BeforeRet_;
			}
			LA18_: ;
			T20_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__pureZcollectionsZsets_41(h, T20_);
		} LA12: ;
	}
	result = (NI)(((NI) -1) - h);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__nilcheck_4332)(tyObject_HashSet__zVZZy9cn25qKcaABhU9aN2vw s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw key) {
	NIM_BOOL result;
	NI hc;
	NI index;
	result = (NIM_BOOL)0;
	hc = (NI)0;
	index = rawGet__nilcheck_4345(s, key, (&hc));
	result = (((NI) 0) <= index);
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__nilcheck_4720)(tyObject_HashSet__zVZZy9cn25qKcaABhU9aN2vw t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (t.data ? t.data->Sup.len : 0);
	T1_ = ((NI)(T2_ * ((NI) 2)) < (NI)(t.counter * ((NI) 3)));
	if (T1_) goto LA3_;
	T4_ = (t.data ? t.data->Sup.len : 0);
	T1_ = ((NI)(T4_ - t.counter) < ((NI) 4));
	LA3_: ;
	result = T1_;
	return result;
}
static N_INLINE(NI, rawGetKnownHC__nilcheck_5163)(tyObject_HashSet__zVZZy9cn25qKcaABhU9aN2vw t, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw key, NI hc) {
	NI result;
	NI h;
	NI T6_;
{	result = (NI)0;
	{
		NI T3_;
		T3_ = (t.data ? t.data->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		result = ((NI) -1);
		goto BeforeRet_;
	}
	LA4_: ;
	T6_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)(hc & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZsets_38(t.data->data[h].Field0);
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t.data->data[h].Field0 == hc);
				if (!(T12_)) goto LA13_;
				T12_ = eqeq___msgs_1003(t.data->data[h].Field1, key);
				LA13_: ;
				if (!T12_) goto LA14_;
				result = h;
				goto BeforeRet_;
			}
			LA14_: ;
			T16_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__pureZcollectionsZsets_41(h, T16_);
		} LA8: ;
	}
	result = (NI)(((NI) -1) - h);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__nilcheck_5525)(tyObject_HashSet__zVZZy9cn25qKcaABhU9aN2vw* s, tySequence__nueg5spSfGVW7EdegG2fTw** data, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw key, NI hc, NI h) {
	{
		NI T3_;
		NI correctSizeX60gensym48_;
		T3_ = ((*data) ? (*data)->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		correctSizeX60gensym48_ = slotsNeeded__pureZcollectionsZsets_49(((NI) 64));
		(*s).counter = ((NI) 0);
		unsureAsgnRef((void**) (&(*s).data), (tySequence__nueg5spSfGVW7EdegG2fTw*) newSeq((&NTIkeyvaluepairseq__nueg5spSfGVW7EdegG2fTw_), ((NI) (correctSizeX60gensym48_))));
	}
	LA4_: ;
	(*data)->data[h].Field1 = key;
	(*data)->data[h].Field0 = hc;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__nilcheck_4912)(tyObject_HashSet__zVZZy9cn25qKcaABhU9aN2vw* s) {
	tySequence__nueg5spSfGVW7EdegG2fTw* n;
	NI T1_;
	tySequence__nueg5spSfGVW7EdegG2fTw* T2_;
	n = NIM_NIL;
	T1_ = ((*s).data ? (*s).data->Sup.len : 0);
	n = (tySequence__nueg5spSfGVW7EdegG2fTw*) newSeq((&NTIkeyvaluepairseq__nueg5spSfGVW7EdegG2fTw_), ((NI) ((NI)(T1_ * ((NI) 2)))));
	T2_ = NIM_NIL;
	T2_ = (*s).data;
	unsureAsgnRef((void**) (&(*s).data), n);
	n = T2_;
	{
		NI i;
		NI colontmp_;
		NI T4_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T4_ = ((n ? n->Sup.len : 0)-1);
		colontmp_ = T4_;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA6;
				i = res;
				{
					NIM_BOOL T9_;
					NI j;
					NI T12_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZsets_38(n->data[i].Field0);
					if (!T9_) goto LA10_;
					T12_ = (NI)0;
					T12_ = rawGetKnownHC__nilcheck_5163((*s), n->data[i].Field1, n->data[i].Field0);
					j = (NI)(((NI) -1) - T12_);
					rawInsert__nilcheck_5525(s, (&(*s).data), n->data[i].Field1, n->data[i].Field0, j);
				}
				LA10_: ;
				res += ((NI) 1);
			} LA6: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, incl__nilcheck_4627)(tyObject_HashSet__zVZZy9cn25qKcaABhU9aN2vw* s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw key) {
	NI hc;
	NI index;
	{
		NI T3_;
		NI correctSizeX60gensym41_;
		T3_ = ((*s).data ? (*s).data->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		correctSizeX60gensym41_ = slotsNeeded__pureZcollectionsZsets_49(((NI) 64));
		(*s).counter = ((NI) 0);
		unsureAsgnRef((void**) (&(*s).data), (tySequence__nueg5spSfGVW7EdegG2fTw*) newSeq((&NTIkeyvaluepairseq__nueg5spSfGVW7EdegG2fTw_), ((NI) (correctSizeX60gensym41_))));
	}
	LA4_: ;
	hc = (NI)0;
	index = rawGet__nilcheck_4345((*s), key, (&hc));
	{
		if (!(index < ((NI) 0))) goto LA8_;
		{
			NIM_BOOL T12_;
			T12_ = (NIM_BOOL)0;
			T12_ = mustRehash__nilcheck_4720((*s));
			if (!T12_) goto LA13_;
			enlarge__nilcheck_4912(s);
			index = rawGetKnownHC__nilcheck_5163((*s), key, hc);
		}
		LA13_: ;
		rawInsert__nilcheck_5525(s, (&(*s).data), key, hc, (NI)(((NI) -1) - index));
		(*s).counter += ((NI) 1);
	}
	LA8_: ;
}
static N_INLINE(NIM_BOOL, mustRehash__importer_333)(tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (t.data ? t.data->Sup.len : 0);
	T1_ = ((NI)(T2_ * ((NI) 2)) < (NI)(t.counter * ((NI) 3)));
	if (T1_) goto LA3_;
	T4_ = (t.data ? t.data->Sup.len : 0);
	T1_ = ((NI)(T4_ - t.counter) < ((NI) 4));
	LA3_: ;
	result = T1_;
	return result;
}
static N_INLINE(NI, rawGetKnownHC__importer_776)(tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ t, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ key, NI hc) {
	NI result;
	NI h;
	NI T6_;
{	result = (NI)0;
	{
		NI T3_;
		T3_ = (t.data ? t.data->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		result = ((NI) -1);
		goto BeforeRet_;
	}
	LA4_: ;
	T6_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)(hc & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZsets_38(t.data->data[h].Field0);
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t.data->data[h].Field0 == hc);
				if (!(T12_)) goto LA13_;
				T12_ = eqeq___sigmatch_6056(t.data->data[h].Field1, key);
				LA13_: ;
				if (!T12_) goto LA14_;
				result = h;
				goto BeforeRet_;
			}
			LA14_: ;
			T16_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__pureZcollectionsZsets_41(h, T16_);
		} LA8: ;
	}
	result = (NI)(((NI) -1) - h);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__importer_1142)(tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ* s, tySequence__Bis5AbpONWcIRrPyPJS8Yw** data, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ key, NI hc, NI h) {
	{
		NI T3_;
		NI correctSizeX60gensym36_;
		T3_ = ((*data) ? (*data)->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		correctSizeX60gensym36_ = slotsNeeded__pureZcollectionsZsets_49(((NI) 64));
		(*s).counter = ((NI) 0);
		unsureAsgnRef((void**) (&(*s).data), (tySequence__Bis5AbpONWcIRrPyPJS8Yw*) newSeq((&NTIkeyvaluepairseq__Bis5AbpONWcIRrPyPJS8Yw_), ((NI) (correctSizeX60gensym36_))));
	}
	LA4_: ;
	(*data)->data[h].Field1 = key;
	(*data)->data[h].Field0 = hc;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__importer_525)(tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ* s) {
	tySequence__Bis5AbpONWcIRrPyPJS8Yw* n;
	NI T1_;
	tySequence__Bis5AbpONWcIRrPyPJS8Yw* T2_;
	n = NIM_NIL;
	T1_ = ((*s).data ? (*s).data->Sup.len : 0);
	n = (tySequence__Bis5AbpONWcIRrPyPJS8Yw*) newSeq((&NTIkeyvaluepairseq__Bis5AbpONWcIRrPyPJS8Yw_), ((NI) ((NI)(T1_ * ((NI) 2)))));
	T2_ = NIM_NIL;
	T2_ = (*s).data;
	unsureAsgnRef((void**) (&(*s).data), n);
	n = T2_;
	{
		NI i;
		NI colontmp_;
		NI T4_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T4_ = ((n ? n->Sup.len : 0)-1);
		colontmp_ = T4_;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA6;
				i = res;
				{
					NIM_BOOL T9_;
					NI j;
					NI T12_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZsets_38(n->data[i].Field0);
					if (!T9_) goto LA10_;
					T12_ = (NI)0;
					T12_ = rawGetKnownHC__importer_776((*s), n->data[i].Field1, n->data[i].Field0);
					j = (NI)(((NI) -1) - T12_);
					rawInsert__importer_1142(s, (&(*s).data), n->data[i].Field1, n->data[i].Field0, j);
				}
				LA10_: ;
				res += ((NI) 1);
			} LA6: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, incl__importer_240)(tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ* s, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ key) {
	NI hc;
	NI index;
	{
		NI T3_;
		NI correctSizeX60gensym29_;
		T3_ = ((*s).data ? (*s).data->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		correctSizeX60gensym29_ = slotsNeeded__pureZcollectionsZsets_49(((NI) 64));
		(*s).counter = ((NI) 0);
		unsureAsgnRef((void**) (&(*s).data), (tySequence__Bis5AbpONWcIRrPyPJS8Yw*) newSeq((&NTIkeyvaluepairseq__Bis5AbpONWcIRrPyPJS8Yw_), ((NI) (correctSizeX60gensym29_))));
	}
	LA4_: ;
	hc = (NI)0;
	index = rawGet__sigmatch_5801((*s), key, (&hc));
	{
		if (!(index < ((NI) 0))) goto LA8_;
		{
			NIM_BOOL T12_;
			T12_ = (NIM_BOOL)0;
			T12_ = mustRehash__importer_333((*s));
			if (!T12_) goto LA13_;
			enlarge__importer_525(s);
			index = rawGetKnownHC__importer_776((*s), key, hc);
		}
		LA13_: ;
		rawInsert__importer_1142(s, (&(*s).data), key, hc, (NI)(((NI) -1) - index));
		(*s).counter += ((NI) 1);
	}
	LA8_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, len__injectdestructors_2169)(tyObject_HashSet__4M9cdYsKLFZugenKrKIlmiA s) {
	NI result;
	result = (NI)0;
	result = s.counter;
	return result;
}
static N_INLINE(NI, rawGet__injectdestructors_2482)(tyObject_HashSet__4M9cdYsKLFZugenKrKIlmiA t, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* key, NI* hc) {
	NI result;
	NI h;
	NI T10_;
{	result = (NI)0;
	(*hc) = hash__injectdestructors_118(key);
	{
		if (!((*hc) == ((NI) 0))) goto LA3_;
		(*hc) = ((NI) 314159265);
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (t.data ? t.data->Sup.len : 0);
		if (!(T7_ == ((NI) 0))) goto LA8_;
		result = ((NI) -1);
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)((*hc) & T10_);
	{
		while (1) {
			NIM_BOOL T13_;
			NI T20_;
			T13_ = (NIM_BOOL)0;
			T13_ = isFilled__pureZcollectionsZsets_38(t.data->data[h].Field0);
			if (!T13_) goto LA12;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = (t.data->data[h].Field0 == (*hc));
				if (!(T16_)) goto LA17_;
				T16_ = (t.data->data[h].Field1 == key);
				LA17_: ;
				if (!T16_) goto LA18_;
				result = h;
				goto BeforeRet_;
			}
			LA18_: ;
			T20_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__pureZcollectionsZsets_41(h, T20_);
		} LA12: ;
	}
	result = (NI)(((NI) -1) - h);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__injectdestructors_2730)(tyObject_HashSet__4M9cdYsKLFZugenKrKIlmiA t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (t.data ? t.data->Sup.len : 0);
	T1_ = ((NI)(T2_ * ((NI) 2)) < (NI)(t.counter * ((NI) 3)));
	if (T1_) goto LA3_;
	T4_ = (t.data ? t.data->Sup.len : 0);
	T1_ = ((NI)(T4_ - t.counter) < ((NI) 4));
	LA3_: ;
	result = T1_;
	return result;
}
static N_INLINE(NI, rawGetKnownHC__injectdestructors_3173)(tyObject_HashSet__4M9cdYsKLFZugenKrKIlmiA t, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* key, NI hc) {
	NI result;
	NI h;
	NI T6_;
{	result = (NI)0;
	{
		NI T3_;
		T3_ = (t.data ? t.data->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		result = ((NI) -1);
		goto BeforeRet_;
	}
	LA4_: ;
	T6_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)(hc & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZsets_38(t.data->data[h].Field0);
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t.data->data[h].Field0 == hc);
				if (!(T12_)) goto LA13_;
				T12_ = (t.data->data[h].Field1 == key);
				LA13_: ;
				if (!T12_) goto LA14_;
				result = h;
				goto BeforeRet_;
			}
			LA14_: ;
			T16_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__pureZcollectionsZsets_41(h, T16_);
		} LA8: ;
	}
	result = (NI)(((NI) -1) - h);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5302)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5264(src);
		incRef__system_5302(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5264((*dest));
		decRef__system_5309(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__injectdestructors_3539)(tyObject_HashSet__4M9cdYsKLFZugenKrKIlmiA* s, tySequence__387YteDgSUbs69cJAUWxHOA** data, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* key, NI hc, NI h) {
	{
		NI T3_;
		NI correctSizeX60gensym32_;
		T3_ = ((*data) ? (*data)->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		correctSizeX60gensym32_ = slotsNeeded__pureZcollectionsZsets_49(((NI) 64));
		(*s).counter = ((NI) 0);
		unsureAsgnRef((void**) (&(*s).data), (tySequence__387YteDgSUbs69cJAUWxHOA*) newSeq((&NTIkeyvaluepairseq__387YteDgSUbs69cJAUWxHOA_), ((NI) (correctSizeX60gensym32_))));
	}
	LA4_: ;
	asgnRef((void**) (&(*data)->data[h].Field1), key);
	(*data)->data[h].Field0 = hc;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__injectdestructors_2922)(tyObject_HashSet__4M9cdYsKLFZugenKrKIlmiA* s) {
	tySequence__387YteDgSUbs69cJAUWxHOA* n;
	NI T1_;
	tySequence__387YteDgSUbs69cJAUWxHOA* T2_;
	n = NIM_NIL;
	T1_ = ((*s).data ? (*s).data->Sup.len : 0);
	n = (tySequence__387YteDgSUbs69cJAUWxHOA*) newSeq((&NTIkeyvaluepairseq__387YteDgSUbs69cJAUWxHOA_), ((NI) ((NI)(T1_ * ((NI) 2)))));
	T2_ = NIM_NIL;
	T2_ = (*s).data;
	unsureAsgnRef((void**) (&(*s).data), n);
	n = T2_;
	{
		NI i;
		NI colontmp_;
		NI T4_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T4_ = ((n ? n->Sup.len : 0)-1);
		colontmp_ = T4_;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA6;
				i = res;
				{
					NIM_BOOL T9_;
					NI j;
					NI T12_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZsets_38(n->data[i].Field0);
					if (!T9_) goto LA10_;
					T12_ = (NI)0;
					T12_ = rawGetKnownHC__injectdestructors_3173((*s), n->data[i].Field1, n->data[i].Field0);
					j = (NI)(((NI) -1) - T12_);
					rawInsert__injectdestructors_3539(s, (&(*s).data), n->data[i].Field1, n->data[i].Field0, j);
				}
				LA10_: ;
				res += ((NI) 1);
			} LA6: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, incl__injectdestructors_2395)(tyObject_HashSet__4M9cdYsKLFZugenKrKIlmiA* s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* key) {
	NI hc;
	NI index;
	{
		NI T3_;
		NI correctSizeX60gensym23_;
		T3_ = ((*s).data ? (*s).data->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		correctSizeX60gensym23_ = slotsNeeded__pureZcollectionsZsets_49(((NI) 64));
		(*s).counter = ((NI) 0);
		unsureAsgnRef((void**) (&(*s).data), (tySequence__387YteDgSUbs69cJAUWxHOA*) newSeq((&NTIkeyvaluepairseq__387YteDgSUbs69cJAUWxHOA_), ((NI) (correctSizeX60gensym23_))));
	}
	LA4_: ;
	hc = (NI)0;
	index = rawGet__injectdestructors_2482((*s), key, (&hc));
	{
		if (!(index < ((NI) 0))) goto LA8_;
		{
			NIM_BOOL T12_;
			T12_ = (NIM_BOOL)0;
			T12_ = mustRehash__injectdestructors_2730((*s));
			if (!T12_) goto LA13_;
			enlarge__injectdestructors_2922(s);
			index = rawGetKnownHC__injectdestructors_3173((*s), key, hc);
		}
		LA13_: ;
		rawInsert__injectdestructors_3539(s, (&(*s).data), key, hc, (NI)(((NI) -1) - index));
		(*s).counter += ((NI) 1);
	}
	LA8_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, incl__injectdestructors_2107)(tyObject_HashSet__4M9cdYsKLFZugenKrKIlmiA* s, tyObject_HashSet__4M9cdYsKLFZugenKrKIlmiA other) {
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* item;
		NI length;
		item = NIM_NIL;
		length = len__injectdestructors_2169(other);
		{
			NI h;
			NI colontmp_;
			NI T3_;
			NI res;
			h = (NI)0;
			colontmp_ = (NI)0;
			T3_ = ((other.data ? other.data->Sup.len : 0)-1);
			colontmp_ = T3_;
			res = ((NI) 0);
			{
				while (1) {
					if (!(res <= colontmp_)) goto LA5;
					h = res;
					{
						NIM_BOOL T8_;
						T8_ = (NIM_BOOL)0;
						T8_ = isFilled__pureZcollectionsZsets_38(other.data->data[h].Field0);
						if (!T8_) goto LA9_;
						item = other.data->data[h].Field1;
						incl__injectdestructors_2395(s, item);
					}
					LA9_: ;
					res += ((NI) 1);
				} LA5: ;
			}
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__cgen_720)(tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw s, NimStringDesc* key) {
	NIM_BOOL result;
	NI hc;
	NI index;
	result = (NIM_BOOL)0;
	hc = (NI)0;
	index = rawGet__options_2639(s, key, (&hc));
	result = (((NI) 0) <= index);
	return result;
}
static N_INLINE(NI, rawGet__cgen_4259)(tyObject_HashSet__KYwZ0vHsYO0DQEC4qpQkAQ t, tyArray__qtqsWM5aXmcpMIVmvq3kAA key, NI* hc) {
	NI result;
	NI h;
	NI T10_;
{	result = (NI)0;
	(*hc) = hash__modulegraphs_9001(key);
	{
		if (!((*hc) == ((NI) 0))) goto LA3_;
		(*hc) = ((NI) 314159265);
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (t.data ? t.data->Sup.len : 0);
		if (!(T7_ == ((NI) 0))) goto LA8_;
		result = ((NI) -1);
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)((*hc) & T10_);
	{
		while (1) {
			NIM_BOOL T13_;
			NI T20_;
			T13_ = (NIM_BOOL)0;
			T13_ = isFilled__pureZcollectionsZsets_38(t.data->data[h].Field0);
			if (!T13_) goto LA12;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = (t.data->data[h].Field0 == (*hc));
				if (!(T16_)) goto LA17_;
				T16_ = eqeq___modulegraphs_8997(t.data->data[h].Field1, key);
				LA17_: ;
				if (!T16_) goto LA18_;
				result = h;
				goto BeforeRet_;
			}
			LA18_: ;
			T20_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__pureZcollectionsZsets_41(h, T20_);
		} LA12: ;
	}
	result = (NI)(((NI) -1) - h);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__cgen_4521)(tyObject_HashSet__KYwZ0vHsYO0DQEC4qpQkAQ t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (t.data ? t.data->Sup.len : 0);
	T1_ = ((NI)(T2_ * ((NI) 2)) < (NI)(t.counter * ((NI) 3)));
	if (T1_) goto LA3_;
	T4_ = (t.data ? t.data->Sup.len : 0);
	T1_ = ((NI)(T4_ - t.counter) < ((NI) 4));
	LA3_: ;
	result = T1_;
	return result;
}
static N_INLINE(NI, rawGetKnownHC__cgen_4964)(tyObject_HashSet__KYwZ0vHsYO0DQEC4qpQkAQ t, tyArray__qtqsWM5aXmcpMIVmvq3kAA key, NI hc) {
	NI result;
	NI h;
	NI T6_;
{	result = (NI)0;
	{
		NI T3_;
		T3_ = (t.data ? t.data->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		result = ((NI) -1);
		goto BeforeRet_;
	}
	LA4_: ;
	T6_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)(hc & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZsets_38(t.data->data[h].Field0);
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t.data->data[h].Field0 == hc);
				if (!(T12_)) goto LA13_;
				T12_ = eqeq___modulegraphs_8997(t.data->data[h].Field1, key);
				LA13_: ;
				if (!T12_) goto LA14_;
				result = h;
				goto BeforeRet_;
			}
			LA14_: ;
			T16_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__pureZcollectionsZsets_41(h, T16_);
		} LA8: ;
	}
	result = (NI)(((NI) -1) - h);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__cgen_5326)(tyObject_HashSet__KYwZ0vHsYO0DQEC4qpQkAQ* s, tySequence__WPcy3bORPBFlmk2KIq2pbQ** data, tyArray__qtqsWM5aXmcpMIVmvq3kAA key, NI hc, NI h) {
	{
		NI T3_;
		NI correctSizeX60gensym398_;
		T3_ = ((*data) ? (*data)->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		correctSizeX60gensym398_ = slotsNeeded__pureZcollectionsZsets_49(((NI) 64));
		(*s).counter = ((NI) 0);
		unsureAsgnRef((void**) (&(*s).data), (tySequence__WPcy3bORPBFlmk2KIq2pbQ*) newSeq((&NTIkeyvaluepairseq__WPcy3bORPBFlmk2KIq2pbQ_), ((NI) (correctSizeX60gensym398_))));
	}
	LA4_: ;
	nimCopyMem((void*)(*data)->data[h].Field1, (NIM_CONST void*)key, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
	(*data)->data[h].Field0 = hc;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__cgen_4713)(tyObject_HashSet__KYwZ0vHsYO0DQEC4qpQkAQ* s) {
	tySequence__WPcy3bORPBFlmk2KIq2pbQ* n;
	NI T1_;
	tySequence__WPcy3bORPBFlmk2KIq2pbQ* T2_;
	n = NIM_NIL;
	T1_ = ((*s).data ? (*s).data->Sup.len : 0);
	n = (tySequence__WPcy3bORPBFlmk2KIq2pbQ*) newSeq((&NTIkeyvaluepairseq__WPcy3bORPBFlmk2KIq2pbQ_), ((NI) ((NI)(T1_ * ((NI) 2)))));
	T2_ = NIM_NIL;
	T2_ = (*s).data;
	unsureAsgnRef((void**) (&(*s).data), n);
	n = T2_;
	{
		NI i;
		NI colontmp_;
		NI T4_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T4_ = ((n ? n->Sup.len : 0)-1);
		colontmp_ = T4_;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA6;
				i = res;
				{
					NIM_BOOL T9_;
					NI j;
					NI T12_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZsets_38(n->data[i].Field0);
					if (!T9_) goto LA10_;
					T12_ = (NI)0;
					T12_ = rawGetKnownHC__cgen_4964((*s), n->data[i].Field1, n->data[i].Field0);
					j = (NI)(((NI) -1) - T12_);
					rawInsert__cgen_5326(s, (&(*s).data), n->data[i].Field1, n->data[i].Field0, j);
				}
				LA10_: ;
				res += ((NI) 1);
			} LA6: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__cgen_4171)(tyObject_HashSet__KYwZ0vHsYO0DQEC4qpQkAQ* s, tyArray__qtqsWM5aXmcpMIVmvq3kAA key) {
	NIM_BOOL result;
	NI hc;
	NI index;
	result = (NIM_BOOL)0;
	{
		NI T3_;
		NI correctSizeX60gensym389_;
		T3_ = ((*s).data ? (*s).data->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		correctSizeX60gensym389_ = slotsNeeded__pureZcollectionsZsets_49(((NI) 64));
		(*s).counter = ((NI) 0);
		unsureAsgnRef((void**) (&(*s).data), (tySequence__WPcy3bORPBFlmk2KIq2pbQ*) newSeq((&NTIkeyvaluepairseq__WPcy3bORPBFlmk2KIq2pbQ_), ((NI) (correctSizeX60gensym389_))));
	}
	LA4_: ;
	hc = (NI)0;
	index = rawGet__cgen_4259((*s), key, (&hc));
	{
		if (!(((NI) 0) <= index)) goto LA8_;
		result = NIM_TRUE;
	}
	goto LA6_;
	LA8_: ;
	{
		{
			NIM_BOOL T13_;
			T13_ = (NIM_BOOL)0;
			T13_ = mustRehash__cgen_4521((*s));
			if (!T13_) goto LA14_;
			enlarge__cgen_4713(s);
			index = rawGetKnownHC__cgen_4964((*s), key, hc);
		}
		LA14_: ;
		rawInsert__cgen_5326(s, (&(*s).data), key, hc, (NI)(((NI) -1) - index));
		(*s).counter += ((NI) 1);
	}
	LA6_: ;
	return result;
}
static N_INLINE(NIM_BOOL, eqeq___ast_777)(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg a, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg b) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (a.item == b.item);
	if (!(T1_)) goto LA2_;
	T1_ = (a.module == b.module);
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(NI, rawGet__icZintegrity_112)(tyObject_HashSet__rOalG16fHtjsOOJNJ8viBg t, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg key, NI* hc) {
	NI result;
	NI h;
	NI T10_;
{	result = (NI)0;
	(*hc) = hash__ast_781(key);
	{
		if (!((*hc) == ((NI) 0))) goto LA3_;
		(*hc) = ((NI) 314159265);
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (t.data ? t.data->Sup.len : 0);
		if (!(T7_ == ((NI) 0))) goto LA8_;
		result = ((NI) -1);
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)((*hc) & T10_);
	{
		while (1) {
			NIM_BOOL T13_;
			NI T20_;
			T13_ = (NIM_BOOL)0;
			T13_ = isFilled__pureZcollectionsZsets_38(t.data->data[h].Field0);
			if (!T13_) goto LA12;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = (t.data->data[h].Field0 == (*hc));
				if (!(T16_)) goto LA17_;
				T16_ = eqeq___ast_777(t.data->data[h].Field1, key);
				LA17_: ;
				if (!T16_) goto LA18_;
				result = h;
				goto BeforeRet_;
			}
			LA18_: ;
			T20_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__pureZcollectionsZsets_41(h, T20_);
		} LA12: ;
	}
	result = (NI)(((NI) -1) - h);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__icZintegrity_189)(tyObject_HashSet__rOalG16fHtjsOOJNJ8viBg t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (t.data ? t.data->Sup.len : 0);
	T1_ = ((NI)(T2_ * ((NI) 2)) < (NI)(t.counter * ((NI) 3)));
	if (T1_) goto LA3_;
	T4_ = (t.data ? t.data->Sup.len : 0);
	T1_ = ((NI)(T4_ - t.counter) < ((NI) 4));
	LA3_: ;
	result = T1_;
	return result;
}
static N_INLINE(NI, rawGetKnownHC__icZintegrity_333)(tyObject_HashSet__rOalG16fHtjsOOJNJ8viBg t, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg key, NI hc) {
	NI result;
	NI h;
	NI T6_;
{	result = (NI)0;
	{
		NI T3_;
		T3_ = (t.data ? t.data->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		result = ((NI) -1);
		goto BeforeRet_;
	}
	LA4_: ;
	T6_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)(hc & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZsets_38(t.data->data[h].Field0);
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t.data->data[h].Field0 == hc);
				if (!(T12_)) goto LA13_;
				T12_ = eqeq___ast_777(t.data->data[h].Field1, key);
				LA13_: ;
				if (!T12_) goto LA14_;
				result = h;
				goto BeforeRet_;
			}
			LA14_: ;
			T16_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__pureZcollectionsZsets_41(h, T16_);
		} LA8: ;
	}
	result = (NI)(((NI) -1) - h);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__icZintegrity_412)(tyObject_HashSet__rOalG16fHtjsOOJNJ8viBg* s, tySequence__Mh5ToiAHng5Z72oMQ0yKVg** data, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg key, NI hc, NI h) {
	{
		NI T3_;
		NI correctSizeX60gensym12_;
		T3_ = ((*data) ? (*data)->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		correctSizeX60gensym12_ = slotsNeeded__pureZcollectionsZsets_49(((NI) 64));
		(*s).counter = ((NI) 0);
		unsureAsgnRef((void**) (&(*s).data), (tySequence__Mh5ToiAHng5Z72oMQ0yKVg*) newSeq((&NTIkeyvaluepairseq__Mh5ToiAHng5Z72oMQ0yKVg_), ((NI) (correctSizeX60gensym12_))));
	}
	LA4_: ;
	(*data)->data[h].Field1 = key;
	(*data)->data[h].Field0 = hc;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__icZintegrity_267)(tyObject_HashSet__rOalG16fHtjsOOJNJ8viBg* s) {
	tySequence__Mh5ToiAHng5Z72oMQ0yKVg* n;
	NI T1_;
	tySequence__Mh5ToiAHng5Z72oMQ0yKVg* T2_;
	n = NIM_NIL;
	T1_ = ((*s).data ? (*s).data->Sup.len : 0);
	n = (tySequence__Mh5ToiAHng5Z72oMQ0yKVg*) newSeq((&NTIkeyvaluepairseq__Mh5ToiAHng5Z72oMQ0yKVg_), ((NI) ((NI)(T1_ * ((NI) 2)))));
	T2_ = NIM_NIL;
	T2_ = (*s).data;
	unsureAsgnRef((void**) (&(*s).data), n);
	n = T2_;
	{
		NI i;
		NI colontmp_;
		NI T4_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T4_ = ((n ? n->Sup.len : 0)-1);
		colontmp_ = T4_;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA6;
				i = res;
				{
					NIM_BOOL T9_;
					NI j;
					NI T12_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZsets_38(n->data[i].Field0);
					if (!T9_) goto LA10_;
					T12_ = (NI)0;
					T12_ = rawGetKnownHC__icZintegrity_333((*s), n->data[i].Field1, n->data[i].Field0);
					j = (NI)(((NI) -1) - T12_);
					rawInsert__icZintegrity_412(s, (&(*s).data), n->data[i].Field1, n->data[i].Field0, j);
				}
				LA10_: ;
				res += ((NI) 1);
			} LA6: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__icZintegrity_62)(tyObject_HashSet__rOalG16fHtjsOOJNJ8viBg* s, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg key) {
	NIM_BOOL result;
	NI hc;
	NI index;
	result = (NIM_BOOL)0;
	{
		NI T3_;
		NI correctSizeX60gensym3_;
		T3_ = ((*s).data ? (*s).data->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		correctSizeX60gensym3_ = slotsNeeded__pureZcollectionsZsets_49(((NI) 64));
		(*s).counter = ((NI) 0);
		unsureAsgnRef((void**) (&(*s).data), (tySequence__Mh5ToiAHng5Z72oMQ0yKVg*) newSeq((&NTIkeyvaluepairseq__Mh5ToiAHng5Z72oMQ0yKVg_), ((NI) (correctSizeX60gensym3_))));
	}
	LA4_: ;
	hc = (NI)0;
	index = rawGet__icZintegrity_112((*s), key, (&hc));
	{
		if (!(((NI) 0) <= index)) goto LA8_;
		result = NIM_TRUE;
	}
	goto LA6_;
	LA8_: ;
	{
		{
			NIM_BOOL T13_;
			T13_ = (NIM_BOOL)0;
			T13_ = mustRehash__icZintegrity_189((*s));
			if (!T13_) goto LA14_;
			enlarge__icZintegrity_267(s);
			index = rawGetKnownHC__icZintegrity_333((*s), key, hc);
		}
		LA14_: ;
		rawInsert__icZintegrity_412(s, (&(*s).data), key, hc, (NI)(((NI) -1) - index));
		(*s).counter += ((NI) 1);
	}
	LA6_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__icZnavigator_143)(tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw* s, NimStringDesc* key) {
	NIM_BOOL result;
	NI hc;
	NI index;
	result = (NIM_BOOL)0;
	{
		NI T3_;
		NI correctSizeX60gensym15_;
		T3_ = ((*s).data ? (*s).data->Sup.len : 0);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		correctSizeX60gensym15_ = slotsNeeded__pureZcollectionsZsets_49(((NI) 64));
		(*s).counter = ((NI) 0);
		unsureAsgnRef((void**) (&(*s).data), (tySequence__4eRCaZmrYLLw2k30GPTiMw*) newSeq((&NTIkeyvaluepairseq__4eRCaZmrYLLw2k30GPTiMw_), ((NI) (correctSizeX60gensym15_))));
	}
	LA4_: ;
	hc = (NI)0;
	index = rawGet__options_2639((*s), key, (&hc));
	{
		if (!(((NI) 0) <= index)) goto LA8_;
		result = NIM_TRUE;
	}
	goto LA6_;
	LA8_: ;
	{
		{
			NIM_BOOL T13_;
			T13_ = (NIM_BOOL)0;
			T13_ = mustRehash__options_2892((*s));
			if (!T13_) goto LA14_;
			enlarge__options_3084(s);
			index = rawGetKnownHC__options_3335((*s), key, hc);
		}
		LA14_: ;
		rawInsert__options_3697(s, (&(*s).data), key, hc, (NI)(((NI) -1) - index));
		(*s).counter += ((NI) 1);
	}
	LA6_: ;
	return result;
}
