/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 32

#include "nimbase.h"
#include <string.h>
#include <stdio.h>
#include <setjmp.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct TNimType TNimType;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_Env_docgendotnim_newDocumentor___l319aWpTxh3BHYVEmIhN02w tyObject_Env_docgendotnim_newDocumentor___l319aWpTxh3BHYVEmIhN02w;
typedef struct RootObj RootObj;
typedef struct TNimNode TNimNode;
typedef struct tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ;
typedef struct tySequence__ng4kcoK184wyb3xemBLQmw tySequence__ng4kcoK184wyb3xemBLQmw;
typedef struct tyObject_RstFileTable__JJYG5kijP4PSa5F9a7da5tw tyObject_RstFileTable__JJYG5kijP4PSa5F9a7da5tw;
typedef struct tyObject_Table__NKkg36PLm9cXyIIgbxq1hGQ tyObject_Table__NKkg36PLm9cXyIIgbxq1hGQ;
typedef struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og tySequence__pUxI6Ljo6IKKHXKOZkQ7Og;
typedef struct tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q;
typedef struct tyObject_ModSection__HB5R2AMUpdfd7aJdlibDhA tyObject_ModSection__HB5R2AMUpdfd7aJdlibDhA;
typedef struct tySequence__bLuZlbeJhlfg9axVlmjdJXw tySequence__bLuZlbeJhlfg9axVlmjdJXw;
typedef struct tySequence__spLz9azjOgbpYKrtmm9aMHEw tySequence__spLz9azjOgbpYKrtmm9aMHEw;
typedef struct tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q;
typedef struct tyObject_Table__IzudB87pHlXWFsowpECF3Q tyObject_Table__IzudB87pHlXWFsowpECF3Q;
typedef struct tySequence__eo8AEcZEcjOKWtrX6vLg3Q tySequence__eo8AEcZEcjOKWtrX6vLg3Q;
typedef struct tySequence__Z0K9aZr9c4ex9ad72Ulcdqy7g tySequence__Z0K9aZr9c4ex9ad72Ulcdqy7g;
typedef struct tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g;
typedef struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw;
typedef struct tySequence__ed0C0uAUZPhvw3RAc5hfYg tySequence__ed0C0uAUZPhvw3RAc5hfYg;
typedef struct tyObject_RstSharedState__RaVISFn5lBYmQPVCuG88JA tyObject_RstSharedState__RaVISFn5lBYmQPVCuG88JA;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tyObject_OrderedTable__uUf2ABI4SLuvVLy2s8ygdw tyObject_OrderedTable__uUf2ABI4SLuvVLy2s8ygdw;
typedef struct tySequence__RKPQcDl19bqs7bJVDyxdQYg tySequence__RKPQcDl19bqs7bJVDyxdQYg;
typedef struct tyObject_ItemFragment__s61pcFD9bQO8uWIzfNjndzg tyObject_ItemFragment__s61pcFD9bQO8uWIzfNjndzg;
typedef struct tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ;
typedef struct tyObject_Item__T7UjOImKJxoSfGY6SB3KMg tyObject_Item__T7UjOImKJxoSfGY6SB3KMg;
typedef struct tyTuple__2nwM9b3fWcA0dvFwaUqLcQg tyTuple__2nwM9b3fWcA0dvFwaUqLcQg;
typedef struct tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw;
typedef struct tyTuple__qrCj5BRLChMPPtE8mZNTMw tyTuple__qrCj5BRLChMPPtE8mZNTMw;
typedef struct tyObject_ExampleGroupcolonObjectType___bbSjO9aaIauVHOujtpjo3Rw tyObject_ExampleGroupcolonObjectType___bbSjO9aaIauVHOujtpjo3Rw;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tySequence__7EPs9bALtRDoJ5HKNxchjbQ tySequence__7EPs9bALtRDoJ5HKNxchjbQ;
typedef struct tySequence__7HTk34lAlArJP89aG2XjZEA tySequence__7HTk34lAlArJP89aG2XjZEA;
typedef struct tySequence__29caZmiPrO6d9cg0Ucdm9bdAA tySequence__29caZmiPrO6d9cg0Ucdm9bdAA;
typedef struct tySequence__axx1LQ9awiGkP3NNnW2X9cOQ tySequence__axx1LQ9awiGkP3NNnW2X9cOQ;
typedef struct tySequence__YYKlUlCjbni3i58WM0kegw tySequence__YYKlUlCjbni3i58WM0kegw;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tySequence__xv3aaFd3JCw8NbmALHiezQ tySequence__xv3aaFd3JCw8NbmALHiezQ;
typedef struct tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ;
typedef struct tySequence__CZrkID0OnHjQpN63AqYJwg tySequence__CZrkID0OnHjQpN63AqYJwg;
typedef struct tySequence__qIo1GWQhO9cOgsAJDKUY8kw tySequence__qIo1GWQhO9cOgsAJDKUY8kw;
typedef struct tyObject_Env_docgendotnim_colonanonymous___Jp5hmeXcpCwUxySNwOFFoQ tyObject_Env_docgendotnim_colonanonymous___Jp5hmeXcpCwUxySNwOFFoQ;
typedef struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tyTuple__7q7q3E6Oj24ZNVJb9aonhAg;
typedef struct tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw;
typedef struct tyTuple__XOVT24GHXwqiEj5GCsEGCA tyTuple__XOVT24GHXwqiEj5GCsEGCA;
typedef struct tyObject_Env_docgendotnim_presentationPath___FkNfvNWmsd8YzfuKoBUSmA tyObject_Env_docgendotnim_presentationPath___FkNfvNWmsd8YzfuKoBUSmA;
typedef struct tyTuple__UV3llMMYFckfui8YMBuUZA tyTuple__UV3llMMYFckfui8YMBuUZA;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_TLineInfo__AUK89aIO9ccPtw38jya2kdpA tyObject_TLineInfo__AUK89aIO9ccPtw38jya2kdpA;
typedef struct tySequence__jo4WO9beNiWGoaKRjSrOMJQ tySequence__jo4WO9beNiWGoaKRjSrOMJQ;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyObject_TSrcGen__FLkIzVI9alYjwMpiriDPTPQ tyObject_TSrcGen__FLkIzVI9alYjwMpiriDPTPQ;
typedef struct tySequence__U1GhxZcouR7SC9csuA1Iicg tySequence__U1GhxZcouR7SC9csuA1Iicg;
typedef struct tyObject_IOError__5GCiDuy5Wsuc9an2QZvqgIA tyObject_IOError__5GCiDuy5Wsuc9an2QZvqgIA;
typedef struct tyObject_CatchableError__8K3kdpxrBD9aI27J0kpSCpQ tyObject_CatchableError__8K3kdpxrBD9aI27J0kpSCpQ;
typedef struct Exception Exception;
typedef struct tySequence__QbmGqFaLnb1IWWToREeaIA tySequence__QbmGqFaLnb1IWWToREeaIA;
typedef struct TSafePoint TSafePoint;
typedef struct tyObject_Table__IARuioJxsgUIwpXiUkOgKg tyObject_Table__IARuioJxsgUIwpXiUkOgKg;
typedef struct tySequence__SFipDZIkFtPcrLs0AGBBjQ tySequence__SFipDZIkFtPcrLs0AGBBjQ;
typedef struct tyTuple__Qs8sDfUhU9bpCSJUdwfMJiA tyTuple__Qs8sDfUhU9bpCSJUdwfMJiA;
typedef struct tyObject_Env_docgendotnim_commandJson___EkXrf9bj6BppyBV1BtAGatQ tyObject_Env_docgendotnim_commandJson___EkXrf9bj6BppyBV1BtAGatQ;
typedef struct tyObject_Env_docgendotnim_commandTags___SuJtoUSREUHobzyvPNB0bA tyObject_Env_docgendotnim_commandTags___SuJtoUSREUHobzyvPNB0bA;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
typedef struct tyObject_TocEntry__8s9aRe62JHXKMgO2pStC19cA tyObject_TocEntry__8s9aRe62JHXKMgO2pStC19cA;
typedef struct tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ;
typedef struct tyObject_LevelInfo__PM5uc3aqOwcmxPAA2Yt4pQ tyObject_LevelInfo__PM5uc3aqOwcmxPAA2Yt4pQ;
typedef struct tyObject_Substitution__rZij7FJC9a7u59cpJsTlOCYQ tyObject_Substitution__rZij7FJC9a7u59cpJsTlOCYQ;
typedef struct tyTuple__wOvXi5VibnCNgN9buQRQD4A tyTuple__wOvXi5VibnCNgN9buQRQD4A;
typedef struct tyTuple__KPVKrfx82Va9azSnb0dl1RQ tyTuple__KPVKrfx82Va9azSnb0dl1RQ;
typedef struct tyTuple__sPaDkVPSC0MkcoXCxPH9ccA tyTuple__sPaDkVPSC0MkcoXCxPH9ccA;
typedef struct tyTuple__CWLiqluAXi3Y4RHZUwBh9bQ tyTuple__CWLiqluAXi3Y4RHZUwBh9bQ;
typedef struct tyObject_TRenderTok__z9cSoNPqXol8GydNVfj7f9ag tyObject_TRenderTok__z9cSoNPqXol8GydNVfj7f9ag;
typedef struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA;
typedef struct tyTuple__8ZxhPt1NwfElsJs8zUSV9bg tyTuple__8ZxhPt1NwfElsJs8zUSV9bg;
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
typedef NU8 tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_Env_docgendotnim_newDocumentor___l319aWpTxh3BHYVEmIhN02w {
  RootObj Sup;
NI colonstate_;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf1;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ;
typedef struct {
N_NIMCALL_PTR(NimStringDesc*, ClP_0) (NimStringDesc* filename, void* ClE_0);
void* ClE_0;
} tyProc__oFHfEKFsiYTMAy9a42cSiKw;
typedef NU8 tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* filename, NI line, NI col, tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg msgKind, NimStringDesc* arg, void* ClE_0);
void* ClE_0;
} tyProc__gd6fvPtd9aVRsRjs9bLyzE9bQ;
struct tyObject_RstFileTable__JJYG5kijP4PSa5F9a7da5tw {
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIdx;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* idxToFilename;
};
typedef NimStringDesc* tyArray__2cm2du8CnvAGpSJPsQ9bNhw[5];
struct tyObject_Table__NKkg36PLm9cXyIIgbxq1hGQ {
tySequence__pUxI6Ljo6IKKHXKOZkQ7Og* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, NimStringDesc* filename, NimStringDesc* cmd, NI status, NimStringDesc* content, void* ClE_0);
void* ClE_0;
} tyProc__bvoZymnzBMzGoI59bjcrthA;
typedef NU8 tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg;
struct tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ {
  RootObj Sup;
tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ target;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* config;
NI splitAfter;
NI listingCounter;
tySequence__ng4kcoK184wyb3xemBLQmw* tocPart;
NIM_BOOL hasToc;
NimStringDesc* theIndex;
tyProc__oFHfEKFsiYTMAy9a42cSiKw findFile;
tyProc__gd6fvPtd9aVRsRjs9bLyzE9bQ msgHandler;
NimStringDesc* outDir;
NimStringDesc* destFile;
tyObject_RstFileTable__JJYG5kijP4PSa5F9a7da5tw filenames;
NimStringDesc* filename;
tyArray__2cm2du8CnvAGpSJPsQ9bNhw meta;
NimStringDesc* currentSection;
tyObject_Table__NKkg36PLm9cXyIIgbxq1hGQ seenIndexTerms;
NI id;
tyProc__bvoZymnzBMzGoI59bjcrthA onTestSnippet;
tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg escMode;
};
struct tyObject_ModSection__HB5R2AMUpdfd7aJdlibDhA {
tySequence__bLuZlbeJhlfg9axVlmjdJXw* secItems;
NimStringDesc* finalMarkup;
};
typedef tyObject_ModSection__HB5R2AMUpdfd7aJdlibDhA tyArray__qOSeyO8oLD0KPByNUUqROQ[26];
struct tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q {
NimStringDesc* content;
NimStringDesc* sortName;
};
typedef tySequence__spLz9azjOgbpYKrtmm9aMHEw* tyArray__s1XJ229a5I0gccC9a8ovynJg[26];
struct tyObject_Table__IzudB87pHlXWFsowpECF3Q {
tySequence__eo8AEcZEcjOKWtrX6vLg3Q* data;
NI counter;
};
typedef tyObject_Table__IzudB87pHlXWFsowpECF3Q tyArray__Zd9cawxvdqOKiiqOkm71SmQ[26];
typedef NimStringDesc* tyArray__AIk240fCwwMqKZJEnXPLZA[26];
struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw {
NI counter;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* data;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_OrderedTable__uUf2ABI4SLuvVLy2s8ygdw {
tySequence__RKPQcDl19bqs7bJVDyxdQYg* data;
NI counter;
NI first;
NI last;
};
struct tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg {
  tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ Sup;
tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q* modDescPre;
NimStringDesc* modDescFinal;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
NimStringDesc* modDeprecationMsg;
tyArray__qOSeyO8oLD0KPByNUUqROQ section;
tyArray__s1XJ229a5I0gccC9a8ovynJg tocSimple;
tyArray__Zd9cawxvdqOKiiqOkm71SmQ tocTable;
tyArray__AIk240fCwwMqKZJEnXPLZA toc2;
tyArray__AIk240fCwwMqKZJEnXPLZA toc;
NimStringDesc* indexValFilename;
NimStringDesc* analytics;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* seenSymbols;
tySequence__Z0K9aZr9c4ex9ad72Ulcdqy7g* jEntriesPre;
tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* jEntriesFinal;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw types;
tyObject_RstSharedState__RaVISFn5lBYmQPVCuG88JA* sharedState;
NIM_BOOL isPureRst;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
NI exampleCounter;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw emitted;
NimStringDesc* thisDir;
tyObject_OrderedTable__uUf2ABI4SLuvVLy2s8ygdw exampleGroups;
NIM_BOOL wroteSupportFiles;
};
struct tyObject_ItemFragment__s61pcFD9bQO8uWIzfNjndzg {
NIM_BOOL isRst;
union{
struct {tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* rst;
} _isRst_1;
struct {NimStringDesc* str;
} _isRst_2;
};
};
struct tyObject_Item__T7UjOImKJxoSfGY6SB3KMg {
tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q* descRst;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* substitutions;
NimStringDesc* sortName;
};
struct tyTuple__2nwM9b3fWcA0dvFwaUqLcQg {
NI Field0;
NimStringDesc* Field1;
tySequence__spLz9azjOgbpYKrtmm9aMHEw* Field2;
};
struct tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw {
tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* json;
tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* rst;
NimStringDesc* rstField;
};
struct tyTuple__qrCj5BRLChMPPtE8mZNTMw {
NI Field0;
NI Field1;
NimStringDesc* Field2;
tyObject_ExampleGroupcolonObjectType___bbSjO9aaIauVHOujtpjo3Rw* Field3;
};
struct tyObject_ExampleGroupcolonObjectType___bbSjO9aaIauVHOujtpjo3Rw {
NimStringDesc* rdoccmd;
NimStringDesc* docCmd;
NimStringDesc* code;
NI index;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
typedef tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* tyArray__1iN2CWX9bK5w9bRjT9chFAABA[8192];
struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ {
tyArray__1iN2CWX9bK5w9bRjT9chFAABA buckets;
NI wordCounter;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* idAnon;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* idDelegator;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* emptyIdent;
};
typedef NU8 tySet_tyEnum_RstParseOption__utHUlNkCVsWnNFCaZUhT7g;
typedef NU8 tyEnum_RstParseOption__utHUlNkCVsWnNFCaZUhT7g;
typedef NU8 tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg;
struct tyObject_RstSharedState__RaVISFn5lBYmQPVCuG88JA {
tySet_tyEnum_RstParseOption__utHUlNkCVsWnNFCaZUhT7g options;
tySequence__7EPs9bALtRDoJ5HKNxchjbQ* hLevels;
NI hTitleCnt;
NI hCurLevel;
NimStringDesc* currRole;
tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg currRoleKind;
tySequence__7HTk34lAlArJP89aG2XjZEA* subs;
tySequence__7HTk34lAlArJP89aG2XjZEA* refs;
tySequence__29caZmiPrO6d9cg0Ucdm9bdAA* anchors;
tySequence__axx1LQ9awiGkP3NNnW2X9cOQ* lineFootnoteNum;
tySequence__axx1LQ9awiGkP3NNnW2X9cOQ* lineFootnoteNumRef;
NI currFootnoteNumRef;
tySequence__axx1LQ9awiGkP3NNnW2X9cOQ* lineFootnoteSym;
tySequence__axx1LQ9awiGkP3NNnW2X9cOQ* lineFootnoteSymRef;
NI currFootnoteSymRef;
tySequence__YYKlUlCjbni3i58WM0kegw* footnotes;
tyProc__gd6fvPtd9aVRsRjs9bLyzE9bQ msgHandler;
tyProc__oFHfEKFsiYTMAy9a42cSiKw findFile;
tyObject_RstFileTable__JJYG5kijP4PSa5F9a7da5tw filenames;
NI32 currFileIdx;
NIM_BOOL hasToc;
};
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NimStringDesc* tyArray__nHXaesL0DJZHyVS07ARPRA[1];
typedef NU8 tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA;
struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA {
  RootObj Sup;
NI counter;
tySequence__xv3aaFd3JCw8NbmALHiezQ* data;
tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA mode;
};
typedef NU8 tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A;
struct tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ {
tySequence__CZrkID0OnHjQpN63AqYJwg* data;
NI counter;
NI first;
NI last;
};
struct tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g {
NIM_BOOL isUnquoted;
tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A kind;
union{
struct {NimStringDesc* str;
} _kind_1;
struct {NI64 num;
} _kind_2;
struct {NF fnum;
} _kind_3;
struct {NIM_BOOL bval;
} _kind_4;
struct {tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ fields;
} _kind_6;
struct {tySequence__qIo1GWQhO9cOgsAJDKUY8kw* elems;
} _kind_7;
};
};
struct tyObject_Env_docgendotnim_colonanonymous___Jp5hmeXcpCwUxySNwOFFoQ {
  RootObj Sup;
NI colonstate_;
tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d1;
NimStringDesc* outp2;
};
struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
};
struct tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw {
NI a;
NI b;
};
typedef NimStringDesc* tyArray__meGd17iD6izZVY5NTv9bHUA[10];
typedef N_CLOSURE_PTR(NimStringDesc*, TM__iS6Vfak4fKt7fhPmyApRcg_39) (NimStringDesc* cmd);
typedef NU8 tySet_tyEnum_ProcessOption__79cHN5ErNkq9cfbLi9bttt3Xw;
struct tyTuple__XOVT24GHXwqiEj5GCsEGCA {
NimStringDesc* Field0;
NI Field1;
};
typedef NimStringDesc* tyArray__sMpvt1sOxOJ3LFGulnbeMQ[4];
struct tyObject_Env_docgendotnim_presentationPath___FkNfvNWmsd8YzfuKoBUSmA {
  RootObj Sup;
NI colonstate_;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf1;
NimStringDesc* file22;
};
typedef struct {
N_NIMCALL_PTR(NimStringDesc*, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__LCMSFwcIs5O0HdDmqpX05g;
typedef N_CLOSURE_PTR(NimStringDesc*, TM__iS6Vfak4fKt7fhPmyApRcg_47) (void);
typedef N_CLOSURE_PTR(NimStringDesc*, TM__iS6Vfak4fKt7fhPmyApRcg_48) (void);
struct tyTuple__UV3llMMYFckfui8YMBuUZA {
NimStringDesc* Field0;
NimStringDesc* Field1;
};
typedef NU8 tyEnum_DocFlags__Q2li9cSVrBaVKtfORTUg5dQ;
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
typedef NU16 tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw;
struct tyObject_TLineInfo__AUK89aIO9ccPtw38jya2kdpA {
NU16 line;
NI16 col;
NI32 fileIndex;
};
struct tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ {
tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg kind;
union{
struct {NimStringDesc* text;
} _kind_1;
struct {NimStringDesc* labelFmt;
} _kind_2;
struct {NimStringDesc* lineIndent;
} _kind_3;
struct {NimStringDesc* adType;
} _kind_4;
struct {NI level;
} _kind_5;
struct {NI order;
} _kind_6;
struct {tyObject_TLineInfo__AUK89aIO9ccPtw38jya2kdpA info;
} _kind_7;
};
NimStringDesc* anchor;
tySequence__jo4WO9beNiWGoaKRjSrOMJQ* sons;
};
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInst;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg uniqueId;
};
typedef NU8 tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg;
typedef tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* tyArray__Nfk9cOEzg2bRz9c1V8fGzONg[2];
typedef NU8 tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU8 tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg {
NI id;
NimStringDesc* s;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* next;
NI h;
};
typedef NU8 tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw;
typedef NU8 tyEnum_RunnableState__9b58EmEbGuos3KaMZ9cEC1OA;
typedef NU8 tySet_tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw[21];
typedef NimStringDesc* tyArray__Re75IspeoxXy2oCZHwcRrA[2];
typedef tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* tyArray__DkuVegaMCU6g1mpIOSQPIw[1];
typedef tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* tyArray__iegsN9bf6GqRiWprrJjTAoA[1];
typedef NU16 tySet_tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA;
typedef NimStringDesc* tyArray__24KAM9afIUgUaqBaEBB6r9bg[3];
struct tyObject_TSrcGen__FLkIzVI9alYjwMpiriDPTPQ {
NI indent;
NI lineLen;
NI col;
NI pos;
NI idx;
tySequence__U1GhxZcouR7SC9csuA1Iicg* tokens;
NimStringDesc* buf;
NI pendingNL;
NI pendingWhitespace;
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* comStack;
tySet_tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA flags;
NIM_BOOL inGenericParams;
NIM_BOOL checkAnon;
NI inPragma;
NI32 fid;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* mangler;
};
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
typedef NU8 tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA;
typedef NimStringDesc* tyArray__yt5VDPNtUGx9cBkOVakHwdQ[6];
typedef NimStringDesc* tyArray__Q6RksR9bl1dCf8jl3HeN9bXg[8];
typedef struct {
N_NIMCALL_PTR(NI, ClP_0) (tyObject_Item__T7UjOImKJxoSfGY6SB3KMg x, tyObject_Item__T7UjOImKJxoSfGY6SB3KMg y, void* ClE_0);
void* ClE_0;
} tyProc__89bMNSqI54vbXxP9bMMNLCIg;
typedef NU8 tyEnum_SortOrder__TcYjciSJ3jKUT4ygglumjg;
typedef N_CLOSURE_PTR(NI, TM__iS6Vfak4fKt7fhPmyApRcg_162) (tyObject_Item__T7UjOImKJxoSfGY6SB3KMg x, tyObject_Item__T7UjOImKJxoSfGY6SB3KMg y, void* ClE_0);
typedef NimStringDesc* tyArray__rmMMhDIqORJzUU5zqeitSQ[16];
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__QbmGqFaLnb1IWWToREeaIA* trace;
Exception* up;
};
struct tyObject_CatchableError__8K3kdpxrBD9aI27J0kpSCpQ {
  Exception Sup;
};
struct tyObject_IOError__5GCiDuy5Wsuc9an2QZvqgIA {
  tyObject_CatchableError__8K3kdpxrBD9aI27J0kpSCpQ Sup;
};
typedef NimStringDesc* tyArray__DThrQCZozFo0up9c69cEDODw[14];
typedef struct {
N_NIMCALL_PTR(NI, ClP_0) (NimStringDesc* x, NimStringDesc* y, void* ClE_0);
void* ClE_0;
} tyProc__3pmh9bG9bLpdxUjFu9cDtbZaA;
typedef N_CLOSURE_PTR(NI, TM__iS6Vfak4fKt7fhPmyApRcg_203) (NimStringDesc* x, NimStringDesc* y, void* ClE_0);
typedef struct {
N_NIMCALL_PTR(NI, ClP_0) (tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q x, tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q y, void* ClE_0);
void* ClE_0;
} tyProc__WEtPC7U0dE9c3UXfKGHiYrg;
typedef N_CLOSURE_PTR(NI, TM__iS6Vfak4fKt7fhPmyApRcg_204) (tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q x, tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q y, void* ClE_0);
typedef N_CLOSURE_PTR(NI, TM__iS6Vfak4fKt7fhPmyApRcg_207) (tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q x, tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q y, void* ClE_0);
typedef NU8 tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ;
typedef NimStringDesc* tyArray__sNC09at9bGf9bERQNOmgMwXdQ[22];
typedef NimStringDesc* tyArray__1XN7mEfyEE3SOJgMTajV2g[26];
struct TSafePoint {
TSafePoint* prev;
NI status;
jmp_buf context;
};
typedef NU8 tySet_tyEnum_CopyFlag__FAQfI6ph9a9bh5nGNKhOYumg;
struct tyObject_Table__IARuioJxsgUIwpXiUkOgKg {
tySequence__SFipDZIkFtPcrLs0AGBBjQ* data;
NI counter;
};
struct tyTuple__Qs8sDfUhU9bpCSJUdwfMJiA {
NimStringDesc* Field0;
tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* Field1;
};
typedef tyTuple__Qs8sDfUhU9bpCSJUdwfMJiA tyArray__uQuKJ8PXBeys9avtUqAO2FQ[4];
typedef tyTuple__Qs8sDfUhU9bpCSJUdwfMJiA tyArray__gWm1Ak9ah9ayQHjy9cnDizd7A[3];
typedef tyTuple__Qs8sDfUhU9bpCSJUdwfMJiA tyArray__A1IDoa8VAZJ9bsqiNGV27SA[2];
typedef tyTuple__Qs8sDfUhU9bpCSJUdwfMJiA tyArray__X9cKZd9bnz0tK9cWIyeUfZmZw[1];
typedef NU8 tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w;
typedef NimStringDesc* tyArray__ebVs7LW9aC16IAZKgIOCAJQ[24];
struct tyObject_Env_docgendotnim_commandJson___EkXrf9bj6BppyBV1BtAGatQ {
  RootObj Sup;
NI colonstate_;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf1;
};
struct tyObject_Env_docgendotnim_commandTags___SuJtoUSREUHobzyvPNB0bA {
  RootObj Sup;
NI colonstate_;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf1;
};
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
struct tyObject_TocEntry__8s9aRe62JHXKMgO2pStC19cA {
tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n;
NimStringDesc* refname;
NimStringDesc* header;
};
struct tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ {
NI Field0;
NimStringDesc* Field1;
NI Field2;
};
struct tyObject_LevelInfo__PM5uc3aqOwcmxPAA2Yt4pQ {
NIM_CHAR symbol;
NIM_BOOL hasOverline;
NI line;
NIM_BOOL hasPeers;
};
struct tyObject_Substitution__rZij7FJC9a7u59cpJsTlOCYQ {
NimStringDesc* key;
tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* value;
};
struct tyTuple__wOvXi5VibnCNgN9buQRQD4A {
NimStringDesc* Field0;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* Field1;
};
typedef NU8 tyEnum_FootnoteType__jXnI8xEO3SXxVR9afYCJnyQ;
struct tyTuple__KPVKrfx82Va9azSnb0dl1RQ {
tyEnum_FootnoteType__jXnI8xEO3SXxVR9afYCJnyQ Field0;
NI Field1;
NI Field2;
NI Field3;
NimStringDesc* Field4;
};
struct tyTuple__sPaDkVPSC0MkcoXCxPH9ccA {
NimStringDesc* Field0;
NimStringDesc* Field1;
NIM_BOOL Field2;
};
struct tyTuple__CWLiqluAXi3Y4RHZUwBh9bQ {
NI Field0;
NI Field1;
NimStringDesc* Field2;
tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* Field3;
};
struct tyObject_TRenderTok__z9cSoNPqXol8GydNVfj7f9ag {
tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw kind;
NI16 length;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
};
struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA {
NCSTRING procname;
NI line;
NCSTRING filename;
};
struct tyTuple__8ZxhPt1NwfElsJs8zUSV9bg {
NI Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
};
struct tySequence__spLz9azjOgbpYKrtmm9aMHEw {
  TGenericSeq Sup;
  tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q data[SEQ_DECL_SIZE];
};
struct tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q {
  TGenericSeq Sup;
  tyObject_ItemFragment__s61pcFD9bQO8uWIzfNjndzg data[SEQ_DECL_SIZE];
};
struct tySequence__bLuZlbeJhlfg9axVlmjdJXw {
  TGenericSeq Sup;
  tyObject_Item__T7UjOImKJxoSfGY6SB3KMg data[SEQ_DECL_SIZE];
};
struct tySequence__eo8AEcZEcjOKWtrX6vLg3Q {
  TGenericSeq Sup;
  tyTuple__2nwM9b3fWcA0dvFwaUqLcQg data[SEQ_DECL_SIZE];
};
struct tySequence__Z0K9aZr9c4ex9ad72Ulcdqy7g {
  TGenericSeq Sup;
  tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw data[SEQ_DECL_SIZE];
};
struct tySequence__RKPQcDl19bqs7bJVDyxdQYg {
  TGenericSeq Sup;
  tyTuple__qrCj5BRLChMPPtE8mZNTMw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
struct tySequence__ng4kcoK184wyb3xemBLQmw {
  TGenericSeq Sup;
  tyObject_TocEntry__8s9aRe62JHXKMgO2pStC19cA data[SEQ_DECL_SIZE];
};
struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og {
  TGenericSeq Sup;
  tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ data[SEQ_DECL_SIZE];
};
struct tySequence__ed0C0uAUZPhvw3RAc5hfYg {
  TGenericSeq Sup;
  tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__7EPs9bALtRDoJ5HKNxchjbQ {
  TGenericSeq Sup;
  tyObject_LevelInfo__PM5uc3aqOwcmxPAA2Yt4pQ data[SEQ_DECL_SIZE];
};
struct tySequence__7HTk34lAlArJP89aG2XjZEA {
  TGenericSeq Sup;
  tyObject_Substitution__rZij7FJC9a7u59cpJsTlOCYQ data[SEQ_DECL_SIZE];
};
struct tySequence__29caZmiPrO6d9cg0Ucdm9bdAA {
  TGenericSeq Sup;
  tyTuple__wOvXi5VibnCNgN9buQRQD4A data[SEQ_DECL_SIZE];
};
struct tySequence__axx1LQ9awiGkP3NNnW2X9cOQ {
  TGenericSeq Sup;
  tyObject_TLineInfo__AUK89aIO9ccPtw38jya2kdpA data[SEQ_DECL_SIZE];
};
struct tySequence__YYKlUlCjbni3i58WM0kegw {
  TGenericSeq Sup;
  tyTuple__KPVKrfx82Va9azSnb0dl1RQ data[SEQ_DECL_SIZE];
};
struct tySequence__xv3aaFd3JCw8NbmALHiezQ {
  TGenericSeq Sup;
  tyTuple__sPaDkVPSC0MkcoXCxPH9ccA data[SEQ_DECL_SIZE];
};
struct tySequence__CZrkID0OnHjQpN63AqYJwg {
  TGenericSeq Sup;
  tyTuple__CWLiqluAXi3Y4RHZUwBh9bQ data[SEQ_DECL_SIZE];
};
struct tySequence__qIo1GWQhO9cOgsAJDKUY8kw {
  TGenericSeq Sup;
  tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* data[SEQ_DECL_SIZE];
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__jo4WO9beNiWGoaKRjSrOMJQ {
  TGenericSeq Sup;
  tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* data[SEQ_DECL_SIZE];
};
struct tySequence__U1GhxZcouR7SC9csuA1Iicg {
  TGenericSeq Sup;
  tyObject_TRenderTok__z9cSoNPqXol8GydNVfj7f9ag data[SEQ_DECL_SIZE];
};
struct tySequence__QbmGqFaLnb1IWWToREeaIA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA data[SEQ_DECL_SIZE];
};
struct tySequence__SFipDZIkFtPcrLs0AGBBjQ {
  TGenericSeq Sup;
  tyTuple__8ZxhPt1NwfElsJs8zUSV9bg data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(void, handleDocOutputOptions__docgen_7225)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, slash___pathutils_90)(NimStringDesc* base, NimStringDesc* f);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5302)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5264)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5309)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5307)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5258)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, parseFile__syntaxes_217)(NI32 fileIdx, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config);
N_LIB_PRIVATE N_NIMCALL(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg*, newDocumentor__docgen_356)(NimStringDesc* filename, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* outExt, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, NIM_BOOL isPureRst);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tyRef__QkCnC3fwblDHMj9b4OGf6Nw)(void* p, NI op);
N_LIB_PRIVATE N_NOINLINE(void*, newObj)(TNimType* typ, NI size);
static N_NIMCALL(void, Marker_tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__bLuZlbeJhlfg9axVlmjdJXw)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__spLz9azjOgbpYKrtmm9aMHEw)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__eo8AEcZEcjOKWtrX6vLg3Q)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__Z0K9aZr9c4ex9ad72Ulcdqy7g)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__Z4Ed9aRleAg258AnxIUkcCQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__RKPQcDl19bqs7bJVDyxdQYg)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__DVY9cSsFXOXsfAd5wCWVrTg)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
N_LIB_PRIVATE N_NIMCALL(tyObject_RstSharedState__RaVISFn5lBYmQPVCuG88JA*, newRstSharedState__packagesZdocutilsZrst_2004)(tySet_tyEnum_RstParseOption__utHUlNkCVsWnNFCaZUhT7g options, NimStringDesc* filename, tyProc__oFHfEKFsiYTMAy9a42cSiKw findFile, tyProc__gd6fvPtd9aVRsRjs9bLyzE9bQ msgHandler);
N_LIB_PRIVATE N_CLOSURE(NimStringDesc*, docgenFindFile__docgen_378)(NimStringDesc* sX60gensym38_, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, findFile__options_4487)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* f, NIM_BOOL suppressStdlib);
static N_INLINE(NimStringDesc*, slash___pureZos_121)(NimStringDesc* head, NimStringDesc* tail);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosjoinPath)(NimStringDesc* head, NimStringDesc* tail);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosgetCurrentDir)(void);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosfileExists)(NimStringDesc* filename);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_CLOSURE(void, compilerMsgHandler__docgen_371)(NimStringDesc* filenameX60gensym38_, NI lineX60gensym38_, NI colX60gensym38_, tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg msgKindX60gensym38_, NimStringDesc* argX60gensym38_, void* ClE_0);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
static N_INLINE(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw, newLineInfo__msgs_408)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename, NI line, NI col);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw, newLineInfo__msgs_391)(NI32 fileInfoIdx, NI line, NI col);
N_LIB_PRIVATE N_NIMCALL(NI32, fileInfoIdx__msgs_376)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(void, initRstGenerator__packagesZdocutilsZrstgen_90)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* g, tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ target, tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* config, NimStringDesc* filename, tyProc__oFHfEKFsiYTMAy9a42cSiKw findFile, tyProc__gd6fvPtd9aVRsRjs9bLyzE9bQ msgHandler, tyObject_RstFileTable__JJYG5kijP4PSa5F9a7da5tw filenames);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isLatexCmd__docgen_349)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsthasKey)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__systemZassertions_56)(NimStringDesc* msg);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getOrDefault__pureZstrtabs_173)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, NimStringDesc* key, NimStringDesc* default_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA*, nstnewStringTable)(tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA mode);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, newJArray__pureZjson_133)(void);
N_LIB_PRIVATE N_NIMCALL(void, initStrTable__ast_4076)(tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* x);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___docgen_394)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* gen, NimStringDesc* filename, NimStringDesc* cmd, NI status, NimStringDesc* content, void* ClE_0);
static N_NIMCALL(void, Marker_tyRef__TGC3u8unDUvns3a0CJWQdw)(void* p, NI op);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(void, nossplitFile)(NimStringDesc* path, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, slash___pathutils_112)(NimStringDesc* base, NimStringDesc* f);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getNimcacheDir__options_4185)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___systemZdollars_3)(NI x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosisAbsolute)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(void, noscreateDir)(NimStringDesc* dir);
N_LIB_PRIVATE N_NIMCALL(void, splitFile__pathutils_27)(NimStringDesc* x, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuReplaceStr)(NimStringDesc* s, NimStringDesc* sub, NimStringDesc* by);
N_LIB_PRIVATE N_NIMCALL(void, writeFile__systemZio_474)(NimStringDesc* filename, NimStringDesc* content);
N_LIB_PRIVATE N_CLOSURE(NimStringDesc*, interpSnippetCmd__docgen_409)(NimStringDesc* cmd, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuStartsWith)(NimStringDesc* s, NimStringDesc* prefix);
static N_INLINE(NimStringDesc*, X5BX5D___pureZunicode_3215)(NimStringDesc* s, tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw x);
N_NIMCALL(NimStringDesc*, mnewString)(NI len);
static N_INLINE(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw, dotdot___stdZenumutils_90)(NI a, NI b);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nospquoteShell)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosgetAppFilename)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, execCmdEx__pureZosproc_1164)(NimStringDesc* command, tySet_tyEnum_ProcessOption__79cHN5ErNkq9cfbLi9bttt3Xw options, tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* env, NimStringDesc* workingDir, NimStringDesc* input, tyTuple__XOVT24GHXwqiEj5GCsEGCA* Result);
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(void, initPackedSet__pureZcollectionsZintsets_16)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getOutFile2__docgen_335)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename, NimStringDesc* ext, NIM_BOOL guessTarget);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, noschangeFileExt)(NimStringDesc* filename, NimStringDesc* ext);
static N_INLINE(NIM_BOOL, isEmpty__options_4084)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, absOutFile__options_4073)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getOutFile__options_4063)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename, NimStringDesc* ext);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, presentationPath__docgen_197)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* file);
static N_NIMCALL(void, Marker_tyRef__rNRAvx86kE4vxe49aRy4cdQ)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___options_4370)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getRelativePathFromConfigPath__options_4365)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* f, NIM_BOOL isTitle);
N_LIB_PRIVATE N_CLOSURE(NimStringDesc*, nimbleDir__docgen_206)(void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosparentDir)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getNimbleFile__options_4161)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* path);
static N_INLINE(NIM_BOOL, isEmpty__pathutils_94)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, relativeTo__pathutils_133)(NimStringDesc* fullPath, NimStringDesc* baseFilename, NIM_CHAR sep);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosdirExists)(NimStringDesc* dir);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosexpandFilename)(NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(void, nossplitPath)(NimStringDesc* path, tyTuple__UV3llMMYFckfui8YMBuUZA* Result);
N_LIB_PRIVATE N_NIMCALL(void, generateDoc__docgen_5358)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* orig, tyEnum_DocFlags__Q2li9cSVrBaVKtfORTUg5dQ docFlags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, findPragma__trees_271)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw which);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, genDeprecationMsg__docgen_3401)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getConfigVar__options_4054)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* key, NimStringDesc* default_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, escape__pureZxmltree_479)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(void, add__docgen_107)(tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q** dest, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* rst);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(void, genericAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ*, genComment__docgen_508)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, comment__ast_997)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ*, parseRst__docgen_310)(NimStringDesc* text, NimStringDesc* filename, NI line, NI column, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_RstSharedState__RaVISFn5lBYmQPVCuG88JA* sharedState);
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ*, rstParsePass1__packagesZdocutilsZrst_6811)(NimStringDesc* fragment, NI line, NI column, tyObject_RstSharedState__RaVISFn5lBYmQPVCuG88JA* sharedState);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPath__msgs_548)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
static N_INLINE(NI, toLinenumber__msgs_619)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
static N_INLINE(NI, toColumn__msgs_622)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, documentRaises__docgen_5273)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, documentEffect__docgen_5195)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x, tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw effectType, NI idx);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, effectSpec__trees_284)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw effectType);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeI__ast_3324)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NI children);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, typeToString__types_50)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg prefer);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__system_7736)(NimStringDesc* s, NI first);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newIdentNode__ast_3700)(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*, getIdent__idents_152)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* ic, NimStringDesc* identifier);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newTreeI__ast_3384)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** children, NI childrenLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, documentWriteEffect__docgen_5237)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flag, NimStringDesc* pragmaName);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeI__ast_3320)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_4798)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, documentNewEffect__docgen_5185)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genItem__docgen_3437)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nameNode, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw k, tyEnum_DocFlags__Q2li9cSVrBaVKtfORTUg5dQ docFlags);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isVisible__docgen_3258)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__astalgo_402)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getName__docgen_3321)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI splitAfter);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, esc__packagesZdocutilsZrstgen_249)(tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ target, NimStringDesc* s, NI splitAfter, tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg escMode);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderDefinitionName__renderer_88)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NIM_BOOL noQuotes);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getPlainDocstring__docgen_558)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, getAllRunnableExamples__docgen_3238)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q** dest);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, getRoutineBody__docgen_3208)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_RunnableState__9b58EmEbGuos3KaMZ9cEC1OA, getAllRunnableExamplesImpl__docgen_3162)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q** dest, tyEnum_RunnableState__9b58EmEbGuos3KaMZ9cEC1OA state, NIM_BOOL topLevel);
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ*, genRecComment__docgen_541)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ*, genRecCommentAux__docgen_512)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, commenteq___ast_1365)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NimStringDesc* a);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isRunnableExamples__ast_4699)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, lastSon__ast_4833)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, prepareExample__docgen_1027)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL topLevel, tyTuple__UV3llMMYFckfui8YMBuUZA* Result);
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_629)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toMsgFilename__msgs_612)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_167)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, extractRunnableExamplesSource__renderverbatim_97)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI indent);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, exampleOutputDir__docgen_639)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosextractFilename)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newTree__ast_3356)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** children, NI childrenLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newStrNode__ast_3801)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, NimStringDesc* strVal);
N_LIB_PRIVATE N_NIMCALL(void, renderModule__renderer_2119)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NimStringDesc* outfile, tySet_tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA renderFlags, NI32 fid, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__pureZstrutils_1627)(NimStringDesc* s, NimStringDesc* sub);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___docgen_1072)(tyTuple__kN8up2W6YKc5YA9avn5mV5w x);
N_LIB_PRIVATE N_NIMCALL(void, toInstantiationInfo__docgen_1023)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyTuple__kN8up2W6YKc5YA9avn5mV5w* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, quoted__docgen_1016)(NimStringDesc* a);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__pureZos_449)(NimStringDesc** s, NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__docgen_1160)(tyObject_OrderedTable__uUf2ABI4SLuvVLy2s8ygdw t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___docgen_1518)(tyObject_OrderedTable__uUf2ABI4SLuvVLy2s8ygdw* t, NimStringDesc* key, tyObject_ExampleGroupcolonObjectType___bbSjO9aaIauVHOujtpjo3Rw* val);
static N_INLINE(NI, len__docgen_693)(tyObject_OrderedTable__uUf2ABI4SLuvVLy2s8ygdw t);
N_LIB_PRIVATE N_NIMCALL(tyObject_ExampleGroupcolonObjectType___bbSjO9aaIauVHOujtpjo3Rw**, X5BX5D___docgen_2850)(tyObject_OrderedTable__uUf2ABI4SLuvVLy2s8ygdw* t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatSingleElem)(NimStringDesc* formatstr, NimStringDesc* a);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, canonicalImport__options_4661)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* file);
N_LIB_PRIVATE N_NIMCALL(void, nsuAddf)(NimStringDesc** s, NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(void, add__docgen_129)(tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q** dest, NimStringDesc* str);
N_LIB_PRIVATE N_NIMCALL(void, renderNimCode__packagesZdocutilsZrstgen_8248)(NimStringDesc** result, NimStringDesc* code, tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ target);
N_LIB_PRIVATE N_NIMCALL(void, initTokRender__renderer_2137)(tyObject_TSrcGen__FLkIzVI9alYjwMpiriDPTPQ* r, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA renderFlags);
N_LIB_PRIVATE N_NIMCALL(void, getNextTok__renderer_2141)(tyObject_TSrcGen__FLkIzVI9alYjwMpiriDPTPQ* r, tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw* kind, NimStringDesc** literal);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, getDeclPragma__ast_3203)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuStrip)(NimStringDesc* s, NIM_BOOL leading, NIM_BOOL trailing, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderPlainSymbolName__typesrenderer_6)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, complexName__docgen_3380)(tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw k, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NimStringDesc* baseName);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderParamTypes__typesrenderer_167)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NimStringDesc* sep);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, encodeUrl__pureZuri_40)(NimStringDesc* s, NIM_BOOL usePlus);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, newUniquePlainSymbol__docgen_3371)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, NimStringDesc* original);
N_LIB_PRIVATE N_NIMCALL(void, nstPut)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, NimStringDesc* key, NimStringDesc* val);
N_LIB_PRIVATE N_NIMCALL(void, nodeToHighlightedHtml__docgen_585)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NimStringDesc** result, tySet_tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA renderFlags, NimStringDesc* procLink);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getTokSym__renderer_2157)(tyObject_TSrcGen__FLkIzVI9alYjwMpiriDPTPQ* r);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, belongsToProjectPackage__packages_50)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, externalDep__docgen_571)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, genSeeSrc__docgen_3426)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, NimStringDesc* path, NI line);
N_LIB_PRIVATE N_NIMCALL(void, genericSeqAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(void*, newSeq)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, attachToType__docgen_265)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* p);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, whichType__docgen_246)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, strTableContains__astalgo_3226)(tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw t, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* n);
N_LIB_PRIVATE N_NIMCALL(void, setIndexTerm__packagesZdocutilsZrstgen_353)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, NimStringDesc* htmlFile, NimStringDesc* id, NimStringDesc* term, NimStringDesc* linkTitle, NimStringDesc* linkDesc);
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, docstringSummary__docgen_3392)(NimStringDesc* rstText);
N_LIB_PRIVATE N_NIMCALL(NI, nsuFindChar)(NimStringDesc* s, NIM_CHAR sub, NI start, NI last);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, setLengthStr)(NimStringDesc* s, NI newLen);
N_LIB_PRIVATE N_NIMCALL(NI, nsuFindCharSet)(NimStringDesc* s, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars, NI start, NI last);
N_LIB_PRIVATE N_NIMCALL(tySequence__spLz9azjOgbpYKrtmm9aMHEw**, mgetOrPut__docgen_3594)(tyObject_Table__IzudB87pHlXWFsowpECF3Q* t, NimStringDesc* key, tySequence__spLz9azjOgbpYKrtmm9aMHEw* val);
N_LIB_PRIVATE N_NIMCALL(tySequence__spLz9azjOgbpYKrtmm9aMHEw*, newSeq__docgen_3547)(NI len);
N_LIB_PRIVATE N_NIMCALL(void, strTableAdd__astalgo_3325)(tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* t, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, checkForFalse__docgen_5116)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreStyle)(NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(void, traceDeps__docgen_5123)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, prettyLink__packagesZdocutilsZrstgen_85)(NimStringDesc* file);
N_LIB_PRIVATE N_NIMCALL(void, exportSym__docgen_5164)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, originatingModule__ast_4670)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, add__docgen_5438)(tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q** x, tyObject_ItemFragment__s61pcFD9bQO8uWIzfNjndzg* y, NI yLen_0);
N_LIB_PRIVATE N_NIMCALL(void, finishGenerateDoc__docgen_5471)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg** d);
N_LIB_PRIVATE N_NIMCALL(void, preparePass2__packagesZdocutilsZrst_6818)(tyObject_RstSharedState__RaVISFn5lBYmQPVCuG88JA* s, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* mainNode);
N_LIB_PRIVATE N_NIMCALL(tySequence__bLuZlbeJhlfg9axVlmjdJXw*, sorted__docgen_5522)(tyObject_Item__T7UjOImKJxoSfGY6SB3KMg* a, NI aLen_0, tyProc__89bMNSqI54vbXxP9bMMNLCIg cmp, tyEnum_SortOrder__TcYjciSJ3jKUT4ygglumjg order);
N_LIB_PRIVATE N_NIMCALL(NI, cmp__docgen_5511)(tyObject_Item__T7UjOImKJxoSfGY6SB3KMg x, tyObject_Item__T7UjOImKJxoSfGY6SB3KMg y);
N_LIB_PRIVATE N_NIMCALL(NI, cmpDecimalsIgnoreCase__docgen_136)(NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuIsDigitChar)(NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NIM_CHAR, nsuToLowerAsciiChar)(NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(void, renderItemPre__docgen_5493)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q* fragments, NimStringDesc** result);
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ*, resolveSubs__packagesZdocutilsZrst_6821)(tyObject_RstSharedState__RaVISFn5lBYmQPVCuG88JA* s, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n);
N_LIB_PRIVATE N_NIMCALL(void, renderRstToOut__packagesZdocutilsZrstgen_308)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc** result);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ*, amp___docgen_5660)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x, tySequence__sM4lkSb7zS6F7OVMvW9cffQ* y);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
static N_INLINE(void, X5BX5Deq___pureZjson_1942)(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* obj, NimStringDesc* key, tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* val);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___pureZjson_306)(tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ* t, NimStringDesc* key, tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* val);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, percent___pureZjson_1809)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(void, add__pureZjson_241)(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* father, tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* child);
N_LIB_PRIVATE N_NIMCALL(void, writeOutput__docgen_7163)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, NIM_BOOL useWarning, NIM_BOOL groupedToc);
N_LIB_PRIVATE N_NIMCALL(void, runAllExamples__docgen_642)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d);
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_31)(NI hcode);
static N_INLINE(NimStringDesc*, findNodeJs__nodejs_2)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, findExe__pureZos_653)(NimStringDesc* exe, NIM_BOOL followSymlinks, NimStringDesc** extensions, NI extensionsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, echoBinSafe)(NimStringDesc** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, raiseExceptionEx)(Exception* e, NCSTRING ename, NCSTRING procname, NCSTRING filename, NI line);
N_LIB_PRIVATE N_NIMCALL(NI, nosexecShellCmd)(NimStringDesc* command);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefined__options_2292)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* symbol);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, prettyString__docgen_993)(tyObject_ExampleGroupcolonObjectType___bbSjO9aaIauVHOujtpjo3Rw a);
N_LIB_PRIVATE N_NIMCALL(void, quit__system_7154)(NimStringDesc* errormsg, NI errorcode) __attribute__((noreturn));
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, msgKindToString__msgs_782)(tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ kind);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, genOutFile__docgen_7095)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, NIM_BOOL groupedToc);
N_LIB_PRIVATE N_NIMCALL(void, renderTocEntries__packagesZdocutilsZrstgen_8135)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, NI* j, NI lvl, NimStringDesc** result);
N_LIB_PRIVATE N_NIMCALL(void, genSection__docgen_6247)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind, NIM_BOOL groupedToc);
N_LIB_PRIVATE N_NIMCALL(NI, len__docgen_6535)(tyObject_Table__IzudB87pHlXWFsowpECF3Q t);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ*, sorted__docgen_6719)(NimStringDesc** a, NI aLen_0, tyProc__3pmh9bG9bLpdxUjFu9cDtbZaA cmp, tyEnum_SortOrder__TcYjciSJ3jKUT4ygglumjg order);
N_LIB_PRIVATE N_NIMCALL(tySequence__spLz9azjOgbpYKrtmm9aMHEw**, X5BX5D___docgen_6805)(tyObject_Table__IzudB87pHlXWFsowpECF3Q* t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(void, sort__docgen_6878)(tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q* a, NI aLen_0, tyProc__WEtPC7U0dE9c3UXfKGHiYrg cmp, tyEnum_SortOrder__TcYjciSJ3jKUT4ygglumjg order);
N_LIB_PRIVATE N_NIMCALL(NI, cmp__docgen_6259)(tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q x, tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q y);
N_LIB_PRIVATE N_NIMCALL(tySequence__spLz9azjOgbpYKrtmm9aMHEw*, sorted__docgen_6984)(tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q* a, NI aLen_0, tyProc__WEtPC7U0dE9c3UXfKGHiYrg cmp, tyEnum_SortOrder__TcYjciSJ3jKUT4ygglumjg order);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nativeToUnixPath__stdZprivateZglobs_50)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getDateStr__options_596)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getClockStr__options_604)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, relLink__docgen_7086)(NimStringDesc* outDir, NimStringDesc* destFile, NimStringDesc* linkto);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___docgen_7091)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(void, write__systemZio_205)(FILE* f, NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(void, updateOutfile__docgen_7149)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, NimStringDesc* outfile);
static N_INLINE(void, pushSafePoint)(TSafePoint* s);
static N_INLINE(void, popSafePoint)(void);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isObj)(TNimType* obj, TNimType* subclass);
static N_INLINE(Exception*, nimBorrowCurrentException)(void);
static N_INLINE(void, popCurrentException)(void);
N_LIB_PRIVATE N_NIMCALL(void, reraiseException)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___options_4472)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getPrefixDir__options_4096)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, noscopyFile)(NimStringDesc* source, NimStringDesc* dest, tySet_tyEnum_CopyFlag__FAQfI6ph9a9bh5nGNKhOYumg options);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, interp__nimpaths_25)(NimStringDesc* path, NimStringDesc* nimr);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getDocHacksJs__nimpaths_84)(NimStringDesc* nimr, NimStringDesc* nim, NIM_BOOL forceRebuild);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, noslastPathPart)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(void, generateIndex__docgen_7141)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d);
N_LIB_PRIVATE N_NIMCALL(void, writeIndexFile__packagesZdocutilsZrstgen_202)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* g, NimStringDesc* outfile);
N_LIB_PRIVATE N_NIMCALL(void, add__docgen_5794)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw j);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___pureZjson_2063)(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* a, tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, percent___docgen_5835)(tyObject_Table__IARuioJxsgUIwpXiUkOgKg table);
N_LIB_PRIVATE N_NIMCALL(void, genJsonItem__docgen_4917)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nameNode, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw k, tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, percent___pureZjson_1838)(tyTuple__Qs8sDfUhU9bpCSJUdwfMJiA* keyVals, NI keyValsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, percent___pureZjson_1819)(NI n);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, newJObject__pureZjson_102)(void);
static N_INLINE(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, X5BX5D___pureZjson_3062)(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* node, NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g**, X5BX5D___pureZjson_2657)(tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ* t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___renderer_2116)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, generateJson__docgen_5805)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL includeComments);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getPackageName__options_4178)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___pureZjson_4484)(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* node);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, open__systemZio_389)(FILE** f, NimStringDesc* filename, tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w mode, NI bufSize);
N_LIB_PRIVATE N_NIMCALL(void, close__systemZio_217)(FILE* f);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, mergeIndexes__packagesZdocutilsZrstgen_7942)(NimStringDesc* dir);
N_LIB_PRIVATE N_NIMCALL(void, commandRstAux__docgen_7240)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename, NimStringDesc* outExt);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosaddFileExt)(NimStringDesc* filename, NimStringDesc* ext);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, readFile__systemZio_469)(NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqRC1)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(void, genericShallowAssign)(void* dest, void* src, TNimType* mt);
static N_NIMCALL(void, Marker_tyRef__X8kkALavbEdzXIrP0m7q2g)(void* p, NI op);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___docgen_7276)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, NimStringDesc* filename, NimStringDesc* cmd, NI status, NimStringDesc* content, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, pretty__pureZjson_4480)(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* node, NI indent);
static N_NIMCALL(void, Marker_tyRef__79c3Y3ZwA6fl2mb7ydHMpdg)(void* p, NI op);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___docgen_7298)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, NimStringDesc* filename, NimStringDesc* cmd, NI status, NimStringDesc* content, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, generateTags__docgen_6194)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NimStringDesc** r);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, genTagsItem__docgen_6188)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nameNode, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw k);
extern TNimType NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_;
N_LIB_PRIVATE TNimType NTIobject__l319aWpTxh3BHYVEmIhN02w_;
extern TNimType NTIint__xHTZrq9aYs6boc9bCba0JbpQ_;
extern TNimType NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_;
N_LIB_PRIVATE TNimType NTIrefobject__QkCnC3fwblDHMj9b4OGf6Nw_;
extern TNimType NTIrstgenerator__qr285fchxFL31hqgMYpbNQ_;
N_LIB_PRIVATE TNimType NTItdocumentor__bjDxkrkDk9c19abCetktG5Qg_;
N_LIB_PRIVATE TNimType NTIitemfragment__s61pcFD9bQO8uWIzfNjndzg_;
extern TNimType NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_;
TNimNode* NimDT___s61pcFD9bQO8uWIzfNjndzg_isRst[3];
extern TNimType NTIprstnode__yfV9aZUcV0SioJcvRrGyZlg_;
extern TNimType NTIstring__77mFvmsOLKik79ci2hXkHEg_;
N_LIB_PRIVATE TNimType NTIitempre__JSDKkkE7gMRTYRB9bRZ9bH7Q_;
extern TNimType NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_;
N_LIB_PRIVATE TNimType NTImodsection__HB5R2AMUpdfd7aJdlibDhA_;
N_LIB_PRIVATE TNimType NTIitem__T7UjOImKJxoSfGY6SB3KMg_;
extern TNimType NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_;
N_LIB_PRIVATE TNimType NTIseqLitemT__bLuZlbeJhlfg9axVlmjdJXw_;
N_LIB_PRIVATE TNimType NTImodsections__qOSeyO8oLD0KPByNUUqROQ_;
N_LIB_PRIVATE TNimType NTItocitem__f5Z7HAch49an2qSNSGguP7Q_;
N_LIB_PRIVATE TNimType NTIseqLtocitemT__spLz9azjOgbpYKrtmm9aMHEw_;
N_LIB_PRIVATE TNimType NTIarrayLtsymkind_seqLtocitemTT__s1XJ229a5I0gccC9a8ovynJg_;
N_LIB_PRIVATE TNimType NTItable__IzudB87pHlXWFsowpECF3Q_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__2nwM9b3fWcA0dvFwaUqLcQg_;
extern TNimType NTIint__rR5Bzr1D5krxoo1NcNyeMA_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__eo8AEcZEcjOKWtrX6vLg3Q_;
N_LIB_PRIVATE TNimType NTIarrayLtsymkind_tableLsystemOstring_seqLtocitemTTT__Zd9cawxvdqOKiiqOkm71SmQ_;
N_LIB_PRIVATE TNimType NTItocsectionsfinal__AIk240fCwwMqKZJEnXPLZA_;
extern TNimType NTIstringtableref__frXcOWngaP9adxeuIUa3iBg_;
N_LIB_PRIVATE TNimType NTIjsonitem__OoNLxNebe9baMFlzOh1jvdw_;
extern TNimType NTIjsonnode__LaYTJJQFT9b3qbn9c5fIsCog_;
N_LIB_PRIVATE TNimType NTIseqLjsonitemT__Z0K9aZr9c4ex9ad72Ulcdqy7g_;
extern TNimType NTItstrtable__CJQ42V2zij8fd39a9aMiwtZw_;
extern TNimType NTIprstsharedstate__dLMuJdRQoOg2PJi1ktqSYQ_;
extern TNimType NTIidentcache__6ZZ9cf5acLVYxUxl0ehlA1g_;
extern TNimType NTIpackedset__THXDbzJSs2hcC9a33en2pdw_;
N_LIB_PRIVATE TNimType NTIorderedtable__uUf2ABI4SLuvVLy2s8ygdw_;
N_LIB_PRIVATE TNimType NTIorderedkeyvaluepair__qrCj5BRLChMPPtE8mZNTMw_;
N_LIB_PRIVATE TNimType NTIexamplegroup58objecttype__bbSjO9aaIauVHOujtpjo3Rw_;
N_LIB_PRIVATE TNimType NTIexamplegroup__Z4Ed9aRleAg258AnxIUkcCQ_;
N_LIB_PRIVATE TNimType NTIorderedkeyvaluepairseq__RKPQcDl19bqs7bJVDyxdQYg_;
N_LIB_PRIVATE TNimType NTIpdoc__DVY9cSsFXOXsfAd5wCWVrTg_;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_14, "/home/runner/work/nightlies/nightlies/nim/compiler/docgen.nim", 61);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__iS6Vfak4fKt7fhPmyApRcg_13 = {((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_14),
((NI) 232),
((NI) 17)}
;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_15, "doc.googleAnalytics", 19);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_16, "doc.plausibleAnalytics", 22);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_17, "docgen.nim(280, 14) `false` Either use googleAnalytics or plausibleAnalytics", 76);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_18, "<script>\012  (function(i,s,o,g,r,a,m){i[\'GoogleAnalyticsObject\']=r;i[r]=i[r]||function(){\012  (i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),\012  m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)\012  })(window,document,\'script\',\'//www.google-analytics.com/analytics.js\',\'ga\');\012\012  ga(\'create\', \'$1\', \'auto\');\012  ga(\'send\', \'pageview\');\012\012</script>\012    ", 402);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_19, "doc.googleAnalytics", 19);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_20, "    <script defer data-domain=\"$1\" src=\"https://plausible.io/js/plausible.js\"></script>\012    ", 92);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_21, "doc.plausibleAnalytics", 22);
N_LIB_PRIVATE TNimType NTIobject__Jp5hmeXcpCwUxySNwOFFoQ_;
N_LIB_PRIVATE TNimType NTIptrtdocumentor__5rKcOUCklcaxmojH8unweg_;
N_LIB_PRIVATE TNimType NTIrefobject__TGC3u8unDUvns3a0CJWQdw_;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_23, "skip", 4);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_24, "snippets", 8);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_25, "_snippet_", 9);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_26, ".nim", 4);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_27, "import \"$1\"\012", 12);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_28, "\\", 1);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_29, "/", 1);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_30, "nim ", 4);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_31, "$nim ", 5);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_32, "$1", 2);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_33, "$options", 8);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_34, "nim", 3);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_35, "libpath", 7);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_36, "docCmd", 6);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_37, "backend", 7);
extern TNimType NTItbackend__zoooocqvga73vZuhGAAy6A_;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_38, "options", 7);
extern NIM_CONST tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw unknownLineInfo__lineinfos_284;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__iS6Vfak4fKt7fhPmyApRcg_40 = {((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_14),
((NI) 343),
((NI) 16)}
;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_41, "snippet failed: cmd: \'$1\' status: $2 expected: $3 output: $4", 60);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__iS6Vfak4fKt7fhPmyApRcg_42 = {((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_14),
((NI) 346),
((NI) 18)}
;
N_LIB_PRIVATE TNimType NTIobject__FkNfvNWmsd8YzfuKoBUSmA_;
N_LIB_PRIVATE TNimType NTIrefobject__rNRAvx86kE4vxe49aRy4cdQ_;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_44, "@default", 8);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_45, "@pkg", 4);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_46, "@path", 5);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_49, "\'$1\' failed", 11);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_51, "conf.docRoot.isAbsolute", 23);
static NIM_CONST tyArray__nHXaesL0DJZHyVS07ARPRA TM__iS6Vfak4fKt7fhPmyApRcg_50 = {((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_51)}
;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_52, "; conf.docRoot: ", 16);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__iS6Vfak4fKt7fhPmyApRcg_53 = {((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_14),
((NI) 176),
((NI) 8)}
;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_55, "conf.docRoot.dirExists", 22);
static NIM_CONST tyArray__nHXaesL0DJZHyVS07ARPRA TM__iS6Vfak4fKt7fhPmyApRcg_54 = {((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_55)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__iS6Vfak4fKt7fhPmyApRcg_56 = {((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_14),
((NI) 177),
((NI) 8)}
;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_57, "..", 2);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_58, "_._", 3);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_59, "docgen.nim(185, 3) `not result.isEmpty` ", 40);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_60, "docgen.nim(186, 3) `not isAbsolute(result.string)` ", 51);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_61, "html", 4);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_62, "doc.deprecationmsg", 18);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_64, "label", 5);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_65, "Deprecated", 10);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_66, "message", 7);
static NIM_CONST tyArray__sMpvt1sOxOJ3LFGulnbeMQ TM__iS6Vfak4fKt7fhPmyApRcg_63 = {((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_64),
((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_65),
((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_66),
((NimStringDesc*) NIM_NIL)}
;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_67, "Deprecated:", 11);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_68, "docgen.nim(868, 14) `false` ", 28);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_69, "ref ", 4);
extern TNimType NTItspecialword__N2XsqTpO5IzOf2KmXwk4Dw_;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_70, "writes", 6);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_71, "new", 3);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_72, "escapes", 7);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_73, "`", 1);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_74, "##", 2);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_75, "docgen.nim(700, 14) `result.len == 2` ", 38);
static NIM_CONST tySet_tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw TM__iS6Vfak4fKt7fhPmyApRcg_76 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04,
0x00, 0x06, 0x00, 0x00, 0xc0, 0x00, 0x08, 0x40,
0x20, 0x60, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_77, "runnableExamples invalid", 24);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__iS6Vfak4fKt7fhPmyApRcg_78 = {((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_14),
((NI) 539),
((NI) 40)}
;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_79, "string litteral expected", 24);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__iS6Vfak4fKt7fhPmyApRcg_80 = {((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_14),
((NI) 543),
((NI) 44)}
;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_81, "(", 1);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_82, ", ", 2);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_83, ")", 1);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_84, "autogenerated by docgen\012loc: $1\012rdoccmd: $2", 43);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_85, "runnableExamples", 16);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_86, "$#_examples_$#.nim", 18);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_87, "codeReordering", 14);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_88, "{.line: $#.}:\012$#\012", 17);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_89, "#[\012$#\012]#\012import $#\012$#\012", 22);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_90, "import $1\012", 10);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_91, "import $#\012$#", 12);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_92, "Example:", 8);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_93, " cmd: ", 6);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_94, "\012<p><strong class=\"examples_text\">$1</strong></p>\012", 50);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_95, "\012\012\\textbf{$1}\012", 14);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_96, "doc.listing_start", 17);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_97, "langNim", 7);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_98, "doc.listing_end", 15);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_99, "runnableExamples must appear before the first non-comment statement", 67);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__iS6Vfak4fKt7fhPmyApRcg_100 = {((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_14),
((NI) 667),
((NI) 18)}
;
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__iS6Vfak4fKt7fhPmyApRcg_101 = {
0x00, 0x3e, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_102, ".m", 2);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_103, ".e", 2);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_104, ".i", 2);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_105, ".t", 2);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_106, ".c", 2);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_107, ",", 1);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_108, "_", 1);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_109, "<span class=\"Comment\">$1</span>", 31);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_110, "\\spanComment{$1}", 16);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_111, "<span class=\"Keyword\">$1</span>", 31);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_112, "\\spanKeyword{$1}", 16);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_113, "<span class=\"Operator\">$1</span>", 32);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_114, "\\spanOperator{$1}", 17);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_115, "<span class=\"StringLit\">$1</span>", 33);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_116, "\\spanStringLit{$1}", 18);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_117, "<span class=\"CharLit\">$1</span>", 31);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_118, "\\spanCharLit{$1}", 16);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_119, "<span class=\"DecNumber\">$1</span>", 33);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_120, "\\spanDecNumber{$1}", 18);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_121, "<span class=\"FloatNumber\">$1</span>", 35);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_122, "\\spanFloatNumber{$1}", 20);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_123, "<a href=\"#$2\"><span class=\"Identifier\">$1</span></a>", 52);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_124, "\\spanIdentifier{$1}", 19);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_125, "<a href=\"$1#$2\"><span class=\"Identifier\">$3</span></a>", 54);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_126, "<span class=\"Identifier\">$1</span>", 34);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_127, "\\spanOther{$1}", 14);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_128, "<span>\012<span class=\"Other pragmadots\">...</span>\012</span>\012<span class=\"pragmawrap\">", 82);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_129, "\012", 1);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_130, "</span>", 7);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_131, "<span class=\"Other\">$1</span>", 29);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_132, "doc.item.seesrc", 15);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_133, "git.url", 7);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_134, "devel", 5);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_135, "version-$1-$2", 13);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_136, "git.commit", 10);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_137, "git.devel", 9);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_138, "path", 4);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_139, "line", 4);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_140, "url", 3);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_141, "commit", 6);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_142, "name", 4);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_143, "uniqueName", 10);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_144, "header", 6);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_145, "itemID", 6);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_146, "header_plain", 12);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_147, "itemSym", 7);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_148, "itemSymOrID", 11);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_149, "itemSymEnc", 10);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_150, "itemSymOrIDEnc", 14);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_151, "seeSrc", 6);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_152, "deprecationMsg", 14);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_153, "\342\200\246", 3);
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__iS6Vfak4fKt7fhPmyApRcg_154 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x50, 0x00, 0x04,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_155, "doc.item.toc", 12);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_156, "doc.item.tocTable", 17);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_157, ",<wbr>", 6);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_158, ": ", 2);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_159, "false", 5);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_160, "<a class=\"reference external\" href=\"$2\">$1</a>", 46);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_161, "<a href=\"$2#$3\"><span class=\"Identifier\">$1</span></a>", 54);
extern TNimType NTIkeyvaluepairseq__7lEisrXlQEzwtUKW5pzRCw_;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_163, "doc.item", 8);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_164, "desc", 4);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_165, "$1_group$2_examples.nim", 23);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_166, "# autogenerated by docgen\012# source: $1\012# rdoccmd: $2\012$3", 55);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_167, "$nim $backend -r --lib:$libpath --warning:UnusedImport:off --path:$path --nimcache:$nimcache $rdoccmd $docCmd $file", 115);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_168, "nimcache", 8);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_169, "file", 4);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_170, "rdoccmd", 7);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_171, "nodejs", 6);
extern NIM_CONST tyArray__nHXaesL0DJZHyVS07ARPRA ExeExts__pureZos_652;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_172, "node", 4);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_174, "Please install NodeJS first, see https://nodejs.org/en/download", 63);
static NIM_CONST tyArray__nHXaesL0DJZHyVS07ARPRA TM__iS6Vfak4fKt7fhPmyApRcg_173 = {((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_174)}
;
extern TNimType NTIrefioerror__0NUycR3lTt5ae7Mj01Qw8A_;
extern TNimType NTIioerror__5GCiDuy5Wsuc9an2QZvqgIA_;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_175, "NodeJS not found in PATH: ", 26);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_176, "nimDebug", 8);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_177, "options.nim(645, 14) `false` ", 29);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_178, "[runnableExamples] failed: generated file: \'$1\' group: \'$2\' cmd: $3", 67);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_179, "rdoccmd: ", 9);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_180, "docCmd: ", 8);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_181, "code: ", 6);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_182, "index: ", 7);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_183, "runnableExamples: ", 18);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__iS6Vfak4fKt7fhPmyApRcg_184 = {((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_14),
((NI) 527),
((NI) 16)}
;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_185, "Imports", 7);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_186, "Types", 5);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_187, "Vars", 4);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_188, "Lets", 4);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_189, "Consts", 6);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_190, "Procs", 5);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_191, "Funcs", 5);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_192, "Methods", 7);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_193, "Iterators", 9);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_194, "Converters", 10);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_195, "Macros", 6);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_196, "Templates", 9);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_197, "Exports", 7);
N_LIB_PRIVATE NIM_CONST tyArray__DThrQCZozFo0up9c69cEDODw sectionNames__docgen_6251 = {((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_185),
((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_186),
((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_187),
((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_188),
((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_189),
((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_187),
((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_190),
((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_191),
((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_192),
((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_193),
((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_194),
((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_195),
((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_196),
((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_197)}
;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_198, "doc.section", 11);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_199, "sectionid", 9);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_200, "sectionTitle", 12);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_201, "sectionTitleID", 14);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_202, "content", 7);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_205, "doc.section.toc2", 16);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_206, "plainName", 9);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_208, "doc.section.toc", 15);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_209, "doc.toc", 7);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_210, "<h2 class=\"subtitle\">$1</h2>", 28);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_211, "\\\\\\vspace{0.5em}\\large $1", 25);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_212, "doc.body_toc_groupsection", 25);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_213, "doc.body_toc_group", 18);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_214, "doc.body_toc", 12);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_215, "doc.body_no_toc", 15);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_216, "title", 5);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_217, "subtitle", 8);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_218, "tableofcontents", 15);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_219, "moduledesc", 10);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_220, "date", 4);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_221, "time", 4);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_222, "theindexhref", 12);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_223, "theindex.html", 13);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_224, "body_toc_groupsection", 21);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_225, "doc.file", 8);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_226, "nimdoccss", 9);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_227, "nimdoc.out.css", 14);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_228, "dochackjs", 9);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_229, "dochack.js", 10);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_230, "author", 6);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_231, "version", 7);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_232, "analytics", 9);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__iS6Vfak4fKt7fhPmyApRcg_234 = {((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_14),
((NI) 1448),
((NI) 16)}
;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_235, "$nimr/doc/nimdoc.css", 20);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_236, "nimdoc.out.css", 14);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_237, ".idx", 4);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_238, "comment", 7);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_239, "type", 4);
extern TNimType NTItsymkind__sjiB9b9aO1FRPetW6gPYZbfw_;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_240, "col", 3);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_241, "description", 11);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_242, "code", 4);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_243, "signature", 9);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_244, "return", 6);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_245, "arguments", 9);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_246, "default", 7);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_247, "pragmas", 7);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_248, "genericParams", 13);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_249, "types", 5);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_250, "orig", 4);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_251, "nimble", 6);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_252, "moduleDescription", 17);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_253, "entries", 7);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_254, "unable to open file \"", 21);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_255, "\" for writing", 13);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__iS6Vfak4fKt7fhPmyApRcg_256 = {((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_14),
((NI) 1476),
((NI) 16)}
;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_257, "Index", 5);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__iS6Vfak4fKt7fhPmyApRcg_259 = {((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_14),
((NI) 1584),
((NI) 14)}
;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_260, "txt", 3);
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_261, "tex", 3);
N_LIB_PRIVATE TNimType NTIobject__EkXrf9bj6BppyBV1BtAGatQ_;
N_LIB_PRIVATE TNimType NTIrefobject__X8kkALavbEdzXIrP0m7q2g_;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_263, "the \':test:\' attribute is not supported by this backend", 55);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__iS6Vfak4fKt7fhPmyApRcg_264 = {((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_14),
((NI) 1524),
((NI) 14)}
;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_265, "json", 4);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__iS6Vfak4fKt7fhPmyApRcg_267 = {((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_14),
((NI) 1540),
((NI) 16)}
;
N_LIB_PRIVATE TNimType NTIobject__SuJtoUSREUHobzyvPNB0bA_;
N_LIB_PRIVATE TNimType NTIrefobject__79c3Y3ZwA6fl2mb7ydHMpdg_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__iS6Vfak4fKt7fhPmyApRcg_269 = {((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_14),
((NI) 1548),
((NI) 14)}
;
STRING_LITERAL(TM__iS6Vfak4fKt7fhPmyApRcg_270, "tags", 4);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__iS6Vfak4fKt7fhPmyApRcg_272 = {((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_14),
((NI) 1563),
((NI) 16)}
;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5211;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern Exception* currException__system_2566;
extern Exception* currException__system_2566;
extern Exception* currException__system_2566;
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5302)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5264)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5307)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5258((&gch__system_5211.zct), c);
}
static N_INLINE(void, decRef__system_5309)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5307(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5264(src);
		incRef__system_5302(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5264((*dest));
		decRef__system_5309(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(void, handleDocOutputOptions__docgen_7225)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	{
		if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 33))&63U)))!=0)) goto LA3_;
		asgnRef((void**) (&(*conf).outDir), slash___pathutils_90((*conf).outDir, (*conf).outFile));
	}
	LA3_: ;
}
static N_NIMCALL(void, Marker_tyRef__QkCnC3fwblDHMj9b4OGf6Nw)(void* p, NI op) {
	tyObject_Env_docgendotnim_newDocumentor___l319aWpTxh3BHYVEmIhN02w* a;
	a = (tyObject_Env_docgendotnim_newDocumentor___l319aWpTxh3BHYVEmIhN02w*)p;
	nimGCvisit((void*)(*a).conf1, op);
}
static N_NIMCALL(void, Marker_tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q)(void* p, NI op) {
	tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q* a;
	NI T1_;
	a = (tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	switch (a->data[T1_].isRst) {
	case NIM_TRUE:
	nimGCvisit((void*)a->data[T1_]._isRst_1.rst, op);
	break;
	case NIM_FALSE:
	nimGCvisit((void*)a->data[T1_]._isRst_2.str, op);
	break;
	} 
	}
}
static N_NIMCALL(void, Marker_tySequence__bLuZlbeJhlfg9axVlmjdJXw)(void* p, NI op) {
	tySequence__bLuZlbeJhlfg9axVlmjdJXw* a;
	NI T1_;
	a = (tySequence__bLuZlbeJhlfg9axVlmjdJXw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].descRst, op);
	nimGCvisit((void*)a->data[T1_].substitutions, op);
	nimGCvisit((void*)a->data[T1_].sortName, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__spLz9azjOgbpYKrtmm9aMHEw)(void* p, NI op) {
	tySequence__spLz9azjOgbpYKrtmm9aMHEw* a;
	NI T1_;
	a = (tySequence__spLz9azjOgbpYKrtmm9aMHEw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].content, op);
	nimGCvisit((void*)a->data[T1_].sortName, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__eo8AEcZEcjOKWtrX6vLg3Q)(void* p, NI op) {
	tySequence__eo8AEcZEcjOKWtrX6vLg3Q* a;
	NI T1_;
	a = (tySequence__eo8AEcZEcjOKWtrX6vLg3Q*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field1, op);
	nimGCvisit((void*)a->data[T1_].Field2, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__Z0K9aZr9c4ex9ad72Ulcdqy7g)(void* p, NI op) {
	tySequence__Z0K9aZr9c4ex9ad72Ulcdqy7g* a;
	NI T1_;
	a = (tySequence__Z0K9aZr9c4ex9ad72Ulcdqy7g*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].json, op);
	nimGCvisit((void*)a->data[T1_].rst, op);
	nimGCvisit((void*)a->data[T1_].rstField, op);
	}
}
static N_NIMCALL(void, Marker_tyRef__Z4Ed9aRleAg258AnxIUkcCQ)(void* p, NI op) {
	tyObject_ExampleGroupcolonObjectType___bbSjO9aaIauVHOujtpjo3Rw* a;
	a = (tyObject_ExampleGroupcolonObjectType___bbSjO9aaIauVHOujtpjo3Rw*)p;
	nimGCvisit((void*)(*a).rdoccmd, op);
	nimGCvisit((void*)(*a).docCmd, op);
	nimGCvisit((void*)(*a).code, op);
}
static N_NIMCALL(void, Marker_tySequence__RKPQcDl19bqs7bJVDyxdQYg)(void* p, NI op) {
	tySequence__RKPQcDl19bqs7bJVDyxdQYg* a;
	NI T1_;
	a = (tySequence__RKPQcDl19bqs7bJVDyxdQYg*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field2, op);
	nimGCvisit((void*)a->data[T1_].Field3, op);
	}
}
static N_NIMCALL(void, Marker_tyRef__DVY9cSsFXOXsfAd5wCWVrTg)(void* p, NI op) {
	tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* a;
	NI T1_;
	NI T2_;
	NI T3_;
	NI T4_;
	NI T5_;
	NI T6_;
	NI T7_;
	a = (tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg*)p;
	nimGCvisit((void*)(*a).Sup.config, op);
	nimGCvisit((void*)(*a).Sup.tocPart, op);
	nimGCvisit((void*)(*a).Sup.theIndex, op);
	nimGCvisit((void*)(*a).Sup.findFile.ClE_0, op);
	nimGCvisit((void*)(*a).Sup.msgHandler.ClE_0, op);
	nimGCvisit((void*)(*a).Sup.outDir, op);
	nimGCvisit((void*)(*a).Sup.destFile, op);
	nimGCvisit((void*)(*a).Sup.filenames.filenameToIdx.data, op);
	nimGCvisit((void*)(*a).Sup.filenames.idxToFilename, op);
	nimGCvisit((void*)(*a).Sup.filename, op);
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < 5; T1_++) {
	nimGCvisit((void*)(*a).Sup.meta[T1_], op);
	}
	nimGCvisit((void*)(*a).Sup.currentSection, op);
	nimGCvisit((void*)(*a).Sup.seenIndexTerms.data, op);
	nimGCvisit((void*)(*a).Sup.onTestSnippet.ClE_0, op);
	nimGCvisit((void*)(*a).modDescPre, op);
	nimGCvisit((void*)(*a).modDescFinal, op);
	nimGCvisit((void*)(*a).module, op);
	nimGCvisit((void*)(*a).modDeprecationMsg, op);
	T2_ = (NI)0;
	for (T2_ = 0; T2_ < 26; T2_++) {
	nimGCvisit((void*)(*a).section[T2_].secItems, op);
	nimGCvisit((void*)(*a).section[T2_].finalMarkup, op);
	}
	T3_ = (NI)0;
	for (T3_ = 0; T3_ < 26; T3_++) {
	nimGCvisit((void*)(*a).tocSimple[T3_], op);
	}
	T4_ = (NI)0;
	for (T4_ = 0; T4_ < 26; T4_++) {
	nimGCvisit((void*)(*a).tocTable[T4_].data, op);
	}
	T5_ = (NI)0;
	for (T5_ = 0; T5_ < 26; T5_++) {
	nimGCvisit((void*)(*a).toc2[T5_], op);
	}
	T6_ = (NI)0;
	for (T6_ = 0; T6_ < 26; T6_++) {
	nimGCvisit((void*)(*a).toc[T6_], op);
	}
	nimGCvisit((void*)(*a).indexValFilename, op);
	nimGCvisit((void*)(*a).analytics, op);
	nimGCvisit((void*)(*a).seenSymbols, op);
	nimGCvisit((void*)(*a).jEntriesPre, op);
	nimGCvisit((void*)(*a).jEntriesFinal, op);
	nimGCvisit((void*)(*a).types.data, op);
	nimGCvisit((void*)(*a).sharedState, op);
	nimGCvisit((void*)(*a).conf, op);
	nimGCvisit((void*)(*a).cache, op);
	nimGCvisit((void*)(*a).emitted.head, op);
	nimGCvisit((void*)(*a).emitted.data, op);
	T7_ = (NI)0;
	nimGCvisit((void*)(*a).thisDir, op);
	nimGCvisit((void*)(*a).exampleGroups.data, op);
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5264(p);
	decRef__system_5309(T1_);
}
static N_INLINE(NimStringDesc*, slash___pureZos_121)(NimStringDesc* head, NimStringDesc* tail) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = nosjoinPath(head, tail);
	return result;
}
N_LIB_PRIVATE N_CLOSURE(NimStringDesc*, docgenFindFile__docgen_378)(NimStringDesc* sX60gensym38_, void* ClE_0) {
	NimStringDesc* result;
	tyObject_Env_docgendotnim_newDocumentor___l319aWpTxh3BHYVEmIhN02w* colonenvP_;
	result = NIM_NIL;
	colonenvP_ = (tyObject_Env_docgendotnim_newDocumentor___l319aWpTxh3BHYVEmIhN02w*) ClE_0;
	result = findFile__options_4487((*colonenvP_).conf1, sX60gensym38_, NIM_FALSE);
	{
		NimStringDesc* T5_;
		if (!((result ? result->Sup.len : 0) == ((NI) 0))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = nosgetCurrentDir();
		result = slash___pureZos_121(T5_, sX60gensym38_);
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = nosfileExists(result);
			if (!!(T8_)) goto LA9_;
			result = ((NimStringDesc*) NIM_NIL);
		}
		LA9_: ;
	}
	LA3_: ;
	return result;
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw, newLineInfo__msgs_408)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename, NI line, NI col) {
	tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw result;
	NI32 T1_;
	nimZeroMem((void*)(&result), sizeof(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw));
	T1_ = (NI32)0;
	T1_ = fileInfoIdx__msgs_376(conf, filename);
	result = newLineInfo__msgs_391(T1_, line, col);
	return result;
}
N_LIB_PRIVATE N_CLOSURE(void, compilerMsgHandler__docgen_371)(NimStringDesc* filenameX60gensym38_, NI lineX60gensym38_, NI colX60gensym38_, tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg msgKindX60gensym38_, NimStringDesc* argX60gensym38_, void* ClE_0) {
	tyObject_Env_docgendotnim_newDocumentor___l319aWpTxh3BHYVEmIhN02w* colonenvP_;
	tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ kX60gensym38_;
	tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw T17_;
	colonenvP_ = (tyObject_Env_docgendotnim_newDocumentor___l319aWpTxh3BHYVEmIhN02w*) ClE_0;
	kX60gensym38_ = (tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ)0;
	switch (msgKindX60gensym38_) {
	case ((tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg) 0):
	{
		kX60gensym38_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 4);
	}
	break;
	case ((tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg) 1):
	{
		kX60gensym38_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 5);
	}
	break;
	case ((tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg) 2):
	{
		kX60gensym38_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 6);
	}
	break;
	case ((tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg) 3):
	{
		kX60gensym38_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 7);
	}
	break;
	case ((tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg) 4):
	{
		kX60gensym38_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 8);
	}
	break;
	case ((tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg) 5):
	{
		kX60gensym38_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 9);
	}
	break;
	case ((tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg) 6):
	{
		kX60gensym38_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 10);
	}
	break;
	case ((tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg) 7):
	{
		kX60gensym38_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 11);
	}
	break;
	case ((tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg) 8):
	{
		kX60gensym38_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 12);
	}
	break;
	case ((tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg) 15):
	{
		kX60gensym38_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 13);
	}
	break;
	case ((tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg) 9):
	{
		kX60gensym38_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 26);
	}
	break;
	case ((tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg) 10):
	{
		kX60gensym38_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 27);
	}
	break;
	case ((tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg) 11):
	{
		kX60gensym38_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 28);
	}
	break;
	case ((tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg) 12):
	{
		kX60gensym38_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 29);
	}
	break;
	case ((tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg) 13):
	{
		kX60gensym38_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 30);
	}
	break;
	case ((tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg) 14):
	{
		kX60gensym38_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 31);
	}
	break;
	}
	T17_ = newLineInfo__msgs_408((*colonenvP_).conf1, filenameX60gensym38_, lineX60gensym38_, colX60gensym38_);
	liMessage__msgs_1128((*colonenvP_).conf1, T17_, kX60gensym38_, argX60gensym38_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 2), TM__iS6Vfak4fKt7fhPmyApRcg_13, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isLatexCmd__docgen_349)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((163840 &((NU32)1<<((NU)((*conf).cmd)&31U)))!=0);
	return result;
}
static N_NIMCALL(void, Marker_tyRef__TGC3u8unDUvns3a0CJWQdw)(void* p, NI op) {
	tyObject_Env_docgendotnim_colonanonymous___Jp5hmeXcpCwUxySNwOFFoQ* a;
	a = (tyObject_Env_docgendotnim_colonanonymous___Jp5hmeXcpCwUxySNwOFFoQ*)p;
	nimGCvisit((void*)(*a).outp2, op);
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(NimStringDesc*, X5BX5D___pureZunicode_3215)(NimStringDesc* s, tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw x) {
	NimStringDesc* result;
	NI a;
	NI L;
	result = NIM_NIL;
	a = x.a;
	L = (NI)((NI)((NI)((s ? s->Sup.len : 0) - x.b) - a) + ((NI) 1));
	result = mnewString(((NI) (L)));
	{
		NI i;
		NI i_2;
		i = (NI)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < L)) goto LA3;
				i = i_2;
				result->data[i] = s->data[(NI)(i + a)];
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
static N_INLINE(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw, dotdot___stdZenumutils_90)(NI a, NI b) {
	tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw));
	result.a = a;
	result.b = b;
	return result;
}
N_LIB_PRIVATE N_CLOSURE(NimStringDesc*, interpSnippetCmd__docgen_409)(NimStringDesc* cmd, void* ClE_0) {
	NimStringDesc* result;
	tyObject_Env_docgendotnim_colonanonymous___Jp5hmeXcpCwUxySNwOFFoQ* colonenvP_;
	NimStringDesc* T10_;
	tyArray__meGd17iD6izZVY5NTv9bHUA T11_;
	NimStringDesc* T12_;
	result = NIM_NIL;
	colonenvP_ = (tyObject_Env_docgendotnim_colonanonymous___Jp5hmeXcpCwUxySNwOFFoQ*) ClE_0;
	{
		NIM_BOOL T3_;
		NimStringDesc* T6_;
		tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw T7_;
		NimStringDesc* T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = nsuStartsWith(cmd, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_30));
		if (!T3_) goto LA4_;
		T6_ = NIM_NIL;
		T7_ = dotdot___stdZenumutils_90(((NI) 4), ((NI) 1));
		T8_ = NIM_NIL;
		T8_ = X5BX5D___pureZunicode_3215(cmd, T7_);
		T6_ = rawNewString((T8_ ? T8_->Sup.len : 0) + 5);
appendString(T6_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_31));
appendString(T6_, T8_);
		result = T6_;
	}
	goto LA1_;
	LA4_: ;
	{
		result = copyString(cmd);
	}
	LA1_: ;
	T10_ = NIM_NIL;
	T10_ = nsuReplaceStr(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_32), ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_33));
	nimZeroMem((void*)T11_, sizeof(tyArray__meGd17iD6izZVY5NTv9bHUA));
	T11_[0] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_34));
	T12_ = NIM_NIL;
	T12_ = nosgetAppFilename();
	T11_[1] = nospquoteShell(T12_);
	T11_[2] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_35));
	T11_[3] = nospquoteShell((*(*(*colonenvP_).d1).conf).libpath);
	T11_[4] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_36));
	T11_[5] = copyString((*(*(*colonenvP_).d1).conf).docCmd);
	T11_[6] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_37));
	T11_[7] = reprEnum((NI)(*(*(*colonenvP_).d1).conf).backend, (&NTItbackend__zoooocqvga73vZuhGAAy6A_));
	T11_[8] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_38));
	T11_[9] = nospquoteShell((*colonenvP_).outp2);
	result = nsuFormatOpenArray(T10_, T11_, 10);
	return result;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___docgen_394)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* gen, NimStringDesc* filename, NimStringDesc* cmd, NI status, NimStringDesc* content, void* ClE_0) {
	tyObject_Env_docgendotnim_newDocumentor___l319aWpTxh3BHYVEmIhN02w* colonenvP_;
	tyObject_Env_docgendotnim_colonanonymous___Jp5hmeXcpCwUxySNwOFFoQ* colonenv_;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T22_;
	NimStringDesc* importStmt;
	NimStringDesc* T29_;
	NimStringDesc* cmd_2;
	tyProc__oFHfEKFsiYTMAy9a42cSiKw T30_;
	tyTuple__XOVT24GHXwqiEj5GCsEGCA T31_;
	NimStringDesc* output;
	NI gotten;
{	colonenvP_ = (tyObject_Env_docgendotnim_newDocumentor___l319aWpTxh3BHYVEmIhN02w*) ClE_0;
	colonenv_ = NIM_NIL;
	colonenv_ = (tyObject_Env_docgendotnim_colonanonymous___Jp5hmeXcpCwUxySNwOFFoQ*) newObj((&NTIrefobject__TGC3u8unDUvns3a0CJWQdw_), sizeof(tyObject_Env_docgendotnim_colonanonymous___Jp5hmeXcpCwUxySNwOFFoQ));
	(*colonenv_).Sup.m_type = (&NTIobject__Jp5hmeXcpCwUxySNwOFFoQ_);
	{
		if (!eqStrings((*(*colonenvP_).conf1).docCmd, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_23))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	(*gen).id += ((NI) 1);
	(*colonenv_).d1 = (*((tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg**) (&(gen))));
	asgnRef((void**) (&(*colonenv_).outp2), NIM_NIL);
	{
		NimStringDesc* nameOnly;
		tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T9_;
		NimStringDesc* T10_;
		NimStringDesc* T11_;
		NimStringDesc* T12_;
		NimStringDesc* T13_;
		NimStringDesc* T14_;
		if (!((filename ? filename->Sup.len : 0) == ((NI) 0))) goto LA7_;
		nimZeroMem((void*)(&T9_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
		nossplitFile((*(*colonenv_).d1).Sup.filename, (&T9_));
		nameOnly = T9_.Field1;
		T10_ = NIM_NIL;
		T10_ = getNimcacheDir__options_4185((*colonenvP_).conf1);
		T11_ = NIM_NIL;
		T11_ = slash___pathutils_112(T10_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_24));
		T12_ = NIM_NIL;
		T12_ = slash___pathutils_112(T11_, nameOnly);
		T13_ = NIM_NIL;
		T14_ = NIM_NIL;
		T14_ = dollar___systemZdollars_3((*(*colonenv_).d1).Sup.id);
		T13_ = rawNewString((nameOnly ? nameOnly->Sup.len : 0) + (T14_ ? T14_->Sup.len : 0) + 13);
appendString(T13_, nameOnly);
appendString(T13_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_25));
appendString(T13_, T14_);
appendString(T13_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_26));
		asgnRef((void**) (&(*colonenv_).outp2), slash___pathutils_90(T12_, T13_));
	}
	goto LA5_;
	LA7_: ;
	{
		NIM_BOOL T16_;
		NimStringDesc* T19_;
		T16_ = (NIM_BOOL)0;
		T16_ = nosisAbsolute(filename);
		if (!T16_) goto LA17_;
		T19_ = NIM_NIL;
		T19_ = (*colonenv_).outp2; (*colonenv_).outp2 = copyStringRC1(filename);
		if (T19_) nimGCunrefNoCycle(T19_);
	}
	goto LA5_;
	LA17_: ;
	{
		NimStringDesc* nameOnly_2;
		tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T21_;
		nimZeroMem((void*)(&T21_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
		nossplitFile((*(*colonenv_).d1).Sup.filename, (&T21_));
		nameOnly_2 = T21_.Field1;
		asgnRef((void**) (&(*colonenv_).outp2), slash___pathutils_90(nameOnly_2, filename));
	}
	LA5_: ;
	nimZeroMem((void*)(&T22_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	splitFile__pathutils_27((*colonenv_).outp2, (&T22_));
	noscreateDir(T22_.Field0);
	{
		if (!(*(*colonenv_).d1).isPureRst) goto LA25_;
		importStmt = ((NimStringDesc*) NIM_NIL);
	}
	goto LA23_;
	LA25_: ;
	{
		tyArray__nHXaesL0DJZHyVS07ARPRA T28_;
		nimZeroMem((void*)T28_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
		T28_[0] = nsuReplaceStr((*(*colonenv_).d1).Sup.filename, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_28), ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_29));
		importStmt = nsuFormatOpenArray(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_27), T28_, 1);
	}
	LA23_: ;
	T29_ = NIM_NIL;
	T29_ = rawNewString((importStmt ? importStmt->Sup.len : 0) + (content ? content->Sup.len : 0) + 0);
appendString(T29_, importStmt);
appendString(T29_, content);
	writeFile__systemZio_474((*colonenv_).outp2, T29_);
	nimZeroMem((void*)(&T30_), sizeof(tyProc__oFHfEKFsiYTMAy9a42cSiKw));
	T30_.ClP_0 = interpSnippetCmd__docgen_409; T30_.ClE_0 = colonenv_;
	cmd_2 = T30_.ClE_0? T30_.ClP_0(cmd, T30_.ClE_0):((TM__iS6Vfak4fKt7fhPmyApRcg_39)(T30_.ClP_0))(cmd);
	liMessage__msgs_1128((*colonenvP_).conf1, unknownLineInfo__lineinfos_284, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 93), cmd_2, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), TM__iS6Vfak4fKt7fhPmyApRcg_40, NIM_FALSE);
	nimZeroMem((void*)(&T31_), sizeof(tyTuple__XOVT24GHXwqiEj5GCsEGCA));
	execCmdEx__pureZosproc_1164(cmd_2, 10, ((tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA*) NIM_NIL), ((NimStringDesc*) NIM_NIL), ((NimStringDesc*) NIM_NIL), (&T31_));
	output = NIM_NIL;
	output = T31_.Field0;
	gotten = (NI)0;
	gotten = T31_.Field1;
	{
		tyArray__sMpvt1sOxOJ3LFGulnbeMQ T36_;
		NimStringDesc* T37_;
		if (!!((gotten == status))) goto LA34_;
		nimZeroMem((void*)T36_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
		T36_[0] = copyString(cmd_2);
		T36_[1] = dollar___systemZdollars_3(gotten);
		T36_[2] = dollar___systemZdollars_3(status);
		T36_[3] = copyString(output);
		T37_ = NIM_NIL;
		T37_ = nsuFormatOpenArray(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_41), T36_, 4);
		liMessage__msgs_1128((*colonenvP_).conf1, unknownLineInfo__lineinfos_284, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T37_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), TM__iS6Vfak4fKt7fhPmyApRcg_42, NIM_FALSE);
	}
	LA34_: ;
	}BeforeRet_: ;
}
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result) {
	initPackedSet__pureZcollectionsZintsets_16(Result);
}
static N_INLINE(NIM_BOOL, isEmpty__options_4084)(NimStringDesc* x) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((x ? x->Sup.len : 0) == ((NI) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getOutFile2__docgen_335)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename, NimStringDesc* ext, NIM_BOOL guessTarget) {
	NimStringDesc* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		NimStringDesc* d;
		NimStringDesc* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 33))&63U)))!=0);
		if (T3_) goto LA4_;
		T3_ = guessTarget;
		LA4_: ;
		if (!T3_) goto LA5_;
		d = (*conf).outDir;
		noscreateDir(d);
		T7_ = NIM_NIL;
		T7_ = noschangeFileExt(filename, ext);
		result = slash___pathutils_90(d, T7_);
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T9_;
		T9_ = (NIM_BOOL)0;
		T9_ = isEmpty__options_4084((*conf).outFile);
		if (!!(T9_)) goto LA10_;
		result = absOutFile__options_4073(conf);
	}
	goto LA1_;
	LA10_: ;
	{
		result = getOutFile__options_4063(conf, filename, ext);
	}
	LA1_: ;
	return result;
}
static N_NIMCALL(void, Marker_tyRef__rNRAvx86kE4vxe49aRy4cdQ)(void* p, NI op) {
	tyObject_Env_docgendotnim_presentationPath___FkNfvNWmsd8YzfuKoBUSmA* a;
	a = (tyObject_Env_docgendotnim_presentationPath___FkNfvNWmsd8YzfuKoBUSmA*)p;
	nimGCvisit((void*)(*a).conf1, op);
	nimGCvisit((void*)(*a).file22, op);
}
N_LIB_PRIVATE N_CLOSURE(NimStringDesc*, nimbleDir__docgen_206)(void* ClE_0) {
	NimStringDesc* result;
	tyObject_Env_docgendotnim_presentationPath___FkNfvNWmsd8YzfuKoBUSmA* colonenvP_;
	NimStringDesc* T1_;
	result = NIM_NIL;
	colonenvP_ = (tyObject_Env_docgendotnim_presentationPath___FkNfvNWmsd8YzfuKoBUSmA*) ClE_0;
	T1_ = NIM_NIL;
	T1_ = getNimbleFile__options_4161((*colonenvP_).conf1, (*colonenvP_).file22);
	result = nosparentDir(T1_);
	return result;
}
static N_INLINE(NIM_BOOL, isEmpty__pathutils_94)(NimStringDesc* x) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((x ? x->Sup.len : 0) == ((NI) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, presentationPath__docgen_197)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* file) {
	NimStringDesc* result;
	tyObject_Env_docgendotnim_presentationPath___FkNfvNWmsd8YzfuKoBUSmA* colonenv_;
	result = NIM_NIL;
	colonenv_ = NIM_NIL;
	colonenv_ = (tyObject_Env_docgendotnim_presentationPath___FkNfvNWmsd8YzfuKoBUSmA*) newObj((&NTIrefobject__rNRAvx86kE4vxe49aRy4cdQ_), sizeof(tyObject_Env_docgendotnim_presentationPath___FkNfvNWmsd8YzfuKoBUSmA));
	(*colonenv_).Sup.m_type = (&NTIobject__FkNfvNWmsd8YzfuKoBUSmA_);
	asgnRef((void**) (&(*colonenv_).conf1), conf);
	asgnRef((void**) (&(*colonenv_).file22), dollar___options_4370(file));
	if (eqStrings((*(*colonenv_).conf1).docRoot, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_44))) goto LA1_;
	if (eqStrings((*(*colonenv_).conf1).docRoot, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_45))) goto LA2_;
	if (eqStrings((*(*colonenv_).conf1).docRoot, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_46))) goto LA3_;
	goto LA4_;
	LA1_: ;
	{
		NimStringDesc* dir;
		tyProc__LCMSFwcIs5O0HdDmqpX05g T7_;
		result = getRelativePathFromConfigPath__options_4365((*colonenv_).conf1, file, NIM_FALSE);
		nimZeroMem((void*)(&T7_), sizeof(tyProc__LCMSFwcIs5O0HdDmqpX05g));
		T7_.ClP_0 = nimbleDir__docgen_206; T7_.ClE_0 = colonenv_;
		dir = T7_.ClE_0? T7_.ClP_0(T7_.ClE_0):((TM__iS6Vfak4fKt7fhPmyApRcg_47)(T7_.ClP_0))();
		{
			NIM_BOOL T10_;
			NimStringDesc* result2;
			T10_ = (NIM_BOOL)0;
			T10_ = isEmpty__pathutils_94(dir);
			if (!!(T10_)) goto LA11_;
			result2 = relativeTo__pathutils_133(file, dir, 47);
			{
				NIM_BOOL T15_;
				NIM_BOOL T16_;
				NIM_BOOL T18_;
				T15_ = (NIM_BOOL)0;
				T16_ = (NIM_BOOL)0;
				T16_ = isEmpty__options_4084(result2);
				T15_ = !(T16_);
				if (!(T15_)) goto LA17_;
				T18_ = (NIM_BOOL)0;
				T18_ = isEmpty__options_4084(result);
				if (T18_) goto LA19_;
				T18_ = ((result2 ? result2->Sup.len : 0) < (result ? result->Sup.len : 0));
				LA19_: ;
				T15_ = T18_;
				LA17_: ;
				if (!T15_) goto LA20_;
				result = copyString(result2);
			}
			LA20_: ;
		}
		LA11_: ;
		{
			NIM_BOOL T24_;
			T24_ = (NIM_BOOL)0;
			T24_ = isEmpty__options_4084(result);
			if (!T24_) goto LA25_;
			result = relativeTo__pathutils_133(file, (*(*colonenv_).conf1).projectPath, 47);
		}
		LA25_: ;
	}
	goto LA5_;
	LA2_: ;
	{
		NimStringDesc* dir_2;
		tyProc__LCMSFwcIs5O0HdDmqpX05g T28_;
		nimZeroMem((void*)(&T28_), sizeof(tyProc__LCMSFwcIs5O0HdDmqpX05g));
		T28_.ClP_0 = nimbleDir__docgen_206; T28_.ClE_0 = colonenv_;
		dir_2 = T28_.ClE_0? T28_.ClP_0(T28_.ClE_0):((TM__iS6Vfak4fKt7fhPmyApRcg_48)(T28_.ClP_0))();
		{
			NIM_BOOL T31_;
			T31_ = (NIM_BOOL)0;
			T31_ = isEmpty__pathutils_94(dir_2);
			if (!T31_) goto LA32_;
			result = relativeTo__pathutils_133(file, (*(*colonenv_).conf1).projectPath, 47);
		}
		goto LA29_;
		LA32_: ;
		{
			result = relativeTo__pathutils_133(file, dir_2, 47);
		}
		LA29_: ;
	}
	goto LA5_;
	LA3_: ;
	{
		result = getRelativePathFromConfigPath__options_4365((*colonenv_).conf1, file, NIM_FALSE);
		{
			NIM_BOOL T38_;
			T38_ = (NIM_BOOL)0;
			T38_ = isEmpty__options_4084(result);
			if (!T38_) goto LA39_;
			result = relativeTo__pathutils_133(file, (*(*colonenv_).conf1).projectPath, 47);
		}
		LA39_: ;
	}
	goto LA5_;
	LA4_: ;
	{
		{
			NimStringDesc* T66_;
			if (!(((NI) 0) < ((*(*colonenv_).conf1).docRoot ? (*(*colonenv_).conf1).docRoot->Sup.len : 0))) goto LA44_;
			{
				NIM_BOOL T48_;
				NimStringDesc* arg2X60gensym8_;
				T48_ = (NIM_BOOL)0;
				T48_ = nosisAbsolute((*(*colonenv_).conf1).docRoot);
				if (!!(T48_)) goto LA49_;
				arg2X60gensym8_ = nsuFormatOpenArray(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_49), TM__iS6Vfak4fKt7fhPmyApRcg_50, 1);
				{
					NimStringDesc* T55_;
					if (!(((NI) 0) < ((*(*colonenv_).conf1).docRoot ? (*(*colonenv_).conf1).docRoot->Sup.len : 0))) goto LA53_;
					T55_ = NIM_NIL;
					T55_ = rawNewString(((*(*colonenv_).conf1).docRoot ? (*(*colonenv_).conf1).docRoot->Sup.len : 0) + 16);
appendString(T55_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_52));
appendString(T55_, (*(*colonenv_).conf1).docRoot);
					arg2X60gensym8_ = resizeString(arg2X60gensym8_, (T55_ ? T55_->Sup.len : 0) + 0);
appendString(arg2X60gensym8_, T55_);
				}
				LA53_: ;
				liMessage__msgs_1128((*colonenv_).conf1, unknownLineInfo__lineinfos_284, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), arg2X60gensym8_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 2), TM__iS6Vfak4fKt7fhPmyApRcg_53, NIM_FALSE);
			}
			LA49_: ;
			{
				NIM_BOOL T58_;
				NimStringDesc* arg2X60gensym11_;
				T58_ = (NIM_BOOL)0;
				T58_ = nosdirExists((*(*colonenv_).conf1).docRoot);
				if (!!(T58_)) goto LA59_;
				arg2X60gensym11_ = nsuFormatOpenArray(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_49), TM__iS6Vfak4fKt7fhPmyApRcg_54, 1);
				{
					NimStringDesc* T65_;
					if (!(((NI) 0) < ((*(*colonenv_).conf1).docRoot ? (*(*colonenv_).conf1).docRoot->Sup.len : 0))) goto LA63_;
					T65_ = NIM_NIL;
					T65_ = rawNewString(((*(*colonenv_).conf1).docRoot ? (*(*colonenv_).conf1).docRoot->Sup.len : 0) + 16);
appendString(T65_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_52));
appendString(T65_, (*(*colonenv_).conf1).docRoot);
					arg2X60gensym11_ = resizeString(arg2X60gensym11_, (T65_ ? T65_->Sup.len : 0) + 0);
appendString(arg2X60gensym11_, T65_);
				}
				LA63_: ;
				liMessage__msgs_1128((*colonenv_).conf1, unknownLineInfo__lineinfos_284, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), arg2X60gensym11_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 2), TM__iS6Vfak4fKt7fhPmyApRcg_56, NIM_FALSE);
			}
			LA59_: ;
			T66_ = NIM_NIL;
			T66_ = nosexpandFilename((*(*colonenv_).conf1).docRoot);
			result = relativeTo__pathutils_133(file, T66_, 47);
		}
		goto LA42_;
		LA44_: ;
		{
			result = relativeTo__pathutils_133(file, (*(*colonenv_).conf1).projectPath, 47);
		}
		LA42_: ;
	}
	LA5_: ;
	{
		NIM_BOOL T70_;
		tyTuple__UV3llMMYFckfui8YMBuUZA T73_;
		T70_ = (NIM_BOOL)0;
		T70_ = nosisAbsolute(result);
		if (!T70_) goto LA71_;
		nimZeroMem((void*)(&T73_), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
		nossplitPath(file, (&T73_));
		result = copyString(T73_.Field1);
	}
	LA71_: ;
	result = nsuReplaceStr(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_57), ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_58));
	{
		NIM_BOOL T76_;
		T76_ = (NIM_BOOL)0;
		T76_ = isEmpty__options_4084(result);
		if (!!(!(T76_))) goto LA77_;
		failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_59));
	}
	LA77_: ;
	{
		NIM_BOOL T81_;
		T81_ = (NIM_BOOL)0;
		T81_ = nosisAbsolute(result);
		if (!!(!(T81_))) goto LA82_;
		failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_60));
	}
	LA82_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg*, newDocumentor__docgen_356)(NimStringDesc* filename, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* outExt, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, NIM_BOOL isPureRst) {
	tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* result;
	tyObject_Env_docgendotnim_newDocumentor___l319aWpTxh3BHYVEmIhN02w* colonenv_;
	NimStringDesc* T1_;
	tySet_tyEnum_RstParseOption__utHUlNkCVsWnNFCaZUhT7g options;
	tyProc__oFHfEKFsiYTMAy9a42cSiKw T6_;
	tyProc__gd6fvPtd9aVRsRjs9bLyzE9bQ T7_;
	tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ T8_;
	tyProc__oFHfEKFsiYTMAy9a42cSiKw T15_;
	tyProc__gd6fvPtd9aVRsRjs9bLyzE9bQ T16_;
	tyObject_RstFileTable__JJYG5kijP4PSa5F9a7da5tw T17_;
	tyProc__bvoZymnzBMzGoI59bjcrthA T40_;
	NimStringDesc* T41_;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T42_;
	NimStringDesc* T43_;
	result = NIM_NIL;
	colonenv_ = NIM_NIL;
	colonenv_ = (tyObject_Env_docgendotnim_newDocumentor___l319aWpTxh3BHYVEmIhN02w*) newObj((&NTIrefobject__QkCnC3fwblDHMj9b4OGf6Nw_), sizeof(tyObject_Env_docgendotnim_newDocumentor___l319aWpTxh3BHYVEmIhN02w));
	(*colonenv_).Sup.m_type = (&NTIobject__l319aWpTxh3BHYVEmIhN02w_);
	asgnRef((void**) (&(*colonenv_).conf1), conf);
	result = (tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg*) newObj((&NTIpdoc__DVY9cSsFXOXsfAd5wCWVrTg_), sizeof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg));
	(*result).Sup.Sup.m_type = (&NTItdocumentor__bjDxkrkDk9c19abCetktG5Qg_);
	asgnRef((void**) (&(*result).module), module);
	asgnRef((void**) (&(*result).conf), (*colonenv_).conf1);
	asgnRef((void**) (&(*result).cache), cache);
	T1_ = NIM_NIL;
	T1_ = (*result).Sup.outDir; (*result).Sup.outDir = copyStringRC1((*(*colonenv_).conf1).outDir);
	if (T1_) nimGCunrefNoCycle(T1_);
	(*result).isPureRst = isPureRst;
	options = 46;
	{
		if (!!(isPureRst)) goto LA4_;
		options |= ((NU8)1)<<((((tyEnum_RstParseOption__utHUlNkCVsWnNFCaZUhT7g) 4)) & 7);
	}
	LA4_: ;
	nimZeroMem((void*)(&T6_), sizeof(tyProc__oFHfEKFsiYTMAy9a42cSiKw));
	T6_.ClP_0 = docgenFindFile__docgen_378; T6_.ClE_0 = colonenv_;
	nimZeroMem((void*)(&T7_), sizeof(tyProc__gd6fvPtd9aVRsRjs9bLyzE9bQ));
	T7_.ClP_0 = compilerMsgHandler__docgen_371; T7_.ClE_0 = colonenv_;
	asgnRef((void**) (&(*result).sharedState), newRstSharedState__packagesZdocutilsZrst_2004(options, filename, T6_, T7_));
	T8_ = (tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ)0;
	{
		NIM_BOOL T11_;
		T11_ = (NIM_BOOL)0;
		T11_ = isLatexCmd__docgen_349((*colonenv_).conf1);
		if (!T11_) goto LA12_;
		T8_ = ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 1);
	}
	goto LA9_;
	LA12_: ;
	{
		T8_ = ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 0);
	}
	LA9_: ;
	nimZeroMem((void*)(&T15_), sizeof(tyProc__oFHfEKFsiYTMAy9a42cSiKw));
	T15_.ClP_0 = docgenFindFile__docgen_378; T15_.ClE_0 = colonenv_;
	nimZeroMem((void*)(&T16_), sizeof(tyProc__gd6fvPtd9aVRsRjs9bLyzE9bQ));
	T16_.ClP_0 = compilerMsgHandler__docgen_371; T16_.ClE_0 = colonenv_;
	nimZeroMem((void*)(&T17_), sizeof(tyObject_RstFileTable__JJYG5kijP4PSa5F9a7da5tw));
	initRstGenerator__packagesZdocutilsZrstgen_90(&result->Sup, T8_, (*(*colonenv_).conf1).configVars, filename, T15_, T16_, T17_);
	{
		NIM_BOOL T20_;
		T20_ = (NIM_BOOL)0;
		T20_ = nsthasKey((*(*colonenv_).conf1).configVars, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_15));
		if (!(T20_)) goto LA21_;
		T20_ = nsthasKey((*(*colonenv_).conf1).configVars, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_16));
		LA21_: ;
		if (!T20_) goto LA22_;
		{
			if (!NIM_TRUE) goto LA26_;
			failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_17));
		}
		LA26_: ;
	}
	LA22_: ;
	{
		NIM_BOOL T30_;
		tyArray__nHXaesL0DJZHyVS07ARPRA T33_;
		T30_ = (NIM_BOOL)0;
		T30_ = nsthasKey((*(*colonenv_).conf1).configVars, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_15));
		if (!T30_) goto LA31_;
		nimZeroMem((void*)T33_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
		T33_[0] = getOrDefault__pureZstrtabs_173((*(*colonenv_).conf1).configVars, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_19), ((NimStringDesc*) NIM_NIL));
		asgnRef((void**) (&(*result).analytics), nsuFormatOpenArray(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_18), T33_, 1));
	}
	goto LA28_;
	LA31_: ;
	{
		NIM_BOOL T35_;
		tyArray__nHXaesL0DJZHyVS07ARPRA T38_;
		T35_ = (NIM_BOOL)0;
		T35_ = nsthasKey((*(*colonenv_).conf1).configVars, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_16));
		if (!T35_) goto LA36_;
		nimZeroMem((void*)T38_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
		T38_[0] = getOrDefault__pureZstrtabs_173((*(*colonenv_).conf1).configVars, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_21), ((NimStringDesc*) NIM_NIL));
		asgnRef((void**) (&(*result).analytics), nsuFormatOpenArray(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_20), T38_, 1));
	}
	goto LA28_;
	LA36_: ;
	{
		asgnRef((void**) (&(*result).analytics), ((NimStringDesc*) NIM_NIL));
	}
	LA28_: ;
	asgnRef((void**) (&(*result).seenSymbols), nstnewStringTable(((tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA) 1)));
	(*result).Sup.id = ((NI) 100);
	asgnRef((void**) (&(*result).jEntriesFinal), newJArray__pureZjson_133());
	initStrTable__ast_4076((&(*result).types));
	nimZeroMem((void*)(&T40_), sizeof(tyProc__bvoZymnzBMzGoI59bjcrthA));
	T40_.ClP_0 = colonanonymous___docgen_394; T40_.ClE_0 = colonenv_;
	asgnRef((void**) (&(*result).Sup.onTestSnippet.ClE_0), T40_.ClE_0);
	(*result).Sup.onTestSnippet.ClP_0 = T40_.ClP_0;
	initIntSet__pureZcollectionsZintsets_238((&(*result).emitted));
	T41_ = NIM_NIL;
	T41_ = presentationPath__docgen_197((*colonenv_).conf1, filename);
	asgnRef((void**) (&(*result).Sup.destFile), getOutFile2__docgen_335((*colonenv_).conf1, T41_, outExt, NIM_FALSE));
	nimZeroMem((void*)(&T42_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	splitFile__pathutils_27((*result).Sup.destFile, (&T42_));
	T43_ = NIM_NIL;
	T43_ = (*result).thisDir; (*result).thisDir = copyStringRC1(T42_.Field0);
	if (T43_) nimGCunrefNoCycle(T43_);
	return result;
}
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__ast_3155(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, genDeprecationMsg__docgen_3401)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NimStringDesc* result;
	NI T5_;
{	result = NIM_NIL;
	{
		if (!(n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	T5_ = (NI)0;
	T5_ = safeLen__ast_3148(n);
	switch (T5_) {
	case ((NI) 0):
	{
		NimStringDesc* T7_;
		T7_ = NIM_NIL;
		T7_ = getConfigVar__options_4054((*d).conf, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_62), ((NimStringDesc*) NIM_NIL));
		result = nsuFormatOpenArray(T7_, TM__iS6Vfak4fKt7fhPmyApRcg_63, 4);
	}
	break;
	case ((NI) 2):
	{
		{
			NimStringDesc* T13_;
			tyArray__sMpvt1sOxOJ3LFGulnbeMQ T14_;
			if (!((*(*n)._kind_6.sons->data[((NI) 1)]).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) && (*(*n)._kind_6.sons->data[((NI) 1)]).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22))) goto LA11_;
			T13_ = NIM_NIL;
			T13_ = getConfigVar__options_4054((*d).conf, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_62), ((NimStringDesc*) NIM_NIL));
			nimZeroMem((void*)T14_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
			T14_[0] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_64));
			T14_[1] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_67));
			T14_[2] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_66));
			T14_[3] = escape__pureZxmltree_479((*(*n)._kind_6.sons->data[((NI) 1)])._kind_3.strVal);
			result = nsuFormatOpenArray(T13_, T14_, 4);
		}
		LA11_: ;
	}
	break;
	default:
	{
		{
			if (!NIM_TRUE) goto LA18_;
			failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_68));
		}
		LA18_: ;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__docgen_107)(tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q** dest, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* rst) {
	tyObject_ItemFragment__s61pcFD9bQO8uWIzfNjndzg T1_;
	NI T2_;
	nimZeroMem((void*)(&T1_), sizeof(tyObject_ItemFragment__s61pcFD9bQO8uWIzfNjndzg));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_ItemFragment__s61pcFD9bQO8uWIzfNjndzg));
	T1_.isRst = NIM_TRUE;
	T1_._isRst_1.rst = rst;
	unsureAsgnRef((void**) (&(*dest)), (tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q*) incrSeqV3((TGenericSeq*)((*dest)), (&NTIitempre__JSDKkkE7gMRTYRB9bRZ9bH7Q_)));
	T2_ = (*dest)->Sup.len++;
	genericAssign((void*)(&(*dest)->data[T2_]), (void*)(&T1_), (&NTIitemfragment__s61pcFD9bQO8uWIzfNjndzg_));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ*, parseRst__docgen_310)(NimStringDesc* text, NimStringDesc* filename, NI line, NI column, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_RstSharedState__RaVISFn5lBYmQPVCuG88JA* sharedState) {
	tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* result;
	result = NIM_NIL;
	result = rstParsePass1__packagesZdocutilsZrst_6811(text, line, column, sharedState);
	return result;
}
static N_INLINE(NI, toLinenumber__msgs_619)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NI result;
	result = (NI)0;
	result = ((NI) (info.line));
	return result;
}
static N_INLINE(NI, toColumn__msgs_622)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NI result;
	result = (NI)0;
	result = ((NI) (info.col));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ*, genComment__docgen_508)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* result;
	result = NIM_NIL;
	{
		NimStringDesc* T3_;
		NimStringDesc* T6_;
		NimStringDesc* T7_;
		NI T8_;
		NI T9_;
		T3_ = NIM_NIL;
		T3_ = comment__ast_997(n);
		if (!(((NI) 0) < (T3_ ? T3_->Sup.len : 0))) goto LA4_;
		T6_ = NIM_NIL;
		T6_ = comment__ast_997(n);
		T7_ = NIM_NIL;
		T7_ = toFullPath__msgs_548((*d).conf, (*n).info.fileIndex);
		T8_ = (NI)0;
		T8_ = toLinenumber__msgs_619((*n).info);
		T9_ = (NI)0;
		T9_ = toColumn__msgs_622((*n).info);
		result = parseRst__docgen_310(T6_, T7_, T8_, (NI)(T9_ + ((NI) 3)), (*d).conf, (*d).sharedState);
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, documentEffect__docgen_5195)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x, tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw effectType, NI idx) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* spec;
{	result = NIM_NIL;
	spec = effectSpec__trees_284(x, effectType);
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* actual;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* real;
		NI realLen;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* effects;
		tyArray__Nfk9cOEzg2bRz9c1V8fGzONg T23_;
		tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T24_;
		if (!(spec == 0)) goto LA3_;
		s = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		actual = (*(*(*s).typ).n)._kind_6.sons->data[((NI) 0)];
		{
			NI T7_;
			T7_ = (NI)0;
			T7_ = len__ast_3155(actual);
			if (!!((T7_ == ((NI) 5)))) goto LA8_;
			goto BeforeRet_;
		}
		LA8_: ;
		real = (*actual)._kind_6.sons->data[idx];
		{
			if (!(real == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA12_;
			goto BeforeRet_;
		}
		LA12_: ;
		realLen = len__ast_3155(real);
		effects = newNodeI__ast_3324(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41), (*n).info, realLen);
		{
			NI i;
			NI i_2;
			i = (NI)0;
			i_2 = ((NI) 0);
			{
				while (1) {
					NimStringDesc* t;
					tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T22_;
					if (!(i_2 < realLen)) goto LA16;
					i = i_2;
					t = typeToString__types_50((*(*real)._kind_6.sons->data[i]).typ, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
					{
						NIM_BOOL T19_;
						T19_ = (NIM_BOOL)0;
						T19_ = nsuStartsWith(t, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_69));
						if (!T19_) goto LA20_;
						t = substr__system_7736(t, ((NI) 4));
					}
					LA20_: ;
					T22_ = NIM_NIL;
					T22_ = getIdent__idents_152(cache, t);
					asgnRef((void**) (&(*effects)._kind_6.sons->data[i]), newIdentNode__ast_3700(T22_, (*n).info));
					asgnRef((void**) (&(*(*effects)._kind_6.sons->data[i]).typ), (*(*real)._kind_6.sons->data[i]).typ);
					i_2 += ((NI) 1);
				} LA16: ;
			}
		}
		nimZeroMem((void*)T23_, sizeof(tyArray__Nfk9cOEzg2bRz9c1V8fGzONg));
		T24_ = NIM_NIL;
		T24_ = getIdent__idents_152(cache, reprEnum((NI)effectType, (&NTItspecialword__N2XsqTpO5IzOf2KmXwk4Dw_)));
		T23_[0] = newIdentNode__ast_3700(T24_, (*n).info);
		T23_[1] = effects;
		result = newTreeI__ast_3384(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34), (*n).info, T23_, 2);
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, documentWriteEffect__docgen_5237)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flag, NimStringDesc* pragmaName) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* params;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* effects;
	result = NIM_NIL;
	s = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
	params = (*(*s).typ).n;
	effects = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41), (*n).info);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(params);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					NIM_BOOL T6_;
					T6_ = (NIM_BOOL)0;
					T6_ = ((*(*params)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
					if (!(T6_)) goto LA7_;
					T6_ = (((*(*(*params)._kind_6.sons->data[i])._kind_4.sym).flags &((NU64)1<<((NU)(flag)&63U)))!=0);
					LA7_: ;
					if (!T6_) goto LA8_;
					add__ast_4798(effects, (*params)._kind_6.sons->data[i]);
				}
				LA8_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	{
		NI T12_;
		tyArray__Nfk9cOEzg2bRz9c1V8fGzONg T15_;
		tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T16_;
		T12_ = (NI)0;
		T12_ = len__ast_3155(effects);
		if (!(((NI) 0) < T12_)) goto LA13_;
		nimZeroMem((void*)T15_, sizeof(tyArray__Nfk9cOEzg2bRz9c1V8fGzONg));
		T16_ = NIM_NIL;
		T16_ = getIdent__idents_152(cache, pragmaName);
		T15_[0] = newIdentNode__ast_3700(T16_, (*n).info);
		T15_[1] = effects;
		result = newTreeI__ast_3384(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34), (*n).info, T15_, 2);
	}
	LA13_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, documentNewEffect__docgen_5185)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
	result = NIM_NIL;
	s = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
	{
		tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T5_;
		if (!(((*(*s).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 3))&63U)))!=0)) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = getIdent__idents_152(cache, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_71));
		result = newIdentNode__ast_3700(T5_, (*n).info);
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, documentRaises__docgen_5273)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pragmas;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p1;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p2;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p3;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p4;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p5;
{	{
		if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	pragmas = (*n)._kind_6.sons->data[((NI) 4)];
	p1 = documentEffect__docgen_5195(cache, n, pragmas, ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 174), ((NI) 0));
	p2 = documentEffect__docgen_5195(cache, n, pragmas, ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 179), ((NI) 3));
	p3 = documentWriteEffect__docgen_5237(cache, n, ((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 31), ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_70));
	p4 = documentNewEffect__docgen_5185(cache, n);
	p5 = documentWriteEffect__docgen_5237(cache, n, ((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 19), ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_72));
	{
		NIM_BOOL T7_;
		NIM_BOOL T8_;
		NIM_BOOL T9_;
		NIM_BOOL T10_;
		T7_ = (NIM_BOOL)0;
		T8_ = (NIM_BOOL)0;
		T9_ = (NIM_BOOL)0;
		T10_ = (NIM_BOOL)0;
		T10_ = !((p1 == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
		if (T10_) goto LA11_;
		T10_ = !((p2 == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
		LA11_: ;
		T9_ = T10_;
		if (T9_) goto LA12_;
		T9_ = !((p3 == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
		LA12_: ;
		T8_ = T9_;
		if (T8_) goto LA13_;
		T8_ = !((p4 == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
		LA13_: ;
		T7_ = T8_;
		if (T7_) goto LA14_;
		T7_ = !((p5 == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
		LA14_: ;
		if (!T7_) goto LA15_;
		{
			if (!((*pragmas).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1))) goto LA19_;
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 4)]), newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 90), (*n).info));
		}
		LA19_: ;
		{
			if (!!((p1 == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA23_;
			add__ast_4798((*n)._kind_6.sons->data[((NI) 4)], p1);
		}
		LA23_: ;
		{
			if (!!((p2 == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA27_;
			add__ast_4798((*n)._kind_6.sons->data[((NI) 4)], p2);
		}
		LA27_: ;
		{
			if (!!((p3 == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA31_;
			add__ast_4798((*n)._kind_6.sons->data[((NI) 4)], p3);
		}
		LA31_: ;
		{
			if (!!((p4 == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA35_;
			add__ast_4798((*n)._kind_6.sons->data[((NI) 4)], p4);
		}
		LA35_: ;
		{
			if (!!((p5 == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA39_;
			add__ast_4798((*n)._kind_6.sons->data[((NI) 4)], p5);
		}
		LA39_: ;
	}
	LA15_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isVisible__docgen_3258)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = NIM_FALSE;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31))) goto LA3_;
		{
			NIM_BOOL T7_;
			NI T8_;
			tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* v;
			NIM_BOOL T12_;
			T7_ = (NIM_BOOL)0;
			T8_ = (NI)0;
			T8_ = len__ast_3155(n);
			T7_ = (T8_ == ((NI) 2));
			if (!(T7_)) goto LA9_;
			T7_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2));
			LA9_: ;
			if (!T7_) goto LA10_;
			v = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_5.ident;
			T12_ = (NIM_BOOL)0;
			T12_ = ((*v).id == ((NI) 72));
			if (T12_) goto LA13_;
			T12_ = ((*v).id == ((NI) 73));
			LA13_: ;
			result = T12_;
		}
		LA10_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA15_;
		{
			if (!(((*(*d).conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 34))&63U)))!=0)) goto LA19_;
			result = ((20 & (*(*n)._kind_4.sym).flags) == 0);
		}
		goto LA17_;
		LA19_: ;
		{
			result = ((22 & (*(*n)._kind_4.sym).flags) == 2);
		}
		LA17_: ;
		{
			NIM_BOOL T24_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym164_;
			T24_ = (NIM_BOOL)0;
			T24_ = result;
			if (!(T24_)) goto LA25_;
			xX60gensym164_ = (*n)._kind_4.sym;
			T24_ = containsOrIncl__astalgo_402((&(*d).emitted), (NI)((NI)((NU32)(((NI) ((*xX60gensym164_).Sup.itemId.module))) << (NU32)(((NI) 20))) + ((NI) ((*xX60gensym164_).Sup.itemId.item))));
			LA25_: ;
			if (!T24_) goto LA26_;
			result = NIM_FALSE;
		}
		LA26_: ;
	}
	goto LA1_;
	LA15_: ;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 43))) goto LA29_;
		result = isVisible__docgen_3258(d, (*n)._kind_6.sons->data[((NI) 0)]);
	}
	goto LA1_;
	LA29_: ;
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getName__docgen_3321)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI splitAfter) {
	NimStringDesc* result;
	result = NIM_NIL;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31):
	{
		result = getName__docgen_3321(d, (*n)._kind_6.sons->data[((NI) 1)], splitAfter);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 43):
	{
		result = getName__docgen_3321(d, (*n)._kind_6.sons->data[((NI) 0)], splitAfter);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		NimStringDesc* T4_;
		T4_ = NIM_NIL;
		T4_ = renderDefinitionName__renderer_88((*n)._kind_4.sym, NIM_FALSE);
		result = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, T4_, splitAfter, ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	{
		result = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, (*(*n)._kind_5.ident).s, splitAfter, ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 53):
	{
		NimStringDesc* T11_;
		result = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_73), ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					NimStringDesc* T10_;
					if (!(i_2 < colontmp_)) goto LA9;
					i = i_2;
					T10_ = NIM_NIL;
					T10_ = getName__docgen_3321(d, (*n)._kind_6.sons->data[i], splitAfter);
					result = resizeString(result, (T10_ ? T10_->Sup.len : 0) + 0);
appendString(result, T10_);
					i_2 += ((NI) 1);
				} LA9: ;
			}
		}
		T11_ = NIM_NIL;
		T11_ = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_73), ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
		result = resizeString(result, (T11_ ? T11_->Sup.len : 0) + 0);
appendString(result, T11_);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 57):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 56):
	{
		result = getName__docgen_3321(d, (*n)._kind_6.sons->data[((NI) 0)], splitAfter);
	}
	break;
	default:
	{
		result = ((NimStringDesc*) NIM_NIL);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getPlainDocstring__docgen_558)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NimStringDesc* result;
{	result = NIM_NIL;
	{
		if (!(n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA3_;
		result = ((NimStringDesc*) NIM_NIL);
	}
	goto LA1_;
	LA3_: ;
	{
		NimStringDesc* T6_;
		NIM_BOOL T7_;
		T6_ = NIM_NIL;
		T6_ = comment__ast_997(n);
		T7_ = (NIM_BOOL)0;
		T7_ = nsuStartsWith(T6_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_74));
		if (!T7_) goto LA8_;
		result = comment__ast_997(n);
	}
	goto LA1_;
	LA8_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA13;
					i = i_2;
					result = getPlainDocstring__docgen_558((*n)._kind_6.sons->data[i]);
					{
						if (!(((NI) 0) < (result ? result->Sup.len : 0))) goto LA16_;
						goto BeforeRet_;
					}
					LA16_: ;
					i_2 += ((NI) 1);
				} LA13: ;
			}
		}
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, getRoutineBody__docgen_3208)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = (*n)._kind_6.sons->data[((NI) 6)];
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		NI T8_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T5_ = ((*result).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 73));
		if (!(T5_)) goto LA6_;
		T5_ = ((*(*result)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		LA6_: ;
		T4_ = T5_;
		if (!(T4_)) goto LA7_;
		T8_ = (NI)0;
		T8_ = len__ast_3155(n);
		T4_ = (((NI) 7) < T8_);
		LA7_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA9_;
		T3_ = ((*(*n)._kind_6.sons->data[((NI) 7)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		LA9_: ;
		if (!T3_) goto LA10_;
		{
			NI T14_;
			T14_ = (NI)0;
			T14_ = len__ast_3155(result);
			if (!!((T14_ == ((NI) 2)))) goto LA15_;
			failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_75));
		}
		LA15_: ;
		result = (*result)._kind_6.sons->data[((NI) 1)];
	}
	LA10_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ*, genRecCommentAux__docgen_512)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* result;
{	result = NIM_NIL;
	{
		if (!(n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA3_;
		result = ((tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ*) NIM_NIL);
		goto BeforeRet_;
	}
	LA3_: ;
	result = genComment__docgen_508(d, n);
	{
		if (!(result == ((tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ*) NIM_NIL))) goto LA7_;
		{
			if (!((TM__iS6Vfak4fKt7fhPmyApRcg_76[(NU)((*n).kind)>>3] &(1U<<((NU)((*n).kind)&7U)))!=0)) goto LA11_;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_3155(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA15;
						i = i_2;
						result = genRecCommentAux__docgen_512(d, (*n)._kind_6.sons->data[i]);
						{
							if (!!((result == ((tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ*) NIM_NIL)))) goto LA18_;
							goto BeforeRet_;
						}
						LA18_: ;
						i_2 += ((NI) 1);
					} LA15: ;
				}
			}
		}
		LA11_: ;
	}
	goto LA5_;
	LA7_: ;
	{
		commenteq___ast_1365(n, ((NimStringDesc*) NIM_NIL));
	}
	LA5_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ*, genRecComment__docgen_541)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* result;
{	result = NIM_NIL;
	{
		if (!(n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA3_;
		result = ((tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ*) NIM_NIL);
		goto BeforeRet_;
	}
	LA3_: ;
	result = genComment__docgen_508(d, n);
	{
		if (!(result == ((tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ*) NIM_NIL))) goto LA7_;
		{
			if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 80) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 82) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 83) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 81))) goto LA11_;
			result = genRecCommentAux__docgen_512(d, (*n)._kind_6.sons->data[((NI) 6)]);
		}
		goto LA9_;
		LA11_: ;
		{
			result = genRecCommentAux__docgen_512(d, n);
		}
		LA9_: ;
	}
	LA7_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x) {
	addInt__stdZprivateZdigitsutils_167(result, ((NI64) (x)));
}
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_629)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = toMsgFilename__msgs_612(conf, info.fileIndex);
	result = resizeString(result, (T1_ ? T1_->Sup.len : 0) + 0);
appendString(result, T1_);
	{
		if (!(((NI) 0) < ((NI) (info.line)))) goto LA4_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_81));
		addInt__stdZprivateZdigitsutils_189((&result), ((NI) (info.line)));
		{
			if (!(((NI) 0) < (NI)(((NI) (info.col)) + ((NI) 1)))) goto LA8_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_82));
			addInt__stdZprivateZdigitsutils_189((&result), (NI)(((NI) (info.col)) + ((NI) 1)));
		}
		LA8_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_83));
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, exampleOutputDir__docgen_639)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = getNimcacheDir__options_4185((*d).conf);
	result = slash___pathutils_112(T1_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_85));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, toInstantiationInfo__docgen_1023)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyTuple__kN8up2W6YKc5YA9avn5mV5w* Result) {
	NimStringDesc* colontmp_;
	NI colontmp__2;
	NI colontmp__3;
	colontmp_ = toMsgFilename__msgs_612(conf, info.fileIndex);
	colontmp__2 = ((NI) (info.line));
	colontmp__3 = (NI)(((NI) (info.col)) + ((NI) 1));
	unsureAsgnRef((void**) (&(*Result).Field0), copyString(colontmp_));
	(*Result).Field1 = colontmp__2;
	(*Result).Field2 = colontmp__3;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, quoted__docgen_1016)(NimStringDesc* a) {
	NimStringDesc* result;
	result = NIM_NIL;
	addQuoted__pureZos_449((&result), a);
	return result;
}
static N_INLINE(NI, len__docgen_693)(tyObject_OrderedTable__uUf2ABI4SLuvVLy2s8ygdw t) {
	NI result;
	result = (NI)0;
	result = t.counter;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, prepareExample__docgen_1027)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL topLevel, tyTuple__UV3llMMYFckfui8YMBuUZA* Result) {
	NimStringDesc* rdoccmd;
	NIM_BOOL useRenderModule;
	NimStringDesc* loc;
	NimStringDesc* code;
	NimStringDesc* codeIndent;
	NimStringDesc* comment;
	tyArray__Re75IspeoxXy2oCZHwcRrA T22_;
	NimStringDesc* outputDir;
	NimStringDesc* outp;
	tyArray__Re75IspeoxXy2oCZHwcRrA T23_;
	NimStringDesc* T24_;
	NimStringDesc* T25_;
	tyObject_ExampleGroupcolonObjectType___bbSjO9aaIauVHOujtpjo3Rw** T56_;
	NimStringDesc* T57_;
	NimStringDesc* T58_;
	NimStringDesc* codeShown;
	NimStringDesc* colontmp__5;
	NimStringDesc* colontmp__6;
{	rdoccmd = ((NimStringDesc*) NIM_NIL);
	{
		NIM_BOOL T3_;
		NI T4_;
		NI T6_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NI)0;
		T4_ = len__ast_3155(n);
		T3_ = (T4_ < ((NI) 2));
		if (T3_) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__ast_3155(n);
		T3_ = (((NI) 3) < T6_);
		LA5_: ;
		if (!T3_) goto LA7_;
		liMessage__msgs_1128((*d).conf, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_77), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 2), TM__iS6Vfak4fKt7fhPmyApRcg_78, NIM_FALSE);
	}
	LA7_: ;
	{
		NI T11_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n1;
		T11_ = (NI)0;
		T11_ = len__ast_3155(n);
		if (!(T11_ == ((NI) 3))) goto LA12_;
		n1 = (*n)._kind_6.sons->data[((NI) 1)];
		{
			if (!!(((*n1).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) && (*n1).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22)))) goto LA16_;
			liMessage__msgs_1128((*d).conf, (*n1).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_79), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 2), TM__iS6Vfak4fKt7fhPmyApRcg_80, NIM_FALSE);
		}
		LA16_: ;
		rdoccmd = copyString((*n1)._kind_3.strVal);
	}
	LA12_: ;
	useRenderModule = NIM_FALSE;
	loc = toFileLineCol__msgs_629((*d).conf, (*n).info);
	code = extractRunnableExamplesSource__renderverbatim_97((*d).conf, n, ((NI) 0));
	codeIndent = extractRunnableExamplesSource__renderverbatim_97((*d).conf, n, ((NI) 2));
	{
		NimStringDesc* colontmp_;
		NimStringDesc* colontmp__2;
		if (!(((NI) 0) < (*(*d).conf).errorCounter)) goto LA20_;
		colontmp_ = copyString(rdoccmd);
		colontmp__2 = copyString(code);
		unsureAsgnRef((void**) (&(*Result).Field0), copyString(colontmp_));
		unsureAsgnRef((void**) (&(*Result).Field1), copyString(colontmp__2));
		goto BeforeRet_;
	}
	LA20_: ;
	nimZeroMem((void*)T22_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
	T22_[0] = copyString(loc);
	T22_[1] = copyString(rdoccmd);
	comment = nsuFormatOpenArray(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_84), T22_, 2);
	outputDir = exampleOutputDir__docgen_639(d);
	noscreateDir(outputDir);
	(*d).exampleCounter += ((NI) 1);
	nimZeroMem((void*)T23_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
	T24_ = NIM_NIL;
	T24_ = nosextractFilename((*d).Sup.filename);
	T23_[0] = noschangeFileExt(T24_, ((NimStringDesc*) NIM_NIL));
	T23_[1] = dollar___systemZdollars_3((*d).exampleCounter);
	T25_ = NIM_NIL;
	T25_ = nsuFormatOpenArray(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_86), T23_, 2);
	outp = slash___pathutils_90(outputDir, T25_);
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* docComment;
		tyArray__DkuVegaMCU6g1mpIOSQPIw T30_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* runnableExamples;
		tyArray__Nfk9cOEzg2bRz9c1V8fGzONg T31_;
		tyArray__iegsN9bf6GqRiWprrJjTAoA T32_;
		if (!useRenderModule) goto LA28_;
		nimZeroMem((void*)T30_, sizeof(tyArray__DkuVegaMCU6g1mpIOSQPIw));
		docComment = newTree__ast_3356(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 125), T30_, 0);
		commenteq___ast_1365(docComment, comment);
		nimZeroMem((void*)T31_, sizeof(tyArray__Nfk9cOEzg2bRz9c1V8fGzONg));
		T31_[0] = docComment;
		nimZeroMem((void*)T32_, sizeof(tyArray__iegsN9bf6GqRiWprrJjTAoA));
		T32_[0] = newStrNode__ast_3801(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20), (*d).Sup.filename);
		T31_[1] = newTree__ast_3356(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 116), T32_, 1);
		runnableExamples = newTree__ast_3356(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115), T31_, 2);
		(*runnableExamples).info = (*n).info;
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* colontmp__3;
			a = NIM_NIL;
			colontmp__3 = NIM_NIL;
			colontmp__3 = lastSon__ast_4833(n);
			{
				NI i;
				NI colontmp__4;
				NI i_2;
				i = (NI)0;
				colontmp__4 = (NI)0;
				colontmp__4 = safeLen__ast_3148(colontmp__3);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp__4)) goto LA36;
						i = i_2;
						a = (*colontmp__3)._kind_6.sons->data[i];
						add__ast_4798(runnableExamples, a);
						i_2 += ((NI) 1);
					} LA36: ;
				}
			}
		}
		renderModule__renderer_2119(runnableExamples, outp, 0, ((NI32) -1), (*d).conf);
	}
	goto LA26_;
	LA28_: ;
	{
		NimStringDesc* code2;
		tyArray__24KAM9afIUgUaqBaEBB6r9bg T47_;
		code2 = copyString(code);
		{
			NIM_BOOL T40_;
			NIM_BOOL T42_;
			tyArray__Re75IspeoxXy2oCZHwcRrA T45_;
			tyTuple__kN8up2W6YKc5YA9avn5mV5w T46_;
			T40_ = (NIM_BOOL)0;
			T40_ = (((NI) 0) < (code ? code->Sup.len : 0));
			if (!(T40_)) goto LA41_;
			T42_ = (NIM_BOOL)0;
			T42_ = contains__pureZstrutils_1627(code, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_87));
			T40_ = !(T42_);
			LA41_: ;
			if (!T40_) goto LA43_;
			nimZeroMem((void*)T45_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			nimZeroMem((void*)(&T46_), sizeof(tyTuple__kN8up2W6YKc5YA9avn5mV5w));
			toInstantiationInfo__docgen_1023((*d).conf, (*n).info, (&T46_));
			T45_[0] = dollar___docgen_1072(T46_);
			T45_[1] = copyString(codeIndent);
			code2 = nsuFormatOpenArray(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_88), T45_, 2);
		}
		LA43_: ;
		nimZeroMem((void*)T47_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
		T47_[0] = copyString(comment);
		T47_[1] = quoted__docgen_1016((*d).Sup.filename);
		T47_[2] = copyString(code2);
		code2 = nsuFormatOpenArray(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_89), T47_, 3);
		writeFile__systemZio_474(outp, code2);
	}
	LA26_: ;
	{
		NIM_BOOL T50_;
		tyObject_ExampleGroupcolonObjectType___bbSjO9aaIauVHOujtpjo3Rw* T53_;
		NimStringDesc* T54_;
		NimStringDesc* T55_;
		T50_ = (NIM_BOOL)0;
		T50_ = contains__docgen_1160((*d).exampleGroups, rdoccmd);
		if (!!(T50_)) goto LA51_;
		T53_ = NIM_NIL;
		T53_ = (tyObject_ExampleGroupcolonObjectType___bbSjO9aaIauVHOujtpjo3Rw*) newObj((&NTIexamplegroup__Z4Ed9aRleAg258AnxIUkcCQ_), sizeof(tyObject_ExampleGroupcolonObjectType___bbSjO9aaIauVHOujtpjo3Rw));
		T54_ = NIM_NIL;
		T54_ = (*T53_).rdoccmd; (*T53_).rdoccmd = copyStringRC1(rdoccmd);
		if (T54_) nimGCunrefNoCycle(T54_);
		T55_ = NIM_NIL;
		T55_ = (*T53_).docCmd; (*T53_).docCmd = copyStringRC1((*(*d).conf).docCmd);
		if (T55_) nimGCunrefNoCycle(T55_);
		(*T53_).index = len__docgen_693((*d).exampleGroups);
		X5BX5Deq___docgen_1518((&(*d).exampleGroups), rdoccmd, T53_);
	}
	LA51_: ;
	T56_ = (tyObject_ExampleGroupcolonObjectType___bbSjO9aaIauVHOujtpjo3Rw**)0;
	T56_ = X5BX5D___docgen_2850((&(*d).exampleGroups), rdoccmd);
	T57_ = NIM_NIL;
	T57_ = quoted__docgen_1016(outp);
	T58_ = NIM_NIL;
	T58_ = nsuFormatSingleElem(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_90), T57_);
	asgnRef((void**) (&(*(*T56_)).code), resizeString((*(*T56_)).code, (T58_ ? T58_->Sup.len : 0) + 0));
appendString((*(*T56_)).code, T58_);
	codeShown = NIM_NIL;
	{
		NimStringDesc* title;
		tyArray__Re75IspeoxXy2oCZHwcRrA T63_;
		if (!topLevel) goto LA61_;
		title = canonicalImport__options_4661((*d).conf, (*d).Sup.filename);
		nimZeroMem((void*)T63_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
		T63_[0] = copyString(title);
		T63_[1] = copyString(code);
		codeShown = nsuFormatOpenArray(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_91), T63_, 2);
	}
	goto LA59_;
	LA61_: ;
	{
		codeShown = copyString(code);
	}
	LA59_: ;
	colontmp__5 = copyString(rdoccmd);
	colontmp__6 = copyString(codeShown);
	unsureAsgnRef((void**) (&(*Result).Field0), copyString(colontmp__5));
	unsureAsgnRef((void**) (&(*Result).Field1), copyString(colontmp__6));
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, add__docgen_129)(tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q** dest, NimStringDesc* str) {
	tyObject_ItemFragment__s61pcFD9bQO8uWIzfNjndzg T1_;
	NI T2_;
	nimZeroMem((void*)(&T1_), sizeof(tyObject_ItemFragment__s61pcFD9bQO8uWIzfNjndzg));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_ItemFragment__s61pcFD9bQO8uWIzfNjndzg));
	T1_.isRst = NIM_FALSE;
	T1_._isRst_2.str = copyString(str);
	unsureAsgnRef((void**) (&(*dest)), (tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q*) incrSeqV3((TGenericSeq*)((*dest)), (&NTIitempre__JSDKkkE7gMRTYRB9bRZ9bH7Q_)));
	T2_ = (*dest)->Sup.len++;
	genericAssign((void*)(&(*dest)->data[T2_]), (void*)(&T1_), (&NTIitemfragment__s61pcFD9bQO8uWIzfNjndzg_));
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_RunnableState__9b58EmEbGuos3KaMZ9cEC1OA, getAllRunnableExamplesImpl__docgen_3162)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q** dest, tyEnum_RunnableState__9b58EmEbGuos3KaMZ9cEC1OA state, NIM_BOOL topLevel) {
	tyEnum_RunnableState__9b58EmEbGuos3KaMZ9cEC1OA result;
{	result = (tyEnum_RunnableState__9b58EmEbGuos3KaMZ9cEC1OA)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 125):
	{
		{
			tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* T6_;
			if (!((5 &((NU8)1<<((NU)(state)&7U)))!=0)) goto LA4_;
			T6_ = NIM_NIL;
			T6_ = genRecComment__docgen_541(d, n);
			add__docgen_107(dest, T6_);
			result = ((tyEnum_RunnableState__9b58EmEbGuos3KaMZ9cEC1OA) 1);
			goto BeforeRet_;
		}
		LA4_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
	{
		{
			NIM_BOOL T10_;
			NIM_BOOL T11_;
			NI T13_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T15_;
			T10_ = (NIM_BOOL)0;
			T11_ = (NIM_BOOL)0;
			T11_ = isRunnableExamples__ast_4699((*n)._kind_6.sons->data[((NI) 0)]);
			if (!(T11_)) goto LA12_;
			T13_ = (NI)0;
			T13_ = len__ast_3155(n);
			T11_ = (((NI) 2) <= T13_);
			LA12_: ;
			T10_ = T11_;
			if (!(T10_)) goto LA14_;
			T15_ = NIM_NIL;
			T15_ = lastSon__ast_4833(n);
			T10_ = ((*T15_).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115));
			LA14_: ;
			if (!T10_) goto LA16_;
			{
				tyTuple__UV3llMMYFckfui8YMBuUZA T22_;
				NimStringDesc* rdoccmd;
				NimStringDesc* code;
				NimStringDesc* msg;
				NimStringDesc* s;
				NimStringDesc* id;
				NimStringDesc* T36_;
				tyArray__24KAM9afIUgUaqBaEBB6r9bg T37_;
				NimStringDesc* T38_;
				NimStringDesc* dest2;
				NimStringDesc* T39_;
				NimStringDesc* T40_;
				if (!((7 &((NU8)1<<((NU)(state)&7U)))!=0)) goto LA20_;
				nimZeroMem((void*)(&T22_), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
				prepareExample__docgen_1027(d, n, topLevel, (&T22_));
				rdoccmd = NIM_NIL;
				rdoccmd = T22_.Field0;
				code = NIM_NIL;
				code = T22_.Field1;
				msg = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_92));
				{
					NimStringDesc* T27_;
					if (!(((NI) 0) < (rdoccmd ? rdoccmd->Sup.len : 0))) goto LA25_;
					T27_ = NIM_NIL;
					T27_ = rawNewString((rdoccmd ? rdoccmd->Sup.len : 0) + 6);
appendString(T27_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_93));
appendString(T27_, rdoccmd);
					msg = resizeString(msg, (T27_ ? T27_->Sup.len : 0) + 0);
appendString(msg, T27_);
				}
				LA25_: ;
				s = NIM_NIL;
				{
					NIM_BOOL T30_;
					tyArray__nHXaesL0DJZHyVS07ARPRA T33_;
					T30_ = (NIM_BOOL)0;
					T30_ = isLatexCmd__docgen_349((*d).conf);
					if (!!(T30_)) goto LA31_;
					nimZeroMem((void*)T33_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					T33_[0] = copyString(msg);
					nsuAddf((&s), ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_94), T33_, 1);
				}
				goto LA28_;
				LA31_: ;
				{
					tyArray__nHXaesL0DJZHyVS07ARPRA T35_;
					nimZeroMem((void*)T35_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					T35_[0] = copyString(msg);
					nsuAddf((&s), ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_95), T35_, 1);
				}
				LA28_: ;
				add__docgen_129(dest, s);
				(*d).Sup.listingCounter += ((NI) 1);
				id = dollar___systemZdollars_3((*d).Sup.listingCounter);
				T36_ = NIM_NIL;
				T36_ = getOrDefault__pureZstrtabs_173((*d).Sup.config, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_96), ((NimStringDesc*) NIM_NIL));
				nimZeroMem((void*)T37_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
				T37_[0] = copyString(id);
				T37_[1] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_97));
				T37_[2] = ((NimStringDesc*) NIM_NIL);
				T38_ = NIM_NIL;
				T38_ = nsuFormatOpenArray(T36_, T37_, 3);
				add__docgen_129(dest, T38_);
				dest2 = ((NimStringDesc*) NIM_NIL);
				renderNimCode__packagesZdocutilsZrstgen_8248((&dest2), code, (*d).Sup.target);
				add__docgen_129(dest, dest2);
				T39_ = NIM_NIL;
				T39_ = getOrDefault__pureZstrtabs_173((*d).Sup.config, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_98), ((NimStringDesc*) NIM_NIL));
				T40_ = NIM_NIL;
				T40_ = nsuFormatSingleElem(T39_, id);
				add__docgen_129(dest, T40_);
				result = ((tyEnum_RunnableState__9b58EmEbGuos3KaMZ9cEC1OA) 2);
				goto BeforeRet_;
			}
			goto LA18_;
			LA20_: ;
			{
				liMessage__msgs_1128((*d).conf, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 16), ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_99), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__iS6Vfak4fKt7fhPmyApRcg_100, NIM_FALSE);
			}
			LA18_: ;
		}
		LA16_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	result = ((tyEnum_RunnableState__9b58EmEbGuos3KaMZ9cEC1OA) 3);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, getAllRunnableExamples__docgen_3238)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q** dest) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n_2;
	tyEnum_RunnableState__9b58EmEbGuos3KaMZ9cEC1OA state;
	tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* T1_;
	n_2 = n;
	state = ((tyEnum_RunnableState__9b58EmEbGuos3KaMZ9cEC1OA) 0);
	T1_ = NIM_NIL;
	T1_ = genComment__docgen_508(d, n_2);
	add__docgen_107(dest, T1_);
	switch ((*n_2).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159):
	{
		n_2 = getRoutineBody__docgen_3208(n_2);
		switch ((*n_2).kind) {
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 125):
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
		{
			state = getAllRunnableExamplesImpl__docgen_3162(d, n_2, dest, state, NIM_FALSE);
		}
		break;
		default:
		{
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(n_2);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA7;
						i = i_2;
						state = getAllRunnableExamplesImpl__docgen_3162(d, (*n_2)._kind_6.sons->data[i], dest, state, NIM_FALSE);
						{
							if (!(state == ((tyEnum_RunnableState__9b58EmEbGuos3KaMZ9cEC1OA) 3))) goto LA10_;
						}
						LA10_: ;
						i_2 += ((NI) 1);
					} LA7: ;
				}
			}
		}
		break;
		}
	}
	break;
	default:
	{
		state = getAllRunnableExamplesImpl__docgen_3162(d, n_2, dest, state, NIM_TRUE);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, complexName__docgen_3380)(tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw k, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NimStringDesc* baseName) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = copyString(baseName);
	switch (k) {
	case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 12):
	case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 13):
	{
	}
	break;
	case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 17):
	{
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_102));
	}
	break;
	case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 14):
	{
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_103));
	}
	break;
	case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 15):
	{
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_104));
	}
	break;
	case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 18):
	{
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_105));
	}
	break;
	case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 16):
	{
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_106));
	}
	break;
	default:
	{
	}
	break;
	}
	{
		NIM_BOOL T10_;
		NI T11_;
		NimStringDesc* params;
		T10_ = (NIM_BOOL)0;
		T11_ = (NI)0;
		T11_ = safeLen__ast_3148(n);
		T10_ = (((NI) 3) < T11_);
		if (!(T10_)) goto LA12_;
		T10_ = ((*(*n)._kind_6.sons->data[((NI) 3)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 76));
		LA12_: ;
		if (!T10_) goto LA13_;
		params = renderParamTypes__typesrenderer_167((*n)._kind_6.sons->data[((NI) 3)], ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_107));
		{
			if (!(((NI) 0) < (params ? params->Sup.len : 0))) goto LA17_;
			result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_107));
			result = resizeString(result, (params ? params->Sup.len : 0) + 0);
appendString(result, params);
		}
		LA17_: ;
	}
	LA13_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, newUniquePlainSymbol__docgen_3371)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, NimStringDesc* original) {
	NimStringDesc* result;
	NI count;
{	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nsthasKey((*d).seenSymbols, original);
		if (!!(T3_)) goto LA4_;
		result = copyString(original);
		nstPut((*d).seenSymbols, original, ((NimStringDesc*) NIM_NIL));
		goto BeforeRet_;
	}
	LA4_: ;
	count = ((NI) 2);
	{
		while (1) {
			NimStringDesc* T8_;
			NimStringDesc* T9_;
			T8_ = NIM_NIL;
			T9_ = NIM_NIL;
			T9_ = dollar___systemZdollars_3(count);
			T8_ = rawNewString((original ? original->Sup.len : 0) + (T9_ ? T9_->Sup.len : 0) + 1);
appendString(T8_, original);
appendString(T8_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_108));
appendString(T8_, T9_);
			result = T8_;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = nsthasKey((*d).seenSymbols, result);
				if (!!(T12_)) goto LA13_;
				nstPut((*d).seenSymbols, result, ((NimStringDesc*) NIM_NIL));
				goto LA6;
			}
			LA13_: ;
			count += ((NI) 1);
		}
	} LA6: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, externalDep__docgen_571)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module) {
	NimStringDesc* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		NimStringDesc* full;
		NimStringDesc* tmp;
		NimStringDesc* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((*(*d).conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 33))&63U)))!=0);
		if (T3_) goto LA4_;
		T3_ = (((NI) 0) < ((*(*d).conf).docRoot ? (*(*d).conf).docRoot->Sup.len : 0));
		LA4_: ;
		if (!T3_) goto LA5_;
		full = toFullPath__msgs_548((*d).conf, ((NI32) ((*module).position)));
		T7_ = NIM_NIL;
		T7_ = presentationPath__docgen_197((*d).conf, full);
		tmp = getOutFile2__docgen_335((*d).conf, T7_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_61), !((((*module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 14))&63U)))!=0)));
		result = relativeTo__pathutils_133(tmp, (*d).thisDir, 47);
	}
	goto LA1_;
	LA5_: ;
	{
		NimStringDesc* T9_;
		T9_ = NIM_NIL;
		T9_ = toFullPath__msgs_548((*d).conf, ((NI32) ((*module).position)));
		result = nosextractFilename(T9_);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, nodeToHighlightedHtml__docgen_585)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NimStringDesc** result, tySet_tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA renderFlags, NimStringDesc* procLink) {
	tyObject_TSrcGen__FLkIzVI9alYjwMpiriDPTPQ r;
	NimStringDesc* literal;
	tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw kind;
	NI tokenPos;
	NI procTokenPos;
	nimZeroMem((void*)(&r), sizeof(tyObject_TSrcGen__FLkIzVI9alYjwMpiriDPTPQ));
	literal = ((NimStringDesc*) NIM_NIL);
	initTokRender__renderer_2137((&r), n, renderFlags);
	kind = ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 1);
	tokenPos = ((NI) 0);
	procTokenPos = ((NI) 0);
	{
		while (1) {
			getNextTok__renderer_2141((&r), (&kind), (&literal));
			tokenPos += ((NI) 1);
			switch (kind) {
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 1):
			{
				goto LA1;
			}
			break;
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 111):
			{
				{
					NIM_BOOL T7_;
					tyArray__nHXaesL0DJZHyVS07ARPRA T10_;
					T7_ = (NIM_BOOL)0;
					T7_ = isLatexCmd__docgen_349((*d).conf);
					if (!!(T7_)) goto LA8_;
					nimZeroMem((void*)T10_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					T10_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
					nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_109), T10_, 1);
				}
				goto LA5_;
				LA8_: ;
				{
					tyArray__nHXaesL0DJZHyVS07ARPRA T12_;
					nimZeroMem((void*)T12_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					T12_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
					nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_110), T12_, 1);
				}
				LA5_: ;
			}
			break;
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 3) ... ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 68):
			{
				{
					if (!(kind == ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 51) || kind == ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 41) || kind == ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 38) || kind == ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 40) || kind == ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 59) || kind == ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 30) || kind == ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 15))) goto LA16_;
					procTokenPos = tokenPos;
				}
				LA16_: ;
				{
					NIM_BOOL T20_;
					tyArray__nHXaesL0DJZHyVS07ARPRA T23_;
					T20_ = (NIM_BOOL)0;
					T20_ = isLatexCmd__docgen_349((*d).conf);
					if (!!(T20_)) goto LA21_;
					nimZeroMem((void*)T23_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					T23_[0] = copyString(literal);
					nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_111), T23_, 1);
				}
				goto LA18_;
				LA21_: ;
				{
					tyArray__nHXaesL0DJZHyVS07ARPRA T25_;
					nimZeroMem((void*)T25_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					T25_[0] = copyString(literal);
					nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_112), T25_, 1);
				}
				LA18_: ;
			}
			break;
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 110):
			{
				{
					NIM_BOOL T29_;
					tyArray__nHXaesL0DJZHyVS07ARPRA T32_;
					T29_ = (NIM_BOOL)0;
					T29_ = isLatexCmd__docgen_349((*d).conf);
					if (!!(T29_)) goto LA30_;
					nimZeroMem((void*)T32_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					T32_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
					nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_113), T32_, 1);
				}
				goto LA27_;
				LA30_: ;
				{
					tyArray__nHXaesL0DJZHyVS07ARPRA T34_;
					nimZeroMem((void*)T34_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					T34_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
					nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_114), T34_, 1);
				}
				LA27_: ;
			}
			break;
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 83) ... ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 85):
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 89):
			{
				{
					NIM_BOOL T38_;
					tyArray__nHXaesL0DJZHyVS07ARPRA T41_;
					T38_ = (NIM_BOOL)0;
					T38_ = isLatexCmd__docgen_349((*d).conf);
					if (!!(T38_)) goto LA39_;
					nimZeroMem((void*)T41_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					T41_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
					nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_115), T41_, 1);
				}
				goto LA36_;
				LA39_: ;
				{
					tyArray__nHXaesL0DJZHyVS07ARPRA T43_;
					nimZeroMem((void*)T43_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					T43_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
					nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_116), T43_, 1);
				}
				LA36_: ;
			}
			break;
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 88):
			{
				{
					NIM_BOOL T47_;
					tyArray__nHXaesL0DJZHyVS07ARPRA T50_;
					T47_ = (NIM_BOOL)0;
					T47_ = isLatexCmd__docgen_349((*d).conf);
					if (!!(T47_)) goto LA48_;
					nimZeroMem((void*)T50_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					T50_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
					nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_117), T50_, 1);
				}
				goto LA45_;
				LA48_: ;
				{
					tyArray__nHXaesL0DJZHyVS07ARPRA T52_;
					nimZeroMem((void*)T52_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					T52_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
					nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_118), T52_, 1);
				}
				LA45_: ;
			}
			break;
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 69) ... ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 78):
			{
				{
					NIM_BOOL T56_;
					tyArray__nHXaesL0DJZHyVS07ARPRA T59_;
					T56_ = (NIM_BOOL)0;
					T56_ = isLatexCmd__docgen_349((*d).conf);
					if (!!(T56_)) goto LA57_;
					nimZeroMem((void*)T59_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					T59_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
					nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_119), T59_, 1);
				}
				goto LA54_;
				LA57_: ;
				{
					tyArray__nHXaesL0DJZHyVS07ARPRA T61_;
					nimZeroMem((void*)T61_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					T61_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
					nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_120), T61_, 1);
				}
				LA54_: ;
			}
			break;
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 79) ... ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 82):
			{
				{
					NIM_BOOL T65_;
					tyArray__nHXaesL0DJZHyVS07ARPRA T68_;
					T65_ = (NIM_BOOL)0;
					T65_ = isLatexCmd__docgen_349((*d).conf);
					if (!!(T65_)) goto LA66_;
					nimZeroMem((void*)T68_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					T68_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
					nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_121), T68_, 1);
				}
				goto LA63_;
				LA66_: ;
				{
					tyArray__nHXaesL0DJZHyVS07ARPRA T70_;
					nimZeroMem((void*)T70_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					T70_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
					nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_122), T70_, 1);
				}
				LA63_: ;
			}
			break;
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 2):
			{
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
				s = getTokSym__renderer_2157((&r));
				{
					NIM_BOOL T74_;
					T74_ = (NIM_BOOL)0;
					T74_ = (procTokenPos == (NI)(tokenPos - ((NI) 2)));
					if (!(T74_)) goto LA75_;
					T74_ = !(((procLink ? procLink->Sup.len : 0) == 0));
					LA75_: ;
					if (!T74_) goto LA76_;
					{
						NIM_BOOL T80_;
						tyArray__Re75IspeoxXy2oCZHwcRrA T83_;
						T80_ = (NIM_BOOL)0;
						T80_ = isLatexCmd__docgen_349((*d).conf);
						if (!!(T80_)) goto LA81_;
						nimZeroMem((void*)T83_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
						T83_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
						T83_[1] = copyString(procLink);
						nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_123), T83_, 2);
					}
					goto LA78_;
					LA81_: ;
					{
						tyArray__Re75IspeoxXy2oCZHwcRrA T85_;
						nimZeroMem((void*)T85_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
						T85_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
						T85_[1] = copyString(procLink);
						nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_124), T85_, 2);
					}
					LA78_: ;
				}
				goto LA72_;
				LA76_: ;
				{
					NIM_BOOL T87_;
					NIM_BOOL T88_;
					NIM_BOOL T89_;
					NIM_BOOL T90_;
					NIM_BOOL T91_;
					NimStringDesc* external;
					tyArray__24KAM9afIUgUaqBaEBB6r9bg T99_;
					T87_ = (NIM_BOOL)0;
					T88_ = (NIM_BOOL)0;
					T89_ = (NIM_BOOL)0;
					T90_ = (NIM_BOOL)0;
					T91_ = (NIM_BOOL)0;
					T91_ = !((s == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
					if (!(T91_)) goto LA92_;
					T91_ = ((1920 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
					LA92_: ;
					T90_ = T91_;
					if (!(T90_)) goto LA93_;
					T90_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 1))&63U)))!=0);
					LA93_: ;
					T89_ = T90_;
					if (!(T89_)) goto LA94_;
					T89_ = !(((*s).owner == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
					LA94_: ;
					T88_ = T89_;
					if (!(T88_)) goto LA95_;
					T88_ = belongsToProjectPackage__packages_50((*d).conf, (*s).owner);
					LA95_: ;
					T87_ = T88_;
					if (!(T87_)) goto LA96_;
					T87_ = ((*d).Sup.target == ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 0));
					LA96_: ;
					if (!T87_) goto LA97_;
					external = externalDep__docgen_571(d, (*s).owner);
					nimZeroMem((void*)T99_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
					T99_[0] = noschangeFileExt(external, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_61));
					T99_[1] = copyString(literal);
					T99_[2] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
					nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_125), T99_, 3);
				}
				goto LA72_;
				LA97_: ;
				{
					{
						NIM_BOOL T103_;
						tyArray__nHXaesL0DJZHyVS07ARPRA T106_;
						T103_ = (NIM_BOOL)0;
						T103_ = isLatexCmd__docgen_349((*d).conf);
						if (!!(T103_)) goto LA104_;
						nimZeroMem((void*)T106_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
						T106_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
						nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_126), T106_, 1);
					}
					goto LA101_;
					LA104_: ;
					{
						tyArray__nHXaesL0DJZHyVS07ARPRA T108_;
						nimZeroMem((void*)T108_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
						T108_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
						nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_124), T108_, 1);
					}
					LA101_: ;
				}
				LA72_: ;
			}
			break;
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 113):
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 0):
			{
				unsureAsgnRef((void**) (&(*result)), resizeString((*result), (literal ? literal->Sup.len : 0) + 0));
appendString((*result), literal);
			}
			break;
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 117):
			{
				{
					if (!((renderFlags &((NU16)1<<((NU)(((tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA) 8))&15U)))!=0)) goto LA113_;
					{
						NIM_BOOL T117_;
						tyArray__nHXaesL0DJZHyVS07ARPRA T120_;
						T117_ = (NIM_BOOL)0;
						T117_ = isLatexCmd__docgen_349((*d).conf);
						if (!!(T117_)) goto LA118_;
						nimZeroMem((void*)T120_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
						T120_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
						nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_32), T120_, 1);
					}
					goto LA115_;
					LA118_: ;
					{
						tyArray__nHXaesL0DJZHyVS07ARPRA T122_;
						nimZeroMem((void*)T122_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
						T122_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
						nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_127), T122_, 1);
					}
					LA115_: ;
				}
				goto LA111_;
				LA113_: ;
				{
					{
						NIM_BOOL T126_;
						NimStringDesc* T129_;
						tyArray__nHXaesL0DJZHyVS07ARPRA T130_;
						T126_ = (NIM_BOOL)0;
						T126_ = isLatexCmd__docgen_349((*d).conf);
						if (!!(T126_)) goto LA127_;
						T129_ = NIM_NIL;
						T129_ = nsuReplaceStr(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_128), ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_129), ((NimStringDesc*) NIM_NIL));
						nimZeroMem((void*)T130_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
						T130_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
						nsuAddf(result, T129_, T130_, 1);
					}
					goto LA124_;
					LA127_: ;
					{
						tyArray__nHXaesL0DJZHyVS07ARPRA T132_;
						nimZeroMem((void*)T132_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
						T132_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
						nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_127), T132_, 1);
					}
					LA124_: ;
				}
				LA111_: ;
			}
			break;
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 118):
			{
				{
					if (!((renderFlags &((NU16)1<<((NU)(((tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA) 8))&15U)))!=0)) goto LA136_;
					{
						NIM_BOOL T140_;
						tyArray__nHXaesL0DJZHyVS07ARPRA T143_;
						T140_ = (NIM_BOOL)0;
						T140_ = isLatexCmd__docgen_349((*d).conf);
						if (!!(T140_)) goto LA141_;
						nimZeroMem((void*)T143_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
						T143_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
						nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_32), T143_, 1);
					}
					goto LA138_;
					LA141_: ;
					{
						tyArray__nHXaesL0DJZHyVS07ARPRA T145_;
						nimZeroMem((void*)T145_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
						T145_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
						nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_127), T145_, 1);
					}
					LA138_: ;
				}
				goto LA134_;
				LA136_: ;
				{
					{
						NIM_BOOL T149_;
						tyArray__nHXaesL0DJZHyVS07ARPRA T152_;
						T149_ = (NIM_BOOL)0;
						T149_ = isLatexCmd__docgen_349((*d).conf);
						if (!!(T149_)) goto LA150_;
						nimZeroMem((void*)T152_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
						T152_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
						nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_130), T152_, 1);
					}
					goto LA147_;
					LA150_: ;
					{
						tyArray__nHXaesL0DJZHyVS07ARPRA T154_;
						nimZeroMem((void*)T154_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
						T154_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
						nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_127), T154_, 1);
					}
					LA147_: ;
				}
				LA134_: ;
			}
			break;
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 98):
			{
				{
					NIM_BOOL T158_;
					tyArray__nHXaesL0DJZHyVS07ARPRA T161_;
					T158_ = (NIM_BOOL)0;
					T158_ = isLatexCmd__docgen_349((*d).conf);
					if (!!(T158_)) goto LA159_;
					nimZeroMem((void*)T161_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					T161_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
					nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_32), T161_, 1);
				}
				goto LA156_;
				LA159_: ;
				{
					tyArray__nHXaesL0DJZHyVS07ARPRA T163_;
					nimZeroMem((void*)T163_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					T163_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
					nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_127), T163_, 1);
				}
				LA156_: ;
			}
			break;
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 99):
			{
				{
					NIM_BOOL T167_;
					tyArray__nHXaesL0DJZHyVS07ARPRA T170_;
					T167_ = (NIM_BOOL)0;
					T167_ = isLatexCmd__docgen_349((*d).conf);
					if (!!(T167_)) goto LA168_;
					nimZeroMem((void*)T170_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					T170_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
					nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_32), T170_, 1);
				}
				goto LA165_;
				LA168_: ;
				{
					tyArray__nHXaesL0DJZHyVS07ARPRA T172_;
					nimZeroMem((void*)T172_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					T172_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
					nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_127), T172_, 1);
				}
				LA165_: ;
			}
			break;
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 90):
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 91):
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 92):
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 93):
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 94):
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 95):
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 96):
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 97):
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 100):
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 101):
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 102):
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 103):
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 104):
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 106):
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 107):
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 108):
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 112):
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 105):
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 86):
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 87):
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 114):
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 115):
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 116):
			case ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 109):
			{
				{
					NIM_BOOL T176_;
					tyArray__nHXaesL0DJZHyVS07ARPRA T179_;
					T176_ = (NIM_BOOL)0;
					T176_ = isLatexCmd__docgen_349((*d).conf);
					if (!!(T176_)) goto LA177_;
					nimZeroMem((void*)T179_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					T179_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
					nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_131), T179_, 1);
				}
				goto LA174_;
				LA177_: ;
				{
					tyArray__nHXaesL0DJZHyVS07ARPRA T181_;
					nimZeroMem((void*)T181_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					T181_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, literal, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
					nsuAddf(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_127), T181_, 1);
				}
				LA174_: ;
			}
			break;
			}
		}
	} LA1: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, genSeeSrc__docgen_3426)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, NimStringDesc* path, NI line) {
	NimStringDesc* result;
	NimStringDesc* docItemSeeSrc;
	result = NIM_NIL;
	docItemSeeSrc = getConfigVar__options_4054((*d).conf, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_132), ((NimStringDesc*) NIM_NIL));
	{
		NimStringDesc* path_2;
		NimStringDesc* T5_;
		NimStringDesc* gitUrl;
		if (!(((NI) 0) < (docItemSeeSrc ? docItemSeeSrc->Sup.len : 0))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = nosgetCurrentDir();
		path_2 = relativeTo__pathutils_133(path, T5_, 47);
		gitUrl = getConfigVar__options_4054((*d).conf, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_133), ((NimStringDesc*) NIM_NIL));
		{
			NimStringDesc* defaultBranch;
			NimStringDesc* commit;
			NimStringDesc* develBranch;
			if (!(((NI) 0) < (gitUrl ? gitUrl->Sup.len : 0))) goto LA8_;
			{
				if (!NIM_FALSE) goto LA12_;
				defaultBranch = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_134));
			}
			goto LA10_;
			LA12_: ;
			{
				tyArray__Re75IspeoxXy2oCZHwcRrA T15_;
				nimZeroMem((void*)T15_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T15_[0] = dollar___systemZdollars_3(((NI) 1));
				T15_[1] = dollar___systemZdollars_3(((NI) 6));
				defaultBranch = nsuFormatOpenArray(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_135), T15_, 2);
			}
			LA10_: ;
			commit = getConfigVar__options_4054((*d).conf, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_136), defaultBranch);
			develBranch = getConfigVar__options_4054((*d).conf, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_137), ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_134));
			{
				NIM_BOOL T18_;
				tyArray__nHXaesL0DJZHyVS07ARPRA T21_;
				tyArray__meGd17iD6izZVY5NTv9bHUA T22_;
				T18_ = (NIM_BOOL)0;
				T18_ = isLatexCmd__docgen_349((*d).conf);
				if (!!(T18_)) goto LA19_;
				nimZeroMem((void*)T21_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
				nimZeroMem((void*)T22_, sizeof(tyArray__meGd17iD6izZVY5NTv9bHUA));
				T22_[0] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_138));
				T22_[1] = copyString(path_2);
				T22_[2] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_139));
				T22_[3] = dollar___systemZdollars_3(line);
				T22_[4] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_140));
				T22_[5] = copyString(gitUrl);
				T22_[6] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_141));
				T22_[7] = copyString(commit);
				T22_[8] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_134));
				T22_[9] = copyString(develBranch);
				T21_[0] = nsuFormatOpenArray(docItemSeeSrc, T22_, 10);
				nsuAddf((&result), ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_32), T21_, 1);
			}
			goto LA16_;
			LA19_: ;
			{
				tyArray__nHXaesL0DJZHyVS07ARPRA T24_;
				tyArray__meGd17iD6izZVY5NTv9bHUA T25_;
				nimZeroMem((void*)T24_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
				nimZeroMem((void*)T25_, sizeof(tyArray__meGd17iD6izZVY5NTv9bHUA));
				T25_[0] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_138));
				T25_[1] = copyString(path_2);
				T25_[2] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_139));
				T25_[3] = dollar___systemZdollars_3(line);
				T25_[4] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_140));
				T25_[5] = copyString(gitUrl);
				T25_[6] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_141));
				T25_[7] = copyString(commit);
				T25_[8] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_134));
				T25_[9] = copyString(develBranch);
				T24_[0] = nsuFormatOpenArray(docItemSeeSrc, T25_, 10);
				nsuAddf((&result), ((NimStringDesc*) NIM_NIL), T24_, 1);
			}
			LA16_: ;
		}
		LA8_: ;
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, whichType__docgen_246)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
{	result = NIM_NIL;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = strTableContains__astalgo_3226((*d).types, (*n)._kind_4.sym);
			if (!T7_) goto LA8_;
			result = (*n)._kind_4.sym;
		}
		LA8_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* x;
					if (!(i_2 < colontmp_)) goto LA13;
					i = i_2;
					x = whichType__docgen_246(d, (*n)._kind_6.sons->data[i]);
					{
						if (!!((x == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA16_;
						result = x;
						goto BeforeRet_;
					}
					LA16_: ;
					i_2 += ((NI) 1);
				} LA13: ;
			}
		}
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, attachToType__docgen_265)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* p) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* params;
{	result = NIM_NIL;
	params = (*(*p).ast)._kind_6.sons->data[((NI) 3)];
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__ast_3155(params);
		if (!(((NI) 1) < T3_)) goto LA4_;
		result = whichType__docgen_246(d, (*params)._kind_6.sons->data[((NI) 1)]);
		{
			if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA8_;
			goto BeforeRet_;
		}
		LA8_: ;
	}
	LA4_: ;
	{
		NI T12_;
		T12_ = (NI)0;
		T12_ = len__ast_3155(params);
		if (!(((NI) 0) < T12_)) goto LA13_;
		result = whichType__docgen_246(d, (*params)._kind_6.sons->data[((NI) 0)]);
		{
			if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA17_;
			goto BeforeRet_;
		}
		LA17_: ;
	}
	LA13_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(params);
		i_2 = ((NI) 2);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA21;
				i = i_2;
				result = whichType__docgen_246(d, (*params)._kind_6.sons->data[i]);
				{
					if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA24_;
					goto BeforeRet_;
				}
				LA24_: ;
				i_2 += ((NI) 1);
			} LA21: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c) {
	(*dest).data[(*dest).Sup.len] = c;
	(*dest).data[(NI)((*dest).Sup.len + ((NI) 1))] = 0;
	(*dest).Sup.len += ((NI) 1);
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, docstringSummary__docgen_3392)(NimStringDesc* rstText) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	NI pos;
	NI last;
{	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = substr__system_7736(rstText, ((NI) 2));
	result = nsuStrip(T1_, NIM_TRUE, NIM_TRUE, TM__iS6Vfak4fKt7fhPmyApRcg_101);
	pos = nsuFindChar(result, 10, ((NI) 0), ((NI) 0));
	{
		if (!(((NI) 0) < pos)) goto LA4_;
		result = setLengthStr(result, ((NI) ((NI)(pos - ((NI) 1)))));
		result = resizeString(result, 3);
appendString(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_153));
	}
	LA4_: ;
	{
		if (!(pos < ((NI) 100))) goto LA8_;
		goto BeforeRet_;
	}
	LA8_: ;
	pos = nsuFindCharSet(result, TM__iS6Vfak4fKt7fhPmyApRcg_154, ((NI) 0), ((NI) 0));
	last = (NI)((result ? result->Sup.len : 0) - ((NI) 1));
	{
		NIM_BOOL T12_;
		T12_ = (NIM_BOOL)0;
		T12_ = (((NI) 0) < pos);
		if (!(T12_)) goto LA13_;
		T12_ = (pos < last);
		LA13_: ;
		if (!T12_) goto LA14_;
		result = setLengthStr(result, ((NI) ((NI)(pos - ((NI) 1)))));
		result = resizeString(result, 3);
appendString(result, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_153));
	}
	LA14_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genItem__docgen_3437)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nameNode, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw k, tyEnum_DocFlags__Q2li9cSVrBaVKtfORTUg5dQ docFlags) {
	NimStringDesc* name;
	NimStringDesc* plainDocstring;
	NimStringDesc* result;
	NimStringDesc* literal;
	NimStringDesc* plainName;
	tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw kind;
	tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q* comm;
	tyObject_TSrcGen__FLkIzVI9alYjwMpiriDPTPQ r;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pragmaNode;
	NimStringDesc* plainNameEsc;
	NimStringDesc* T24_;
	NimStringDesc* uniqueName;
	NimStringDesc* sortName;
	NimStringDesc* cleanPlainSymbol;
	NimStringDesc* complexSymbol;
	NimStringDesc* plainSymbolEnc;
	NimStringDesc* symbolOrId;
	NimStringDesc* symbolOrIdEnc;
	NimStringDesc* deprecationMsg;
	NimStringDesc* seeSrc;
	NimStringDesc* T35_;
	tyObject_Item__T7UjOImKJxoSfGY6SB3KMg T36_;
	NimStringDesc* T37_;
	NimStringDesc* T38_;
	NimStringDesc* T39_;
	NimStringDesc* T40_;
	NimStringDesc* T41_;
	NimStringDesc* T42_;
	NimStringDesc* T43_;
	NimStringDesc* T44_;
	NimStringDesc* T45_;
	NimStringDesc* T46_;
	NimStringDesc* T47_;
	NimStringDesc* T48_;
	NimStringDesc* T49_;
	NimStringDesc* T50_;
	NimStringDesc* T51_;
	NimStringDesc* T52_;
	NimStringDesc* T53_;
	NimStringDesc* T54_;
	NimStringDesc* T55_;
	NimStringDesc* T56_;
	NimStringDesc* T57_;
	NI T58_;
	NimStringDesc* T59_;
	NimStringDesc* external;
	NimStringDesc* T60_;
	NimStringDesc* attype;
	tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q T91_;
	NimStringDesc* T92_;
	tyArray__yt5VDPNtUGx9cBkOVakHwdQ T93_;
	NI T94_;
	NimStringDesc* T95_;
	NimStringDesc* T96_;
	tySequence__spLz9azjOgbpYKrtmm9aMHEw* T97_;
	tySequence__spLz9azjOgbpYKrtmm9aMHEw** T98_;
	tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q T99_;
	NimStringDesc* T100_;
	tyArray__Q6RksR9bl1dCf8jl3HeN9bXg T101_;
	NI T102_;
	NimStringDesc* T103_;
	NimStringDesc* T104_;
	NimStringDesc* linkTitle;
	NimStringDesc* T105_;
	NimStringDesc* T106_;
	NimStringDesc* T107_;
	NimStringDesc* T117_;
	NimStringDesc* T118_;
{	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !((docFlags == ((tyEnum_DocFlags__Q2li9cSVrBaVKtfORTUg5dQ) 1)));
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = isVisible__docgen_3258(d, nameNode);
		T3_ = !(T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		goto BeforeRet_;
	}
	LA6_: ;
	name = getName__docgen_3321(d, nameNode, ((NI) -1));
	plainDocstring = getPlainDocstring__docgen_558(n);
	result = ((NimStringDesc*) NIM_NIL);
	literal = ((NimStringDesc*) NIM_NIL);
	plainName = ((NimStringDesc*) NIM_NIL);
	kind = ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 1);
	comm = NIM_NIL;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159))) goto LA10_;
		getAllRunnableExamples__docgen_3238(d, n, (&comm));
	}
	goto LA8_;
	LA10_: ;
	{
		tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* T13_;
		T13_ = NIM_NIL;
		T13_ = genRecComment__docgen_541(d, n);
		add__docgen_107((&comm), T13_);
	}
	LA8_: ;
	nimZeroMem((void*)(&r), sizeof(tyObject_TSrcGen__FLkIzVI9alYjwMpiriDPTPQ));
	initTokRender__renderer_2137((&r), n, 94);
	{
		while (1) {
			getNextTok__renderer_2141((&r), (&kind), (&literal));
			{
				if (!(kind == ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 1))) goto LA18_;
				goto LA14;
			}
			LA18_: ;
			plainName = resizeString(plainName, (literal ? literal->Sup.len : 0) + 0);
appendString(plainName, literal);
		}
	} LA14: ;
	pragmaNode = getDeclPragma__ast_3203(n);
	{
		if (!!((pragmaNode == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA22_;
		pragmaNode = findPragma__trees_271(pragmaNode, ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 138));
	}
	LA22_: ;
	(*d).Sup.id += ((NI) 1);
	T24_ = NIM_NIL;
	T24_ = nsuStrip(plainName, NIM_TRUE, NIM_TRUE, TM__iS6Vfak4fKt7fhPmyApRcg_101);
	plainNameEsc = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, T24_, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
	{
		if (!((520192 &((NU32)1<<((NU)(k)&31U)))!=0)) goto LA27_;
		uniqueName = plainNameEsc;
	}
	goto LA25_;
	LA27_: ;
	{
		uniqueName = name;
	}
	LA25_: ;
	{
		if (!((520192 &((NU32)1<<((NU)(k)&31U)))!=0)) goto LA32_;
		sortName = nsuStrip(plainName, NIM_TRUE, NIM_TRUE, TM__iS6Vfak4fKt7fhPmyApRcg_101);
	}
	goto LA30_;
	LA32_: ;
	{
		sortName = name;
	}
	LA30_: ;
	cleanPlainSymbol = renderPlainSymbolName__typesrenderer_6(nameNode);
	complexSymbol = complexName__docgen_3380(k, n, cleanPlainSymbol);
	plainSymbolEnc = encodeUrl__pureZuri_40(cleanPlainSymbol, NIM_FALSE);
	symbolOrId = newUniquePlainSymbol__docgen_3371(d, complexSymbol);
	symbolOrIdEnc = encodeUrl__pureZuri_40(symbolOrId, NIM_FALSE);
	deprecationMsg = genDeprecationMsg__docgen_3401(d, pragmaNode);
	nodeToHighlightedHtml__docgen_585(d, n, (&result), 142, symbolOrIdEnc);
	T35_ = NIM_NIL;
	T35_ = toFullPath__msgs_548((*d).conf, (*n).info.fileIndex);
	seeSrc = genSeeSrc__docgen_3426(d, T35_, ((NI) ((*n).info.line)));
	nimZeroMem((void*)(&T36_), sizeof(tyObject_Item__T7UjOImKJxoSfGY6SB3KMg));
	nimZeroMem((void*)(&T36_), sizeof(tyObject_Item__T7UjOImKJxoSfGY6SB3KMg));
	genericSeqAssign((&T36_.descRst), comm, (&NTIitempre__JSDKkkE7gMRTYRB9bRZ9bH7Q_));
	T36_.sortName = copyString(sortName);
	T36_.substitutions = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) newSeq((&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_), 22);
	T37_ = NIM_NIL;
	T37_ = T36_.substitutions->data[0]; T36_.substitutions->data[0] = copyStringRC1(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_142));
	if (T37_) nimGCunrefNoCycle(T37_);
	T38_ = NIM_NIL;
	T38_ = T36_.substitutions->data[1]; T36_.substitutions->data[1] = copyStringRC1(name);
	if (T38_) nimGCunrefNoCycle(T38_);
	T39_ = NIM_NIL;
	T39_ = T36_.substitutions->data[2]; T36_.substitutions->data[2] = copyStringRC1(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_143));
	if (T39_) nimGCunrefNoCycle(T39_);
	T40_ = NIM_NIL;
	T40_ = T36_.substitutions->data[3]; T36_.substitutions->data[3] = copyStringRC1(uniqueName);
	if (T40_) nimGCunrefNoCycle(T40_);
	T41_ = NIM_NIL;
	T41_ = T36_.substitutions->data[4]; T36_.substitutions->data[4] = copyStringRC1(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_144));
	if (T41_) nimGCunrefNoCycle(T41_);
	T42_ = NIM_NIL;
	T42_ = T36_.substitutions->data[5]; T36_.substitutions->data[5] = copyStringRC1(result);
	if (T42_) nimGCunrefNoCycle(T42_);
	T43_ = NIM_NIL;
	T43_ = T36_.substitutions->data[6]; T36_.substitutions->data[6] = copyStringRC1(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_145));
	if (T43_) nimGCunrefNoCycle(T43_);
	asgnRef((void**) (&T36_.substitutions->data[7]), dollar___systemZdollars_3((*d).Sup.id));
	T44_ = NIM_NIL;
	T44_ = T36_.substitutions->data[8]; T36_.substitutions->data[8] = copyStringRC1(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_146));
	if (T44_) nimGCunrefNoCycle(T44_);
	T45_ = NIM_NIL;
	T45_ = T36_.substitutions->data[9]; T36_.substitutions->data[9] = copyStringRC1(plainNameEsc);
	if (T45_) nimGCunrefNoCycle(T45_);
	T46_ = NIM_NIL;
	T46_ = T36_.substitutions->data[10]; T36_.substitutions->data[10] = copyStringRC1(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_147));
	if (T46_) nimGCunrefNoCycle(T46_);
	T47_ = NIM_NIL;
	T47_ = T36_.substitutions->data[11]; T36_.substitutions->data[11] = copyStringRC1(cleanPlainSymbol);
	if (T47_) nimGCunrefNoCycle(T47_);
	T48_ = NIM_NIL;
	T48_ = T36_.substitutions->data[12]; T36_.substitutions->data[12] = copyStringRC1(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_148));
	if (T48_) nimGCunrefNoCycle(T48_);
	T49_ = NIM_NIL;
	T49_ = T36_.substitutions->data[13]; T36_.substitutions->data[13] = copyStringRC1(symbolOrId);
	if (T49_) nimGCunrefNoCycle(T49_);
	T50_ = NIM_NIL;
	T50_ = T36_.substitutions->data[14]; T36_.substitutions->data[14] = copyStringRC1(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_149));
	if (T50_) nimGCunrefNoCycle(T50_);
	T51_ = NIM_NIL;
	T51_ = T36_.substitutions->data[15]; T36_.substitutions->data[15] = copyStringRC1(plainSymbolEnc);
	if (T51_) nimGCunrefNoCycle(T51_);
	T52_ = NIM_NIL;
	T52_ = T36_.substitutions->data[16]; T36_.substitutions->data[16] = copyStringRC1(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_150));
	if (T52_) nimGCunrefNoCycle(T52_);
	T53_ = NIM_NIL;
	T53_ = T36_.substitutions->data[17]; T36_.substitutions->data[17] = copyStringRC1(symbolOrIdEnc);
	if (T53_) nimGCunrefNoCycle(T53_);
	T54_ = NIM_NIL;
	T54_ = T36_.substitutions->data[18]; T36_.substitutions->data[18] = copyStringRC1(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_151));
	if (T54_) nimGCunrefNoCycle(T54_);
	T55_ = NIM_NIL;
	T55_ = T36_.substitutions->data[19]; T36_.substitutions->data[19] = copyStringRC1(seeSrc);
	if (T55_) nimGCunrefNoCycle(T55_);
	T56_ = NIM_NIL;
	T56_ = T36_.substitutions->data[20]; T36_.substitutions->data[20] = copyStringRC1(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_152));
	if (T56_) nimGCunrefNoCycle(T56_);
	T57_ = NIM_NIL;
	T57_ = T36_.substitutions->data[21]; T36_.substitutions->data[21] = copyStringRC1(deprecationMsg);
	if (T57_) nimGCunrefNoCycle(T57_);
	asgnRef((void**) (&(*d).section[(k)- 0].secItems), (tySequence__bLuZlbeJhlfg9axVlmjdJXw*) incrSeqV3((TGenericSeq*)((*d).section[(k)- 0].secItems), (&NTIseqLitemT__bLuZlbeJhlfg9axVlmjdJXw_)));
	T58_ = (*d).section[(k)- 0].secItems->Sup.len++;
	genericSeqAssign((&(*d).section[(k)- 0].secItems->data[T58_].descRst), T36_.descRst, (&NTIitempre__JSDKkkE7gMRTYRB9bRZ9bH7Q_));
	genericSeqAssign((&(*d).section[(k)- 0].secItems->data[T58_].substitutions), T36_.substitutions, (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_));
	T59_ = NIM_NIL;
	T59_ = (*d).section[(k)- 0].secItems->data[T58_].sortName; (*d).section[(k)- 0].secItems->data[T58_].sortName = copyStringRC1(T36_.sortName);
	if (T59_) nimGCunrefNoCycle(T59_);
	T60_ = NIM_NIL;
	T60_ = relativeTo__pathutils_133((*d).Sup.destFile, (*(*d).conf).outDir, 47);
	external = noschangeFileExt(T60_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_61));
	attype = ((NimStringDesc*) NIM_NIL);
	{
		NIM_BOOL T63_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* att;
		T63_ = (NIM_BOOL)0;
		T63_ = ((520192 &((NU32)1<<((NU)(k)&31U)))!=0);
		if (!(T63_)) goto LA64_;
		T63_ = ((*nameNode).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		LA64_: ;
		if (!T63_) goto LA65_;
		att = attachToType__docgen_265(d, (*nameNode)._kind_4.sym);
		{
			if (!!((att == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA69_;
			attype = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, (*(*att).name).s, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
		}
		LA69_: ;
	}
	goto LA61_;
	LA65_: ;
	{
		NIM_BOOL T72_;
		NIM_BOOL T73_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* etyp;
		T72_ = (NIM_BOOL)0;
		T73_ = (NIM_BOOL)0;
		T73_ = (k == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 7));
		if (!(T73_)) goto LA74_;
		T73_ = ((*nameNode).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		LA74_: ;
		T72_ = T73_;
		if (!(T72_)) goto LA75_;
		T72_ = ((*(*(*nameNode)._kind_4.sym).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14) || (*(*(*nameNode)._kind_4.sym).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1));
		LA75_: ;
		if (!T72_) goto LA76_;
		etyp = (*(*nameNode)._kind_4.sym).typ;
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e;
			e = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148((*etyp).n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA81;
						i = i_2;
						e = (*(*etyp).n)._kind_6.sons->data[i];
						{
							NimStringDesc* plain;
							NimStringDesc* symbolOrId_2;
							NimStringDesc* T87_;
							NimStringDesc* T88_;
							NimStringDesc* T89_;
							NimStringDesc* T90_;
							{
								if (!!(((*(*e)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 20)))) goto LA85_;
								goto LA82;
							}
							LA85_: ;
							plain = renderPlainSymbolName__typesrenderer_6(e);
							symbolOrId_2 = newUniquePlainSymbol__docgen_3371(d, plain);
							T87_ = NIM_NIL;
							T87_ = rawNewString(((*(*(*nameNode)._kind_4.sym).name).s ? (*(*(*nameNode)._kind_4.sym).name).s->Sup.len : 0) + (plain ? plain->Sup.len : 0) + 1);
appendString(T87_, (*(*(*nameNode)._kind_4.sym).name).s);
appendChar(T87_, 46);
appendString(T87_, plain);
							T88_ = NIM_NIL;
							T88_ = getPlainDocstring__docgen_558(e);
							T89_ = NIM_NIL;
							T89_ = docstringSummary__docgen_3392(T88_);
							T90_ = NIM_NIL;
							T90_ = escape__pureZxmltree_479(T89_);
							setIndexTerm__packagesZdocutilsZrstgen_353(&d->Sup, external, symbolOrId_2, plain, T87_, T90_);
						} LA82: ;
						i_2 += ((NI) 1);
					} LA81: ;
				}
			}
		}
	}
	goto LA61_;
	LA76_: ;
	LA61_: ;
	nimZeroMem((void*)(&T91_), sizeof(tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q));
	nimZeroMem((void*)(&T91_), sizeof(tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q));
	T91_.sortName = copyString(sortName);
	T92_ = NIM_NIL;
	T92_ = getConfigVar__options_4054((*d).conf, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_155), ((NimStringDesc*) NIM_NIL));
	nimZeroMem((void*)T93_, sizeof(tyArray__yt5VDPNtUGx9cBkOVakHwdQ));
	T93_[0] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_142));
	T93_[1] = copyString(name);
	T93_[2] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_146));
	T93_[3] = copyString(plainNameEsc);
	T93_[4] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_150));
	T93_[5] = copyString(symbolOrIdEnc);
	T91_.content = nsuFormatOpenArray(T92_, T93_, 6);
	asgnRef((void**) (&(*d).tocSimple[(k)- 0]), (tySequence__spLz9azjOgbpYKrtmm9aMHEw*) incrSeqV3((TGenericSeq*)((*d).tocSimple[(k)- 0]), (&NTIseqLtocitemT__spLz9azjOgbpYKrtmm9aMHEw_)));
	T94_ = (*d).tocSimple[(k)- 0]->Sup.len++;
	T95_ = NIM_NIL;
	T95_ = (*d).tocSimple[(k)- 0]->data[T94_].content; (*d).tocSimple[(k)- 0]->data[T94_].content = copyStringRC1(T91_.content);
	if (T95_) nimGCunrefNoCycle(T95_);
	T96_ = NIM_NIL;
	T96_ = (*d).tocSimple[(k)- 0]->data[T94_].sortName; (*d).tocSimple[(k)- 0]->data[T94_].sortName = copyStringRC1(T91_.sortName);
	if (T96_) nimGCunrefNoCycle(T96_);
	T97_ = NIM_NIL;
	T97_ = newSeq__docgen_3547(((NI) 0));
	T98_ = (tySequence__spLz9azjOgbpYKrtmm9aMHEw**)0;
	T98_ = mgetOrPut__docgen_3594((&(*d).tocTable[(k)- 0]), cleanPlainSymbol, T97_);
	nimZeroMem((void*)(&T99_), sizeof(tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q));
	nimZeroMem((void*)(&T99_), sizeof(tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q));
	T99_.sortName = copyString(sortName);
	T100_ = NIM_NIL;
	T100_ = getConfigVar__options_4054((*d).conf, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_156), ((NimStringDesc*) NIM_NIL));
	nimZeroMem((void*)T101_, sizeof(tyArray__Q6RksR9bl1dCf8jl3HeN9bXg));
	T101_[0] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_142));
	T101_[1] = copyString(name);
	T101_[2] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_146));
	T101_[3] = copyString(plainNameEsc);
	T101_[4] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_148));
	T101_[5] = nsuReplaceStr(symbolOrId, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_107), ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_157));
	T101_[6] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_150));
	T101_[7] = copyString(symbolOrIdEnc);
	T99_.content = nsuFormatOpenArray(T100_, T101_, 8);
	unsureAsgnRef((void**) (&(*T98_)), (tySequence__spLz9azjOgbpYKrtmm9aMHEw*) incrSeqV3((TGenericSeq*)((*T98_)), (&NTIseqLtocitemT__spLz9azjOgbpYKrtmm9aMHEw_)));
	T102_ = (*T98_)->Sup.len++;
	T103_ = NIM_NIL;
	T103_ = (*T98_)->data[T102_].content; (*T98_)->data[T102_].content = copyStringRC1(T99_.content);
	if (T103_) nimGCunrefNoCycle(T103_);
	T104_ = NIM_NIL;
	T104_ = (*T98_)->data[T102_].sortName; (*T98_)->data[T102_].sortName = copyStringRC1(T99_.sortName);
	if (T104_) nimGCunrefNoCycle(T104_);
	T105_ = NIM_NIL;
	T106_ = NIM_NIL;
	T106_ = nosextractFilename((*d).Sup.filename);
	T107_ = NIM_NIL;
	T107_ = noschangeFileExt(T106_, ((NimStringDesc*) NIM_NIL));
	T105_ = rawNewString((T107_ ? T107_->Sup.len : 0) + 2);
appendString(T105_, T107_);
appendString(T105_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_158));
	linkTitle = T105_;
	{
		NimStringDesc* T112_;
		NimStringDesc* T113_;
		if (!((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159))) goto LA110_;
		T112_ = NIM_NIL;
		T112_ = nsuStrip(plainName, NIM_TRUE, NIM_TRUE, TM__iS6Vfak4fKt7fhPmyApRcg_101);
		T113_ = NIM_NIL;
		T113_ = escape__pureZxmltree_479(T112_);
		linkTitle = resizeString(linkTitle, (T113_ ? T113_->Sup.len : 0) + 0);
appendString(linkTitle, T113_);
	}
	goto LA108_;
	LA110_: ;
	{
		NimStringDesc* T115_;
		NimStringDesc* T116_;
		T115_ = NIM_NIL;
		T115_ = nsuStrip(complexSymbol, NIM_TRUE, NIM_TRUE, TM__iS6Vfak4fKt7fhPmyApRcg_101);
		T116_ = NIM_NIL;
		T116_ = escape__pureZxmltree_479(T115_);
		linkTitle = resizeString(linkTitle, (T116_ ? T116_->Sup.len : 0) + 0);
appendString(linkTitle, T116_);
	}
	LA108_: ;
	T117_ = NIM_NIL;
	T117_ = docstringSummary__docgen_3392(plainDocstring);
	T118_ = NIM_NIL;
	T118_ = escape__pureZxmltree_479(T117_);
	setIndexTerm__packagesZdocutilsZrstgen_353(&d->Sup, external, symbolOrId, name, linkTitle, T118_);
	{
		NIM_BOOL T121_;
		T121_ = (NIM_BOOL)0;
		T121_ = (k == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 7));
		if (!(T121_)) goto LA122_;
		T121_ = ((*nameNode).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		LA122_: ;
		if (!T121_) goto LA123_;
		strTableAdd__astalgo_3325((&(*d).types), (*nameNode)._kind_4.sym);
	}
	LA123_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, checkForFalse__docgen_5116)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T3_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2));
	if (!(T1_)) goto LA2_;
	T3_ = (NI)0;
	T3_ = nsuCmpIgnoreStyle((*(*n)._kind_5.ident).s, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_159));
	T1_ = (T3_ == ((NI) 0));
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, traceDeps__docgen_5123)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T6_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* sep;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* dir;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29));
		if (!(T4_)) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__ast_3155(it);
		T4_ = (T6_ == ((NI) 3));
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA7_;
		T3_ = ((*(*it)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41));
		LA7_: ;
		if (!T3_) goto LA8_;
		sep = (*it)._kind_6.sons->data[((NI) 0)];
		dir = (*it)._kind_6.sons->data[((NI) 1)];
		a = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29), (*it).info);
		add__ast_4798(a, sep);
		add__ast_4798(a, dir);
		add__ast_4798(a, sep);
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* colontmp_;
			x = NIM_NIL;
			colontmp_ = NIM_NIL;
			colontmp_ = (*it)._kind_6.sons->data[((NI) 2)];
			{
				NI i;
				NI colontmp__2;
				NI i_2;
				i = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = safeLen__ast_3148(colontmp_);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp__2)) goto LA13;
						i = i_2;
						x = (*colontmp_)._kind_6.sons->data[i];
						asgnRef((void**) (&(*a)._kind_6.sons->data[((NI) 2)]), x);
						traceDeps__docgen_5123(d, a);
						i_2 += ((NI) 1);
					} LA13: ;
				}
			}
		}
	}
	goto LA1_;
	LA8_: ;
	{
		NIM_BOOL T15_;
		NimStringDesc* external;
		T15_ = (NIM_BOOL)0;
		T15_ = ((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		if (!(T15_)) goto LA16_;
		T15_ = belongsToProjectPackage__packages_50((*d).conf, (*it)._kind_4.sym);
		LA16_: ;
		if (!T15_) goto LA17_;
		external = externalDep__docgen_571(d, (*it)._kind_4.sym);
		{
			if (!!((((*d).section[(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6))- 0].finalMarkup ? (*d).section[(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6))- 0].finalMarkup->Sup.len : 0) == 0))) goto LA21_;
			asgnRef((void**) (&(*d).section[(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6))- 0].finalMarkup), resizeString((*d).section[(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6))- 0].finalMarkup, 2));
appendString((*d).section[(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6))- 0].finalMarkup, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_82));
		}
		LA21_: ;
		{
			NIM_BOOL T25_;
			tyArray__Re75IspeoxXy2oCZHwcRrA T28_;
			NimStringDesc* T29_;
			T25_ = (NIM_BOOL)0;
			T25_ = isLatexCmd__docgen_349((*d).conf);
			if (!!(T25_)) goto LA26_;
			nimZeroMem((void*)T28_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T29_ = NIM_NIL;
			T29_ = prettyLink__packagesZdocutilsZrstgen_85(external);
			T28_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, T29_, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
			T28_[1] = noschangeFileExt(external, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_61));
			nsuAddf((&(*d).section[(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6))- 0].finalMarkup), ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_160), T28_, 2);
		}
		goto LA23_;
		LA26_: ;
		{
			tyArray__Re75IspeoxXy2oCZHwcRrA T31_;
			NimStringDesc* T32_;
			nimZeroMem((void*)T31_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T32_ = NIM_NIL;
			T32_ = prettyLink__packagesZdocutilsZrstgen_85(external);
			T31_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, T32_, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
			T31_[1] = noschangeFileExt(external, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_61));
			nsuAddf((&(*d).section[(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6))- 0].finalMarkup), ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_32), T31_, 2);
		}
		LA23_: ;
	}
	goto LA1_;
	LA17_: ;
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, exportSym__docgen_5164)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	{
		NIM_BOOL T3_;
		NimStringDesc* external;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6));
		if (!(T3_)) goto LA4_;
		T3_ = belongsToProjectPackage__packages_50((*d).conf, s);
		LA4_: ;
		if (!T3_) goto LA5_;
		external = externalDep__docgen_571(d, s);
		{
			if (!!((((*d).section[(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19))- 0].finalMarkup ? (*d).section[(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19))- 0].finalMarkup->Sup.len : 0) == 0))) goto LA9_;
			asgnRef((void**) (&(*d).section[(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19))- 0].finalMarkup), resizeString((*d).section[(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19))- 0].finalMarkup, 2));
appendString((*d).section[(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19))- 0].finalMarkup, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_82));
		}
		LA9_: ;
		{
			NIM_BOOL T13_;
			tyArray__Re75IspeoxXy2oCZHwcRrA T16_;
			NimStringDesc* T17_;
			T13_ = (NIM_BOOL)0;
			T13_ = isLatexCmd__docgen_349((*d).conf);
			if (!!(T13_)) goto LA14_;
			nimZeroMem((void*)T16_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T17_ = NIM_NIL;
			T17_ = prettyLink__packagesZdocutilsZrstgen_85(external);
			T16_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, T17_, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
			T16_[1] = noschangeFileExt(external, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_61));
			nsuAddf((&(*d).section[(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19))- 0].finalMarkup), ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_160), T16_, 2);
		}
		goto LA11_;
		LA14_: ;
		{
			tyArray__Re75IspeoxXy2oCZHwcRrA T19_;
			NimStringDesc* T20_;
			nimZeroMem((void*)T19_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T20_ = NIM_NIL;
			T20_ = prettyLink__packagesZdocutilsZrstgen_85(external);
			T19_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, T20_, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
			T19_[1] = noschangeFileExt(external, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_61));
			nsuAddf((&(*d).section[(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19))- 0].finalMarkup), ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_32), T19_, 2);
		}
		LA11_: ;
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T22_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
		T22_ = (NIM_BOOL)0;
		T22_ = !(((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6)));
		if (!(T22_)) goto LA23_;
		T22_ = !(((*s).owner == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
		LA23_: ;
		if (!T22_) goto LA24_;
		module = originatingModule__ast_4670(s);
		{
			NIM_BOOL T28_;
			NimStringDesc* complexSymbol;
			NimStringDesc* symbolOrId;
			NimStringDesc* external_2;
			T28_ = (NIM_BOOL)0;
			T28_ = belongsToProjectPackage__packages_50((*d).conf, module);
			if (!T28_) goto LA29_;
			complexSymbol = complexName__docgen_3380((*s).kind, (*s).ast, (*(*s).name).s);
			symbolOrId = newUniquePlainSymbol__docgen_3371(d, complexSymbol);
			external_2 = externalDep__docgen_571(d, module);
			{
				if (!!((((*d).section[(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19))- 0].finalMarkup ? (*d).section[(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19))- 0].finalMarkup->Sup.len : 0) == 0))) goto LA33_;
				asgnRef((void**) (&(*d).section[(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19))- 0].finalMarkup), resizeString((*d).section[(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19))- 0].finalMarkup, 2));
appendString((*d).section[(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19))- 0].finalMarkup, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_82));
			}
			LA33_: ;
			{
				NIM_BOOL T37_;
				tyArray__24KAM9afIUgUaqBaEBB6r9bg T40_;
				T37_ = (NIM_BOOL)0;
				T37_ = isLatexCmd__docgen_349((*d).conf);
				if (!!(T37_)) goto LA38_;
				nimZeroMem((void*)T40_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
				T40_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, (*(*s).name).s, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
				T40_[1] = noschangeFileExt(external_2, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_61));
				T40_[2] = copyString(symbolOrId);
				nsuAddf((&(*d).section[(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19))- 0].finalMarkup), ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_161), T40_, 3);
			}
			goto LA35_;
			LA38_: ;
			{
				tyArray__24KAM9afIUgUaqBaEBB6r9bg T42_;
				nimZeroMem((void*)T42_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
				T42_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, (*(*s).name).s, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
				T42_[1] = noschangeFileExt(external_2, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_61));
				T42_[2] = copyString(symbolOrId);
				nsuAddf((&(*d).section[(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19))- 0].finalMarkup), ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_32), T42_, 3);
			}
			LA35_: ;
		}
		LA29_: ;
	}
	goto LA1_;
	LA24_: ;
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, generateDoc__docgen_5358)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* orig, tyEnum_DocFlags__Q2li9cSVrBaVKtfORTUg5dQ docFlags) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 90):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pragmaNode;
		NimStringDesc* T2_;
		pragmaNode = findPragma__trees_271(n, ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 138));
		T2_ = NIM_NIL;
		T2_ = genDeprecationMsg__docgen_3401(d, pragmaNode);
		asgnRef((void**) (&(*d).modDeprecationMsg), resizeString((*d).modDeprecationMsg, (T2_ ? T2_->Sup.len : 0) + 0));
appendString((*d).modDeprecationMsg, T2_);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 125):
	{
		tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* T4_;
		T4_ = NIM_NIL;
		T4_ = genComment__docgen_508(d, n);
		add__docgen_107((&(*d).modDescPre), T4_);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159):
	{
		documentRaises__docgen_5273((*d).cache, n);
		genItem__docgen_3437(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 12), docFlags);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 80):
	{
		documentRaises__docgen_5273((*d).cache, n);
		genItem__docgen_3437(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 14), docFlags);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84):
	{
		documentRaises__docgen_5273((*d).cache, n);
		genItem__docgen_3437(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 15), docFlags);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 82):
	{
		genItem__docgen_3437(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 17), docFlags);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 83):
	{
		genItem__docgen_3437(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 18), docFlags);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 81):
	{
		documentRaises__docgen_5273((*d).cache, n);
		genItem__docgen_3437(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 16), docFlags);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 98):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 99):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 100):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 101):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA14;
					i = i_2;
					{
						if (!!(((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 125)))) goto LA17_;
						genItem__docgen_3437(d, (*n)._kind_6.sons->data[i], (*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)], (tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw)(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 7) + (NI)((*n).kind - ((NI) 98))), docFlags);
					}
					LA17_: ;
					i_2 += ((NI) 1);
				} LA14: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115):
	{
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3155(n);
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA22;
					i_3 = i_4;
					generateDoc__docgen_5358(d, (*n)._kind_6.sons->data[i_3], orig, ((tyEnum_DocFlags__Q2li9cSVrBaVKtfORTUg5dQ) 0));
					i_4 += ((NI) 1);
				} LA22: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 93):
	{
		{
			NIM_BOOL T26_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T29_;
			T26_ = (NIM_BOOL)0;
			T26_ = checkForFalse__docgen_5116((*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)]);
			if (!!(T26_)) goto LA27_;
			T29_ = NIM_NIL;
			T29_ = lastSon__ast_4833((*n)._kind_6.sons->data[((NI) 0)]);
			generateDoc__docgen_5358(d, T29_, orig, ((tyEnum_DocFlags__Q2li9cSVrBaVKtfORTUg5dQ) 0));
		}
		LA27_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 116):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
			it = NIM_NIL;
			{
				NI i_5;
				NI colontmp__3;
				NI i_6;
				i_5 = (NI)0;
				colontmp__3 = (NI)0;
				colontmp__3 = safeLen__ast_3148(n);
				i_6 = ((NI) 0);
				{
					while (1) {
						if (!(i_6 < colontmp__3)) goto LA34;
						i_5 = i_6;
						it = (*n)._kind_6.sons->data[i_5];
						traceDeps__docgen_5123(d, it);
						i_6 += ((NI) 1);
					} LA34: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 118):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it_2;
			it_2 = NIM_NIL;
			{
				NI i_7;
				NI colontmp__4;
				NI i_8;
				i_7 = (NI)0;
				colontmp__4 = (NI)0;
				colontmp__4 = safeLen__ast_3148(n);
				i_8 = ((NI) 0);
				{
					while (1) {
						if (!(i_8 < colontmp__4)) goto LA39;
						i_7 = i_8;
						it_2 = (*n)._kind_6.sons->data[i_7];
						{
							if (!((*it_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA42_;
							{
								NIM_BOOL T46_;
								T46_ = (NIM_BOOL)0;
								T46_ = !(((*d).module == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
								if (!(T46_)) goto LA47_;
								T46_ = ((*d).module == (*(*it_2)._kind_4.sym).owner);
								LA47_: ;
								if (!T46_) goto LA48_;
								generateDoc__docgen_5358(d, (*(*it_2)._kind_4.sym).ast, orig, ((tyEnum_DocFlags__Q2li9cSVrBaVKtfORTUg5dQ) 1));
							}
							goto LA44_;
							LA48_: ;
							{
								if (!!(((*(*it_2)._kind_4.sym).ast == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA51_;
								exportSym__docgen_5164(d, (*it_2)._kind_4.sym);
							}
							goto LA44_;
							LA51_: ;
							LA44_: ;
						}
						LA42_: ;
						i_8 += ((NI) 1);
					} LA39: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 119):
	{
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 120):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 117):
	{
		traceDeps__docgen_5123(d, (*n)._kind_6.sons->data[((NI) 0)]);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
	{
		tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q* comm;
		comm = NIM_NIL;
		getAllRunnableExamples__docgen_3238(d, n, (&comm));
		{
			NI T58_;
			T58_ = (comm ? comm->Sup.len : 0);
			if (!!((T58_ == ((NI) 0)))) goto LA59_;
			add__docgen_5438((&(*d).modDescPre), (comm) ? (comm->data) : NIM_NIL, (comm ? comm->Sup.len : 0));
		}
		LA59_: ;
	}
	break;
	default:
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(NI, cmpDecimalsIgnoreCase__docgen_136)(NimStringDesc* a, NimStringDesc* b) {
	NI result;
	NI aLen;
	NI bLen;
	NI iA;
	NI iB;
{	result = (NI)0;
	aLen = (a ? a->Sup.len : 0);
	bLen = (b ? b->Sup.len : 0);
	iA = ((NI) 0);
	iB = ((NI) 0);
	{
		while (1) {
			NIM_BOOL T3_;
			T3_ = (NIM_BOOL)0;
			T3_ = (iA < aLen);
			if (!(T3_)) goto LA4_;
			T3_ = (iB < bLen);
			LA4_: ;
			if (!T3_) goto LA2;
			{
				NIM_BOOL T7_;
				NI limitA;
				NI limitB;
				NI pos;
				T7_ = (NIM_BOOL)0;
				T7_ = nsuIsDigitChar(a->data[iA]);
				if (!(T7_)) goto LA8_;
				T7_ = nsuIsDigitChar(b->data[iB]);
				LA8_: ;
				if (!T7_) goto LA9_;
				limitA = iA;
				limitB = iB;
				{
					while (1) {
						NIM_BOOL T13_;
						T13_ = (NIM_BOOL)0;
						T13_ = (limitA < aLen);
						if (!(T13_)) goto LA14_;
						T13_ = nsuIsDigitChar(a->data[limitA]);
						LA14_: ;
						if (!T13_) goto LA12;
						limitA += ((NI) 1);
					} LA12: ;
				}
				{
					while (1) {
						NIM_BOOL T17_;
						T17_ = (NIM_BOOL)0;
						T17_ = (limitB < bLen);
						if (!(T17_)) goto LA18_;
						T17_ = nsuIsDigitChar(b->data[limitB]);
						LA18_: ;
						if (!T17_) goto LA16;
						limitB += ((NI) 1);
					} LA16: ;
				}
				pos = (((NI)(limitA - iA) >= (NI)(limitB - iA)) ? (NI)(limitA - iA) : (NI)(limitB - iA));
				{
					while (1) {
						if (!(((NI) 0) < pos)) goto LA20;
						{
							if (!((NI)(limitA - pos) < iA)) goto LA23_;
							result = (NI)(((NI) 48) - ((NU8)(b->data[(NI)(limitB - pos)])));
						}
						goto LA21_;
						LA23_: ;
						{
							if (!((NI)(limitB - pos) < iB)) goto LA26_;
							result = (NI)(((NU8)(a->data[(NI)(limitA - pos)])) - ((NI) 48));
						}
						goto LA21_;
						LA26_: ;
						{
							result = (NI)(((NU8)(a->data[(NI)(limitA - pos)])) - ((NU8)(b->data[(NI)(limitB - pos)])));
						}
						LA21_: ;
						{
							if (!!((result == ((NI) 0)))) goto LA31_;
							goto BeforeRet_;
						}
						LA31_: ;
						pos -= ((NI) 1);
					} LA20: ;
				}
				result = (NI)((NI)(limitA - iA) - (NI)(limitB - iB));
				{
					if (!!((result == ((NI) 0)))) goto LA35_;
					goto BeforeRet_;
				}
				LA35_: ;
				iA = limitA;
				iB = limitB;
			}
			goto LA5_;
			LA9_: ;
			{
				NIM_CHAR T38_;
				NIM_CHAR T39_;
				T38_ = (NIM_CHAR)0;
				T38_ = nsuToLowerAsciiChar(a->data[iA]);
				T39_ = (NIM_CHAR)0;
				T39_ = nsuToLowerAsciiChar(b->data[iB]);
				result = (NI)(((NU8)(T38_)) - ((NU8)(T39_)));
				{
					if (!!((result == ((NI) 0)))) goto LA42_;
					goto BeforeRet_;
				}
				LA42_: ;
				iA += ((NI) 1);
				iB += ((NI) 1);
			}
			LA5_: ;
		} LA2: ;
	}
	result = (NI)((NI)(aLen - iA) - (NI)(bLen - iB));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, cmp__docgen_5511)(tyObject_Item__T7UjOImKJxoSfGY6SB3KMg x, tyObject_Item__T7UjOImKJxoSfGY6SB3KMg y) {
	NI result;
	result = (NI)0;
	result = cmpDecimalsIgnoreCase__docgen_136(x.sortName, y.sortName);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, renderItemPre__docgen_5493)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q* fragments, NimStringDesc** result) {
	{
		tyObject_ItemFragment__s61pcFD9bQO8uWIzfNjndzg* f;
		NI i;
		NI L;
		NI T2_;
		f = (tyObject_ItemFragment__s61pcFD9bQO8uWIzfNjndzg*)0;
		i = ((NI) 0);
		T2_ = (fragments ? fragments->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				f = (&fragments->data[i]);
				switch ((*f).isRst) {
				case NIM_TRUE:
				{
					tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* resolved;
					resolved = resolveSubs__packagesZdocutilsZrst_6821((*d).sharedState, (*f)._isRst_1.rst);
					renderRstToOut__packagesZdocutilsZrstgen_308(&d->Sup, resolved, result);
				}
				break;
				case NIM_FALSE:
				{
					unsureAsgnRef((void**) (&(*result)), resizeString((*result), ((*f)._isRst_2.str ? (*f)._isRst_2.str->Sup.len : 0) + 0));
appendString((*result), (*f)._isRst_2.str);
				}
				break;
				default:
				{
				}
				break;
				}
				i += ((NI) 1);
			} LA4: ;
		}
	}
}
static N_INLINE(void, X5BX5Deq___pureZjson_1942)(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* obj, NimStringDesc* key, tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* val) {
	X5BX5Deq___pureZjson_306((&(*obj)._kind_6.fields), key, val);
}
N_LIB_PRIVATE N_NIMCALL(void, finishGenerateDoc__docgen_5471)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg** d) {
	tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* firstRst;
	NIM_BOOL T24_;
	genericSeqAssign((&(*(*d)).Sup.filenames.filenameToIdx.data), (*(*(*d)).sharedState).filenames.filenameToIdx.data, (&NTIkeyvaluepairseq__7lEisrXlQEzwtUKW5pzRCw_));
	(*(*d)).Sup.filenames.filenameToIdx.counter = (*(*(*d)).sharedState).filenames.filenameToIdx.counter;
	genericSeqAssign((&(*(*d)).Sup.filenames.idxToFilename), (*(*(*d)).sharedState).filenames.idxToFilename, (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_));
	firstRst = ((tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ*) NIM_NIL);
	{
		tyObject_ItemFragment__s61pcFD9bQO8uWIzfNjndzg* fragment;
		NI i;
		NI L;
		NI T2_;
		fragment = (tyObject_ItemFragment__s61pcFD9bQO8uWIzfNjndzg*)0;
		i = ((NI) 0);
		T2_ = ((*(*d)).modDescPre ? (*(*d)).modDescPre->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				fragment = (&(*(*d)).modDescPre->data[i]);
				{
					if (!(*fragment).isRst) goto LA7_;
					firstRst = (*fragment)._isRst_1.rst;
					goto LA1;
				}
				LA7_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	} LA1: ;
	preparePass2__packagesZdocutilsZrst_6818((*(*d)).sharedState, firstRst);
	{
		tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw k;
		k = (tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw)0;
		{
			tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw v;
			NI res;
			v = (tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw)0;
			res = ((NI) 0);
			{
				while (1) {
					if (!(res <= ((NI) 25))) goto LA12;
					v = ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) (res));
					k = v;
					{
						tyObject_Item__T7UjOImKJxoSfGY6SB3KMg* item;
						tySequence__bLuZlbeJhlfg9axVlmjdJXw* colontmp_;
						tyProc__89bMNSqI54vbXxP9bMMNLCIg T14_;
						NI i_2;
						NI L_2;
						NI T15_;
						item = (tyObject_Item__T7UjOImKJxoSfGY6SB3KMg*)0;
						colontmp_ = NIM_NIL;
						nimZeroMem((void*)(&T14_), sizeof(tyProc__89bMNSqI54vbXxP9bMMNLCIg));
						T14_.ClP_0 = ((TM__iS6Vfak4fKt7fhPmyApRcg_162) (cmp__docgen_5511)); T14_.ClE_0 = NIM_NIL;
						colontmp_ = sorted__docgen_5522(((*(*d)).section[(k)- 0].secItems) ? ((*(*d)).section[(k)- 0].secItems->data) : NIM_NIL, ((*(*d)).section[(k)- 0].secItems ? (*(*d)).section[(k)- 0].secItems->Sup.len : 0), T14_, ((tyEnum_SortOrder__TcYjciSJ3jKUT4ygglumjg) 1));
						i_2 = ((NI) 0);
						T15_ = (colontmp_ ? colontmp_->Sup.len : 0);
						L_2 = T15_;
						{
							while (1) {
								NimStringDesc* itemDesc;
								NimStringDesc* T18_;
								tySequence__sM4lkSb7zS6F7OVMvW9cffQ* T19_;
								NimStringDesc* T20_;
								NimStringDesc* T21_;
								tySequence__sM4lkSb7zS6F7OVMvW9cffQ* T22_;
								NimStringDesc* T23_;
								if (!(i_2 < L_2)) goto LA17;
								item = (&colontmp_->data[i_2]);
								itemDesc = NIM_NIL;
								renderItemPre__docgen_5493((*d), (*item).descRst, (&itemDesc));
								T18_ = NIM_NIL;
								T18_ = getConfigVar__options_4054((*(*d)).conf, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_163), ((NimStringDesc*) NIM_NIL));
								T19_ = NIM_NIL;
								T19_ = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) newSeq((&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_), 2);
								T20_ = NIM_NIL;
								T20_ = T19_->data[0]; T19_->data[0] = copyStringRC1(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_164));
								if (T20_) nimGCunrefNoCycle(T20_);
								T21_ = NIM_NIL;
								T21_ = T19_->data[1]; T19_->data[1] = copyStringRC1(itemDesc);
								if (T21_) nimGCunrefNoCycle(T21_);
								T22_ = NIM_NIL;
								T22_ = amp___docgen_5660((*item).substitutions, T19_);
								T23_ = NIM_NIL;
								T23_ = nsuFormatOpenArray(T18_, (T22_) ? (T22_->data) : NIM_NIL, (T22_ ? T22_->Sup.len : 0));
								asgnRef((void**) (&(*(*d)).section[(k)- 0].finalMarkup), resizeString((*(*d)).section[(k)- 0].finalMarkup, (T23_ ? T23_->Sup.len : 0) + 0));
appendString((*(*d)).section[(k)- 0].finalMarkup, T23_);
								itemDesc = ((NimStringDesc*) NIM_NIL);
								i_2 += ((NI) 1);
							} LA17: ;
						}
					}
					asgnRef((void**) (&(*(*d)).section[(k)- 0].secItems), (tySequence__bLuZlbeJhlfg9axVlmjdJXw*) setLengthSeqV2(((*(*d)).section[(k)- 0].secItems)?&((*(*d)).section[(k)- 0].secItems)->Sup:NIM_NIL, (&NTIseqLitemT__bLuZlbeJhlfg9axVlmjdJXw_), ((NI) 0)));
					res += ((NI) 1);
				} LA12: ;
			}
		}
	}
	renderItemPre__docgen_5493((*d), (*(*d)).modDescPre, (&(*(*d)).modDescFinal));
	asgnRef((void**) (&(*(*d)).modDescPre), (tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q*) setLengthSeqV2(((*(*d)).modDescPre)?&((*(*d)).modDescPre)->Sup:NIM_NIL, (&NTIitempre__JSDKkkE7gMRTYRB9bRZ9bH7Q_), ((NI) 0)));
	T24_ = (NIM_BOOL)0;
	T24_ = (*(*d)).Sup.hasToc;
	if (T24_) goto LA25_;
	T24_ = (*(*(*d)).sharedState).hasToc;
	LA25_: ;
	(*(*d)).Sup.hasToc = T24_;
	{
		NI i_3;
		tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw entry;
		NI i_4;
		NI L_3;
		NI T27_;
		i_3 = (NI)0;
		nimZeroMem((void*)(&entry), sizeof(tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw));
		i_4 = ((NI) 0);
		T27_ = ((*(*d)).jEntriesPre ? (*(*d)).jEntriesPre->Sup.len : 0);
		L_3 = T27_;
		{
			while (1) {
				if (!(i_4 < L_3)) goto LA29;
				i_3 = i_4;
				entry.json = (*(*d)).jEntriesPre->data[i_4].json;
				entry.rst = (*(*d)).jEntriesPre->data[i_4].rst;
				entry.rstField = (*(*d)).jEntriesPre->data[i_4].rstField;
				{
					tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* resolved;
					NimStringDesc* str;
					tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T34_;
					if (!!((entry.rst == ((tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ*) NIM_NIL)))) goto LA32_;
					resolved = resolveSubs__packagesZdocutilsZrst_6821((*(*d)).sharedState, entry.rst);
					str = NIM_NIL;
					renderRstToOut__packagesZdocutilsZrstgen_308(&(*d)->Sup, resolved, (&str));
					T34_ = NIM_NIL;
					T34_ = percent___pureZjson_1809(str);
					X5BX5Deq___pureZjson_1942(entry.json, entry.rstField, T34_);
					asgnRef((void**) (&(*(*d)).jEntriesPre->data[i_3].rst), ((tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ*) NIM_NIL));
				}
				LA32_: ;
				add__pureZjson_241((*(*d)).jEntriesFinal, entry.json);
				i_4 += ((NI) 1);
			} LA29: ;
		}
	}
}
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_31)(NI hcode) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = !((hcode == ((NI) 0)));
	return result;
}
static N_INLINE(NimStringDesc*, findNodeJs__nodejs_2)(void) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = findExe__pureZos_653(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_171), NIM_TRUE, ExeExts__pureZos_652, 1);
	{
		if (!((result ? result->Sup.len : 0) == ((NI) 0))) goto LA3_;
		result = findExe__pureZos_653(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_172), NIM_TRUE, ExeExts__pureZos_652, 1);
	}
	LA3_: ;
	{
		tyObject_IOError__5GCiDuy5Wsuc9an2QZvqgIA* T9_;
		NimStringDesc* T10_;
		if (!((result ? result->Sup.len : 0) == ((NI) 0))) goto LA7_;
		echoBinSafe(TM__iS6Vfak4fKt7fhPmyApRcg_173, 1);
		T9_ = NIM_NIL;
		T9_ = (tyObject_IOError__5GCiDuy5Wsuc9an2QZvqgIA*) newObj((&NTIrefioerror__0NUycR3lTt5ae7Mj01Qw8A_), sizeof(tyObject_IOError__5GCiDuy5Wsuc9an2QZvqgIA));
		(*T9_).Sup.Sup.Sup.m_type = (&NTIioerror__5GCiDuy5Wsuc9an2QZvqgIA_);
		(*T9_).Sup.Sup.name = "IOError";
		T10_ = NIM_NIL;
		T10_ = rawNewString((result ? result->Sup.len : 0) + 26);
appendString(T10_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_175));
appendString(T10_, result);
		asgnRef((void**) (&(*T9_).Sup.Sup.message), T10_);
		asgnRef((void**) (&(*T9_).Sup.Sup.parent), ((Exception*) NIM_NIL));
		raiseExceptionEx((Exception*)T9_, "IOError", "findNodeJs", "nodejs.nim", 10);
	}
	LA7_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, prettyString__docgen_993)(tyObject_ExampleGroupcolonObjectType___bbSjO9aaIauVHOujtpjo3Rw a) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	NimStringDesc* T3_;
	NimStringDesc* T4_;
	NimStringDesc* T5_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = rawNewString((a.rdoccmd ? a.rdoccmd->Sup.len : 0) + 10);
appendString(T1_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_179));
appendString(T1_, a.rdoccmd);
appendString(T1_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_129));
	result = resizeString(result, (T1_ ? T1_->Sup.len : 0) + 0);
appendString(result, T1_);
	T2_ = NIM_NIL;
	T2_ = rawNewString((a.docCmd ? a.docCmd->Sup.len : 0) + 9);
appendString(T2_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_180));
appendString(T2_, a.docCmd);
appendString(T2_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_129));
	result = resizeString(result, (T2_ ? T2_->Sup.len : 0) + 0);
appendString(result, T2_);
	T3_ = NIM_NIL;
	T3_ = rawNewString((a.code ? a.code->Sup.len : 0) + 7);
appendString(T3_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_181));
appendString(T3_, a.code);
appendString(T3_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_129));
	result = resizeString(result, (T3_ ? T3_->Sup.len : 0) + 0);
appendString(result, T3_);
	T4_ = NIM_NIL;
	T5_ = NIM_NIL;
	T5_ = dollar___systemZdollars_3(a.index);
	T4_ = rawNewString((T5_ ? T5_->Sup.len : 0) + 8);
appendString(T4_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_182));
appendString(T4_, T5_);
appendString(T4_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_129));
	result = resizeString(result, (T4_ ? T4_->Sup.len : 0) + 0);
appendString(result, T4_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, runAllExamples__docgen_642)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d) {
	NimStringDesc* outputDir;
	outputDir = exampleOutputDir__docgen_639(d);
	{
		NimStringDesc* _;
		tyObject_ExampleGroupcolonObjectType___bbSjO9aaIauVHOujtpjo3Rw* group;
		NI L;
		_ = NIM_NIL;
		group = NIM_NIL;
		L = len__docgen_693((*d).exampleGroups);
		{
			NI h;
			if (!(((NI) 0) < (*d).exampleGroups.counter)) goto LA4_;
			h = (*d).exampleGroups.first;
			{
				while (1) {
					NI nxt;
					if (!(((NI) 0) <= h)) goto LA7;
					nxt = (*d).exampleGroups.data->data[h].Field1;
					{
						NIM_BOOL T10_;
						T10_ = (NIM_BOOL)0;
						T10_ = isFilled__pureZcollectionsZtables_31((*d).exampleGroups.data->data[h].Field0);
						if (!T10_) goto LA11_;
						_ = (*d).exampleGroups.data->data[h].Field2;
						group = (*d).exampleGroups.data->data[h].Field3;
						{
							NimStringDesc* outp;
							tyArray__Re75IspeoxXy2oCZHwcRrA T18_;
							tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T19_;
							NimStringDesc* T20_;
							tyArray__24KAM9afIUgUaqBaEBB6r9bg T21_;
							NimStringDesc* cmd;
							tyArray__rmMMhDIqORJzUU5zqeitSQ T22_;
							NimStringDesc* T23_;
							{
								if (!eqStrings((*group).docCmd, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_23))) goto LA16_;
								goto LA13;
							}
							LA16_: ;
							nimZeroMem((void*)T18_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
							nimZeroMem((void*)(&T19_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
							nossplitFile((*d).Sup.filename, (&T19_));
							T18_[0] = copyString(T19_.Field1);
							T18_[1] = dollar___systemZdollars_3((*group).index);
							T20_ = NIM_NIL;
							T20_ = nsuFormatOpenArray(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_165), T18_, 2);
							outp = slash___pathutils_90(outputDir, T20_);
							nimZeroMem((void*)T21_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
							T21_[0] = copyString((*d).Sup.filename);
							T21_[1] = copyString((*group).rdoccmd);
							T21_[2] = copyString((*group).code);
							asgnRef((void**) (&(*group).code), nsuFormatOpenArray(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_166), T21_, 3));
							writeFile__systemZio_474(outp, (*group).code);
							nimZeroMem((void*)T22_, sizeof(tyArray__rmMMhDIqORJzUU5zqeitSQ));
							T22_[0] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_34));
							T23_ = NIM_NIL;
							T23_ = nosgetAppFilename();
							T22_[1] = nospquoteShell(T23_);
							T22_[2] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_37));
							T22_[3] = reprEnum((NI)(*(*d).conf).backend, (&NTItbackend__zoooocqvga73vZuhGAAy6A_));
							T22_[4] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_138));
							T22_[5] = nospquoteShell((*(*d).conf).projectPath);
							T22_[6] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_35));
							T22_[7] = nospquoteShell((*(*d).conf).libpath);
							T22_[8] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_168));
							T22_[9] = nospquoteShell(outputDir);
							T22_[10] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_169));
							T22_[11] = nospquoteShell(outp);
							T22_[12] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_170));
							T22_[13] = copyString((*group).rdoccmd);
							T22_[14] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_36));
							T22_[15] = copyString((*group).docCmd);
							cmd = nsuFormatOpenArray(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_167), T22_, 16);
							{
								NIM_BOOL T26_;
								NimStringDesc* T28_;
								T26_ = (NIM_BOOL)0;
								T26_ = ((*(*d).conf).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 3));
								if (!(T26_)) goto LA27_;
								T28_ = NIM_NIL;
								T28_ = findNodeJs__nodejs_2();
								T26_ = ((T28_ ? T28_->Sup.len : 0) == 0);
								LA27_: ;
								if (!T26_) goto LA29_;
							}
							goto LA24_;
							LA29_: ;
							{
								NI T32_;
								T32_ = (NI)0;
								T32_ = nosexecShellCmd(cmd);
								if (!!((T32_ == ((NI) 0)))) goto LA33_;
								{
									NIM_BOOL T37_;
									T37_ = (NIM_BOOL)0;
									T37_ = isDefined__options_2292((*d).conf, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_176));
									if (!T37_) goto LA38_;
									{
										NimStringDesc* T44_;
										tyArray__24KAM9afIUgUaqBaEBB6r9bg T45_;
										NimStringDesc* T46_;
										if (!NIM_TRUE) goto LA42_;
										T44_ = NIM_NIL;
										nimZeroMem((void*)T45_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
										T45_[0] = copyString(outp);
										T45_[1] = prettyString__docgen_993((*group));
										T45_[2] = copyString(cmd);
										T46_ = NIM_NIL;
										T46_ = nsuFormatOpenArray(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_178), T45_, 3);
										T44_ = rawNewString((T46_ ? T46_->Sup.len : 0) + 29);
appendString(T44_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_177));
appendString(T44_, T46_);
										failedAssertImpl__systemZassertions_56(T44_);
									}
									LA42_: ;
								}
								goto LA35_;
								LA38_: ;
								{
									tyArray__24KAM9afIUgUaqBaEBB6r9bg T48_;
									NimStringDesc* T49_;
									nimZeroMem((void*)T48_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
									T48_[0] = copyString(outp);
									T48_[1] = prettyString__docgen_993((*group));
									T48_[2] = copyString(cmd);
									T49_ = NIM_NIL;
									T49_ = nsuFormatOpenArray(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_178), T48_, 3);
									quit__system_7154(T49_, ((NI) 1));
								}
								LA35_: ;
							}
							goto LA24_;
							LA33_: ;
							{
								NimStringDesc* argX60gensym112_;
								NimStringDesc* T51_;
								tyArray__nHXaesL0DJZHyVS07ARPRA T52_;
								NimStringDesc* T53_;
								T51_ = NIM_NIL;
								T51_ = msgKindToString__msgs_782(((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 72));
								nimZeroMem((void*)T52_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
								T53_ = NIM_NIL;
								T53_ = rawNewString((outp ? outp->Sup.len : 0) + 18);
appendString(T53_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_183));
appendString(T53_, outp);
								T52_[0] = T53_;
								argX60gensym112_ = nsuFormatOpenArray(T51_, T52_, 1);
								liMessage__msgs_1128((*d).conf, unknownLineInfo__lineinfos_284, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 72), argX60gensym112_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), TM__iS6Vfak4fKt7fhPmyApRcg_184, NIM_TRUE);
							}
							LA24_: ;
						} LA13: ;
					}
					LA11_: ;
					h = nxt;
				} LA7: ;
			}
		}
		LA4_: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(NI, cmp__docgen_6259)(tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q x, tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q y) {
	NI result;
	result = (NI)0;
	result = cmpDecimalsIgnoreCase__docgen_136(x.sortName, y.sortName);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genSection__docgen_6247)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind, NIM_BOOL groupedToc) {
	NimStringDesc* title;
	NimStringDesc* T5_;
	tyArray__Q6RksR9bl1dCf8jl3HeN9bXg T6_;
	NimStringDesc* T43_;
	tyArray__Q6RksR9bl1dCf8jl3HeN9bXg T44_;
{	{
		if (!(((*d).section[(kind)- 0].finalMarkup ? (*d).section[(kind)- 0].finalMarkup->Sup.len : 0) == 0)) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	title = copyString(sectionNames__docgen_6251[(kind)- 6]);
	T5_ = NIM_NIL;
	T5_ = getConfigVar__options_4054((*d).conf, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_198), ((NimStringDesc*) NIM_NIL));
	nimZeroMem((void*)T6_, sizeof(tyArray__Q6RksR9bl1dCf8jl3HeN9bXg));
	T6_[0] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_199));
	T6_[1] = dollar___systemZdollars_3(kind);
	T6_[2] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_200));
	T6_[3] = copyString(title);
	T6_[4] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_201));
	T6_[5] = dollar___systemZdollars_3((NI)(kind + ((NI) 50)));
	T6_[6] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_202));
	T6_[7] = copyString((*d).section[(kind)- 0].finalMarkup);
	asgnRef((void**) (&(*d).section[(kind)- 0].finalMarkup), nsuFormatOpenArray(T5_, T6_, 8));
	{
		tySequence__sM4lkSb7zS6F7OVMvW9cffQ* overloadableNames;
		tySequence__sM4lkSb7zS6F7OVMvW9cffQ* resultX60gensym377_;
		if (!groupedToc) goto LA9_;
		resultX60gensym377_ = NIM_NIL;
		{
			NimStringDesc** xX60gensym377_;
			tyObject_Table__IzudB87pHlXWFsowpECF3Q colontmp_;
			NI L;
			xX60gensym377_ = (NimStringDesc**)0;
			nimZeroMem((void*)(&colontmp_), sizeof(tyObject_Table__IzudB87pHlXWFsowpECF3Q));
			colontmp_.data = (*d).tocTable[(kind)- 0].data;
			colontmp_.counter = (*d).tocTable[(kind)- 0].counter;
			L = len__docgen_6535(colontmp_);
			{
				NI h;
				NI colontmp__2;
				NI T13_;
				NI res;
				h = (NI)0;
				colontmp__2 = (NI)0;
				T13_ = ((colontmp_.data ? colontmp_.data->Sup.len : 0)-1);
				colontmp__2 = T13_;
				res = ((NI) 0);
				{
					while (1) {
						if (!(res <= colontmp__2)) goto LA15;
						h = res;
						{
							NIM_BOOL T18_;
							NI T21_;
							NimStringDesc* T22_;
							T18_ = (NIM_BOOL)0;
							T18_ = isFilled__pureZcollectionsZtables_31(colontmp_.data->data[h].Field0);
							if (!T18_) goto LA19_;
							xX60gensym377_ = (&colontmp_.data->data[h].Field1);
							resultX60gensym377_ = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)(resultX60gensym377_), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_));
							T21_ = resultX60gensym377_->Sup.len++;
							T22_ = NIM_NIL;
							T22_ = resultX60gensym377_->data[T21_]; resultX60gensym377_->data[T21_] = copyStringRC1((*xX60gensym377_));
							if (T22_) nimGCunrefNoCycle(T22_);
						}
						LA19_: ;
						res += ((NI) 1);
					} LA15: ;
				}
			}
		}
		overloadableNames = resultX60gensym377_;
		{
			NimStringDesc** plainName;
			tySequence__sM4lkSb7zS6F7OVMvW9cffQ* colontmp__3;
			tyProc__3pmh9bG9bLpdxUjFu9cDtbZaA T24_;
			NI i;
			NI L_2;
			NI T25_;
			plainName = (NimStringDesc**)0;
			colontmp__3 = NIM_NIL;
			nimZeroMem((void*)(&T24_), sizeof(tyProc__3pmh9bG9bLpdxUjFu9cDtbZaA));
			T24_.ClP_0 = ((TM__iS6Vfak4fKt7fhPmyApRcg_203) (cmpDecimalsIgnoreCase__docgen_136)); T24_.ClE_0 = NIM_NIL;
			colontmp__3 = sorted__docgen_6719((overloadableNames) ? (overloadableNames->data) : NIM_NIL, (overloadableNames ? overloadableNames->Sup.len : 0), T24_, ((tyEnum_SortOrder__TcYjciSJ3jKUT4ygglumjg) 1));
			i = ((NI) 0);
			T25_ = (colontmp__3 ? colontmp__3->Sup.len : 0);
			L_2 = T25_;
			{
				while (1) {
					tySequence__spLz9azjOgbpYKrtmm9aMHEw* overloadChoices;
					tySequence__spLz9azjOgbpYKrtmm9aMHEw** T28_;
					tyProc__WEtPC7U0dE9c3UXfKGHiYrg T29_;
					NimStringDesc* content;
					NimStringDesc* T34_;
					tyArray__meGd17iD6izZVY5NTv9bHUA T35_;
					NimStringDesc* T36_;
					if (!(i < L_2)) goto LA27;
					plainName = (&colontmp__3->data[i]);
					T28_ = (tySequence__spLz9azjOgbpYKrtmm9aMHEw**)0;
					T28_ = X5BX5D___docgen_6805((&(*d).tocTable[(kind)- 0]), (*plainName));
					genericSeqAssign((&overloadChoices), (*T28_), (&NTIseqLtocitemT__spLz9azjOgbpYKrtmm9aMHEw_));
					nimZeroMem((void*)(&T29_), sizeof(tyProc__WEtPC7U0dE9c3UXfKGHiYrg));
					T29_.ClP_0 = ((TM__iS6Vfak4fKt7fhPmyApRcg_204) (cmp__docgen_6259)); T29_.ClE_0 = NIM_NIL;
					sort__docgen_6878((overloadChoices) ? (overloadChoices->data) : NIM_NIL, (overloadChoices ? overloadChoices->Sup.len : 0), T29_, ((tyEnum_SortOrder__TcYjciSJ3jKUT4ygglumjg) 1));
					content = NIM_NIL;
					{
						tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q* item;
						NI i_2;
						NI L_3;
						NI T31_;
						item = (tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q*)0;
						i_2 = ((NI) 0);
						T31_ = (overloadChoices ? overloadChoices->Sup.len : 0);
						L_3 = T31_;
						{
							while (1) {
								if (!(i_2 < L_3)) goto LA33;
								item = (&overloadChoices->data[i_2]);
								content = resizeString(content, ((*item).content ? (*item).content->Sup.len : 0) + 0);
appendString(content, (*item).content);
								i_2 += ((NI) 1);
							} LA33: ;
						}
					}
					T34_ = NIM_NIL;
					T34_ = getConfigVar__options_4054((*d).conf, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_205), ((NimStringDesc*) NIM_NIL));
					nimZeroMem((void*)T35_, sizeof(tyArray__meGd17iD6izZVY5NTv9bHUA));
					T35_[0] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_199));
					T35_[1] = dollar___systemZdollars_3(kind);
					T35_[2] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_200));
					T35_[3] = copyString(title);
					T35_[4] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_201));
					T35_[5] = dollar___systemZdollars_3((NI)(kind + ((NI) 50)));
					T35_[6] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_202));
					T35_[7] = copyString(content);
					T35_[8] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_206));
					T35_[9] = copyString((*plainName));
					T36_ = NIM_NIL;
					T36_ = nsuFormatOpenArray(T34_, T35_, 10);
					asgnRef((void**) (&(*d).toc2[(kind)- 0]), resizeString((*d).toc2[(kind)- 0], (T36_ ? T36_->Sup.len : 0) + 0));
appendString((*d).toc2[(kind)- 0], T36_);
					i += ((NI) 1);
				} LA27: ;
			}
		}
	}
	goto LA7_;
	LA9_: ;
	{
		{
			tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q* item_2;
			tySequence__spLz9azjOgbpYKrtmm9aMHEw* colontmp__4;
			tyProc__WEtPC7U0dE9c3UXfKGHiYrg T39_;
			NI i_3;
			NI L_4;
			NI T40_;
			item_2 = (tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q*)0;
			colontmp__4 = NIM_NIL;
			nimZeroMem((void*)(&T39_), sizeof(tyProc__WEtPC7U0dE9c3UXfKGHiYrg));
			T39_.ClP_0 = ((TM__iS6Vfak4fKt7fhPmyApRcg_207) (cmp__docgen_6259)); T39_.ClE_0 = NIM_NIL;
			colontmp__4 = sorted__docgen_6984(((*d).tocSimple[(kind)- 0]) ? ((*d).tocSimple[(kind)- 0]->data) : NIM_NIL, ((*d).tocSimple[(kind)- 0] ? (*d).tocSimple[(kind)- 0]->Sup.len : 0), T39_, ((tyEnum_SortOrder__TcYjciSJ3jKUT4ygglumjg) 1));
			i_3 = ((NI) 0);
			T40_ = (colontmp__4 ? colontmp__4->Sup.len : 0);
			L_4 = T40_;
			{
				while (1) {
					if (!(i_3 < L_4)) goto LA42;
					item_2 = (&colontmp__4->data[i_3]);
					asgnRef((void**) (&(*d).toc2[(kind)- 0]), resizeString((*d).toc2[(kind)- 0], ((*item_2).content ? (*item_2).content->Sup.len : 0) + 0));
appendString((*d).toc2[(kind)- 0], (*item_2).content);
					i_3 += ((NI) 1);
				} LA42: ;
			}
		}
	}
	LA7_: ;
	T43_ = NIM_NIL;
	T43_ = getConfigVar__options_4054((*d).conf, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_208), ((NimStringDesc*) NIM_NIL));
	nimZeroMem((void*)T44_, sizeof(tyArray__Q6RksR9bl1dCf8jl3HeN9bXg));
	T44_[0] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_199));
	T44_[1] = dollar___systemZdollars_3(kind);
	T44_[2] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_200));
	T44_[3] = copyString(title);
	T44_[4] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_201));
	T44_[5] = dollar___systemZdollars_3((NI)(kind + ((NI) 50)));
	T44_[6] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_202));
	T44_[7] = copyString((*d).toc2[(kind)- 0]);
	asgnRef((void**) (&(*d).toc[(kind)- 0]), nsuFormatOpenArray(T43_, T44_, 8));
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, relLink__docgen_7086)(NimStringDesc* outDir, NimStringDesc* destFile, NimStringDesc* linkto) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T2_;
	NimStringDesc* T3_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = slash___pathutils_90(outDir, linkto);
	nimZeroMem((void*)(&T2_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	splitFile__pathutils_27(destFile, (&T2_));
	T3_ = NIM_NIL;
	T3_ = relativeTo__pathutils_133(T1_, T2_.Field0, 47);
	result = dollar___docgen_7091(T3_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, genOutFile__docgen_7095)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, NIM_BOOL groupedToc) {
	NimStringDesc* result;
	NimStringDesc* code;
	NimStringDesc* content;
	NimStringDesc* title;
	NI j;
	NimStringDesc* toc;
	NimStringDesc* subtitle;
	NimStringDesc* groupsection;
	NimStringDesc* bodyname;
	NimStringDesc* seeSrc;
	NimStringDesc* T51_;
	tyArray__sNC09at9bGf9bERQNOmgMwXdQ T52_;
	result = NIM_NIL;
	code = NIM_NIL;
	content = NIM_NIL;
	title = ((NimStringDesc*) NIM_NIL);
	j = ((NI) 0);
	toc = ((NimStringDesc*) NIM_NIL);
	renderTocEntries__packagesZdocutilsZrstgen_8135(&d->Sup, (&j), ((NI) 1), (&toc));
	{
		tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw i;
		i = (tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw)0;
		{
			tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw v;
			NI res;
			v = (tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw)0;
			res = ((NI) 0);
			{
				while (1) {
					NIM_BOOL shouldSort;
					NIM_BOOL T5_;
					if (!(res <= ((NI) 25))) goto LA4;
					v = ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) (res));
					i = v;
					T5_ = (NIM_BOOL)0;
					T5_ = ((520192 &((NU32)1<<((NU)(i)&31U)))!=0);
					if (!(T5_)) goto LA6_;
					T5_ = groupedToc;
					LA6_: ;
					shouldSort = T5_;
					genSection__docgen_6247(d, i, shouldSort);
					toc = resizeString(toc, ((*d).toc[(i)- 0] ? (*d).toc[(i)- 0]->Sup.len : 0) + 0);
appendString(toc, (*d).toc[(i)- 0]);
					res += ((NI) 1);
				} LA4: ;
			}
		}
	}
	{
		NIM_BOOL T9_;
		NimStringDesc* T13_;
		tyArray__Re75IspeoxXy2oCZHwcRrA T14_;
		T9_ = (NIM_BOOL)0;
		T9_ = !(((toc ? toc->Sup.len : 0) == 0));
		if (T9_) goto LA10_;
		T9_ = ((*d).Sup.target == ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 1));
		LA10_: ;
		if (!T9_) goto LA11_;
		T13_ = NIM_NIL;
		T13_ = getConfigVar__options_4054((*d).conf, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_209), ((NimStringDesc*) NIM_NIL));
		nimZeroMem((void*)T14_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
		T14_[0] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_202));
		T14_[1] = copyString(toc);
		toc = nsuFormatOpenArray(T13_, T14_, 2);
	}
	LA11_: ;
	{
		tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw i_2;
		i_2 = (tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw)0;
		{
			tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw v_2;
			NI res_2;
			v_2 = (tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw)0;
			res_2 = ((NI) 0);
			{
				while (1) {
					if (!(res_2 <= ((NI) 25))) goto LA18;
					v_2 = ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) (res_2));
					i_2 = v_2;
					code = resizeString(code, ((*d).section[(i_2)- 0].finalMarkup ? (*d).section[(i_2)- 0].finalMarkup->Sup.len : 0) + 0);
appendString(code, (*d).section[(i_2)- 0].finalMarkup);
					res_2 += ((NI) 1);
				} LA18: ;
			}
		}
	}
	{
		NimStringDesc* external;
		NimStringDesc* T23_;
		NimStringDesc* T24_;
		if (!!((((*d).Sup.meta[(((tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ) 1))- 0] ? (*d).Sup.meta[(((tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ) 1))- 0]->Sup.len : 0) == ((NI) 0)))) goto LA21_;
		title = copyString((*d).Sup.meta[(((tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ) 1))- 0]);
		T23_ = NIM_NIL;
		T23_ = presentationPath__docgen_197((*d).conf, (*d).Sup.filename);
		T24_ = NIM_NIL;
		T24_ = noschangeFileExt(T23_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_61));
		external = nativeToUnixPath__stdZprivateZglobs_50(T24_);
		setIndexTerm__packagesZdocutilsZrstgen_353(&d->Sup, external, ((NimStringDesc*) NIM_NIL), title, ((NimStringDesc*) NIM_NIL), ((NimStringDesc*) NIM_NIL));
	}
	goto LA19_;
	LA21_: ;
	{
		title = canonicalImport__options_4661((*d).conf, (*d).Sup.filename);
	}
	LA19_: ;
	title = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, title, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
	subtitle = ((NimStringDesc*) NIM_NIL);
	{
		if (!!((((*d).Sup.meta[(((tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ) 2))- 0] ? (*d).Sup.meta[(((tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ) 2))- 0]->Sup.len : 0) == 0))) goto LA28_;
		{
			NIM_BOOL T32_;
			tyArray__nHXaesL0DJZHyVS07ARPRA T35_;
			T32_ = (NIM_BOOL)0;
			T32_ = isLatexCmd__docgen_349((*d).conf);
			if (!!(T32_)) goto LA33_;
			nimZeroMem((void*)T35_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
			T35_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, (*d).Sup.meta[(((tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ) 2))- 0], ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
			nsuAddf((&subtitle), ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_210), T35_, 1);
		}
		goto LA30_;
		LA33_: ;
		{
			tyArray__nHXaesL0DJZHyVS07ARPRA T37_;
			nimZeroMem((void*)T37_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
			T37_[0] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, (*d).Sup.meta[(((tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ) 2))- 0], ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
			nsuAddf((&subtitle), ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_211), T37_, 1);
		}
		LA30_: ;
	}
	LA28_: ;
	groupsection = getConfigVar__options_4054((*d).conf, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_212), ((NimStringDesc*) NIM_NIL));
	{
		NIM_BOOL T40_;
		NIM_BOOL T41_;
		NIM_BOOL T44_;
		T40_ = (NIM_BOOL)0;
		T41_ = (NIM_BOOL)0;
		T41_ = (*d).Sup.hasToc;
		if (!(T41_)) goto LA42_;
		T41_ = !((*d).isPureRst);
		LA42_: ;
		T40_ = T41_;
		if (!(T40_)) goto LA43_;
		T44_ = (NIM_BOOL)0;
		T44_ = isLatexCmd__docgen_349((*d).conf);
		T40_ = !(T44_);
		LA43_: ;
		if (!T40_) goto LA45_;
		groupsection = setLengthStr(groupsection, ((NI) 0));
		bodyname = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_213));
	}
	goto LA38_;
	LA45_: ;
	{
		if (!(*d).Sup.hasToc) goto LA48_;
		bodyname = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_214));
	}
	goto LA38_;
	LA48_: ;
	{
		bodyname = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_215));
	}
	LA38_: ;
	seeSrc = genSeeSrc__docgen_3426(d, (*d).Sup.filename, ((NI) 1));
	T51_ = NIM_NIL;
	T51_ = getConfigVar__options_4054((*d).conf, bodyname, ((NimStringDesc*) NIM_NIL));
	nimZeroMem((void*)T52_, sizeof(tyArray__sNC09at9bGf9bERQNOmgMwXdQ));
	T52_[0] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_216));
	T52_[1] = copyString(title);
	T52_[2] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_217));
	T52_[3] = copyString(subtitle);
	T52_[4] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_218));
	T52_[5] = copyString(toc);
	T52_[6] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_219));
	T52_[7] = copyString((*d).modDescFinal);
	T52_[8] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_220));
	T52_[9] = getDateStr__options_596();
	T52_[10] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_221));
	T52_[11] = getClockStr__options_604();
	T52_[12] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_202));
	T52_[13] = copyString(code);
	T52_[14] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_152));
	T52_[15] = copyString((*d).modDeprecationMsg);
	T52_[16] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_222));
	T52_[17] = relLink__docgen_7086((*(*d).conf).outDir, (*d).Sup.destFile, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_223));
	T52_[18] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_224));
	T52_[19] = copyString(groupsection);
	T52_[20] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_151));
	T52_[21] = copyString(seeSrc);
	content = nsuFormatOpenArray(T51_, T52_, 22);
	{
		NimStringDesc* T57_;
		tyArray__1XN7mEfyEE3SOJgMTajV2g T58_;
		if (!!((((*(*d).conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 4))&63U)))!=0))) goto LA55_;
		T57_ = NIM_NIL;
		T57_ = getConfigVar__options_4054((*d).conf, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_225), ((NimStringDesc*) NIM_NIL));
		nimZeroMem((void*)T58_, sizeof(tyArray__1XN7mEfyEE3SOJgMTajV2g));
		T58_[0] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_226));
		T58_[1] = relLink__docgen_7086((*(*d).conf).outDir, (*d).Sup.destFile, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_227));
		T58_[2] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_228));
		T58_[3] = relLink__docgen_7086((*(*d).conf).outDir, (*d).Sup.destFile, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_229));
		T58_[4] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_216));
		T58_[5] = copyString(title);
		T58_[6] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_217));
		T58_[7] = copyString(subtitle);
		T58_[8] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_218));
		T58_[9] = copyString(toc);
		T58_[10] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_219));
		T58_[11] = copyString((*d).modDescFinal);
		T58_[12] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_220));
		T58_[13] = getDateStr__options_596();
		T58_[14] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_221));
		T58_[15] = getClockStr__options_604();
		T58_[16] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_202));
		T58_[17] = copyString(content);
		T58_[18] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_230));
		T58_[19] = copyString((*d).Sup.meta[(((tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ) 3))- 0]);
		T58_[20] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_231));
		T58_[21] = esc__packagesZdocutilsZrstgen_249((*d).Sup.target, (*d).Sup.meta[(((tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ) 4))- 0], ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
		T58_[22] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_232));
		T58_[23] = copyString((*d).analytics);
		T58_[24] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_152));
		T58_[25] = copyString((*d).modDeprecationMsg);
		code = nsuFormatOpenArray(T57_, T58_, 26);
	}
	goto LA53_;
	LA55_: ;
	{
		code = copyString(content);
	}
	LA53_: ;
	result = copyString(code);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, updateOutfile__docgen_7149)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, NimStringDesc* outfile) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*d).module == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = (((*(*d).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 14))&63U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			NIM_BOOL T9_;
			T9_ = (NIM_BOOL)0;
			T9_ = isEmpty__options_4084((*(*d).conf).outFile);
			if (!T9_) goto LA10_;
			asgnRef((void**) (&(*(*d).conf).outFile), relativeTo__pathutils_133(outfile, (*(*d).conf).outDir, 47));
			{
				NIM_BOOL T14_;
				tyTuple__UV3llMMYFckfui8YMBuUZA T17_;
				NimStringDesc* T18_;
				T14_ = (NIM_BOOL)0;
				T14_ = nosisAbsolute((*(*d).conf).outFile);
				if (!T14_) goto LA15_;
				nimZeroMem((void*)(&T17_), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
				nossplitPath((*(*d).conf).outFile, (&T17_));
				T18_ = NIM_NIL;
				T18_ = (*(*d).conf).outFile; (*(*d).conf).outFile = copyStringRC1(T17_.Field1);
				if (T18_) nimGCunrefNoCycle(T18_);
			}
			LA15_: ;
		}
		LA10_: ;
	}
	LA5_: ;
}
static N_INLINE(void, pushSafePoint)(TSafePoint* s) {
	(*s).prev = excHandler__system_2565;
	excHandler__system_2565 = s;
}
static N_INLINE(void, popSafePoint)(void) {
	excHandler__system_2565 = (*excHandler__system_2565).prev;
}
static N_INLINE(Exception*, nimBorrowCurrentException)(void) {
	Exception* result;
	result = NIM_NIL;
	result = currException__system_2566;
	return result;
}
static N_INLINE(void, popCurrentException)(void) {
	asgnRef((void**) (&currException__system_2566), (*currException__system_2566).up);
}
N_LIB_PRIVATE N_NIMCALL(void, writeOutput__docgen_7163)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, NIM_BOOL useWarning, NIM_BOOL groupedToc) {
	NimStringDesc* content;
	runAllExamples__docgen_642(d);
	content = genOutFile__docgen_7095(d, groupedToc);
	{
		if (!(((*(*d).conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 24))&63U)))!=0)) goto LA3_;
		write__systemZio_205(stdout, content);
	}
	goto LA1_;
	LA3_: ;
	{
		NimStringDesc* dir;
		tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T6_;
		TSafePoint TM__iS6Vfak4fKt7fhPmyApRcg_233;
		nimZeroMem((void*)(&T6_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
		splitFile__pathutils_27((*d).Sup.destFile, (&T6_));
		dir = T6_.Field0;
		noscreateDir(dir);
		updateOutfile__docgen_7149(d, (*d).Sup.destFile);
		pushSafePoint(&TM__iS6Vfak4fKt7fhPmyApRcg_233);
		TM__iS6Vfak4fKt7fhPmyApRcg_233.status = setjmp(TM__iS6Vfak4fKt7fhPmyApRcg_233.context);
		if (TM__iS6Vfak4fKt7fhPmyApRcg_233.status == 0) {
		writeFile__systemZio_474((*d).Sup.destFile, content);
		popSafePoint();
		}
		else {
			popSafePoint();
			if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIioerror__5GCiDuy5Wsuc9an2QZvqgIA_))) {
				tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ T9_;
				TM__iS6Vfak4fKt7fhPmyApRcg_233.status = 0;
				T9_ = (tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ)0;
				{
					if (!useWarning) goto LA12_;
					T9_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 17);
				}
				goto LA10_;
				LA12_: ;
				{
					T9_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 4);
				}
				LA10_: ;
				liMessage__msgs_1128((*d).conf, unknownLineInfo__lineinfos_284, T9_, (*d).Sup.destFile, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), TM__iS6Vfak4fKt7fhPmyApRcg_234, NIM_FALSE);
				popCurrentException();
			}
		}
		if (TM__iS6Vfak4fKt7fhPmyApRcg_233.status != 0) reraiseException();
		{
			NimStringDesc* nimr;
			NimStringDesc* T19_;
			NimStringDesc* T20_;
			NimStringDesc* T21_;
			NimStringDesc* T22_;
			if (!!((*d).wroteSupportFiles)) goto LA17_;
			T19_ = NIM_NIL;
			T19_ = getPrefixDir__options_4096((*d).conf);
			nimr = dollar___options_4472(T19_);
			T20_ = NIM_NIL;
			T20_ = interp__nimpaths_25(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_235), nimr);
			T21_ = NIM_NIL;
			T21_ = dollar___options_4472((*(*d).conf).outDir);
			T22_ = NIM_NIL;
			T22_ = slash___pureZos_121(T21_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_236));
			noscopyFile(T20_, T22_, 2);
			{
				NimStringDesc* docHackJs2;
				NimStringDesc* T27_;
				NimStringDesc* T28_;
				NimStringDesc* T29_;
				NimStringDesc* T30_;
				if (!(((*(*d).conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 27))&63U)))!=0)) goto LA25_;
				T27_ = NIM_NIL;
				T27_ = nosgetAppFilename();
				docHackJs2 = getDocHacksJs__nimpaths_84(nimr, T27_, NIM_FALSE);
				T28_ = NIM_NIL;
				T28_ = dollar___options_4472((*(*d).conf).outDir);
				T29_ = NIM_NIL;
				T29_ = noslastPathPart(docHackJs2);
				T30_ = NIM_NIL;
				T30_ = slash___pureZos_121(T28_, T29_);
				noscopyFile(docHackJs2, T30_, 2);
			}
			LA25_: ;
			(*d).wroteSupportFiles = NIM_TRUE;
		}
		LA17_: ;
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, generateIndex__docgen_7141)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d) {
	{
		NimStringDesc* dir;
		NimStringDesc* dest;
		NimStringDesc* T5_;
		NimStringDesc* T6_;
		if (!(((*(*d).conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 27))&63U)))!=0)) goto LA3_;
		dir = (*(*d).conf).outDir;
		noscreateDir(dir);
		T5_ = NIM_NIL;
		T5_ = presentationPath__docgen_197((*d).conf, (*d).Sup.filename);
		T6_ = NIM_NIL;
		T6_ = noschangeFileExt(T5_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_237));
		dest = slash___pathutils_90(dir, T6_);
		writeIndexFile__packagesZdocutilsZrstgen_202(&d->Sup, dest);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, commandDoc__docgen_7231)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
	tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d;
{	handleDocOutputOptions__docgen_7225(conf);
	ast = parseFile__syntaxes_217((*conf).projectMainIdx, cache, conf);
	{
		if (!(ast == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	d = newDocumentor__docgen_356((*conf).projectFull, cache, conf, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_61), ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL), NIM_FALSE);
	(*d).Sup.hasToc = NIM_TRUE;
	generateDoc__docgen_5358(d, ast, ast, ((tyEnum_DocFlags__Q2li9cSVrBaVKtfORTUg5dQ) 0));
	finishGenerateDoc__docgen_5471(&d);
	writeOutput__docgen_7163(d, NIM_FALSE, NIM_FALSE);
	generateIndex__docgen_7141(d);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, add__docgen_5794)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw j) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T8_;
		NimStringDesc* T9_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = eqeq___pureZjson_2063(j.json, ((tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*) NIM_NIL));
		T3_ = !(T4_);
		if (T3_) goto LA5_;
		T3_ = !((j.rst == ((tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ*) NIM_NIL)));
		LA5_: ;
		if (!T3_) goto LA6_;
		asgnRef((void**) (&(*d).jEntriesPre), (tySequence__Z0K9aZr9c4ex9ad72Ulcdqy7g*) incrSeqV3((TGenericSeq*)((*d).jEntriesPre), (&NTIseqLjsonitemT__Z0K9aZr9c4ex9ad72Ulcdqy7g_)));
		T8_ = (*d).jEntriesPre->Sup.len++;
		asgnRef((void**) (&(*d).jEntriesPre->data[T8_].json), j.json);
		asgnRef((void**) (&(*d).jEntriesPre->data[T8_].rst), j.rst);
		T9_ = NIM_NIL;
		T9_ = (*d).jEntriesPre->data[T8_].rstField; (*d).jEntriesPre->data[T8_].rstField = copyStringRC1(j.rstField);
		if (T9_) nimGCunrefNoCycle(T9_);
	}
	LA6_: ;
}
static N_INLINE(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, X5BX5D___pureZjson_3062)(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* node, NimStringDesc* name) {
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* result;
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g** T1_;
	result = NIM_NIL;
	T1_ = (tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g**)0;
	T1_ = X5BX5D___pureZjson_2657((&(*node)._kind_6.fields), name);
	result = (*T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genJsonItem__docgen_4917)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nameNode, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw k, tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw* Result) {
	NimStringDesc* name;
	tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* comm;
	tyObject_TSrcGen__FLkIzVI9alYjwMpiriDPTPQ r;
	tyArray__uQuKJ8PXBeys9avtUqAO2FQ T6_;
{	unsureAsgnRef((void**)&(*Result).json, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).rst, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).rstField, NIM_NIL);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isVisible__docgen_3258(d, nameNode);
		if (!!(T3_)) goto LA4_;
		goto BeforeRet_;
	}
	LA4_: ;
	name = getName__docgen_3321(d, nameNode, ((NI) -1));
	comm = genRecComment__docgen_541(d, n);
	nimZeroMem((void*)(&r), sizeof(tyObject_TSrcGen__FLkIzVI9alYjwMpiriDPTPQ));
	initTokRender__renderer_2137((&r), n, 14);
	nimZeroMem((void*)T6_, sizeof(tyArray__uQuKJ8PXBeys9avtUqAO2FQ));
	T6_[0].Field0 = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_142));
	T6_[0].Field1 = percent___pureZjson_1809(name);
	T6_[1].Field0 = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_239));
	T6_[1].Field1 = percent___pureZjson_1809(reprEnum((NI)k, (&NTItsymkind__sjiB9b9aO1FRPetW6gPYZbfw_)));
	T6_[2].Field0 = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_139));
	T6_[2].Field1 = percent___pureZjson_1819(((NI) ((*n).info.line)));
	T6_[3].Field0 = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_240));
	T6_[3].Field1 = percent___pureZjson_1819(((NI) ((*n).info.col)));
	unsureAsgnRef((void**) (&(*Result).json), percent___pureZjson_1838(T6_, 4));
	{
		if (!!((comm == ((tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ*) NIM_NIL)))) goto LA9_;
		unsureAsgnRef((void**) (&(*Result).rst), comm);
		unsureAsgnRef((void**) (&(*Result).rstField), copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_241)));
	}
	LA9_: ;
	{
		tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T15_;
		if (!(((NI) 0) < (r.buf ? r.buf->Sup.len : 0))) goto LA13_;
		T15_ = NIM_NIL;
		T15_ = percent___pureZjson_1809(r.buf);
		X5BX5Deq___pureZjson_1942((*Result).json, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_242), T15_);
	}
	LA13_: ;
	{
		tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T20_;
		if (!((520192 &((NU32)1<<((NU)(k)&31U)))!=0)) goto LA18_;
		T20_ = NIM_NIL;
		T20_ = newJObject__pureZjson_102();
		X5BX5Deq___pureZjson_1942((*Result).json, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_243), T20_);
		{
			tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T25_;
			NimStringDesc* T26_;
			tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T27_;
			if (!!(((*(*(*n)._kind_6.sons->data[((NI) 3)])._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)))) goto LA23_;
			T25_ = NIM_NIL;
			T25_ = X5BX5D___pureZjson_3062((*Result).json, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_243));
			T26_ = NIM_NIL;
			T26_ = dollar___renderer_2116((*(*n)._kind_6.sons->data[((NI) 3)])._kind_6.sons->data[((NI) 0)]);
			T27_ = NIM_NIL;
			T27_ = percent___pureZjson_1809(T26_);
			X5BX5Deq___pureZjson_1942(T25_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_244), T27_);
		}
		LA23_: ;
		{
			NI T30_;
			tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T33_;
			tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T34_;
			T30_ = (NI)0;
			T30_ = len__ast_3155((*n)._kind_6.sons->data[((NI) 3)]);
			if (!(((NI) 1) < T30_)) goto LA31_;
			T33_ = NIM_NIL;
			T33_ = X5BX5D___pureZjson_3062((*Result).json, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_243));
			T34_ = NIM_NIL;
			T34_ = newJArray__pureZjson_133();
			X5BX5Deq___pureZjson_1942(T33_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_245), T34_);
		}
		LA31_: ;
		{
			NI paramIdx;
			NI colontmp_;
			NI i;
			paramIdx = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155((*n)._kind_6.sons->data[((NI) 3)]);
			i = ((NI) 1);
			{
				while (1) {
					if (!(i < colontmp_)) goto LA37;
					paramIdx = i;
					{
						NI identIdx;
						NI colontmp__2;
						NI T39_;
						NI i_2;
						identIdx = (NI)0;
						colontmp__2 = (NI)0;
						T39_ = (NI)0;
						T39_ = len__ast_3155((*(*n)._kind_6.sons->data[((NI) 3)])._kind_6.sons->data[paramIdx]);
						colontmp__2 = (NI)(T39_ - ((NI) 2));
						i_2 = ((NI) 0);
						{
							while (1) {
								NimStringDesc* paramName;
								NimStringDesc* paramType;
								NI T42_;
								if (!(i_2 < colontmp__2)) goto LA41;
								identIdx = i_2;
								paramName = dollar___renderer_2116((*(*(*n)._kind_6.sons->data[((NI) 3)])._kind_6.sons->data[paramIdx])._kind_6.sons->data[identIdx]);
								T42_ = (NI)0;
								T42_ = len__ast_3155((*(*n)._kind_6.sons->data[((NI) 3)])._kind_6.sons->data[paramIdx]);
								paramType = dollar___renderer_2116((*(*(*n)._kind_6.sons->data[((NI) 3)])._kind_6.sons->data[paramIdx])._kind_6.sons->data[(NI)(T42_ - ((NI) 2))]);
								{
									NI T45_;
									NimStringDesc* paramDefault;
									NI T48_;
									tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T49_;
									tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T50_;
									tyArray__gWm1Ak9ah9ayQHjy9cnDizd7A T51_;
									tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T52_;
									T45_ = (NI)0;
									T45_ = len__ast_3155((*(*n)._kind_6.sons->data[((NI) 3)])._kind_6.sons->data[paramIdx]);
									if (!!(((*(*(*(*n)._kind_6.sons->data[((NI) 3)])._kind_6.sons->data[paramIdx])._kind_6.sons->data[(NI)(T45_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)))) goto LA46_;
									T48_ = (NI)0;
									T48_ = len__ast_3155((*(*n)._kind_6.sons->data[((NI) 3)])._kind_6.sons->data[paramIdx]);
									paramDefault = dollar___renderer_2116((*(*(*n)._kind_6.sons->data[((NI) 3)])._kind_6.sons->data[paramIdx])._kind_6.sons->data[(NI)(T48_ - ((NI) 1))]);
									T49_ = NIM_NIL;
									T49_ = X5BX5D___pureZjson_3062((*Result).json, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_243));
									T50_ = NIM_NIL;
									T50_ = X5BX5D___pureZjson_3062(T49_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_245));
									nimZeroMem((void*)T51_, sizeof(tyArray__gWm1Ak9ah9ayQHjy9cnDizd7A));
									T51_[0].Field0 = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_142));
									T51_[0].Field1 = percent___pureZjson_1809(paramName);
									T51_[1].Field0 = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_239));
									T51_[1].Field1 = percent___pureZjson_1809(paramType);
									T51_[2].Field0 = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_246));
									T51_[2].Field1 = percent___pureZjson_1809(paramDefault);
									T52_ = NIM_NIL;
									T52_ = percent___pureZjson_1838(T51_, 3);
									add__pureZjson_241(T50_, T52_);
								}
								goto LA43_;
								LA46_: ;
								{
									tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T54_;
									tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T55_;
									tyArray__A1IDoa8VAZJ9bsqiNGV27SA T56_;
									tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T57_;
									T54_ = NIM_NIL;
									T54_ = X5BX5D___pureZjson_3062((*Result).json, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_243));
									T55_ = NIM_NIL;
									T55_ = X5BX5D___pureZjson_3062(T54_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_245));
									nimZeroMem((void*)T56_, sizeof(tyArray__A1IDoa8VAZJ9bsqiNGV27SA));
									T56_[0].Field0 = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_142));
									T56_[0].Field1 = percent___pureZjson_1809(paramName);
									T56_[1].Field0 = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_239));
									T56_[1].Field1 = percent___pureZjson_1809(paramType);
									T57_ = NIM_NIL;
									T57_ = percent___pureZjson_1838(T56_, 2);
									add__pureZjson_241(T55_, T57_);
								}
								LA43_: ;
								i_2 += ((NI) 1);
							} LA41: ;
						}
					}
					i += ((NI) 1);
				} LA37: ;
			}
		}
		{
			tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T62_;
			tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T63_;
			if (!!(((*(*n)._kind_6.sons->data[((NI) 4)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)))) goto LA60_;
			T62_ = NIM_NIL;
			T62_ = X5BX5D___pureZjson_3062((*Result).json, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_243));
			T63_ = NIM_NIL;
			T63_ = newJArray__pureZjson_133();
			X5BX5Deq___pureZjson_1942(T62_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_247), T63_);
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pragma;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* colontmp__3;
				pragma = NIM_NIL;
				colontmp__3 = NIM_NIL;
				colontmp__3 = (*n)._kind_6.sons->data[((NI) 4)];
				{
					NI i_3;
					NI colontmp__4;
					NI i_4;
					i_3 = (NI)0;
					colontmp__4 = (NI)0;
					colontmp__4 = safeLen__ast_3148(colontmp__3);
					i_4 = ((NI) 0);
					{
						while (1) {
							tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T68_;
							tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T69_;
							NimStringDesc* T70_;
							tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T71_;
							if (!(i_4 < colontmp__4)) goto LA67;
							i_3 = i_4;
							pragma = (*colontmp__3)._kind_6.sons->data[i_3];
							T68_ = NIM_NIL;
							T68_ = X5BX5D___pureZjson_3062((*Result).json, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_243));
							T69_ = NIM_NIL;
							T69_ = X5BX5D___pureZjson_3062(T68_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_247));
							T70_ = NIM_NIL;
							T70_ = dollar___renderer_2116(pragma);
							T71_ = NIM_NIL;
							T71_ = percent___pureZjson_1809(T70_);
							add__pureZjson_241(T69_, T71_);
							i_4 += ((NI) 1);
						} LA67: ;
					}
				}
			}
		}
		LA60_: ;
		{
			tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T76_;
			tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T77_;
			if (!!(((*(*n)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)))) goto LA74_;
			T76_ = NIM_NIL;
			T76_ = X5BX5D___pureZjson_3062((*Result).json, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_243));
			T77_ = NIM_NIL;
			T77_ = newJArray__pureZjson_133();
			X5BX5Deq___pureZjson_1942(T76_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_248), T77_);
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* genericParam;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* colontmp__5;
				genericParam = NIM_NIL;
				colontmp__5 = NIM_NIL;
				colontmp__5 = (*n)._kind_6.sons->data[((NI) 2)];
				{
					NI i_5;
					NI colontmp__6;
					NI i_6;
					i_5 = (NI)0;
					colontmp__6 = (NI)0;
					colontmp__6 = safeLen__ast_3148(colontmp__5);
					i_6 = ((NI) 0);
					{
						while (1) {
							tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* param;
							tyArray__X9cKZd9bnz0tK9cWIyeUfZmZw T82_;
							NimStringDesc* T83_;
							tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T97_;
							tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T98_;
							if (!(i_6 < colontmp__6)) goto LA81;
							i_5 = i_6;
							genericParam = (*colontmp__5)._kind_6.sons->data[i_5];
							nimZeroMem((void*)T82_, sizeof(tyArray__X9cKZd9bnz0tK9cWIyeUfZmZw));
							T82_[0].Field0 = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_142));
							T83_ = NIM_NIL;
							T83_ = dollar___renderer_2116(genericParam);
							T82_[0].Field1 = percent___pureZjson_1809(T83_);
							param = percent___pureZjson_1838(T82_, 1);
							{
								NI T86_;
								tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T89_;
								T86_ = ((*(*(*genericParam)._kind_4.sym).typ).sons ? (*(*(*genericParam)._kind_4.sym).typ).sons->Sup.len : 0);
								if (!(((NI) 0) < T86_)) goto LA87_;
								T89_ = NIM_NIL;
								T89_ = newJArray__pureZjson_133();
								X5BX5Deq___pureZjson_1942(param, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_249), T89_);
							}
							LA87_: ;
							{
								tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA** kind;
								tySequence__vKogasEnJSPhbQmA8r4Y9aA* colontmp__7;
								NI i_7;
								NI L;
								NI T91_;
								kind = (tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA**)0;
								colontmp__7 = NIM_NIL;
								colontmp__7 = (*(*(*genericParam)._kind_4.sym).typ).sons;
								i_7 = ((NI) 0);
								T91_ = (colontmp__7 ? colontmp__7->Sup.len : 0);
								L = T91_;
								{
									while (1) {
										tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T94_;
										NimStringDesc* T95_;
										tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T96_;
										if (!(i_7 < L)) goto LA93;
										kind = &colontmp__7->data[i_7];
										T94_ = NIM_NIL;
										T94_ = X5BX5D___pureZjson_3062(param, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_249));
										T95_ = NIM_NIL;
										T95_ = typeToString__types_50((*kind), ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
										T96_ = NIM_NIL;
										T96_ = percent___pureZjson_1809(T95_);
										add__pureZjson_241(T94_, T96_);
										i_7 += ((NI) 1);
									} LA93: ;
								}
							}
							T97_ = NIM_NIL;
							T97_ = X5BX5D___pureZjson_3062((*Result).json, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_243));
							T98_ = NIM_NIL;
							T98_ = X5BX5D___pureZjson_3062(T97_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_248));
							add__pureZjson_241(T98_, param);
							i_6 += ((NI) 1);
						} LA81: ;
					}
				}
			}
		}
		LA74_: ;
	}
	LA18_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, generateJson__docgen_5805)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL includeComments) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 125):
	{
		{
			tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw T6_;
			tyObject_Table__IARuioJxsgUIwpXiUkOgKg T7_;
			if (!includeComments) goto LA4_;
			nimZeroMem((void*)(&T6_), sizeof(tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw));
			nimZeroMem((void*)(&T6_), sizeof(tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw));
			T6_.rst = genComment__docgen_508(d, n);
			T6_.rstField = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_238));
			nimZeroMem((void*)(&T7_), sizeof(tyObject_Table__IARuioJxsgUIwpXiUkOgKg));
			nimZeroMem((void*)(&T7_), sizeof(tyObject_Table__IARuioJxsgUIwpXiUkOgKg));
			T6_.json = percent___docgen_5835(T7_);
			add__docgen_5794(d, T6_);
		}
		goto LA2_;
		LA4_: ;
		{
			tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* T9_;
			T9_ = NIM_NIL;
			T9_ = genComment__docgen_508(d, n);
			add__docgen_107((&(*d).modDescPre), T9_);
		}
		LA2_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159):
	{
		tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw T11_;
		documentRaises__docgen_5273((*d).cache, n);
		nimZeroMem((void*)(&T11_), sizeof(tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw));
		genJsonItem__docgen_4917(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 12), (&T11_));
		add__docgen_5794(d, T11_);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 80):
	{
		tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw T13_;
		documentRaises__docgen_5273((*d).cache, n);
		nimZeroMem((void*)(&T13_), sizeof(tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw));
		genJsonItem__docgen_4917(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 14), (&T13_));
		add__docgen_5794(d, T13_);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84):
	{
		tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw T15_;
		documentRaises__docgen_5273((*d).cache, n);
		nimZeroMem((void*)(&T15_), sizeof(tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw));
		genJsonItem__docgen_4917(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 15), (&T15_));
		add__docgen_5794(d, T15_);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 82):
	{
		tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw T17_;
		nimZeroMem((void*)(&T17_), sizeof(tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw));
		genJsonItem__docgen_4917(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 17), (&T17_));
		add__docgen_5794(d, T17_);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 83):
	{
		tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw T19_;
		nimZeroMem((void*)(&T19_), sizeof(tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw));
		genJsonItem__docgen_4917(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 18), (&T19_));
		add__docgen_5794(d, T19_);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 81):
	{
		tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw T21_;
		documentRaises__docgen_5273((*d).cache, n);
		nimZeroMem((void*)(&T21_), sizeof(tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw));
		genJsonItem__docgen_4917(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 16), (&T21_));
		add__docgen_5794(d, T21_);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 98):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 99):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 100):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 101):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA25;
					i = i_2;
					{
						tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw T30_;
						if (!!(((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 125)))) goto LA28_;
						nimZeroMem((void*)(&T30_), sizeof(tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw));
						genJsonItem__docgen_4917(d, (*n)._kind_6.sons->data[i], (*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)], (tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw)(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 7) + (NI)((*n).kind - ((NI) 98))), (&T30_));
						add__docgen_5794(d, T30_);
					}
					LA28_: ;
					i_2 += ((NI) 1);
				} LA25: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115):
	{
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3155(n);
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA34;
					i_3 = i_4;
					generateJson__docgen_5805(d, (*n)._kind_6.sons->data[i_3], includeComments);
					i_4 += ((NI) 1);
				} LA34: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 93):
	{
		{
			NIM_BOOL T38_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T41_;
			T38_ = (NIM_BOOL)0;
			T38_ = checkForFalse__docgen_5116((*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)]);
			if (!!(T38_)) goto LA39_;
			T41_ = NIM_NIL;
			T41_ = lastSon__ast_4833((*n)._kind_6.sons->data[((NI) 0)]);
			generateJson__docgen_5805(d, T41_, includeComments);
		}
		LA39_: ;
	}
	break;
	default:
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, writeOutputJson__docgen_7189)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, NIM_BOOL useWarning) {
	NimStringDesc* modDesc;
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* content;
	tyArray__uQuKJ8PXBeys9avtUqAO2FQ T4_;
	NimStringDesc* T5_;
	runAllExamples__docgen_642(d);
	modDesc = NIM_NIL;
	{
		NIM_CHAR desc;
		NI i;
		NI L;
		desc = (NIM_CHAR)0;
		i = ((NI) 0);
		L = ((*d).modDescFinal ? (*d).modDescFinal->Sup.len : 0);
		{
			while (1) {
				if (!(i < L)) goto LA3;
				desc = (*d).modDescFinal->data[i];
				modDesc = addChar(modDesc, desc);
				i += ((NI) 1);
			} LA3: ;
		}
	}
	nimZeroMem((void*)T4_, sizeof(tyArray__uQuKJ8PXBeys9avtUqAO2FQ));
	T4_[0].Field0 = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_250));
	T4_[0].Field1 = percent___pureZjson_1809((*d).Sup.filename);
	T4_[1].Field0 = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_251));
	T5_ = NIM_NIL;
	T5_ = getPackageName__options_4178((*d).conf, (*d).Sup.filename);
	T4_[1].Field1 = percent___pureZjson_1809(T5_);
	T4_[2].Field0 = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_252));
	T4_[2].Field1 = percent___pureZjson_1809(modDesc);
	T4_[3].Field0 = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_253));
	T4_[3].Field1 = (*d).jEntriesFinal;
	content = percent___pureZjson_1838(T4_, 4);
	{
		NimStringDesc* T10_;
		if (!(((*(*d).conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 24))&63U)))!=0)) goto LA8_;
		T10_ = NIM_NIL;
		T10_ = dollar___pureZjson_4484(content);
		write__systemZio_205(stdout, T10_);
	}
	goto LA6_;
	LA8_: ;
	{
		FILE* f;
		f = (FILE*)0;
		{
			NIM_BOOL T14_;
			NimStringDesc* T17_;
			T14_ = (NIM_BOOL)0;
			T14_ = open__systemZio_389(&f, (*d).Sup.destFile, ((tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w) 1), ((NI) -1));
			if (!T14_) goto LA15_;
			T17_ = NIM_NIL;
			T17_ = dollar___pureZjson_4484(content);
			write__systemZio_205(f, T17_);
			close__systemZio_217(f);
			updateOutfile__docgen_7149(d, (*d).Sup.destFile);
		}
		goto LA12_;
		LA15_: ;
		{
			tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw T19_;
			NimStringDesc* T20_;
			T19_ = newLineInfo__msgs_408((*d).conf, (*d).Sup.filename, ((NI) -1), ((NI) -1));
			T20_ = NIM_NIL;
			T20_ = rawNewString(((*d).Sup.destFile ? (*d).Sup.destFile->Sup.len : 0) + 34);
appendString(T20_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_254));
appendString(T20_, (*d).Sup.destFile);
appendString(T20_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_255));
			liMessage__msgs_1128((*d).conf, T19_, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 71), T20_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__iS6Vfak4fKt7fhPmyApRcg_256, NIM_FALSE);
		}
		LA12_: ;
	}
	LA6_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, commandBuildIndex__docgen_7310)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* dir, NimStringDesc* outFile) {
	NimStringDesc* content;
	NimStringDesc* outFile_2;
	NimStringDesc* filename;
	NimStringDesc* code;
	NimStringDesc* T6_;
	tyArray__ebVs7LW9aC16IAZKgIOCAJQ T7_;
	TSafePoint TM__iS6Vfak4fKt7fhPmyApRcg_258;
	content = mergeIndexes__packagesZdocutilsZrstgen_7942(dir);
	outFile_2 = copyString(outFile);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isEmpty__options_4084(outFile_2);
		if (!T3_) goto LA4_;
		outFile_2 = noschangeFileExt(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_223), ((NimStringDesc*) NIM_NIL));
	}
	LA4_: ;
	filename = getOutFile__options_4063(conf, outFile_2, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_61));
	T6_ = NIM_NIL;
	T6_ = getConfigVar__options_4054(conf, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_225), ((NimStringDesc*) NIM_NIL));
	nimZeroMem((void*)T7_, sizeof(tyArray__ebVs7LW9aC16IAZKgIOCAJQ));
	T7_[0] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_226));
	T7_[1] = relLink__docgen_7086((*conf).outDir, filename, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_227));
	T7_[2] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_228));
	T7_[3] = relLink__docgen_7086((*conf).outDir, filename, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_229));
	T7_[4] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_216));
	T7_[5] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_257));
	T7_[6] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_217));
	T7_[7] = ((NimStringDesc*) NIM_NIL);
	T7_[8] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_218));
	T7_[9] = ((NimStringDesc*) NIM_NIL);
	T7_[10] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_219));
	T7_[11] = ((NimStringDesc*) NIM_NIL);
	T7_[12] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_220));
	T7_[13] = getDateStr__options_596();
	T7_[14] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_221));
	T7_[15] = getClockStr__options_604();
	T7_[16] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_202));
	T7_[17] = copyString(content);
	T7_[18] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_230));
	T7_[19] = ((NimStringDesc*) NIM_NIL);
	T7_[20] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_231));
	T7_[21] = ((NimStringDesc*) NIM_NIL);
	T7_[22] = copyString(((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_232));
	T7_[23] = ((NimStringDesc*) NIM_NIL);
	code = nsuFormatOpenArray(T6_, T7_, 24);
	pushSafePoint(&TM__iS6Vfak4fKt7fhPmyApRcg_258);
	TM__iS6Vfak4fKt7fhPmyApRcg_258.status = setjmp(TM__iS6Vfak4fKt7fhPmyApRcg_258.context);
	if (TM__iS6Vfak4fKt7fhPmyApRcg_258.status == 0) {
	writeFile__systemZio_474(filename, code);
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIioerror__5GCiDuy5Wsuc9an2QZvqgIA_))) {
			TM__iS6Vfak4fKt7fhPmyApRcg_258.status = 0;
			liMessage__msgs_1128(conf, unknownLineInfo__lineinfos_284, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 4), filename, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), TM__iS6Vfak4fKt7fhPmyApRcg_259, NIM_FALSE);
			popCurrentException();
		}
	}
	if (TM__iS6Vfak4fKt7fhPmyApRcg_258.status != 0) reraiseException();
}
N_LIB_PRIVATE N_NIMCALL(void, commandRstAux__docgen_7240)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename, NimStringDesc* outExt) {
	NimStringDesc* filen;
	tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d;
	tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* rst;
	NimStringDesc* T1_;
	tyObject_ItemFragment__s61pcFD9bQO8uWIzfNjndzg T2_;
	filen = nosaddFileExt(filename, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_260));
	d = newDocumentor__docgen_356(filen, cache, conf, outExt, ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL), NIM_TRUE);
	T1_ = NIM_NIL;
	T1_ = readFile__systemZio_469(filen);
	rst = parseRst__docgen_310(T1_, filen, ((NI) 1), ((NI) 0), conf, (*d).sharedState);
	if ((*d).modDescPre) { nimGCunrefNoCycle((*d).modDescPre); (*d).modDescPre = NIM_NIL; }
	(*d).modDescPre = (tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q*) newSeqRC1((&NTIitempre__JSDKkkE7gMRTYRB9bRZ9bH7Q_), 1);
	nimZeroMem((void*)(&T2_), sizeof(tyObject_ItemFragment__s61pcFD9bQO8uWIzfNjndzg));
	nimZeroMem((void*)(&T2_), sizeof(tyObject_ItemFragment__s61pcFD9bQO8uWIzfNjndzg));
	T2_.isRst = NIM_TRUE;
	T2_._isRst_1.rst = rst;
	genericShallowAssign((void*)(&(*d).modDescPre->data[0]), (void*)(&T2_), (&NTIitemfragment__s61pcFD9bQO8uWIzfNjndzg_));
	finishGenerateDoc__docgen_5471(&d);
	writeOutput__docgen_7163(d, NIM_FALSE, NIM_FALSE);
	generateIndex__docgen_7141(d);
}
N_LIB_PRIVATE N_NIMCALL(void, commandRst2Html__docgen_7261)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	commandRstAux__docgen_7240(cache, conf, (*conf).projectFull, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_61));
}
N_LIB_PRIVATE N_NIMCALL(void, commandRst2TeX__docgen_7264)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	commandRstAux__docgen_7240(cache, conf, (*conf).projectFull, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_261));
}
static N_NIMCALL(void, Marker_tyRef__X8kkALavbEdzXIrP0m7q2g)(void* p, NI op) {
	tyObject_Env_docgendotnim_commandJson___EkXrf9bj6BppyBV1BtAGatQ* a;
	a = (tyObject_Env_docgendotnim_commandJson___EkXrf9bj6BppyBV1BtAGatQ*)p;
	nimGCvisit((void*)(*a).conf1, op);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___docgen_7276)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, NimStringDesc* filename, NimStringDesc* cmd, NI status, NimStringDesc* content, void* ClE_0) {
	tyObject_Env_docgendotnim_commandJson___EkXrf9bj6BppyBV1BtAGatQ* colonenvP_;
	tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw T1_;
	colonenvP_ = (tyObject_Env_docgendotnim_commandJson___EkXrf9bj6BppyBV1BtAGatQ*) ClE_0;
	T1_ = newLineInfo__msgs_408((*colonenvP_).conf1, (*d).filename, ((NI) -1), ((NI) -1));
	liMessage__msgs_1128((*colonenvP_).conf1, T1_, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 71), ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_263), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__iS6Vfak4fKt7fhPmyApRcg_264, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(void, commandJson__docgen_7267)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	tyObject_Env_docgendotnim_commandJson___EkXrf9bj6BppyBV1BtAGatQ* colonenv_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
	tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d;
	tyProc__bvoZymnzBMzGoI59bjcrthA T5_;
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* json;
	NimStringDesc* content;
{	colonenv_ = NIM_NIL;
	colonenv_ = (tyObject_Env_docgendotnim_commandJson___EkXrf9bj6BppyBV1BtAGatQ*) newObj((&NTIrefobject__X8kkALavbEdzXIrP0m7q2g_), sizeof(tyObject_Env_docgendotnim_commandJson___EkXrf9bj6BppyBV1BtAGatQ));
	(*colonenv_).Sup.m_type = (&NTIobject__EkXrf9bj6BppyBV1BtAGatQ_);
	asgnRef((void**) (&(*colonenv_).conf1), conf);
	ast = parseFile__syntaxes_217((*(*colonenv_).conf1).projectMainIdx, cache, (*colonenv_).conf1);
	{
		if (!(ast == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	d = newDocumentor__docgen_356((*(*colonenv_).conf1).projectFull, cache, (*colonenv_).conf1, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_61), ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL), NIM_FALSE);
	nimZeroMem((void*)(&T5_), sizeof(tyProc__bvoZymnzBMzGoI59bjcrthA));
	T5_.ClP_0 = colonanonymous___docgen_7276; T5_.ClE_0 = colonenv_;
	asgnRef((void**) (&(*d).Sup.onTestSnippet.ClE_0), T5_.ClE_0);
	(*d).Sup.onTestSnippet.ClP_0 = T5_.ClP_0;
	(*d).Sup.hasToc = NIM_TRUE;
	generateJson__docgen_5805(d, ast, NIM_TRUE);
	finishGenerateDoc__docgen_5471(&d);
	json = (*d).jEntriesFinal;
	content = pretty__pureZjson_4480(json, ((NI) 2));
	{
		if (!(((*(*d).conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 24))&63U)))!=0)) goto LA8_;
		write__systemZio_205(stdout, content);
	}
	goto LA6_;
	LA8_: ;
	{
		NimStringDesc* filename;
		TSafePoint TM__iS6Vfak4fKt7fhPmyApRcg_266;
		filename = getOutFile__options_4063((*colonenv_).conf1, (*(*colonenv_).conf1).projectName, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_265));
		pushSafePoint(&TM__iS6Vfak4fKt7fhPmyApRcg_266);
		TM__iS6Vfak4fKt7fhPmyApRcg_266.status = setjmp(TM__iS6Vfak4fKt7fhPmyApRcg_266.context);
		if (TM__iS6Vfak4fKt7fhPmyApRcg_266.status == 0) {
		writeFile__systemZio_474(filename, content);
		popSafePoint();
		}
		else {
			popSafePoint();
			if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIioerror__5GCiDuy5Wsuc9an2QZvqgIA_))) {
				TM__iS6Vfak4fKt7fhPmyApRcg_266.status = 0;
				liMessage__msgs_1128((*colonenv_).conf1, unknownLineInfo__lineinfos_284, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 4), filename, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), TM__iS6Vfak4fKt7fhPmyApRcg_267, NIM_FALSE);
				popCurrentException();
			}
		}
		if (TM__iS6Vfak4fKt7fhPmyApRcg_266.status != 0) reraiseException();
	}
	LA6_: ;
	}BeforeRet_: ;
}
static N_NIMCALL(void, Marker_tyRef__79c3Y3ZwA6fl2mb7ydHMpdg)(void* p, NI op) {
	tyObject_Env_docgendotnim_commandTags___SuJtoUSREUHobzyvPNB0bA* a;
	a = (tyObject_Env_docgendotnim_commandTags___SuJtoUSREUHobzyvPNB0bA*)p;
	nimGCvisit((void*)(*a).conf1, op);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___docgen_7298)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, NimStringDesc* filename, NimStringDesc* cmd, NI status, NimStringDesc* content, void* ClE_0) {
	tyObject_Env_docgendotnim_commandTags___SuJtoUSREUHobzyvPNB0bA* colonenvP_;
	tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw T1_;
	colonenvP_ = (tyObject_Env_docgendotnim_commandTags___SuJtoUSREUHobzyvPNB0bA*) ClE_0;
	T1_ = newLineInfo__msgs_408((*colonenvP_).conf1, (*d).filename, ((NI) -1), ((NI) -1));
	liMessage__msgs_1128((*colonenvP_).conf1, T1_, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 71), ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_263), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__iS6Vfak4fKt7fhPmyApRcg_269, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, genTagsItem__docgen_6188)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nameNode, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw k) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T2_ = NIM_NIL;
	T2_ = getName__docgen_3321(d, nameNode, ((NI) -1));
	T1_ = rawNewString((T2_ ? T2_->Sup.len : 0) + 1);
appendString(T1_, T2_);
appendString(T1_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_129));
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, generateTags__docgen_6194)(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NimStringDesc** r) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 125):
	{
		{
			NimStringDesc* T4_;
			NIM_BOOL T5_;
			NimStringDesc* stripped;
			NimStringDesc* T8_;
			NimStringDesc* T9_;
			T4_ = NIM_NIL;
			T4_ = comment__ast_997(n);
			T5_ = (NIM_BOOL)0;
			T5_ = nsuStartsWith(T4_, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_74));
			if (!T5_) goto LA6_;
			T8_ = NIM_NIL;
			T8_ = comment__ast_997(n);
			T9_ = NIM_NIL;
			T9_ = substr__system_7736(T8_, ((NI) 2));
			stripped = nsuStrip(T9_, NIM_TRUE, NIM_TRUE, TM__iS6Vfak4fKt7fhPmyApRcg_101);
			unsureAsgnRef((void**) (&(*r)), resizeString((*r), (stripped ? stripped->Sup.len : 0) + 0));
appendString((*r), stripped);
		}
		LA6_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79):
	{
		NimStringDesc* T11_;
		documentRaises__docgen_5273((*d).cache, n);
		T11_ = NIM_NIL;
		T11_ = genTagsItem__docgen_6188(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 12));
		unsureAsgnRef((void**) (&(*r)), resizeString((*r), (T11_ ? T11_->Sup.len : 0) + 0));
appendString((*r), T11_);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159):
	{
		NimStringDesc* T13_;
		documentRaises__docgen_5273((*d).cache, n);
		T13_ = NIM_NIL;
		T13_ = genTagsItem__docgen_6188(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 13));
		unsureAsgnRef((void**) (&(*r)), resizeString((*r), (T13_ ? T13_->Sup.len : 0) + 0));
appendString((*r), T13_);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 80):
	{
		NimStringDesc* T15_;
		documentRaises__docgen_5273((*d).cache, n);
		T15_ = NIM_NIL;
		T15_ = genTagsItem__docgen_6188(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 14));
		unsureAsgnRef((void**) (&(*r)), resizeString((*r), (T15_ ? T15_->Sup.len : 0) + 0));
appendString((*r), T15_);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84):
	{
		NimStringDesc* T17_;
		documentRaises__docgen_5273((*d).cache, n);
		T17_ = NIM_NIL;
		T17_ = genTagsItem__docgen_6188(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 15));
		unsureAsgnRef((void**) (&(*r)), resizeString((*r), (T17_ ? T17_->Sup.len : 0) + 0));
appendString((*r), T17_);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 82):
	{
		NimStringDesc* T19_;
		T19_ = NIM_NIL;
		T19_ = genTagsItem__docgen_6188(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 17));
		unsureAsgnRef((void**) (&(*r)), resizeString((*r), (T19_ ? T19_->Sup.len : 0) + 0));
appendString((*r), T19_);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 83):
	{
		NimStringDesc* T21_;
		T21_ = NIM_NIL;
		T21_ = genTagsItem__docgen_6188(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 18));
		unsureAsgnRef((void**) (&(*r)), resizeString((*r), (T21_ ? T21_->Sup.len : 0) + 0));
appendString((*r), T21_);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 81):
	{
		NimStringDesc* T23_;
		documentRaises__docgen_5273((*d).cache, n);
		T23_ = NIM_NIL;
		T23_ = genTagsItem__docgen_6188(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 16));
		unsureAsgnRef((void**) (&(*r)), resizeString((*r), (T23_ ? T23_->Sup.len : 0) + 0));
appendString((*r), T23_);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 98):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 99):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 100):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 101):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA27;
					i = i_2;
					{
						NimStringDesc* T32_;
						if (!!(((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 125)))) goto LA30_;
						T32_ = NIM_NIL;
						T32_ = genTagsItem__docgen_6188(d, (*n)._kind_6.sons->data[i], (*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)], (tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw)(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 7) + (NI)((*n).kind - ((NI) 98))));
						unsureAsgnRef((void**) (&(*r)), resizeString((*r), (T32_ ? T32_->Sup.len : 0) + 0));
appendString((*r), T32_);
					}
					LA30_: ;
					i_2 += ((NI) 1);
				} LA27: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115):
	{
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3155(n);
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA36;
					i_3 = i_4;
					generateTags__docgen_6194(d, (*n)._kind_6.sons->data[i_3], r);
					i_4 += ((NI) 1);
				} LA36: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 93):
	{
		{
			NIM_BOOL T40_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T43_;
			T40_ = (NIM_BOOL)0;
			T40_ = checkForFalse__docgen_5116((*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)]);
			if (!!(T40_)) goto LA41_;
			T43_ = NIM_NIL;
			T43_ = lastSon__ast_4833((*n)._kind_6.sons->data[((NI) 0)]);
			generateTags__docgen_6194(d, T43_, r);
		}
		LA41_: ;
	}
	break;
	default:
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, commandTags__docgen_7289)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	tyObject_Env_docgendotnim_commandTags___SuJtoUSREUHobzyvPNB0bA* colonenv_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
	tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg* d;
	tyProc__bvoZymnzBMzGoI59bjcrthA T5_;
	NimStringDesc* content;
{	colonenv_ = NIM_NIL;
	colonenv_ = (tyObject_Env_docgendotnim_commandTags___SuJtoUSREUHobzyvPNB0bA*) newObj((&NTIrefobject__79c3Y3ZwA6fl2mb7ydHMpdg_), sizeof(tyObject_Env_docgendotnim_commandTags___SuJtoUSREUHobzyvPNB0bA));
	(*colonenv_).Sup.m_type = (&NTIobject__SuJtoUSREUHobzyvPNB0bA_);
	asgnRef((void**) (&(*colonenv_).conf1), conf);
	ast = parseFile__syntaxes_217((*(*colonenv_).conf1).projectMainIdx, cache, (*colonenv_).conf1);
	{
		if (!(ast == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	d = newDocumentor__docgen_356((*(*colonenv_).conf1).projectFull, cache, (*colonenv_).conf1, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_61), ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL), NIM_FALSE);
	nimZeroMem((void*)(&T5_), sizeof(tyProc__bvoZymnzBMzGoI59bjcrthA));
	T5_.ClP_0 = colonanonymous___docgen_7298; T5_.ClE_0 = colonenv_;
	asgnRef((void**) (&(*d).Sup.onTestSnippet.ClE_0), T5_.ClE_0);
	(*d).Sup.onTestSnippet.ClP_0 = T5_.ClP_0;
	(*d).Sup.hasToc = NIM_TRUE;
	content = ((NimStringDesc*) NIM_NIL);
	generateTags__docgen_6194(d, ast, (&content));
	{
		if (!(((*(*d).conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 24))&63U)))!=0)) goto LA8_;
		write__systemZio_205(stdout, content);
	}
	goto LA6_;
	LA8_: ;
	{
		NimStringDesc* filename;
		TSafePoint TM__iS6Vfak4fKt7fhPmyApRcg_271;
		filename = getOutFile__options_4063((*colonenv_).conf1, (*(*colonenv_).conf1).projectName, ((NimStringDesc*) &TM__iS6Vfak4fKt7fhPmyApRcg_270));
		pushSafePoint(&TM__iS6Vfak4fKt7fhPmyApRcg_271);
		TM__iS6Vfak4fKt7fhPmyApRcg_271.status = setjmp(TM__iS6Vfak4fKt7fhPmyApRcg_271.context);
		if (TM__iS6Vfak4fKt7fhPmyApRcg_271.status == 0) {
		writeFile__systemZio_474(filename, content);
		popSafePoint();
		}
		else {
			popSafePoint();
			if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIioerror__5GCiDuy5Wsuc9an2QZvqgIA_))) {
				TM__iS6Vfak4fKt7fhPmyApRcg_271.status = 0;
				liMessage__msgs_1128((*colonenv_).conf1, unknownLineInfo__lineinfos_284, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 4), filename, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), TM__iS6Vfak4fKt7fhPmyApRcg_272, NIM_FALSE);
				popCurrentException();
			}
		}
		if (TM__iS6Vfak4fKt7fhPmyApRcg_271.status != 0) reraiseException();
	}
	LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, atmdocgendotnim_DatInit000)(void) {
static TNimNode* TM__iS6Vfak4fKt7fhPmyApRcg_2_2[2];
static TNimNode* TM__iS6Vfak4fKt7fhPmyApRcg_3_24[24];
static TNimNode* TM__iS6Vfak4fKt7fhPmyApRcg_4_2[2];
static TNimNode* TM__iS6Vfak4fKt7fhPmyApRcg_5_3[3];
static TNimNode* TM__iS6Vfak4fKt7fhPmyApRcg_6_2[2];
static TNimNode* TM__iS6Vfak4fKt7fhPmyApRcg_7_2[2];
static TNimNode* TM__iS6Vfak4fKt7fhPmyApRcg_8_3[3];
static TNimNode* TM__iS6Vfak4fKt7fhPmyApRcg_9_3[3];
static TNimNode* TM__iS6Vfak4fKt7fhPmyApRcg_10_4[4];
static TNimNode* TM__iS6Vfak4fKt7fhPmyApRcg_11_4[4];
static TNimNode* TM__iS6Vfak4fKt7fhPmyApRcg_12_4[4];
static TNimNode* TM__iS6Vfak4fKt7fhPmyApRcg_22_3[3];
static TNimNode* TM__iS6Vfak4fKt7fhPmyApRcg_43_3[3];
static TNimNode* TM__iS6Vfak4fKt7fhPmyApRcg_262_2[2];
static TNimNode* TM__iS6Vfak4fKt7fhPmyApRcg_268_2[2];
static TNimNode TM__iS6Vfak4fKt7fhPmyApRcg_0[81];
NTIobject__l319aWpTxh3BHYVEmIhN02w_.size = sizeof(tyObject_Env_docgendotnim_newDocumentor___l319aWpTxh3BHYVEmIhN02w);
NTIobject__l319aWpTxh3BHYVEmIhN02w_.align = NIM_ALIGNOF(tyObject_Env_docgendotnim_newDocumentor___l319aWpTxh3BHYVEmIhN02w);
NTIobject__l319aWpTxh3BHYVEmIhN02w_.kind = 17;
NTIobject__l319aWpTxh3BHYVEmIhN02w_.base = (&NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_);
TM__iS6Vfak4fKt7fhPmyApRcg_2_2[0] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[1];
TM__iS6Vfak4fKt7fhPmyApRcg_0[1].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[1].offset = offsetof(tyObject_Env_docgendotnim_newDocumentor___l319aWpTxh3BHYVEmIhN02w, colonstate_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[1].typ = (&NTIint__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[1].name = ":state";
TM__iS6Vfak4fKt7fhPmyApRcg_2_2[1] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[2];
TM__iS6Vfak4fKt7fhPmyApRcg_0[2].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[2].offset = offsetof(tyObject_Env_docgendotnim_newDocumentor___l319aWpTxh3BHYVEmIhN02w, conf1);
TM__iS6Vfak4fKt7fhPmyApRcg_0[2].typ = (&NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[2].name = "conf1";
TM__iS6Vfak4fKt7fhPmyApRcg_0[0].len = 2; TM__iS6Vfak4fKt7fhPmyApRcg_0[0].kind = 2; TM__iS6Vfak4fKt7fhPmyApRcg_0[0].sons = &TM__iS6Vfak4fKt7fhPmyApRcg_2_2[0];
NTIobject__l319aWpTxh3BHYVEmIhN02w_.node = &TM__iS6Vfak4fKt7fhPmyApRcg_0[0];
NTIrefobject__QkCnC3fwblDHMj9b4OGf6Nw_.size = sizeof(tyObject_Env_docgendotnim_newDocumentor___l319aWpTxh3BHYVEmIhN02w*);
NTIrefobject__QkCnC3fwblDHMj9b4OGf6Nw_.align = NIM_ALIGNOF(tyObject_Env_docgendotnim_newDocumentor___l319aWpTxh3BHYVEmIhN02w*);
NTIrefobject__QkCnC3fwblDHMj9b4OGf6Nw_.kind = 22;
NTIrefobject__QkCnC3fwblDHMj9b4OGf6Nw_.base = (&NTIobject__l319aWpTxh3BHYVEmIhN02w_);
NTIrefobject__QkCnC3fwblDHMj9b4OGf6Nw_.marker = Marker_tyRef__QkCnC3fwblDHMj9b4OGf6Nw;
NTItdocumentor__bjDxkrkDk9c19abCetktG5Qg_.size = sizeof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg);
NTItdocumentor__bjDxkrkDk9c19abCetktG5Qg_.align = NIM_ALIGNOF(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg);
NTItdocumentor__bjDxkrkDk9c19abCetktG5Qg_.kind = 17;
NTItdocumentor__bjDxkrkDk9c19abCetktG5Qg_.base = (&NTIrstgenerator__qr285fchxFL31hqgMYpbNQ_);
TM__iS6Vfak4fKt7fhPmyApRcg_3_24[0] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[4];
NTIitemfragment__s61pcFD9bQO8uWIzfNjndzg_.size = sizeof(tyObject_ItemFragment__s61pcFD9bQO8uWIzfNjndzg);
NTIitemfragment__s61pcFD9bQO8uWIzfNjndzg_.align = NIM_ALIGNOF(tyObject_ItemFragment__s61pcFD9bQO8uWIzfNjndzg);
NTIitemfragment__s61pcFD9bQO8uWIzfNjndzg_.kind = 18;
NTIitemfragment__s61pcFD9bQO8uWIzfNjndzg_.base = 0;
NTIitemfragment__s61pcFD9bQO8uWIzfNjndzg_.flags = 2;
TM__iS6Vfak4fKt7fhPmyApRcg_0[5].kind = 3;
TM__iS6Vfak4fKt7fhPmyApRcg_0[5].offset = offsetof(tyObject_ItemFragment__s61pcFD9bQO8uWIzfNjndzg, isRst);
TM__iS6Vfak4fKt7fhPmyApRcg_0[5].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[5].name = "isRst";
TM__iS6Vfak4fKt7fhPmyApRcg_0[5].sons = &NimDT___s61pcFD9bQO8uWIzfNjndzg_isRst[0];
TM__iS6Vfak4fKt7fhPmyApRcg_0[5].len = 2;
TM__iS6Vfak4fKt7fhPmyApRcg_0[6].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[6].offset = offsetof(tyObject_ItemFragment__s61pcFD9bQO8uWIzfNjndzg, _isRst_1.rst);
TM__iS6Vfak4fKt7fhPmyApRcg_0[6].typ = (&NTIprstnode__yfV9aZUcV0SioJcvRrGyZlg_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[6].name = "rst";
NimDT___s61pcFD9bQO8uWIzfNjndzg_isRst[1] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[6];
TM__iS6Vfak4fKt7fhPmyApRcg_0[7].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[7].offset = offsetof(tyObject_ItemFragment__s61pcFD9bQO8uWIzfNjndzg, _isRst_2.str);
TM__iS6Vfak4fKt7fhPmyApRcg_0[7].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[7].name = "str";
NimDT___s61pcFD9bQO8uWIzfNjndzg_isRst[0] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[7];
NTIitemfragment__s61pcFD9bQO8uWIzfNjndzg_.node = &TM__iS6Vfak4fKt7fhPmyApRcg_0[5];
NTIitempre__JSDKkkE7gMRTYRB9bRZ9bH7Q_.size = sizeof(tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q*);
NTIitempre__JSDKkkE7gMRTYRB9bRZ9bH7Q_.align = NIM_ALIGNOF(tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q*);
NTIitempre__JSDKkkE7gMRTYRB9bRZ9bH7Q_.kind = 24;
NTIitempre__JSDKkkE7gMRTYRB9bRZ9bH7Q_.base = (&NTIitemfragment__s61pcFD9bQO8uWIzfNjndzg_);
NTIitempre__JSDKkkE7gMRTYRB9bRZ9bH7Q_.flags = 2;
NTIitempre__JSDKkkE7gMRTYRB9bRZ9bH7Q_.marker = Marker_tySequence__JSDKkkE7gMRTYRB9bRZ9bH7Q;
TM__iS6Vfak4fKt7fhPmyApRcg_0[4].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[4].offset = offsetof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg, modDescPre);
TM__iS6Vfak4fKt7fhPmyApRcg_0[4].typ = (&NTIitempre__JSDKkkE7gMRTYRB9bRZ9bH7Q_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[4].name = "modDescPre";
TM__iS6Vfak4fKt7fhPmyApRcg_3_24[1] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[8];
TM__iS6Vfak4fKt7fhPmyApRcg_0[8].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[8].offset = offsetof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg, modDescFinal);
TM__iS6Vfak4fKt7fhPmyApRcg_0[8].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[8].name = "modDescFinal";
TM__iS6Vfak4fKt7fhPmyApRcg_3_24[2] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[9];
TM__iS6Vfak4fKt7fhPmyApRcg_0[9].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[9].offset = offsetof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg, module);
TM__iS6Vfak4fKt7fhPmyApRcg_0[9].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[9].name = "module";
TM__iS6Vfak4fKt7fhPmyApRcg_3_24[3] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[10];
TM__iS6Vfak4fKt7fhPmyApRcg_0[10].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[10].offset = offsetof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg, modDeprecationMsg);
TM__iS6Vfak4fKt7fhPmyApRcg_0[10].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[10].name = "modDeprecationMsg";
TM__iS6Vfak4fKt7fhPmyApRcg_3_24[4] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[11];
NTImodsection__HB5R2AMUpdfd7aJdlibDhA_.size = sizeof(tyObject_ModSection__HB5R2AMUpdfd7aJdlibDhA);
NTImodsection__HB5R2AMUpdfd7aJdlibDhA_.align = NIM_ALIGNOF(tyObject_ModSection__HB5R2AMUpdfd7aJdlibDhA);
NTImodsection__HB5R2AMUpdfd7aJdlibDhA_.kind = 18;
NTImodsection__HB5R2AMUpdfd7aJdlibDhA_.base = 0;
NTImodsection__HB5R2AMUpdfd7aJdlibDhA_.flags = 2;
TM__iS6Vfak4fKt7fhPmyApRcg_4_2[0] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[13];
NTIitem__T7UjOImKJxoSfGY6SB3KMg_.size = sizeof(tyObject_Item__T7UjOImKJxoSfGY6SB3KMg);
NTIitem__T7UjOImKJxoSfGY6SB3KMg_.align = NIM_ALIGNOF(tyObject_Item__T7UjOImKJxoSfGY6SB3KMg);
NTIitem__T7UjOImKJxoSfGY6SB3KMg_.kind = 18;
NTIitem__T7UjOImKJxoSfGY6SB3KMg_.base = 0;
NTIitem__T7UjOImKJxoSfGY6SB3KMg_.flags = 2;
TM__iS6Vfak4fKt7fhPmyApRcg_5_3[0] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[15];
TM__iS6Vfak4fKt7fhPmyApRcg_0[15].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[15].offset = offsetof(tyObject_Item__T7UjOImKJxoSfGY6SB3KMg, descRst);
TM__iS6Vfak4fKt7fhPmyApRcg_0[15].typ = (&NTIitempre__JSDKkkE7gMRTYRB9bRZ9bH7Q_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[15].name = "descRst";
TM__iS6Vfak4fKt7fhPmyApRcg_5_3[1] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[16];
TM__iS6Vfak4fKt7fhPmyApRcg_0[16].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[16].offset = offsetof(tyObject_Item__T7UjOImKJxoSfGY6SB3KMg, substitutions);
TM__iS6Vfak4fKt7fhPmyApRcg_0[16].typ = (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[16].name = "substitutions";
TM__iS6Vfak4fKt7fhPmyApRcg_5_3[2] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[17];
TM__iS6Vfak4fKt7fhPmyApRcg_0[17].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[17].offset = offsetof(tyObject_Item__T7UjOImKJxoSfGY6SB3KMg, sortName);
TM__iS6Vfak4fKt7fhPmyApRcg_0[17].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[17].name = "sortName";
TM__iS6Vfak4fKt7fhPmyApRcg_0[14].len = 3; TM__iS6Vfak4fKt7fhPmyApRcg_0[14].kind = 2; TM__iS6Vfak4fKt7fhPmyApRcg_0[14].sons = &TM__iS6Vfak4fKt7fhPmyApRcg_5_3[0];
NTIitem__T7UjOImKJxoSfGY6SB3KMg_.node = &TM__iS6Vfak4fKt7fhPmyApRcg_0[14];
NTIseqLitemT__bLuZlbeJhlfg9axVlmjdJXw_.size = sizeof(tySequence__bLuZlbeJhlfg9axVlmjdJXw*);
NTIseqLitemT__bLuZlbeJhlfg9axVlmjdJXw_.align = NIM_ALIGNOF(tySequence__bLuZlbeJhlfg9axVlmjdJXw*);
NTIseqLitemT__bLuZlbeJhlfg9axVlmjdJXw_.kind = 24;
NTIseqLitemT__bLuZlbeJhlfg9axVlmjdJXw_.base = (&NTIitem__T7UjOImKJxoSfGY6SB3KMg_);
NTIseqLitemT__bLuZlbeJhlfg9axVlmjdJXw_.flags = 2;
NTIseqLitemT__bLuZlbeJhlfg9axVlmjdJXw_.marker = Marker_tySequence__bLuZlbeJhlfg9axVlmjdJXw;
TM__iS6Vfak4fKt7fhPmyApRcg_0[13].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[13].offset = offsetof(tyObject_ModSection__HB5R2AMUpdfd7aJdlibDhA, secItems);
TM__iS6Vfak4fKt7fhPmyApRcg_0[13].typ = (&NTIseqLitemT__bLuZlbeJhlfg9axVlmjdJXw_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[13].name = "secItems";
TM__iS6Vfak4fKt7fhPmyApRcg_4_2[1] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[18];
TM__iS6Vfak4fKt7fhPmyApRcg_0[18].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[18].offset = offsetof(tyObject_ModSection__HB5R2AMUpdfd7aJdlibDhA, finalMarkup);
TM__iS6Vfak4fKt7fhPmyApRcg_0[18].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[18].name = "finalMarkup";
TM__iS6Vfak4fKt7fhPmyApRcg_0[12].len = 2; TM__iS6Vfak4fKt7fhPmyApRcg_0[12].kind = 2; TM__iS6Vfak4fKt7fhPmyApRcg_0[12].sons = &TM__iS6Vfak4fKt7fhPmyApRcg_4_2[0];
NTImodsection__HB5R2AMUpdfd7aJdlibDhA_.node = &TM__iS6Vfak4fKt7fhPmyApRcg_0[12];
NTImodsections__qOSeyO8oLD0KPByNUUqROQ_.size = sizeof(tyArray__qOSeyO8oLD0KPByNUUqROQ);
NTImodsections__qOSeyO8oLD0KPByNUUqROQ_.align = NIM_ALIGNOF(tyArray__qOSeyO8oLD0KPByNUUqROQ);
NTImodsections__qOSeyO8oLD0KPByNUUqROQ_.kind = 16;
NTImodsections__qOSeyO8oLD0KPByNUUqROQ_.base = (&NTImodsection__HB5R2AMUpdfd7aJdlibDhA_);
NTImodsections__qOSeyO8oLD0KPByNUUqROQ_.flags = 2;
TM__iS6Vfak4fKt7fhPmyApRcg_0[11].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[11].offset = offsetof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg, section);
TM__iS6Vfak4fKt7fhPmyApRcg_0[11].typ = (&NTImodsections__qOSeyO8oLD0KPByNUUqROQ_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[11].name = "section";
TM__iS6Vfak4fKt7fhPmyApRcg_3_24[5] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[19];
NTItocitem__f5Z7HAch49an2qSNSGguP7Q_.size = sizeof(tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q);
NTItocitem__f5Z7HAch49an2qSNSGguP7Q_.align = NIM_ALIGNOF(tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q);
NTItocitem__f5Z7HAch49an2qSNSGguP7Q_.kind = 18;
NTItocitem__f5Z7HAch49an2qSNSGguP7Q_.base = 0;
NTItocitem__f5Z7HAch49an2qSNSGguP7Q_.flags = 2;
TM__iS6Vfak4fKt7fhPmyApRcg_6_2[0] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[21];
TM__iS6Vfak4fKt7fhPmyApRcg_0[21].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[21].offset = offsetof(tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q, content);
TM__iS6Vfak4fKt7fhPmyApRcg_0[21].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[21].name = "content";
TM__iS6Vfak4fKt7fhPmyApRcg_6_2[1] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[22];
TM__iS6Vfak4fKt7fhPmyApRcg_0[22].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[22].offset = offsetof(tyObject_TocItem__f5Z7HAch49an2qSNSGguP7Q, sortName);
TM__iS6Vfak4fKt7fhPmyApRcg_0[22].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[22].name = "sortName";
TM__iS6Vfak4fKt7fhPmyApRcg_0[20].len = 2; TM__iS6Vfak4fKt7fhPmyApRcg_0[20].kind = 2; TM__iS6Vfak4fKt7fhPmyApRcg_0[20].sons = &TM__iS6Vfak4fKt7fhPmyApRcg_6_2[0];
NTItocitem__f5Z7HAch49an2qSNSGguP7Q_.node = &TM__iS6Vfak4fKt7fhPmyApRcg_0[20];
NTIseqLtocitemT__spLz9azjOgbpYKrtmm9aMHEw_.size = sizeof(tySequence__spLz9azjOgbpYKrtmm9aMHEw*);
NTIseqLtocitemT__spLz9azjOgbpYKrtmm9aMHEw_.align = NIM_ALIGNOF(tySequence__spLz9azjOgbpYKrtmm9aMHEw*);
NTIseqLtocitemT__spLz9azjOgbpYKrtmm9aMHEw_.kind = 24;
NTIseqLtocitemT__spLz9azjOgbpYKrtmm9aMHEw_.base = (&NTItocitem__f5Z7HAch49an2qSNSGguP7Q_);
NTIseqLtocitemT__spLz9azjOgbpYKrtmm9aMHEw_.flags = 2;
NTIseqLtocitemT__spLz9azjOgbpYKrtmm9aMHEw_.marker = Marker_tySequence__spLz9azjOgbpYKrtmm9aMHEw;
NTIarrayLtsymkind_seqLtocitemTT__s1XJ229a5I0gccC9a8ovynJg_.size = sizeof(tyArray__s1XJ229a5I0gccC9a8ovynJg);
NTIarrayLtsymkind_seqLtocitemTT__s1XJ229a5I0gccC9a8ovynJg_.align = NIM_ALIGNOF(tyArray__s1XJ229a5I0gccC9a8ovynJg);
NTIarrayLtsymkind_seqLtocitemTT__s1XJ229a5I0gccC9a8ovynJg_.kind = 16;
NTIarrayLtsymkind_seqLtocitemTT__s1XJ229a5I0gccC9a8ovynJg_.base = (&NTIseqLtocitemT__spLz9azjOgbpYKrtmm9aMHEw_);
NTIarrayLtsymkind_seqLtocitemTT__s1XJ229a5I0gccC9a8ovynJg_.flags = 2;
TM__iS6Vfak4fKt7fhPmyApRcg_0[19].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[19].offset = offsetof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg, tocSimple);
TM__iS6Vfak4fKt7fhPmyApRcg_0[19].typ = (&NTIarrayLtsymkind_seqLtocitemTT__s1XJ229a5I0gccC9a8ovynJg_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[19].name = "tocSimple";
TM__iS6Vfak4fKt7fhPmyApRcg_3_24[6] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[23];
NTItable__IzudB87pHlXWFsowpECF3Q_.size = sizeof(tyObject_Table__IzudB87pHlXWFsowpECF3Q);
NTItable__IzudB87pHlXWFsowpECF3Q_.align = NIM_ALIGNOF(tyObject_Table__IzudB87pHlXWFsowpECF3Q);
NTItable__IzudB87pHlXWFsowpECF3Q_.kind = 18;
NTItable__IzudB87pHlXWFsowpECF3Q_.base = 0;
NTItable__IzudB87pHlXWFsowpECF3Q_.flags = 2;
TM__iS6Vfak4fKt7fhPmyApRcg_7_2[0] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[25];
NTIkeyvaluepair__2nwM9b3fWcA0dvFwaUqLcQg_.size = sizeof(tyTuple__2nwM9b3fWcA0dvFwaUqLcQg);
NTIkeyvaluepair__2nwM9b3fWcA0dvFwaUqLcQg_.align = NIM_ALIGNOF(tyTuple__2nwM9b3fWcA0dvFwaUqLcQg);
NTIkeyvaluepair__2nwM9b3fWcA0dvFwaUqLcQg_.kind = 18;
NTIkeyvaluepair__2nwM9b3fWcA0dvFwaUqLcQg_.base = 0;
NTIkeyvaluepair__2nwM9b3fWcA0dvFwaUqLcQg_.flags = 2;
TM__iS6Vfak4fKt7fhPmyApRcg_8_3[0] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[27];
TM__iS6Vfak4fKt7fhPmyApRcg_0[27].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[27].offset = offsetof(tyTuple__2nwM9b3fWcA0dvFwaUqLcQg, Field0);
TM__iS6Vfak4fKt7fhPmyApRcg_0[27].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[27].name = "Field0";
TM__iS6Vfak4fKt7fhPmyApRcg_8_3[1] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[28];
TM__iS6Vfak4fKt7fhPmyApRcg_0[28].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[28].offset = offsetof(tyTuple__2nwM9b3fWcA0dvFwaUqLcQg, Field1);
TM__iS6Vfak4fKt7fhPmyApRcg_0[28].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[28].name = "Field1";
TM__iS6Vfak4fKt7fhPmyApRcg_8_3[2] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[29];
TM__iS6Vfak4fKt7fhPmyApRcg_0[29].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[29].offset = offsetof(tyTuple__2nwM9b3fWcA0dvFwaUqLcQg, Field2);
TM__iS6Vfak4fKt7fhPmyApRcg_0[29].typ = (&NTIseqLtocitemT__spLz9azjOgbpYKrtmm9aMHEw_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[29].name = "Field2";
TM__iS6Vfak4fKt7fhPmyApRcg_0[26].len = 3; TM__iS6Vfak4fKt7fhPmyApRcg_0[26].kind = 2; TM__iS6Vfak4fKt7fhPmyApRcg_0[26].sons = &TM__iS6Vfak4fKt7fhPmyApRcg_8_3[0];
NTIkeyvaluepair__2nwM9b3fWcA0dvFwaUqLcQg_.node = &TM__iS6Vfak4fKt7fhPmyApRcg_0[26];
NTIkeyvaluepairseq__eo8AEcZEcjOKWtrX6vLg3Q_.size = sizeof(tySequence__eo8AEcZEcjOKWtrX6vLg3Q*);
NTIkeyvaluepairseq__eo8AEcZEcjOKWtrX6vLg3Q_.align = NIM_ALIGNOF(tySequence__eo8AEcZEcjOKWtrX6vLg3Q*);
NTIkeyvaluepairseq__eo8AEcZEcjOKWtrX6vLg3Q_.kind = 24;
NTIkeyvaluepairseq__eo8AEcZEcjOKWtrX6vLg3Q_.base = (&NTIkeyvaluepair__2nwM9b3fWcA0dvFwaUqLcQg_);
NTIkeyvaluepairseq__eo8AEcZEcjOKWtrX6vLg3Q_.flags = 2;
NTIkeyvaluepairseq__eo8AEcZEcjOKWtrX6vLg3Q_.marker = Marker_tySequence__eo8AEcZEcjOKWtrX6vLg3Q;
TM__iS6Vfak4fKt7fhPmyApRcg_0[25].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[25].offset = offsetof(tyObject_Table__IzudB87pHlXWFsowpECF3Q, data);
TM__iS6Vfak4fKt7fhPmyApRcg_0[25].typ = (&NTIkeyvaluepairseq__eo8AEcZEcjOKWtrX6vLg3Q_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[25].name = "data";
TM__iS6Vfak4fKt7fhPmyApRcg_7_2[1] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[30];
TM__iS6Vfak4fKt7fhPmyApRcg_0[30].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[30].offset = offsetof(tyObject_Table__IzudB87pHlXWFsowpECF3Q, counter);
TM__iS6Vfak4fKt7fhPmyApRcg_0[30].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[30].name = "counter";
TM__iS6Vfak4fKt7fhPmyApRcg_0[24].len = 2; TM__iS6Vfak4fKt7fhPmyApRcg_0[24].kind = 2; TM__iS6Vfak4fKt7fhPmyApRcg_0[24].sons = &TM__iS6Vfak4fKt7fhPmyApRcg_7_2[0];
NTItable__IzudB87pHlXWFsowpECF3Q_.node = &TM__iS6Vfak4fKt7fhPmyApRcg_0[24];
NTIarrayLtsymkind_tableLsystemOstring_seqLtocitemTTT__Zd9cawxvdqOKiiqOkm71SmQ_.size = sizeof(tyArray__Zd9cawxvdqOKiiqOkm71SmQ);
NTIarrayLtsymkind_tableLsystemOstring_seqLtocitemTTT__Zd9cawxvdqOKiiqOkm71SmQ_.align = NIM_ALIGNOF(tyArray__Zd9cawxvdqOKiiqOkm71SmQ);
NTIarrayLtsymkind_tableLsystemOstring_seqLtocitemTTT__Zd9cawxvdqOKiiqOkm71SmQ_.kind = 16;
NTIarrayLtsymkind_tableLsystemOstring_seqLtocitemTTT__Zd9cawxvdqOKiiqOkm71SmQ_.base = (&NTItable__IzudB87pHlXWFsowpECF3Q_);
NTIarrayLtsymkind_tableLsystemOstring_seqLtocitemTTT__Zd9cawxvdqOKiiqOkm71SmQ_.flags = 2;
TM__iS6Vfak4fKt7fhPmyApRcg_0[23].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[23].offset = offsetof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg, tocTable);
TM__iS6Vfak4fKt7fhPmyApRcg_0[23].typ = (&NTIarrayLtsymkind_tableLsystemOstring_seqLtocitemTTT__Zd9cawxvdqOKiiqOkm71SmQ_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[23].name = "tocTable";
TM__iS6Vfak4fKt7fhPmyApRcg_3_24[7] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[31];
NTItocsectionsfinal__AIk240fCwwMqKZJEnXPLZA_.size = sizeof(tyArray__AIk240fCwwMqKZJEnXPLZA);
NTItocsectionsfinal__AIk240fCwwMqKZJEnXPLZA_.align = NIM_ALIGNOF(tyArray__AIk240fCwwMqKZJEnXPLZA);
NTItocsectionsfinal__AIk240fCwwMqKZJEnXPLZA_.kind = 16;
NTItocsectionsfinal__AIk240fCwwMqKZJEnXPLZA_.base = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
NTItocsectionsfinal__AIk240fCwwMqKZJEnXPLZA_.flags = 2;
TM__iS6Vfak4fKt7fhPmyApRcg_0[31].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[31].offset = offsetof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg, toc2);
TM__iS6Vfak4fKt7fhPmyApRcg_0[31].typ = (&NTItocsectionsfinal__AIk240fCwwMqKZJEnXPLZA_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[31].name = "toc2";
TM__iS6Vfak4fKt7fhPmyApRcg_3_24[8] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[32];
TM__iS6Vfak4fKt7fhPmyApRcg_0[32].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[32].offset = offsetof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg, toc);
TM__iS6Vfak4fKt7fhPmyApRcg_0[32].typ = (&NTItocsectionsfinal__AIk240fCwwMqKZJEnXPLZA_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[32].name = "toc";
TM__iS6Vfak4fKt7fhPmyApRcg_3_24[9] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[33];
TM__iS6Vfak4fKt7fhPmyApRcg_0[33].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[33].offset = offsetof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg, indexValFilename);
TM__iS6Vfak4fKt7fhPmyApRcg_0[33].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[33].name = "indexValFilename";
TM__iS6Vfak4fKt7fhPmyApRcg_3_24[10] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[34];
TM__iS6Vfak4fKt7fhPmyApRcg_0[34].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[34].offset = offsetof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg, analytics);
TM__iS6Vfak4fKt7fhPmyApRcg_0[34].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[34].name = "analytics";
TM__iS6Vfak4fKt7fhPmyApRcg_3_24[11] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[35];
TM__iS6Vfak4fKt7fhPmyApRcg_0[35].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[35].offset = offsetof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg, seenSymbols);
TM__iS6Vfak4fKt7fhPmyApRcg_0[35].typ = (&NTIstringtableref__frXcOWngaP9adxeuIUa3iBg_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[35].name = "seenSymbols";
TM__iS6Vfak4fKt7fhPmyApRcg_3_24[12] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[36];
NTIjsonitem__OoNLxNebe9baMFlzOh1jvdw_.size = sizeof(tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw);
NTIjsonitem__OoNLxNebe9baMFlzOh1jvdw_.align = NIM_ALIGNOF(tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw);
NTIjsonitem__OoNLxNebe9baMFlzOh1jvdw_.kind = 18;
NTIjsonitem__OoNLxNebe9baMFlzOh1jvdw_.base = 0;
NTIjsonitem__OoNLxNebe9baMFlzOh1jvdw_.flags = 2;
TM__iS6Vfak4fKt7fhPmyApRcg_9_3[0] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[38];
TM__iS6Vfak4fKt7fhPmyApRcg_0[38].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[38].offset = offsetof(tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw, json);
TM__iS6Vfak4fKt7fhPmyApRcg_0[38].typ = (&NTIjsonnode__LaYTJJQFT9b3qbn9c5fIsCog_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[38].name = "json";
TM__iS6Vfak4fKt7fhPmyApRcg_9_3[1] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[39];
TM__iS6Vfak4fKt7fhPmyApRcg_0[39].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[39].offset = offsetof(tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw, rst);
TM__iS6Vfak4fKt7fhPmyApRcg_0[39].typ = (&NTIprstnode__yfV9aZUcV0SioJcvRrGyZlg_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[39].name = "rst";
TM__iS6Vfak4fKt7fhPmyApRcg_9_3[2] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[40];
TM__iS6Vfak4fKt7fhPmyApRcg_0[40].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[40].offset = offsetof(tyObject_JsonItem__OoNLxNebe9baMFlzOh1jvdw, rstField);
TM__iS6Vfak4fKt7fhPmyApRcg_0[40].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[40].name = "rstField";
TM__iS6Vfak4fKt7fhPmyApRcg_0[37].len = 3; TM__iS6Vfak4fKt7fhPmyApRcg_0[37].kind = 2; TM__iS6Vfak4fKt7fhPmyApRcg_0[37].sons = &TM__iS6Vfak4fKt7fhPmyApRcg_9_3[0];
NTIjsonitem__OoNLxNebe9baMFlzOh1jvdw_.node = &TM__iS6Vfak4fKt7fhPmyApRcg_0[37];
NTIseqLjsonitemT__Z0K9aZr9c4ex9ad72Ulcdqy7g_.size = sizeof(tySequence__Z0K9aZr9c4ex9ad72Ulcdqy7g*);
NTIseqLjsonitemT__Z0K9aZr9c4ex9ad72Ulcdqy7g_.align = NIM_ALIGNOF(tySequence__Z0K9aZr9c4ex9ad72Ulcdqy7g*);
NTIseqLjsonitemT__Z0K9aZr9c4ex9ad72Ulcdqy7g_.kind = 24;
NTIseqLjsonitemT__Z0K9aZr9c4ex9ad72Ulcdqy7g_.base = (&NTIjsonitem__OoNLxNebe9baMFlzOh1jvdw_);
NTIseqLjsonitemT__Z0K9aZr9c4ex9ad72Ulcdqy7g_.flags = 2;
NTIseqLjsonitemT__Z0K9aZr9c4ex9ad72Ulcdqy7g_.marker = Marker_tySequence__Z0K9aZr9c4ex9ad72Ulcdqy7g;
TM__iS6Vfak4fKt7fhPmyApRcg_0[36].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[36].offset = offsetof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg, jEntriesPre);
TM__iS6Vfak4fKt7fhPmyApRcg_0[36].typ = (&NTIseqLjsonitemT__Z0K9aZr9c4ex9ad72Ulcdqy7g_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[36].name = "jEntriesPre";
TM__iS6Vfak4fKt7fhPmyApRcg_3_24[13] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[41];
TM__iS6Vfak4fKt7fhPmyApRcg_0[41].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[41].offset = offsetof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg, jEntriesFinal);
TM__iS6Vfak4fKt7fhPmyApRcg_0[41].typ = (&NTIjsonnode__LaYTJJQFT9b3qbn9c5fIsCog_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[41].name = "jEntriesFinal";
TM__iS6Vfak4fKt7fhPmyApRcg_3_24[14] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[42];
TM__iS6Vfak4fKt7fhPmyApRcg_0[42].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[42].offset = offsetof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg, types);
TM__iS6Vfak4fKt7fhPmyApRcg_0[42].typ = (&NTItstrtable__CJQ42V2zij8fd39a9aMiwtZw_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[42].name = "types";
TM__iS6Vfak4fKt7fhPmyApRcg_3_24[15] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[43];
TM__iS6Vfak4fKt7fhPmyApRcg_0[43].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[43].offset = offsetof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg, sharedState);
TM__iS6Vfak4fKt7fhPmyApRcg_0[43].typ = (&NTIprstsharedstate__dLMuJdRQoOg2PJi1ktqSYQ_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[43].name = "sharedState";
TM__iS6Vfak4fKt7fhPmyApRcg_3_24[16] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[44];
TM__iS6Vfak4fKt7fhPmyApRcg_0[44].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[44].offset = offsetof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg, isPureRst);
TM__iS6Vfak4fKt7fhPmyApRcg_0[44].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[44].name = "isPureRst";
TM__iS6Vfak4fKt7fhPmyApRcg_3_24[17] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[45];
TM__iS6Vfak4fKt7fhPmyApRcg_0[45].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[45].offset = offsetof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg, conf);
TM__iS6Vfak4fKt7fhPmyApRcg_0[45].typ = (&NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[45].name = "conf";
TM__iS6Vfak4fKt7fhPmyApRcg_3_24[18] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[46];
TM__iS6Vfak4fKt7fhPmyApRcg_0[46].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[46].offset = offsetof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg, cache);
TM__iS6Vfak4fKt7fhPmyApRcg_0[46].typ = (&NTIidentcache__6ZZ9cf5acLVYxUxl0ehlA1g_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[46].name = "cache";
TM__iS6Vfak4fKt7fhPmyApRcg_3_24[19] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[47];
TM__iS6Vfak4fKt7fhPmyApRcg_0[47].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[47].offset = offsetof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg, exampleCounter);
TM__iS6Vfak4fKt7fhPmyApRcg_0[47].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[47].name = "exampleCounter";
TM__iS6Vfak4fKt7fhPmyApRcg_3_24[20] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[48];
TM__iS6Vfak4fKt7fhPmyApRcg_0[48].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[48].offset = offsetof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg, emitted);
TM__iS6Vfak4fKt7fhPmyApRcg_0[48].typ = (&NTIpackedset__THXDbzJSs2hcC9a33en2pdw_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[48].name = "emitted";
TM__iS6Vfak4fKt7fhPmyApRcg_3_24[21] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[49];
TM__iS6Vfak4fKt7fhPmyApRcg_0[49].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[49].offset = offsetof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg, thisDir);
TM__iS6Vfak4fKt7fhPmyApRcg_0[49].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[49].name = "thisDir";
TM__iS6Vfak4fKt7fhPmyApRcg_3_24[22] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[50];
NTIorderedtable__uUf2ABI4SLuvVLy2s8ygdw_.size = sizeof(tyObject_OrderedTable__uUf2ABI4SLuvVLy2s8ygdw);
NTIorderedtable__uUf2ABI4SLuvVLy2s8ygdw_.align = NIM_ALIGNOF(tyObject_OrderedTable__uUf2ABI4SLuvVLy2s8ygdw);
NTIorderedtable__uUf2ABI4SLuvVLy2s8ygdw_.kind = 18;
NTIorderedtable__uUf2ABI4SLuvVLy2s8ygdw_.base = 0;
NTIorderedtable__uUf2ABI4SLuvVLy2s8ygdw_.flags = 2;
TM__iS6Vfak4fKt7fhPmyApRcg_10_4[0] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[52];
NTIorderedkeyvaluepair__qrCj5BRLChMPPtE8mZNTMw_.size = sizeof(tyTuple__qrCj5BRLChMPPtE8mZNTMw);
NTIorderedkeyvaluepair__qrCj5BRLChMPPtE8mZNTMw_.align = NIM_ALIGNOF(tyTuple__qrCj5BRLChMPPtE8mZNTMw);
NTIorderedkeyvaluepair__qrCj5BRLChMPPtE8mZNTMw_.kind = 18;
NTIorderedkeyvaluepair__qrCj5BRLChMPPtE8mZNTMw_.base = 0;
NTIorderedkeyvaluepair__qrCj5BRLChMPPtE8mZNTMw_.flags = 2;
TM__iS6Vfak4fKt7fhPmyApRcg_11_4[0] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[54];
TM__iS6Vfak4fKt7fhPmyApRcg_0[54].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[54].offset = offsetof(tyTuple__qrCj5BRLChMPPtE8mZNTMw, Field0);
TM__iS6Vfak4fKt7fhPmyApRcg_0[54].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[54].name = "Field0";
TM__iS6Vfak4fKt7fhPmyApRcg_11_4[1] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[55];
TM__iS6Vfak4fKt7fhPmyApRcg_0[55].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[55].offset = offsetof(tyTuple__qrCj5BRLChMPPtE8mZNTMw, Field1);
TM__iS6Vfak4fKt7fhPmyApRcg_0[55].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[55].name = "Field1";
TM__iS6Vfak4fKt7fhPmyApRcg_11_4[2] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[56];
TM__iS6Vfak4fKt7fhPmyApRcg_0[56].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[56].offset = offsetof(tyTuple__qrCj5BRLChMPPtE8mZNTMw, Field2);
TM__iS6Vfak4fKt7fhPmyApRcg_0[56].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[56].name = "Field2";
TM__iS6Vfak4fKt7fhPmyApRcg_11_4[3] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[57];
NTIexamplegroup58objecttype__bbSjO9aaIauVHOujtpjo3Rw_.size = sizeof(tyObject_ExampleGroupcolonObjectType___bbSjO9aaIauVHOujtpjo3Rw);
NTIexamplegroup58objecttype__bbSjO9aaIauVHOujtpjo3Rw_.align = NIM_ALIGNOF(tyObject_ExampleGroupcolonObjectType___bbSjO9aaIauVHOujtpjo3Rw);
NTIexamplegroup58objecttype__bbSjO9aaIauVHOujtpjo3Rw_.kind = 18;
NTIexamplegroup58objecttype__bbSjO9aaIauVHOujtpjo3Rw_.base = 0;
NTIexamplegroup58objecttype__bbSjO9aaIauVHOujtpjo3Rw_.flags = 2;
TM__iS6Vfak4fKt7fhPmyApRcg_12_4[0] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[59];
TM__iS6Vfak4fKt7fhPmyApRcg_0[59].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[59].offset = offsetof(tyObject_ExampleGroupcolonObjectType___bbSjO9aaIauVHOujtpjo3Rw, rdoccmd);
TM__iS6Vfak4fKt7fhPmyApRcg_0[59].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[59].name = "rdoccmd";
TM__iS6Vfak4fKt7fhPmyApRcg_12_4[1] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[60];
TM__iS6Vfak4fKt7fhPmyApRcg_0[60].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[60].offset = offsetof(tyObject_ExampleGroupcolonObjectType___bbSjO9aaIauVHOujtpjo3Rw, docCmd);
TM__iS6Vfak4fKt7fhPmyApRcg_0[60].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[60].name = "docCmd";
TM__iS6Vfak4fKt7fhPmyApRcg_12_4[2] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[61];
TM__iS6Vfak4fKt7fhPmyApRcg_0[61].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[61].offset = offsetof(tyObject_ExampleGroupcolonObjectType___bbSjO9aaIauVHOujtpjo3Rw, code);
TM__iS6Vfak4fKt7fhPmyApRcg_0[61].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[61].name = "code";
TM__iS6Vfak4fKt7fhPmyApRcg_12_4[3] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[62];
TM__iS6Vfak4fKt7fhPmyApRcg_0[62].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[62].offset = offsetof(tyObject_ExampleGroupcolonObjectType___bbSjO9aaIauVHOujtpjo3Rw, index);
TM__iS6Vfak4fKt7fhPmyApRcg_0[62].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[62].name = "index";
TM__iS6Vfak4fKt7fhPmyApRcg_0[58].len = 4; TM__iS6Vfak4fKt7fhPmyApRcg_0[58].kind = 2; TM__iS6Vfak4fKt7fhPmyApRcg_0[58].sons = &TM__iS6Vfak4fKt7fhPmyApRcg_12_4[0];
NTIexamplegroup58objecttype__bbSjO9aaIauVHOujtpjo3Rw_.node = &TM__iS6Vfak4fKt7fhPmyApRcg_0[58];
NTIexamplegroup__Z4Ed9aRleAg258AnxIUkcCQ_.size = sizeof(tyObject_ExampleGroupcolonObjectType___bbSjO9aaIauVHOujtpjo3Rw*);
NTIexamplegroup__Z4Ed9aRleAg258AnxIUkcCQ_.align = NIM_ALIGNOF(tyObject_ExampleGroupcolonObjectType___bbSjO9aaIauVHOujtpjo3Rw*);
NTIexamplegroup__Z4Ed9aRleAg258AnxIUkcCQ_.kind = 22;
NTIexamplegroup__Z4Ed9aRleAg258AnxIUkcCQ_.base = (&NTIexamplegroup58objecttype__bbSjO9aaIauVHOujtpjo3Rw_);
NTIexamplegroup__Z4Ed9aRleAg258AnxIUkcCQ_.flags = 2;
NTIexamplegroup__Z4Ed9aRleAg258AnxIUkcCQ_.marker = Marker_tyRef__Z4Ed9aRleAg258AnxIUkcCQ;
TM__iS6Vfak4fKt7fhPmyApRcg_0[57].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[57].offset = offsetof(tyTuple__qrCj5BRLChMPPtE8mZNTMw, Field3);
TM__iS6Vfak4fKt7fhPmyApRcg_0[57].typ = (&NTIexamplegroup__Z4Ed9aRleAg258AnxIUkcCQ_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[57].name = "Field3";
TM__iS6Vfak4fKt7fhPmyApRcg_0[53].len = 4; TM__iS6Vfak4fKt7fhPmyApRcg_0[53].kind = 2; TM__iS6Vfak4fKt7fhPmyApRcg_0[53].sons = &TM__iS6Vfak4fKt7fhPmyApRcg_11_4[0];
NTIorderedkeyvaluepair__qrCj5BRLChMPPtE8mZNTMw_.node = &TM__iS6Vfak4fKt7fhPmyApRcg_0[53];
NTIorderedkeyvaluepairseq__RKPQcDl19bqs7bJVDyxdQYg_.size = sizeof(tySequence__RKPQcDl19bqs7bJVDyxdQYg*);
NTIorderedkeyvaluepairseq__RKPQcDl19bqs7bJVDyxdQYg_.align = NIM_ALIGNOF(tySequence__RKPQcDl19bqs7bJVDyxdQYg*);
NTIorderedkeyvaluepairseq__RKPQcDl19bqs7bJVDyxdQYg_.kind = 24;
NTIorderedkeyvaluepairseq__RKPQcDl19bqs7bJVDyxdQYg_.base = (&NTIorderedkeyvaluepair__qrCj5BRLChMPPtE8mZNTMw_);
NTIorderedkeyvaluepairseq__RKPQcDl19bqs7bJVDyxdQYg_.flags = 2;
NTIorderedkeyvaluepairseq__RKPQcDl19bqs7bJVDyxdQYg_.marker = Marker_tySequence__RKPQcDl19bqs7bJVDyxdQYg;
TM__iS6Vfak4fKt7fhPmyApRcg_0[52].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[52].offset = offsetof(tyObject_OrderedTable__uUf2ABI4SLuvVLy2s8ygdw, data);
TM__iS6Vfak4fKt7fhPmyApRcg_0[52].typ = (&NTIorderedkeyvaluepairseq__RKPQcDl19bqs7bJVDyxdQYg_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[52].name = "data";
TM__iS6Vfak4fKt7fhPmyApRcg_10_4[1] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[63];
TM__iS6Vfak4fKt7fhPmyApRcg_0[63].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[63].offset = offsetof(tyObject_OrderedTable__uUf2ABI4SLuvVLy2s8ygdw, counter);
TM__iS6Vfak4fKt7fhPmyApRcg_0[63].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[63].name = "counter";
TM__iS6Vfak4fKt7fhPmyApRcg_10_4[2] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[64];
TM__iS6Vfak4fKt7fhPmyApRcg_0[64].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[64].offset = offsetof(tyObject_OrderedTable__uUf2ABI4SLuvVLy2s8ygdw, first);
TM__iS6Vfak4fKt7fhPmyApRcg_0[64].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[64].name = "first";
TM__iS6Vfak4fKt7fhPmyApRcg_10_4[3] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[65];
TM__iS6Vfak4fKt7fhPmyApRcg_0[65].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[65].offset = offsetof(tyObject_OrderedTable__uUf2ABI4SLuvVLy2s8ygdw, last);
TM__iS6Vfak4fKt7fhPmyApRcg_0[65].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[65].name = "last";
TM__iS6Vfak4fKt7fhPmyApRcg_0[51].len = 4; TM__iS6Vfak4fKt7fhPmyApRcg_0[51].kind = 2; TM__iS6Vfak4fKt7fhPmyApRcg_0[51].sons = &TM__iS6Vfak4fKt7fhPmyApRcg_10_4[0];
NTIorderedtable__uUf2ABI4SLuvVLy2s8ygdw_.node = &TM__iS6Vfak4fKt7fhPmyApRcg_0[51];
TM__iS6Vfak4fKt7fhPmyApRcg_0[50].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[50].offset = offsetof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg, exampleGroups);
TM__iS6Vfak4fKt7fhPmyApRcg_0[50].typ = (&NTIorderedtable__uUf2ABI4SLuvVLy2s8ygdw_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[50].name = "exampleGroups";
TM__iS6Vfak4fKt7fhPmyApRcg_3_24[23] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[66];
TM__iS6Vfak4fKt7fhPmyApRcg_0[66].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[66].offset = offsetof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg, wroteSupportFiles);
TM__iS6Vfak4fKt7fhPmyApRcg_0[66].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[66].name = "wroteSupportFiles";
TM__iS6Vfak4fKt7fhPmyApRcg_0[3].len = 24; TM__iS6Vfak4fKt7fhPmyApRcg_0[3].kind = 2; TM__iS6Vfak4fKt7fhPmyApRcg_0[3].sons = &TM__iS6Vfak4fKt7fhPmyApRcg_3_24[0];
NTItdocumentor__bjDxkrkDk9c19abCetktG5Qg_.node = &TM__iS6Vfak4fKt7fhPmyApRcg_0[3];
NTIpdoc__DVY9cSsFXOXsfAd5wCWVrTg_.size = sizeof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg*);
NTIpdoc__DVY9cSsFXOXsfAd5wCWVrTg_.align = NIM_ALIGNOF(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg*);
NTIpdoc__DVY9cSsFXOXsfAd5wCWVrTg_.kind = 22;
NTIpdoc__DVY9cSsFXOXsfAd5wCWVrTg_.base = (&NTItdocumentor__bjDxkrkDk9c19abCetktG5Qg_);
NTIpdoc__DVY9cSsFXOXsfAd5wCWVrTg_.marker = Marker_tyRef__DVY9cSsFXOXsfAd5wCWVrTg;
NTIobject__Jp5hmeXcpCwUxySNwOFFoQ_.size = sizeof(tyObject_Env_docgendotnim_colonanonymous___Jp5hmeXcpCwUxySNwOFFoQ);
NTIobject__Jp5hmeXcpCwUxySNwOFFoQ_.align = NIM_ALIGNOF(tyObject_Env_docgendotnim_colonanonymous___Jp5hmeXcpCwUxySNwOFFoQ);
NTIobject__Jp5hmeXcpCwUxySNwOFFoQ_.kind = 17;
NTIobject__Jp5hmeXcpCwUxySNwOFFoQ_.base = (&NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_);
TM__iS6Vfak4fKt7fhPmyApRcg_22_3[0] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[68];
TM__iS6Vfak4fKt7fhPmyApRcg_0[68].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[68].offset = offsetof(tyObject_Env_docgendotnim_colonanonymous___Jp5hmeXcpCwUxySNwOFFoQ, colonstate_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[68].typ = (&NTIint__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[68].name = ":state";
TM__iS6Vfak4fKt7fhPmyApRcg_22_3[1] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[69];
NTIptrtdocumentor__5rKcOUCklcaxmojH8unweg_.size = sizeof(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg*);
NTIptrtdocumentor__5rKcOUCklcaxmojH8unweg_.align = NIM_ALIGNOF(tyObject_TDocumentor__bjDxkrkDk9c19abCetktG5Qg*);
NTIptrtdocumentor__5rKcOUCklcaxmojH8unweg_.kind = 21;
NTIptrtdocumentor__5rKcOUCklcaxmojH8unweg_.base = (&NTItdocumentor__bjDxkrkDk9c19abCetktG5Qg_);
NTIptrtdocumentor__5rKcOUCklcaxmojH8unweg_.flags = 3;
TM__iS6Vfak4fKt7fhPmyApRcg_0[69].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[69].offset = offsetof(tyObject_Env_docgendotnim_colonanonymous___Jp5hmeXcpCwUxySNwOFFoQ, d1);
TM__iS6Vfak4fKt7fhPmyApRcg_0[69].typ = (&NTIptrtdocumentor__5rKcOUCklcaxmojH8unweg_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[69].name = "d1";
TM__iS6Vfak4fKt7fhPmyApRcg_22_3[2] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[70];
TM__iS6Vfak4fKt7fhPmyApRcg_0[70].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[70].offset = offsetof(tyObject_Env_docgendotnim_colonanonymous___Jp5hmeXcpCwUxySNwOFFoQ, outp2);
TM__iS6Vfak4fKt7fhPmyApRcg_0[70].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[70].name = "outp2";
TM__iS6Vfak4fKt7fhPmyApRcg_0[67].len = 3; TM__iS6Vfak4fKt7fhPmyApRcg_0[67].kind = 2; TM__iS6Vfak4fKt7fhPmyApRcg_0[67].sons = &TM__iS6Vfak4fKt7fhPmyApRcg_22_3[0];
NTIobject__Jp5hmeXcpCwUxySNwOFFoQ_.node = &TM__iS6Vfak4fKt7fhPmyApRcg_0[67];
NTIrefobject__TGC3u8unDUvns3a0CJWQdw_.size = sizeof(tyObject_Env_docgendotnim_colonanonymous___Jp5hmeXcpCwUxySNwOFFoQ*);
NTIrefobject__TGC3u8unDUvns3a0CJWQdw_.align = NIM_ALIGNOF(tyObject_Env_docgendotnim_colonanonymous___Jp5hmeXcpCwUxySNwOFFoQ*);
NTIrefobject__TGC3u8unDUvns3a0CJWQdw_.kind = 22;
NTIrefobject__TGC3u8unDUvns3a0CJWQdw_.base = (&NTIobject__Jp5hmeXcpCwUxySNwOFFoQ_);
NTIrefobject__TGC3u8unDUvns3a0CJWQdw_.marker = Marker_tyRef__TGC3u8unDUvns3a0CJWQdw;
NTIobject__FkNfvNWmsd8YzfuKoBUSmA_.size = sizeof(tyObject_Env_docgendotnim_presentationPath___FkNfvNWmsd8YzfuKoBUSmA);
NTIobject__FkNfvNWmsd8YzfuKoBUSmA_.align = NIM_ALIGNOF(tyObject_Env_docgendotnim_presentationPath___FkNfvNWmsd8YzfuKoBUSmA);
NTIobject__FkNfvNWmsd8YzfuKoBUSmA_.kind = 17;
NTIobject__FkNfvNWmsd8YzfuKoBUSmA_.base = (&NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_);
TM__iS6Vfak4fKt7fhPmyApRcg_43_3[0] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[72];
TM__iS6Vfak4fKt7fhPmyApRcg_0[72].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[72].offset = offsetof(tyObject_Env_docgendotnim_presentationPath___FkNfvNWmsd8YzfuKoBUSmA, colonstate_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[72].typ = (&NTIint__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[72].name = ":state";
TM__iS6Vfak4fKt7fhPmyApRcg_43_3[1] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[73];
TM__iS6Vfak4fKt7fhPmyApRcg_0[73].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[73].offset = offsetof(tyObject_Env_docgendotnim_presentationPath___FkNfvNWmsd8YzfuKoBUSmA, conf1);
TM__iS6Vfak4fKt7fhPmyApRcg_0[73].typ = (&NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[73].name = "conf1";
TM__iS6Vfak4fKt7fhPmyApRcg_43_3[2] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[74];
TM__iS6Vfak4fKt7fhPmyApRcg_0[74].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[74].offset = offsetof(tyObject_Env_docgendotnim_presentationPath___FkNfvNWmsd8YzfuKoBUSmA, file22);
TM__iS6Vfak4fKt7fhPmyApRcg_0[74].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[74].name = "file22";
TM__iS6Vfak4fKt7fhPmyApRcg_0[71].len = 3; TM__iS6Vfak4fKt7fhPmyApRcg_0[71].kind = 2; TM__iS6Vfak4fKt7fhPmyApRcg_0[71].sons = &TM__iS6Vfak4fKt7fhPmyApRcg_43_3[0];
NTIobject__FkNfvNWmsd8YzfuKoBUSmA_.node = &TM__iS6Vfak4fKt7fhPmyApRcg_0[71];
NTIrefobject__rNRAvx86kE4vxe49aRy4cdQ_.size = sizeof(tyObject_Env_docgendotnim_presentationPath___FkNfvNWmsd8YzfuKoBUSmA*);
NTIrefobject__rNRAvx86kE4vxe49aRy4cdQ_.align = NIM_ALIGNOF(tyObject_Env_docgendotnim_presentationPath___FkNfvNWmsd8YzfuKoBUSmA*);
NTIrefobject__rNRAvx86kE4vxe49aRy4cdQ_.kind = 22;
NTIrefobject__rNRAvx86kE4vxe49aRy4cdQ_.base = (&NTIobject__FkNfvNWmsd8YzfuKoBUSmA_);
NTIrefobject__rNRAvx86kE4vxe49aRy4cdQ_.marker = Marker_tyRef__rNRAvx86kE4vxe49aRy4cdQ;
NTIobject__EkXrf9bj6BppyBV1BtAGatQ_.size = sizeof(tyObject_Env_docgendotnim_commandJson___EkXrf9bj6BppyBV1BtAGatQ);
NTIobject__EkXrf9bj6BppyBV1BtAGatQ_.align = NIM_ALIGNOF(tyObject_Env_docgendotnim_commandJson___EkXrf9bj6BppyBV1BtAGatQ);
NTIobject__EkXrf9bj6BppyBV1BtAGatQ_.kind = 17;
NTIobject__EkXrf9bj6BppyBV1BtAGatQ_.base = (&NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_);
TM__iS6Vfak4fKt7fhPmyApRcg_262_2[0] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[76];
TM__iS6Vfak4fKt7fhPmyApRcg_0[76].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[76].offset = offsetof(tyObject_Env_docgendotnim_commandJson___EkXrf9bj6BppyBV1BtAGatQ, colonstate_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[76].typ = (&NTIint__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[76].name = ":state";
TM__iS6Vfak4fKt7fhPmyApRcg_262_2[1] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[77];
TM__iS6Vfak4fKt7fhPmyApRcg_0[77].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[77].offset = offsetof(tyObject_Env_docgendotnim_commandJson___EkXrf9bj6BppyBV1BtAGatQ, conf1);
TM__iS6Vfak4fKt7fhPmyApRcg_0[77].typ = (&NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[77].name = "conf1";
TM__iS6Vfak4fKt7fhPmyApRcg_0[75].len = 2; TM__iS6Vfak4fKt7fhPmyApRcg_0[75].kind = 2; TM__iS6Vfak4fKt7fhPmyApRcg_0[75].sons = &TM__iS6Vfak4fKt7fhPmyApRcg_262_2[0];
NTIobject__EkXrf9bj6BppyBV1BtAGatQ_.node = &TM__iS6Vfak4fKt7fhPmyApRcg_0[75];
NTIrefobject__X8kkALavbEdzXIrP0m7q2g_.size = sizeof(tyObject_Env_docgendotnim_commandJson___EkXrf9bj6BppyBV1BtAGatQ*);
NTIrefobject__X8kkALavbEdzXIrP0m7q2g_.align = NIM_ALIGNOF(tyObject_Env_docgendotnim_commandJson___EkXrf9bj6BppyBV1BtAGatQ*);
NTIrefobject__X8kkALavbEdzXIrP0m7q2g_.kind = 22;
NTIrefobject__X8kkALavbEdzXIrP0m7q2g_.base = (&NTIobject__EkXrf9bj6BppyBV1BtAGatQ_);
NTIrefobject__X8kkALavbEdzXIrP0m7q2g_.marker = Marker_tyRef__X8kkALavbEdzXIrP0m7q2g;
NTIobject__SuJtoUSREUHobzyvPNB0bA_.size = sizeof(tyObject_Env_docgendotnim_commandTags___SuJtoUSREUHobzyvPNB0bA);
NTIobject__SuJtoUSREUHobzyvPNB0bA_.align = NIM_ALIGNOF(tyObject_Env_docgendotnim_commandTags___SuJtoUSREUHobzyvPNB0bA);
NTIobject__SuJtoUSREUHobzyvPNB0bA_.kind = 17;
NTIobject__SuJtoUSREUHobzyvPNB0bA_.base = (&NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_);
TM__iS6Vfak4fKt7fhPmyApRcg_268_2[0] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[79];
TM__iS6Vfak4fKt7fhPmyApRcg_0[79].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[79].offset = offsetof(tyObject_Env_docgendotnim_commandTags___SuJtoUSREUHobzyvPNB0bA, colonstate_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[79].typ = (&NTIint__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[79].name = ":state";
TM__iS6Vfak4fKt7fhPmyApRcg_268_2[1] = &TM__iS6Vfak4fKt7fhPmyApRcg_0[80];
TM__iS6Vfak4fKt7fhPmyApRcg_0[80].kind = 1;
TM__iS6Vfak4fKt7fhPmyApRcg_0[80].offset = offsetof(tyObject_Env_docgendotnim_commandTags___SuJtoUSREUHobzyvPNB0bA, conf1);
TM__iS6Vfak4fKt7fhPmyApRcg_0[80].typ = (&NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_);
TM__iS6Vfak4fKt7fhPmyApRcg_0[80].name = "conf1";
TM__iS6Vfak4fKt7fhPmyApRcg_0[78].len = 2; TM__iS6Vfak4fKt7fhPmyApRcg_0[78].kind = 2; TM__iS6Vfak4fKt7fhPmyApRcg_0[78].sons = &TM__iS6Vfak4fKt7fhPmyApRcg_268_2[0];
NTIobject__SuJtoUSREUHobzyvPNB0bA_.node = &TM__iS6Vfak4fKt7fhPmyApRcg_0[78];
NTIrefobject__79c3Y3ZwA6fl2mb7ydHMpdg_.size = sizeof(tyObject_Env_docgendotnim_commandTags___SuJtoUSREUHobzyvPNB0bA*);
NTIrefobject__79c3Y3ZwA6fl2mb7ydHMpdg_.align = NIM_ALIGNOF(tyObject_Env_docgendotnim_commandTags___SuJtoUSREUHobzyvPNB0bA*);
NTIrefobject__79c3Y3ZwA6fl2mb7ydHMpdg_.kind = 22;
NTIrefobject__79c3Y3ZwA6fl2mb7ydHMpdg_.base = (&NTIobject__SuJtoUSREUHobzyvPNB0bA_);
NTIrefobject__79c3Y3ZwA6fl2mb7ydHMpdg_.marker = Marker_tyRef__79c3Y3ZwA6fl2mb7ydHMpdg;
}

