/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 32

#include "nimbase.h"
#include <string.h>
#include <setjmp.h>
#include <math.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tySequence__RNhZxf20g9beyq5VBOGxhDg tySequence__RNhZxf20g9beyq5VBOGxhDg;
typedef struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ;
typedef struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ tySequence__lFbCtu5P2Kf7YDYtGjkxAQ;
typedef struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA;
typedef struct tySequence__ijtae5OneaLys0hN9alAicA tySequence__ijtae5OneaLys0hN9alAicA;
typedef struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w;
typedef struct tySequence__SerjNoUujW2dUouVBrJiCw tySequence__SerjNoUujW2dUouVBrJiCw;
typedef struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyObject_Table__r0v8BdcBPKhl73K8p2VMUA;
typedef struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g tySequence__K9agbtcb0qPZuSJFXB9cTe6g;
typedef struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg;
typedef struct tySequence__m88qdML9cQOuqGAQn6XWL1A tySequence__m88qdML9cQOuqGAQn6XWL1A;
typedef struct tyObject_Table__1hIWbTQWYT4BmhdESze57A tyObject_Table__1hIWbTQWYT4BmhdESze57A;
typedef struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ tySequence__naEbXEp9b9aiW1zXJorqf9cXQ;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA;
typedef struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw;
typedef struct tySequence__ed0C0uAUZPhvw3RAc5hfYg tySequence__ed0C0uAUZPhvw3RAc5hfYg;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tyObject_Table__imojfg883tkWsWJwyshGqQ tyObject_Table__imojfg883tkWsWJwyshGqQ;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg tyObject_Table__BCPh85PHtwxox9bv7NLFrlg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA;
typedef struct tySequence__KgiZ29chkJAD01p9aLRB32qw tySequence__KgiZ29chkJAD01p9aLRB32qw;
typedef struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A tyObject_Table__LM44poVdVEn4Mo4N4L8c3A;
typedef struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw tySequence__rkYRZrbHVYL3nhXlQW3K9bw;
typedef struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ tySequence__IRFEb1e9bxgbJLuB5xrdZsQ;
typedef struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ;
typedef struct tySequence__YmPd0eWfcTfrVYrthlXPYA tySequence__YmPd0eWfcTfrVYrthlXPYA;
typedef struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q;
typedef struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg tySequence__Hz5SYwQU29b9aFLt09blvVQPg;
typedef struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg tyObject_Table__R7JnJQEipxxOlJWXQz7jWg;
typedef struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ tySequence__3G9aA9cLXaPxuRxMKm3anacQ;
typedef struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q tySequence__bPFv6ypvvCX2A9a9al8utL2Q;
typedef struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg;
typedef struct tyObject_HSlice__uuLFB9bRXg4euv7O8yFk6pA tyObject_HSlice__uuLFB9bRXg4euv7O8yFk6pA;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tyTuple__cyyQdcuoDUp88Doe6rM7kA tyTuple__cyyQdcuoDUp88Doe6rM7kA;
typedef struct tyTuple__oa1dFn55BmC688WoXKTtUg tyTuple__oa1dFn55BmC688WoXKTtUg;
typedef struct Exception Exception;
typedef struct tySequence__QbmGqFaLnb1IWWToREeaIA tySequence__QbmGqFaLnb1IWWToREeaIA;
typedef struct TSafePoint TSafePoint;
typedef struct tyObject_HSlice__5MokM0MxT5ZF4tSog3uzVQ tyObject_HSlice__5MokM0MxT5ZF4tSog3uzVQ;
typedef struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ;
typedef struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g tySequence__qeAsXh2i1GAL5Nl0g3OP8g;
typedef struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg;
typedef struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg;
typedef struct tySequence__4Murtwnm0Fyc7F9acrytEXw tySequence__4Murtwnm0Fyc7F9acrytEXw;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw;
typedef struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg tySequence__QnmOtn1Iv4LvxOXoMn8Rbg;
typedef struct tySequence__oKtVqsc9bQVCNyrijELM4OQ tySequence__oKtVqsc9bQVCNyrijELM4OQ;
typedef struct tySequence__qy6Iwdy00wN560qud54HTg tySequence__qy6Iwdy00wN560qud54HTg;
typedef struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ tySequence__k67v9bwvvQDmS1ynyGGUbeQ;
typedef struct tySequence__cLsClAAfd0MKkoBQVyvdvw tySequence__cLsClAAfd0MKkoBQVyvdvw;
typedef struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg tySequence__q9bTuOB0JXh1iZ3CSGdRLbg;
typedef struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw;
typedef struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ;
typedef struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ;
typedef struct tySequence__C3r8jsj9chA4sIlYfDN5aDw tySequence__C3r8jsj9chA4sIlYfDN5aDw;
typedef struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ;
typedef struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg tyTuple__UluY8x0Nj6cp9b0o88wJ0lg;
typedef struct tySequence__dlD6tEGzYLLpKVq3XwuFlA tySequence__dlD6tEGzYLLpKVq3XwuFlA;
typedef struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ;
typedef struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg;
typedef struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ;
typedef struct tyTuple__rZZA0skon1OsHdiEvT8RZQ tyTuple__rZZA0skon1OsHdiEvT8RZQ;
typedef struct tySequence__6OFCSvqRaxyEgUqWtnZSlw tySequence__6OFCSvqRaxyEgUqWtnZSlw;
typedef struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q;
typedef struct tySequence__UnGSk9aaLosDroi2QDrlOfQ tySequence__UnGSk9aaLosDroi2QDrlOfQ;
typedef struct tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA;
typedef struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA tyTuple__q13Zt16VkCqu6Zg5jWqwHA;
typedef struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA tyTuple__aWN9bNzF9bubXNJV9ciomgpfA;
typedef struct tySequence__m4PVWjcAAjfxlwJxLkKn8A tySequence__m4PVWjcAAjfxlwJxLkKn8A;
typedef struct tyTuple__RWXAsQlFoGYyEQZp1G65sg tyTuple__RWXAsQlFoGYyEQZp1G65sg;
typedef struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg;
typedef struct tyTuple__RmGJuqOgEaHckHndh0LEsw tyTuple__RmGJuqOgEaHckHndh0LEsw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__J4cxakKjhKxTIJR9bojMmXw tyTuple__J4cxakKjhKxTIJR9bojMmXw;
typedef struct tySequence__i89c5kdtWKzK3OEiI81pkkw tySequence__i89c5kdtWKzK3OEiI81pkkw;
typedef struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A;
typedef struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ;
typedef struct tySequence__GR8qmV1kNRcoQ2g76VFy3A tySequence__GR8qmV1kNRcoQ2g76VFy3A;
typedef struct tyTuple__a7QginWFapakKbWJBJ2vfA tyTuple__a7QginWFapakKbWJBJ2vfA;
typedef struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__kbX6x85REySUrk9auORL0vw tyTuple__kbX6x85REySUrk9auORL0vw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g;
typedef struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q;
typedef struct tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A;
typedef struct tyTuple__nF9cH4hinXgGEUwO4G2bshw tyTuple__nF9cH4hinXgGEUwO4G2bshw;
typedef struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
typedef struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA;
typedef struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__PsEhl3dzznmmJiLAuIXZOg tyTuple__PsEhl3dzznmmJiLAuIXZOg;
typedef struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w;
typedef struct tyTuple__Db8CrQifKGIsKc3w71w7Lw tyTuple__Db8CrQifKGIsKc3w71w7Lw;
typedef struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg;
typedef struct tySequence__lo3S1lKyiPLhGGB9cBawd6A tySequence__lo3S1lKyiPLhGGB9cBawd6A;
typedef struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ;
typedef struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw tyTuple__FEYH9alRJhHD0uTKF2vnIqw;
typedef struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA;
typedef struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA;
typedef struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw;
typedef struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg tyTuple__VUJ5Hjm4tKAResBsRHJvYg;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
typedef NU32 tyArray__FleBT9cC2nxhgiXmSYYnEKA[4];
struct tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ {
tyArray__FleBT9cC2nxhgiXmSYYnEKA udata;
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInst;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg uniqueId;
};
struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg {
NI32 module;
NI32 symId;
NI32 typeId_0;
NIM_BOOL sealed;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA {
tySequence__ijtae5OneaLys0hN9alAicA* data;
NI counter;
};
struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w {
tySequence__SerjNoUujW2dUouVBrJiCw* data;
NI counter;
};
struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA {
tySequence__K9agbtcb0qPZuSJFXB9cTe6g* data;
NI counter;
};
typedef tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyArray__46hjIasL27aUz9c7kgtWooQ[5];
struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg {
tySequence__m88qdML9cQOuqGAQn6XWL1A* data;
NI counter;
};
struct tyObject_Table__1hIWbTQWYT4BmhdESze57A {
tySequence__naEbXEp9b9aiW1zXJorqf9cXQ* data;
NI counter;
};
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
};
struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw {
NI counter;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* data;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__imojfg883tkWsWJwyshGqQ {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA {
tySequence__KgiZ29chkJAD01p9aLRB32qw* data;
NI counter;
};
struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A {
tySequence__rkYRZrbHVYL3nhXlQW3K9bw* data;
NI counter;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg[65];
struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ {
tySequence__YmPd0eWfcTfrVYrthlXPYA* data;
NI counter;
};
struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__I6rzVhdiYtUh7jwWJQoeyw) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__EQOAUyRkp9c3eeiGlHvCThA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q {
tySequence__Hz5SYwQU29b9aFLt09blvVQPg* data;
NI counter;
};
struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg {
tySequence__3G9aA9cLXaPxuRxMKm3anacQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__1CO5eEh25fBKUWGagpikwg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
typedef N_NIMCALL_PTR(void, tyProc__VcUg5jOhttLagdxUmVN8Tg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__XOkru1xuh2bHzmkw1UYzLA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formal, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* actual);
struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opNot;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opContains;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLe;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLt;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAnd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opOr;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opIsNil;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opEq;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAdd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opSub;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opMul;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opDiv;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg {
tySequence__RNhZxf20g9beyq5VBOGxhDg* ifaces;
tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* packed_0;
tySequence__lFbCtu5P2Kf7YDYtGjkxAQ* encoders;
tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA typeInstCache;
tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w procInstCache;
tyArray__46hjIasL27aUz9c7kgtWooQ attachedOps;
tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg methodsPerType;
tyObject_Table__1hIWbTQWYT4BmhdESze57A enumToStringProcs;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw emittedTypeInfo;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA startupPackedConfig;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw deps;
tyObject_Table__imojfg883tkWsWJwyshGqQ importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__BCPh85PHtwxox9bv7NLFrlg inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* usageSym;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* owners;
tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA suggestSymbols;
tyObject_Table__LM44poVdVEn4Mo4N4L8c3A suggestErrors;
tySequence__IRFEb1e9bxgbJLuB5xrdZsQ* methods;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* systemModule;
tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg sysTypes;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw compilerprocs;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw exposed;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageTypes;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* emptyNode;
tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ canonTypes;
tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw symBodyHashes;
tyProc__I6rzVhdiYtUh7jwWJQoeyw importModuleCallback;
tyProc__EQOAUyRkp9c3eeiGlHvCThA includeFileCallback;
tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q cacheSeqs;
tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g cacheCounters;
tyObject_Table__R7JnJQEipxxOlJWXQz7jWg cacheTables;
tySequence__bPFv6ypvvCX2A9a9al8utL2Q* passes;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinition;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinitionResolveForward;
tyProc__1CO5eEh25fBKUWGagpikwg onUsage;
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* globalDestructors;
tyProc__VcUg5jOhttLagdxUmVN8Tg strongSemCheck;
tyProc__XOkru1xuh2bHzmkw1UYzLA compatibleProps;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg operators;
};
typedef NU8 tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg[9];
struct tyObject_HSlice__uuLFB9bRXg4euv7O8yFk6pA {
tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a;
tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b;
};
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg {
NI id;
NimStringDesc* s;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* next;
NI h;
};
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
typedef NimStringDesc* tyArray__nHXaesL0DJZHyVS07ARPRA[1];
typedef NU8 tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg;
typedef NU8 tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU8 tyEnum_Endianness__IxIU7d9c8Q9csHQviYDQM13A;
struct tyTuple__cyyQdcuoDUp88Doe6rM7kA {
NimStringDesc* Field0;
NI Field1;
tyEnum_Endianness__IxIU7d9c8Q9csHQviYDQM13A Field2;
NI Field3;
NI Field4;
};
typedef tyTuple__cyyQdcuoDUp88Doe6rM7kA tyArray__O7sksHvn7BNpHcBD2dBmog[26];
typedef NU8 tySet_tyEnum_TInfoOSProp__zwoAJqKVL5t9aBqjgBrDcAA;
struct tyTuple__oa1dFn55BmC688WoXKTtUg {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
NimStringDesc* Field3;
NimStringDesc* Field4;
NimStringDesc* Field5;
NimStringDesc* Field6;
NimStringDesc* Field7;
NimStringDesc* Field8;
NimStringDesc* Field9;
NimStringDesc* Field10;
NimStringDesc* Field11;
tySet_tyEnum_TInfoOSProp__zwoAJqKVL5t9aBqjgBrDcAA Field12;
};
typedef tyTuple__oa1dFn55BmC688WoXKTtUg tyArray__zAjcTh151RgaydpulQUcEQ[33];
typedef NU8 tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__QbmGqFaLnb1IWWToREeaIA* trace;
Exception* up;
};
struct TSafePoint {
TSafePoint* prev;
NI status;
jmp_buf context;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_HSlice__5MokM0MxT5ZF4tSog3uzVQ {
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg a;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg b;
};
typedef NU16 tySet_tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA;
typedef NU8 tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NimStringDesc* tyArray__Re75IspeoxXy2oCZHwcRrA[2];
typedef NU8 tyEnum_TNodeKind__4gPA2nKyTI2Bfe40Z7kjdg;
struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* converters;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* patterns;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* pureEnums;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interf;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interfHidden;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* uniqueName;
};
typedef NU8 tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg;
struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg {
tySequence__4Murtwnm0Fyc7F9acrytEXw* nodes;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ;
struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ {
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw {
tySequence__IHUFRsFxZNv7YydiUO2esQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag {
NimStringDesc* definedSymbols;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA moduleFlags;
tySequence__PXIzfWocnrafGz5p3CP5LA* includes;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* imports;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg toReplay;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg topLevel;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg bodies;
tySequence__b89aLriiJnVTD186H6zNIgg* exports;
tySequence__b89aLriiJnVTD186H6zNIgg* hidden;
tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw* reexports;
tySequence__b89aLriiJnVTD186H6zNIgg* compilerProcs;
tySequence__48JTohSgTy339bRxHzUD8KA* converters;
tySequence__48JTohSgTy339bRxHzUD8KA* methods;
tySequence__48JTohSgTy339bRxHzUD8KA* trmacros;
tySequence__48JTohSgTy339bRxHzUD8KA* pureEnums;
tySequence__QnmOtn1Iv4LvxOXoMn8Rbg* macroUsages;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* typeInstCache;
tySequence__qy6Iwdy00wN560qud54HTg* procInstCache;
tySequence__k67v9bwvvQDmS1ynyGGUbeQ* attachedOps;
tySequence__cLsClAAfd0MKkoBQVyvdvw* methodsPerType;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* enumToStringProcs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* emittedTypeInfo;
tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ backendFlags;
tySequence__q9bTuOB0JXh1iZ3CSGdRLbg* syms;
tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw* types;
tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ strings;
tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw numbers;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA cfg;
};
struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ {
tySequence__C3r8jsj9chA4sIlYfDN5aDw* data;
NI counter;
};
struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg {
tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg status;
NIM_BOOL symsInit;
NIM_BOOL typesInit;
NIM_BOOL loadedButAliveSetChanged;
tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag fromDisk;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* syms;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* types;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ iface;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ ifaceHidden;
};
struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ {
tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* data;
NI counter;
};
struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ {
NI32 thisModule;
NI32 lastFile;
NU32 lastLit;
tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ filenames;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* pendingTypes;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* pendingSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw typeMarker;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw symMarker;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
};
struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ {
NU32 module;
NI32 item;
};
struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg {
NI module;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ packed_0;
};
struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
};
struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__dlD6tEGzYLLpKVq3XwuFlA* Field2;
};
struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q {
NI module;
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg sym;
tySequence__UnGSk9aaLosDroi2QDrlOfQ* concreteTypes;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__rZZA0skon1OsHdiEvT8RZQ {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__6OFCSvqRaxyEgUqWtnZSlw* Field2;
};
struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field2;
};
struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
};
struct tyTuple__RWXAsQlFoGYyEQZp1G65sg {
NI Field0;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field1;
};
struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__m4PVWjcAAjfxlwJxLkKn8A* Field2;
};
struct tyTuple__RmGJuqOgEaHckHndh0LEsw {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field2;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
};
struct tyTuple__J4cxakKjhKxTIJR9bojMmXw {
NI Field0;
NI32 Field1;
tySequence__i89c5kdtWKzK3OEiI81pkkw* Field2;
};
struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ {
NI Field0;
NI32 Field1;
tySequence__GR8qmV1kNRcoQ2g76VFy3A* Field2;
};
struct tyTuple__a7QginWFapakKbWJBJ2vfA {
tySequence__ed0C0uAUZPhvw3RAc5hfYg* Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__kbX6x85REySUrk9auORL0vw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q {
tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A* root;
NI entries;
};
struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, tyProc__kqPx9c4py2HW6KcFMhNvxtg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__9c6qRjwy7Es8UkDTIUwAfFA) (tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__mv4BsRs5VEnhcxzV6pQU5w) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
struct tyTuple__nF9cH4hinXgGEUwO4G2bshw {
tyProc__kqPx9c4py2HW6KcFMhNvxtg Field0;
tyProc__9c6qRjwy7Es8UkDTIUwAfFA Field1;
tyProc__mv4BsRs5VEnhcxzV6pQU5w Field2;
NIM_BOOL Field3;
};
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA {
NCSTRING procname;
NI line;
NCSTRING filename;
};
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
NU32 Field0;
NimStringDesc* Field1;
};
struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA {
NU16 line;
NI16 col;
NU32 file;
};
struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA {
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
NI32 operand;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeId_0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
};
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
NU32 Field0;
NI32 Field1;
};
struct tyTuple__PsEhl3dzznmmJiLAuIXZOg {
NU32 Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA Field1;
};
struct tyTuple__Db8CrQifKGIsKc3w71w7Lw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ key;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* concreteTypes;
};
typedef NU8 tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ;
struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ {
tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
NI Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
typedef NU8 tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ;
struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA {
tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
NU32 name;
NI32 path;
};
struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA {
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
NU32 name;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typ;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
NI32 ast;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ guard;
NI bitsize;
NI alignment;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
NU32 externalName;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw locFlags;
tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA annex;
NI32 constraint;
};
struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw {
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* types;
NI32 n;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeInst;
NI32 nonUniqueId;
};
struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg {
NI Field0;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* Field1;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* Field2;
};
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
NI Field0;
NI32 Field1;
NU32 Field2;
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
struct tySequence__RNhZxf20g9beyq5VBOGxhDg {
  TGenericSeq Sup;
  tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ data[SEQ_DECL_SIZE];
};
struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ {
  TGenericSeq Sup;
  tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg data[SEQ_DECL_SIZE];
};
struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ {
  TGenericSeq Sup;
  tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ data[SEQ_DECL_SIZE];
};
struct tySequence__dlD6tEGzYLLpKVq3XwuFlA {
  TGenericSeq Sup;
  tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ data[SEQ_DECL_SIZE];
};
struct tySequence__ijtae5OneaLys0hN9alAicA {
  TGenericSeq Sup;
  tyTuple__UluY8x0Nj6cp9b0o88wJ0lg data[SEQ_DECL_SIZE];
};
struct tySequence__6OFCSvqRaxyEgUqWtnZSlw {
  TGenericSeq Sup;
  tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q data[SEQ_DECL_SIZE];
};
struct tySequence__SerjNoUujW2dUouVBrJiCw {
  TGenericSeq Sup;
  tyTuple__rZZA0skon1OsHdiEvT8RZQ data[SEQ_DECL_SIZE];
};
struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g {
  TGenericSeq Sup;
  tyTuple__q13Zt16VkCqu6Zg5jWqwHA data[SEQ_DECL_SIZE];
};
struct tySequence__m4PVWjcAAjfxlwJxLkKn8A {
  TGenericSeq Sup;
  tyTuple__RWXAsQlFoGYyEQZp1G65sg data[SEQ_DECL_SIZE];
};
struct tySequence__m88qdML9cQOuqGAQn6XWL1A {
  TGenericSeq Sup;
  tyTuple__aWN9bNzF9bubXNJV9ciomgpfA data[SEQ_DECL_SIZE];
};
struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ {
  TGenericSeq Sup;
  tyTuple__RmGJuqOgEaHckHndh0LEsw data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__ed0C0uAUZPhvw3RAc5hfYg {
  TGenericSeq Sup;
  tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__i89c5kdtWKzK3OEiI81pkkw {
  TGenericSeq Sup;
  tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A data[SEQ_DECL_SIZE];
};
struct tySequence__KgiZ29chkJAD01p9aLRB32qw {
  TGenericSeq Sup;
  tyTuple__J4cxakKjhKxTIJR9bojMmXw data[SEQ_DECL_SIZE];
};
struct tySequence__GR8qmV1kNRcoQ2g76VFy3A {
  TGenericSeq Sup;
  tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* data[SEQ_DECL_SIZE];
};
struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw {
  TGenericSeq Sup;
  tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ data[SEQ_DECL_SIZE];
};
struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ {
  TGenericSeq Sup;
  tyTuple__a7QginWFapakKbWJBJ2vfA data[SEQ_DECL_SIZE];
};
struct tySequence__YmPd0eWfcTfrVYrthlXPYA {
  TGenericSeq Sup;
  tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg {
  TGenericSeq Sup;
  tyTuple__kbX6x85REySUrk9auORL0vw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ {
  TGenericSeq Sup;
  tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g data[SEQ_DECL_SIZE];
};
struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q {
  TGenericSeq Sup;
  tyTuple__nF9cH4hinXgGEUwO4G2bshw data[SEQ_DECL_SIZE];
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
struct tySequence__QbmGqFaLnb1IWWToREeaIA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA data[SEQ_DECL_SIZE];
};
struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g {
  TGenericSeq Sup;
  tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg data[SEQ_DECL_SIZE];
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  TGenericSeq Sup;
  tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE];
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  TGenericSeq Sup;
  NU32 data[SEQ_DECL_SIZE];
};
struct tySequence__4Murtwnm0Fyc7F9acrytEXw {
  TGenericSeq Sup;
  tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA data[SEQ_DECL_SIZE];
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  TGenericSeq Sup;
  tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE];
};
struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw {
  TGenericSeq Sup;
  tyTuple__PsEhl3dzznmmJiLAuIXZOg data[SEQ_DECL_SIZE];
};
struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg {
  TGenericSeq Sup;
  tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w data[SEQ_DECL_SIZE];
};
struct tySequence__oKtVqsc9bQVCNyrijELM4OQ {
  TGenericSeq Sup;
  tyTuple__Db8CrQifKGIsKc3w71w7Lw data[SEQ_DECL_SIZE];
};
struct tySequence__qy6Iwdy00wN560qud54HTg {
  TGenericSeq Sup;
  tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg data[SEQ_DECL_SIZE];
};
struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ {
  TGenericSeq Sup;
  tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ data[SEQ_DECL_SIZE];
};
struct tySequence__cLsClAAfd0MKkoBQVyvdvw {
  TGenericSeq Sup;
  tyTuple__FEYH9alRJhHD0uTKF2vnIqw data[SEQ_DECL_SIZE];
};
struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg {
  TGenericSeq Sup;
  tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA data[SEQ_DECL_SIZE];
};
struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw {
  TGenericSeq Sup;
  tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw data[SEQ_DECL_SIZE];
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  TGenericSeq Sup;
  NI64 data[SEQ_DECL_SIZE];
};
struct tySequence__lo3S1lKyiPLhGGB9cBawd6A {
  TGenericSeq Sup;
  tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ data[SEQ_DECL_SIZE];
};
struct tySequence__C3r8jsj9chA4sIlYfDN5aDw {
  TGenericSeq Sup;
  tyTuple__VUJ5Hjm4tKAResBsRHJvYg data[SEQ_DECL_SIZE];
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  TGenericSeq Sup;
  tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE];
};
struct tySequence__UnGSk9aaLosDroi2QDrlOfQ {
  TGenericSeq Sup;
  tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newIntNodeT__semfold_57)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ intVal, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newIntTypeNode__ast_3793)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ intVal, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, getIntLitTypeG__semfold_51)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* literal, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, getSysType__magicsys_60)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, copyType__ast_4034)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg id, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner);
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextTypeId__ast_3122)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5302)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5264)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5309)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5307)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5258)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, getOrdValue__types_161)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ onError);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, getInt__ast_4593)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, foldUnarySub__semfold_143)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___int495056_425)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, firstOrd__types_1406)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, minus___int495056_634)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newFloatNodeT__semfold_67)(NF floatVal, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, skipTypes__ast_3723)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kinds);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newFloatNode__ast_3797)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, NF floatVal);
N_LIB_PRIVATE N_NIMCALL(NF, getFloat__ast_4608)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, minus___int495056_637)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, toInt128__int495056_909)(NI64 arg);
N_LIB_PRIVATE N_NIMCALL(NI64, cardSet__nimsets_241)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isUnsigned__types_154)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, maskBytes__int495056_1046)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ arg, NI numbytes);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, bitnot__int495056_431)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a);
N_LIB_PRIVATE N_NIMCALL(NI64, getSize__types_3382)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, lengthOrd__types_1717)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, toInt128__types_1431)(NI arg);
static N_INLINE(NI, nimCStrLen)(NCSTRING a);
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringDesc* s);
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, foldAbs__semfold_149)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, abs__int495056_644)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, foldAdd__semfold_127)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, plus___int495056_611)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, checkInRange__semfold_94)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ res);
static N_INLINE(NIM_BOOL, contains__semfold_120)(tyObject_HSlice__uuLFB9bRXg4euv7O8yFk6pA* s, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ value);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lteq___int495056_421)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b);
static N_INLINE(void, dotdot___semfold_99)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b, tyObject_HSlice__uuLFB9bRXg4euv7O8yFk6pA* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, lastOrd__types_1530)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, foldSub__semfold_135)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, foldMul__semfold_155)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, star___int495056_706)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ lhs, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ rhs);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___int495056_417)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, toInt128__semfold_268)(NI8 arg);
N_LIB_PRIVATE N_NIMCALL(NI8, toInt8__int495056_228)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ arg);
N_LIB_PRIVATE N_NIMCALL(NI64, toInt64__int495056_88)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, toInt128__semfold_292)(NI16 arg);
N_LIB_PRIVATE N_NIMCALL(NI16, toInt16__int495056_183)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, toInt128__semfold_316)(NI32 arg);
N_LIB_PRIVATE N_NIMCALL(NI32, toInt32__int495056_138)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, toInt128__semfold_361)(NU8 arg);
N_LIB_PRIVATE N_NIMCALL(NU8, toUInt8__int495056_309)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, toInt128__semfold_373)(NU16 arg);
N_LIB_PRIVATE N_NIMCALL(NU16, toUInt16__int495056_297)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, toInt128__semfold_385)(NU32 arg);
N_LIB_PRIVATE N_NIMCALL(NU32, toUInt32__int495056_285)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, toInt128__int495056_722)(NU64 arg);
N_LIB_PRIVATE N_NIMCALL(NU64, toUInt64__int495056_276)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ arg);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_1441)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, div__int495056_794)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, mod__int495056_809)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getStr__ast_4611)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a);
static N_INLINE(NI, cmpStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
static N_INLINE(NIM_BOOL, ltpercent___system_1021)(NI64 x, NI64 y);
static N_INLINE(NIM_BOOL, lteqpercent___system_1001)(NI64 x, NI64 y);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, bitand__int495056_434)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, bitor__int495056_438)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, bitxor__int495056_442)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsSets__nimsets_209)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, equalSets__nimsets_216)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, intersectSets__nimsets_195)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, unionSets__nimsets_181)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, diffSets__nimsets_188)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newStrNodeT__semfold_76)(NimStringDesc* strVal, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newStrNode__ast_3801)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, NimStringDesc* strVal);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getStrOrChar__ast_4614)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, inSet__nimsets_7)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* elem);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___int495056_53)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___int495056_952)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, NI64 b);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___system_3126)(NF x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, ordinalValToString__semfold_163)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimCharToStr)(NIM_CHAR x);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___int495056_959)(NI64 a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, typeToString__types_50)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg prefer);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, copyTree__ast_4432)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* src);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, testCompileOption__commands_574)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* switch_0, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, testCompileOptionArg__commands_473)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* switch_0, NimStringDesc* arg, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, exprStructuralEquivalent__trees_56)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b, NIM_BOOL strictSymEquality);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getDateStr__options_596)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getClockStr__options_604)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuToLowerAsciiStr)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, getAppType__semfold_665)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefined__options_2292)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* symbol);
static N_INLINE(void, pushSafePoint)(TSafePoint* s);
N_LIB_PRIVATE N_NIMCALL(NI, nsuParseInt)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc**, nstTake)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, NimStringDesc* key);
static N_INLINE(void, popSafePoint)(void);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isObj)(TNimType* obj, TNimType* subclass);
static N_INLINE(Exception*, nimBorrowCurrentException)(void);
static N_INLINE(void, popCurrentException)(void);
N_LIB_PRIVATE N_NIMCALL(void, reraiseException)(void);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, parseBool__pureZstrutils_998)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newSymNodeTypeDesc__semfold_870)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newSymNode__ast_3707)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, newType__ast_3884)(tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg id, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner);
N_LIB_PRIVATE N_NIMCALL(void, addSonSkipIntLit__magicsys_136)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* father, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* son, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* id);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, base__types_63)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
static N_INLINE(NIM_BOOL, isIntLit__types_186)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, copyNode__ast_4324)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, getConstIfExpr__semfold_584)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, getConstExpr__semfold_81)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
static N_INLINE(NIM_BOOL, contains__semfold_973)(tyObject_HSlice__5MokM0MxT5ZF4tSog3uzVQ s, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg value);
static N_INLINE(tyObject_HSlice__5MokM0MxT5ZF4tSog3uzVQ, dotdot___semfold_951)(tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg a, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg b);
N_LIB_PRIVATE N_NIMCALL(NF, firstFloat__types_1505)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(NF, lastFloat__types_1644)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, getArrayConstr__semfold_729)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, magicCall__semfold_630)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, evalOp__semfold_86)(tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* c, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(void, computeSizeAlign__types_2970)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newIntNode__ast_3711)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, NI64 intVal);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderTree__renderer_46)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA renderFlags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, foldConStrStr__semfold_850)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeIT__ast_3342)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_4798)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* son);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, leValueConv__semfold_626)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
N_LIB_PRIVATE N_NIMCALL(NF, toFloat64__int495056_994)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, foldConv__semfold_685)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NIM_BOOL check);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, toInt128__semfold_702)(NIM_BOOL arg);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__systemZassertions_56)(NimStringDesc* msg);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, toInt128__int495056_1011)(NF arg);
N_LIB_PRIVATE N_NIMCALL(void, rangeCheck__semfold_681)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ value, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(void, transitionIntKind__ast_4360)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyEnum_TNodeKind__4gPA2nKyTI2Bfe40Z7kjdg kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, foldArrayAccess__semfold_743)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___systemZdollars_6)(NI64 x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___systemZdollars_3)(NI x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___renderer_2116)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, foldFieldAccess__semfold_797)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
extern NIM_CONST tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ Max__int495056_27;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__IRrKIA9aNr9b6S9bSzM79cgt1g_2 = {
0x10, 0xa9, 0x00, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
extern NIM_CONST tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ One__int495056_8;
extern NIM_CONST tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ Zero__int495056_7;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__IRrKIA9aNr9b6S9bSzM79cgt1g_3 = {
0x10, 0xa9, 0x10, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_4, "constant folding for shl", 24);
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_6, "/home/runner/work/nightlies/nightlies/nim/compiler/semfold.nim", 62);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__IRrKIA9aNr9b6S9bSzM79cgt1g_5 = {((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_6),
((NI) 186),
((NI) 23)}
;
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_7, "constant folding for ashr", 25);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__IRrKIA9aNr9b6S9bSzM79cgt1g_8 = {((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_6),
((NI) 214),
((NI) 23)}
;
extern NIM_CONST tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ NegOne__int495056_28;
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_9, "false", 5);
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_10, "true", 4);
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_11, "ordinalValToString", 18);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__IRrKIA9aNr9b6S9bSzM79cgt1g_12 = {((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_6),
((NI) 96),
((NI) 42)}
;
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_13, "Cannot convert int literal to $1. The value is invalid.", 55);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__IRrKIA9aNr9b6S9bSzM79cgt1g_14 = {((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_6),
((NI) 103),
((NI) 14)}
;
extern NIM_CONST tyArray__O7sksHvn7BNpHcBD2dBmog CPU__platform_705;
extern NIM_CONST tyArray__zAjcTh151RgaydpulQUcEQ OS__platform_518;
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_15, "lib", 3);
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_16, "staticlib", 9);
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_17, "gui", 3);
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_18, "console", 7);
extern TNimType NTIvalueerror__5lcTdgqMq62cNGRwBb0thA_;
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_20, "{.intdefine.} const was set to an invalid integer: \'", 52);
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_21, "\'", 1);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__IRrKIA9aNr9b6S9bSzM79cgt1g_22 = {((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_6),
((NI) 514),
((NI) 22)}
;
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_24, "{.booldefine.} const was set to an invalid bool: \'", 50);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__IRrKIA9aNr9b6S9bSzM79cgt1g_25 = {((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_6),
((NI) 529),
((NI) 22)}
;
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_26, "getConstIfExpr()", 16);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__IRrKIA9aNr9b6S9bSzM79cgt1g_27 = {((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_6),
((NI) 324),
((NI) 23)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__IRrKIA9aNr9b6S9bSzM79cgt1g_29 = {
0x10, 0xa9, 0x90, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__IRrKIA9aNr9b6S9bSzM79cgt1g_30 = {
0x10, 0xa9, 0x80, 0x00, 0x00, 0xe0, 0xa0, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__IRrKIA9aNr9b6S9bSzM79cgt1g_31 = {
0x10, 0xa9, 0x80, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_32, "can\'t compute offsetof on this ast", 34);
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_34, "/home/runner/work/nightlies/nightlies/nim/compiler/sizealignoffsetimpl.nim", 74);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__IRrKIA9aNr9b6S9bSzM79cgt1g_33 = {((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_34),
((NI) 506),
((NI) 16)}
;
extern TNimType NTIoverflowdefect__CPHzAjT39bZzjUQHYEzAGaw_;
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_35, "over- or underflow", 18);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__IRrKIA9aNr9b6S9bSzM79cgt1g_36 = {((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_6),
((NI) 614),
((NI) 16)}
;
extern TNimType NTIdivbyzerodefect__1jktkmId3HEtpgl3NFg3mg_;
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_37, "division by zero", 16);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__IRrKIA9aNr9b6S9bSzM79cgt1g_38 = {((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_6),
((NI) 616),
((NI) 16)}
;
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_39, "conversion from $1 to $2 is invalid", 35);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__IRrKIA9aNr9b6S9bSzM79cgt1g_40 = {((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_6),
((NI) 668),
((NI) 16)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__IRrKIA9aNr9b6S9bSzM79cgt1g_41 = {
0x10, 0xa8, 0x10, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_42, "semfold.nim(391, 20) `false` ", 29);
extern TNimType NTIttypekind__b28l2MkhJpnFhatVrsrXpg_;
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_43, "cannot convert ", 15);
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_44, " to ", 4);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__IRrKIA9aNr9b6S9bSzM79cgt1g_45 = {((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_6),
((NI) 368),
((NI) 14)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__IRrKIA9aNr9b6S9bSzM79cgt1g_46 = {
0x10, 0x08, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00,
0x00}
;
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_47, "index out of bounds, the container is empty", 43);
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_48, "index ", 6);
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_49, " not in 0 .. ", 13);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__IRrKIA9aNr9b6S9bSzM79cgt1g_50 = {((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_6),
((NI) 442),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__IRrKIA9aNr9b6S9bSzM79cgt1g_51 = {((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_6),
((NI) 446),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__IRrKIA9aNr9b6S9bSzM79cgt1g_52 = {((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_6),
((NI) 452),
((NI) 16)}
;
STRING_LITERAL(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_53, "field not found: ", 17);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__IRrKIA9aNr9b6S9bSzM79cgt1g_54 = {((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_6),
((NI) 472),
((NI) 12)}
;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5211;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern Exception* currException__system_2566;
extern Exception* currException__system_2566;
extern Exception* currException__system_2566;
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextTypeId__ast_3122)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x) {
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*x).typeId_0 += ((NI) 1);
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	result.module = (*x).module;
	result.item = (*x).typeId_0;
	return result;
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5302)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5264)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5307)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5258((&gch__system_5211.zct), c);
}
static N_INLINE(void, decRef__system_5309)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5307(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5264(src);
		incRef__system_5302(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5264((*dest));
		decRef__system_5309(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, getIntLitTypeG__semfold_51)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* literal, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ti;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T1_;
	result = NIM_NIL;
	ti = getSysType__magicsys_60(g, (*literal).info, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31));
	T1_ = nextTypeId__ast_3122(idgen);
	result = copyType__ast_4034(ti, T1_, (*ti).owner);
	asgnRef((void**) (&(*result).n), literal);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newIntNodeT__semfold_57)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ intVal, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = newIntTypeNode__ast_3793(intVal, (*n).typ);
	{
		if (!((*(*n).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31))) goto LA3_;
		asgnRef((void**) (&(*result).typ), getIntLitTypeG__semfold_51(g, result, idgen));
	}
	LA3_: ;
	(*result).info = (*n).info;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, foldUnarySub__semfold_143)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T3_;
		NIM_BOOL T4_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T7_;
		T3_ = firstOrd__types_1406((*g).config, (*n).typ);
		T4_ = (NIM_BOOL)0;
		T4_ = eqeq___int495056_425(a, T3_);
		if (!!(T4_)) goto LA5_;
		T7_ = minus___int495056_634(a);
		result = newIntNodeT__semfold_57(T7_, n, idgen, g);
	}
	LA5_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newFloatNodeT__semfold_67)(NF floatVal, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T3_;
		T3_ = NIM_NIL;
		T3_ = skipTypes__ast_3723((*n).typ, TM__IRrKIA9aNr9b6S9bSzM79cgt1g_2);
		if (!((*T3_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 37))) goto LA4_;
		result = newFloatNode__ast_3797(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 17), floatVal);
	}
	goto LA1_;
	LA4_: ;
	{
		result = newFloatNode__ast_3797(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 16), floatVal);
	}
	LA1_: ;
	asgnRef((void**) (&(*result).typ), (*n).typ);
	(*result).info = (*n).info;
	return result;
}
static N_INLINE(NI, nimCStrLen)(NCSTRING a) {
	NI result;
	size_t T1_;
	result = (NI)0;
	T1_ = (size_t)0;
	T1_ = strlen(a);
	result = ((NI) (T1_));
	return result;
}
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringDesc* s) {
	NCSTRING result;
	result = (NCSTRING)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (s == ((NimStringDesc*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = ((*s).Sup.len == ((NI) 0));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = "";
	}
	goto LA1_;
	LA5_: ;
	{
		result = ((NCSTRING) ((*s).data));
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, foldAbs__semfold_149)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T3_;
		NIM_BOOL T4_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T7_;
		T3_ = firstOrd__types_1406((*g).config, (*n).typ);
		T4_ = (NIM_BOOL)0;
		T4_ = eqeq___int495056_425(a, T3_);
		if (!!(T4_)) goto LA5_;
		T7_ = abs__int495056_644(a);
		result = newIntNodeT__semfold_57(T7_, n, idgen, g);
	}
	LA5_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__semfold_120)(tyObject_HSlice__uuLFB9bRXg4euv7O8yFk6pA* s, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ value) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = lteq___int495056_421((*s).a, value);
	if (!(T1_)) goto LA2_;
	T1_ = lteq___int495056_421(value, (*s).b);
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(void, dotdot___semfold_99)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b, tyObject_HSlice__uuLFB9bRXg4euv7O8yFk6pA* Result) {
	nimZeroMem((void*)Result, sizeof(tyObject_HSlice__uuLFB9bRXg4euv7O8yFk6pA));
	(*Result).a = a;
	(*Result).b = b;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, checkInRange__semfold_94)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ res) {
	NIM_BOOL result;
	tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T1_;
	tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T2_;
	tyObject_HSlice__uuLFB9bRXg4euv7O8yFk6pA T3_;
	result = (NIM_BOOL)0;
	T1_ = firstOrd__types_1406(conf, (*n).typ);
	T2_ = lastOrd__types_1530(conf, (*n).typ);
	nimZeroMem((void*)(&T3_), sizeof(tyObject_HSlice__uuLFB9bRXg4euv7O8yFk6pA));
	dotdot___semfold_99(T1_, T2_, (&T3_));
	result = contains__semfold_120((&T3_), res);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, foldAdd__semfold_127)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ res;
	result = NIM_NIL;
	res = plus___int495056_611(a, b);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = checkInRange__semfold_94((*g).config, n, res);
		if (!T3_) goto LA4_;
		result = newIntNodeT__semfold_57(res, n, idgen, g);
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, foldSub__semfold_135)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ res;
	result = NIM_NIL;
	res = minus___int495056_637(a, b);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = checkInRange__semfold_94((*g).config, n, res);
		if (!T3_) goto LA4_;
		result = newIntNodeT__semfold_57(res, n, idgen, g);
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, foldMul__semfold_155)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ res;
{	result = NIM_NIL;
	res = star___int495056_706(a, b);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = checkInRange__semfold_94((*g).config, n, res);
		if (!T3_) goto LA4_;
		result = newIntNodeT__semfold_57(res, n, idgen, g);
		goto BeforeRet_;
	}
	LA4_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, cmpStrings)(NimStringDesc* a, NimStringDesc* b) {
	NI result;
	NI alen;
	NI blen;
	NI minlen;
	result = (NI)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	minlen = ((alen <= blen) ? alen : blen);
	{
		int T5_;
		if (!(((NI) 0) < minlen)) goto LA3_;
		T5_ = (int)0;
		T5_ = memcmp(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((size_t) (minlen)));
		result = ((NI) (T5_));
		{
			if (!(result == ((NI) 0))) goto LA8_;
			result = (NI)(alen - blen);
		}
		LA8_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		result = (NI)(alen - blen);
	}
	LA1_: ;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1021)(NI64 x, NI64 y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU64) (x))) < (NU64)(((NU64) (y))));
	return result;
}
static N_INLINE(NIM_BOOL, lteqpercent___system_1001)(NI64 x, NI64 y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU64) (x))) <= (NU64)(((NU64) (y))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newStrNodeT__semfold_76)(NimStringDesc* strVal, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = newStrNode__ast_3801(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20), strVal);
	asgnRef((void**) (&(*result).typ), (*n).typ);
	(*result).info = (*n).info;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, ordinalValToString__semfold_163)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	NimStringDesc* result;
	tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ x;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
{	result = NIM_NIL;
	x = getInt__ast_4593(a);
	t = skipTypes__ast_3723((*a).typ, TM__IRrKIA9aNr9b6S9bSzM79cgt1g_3);
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2):
	{
		NI64 T2_;
		T2_ = (NI64)0;
		T2_ = toInt64__int495056_88(x);
		result = nimCharToStr(((NIM_CHAR) (((NI) ((NI64)(T2_ & IL64(255)))))));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
		tyArray__nHXaesL0DJZHyVS07ARPRA T21_;
		NimStringDesc* T22_;
		n = (*t).n;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field;
					if (!(i_2 < colontmp_)) goto LA6;
					i = i_2;
					{
						if (!!(((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)))) goto LA9_;
						internalErrorImpl__msgs_1441((*g).config, (*a).info, ((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_11), TM__IRrKIA9aNr9b6S9bSzM79cgt1g_12);
					}
					LA9_: ;
					field = (*(*n)._kind_6.sons->data[i])._kind_4.sym;
					{
						NIM_BOOL T13_;
						T13_ = (NIM_BOOL)0;
						T13_ = eqeq___int495056_959(((NI64) ((*field).position)), x);
						if (!T13_) goto LA14_;
						{
							if (!((*field).ast == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA18_;
							result = copyString((*(*field).name).s);
							goto BeforeRet_;
						}
						goto LA16_;
						LA18_: ;
						{
							result = copyString((*(*field).ast)._kind_3.strVal);
							goto BeforeRet_;
						}
						LA16_: ;
					}
					LA14_: ;
					i_2 += ((NI) 1);
				} LA6: ;
			}
		}
		nimZeroMem((void*)T21_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
		T21_[0] = typeToString__types_50(t, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
		T22_ = NIM_NIL;
		T22_ = nsuFormatOpenArray(((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_13), T21_, 1);
		liMessage__msgs_1128((*g).config, (*a).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T22_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__IRrKIA9aNr9b6S9bSzM79cgt1g_14, NIM_FALSE);
	}
	break;
	default:
	{
		result = dollar___int495056_53(x);
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, evalOp__semfold_86)(tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* c, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
	switch (m) {
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 31):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T2_;
		T2_ = getOrdValue__types_161(a, Max__int495056_27);
		result = newIntNodeT__semfold_57(T2_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 43):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T4_;
		T4_ = getInt__ast_4593(a);
		result = newIntNodeT__semfold_57(T4_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 93):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 94):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T6_;
		T6_ = getInt__ast_4593(a);
		result = foldUnarySub__semfold_143(T6_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 100):
	{
		NF T8_;
		T8_ = (NF)0;
		T8_ = getFloat__ast_4608(a);
		result = newFloatNodeT__semfold_67(-(T8_), n, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 96):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T10_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T11_;
		T10_ = getInt__ast_4593(a);
		T11_ = minus___int495056_637(One__int495056_8, T10_);
		result = newIntNodeT__semfold_57(T11_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 42):
	{
		NI64 T13_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T14_;
		T13_ = (NI64)0;
		T13_ = cardSet__nimsets_241((*g).config, a);
		T14_ = toInt128__int495056_909(T13_);
		result = newIntNodeT__semfold_57(T14_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 98):
	{
		{
			NIM_BOOL T18_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T21_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T22_;
			NI64 T23_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T24_;
			T18_ = (NIM_BOOL)0;
			T18_ = isUnsigned__types_154((*n).typ);
			if (!T18_) goto LA19_;
			T21_ = getInt__ast_4593(a);
			T22_ = bitnot__int495056_431(T21_);
			T23_ = (NI64)0;
			T23_ = getSize__types_3382((*g).config, (*n).typ);
			T24_ = maskBytes__int495056_1046(T22_, ((NI) (T23_)));
			result = newIntNodeT__semfold_57(T24_, n, idgen, g);
		}
		goto LA16_;
		LA19_: ;
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T26_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T27_;
			T26_ = getInt__ast_4593(a);
			T27_ = bitnot__int495056_431(T26_);
			result = newIntNodeT__semfold_57(T27_, n, idgen, g);
		}
		LA16_: ;
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 38):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T29_;
		T29_ = lengthOrd__types_1717((*g).config, (*a).typ);
		result = newIntNodeT__semfold_57(T29_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 39):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 36):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 37):
	{
		{
			if (!((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA33_;
			result = newIntNodeT__semfold_57(Zero__int495056_7, n, idgen, g);
		}
		goto LA31_;
		LA33_: ;
		{
			if (!((*a).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) && (*a).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22))) goto LA36_;
			{
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T42_;
				if (!((*(*a).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28))) goto LA40_;
				T42_ = toInt128__types_1431(((*a)._kind_3.strVal ? (*a)._kind_3.strVal->Sup.len : 0));
				result = newIntNodeT__semfold_57(T42_, n, idgen, g);
			}
			goto LA38_;
			LA40_: ;
			{
				NI T46_;
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T47_;
				if (!((*(*a).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29))) goto LA44_;
				T46_ = (NI)0;
				T46_ = nimCStrLen(nimToCStringConv((*a)._kind_3.strVal));
				T47_ = toInt128__types_1431(T46_);
				result = newIntNodeT__semfold_57(T47_, n, idgen, g);
			}
			goto LA38_;
			LA44_: ;
			LA38_: ;
		}
		goto LA31_;
		LA36_: ;
		{
			NI T49_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T50_;
			T49_ = (NI)0;
			T49_ = len__ast_3155(a);
			T50_ = toInt128__types_1431(T49_);
			result = newIntNodeT__semfold_57(T50_, n, idgen, g);
		}
		LA31_: ;
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 97):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 99):
	{
		result = a;
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 95):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T53_;
		T53_ = getInt__ast_4593(a);
		result = foldAbs__semfold_149(T53_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 51):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T55_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T56_;
		T55_ = getOrdValue__types_161(a, Max__int495056_27);
		T56_ = getInt__ast_4593(b);
		result = foldAdd__semfold_127(T55_, T56_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 52):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T58_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T59_;
		T58_ = getOrdValue__types_161(a, Max__int495056_27);
		T59_ = getInt__ast_4593(b);
		result = foldSub__semfold_135(T58_, T59_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 46):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T61_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T62_;
		T61_ = getInt__ast_4593(a);
		T62_ = getInt__ast_4593(b);
		result = foldAdd__semfold_127(T61_, T62_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 47):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T64_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T65_;
		T64_ = getInt__ast_4593(a);
		T65_ = getInt__ast_4593(b);
		result = foldSub__semfold_135(T64_, T65_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 48):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T67_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T68_;
		T67_ = getInt__ast_4593(a);
		T68_ = getInt__ast_4593(b);
		result = foldMul__semfold_155(T67_, T68_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 63):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ argA;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ argB;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T70_;
		argA = getInt__ast_4593(a);
		argB = getInt__ast_4593(b);
		{
			NIM_BOOL T73_;
			T73_ = (NIM_BOOL)0;
			T73_ = lt___int495056_417(argA, argB);
			if (!T73_) goto LA74_;
			T70_ = argA;
		}
		goto LA71_;
		LA74_: ;
		{
			T70_ = argB;
		}
		LA71_: ;
		result = newIntNodeT__semfold_57(T70_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 64):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ argA_2;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ argB_2;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T78_;
		argA_2 = getInt__ast_4593(a);
		argB_2 = getInt__ast_4593(b);
		{
			NIM_BOOL T81_;
			T81_ = (NIM_BOOL)0;
			T81_ = lt___int495056_417(argB_2, argA_2);
			if (!T81_) goto LA82_;
			T78_ = argA_2;
		}
		goto LA79_;
		LA82_: ;
		{
			T78_ = argB_2;
		}
		LA79_: ;
		result = newIntNodeT__semfold_57(T78_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 58):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T86_;
		T86_ = NIM_NIL;
		T86_ = skipTypes__ast_3723((*n).typ, TM__IRrKIA9aNr9b6S9bSzM79cgt1g_3);
		switch ((*T86_).kind) {
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 32):
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T88_;
			NI8 T89_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T90_;
			NI64 T91_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T92_;
			T88_ = getInt__ast_4593(a);
			T89_ = (NI8)0;
			T89_ = toInt8__int495056_228(T88_);
			T90_ = getInt__ast_4593(b);
			T91_ = (NI64)0;
			T91_ = toInt64__int495056_88(T90_);
			T92_ = toInt128__semfold_268((NI8)((NU64)(T89_) << (NU64)(T91_)));
			result = newIntNodeT__semfold_57(T92_, n, idgen, g);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 33):
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T94_;
			NI16 T95_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T96_;
			NI64 T97_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T98_;
			T94_ = getInt__ast_4593(a);
			T95_ = (NI16)0;
			T95_ = toInt16__int495056_183(T94_);
			T96_ = getInt__ast_4593(b);
			T97_ = (NI64)0;
			T97_ = toInt64__int495056_88(T96_);
			T98_ = toInt128__semfold_292((NI16)((NU64)(T95_) << (NU64)(T97_)));
			result = newIntNodeT__semfold_57(T98_, n, idgen, g);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 34):
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T100_;
			NI32 T101_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T102_;
			NI64 T103_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T104_;
			T100_ = getInt__ast_4593(a);
			T101_ = (NI32)0;
			T101_ = toInt32__int495056_138(T100_);
			T102_ = getInt__ast_4593(b);
			T103_ = (NI64)0;
			T103_ = toInt64__int495056_88(T102_);
			T104_ = toInt128__semfold_316((NI32)((NU64)(T101_) << (NU64)(T103_)));
			result = newIntNodeT__semfold_57(T104_, n, idgen, g);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35):
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T106_;
			NI64 T107_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T108_;
			NI64 T109_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T110_;
			T106_ = getInt__ast_4593(a);
			T107_ = (NI64)0;
			T107_ = toInt64__int495056_88(T106_);
			T108_ = getInt__ast_4593(b);
			T109_ = (NI64)0;
			T109_ = toInt64__int495056_88(T108_);
			T110_ = toInt128__int495056_909((NI64)((NU64)(T107_) << (NU64)(T109_)));
			result = newIntNodeT__semfold_57(T110_, n, idgen, g);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31):
		{
			{
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T116_;
				NI32 T117_;
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T118_;
				NI64 T119_;
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T120_;
				if (!((*(*g).config).target.intSize == ((NI) 4))) goto LA114_;
				T116_ = getInt__ast_4593(a);
				T117_ = (NI32)0;
				T117_ = toInt32__int495056_138(T116_);
				T118_ = getInt__ast_4593(b);
				T119_ = (NI64)0;
				T119_ = toInt64__int495056_88(T118_);
				T120_ = toInt128__semfold_316((NI32)((NU64)(T117_) << (NU64)(T119_)));
				result = newIntNodeT__semfold_57(T120_, n, idgen, g);
			}
			goto LA112_;
			LA114_: ;
			{
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T122_;
				NI64 T123_;
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T124_;
				NI64 T125_;
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T126_;
				T122_ = getInt__ast_4593(a);
				T123_ = (NI64)0;
				T123_ = toInt64__int495056_88(T122_);
				T124_ = getInt__ast_4593(b);
				T125_ = (NI64)0;
				T125_ = toInt64__int495056_88(T124_);
				T126_ = toInt128__int495056_909((NI64)((NU64)(T123_) << (NU64)(T125_)));
				result = newIntNodeT__semfold_57(T126_, n, idgen, g);
			}
			LA112_: ;
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 41):
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T128_;
			NU8 T129_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T130_;
			NI64 T131_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T132_;
			T128_ = getInt__ast_4593(a);
			T129_ = (NU8)0;
			T129_ = toUInt8__int495056_309(T128_);
			T130_ = getInt__ast_4593(b);
			T131_ = (NI64)0;
			T131_ = toInt64__int495056_88(T130_);
			T132_ = toInt128__semfold_361((NU8)((NU64)(T129_) << (NU64)(T131_)));
			result = newIntNodeT__semfold_57(T132_, n, idgen, g);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 42):
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T134_;
			NU16 T135_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T136_;
			NI64 T137_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T138_;
			T134_ = getInt__ast_4593(a);
			T135_ = (NU16)0;
			T135_ = toUInt16__int495056_297(T134_);
			T136_ = getInt__ast_4593(b);
			T137_ = (NI64)0;
			T137_ = toInt64__int495056_88(T136_);
			T138_ = toInt128__semfold_373((NU16)((NU64)(T135_) << (NU64)(T137_)));
			result = newIntNodeT__semfold_57(T138_, n, idgen, g);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 43):
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T140_;
			NU32 T141_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T142_;
			NI64 T143_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T144_;
			T140_ = getInt__ast_4593(a);
			T141_ = (NU32)0;
			T141_ = toUInt32__int495056_285(T140_);
			T142_ = getInt__ast_4593(b);
			T143_ = (NI64)0;
			T143_ = toInt64__int495056_88(T142_);
			T144_ = toInt128__semfold_385((NU32)((NU64)(T141_) << (NU64)(T143_)));
			result = newIntNodeT__semfold_57(T144_, n, idgen, g);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44):
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T146_;
			NU64 T147_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T148_;
			NI64 T149_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T150_;
			T146_ = getInt__ast_4593(a);
			T147_ = (NU64)0;
			T147_ = toUInt64__int495056_276(T146_);
			T148_ = getInt__ast_4593(b);
			T149_ = (NI64)0;
			T149_ = toInt64__int495056_88(T148_);
			T150_ = toInt128__int495056_722((NU64)((NU64)(T147_) << (NU64)(T149_)));
			result = newIntNodeT__semfold_57(T150_, n, idgen, g);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40):
		{
			{
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T156_;
				NU32 T157_;
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T158_;
				NI64 T159_;
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T160_;
				if (!((*(*g).config).target.intSize == ((NI) 4))) goto LA154_;
				T156_ = getInt__ast_4593(a);
				T157_ = (NU32)0;
				T157_ = toUInt32__int495056_285(T156_);
				T158_ = getInt__ast_4593(b);
				T159_ = (NI64)0;
				T159_ = toInt64__int495056_88(T158_);
				T160_ = toInt128__semfold_385((NU32)((NU64)(T157_) << (NU64)(T159_)));
				result = newIntNodeT__semfold_57(T160_, n, idgen, g);
			}
			goto LA152_;
			LA154_: ;
			{
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T162_;
				NU64 T163_;
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T164_;
				NI64 T165_;
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T166_;
				T162_ = getInt__ast_4593(a);
				T163_ = (NU64)0;
				T163_ = toUInt64__int495056_276(T162_);
				T164_ = getInt__ast_4593(b);
				T165_ = (NI64)0;
				T165_ = toInt64__int495056_88(T164_);
				T166_ = toInt128__int495056_722((NU64)((NU64)(T163_) << (NU64)(T165_)));
				result = newIntNodeT__semfold_57(T166_, n, idgen, g);
			}
			LA152_: ;
		}
		break;
		default:
		{
			internalErrorImpl__msgs_1441((*g).config, (*n).info, ((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_4), TM__IRrKIA9aNr9b6S9bSzM79cgt1g_5);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 57):
	{
		NU64 a_2;
		union { tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ source; NU64 dest; } LOC169;
		NU64 b_2;
		union { tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ source; NU64 dest; } LOC170;
		NI64 c_2;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T185_;
		LOC169.source = getInt__ast_4593(a);
		a_2 = LOC169.dest;
		LOC170.source = getInt__ast_4593(b);
		b_2 = LOC170.dest;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T175_;
			if (!((NU64)(0ULL) < (NU64)(b_2))) goto LA173_;
			T175_ = NIM_NIL;
			T175_ = skipTypes__ast_3723((*n).typ, TM__IRrKIA9aNr9b6S9bSzM79cgt1g_3);
			switch ((*T175_).kind) {
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 32):
			{
				a_2 = (NU64)(a_2 & 255ULL);
			}
			break;
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 33):
			{
				a_2 = (NU64)(a_2 & 65535ULL);
			}
			break;
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 34):
			{
				a_2 = (NU64)(a_2 & 4294967295ULL);
			}
			break;
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31):
			{
				{
					if (!((*(*g).config).target.intSize == ((NI) 4))) goto LA182_;
					a_2 = (NU64)(a_2 & 4294967295ULL);
				}
				LA182_: ;
			}
			break;
			default:
			{
			}
			break;
			}
		}
		LA173_: ;
		c_2 = ((NI64) ((NU64)((NU64)(a_2) >> (NU64)(b_2))));
		T185_ = toInt128__int495056_909(c_2);
		result = newIntNodeT__semfold_57(T185_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 59):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T187_;
		T187_ = NIM_NIL;
		T187_ = skipTypes__ast_3723((*n).typ, TM__IRrKIA9aNr9b6S9bSzM79cgt1g_3);
		switch ((*T187_).kind) {
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 32):
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T189_;
			NI8 T190_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T191_;
			NI8 T192_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T193_;
			T189_ = getInt__ast_4593(a);
			T190_ = (NI8)0;
			T190_ = toInt8__int495056_228(T189_);
			T191_ = getInt__ast_4593(b);
			T192_ = (NI8)0;
			T192_ = toInt8__int495056_228(T191_);
			T193_ = toInt128__semfold_268((NI8)((NI8)(T190_) >> (NU8)(T192_)));
			result = newIntNodeT__semfold_57(T193_, n, idgen, g);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 33):
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T195_;
			NI16 T196_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T197_;
			NI16 T198_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T199_;
			T195_ = getInt__ast_4593(a);
			T196_ = (NI16)0;
			T196_ = toInt16__int495056_183(T195_);
			T197_ = getInt__ast_4593(b);
			T198_ = (NI16)0;
			T198_ = toInt16__int495056_183(T197_);
			T199_ = toInt128__semfold_292((NI16)((NI16)(T196_) >> (NU16)(T198_)));
			result = newIntNodeT__semfold_57(T199_, n, idgen, g);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 34):
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T201_;
			NI32 T202_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T203_;
			NI32 T204_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T205_;
			T201_ = getInt__ast_4593(a);
			T202_ = (NI32)0;
			T202_ = toInt32__int495056_138(T201_);
			T203_ = getInt__ast_4593(b);
			T204_ = (NI32)0;
			T204_ = toInt32__int495056_138(T203_);
			T205_ = toInt128__semfold_316((NI32)((NI32)(T202_) >> (NU32)(T204_)));
			result = newIntNodeT__semfold_57(T205_, n, idgen, g);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35):
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31):
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T207_;
			NI64 T208_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T209_;
			NI64 T210_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T211_;
			T207_ = getInt__ast_4593(a);
			T208_ = (NI64)0;
			T208_ = toInt64__int495056_88(T207_);
			T209_ = getInt__ast_4593(b);
			T210_ = (NI64)0;
			T210_ = toInt64__int495056_88(T209_);
			T211_ = toInt128__int495056_909((NI64)((NI64)(T208_) >> (NU64)(T210_)));
			result = newIntNodeT__semfold_57(T211_, n, idgen, g);
		}
		break;
		default:
		{
			internalErrorImpl__msgs_1441((*g).config, (*n).info, ((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_7), TM__IRrKIA9aNr9b6S9bSzM79cgt1g_8);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 49):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ argA_3;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ argB_3;
		argA_3 = getInt__ast_4593(a);
		argB_3 = getInt__ast_4593(b);
		{
			NIM_BOOL T216_;
			NIM_BOOL T217_;
			NIM_BOOL T219_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T220_;
			NIM_BOOL T221_;
			NIM_BOOL T223_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T226_;
			T216_ = (NIM_BOOL)0;
			T217_ = (NIM_BOOL)0;
			T217_ = eqeq___int495056_425(argB_3, Zero__int495056_7);
			T216_ = !(T217_);
			if (!(T216_)) goto LA218_;
			T219_ = (NIM_BOOL)0;
			T220_ = firstOrd__types_1406((*g).config, (*n).typ);
			T221_ = (NIM_BOOL)0;
			T221_ = eqeq___int495056_425(argA_3, T220_);
			T219_ = !(T221_);
			if (T219_) goto LA222_;
			T223_ = (NIM_BOOL)0;
			T223_ = eqeq___int495056_425(argB_3, NegOne__int495056_28);
			T219_ = !(T223_);
			LA222_: ;
			T216_ = T219_;
			LA218_: ;
			if (!T216_) goto LA224_;
			T226_ = div__int495056_794(argA_3, argB_3);
			result = newIntNodeT__semfold_57(T226_, n, idgen, g);
		}
		LA224_: ;
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 50):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ argA_4;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ argB_4;
		argA_4 = getInt__ast_4593(a);
		argB_4 = getInt__ast_4593(b);
		{
			NIM_BOOL T230_;
			NIM_BOOL T231_;
			NIM_BOOL T233_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T234_;
			NIM_BOOL T235_;
			NIM_BOOL T237_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T240_;
			T230_ = (NIM_BOOL)0;
			T231_ = (NIM_BOOL)0;
			T231_ = eqeq___int495056_425(argB_4, Zero__int495056_7);
			T230_ = !(T231_);
			if (!(T230_)) goto LA232_;
			T233_ = (NIM_BOOL)0;
			T234_ = firstOrd__types_1406((*g).config, (*n).typ);
			T235_ = (NIM_BOOL)0;
			T235_ = eqeq___int495056_425(argA_4, T234_);
			T233_ = !(T235_);
			if (T233_) goto LA236_;
			T237_ = (NIM_BOOL)0;
			T237_ = eqeq___int495056_425(argB_4, NegOne__int495056_28);
			T233_ = !(T237_);
			LA236_: ;
			T230_ = T233_;
			LA232_: ;
			if (!T230_) goto LA238_;
			T240_ = mod__int495056_809(argA_4, argB_4);
			result = newIntNodeT__semfold_57(T240_, n, idgen, g);
		}
		LA238_: ;
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 53):
	{
		NF T242_;
		NF T243_;
		T242_ = (NF)0;
		T242_ = getFloat__ast_4608(a);
		T243_ = (NF)0;
		T243_ = getFloat__ast_4608(b);
		result = newFloatNodeT__semfold_67(((NF)(T242_) + (NF)(T243_)), n, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 54):
	{
		NF T245_;
		NF T246_;
		T245_ = (NF)0;
		T245_ = getFloat__ast_4608(a);
		T246_ = (NF)0;
		T246_ = getFloat__ast_4608(b);
		result = newFloatNodeT__semfold_67(((NF)(T245_) - (NF)(T246_)), n, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 55):
	{
		NF T248_;
		NF T249_;
		T248_ = (NF)0;
		T248_ = getFloat__ast_4608(a);
		T249_ = (NF)0;
		T249_ = getFloat__ast_4608(b);
		result = newFloatNodeT__semfold_67(((NF)(T248_) * (NF)(T249_)), n, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 56):
	{
		NF T251_;
		NF T252_;
		T251_ = (NF)0;
		T251_ = getFloat__ast_4608(a);
		T252_ = (NF)0;
		T252_ = getFloat__ast_4608(b);
		result = newFloatNodeT__semfold_67(((NF)(T251_) / (NF)(T252_)), n, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 143):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T254_;
		T254_ = toInt128__types_1431(((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23)));
		result = newIntNodeT__semfold_57(T254_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 72):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 86):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 80):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 83):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T256_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T257_;
		NIM_BOOL T258_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T259_;
		T256_ = getOrdValue__types_161(a, Max__int495056_27);
		T257_ = getOrdValue__types_161(b, Max__int495056_27);
		T258_ = (NIM_BOOL)0;
		T258_ = lt___int495056_417(T256_, T257_);
		T259_ = toInt128__types_1431(T258_);
		result = newIntNodeT__semfold_57(T259_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 71):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 85):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 79):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 82):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T261_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T262_;
		NIM_BOOL T263_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T264_;
		T261_ = getOrdValue__types_161(a, Max__int495056_27);
		T262_ = getOrdValue__types_161(b, Max__int495056_27);
		T263_ = (NIM_BOOL)0;
		T263_ = lteq___int495056_421(T261_, T262_);
		T264_ = toInt128__types_1431(T263_);
		result = newIntNodeT__semfold_57(T264_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 70):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 84):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 78):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 81):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T266_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T267_;
		NIM_BOOL T268_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T269_;
		T266_ = getOrdValue__types_161(a, Max__int495056_27);
		T267_ = getOrdValue__types_161(b, Max__int495056_27);
		T268_ = (NIM_BOOL)0;
		T268_ = eqeq___int495056_425(T266_, T267_);
		T269_ = toInt128__types_1431(T268_);
		result = newIntNodeT__semfold_57(T269_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 75):
	{
		NF T271_;
		NF T272_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T273_;
		T271_ = (NF)0;
		T271_ = getFloat__ast_4608(a);
		T272_ = (NF)0;
		T272_ = getFloat__ast_4608(b);
		T273_ = toInt128__types_1431((T271_ < T272_));
		result = newIntNodeT__semfold_57(T273_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 74):
	{
		NF T275_;
		NF T276_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T277_;
		T275_ = (NF)0;
		T275_ = getFloat__ast_4608(a);
		T276_ = (NF)0;
		T276_ = getFloat__ast_4608(b);
		T277_ = toInt128__types_1431((T275_ <= T276_));
		result = newIntNodeT__semfold_57(T277_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 73):
	{
		NF T279_;
		NF T280_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T281_;
		T279_ = (NF)0;
		T279_ = getFloat__ast_4608(a);
		T280_ = (NF)0;
		T280_ = getFloat__ast_4608(b);
		T281_ = toInt128__types_1431((T279_ == T280_));
		result = newIntNodeT__semfold_57(T281_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 118):
	{
		NimStringDesc* T283_;
		NimStringDesc* T284_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T285_;
		T283_ = NIM_NIL;
		T283_ = getStr__ast_4611(a);
		T284_ = NIM_NIL;
		T284_ = getStr__ast_4611(b);
		T285_ = toInt128__types_1431((cmpStrings(T283_, T284_) < 0));
		result = newIntNodeT__semfold_57(T285_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 117):
	{
		NimStringDesc* T287_;
		NimStringDesc* T288_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T289_;
		T287_ = NIM_NIL;
		T287_ = getStr__ast_4611(a);
		T288_ = NIM_NIL;
		T288_ = getStr__ast_4611(b);
		T289_ = toInt128__types_1431((cmpStrings(T287_, T288_) <= 0));
		result = newIntNodeT__semfold_57(T289_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 116):
	{
		NimStringDesc* T291_;
		NimStringDesc* T292_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T293_;
		T291_ = NIM_NIL;
		T291_ = getStr__ast_4611(a);
		T292_ = NIM_NIL;
		T292_ = getStr__ast_4611(b);
		T293_ = toInt128__types_1431(eqStrings(T291_, T292_));
		result = newIntNodeT__semfold_57(T293_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 77):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T295_;
		NI64 T296_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T297_;
		NI64 T298_;
		NIM_BOOL T299_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T300_;
		T295_ = getOrdValue__types_161(a, Max__int495056_27);
		T296_ = (NI64)0;
		T296_ = toInt64__int495056_88(T295_);
		T297_ = getOrdValue__types_161(b, Max__int495056_27);
		T298_ = (NI64)0;
		T298_ = toInt64__int495056_88(T297_);
		T299_ = (NIM_BOOL)0;
		T299_ = ltpercent___system_1021(T296_, T298_);
		T300_ = toInt128__types_1431(T299_);
		result = newIntNodeT__semfold_57(T300_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 76):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T302_;
		NI64 T303_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T304_;
		NI64 T305_;
		NIM_BOOL T306_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T307_;
		T302_ = getOrdValue__types_161(a, Max__int495056_27);
		T303_ = (NI64)0;
		T303_ = toInt64__int495056_88(T302_);
		T304_ = getOrdValue__types_161(b, Max__int495056_27);
		T305_ = (NI64)0;
		T305_ = toInt64__int495056_88(T304_);
		T306_ = (NIM_BOOL)0;
		T306_ = lteqpercent___system_1001(T303_, T305_);
		T307_ = toInt128__types_1431(T306_);
		result = newIntNodeT__semfold_57(T307_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 60):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 109):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T309_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T310_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T311_;
		T309_ = getInt__ast_4593(a);
		T310_ = getInt__ast_4593(b);
		T311_ = bitand__int495056_434(T309_, T310_);
		result = newIntNodeT__semfold_57(T311_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 61):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 110):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T313_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T314_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T315_;
		T313_ = getInt__ast_4593(a);
		T314_ = getInt__ast_4593(b);
		T315_ = bitor__int495056_438(T313_, T314_);
		result = newIntNodeT__semfold_57(T315_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 62):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 90):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T317_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T318_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T319_;
		T317_ = getInt__ast_4593(a);
		T318_ = getInt__ast_4593(b);
		T319_ = bitxor__int495056_442(T317_, T318_);
		result = newIntNodeT__semfold_57(T319_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 65):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ val;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T321_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T322_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T323_;
		NI64 T324_;
		T321_ = getInt__ast_4593(a);
		T322_ = getInt__ast_4593(b);
		T323_ = plus___int495056_611(T321_, T322_);
		T324_ = (NI64)0;
		T324_ = getSize__types_3382((*g).config, (*n).typ);
		val = maskBytes__int495056_1046(T323_, ((NI) (T324_)));
		result = newIntNodeT__semfold_57(val, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 66):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ val_2;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T326_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T327_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T328_;
		NI64 T329_;
		T326_ = getInt__ast_4593(a);
		T327_ = getInt__ast_4593(b);
		T328_ = minus___int495056_637(T326_, T327_);
		T329_ = (NI64)0;
		T329_ = getSize__types_3382((*g).config, (*n).typ);
		val_2 = maskBytes__int495056_1046(T328_, ((NI) (T329_)));
		result = newIntNodeT__semfold_57(val_2, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 67):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ val_3;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T331_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T332_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T333_;
		NI64 T334_;
		T331_ = getInt__ast_4593(a);
		T332_ = getInt__ast_4593(b);
		T333_ = star___int495056_706(T331_, T332_);
		T334_ = (NI64)0;
		T334_ = getSize__types_3382((*g).config, (*n).typ);
		val_3 = maskBytes__int495056_1046(T333_, ((NI) (T334_)));
		result = newIntNodeT__semfold_57(val_3, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 69):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ argA_5;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T336_;
		NI64 T337_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ argB_5;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T338_;
		NI64 T339_;
		T336_ = getInt__ast_4593(a);
		T337_ = (NI64)0;
		T337_ = getSize__types_3382((*g).config, (*a).typ);
		argA_5 = maskBytes__int495056_1046(T336_, ((NI) (T337_)));
		T338_ = getInt__ast_4593(b);
		T339_ = (NI64)0;
		T339_ = getSize__types_3382((*g).config, (*a).typ);
		argB_5 = maskBytes__int495056_1046(T338_, ((NI) (T339_)));
		{
			NIM_BOOL T342_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T345_;
			T342_ = (NIM_BOOL)0;
			T342_ = eqeq___int495056_425(argB_5, Zero__int495056_7);
			if (!!(T342_)) goto LA343_;
			T345_ = mod__int495056_809(argA_5, argB_5);
			result = newIntNodeT__semfold_57(T345_, n, idgen, g);
		}
		LA343_: ;
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 68):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ argA_6;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T347_;
		NI64 T348_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ argB_6;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T349_;
		NI64 T350_;
		T347_ = getInt__ast_4593(a);
		T348_ = (NI64)0;
		T348_ = getSize__types_3382((*g).config, (*a).typ);
		argA_6 = maskBytes__int495056_1046(T347_, ((NI) (T348_)));
		T349_ = getInt__ast_4593(b);
		T350_ = (NI64)0;
		T350_ = getSize__types_3382((*g).config, (*a).typ);
		argB_6 = maskBytes__int495056_1046(T349_, ((NI) (T350_)));
		{
			NIM_BOOL T353_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T356_;
			T353_ = (NIM_BOOL)0;
			T353_ = eqeq___int495056_425(argB_6, Zero__int495056_7);
			if (!!(T353_)) goto LA354_;
			T356_ = div__int495056_794(argA_6, argB_6);
			result = newIntNodeT__semfold_57(T356_, n, idgen, g);
		}
		LA354_: ;
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 120):
	{
		NIM_BOOL T358_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T359_;
		T358_ = (NIM_BOOL)0;
		T358_ = containsSets__nimsets_209((*g).config, a, b);
		T359_ = toInt128__types_1431(T358_);
		result = newIntNodeT__semfold_57(T359_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 119):
	{
		NIM_BOOL T361_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T362_;
		T361_ = (NIM_BOOL)0;
		T361_ = equalSets__nimsets_216((*g).config, a, b);
		T362_ = toInt128__types_1431(T361_);
		result = newIntNodeT__semfold_57(T362_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 121):
	{
		NIM_BOOL T364_;
		NIM_BOOL T366_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T367_;
		T364_ = (NIM_BOOL)0;
		T364_ = containsSets__nimsets_209((*g).config, a, b);
		if (!(T364_)) goto LA365_;
		T366_ = (NIM_BOOL)0;
		T366_ = equalSets__nimsets_216((*g).config, a, b);
		T364_ = !(T366_);
		LA365_: ;
		T367_ = toInt128__types_1431(T364_);
		result = newIntNodeT__semfold_57(T367_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 122):
	{
		result = intersectSets__nimsets_195((*g).config, a, b);
		(*result).info = (*n).info;
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 123):
	{
		result = unionSets__nimsets_181((*g).config, a, b);
		(*result).info = (*n).info;
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 124):
	{
		result = diffSets__nimsets_188((*g).config, a, b);
		(*result).info = (*n).info;
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 125):
	{
		NimStringDesc* T372_;
		NimStringDesc* T373_;
		NimStringDesc* T374_;
		T372_ = NIM_NIL;
		T373_ = NIM_NIL;
		T373_ = getStrOrChar__ast_4614(a);
		T374_ = NIM_NIL;
		T374_ = getStrOrChar__ast_4614(b);
		T372_ = rawNewString((T373_ ? T373_->Sup.len : 0) + (T374_ ? T374_->Sup.len : 0) + 0);
appendString(T372_, T373_);
appendString(T372_, T374_);
		result = newStrNodeT__semfold_76(T372_, n, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 134):
	{
		NIM_BOOL T376_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T377_;
		T376_ = (NIM_BOOL)0;
		T376_ = inSet__nimsets_7(a, b);
		T377_ = toInt128__types_1431(T376_);
		result = newIntNodeT__semfold_57(T377_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 135):
	{
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 103):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 104):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T380_;
		NimStringDesc* T381_;
		T380_ = getOrdValue__types_161(a, Max__int495056_27);
		T381_ = NIM_NIL;
		T381_ = dollar___int495056_53(T380_);
		result = newStrNodeT__semfold_76(T381_, n, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 102):
	{
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T385_;
			NIM_BOOL T386_;
			T385_ = getOrdValue__types_161(a, Max__int495056_27);
			T386_ = (NIM_BOOL)0;
			T386_ = eqeq___int495056_952(T385_, IL64(0));
			if (!T386_) goto LA387_;
			result = newStrNodeT__semfold_76(((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_9), n, g);
		}
		goto LA383_;
		LA387_: ;
		{
			result = newStrNodeT__semfold_76(((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_10), n, g);
		}
		LA383_: ;
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 105):
	{
		NF T391_;
		NimStringDesc* T392_;
		T391_ = (NF)0;
		T391_ = getFloat__ast_4608(a);
		T392_ = NIM_NIL;
		T392_ = dollar___system_3126(T391_);
		result = newStrNodeT__semfold_76(T392_, n, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 106):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 101):
	{
		NimStringDesc* T394_;
		T394_ = NIM_NIL;
		T394_ = getStrOrChar__ast_4614(a);
		result = newStrNodeT__semfold_76(T394_, n, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 107):
	{
		NimStringDesc* T396_;
		T396_ = NIM_NIL;
		T396_ = getStrOrChar__ast_4614(a);
		result = newStrNodeT__semfold_76(T396_, n, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 108):
	{
		NimStringDesc* T398_;
		T398_ = NIM_NIL;
		T398_ = ordinalValToString__semfold_163(a, g);
		result = newStrNodeT__semfold_76(T398_, n, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 144):
	{
		result = copyTree__ast_4432(a);
		asgnRef((void**) (&(*result).typ), (*n).typ);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 211):
	{
		NimStringDesc* T401_;
		NIM_BOOL T402_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T403_;
		T401_ = NIM_NIL;
		T401_ = getStr__ast_4611(a);
		T402_ = (NIM_BOOL)0;
		T402_ = testCompileOption__commands_574((*g).config, T401_, (*n).info);
		T403_ = toInt128__types_1431(T402_);
		result = newIntNodeT__semfold_57(T403_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 212):
	{
		NimStringDesc* T405_;
		NimStringDesc* T406_;
		NIM_BOOL T407_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T408_;
		T405_ = NIM_NIL;
		T405_ = getStr__ast_4611(a);
		T406_ = NIM_NIL;
		T406_ = getStr__ast_4611(b);
		T407_ = (NIM_BOOL)0;
		T407_ = testCompileOptionArg__commands_473((*g).config, T405_, T406_, (*n).info);
		T408_ = toInt128__types_1431(T407_);
		result = newIntNodeT__semfold_57(T408_, n, idgen, g);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 92):
	{
		NIM_BOOL T410_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T411_;
		T410_ = (NIM_BOOL)0;
		T410_ = exprStructuralEquivalent__trees_56(a, b, NIM_TRUE);
		T411_ = toInt128__types_1431(T410_);
		result = newIntNodeT__semfold_57(T411_, n, idgen, g);
	}
	break;
	default:
	{
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, getAppType__semfold_665)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	{
		if (!(((*(*g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 7))&63U)))!=0)) goto LA3_;
		result = newStrNodeT__semfold_76(((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_15), n, g);
	}
	goto LA1_;
	LA3_: ;
	{
		if (!(((*(*g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 8))&63U)))!=0)) goto LA6_;
		result = newStrNodeT__semfold_76(((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_16), n, g);
	}
	goto LA1_;
	LA6_: ;
	{
		if (!(((*(*g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 9))&63U)))!=0)) goto LA9_;
		result = newStrNodeT__semfold_76(((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_17), n, g);
	}
	goto LA1_;
	LA9_: ;
	{
		result = newStrNodeT__semfold_76(((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_18), n, g);
	}
	LA1_: ;
	return result;
}
static N_INLINE(void, pushSafePoint)(TSafePoint* s) {
	(*s).prev = excHandler__system_2565;
	excHandler__system_2565 = s;
}
static N_INLINE(void, popSafePoint)(void) {
	excHandler__system_2565 = (*excHandler__system_2565).prev;
}
static N_INLINE(Exception*, nimBorrowCurrentException)(void) {
	Exception* result;
	result = NIM_NIL;
	result = currException__system_2566;
	return result;
}
static N_INLINE(void, popCurrentException)(void) {
	asgnRef((void**) (&currException__system_2566), (*currException__system_2566).up);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newSymNodeTypeDesc__semfold_870)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = newSymNode__ast_3707(s, info);
	{
		tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T5_;
		if (!!(((*(*s).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8)))) goto LA3_;
		T5_ = nextTypeId__ast_3122(idgen);
		asgnRef((void**) (&(*result).typ), newType__ast_3884(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8), T5_, (*s).owner));
		addSonSkipIntLit__magicsys_136((*result).typ, (*s).typ, idgen);
	}
	goto LA1_;
	LA3_: ;
	{
		asgnRef((void**) (&(*result).typ), (*s).typ);
	}
	LA1_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isIntLit__types_186)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31));
	if (!(T2_)) goto LA3_;
	T2_ = !(((*t).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = ((*(*t).n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6));
	LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, getConstIfExpr__semfold_584)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
{	result = NIM_NIL;
	result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				it = (*n)._kind_6.sons->data[i];
				{
					NI T6_;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e;
					T6_ = (NI)0;
					T6_ = len__ast_3155(it);
					if (!(T6_ == ((NI) 2))) goto LA7_;
					e = getConstExpr__semfold_81(c, (*it)._kind_6.sons->data[((NI) 0)], idgen, g);
					{
						if (!(e == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA11_;
						result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
						goto BeforeRet_;
					}
					LA11_: ;
					{
						tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T15_;
						NIM_BOOL T16_;
						T15_ = getOrdValue__types_161(e, Max__int495056_27);
						T16_ = (NIM_BOOL)0;
						T16_ = eqeq___int495056_952(T15_, IL64(0));
						if (!!(T16_)) goto LA17_;
						{
							if (!(result == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA21_;
							result = getConstExpr__semfold_81(c, (*it)._kind_6.sons->data[((NI) 1)], idgen, g);
							{
								if (!(result == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA25_;
								goto BeforeRet_;
							}
							LA25_: ;
						}
						LA21_: ;
					}
					LA17_: ;
				}
				goto LA4_;
				LA7_: ;
				{
					NI T28_;
					T28_ = (NI)0;
					T28_ = len__ast_3155(it);
					if (!(T28_ == ((NI) 1))) goto LA29_;
					{
						if (!(result == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA33_;
						result = getConstExpr__semfold_81(c, (*it)._kind_6.sons->data[((NI) 0)], idgen, g);
					}
					LA33_: ;
				}
				goto LA4_;
				LA29_: ;
				{
					internalErrorImpl__msgs_1441((*g).config, (*it).info, ((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_26), TM__IRrKIA9aNr9b6S9bSzM79cgt1g_27);
				}
				LA4_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__semfold_973)(tyObject_HSlice__5MokM0MxT5ZF4tSog3uzVQ s, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg value) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (s.a <= value);
	if (!(T1_)) goto LA2_;
	T1_ = (value <= s.b);
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(tyObject_HSlice__5MokM0MxT5ZF4tSog3uzVQ, dotdot___semfold_951)(tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg a, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg b) {
	tyObject_HSlice__5MokM0MxT5ZF4tSog3uzVQ result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__5MokM0MxT5ZF4tSog3uzVQ));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__5MokM0MxT5ZF4tSog3uzVQ));
	result.a = a;
	result.b = b;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, getArrayConstr__semfold_729)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41))) goto LA3_;
		result = n;
	}
	goto LA1_;
	LA3_: ;
	{
		result = getConstExpr__semfold_81(m, n, idgen, g);
		{
			if (!(result == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA8_;
			result = n;
		}
		LA8_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, magicCall__semfold_630)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* c;
{	result = NIM_NIL;
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__ast_3155(n);
		if (!(T3_ <= ((NI) 1))) goto LA4_;
		goto BeforeRet_;
	}
	LA4_: ;
	s = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
	a = getConstExpr__semfold_81(m, (*n)._kind_6.sons->data[((NI) 1)], idgen, g);
	b = NIM_NIL;
	c = NIM_NIL;
	{
		if (!(a == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA8_;
		goto BeforeRet_;
	}
	LA8_: ;
	{
		NI T12_;
		T12_ = (NI)0;
		T12_ = len__ast_3155(n);
		if (!(((NI) 2) < T12_)) goto LA13_;
		b = getConstExpr__semfold_81(m, (*n)._kind_6.sons->data[((NI) 2)], idgen, g);
		{
			if (!(b == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA17_;
			goto BeforeRet_;
		}
		LA17_: ;
		{
			NI T21_;
			T21_ = (NI)0;
			T21_ = len__ast_3155(n);
			if (!(((NI) 3) < T21_)) goto LA22_;
			c = getConstExpr__semfold_81(m, (*n)._kind_6.sons->data[((NI) 3)], idgen, g);
			{
				if (!(c == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA26_;
				goto BeforeRet_;
			}
			LA26_: ;
		}
		LA22_: ;
	}
	LA13_: ;
	result = evalOp__semfold_86((*s).magic, n, a, b, c, idgen, g);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, foldConStrStr__semfold_850)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
{	result = NIM_NIL;
	result = newNodeIT__ast_3342(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20), (*n).info, (*n).typ);
	asgnRef((void**) (&(*result)._kind_3.strVal), ((NimStringDesc*) NIM_NIL));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a;
				NimStringDesc* T8_;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				a = getConstExpr__semfold_81(m, (*n)._kind_6.sons->data[i], idgen, g);
				{
					if (!(a == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA6_;
					result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
					goto BeforeRet_;
				}
				LA6_: ;
				T8_ = NIM_NIL;
				T8_ = getStrOrChar__ast_4614(a);
				asgnRef((void**) (&(*result)._kind_3.strVal), resizeString((*result)._kind_3.strVal, (T8_ ? T8_->Sup.len : 0) + 0));
appendString((*result)._kind_3.strVal, T8_);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__ast_3155(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, leValueConv__semfold_626)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = NIM_FALSE;
	switch ((*a).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 15):
	{
		switch ((*b).kind) {
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 15):
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T3_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T4_;
			T3_ = getInt__ast_4593(a);
			T4_ = getInt__ast_4593(b);
			result = lteq___int495056_421(T3_, T4_);
		}
		break;
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 16) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 19):
		{
			NF T6_;
			T6_ = (NF)0;
			T6_ = round((*b)._kind_2.floatVal);
			result = ((*a)._kind_1.intVal <= ((NI64) (((NI) (T6_)))));
		}
		break;
		default:
		{
			result = NIM_FALSE;
		}
		break;
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 16) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 19):
	{
		switch ((*b).kind) {
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 16) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 19):
		{
			result = ((*a)._kind_2.floatVal <= (*b)._kind_2.floatVal);
		}
		break;
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 15):
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T11_;
			NF T12_;
			T11_ = getInt__ast_4593(b);
			T12_ = (NF)0;
			T12_ = toFloat64__int495056_994(T11_);
			result = ((*a)._kind_2.floatVal <= T12_);
		}
		break;
		default:
		{
			result = NIM_FALSE;
		}
		break;
		}
	}
	break;
	default:
	{
		result = NIM_FALSE;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rangeCheck__semfold_681)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ value, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	{
		NIM_BOOL T3_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T4_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T6_;
		NimStringDesc* T9_;
		NimStringDesc* T10_;
		NimStringDesc* T11_;
		T3_ = (NIM_BOOL)0;
		T4_ = firstOrd__types_1406((*g).config, (*n).typ);
		T3_ = lt___int495056_417(value, T4_);
		if (T3_) goto LA5_;
		T6_ = lastOrd__types_1530((*g).config, (*n).typ);
		T3_ = lt___int495056_417(T6_, value);
		LA5_: ;
		if (!T3_) goto LA7_;
		T9_ = NIM_NIL;
		T10_ = NIM_NIL;
		T10_ = dollar___int495056_53(value);
		T11_ = NIM_NIL;
		T11_ = typeToString__types_50((*n).typ, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
		T9_ = rawNewString((T10_ ? T10_->Sup.len : 0) + (T11_ ? T11_->Sup.len : 0) + 19);
appendString(T9_, ((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_43));
appendString(T9_, T10_);
appendString(T9_, ((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_44));
appendString(T9_, T11_);
		liMessage__msgs_1128((*g).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T9_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__IRrKIA9aNr9b6S9bSzM79cgt1g_45, NIM_FALSE);
	}
	LA7_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, foldConv__semfold_685)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NIM_BOOL check) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* dstTyp;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* srcTyp;
	result = NIM_NIL;
	dstTyp = skipTypes__ast_3723((*n).typ, TM__IRrKIA9aNr9b6S9bSzM79cgt1g_41);
	srcTyp = skipTypes__ast_3723((*a).typ, TM__IRrKIA9aNr9b6S9bSzM79cgt1g_41);
	switch ((*dstTyp).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1):
	{
		switch ((*srcTyp).kind) {
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 38):
		{
			NF T3_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T4_;
			T3_ = (NF)0;
			T3_ = getFloat__ast_4608(a);
			T4_ = toInt128__semfold_702(!((T3_ == 0.0)));
			result = newIntNodeT__semfold_57(T4_, n, idgen, g);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2):
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44):
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35):
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T6_;
			NIM_BOOL T7_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T8_;
			T6_ = getOrdValue__types_161(a, Max__int495056_27);
			T7_ = (NIM_BOOL)0;
			T7_ = eqeq___int495056_952(T6_, IL64(0));
			T8_ = toInt128__semfold_702(!(T7_));
			result = newIntNodeT__semfold_57(T8_, n, idgen, g);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1):
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14):
		{
			result = a;
			asgnRef((void**) (&(*result).typ), (*n).typ);
		}
		break;
		default:
		{
			{
				NimStringDesc* T15_;
				if (!NIM_TRUE) goto LA13_;
				T15_ = NIM_NIL;
				T15_ = rawNewString((reprEnum((NI)(*srcTyp).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)) ? reprEnum((NI)(*srcTyp).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_))->Sup.len : 0) + 29);
appendString(T15_, ((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_42));
appendString(T15_, reprEnum((NI)(*srcTyp).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)));
				failedAssertImpl__systemZassertions_56(T15_);
			}
			LA13_: ;
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44):
	{
		switch ((*srcTyp).kind) {
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 38):
		{
			NF T18_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T19_;
			T18_ = (NF)0;
			T18_ = getFloat__ast_4608(a);
			T19_ = toInt128__int495056_1011(T18_);
			result = newIntNodeT__semfold_57(T19_, n, idgen, g);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2):
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44):
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35):
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ val;
			val = getOrdValue__types_161(a, Max__int495056_27);
			{
				if (!check) goto LA23_;
				rangeCheck__semfold_681(n, val, g);
			}
			LA23_: ;
			result = newIntNodeT__semfold_57(val, n, idgen, g);
			{
				if (!((*dstTyp).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40) && (*dstTyp).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44))) goto LA27_;
				transitionIntKind__ast_4360(result, ((tyEnum_TNodeKind__4gPA2nKyTI2Bfe40Z7kjdg) 11));
			}
			LA27_: ;
		}
		break;
		default:
		{
			result = a;
			asgnRef((void**) (&(*result).typ), (*n).typ);
		}
		break;
		}
		{
			NIM_BOOL T32_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T36_;
			T32_ = (NIM_BOOL)0;
			T32_ = check;
			if (!(T32_)) goto LA33_;
			T32_ = ((*result).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) && (*result).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 15));
			LA33_: ;
			if (!T32_) goto LA34_;
			T36_ = getInt__ast_4593(result);
			rangeCheck__semfold_681(n, T36_, g);
		}
		LA34_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 38):
	{
		switch ((*srcTyp).kind) {
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35):
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44):
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14):
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1):
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2):
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T39_;
			NF T40_;
			T39_ = getOrdValue__types_161(a, Max__int495056_27);
			T40_ = (NF)0;
			T40_ = toFloat64__int495056_994(T39_);
			result = newFloatNodeT__semfold_67(T40_, n, g);
		}
		break;
		default:
		{
			result = a;
			asgnRef((void**) (&(*result).typ), (*n).typ);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 26):
	{
	}
	break;
	default:
	{
		result = a;
		asgnRef((void**) (&(*result).typ), (*n).typ);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, foldArrayAccess__semfold_743)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* y;
	NI64 idx;
	tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T12_;
{	result = NIM_NIL;
	x = getConstExpr__semfold_81(m, (*n)._kind_6.sons->data[((NI) 0)], idgen, g);
	{
		NIM_BOOL T3_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = (x == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
		if (T3_) goto LA4_;
		T5_ = NIM_NIL;
		T5_ = skipTypes__ast_3723((*x).typ, TM__IRrKIA9aNr9b6S9bSzM79cgt1g_46);
		T3_ = ((*T5_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8));
		LA4_: ;
		if (!T3_) goto LA6_;
		goto BeforeRet_;
	}
	LA6_: ;
	y = getConstExpr__semfold_81(m, (*n)._kind_6.sons->data[((NI) 1)], idgen, g);
	{
		if (!(y == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA10_;
		goto BeforeRet_;
	}
	LA10_: ;
	T12_ = getOrdValue__types_161(y, Max__int495056_27);
	idx = toInt64__int495056_88(T12_);
	switch ((*x).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 37):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 160):
	{
		{
			NIM_BOOL T16_;
			NI T18_;
			T16_ = (NIM_BOOL)0;
			T16_ = (IL64(0) <= idx);
			if (!(T16_)) goto LA17_;
			T18_ = (NI)0;
			T18_ = len__ast_3155(x);
			T16_ = (idx < ((NI64) (T18_)));
			LA17_: ;
			if (!T16_) goto LA19_;
			result = (*x)._kind_6.sons->data[idx];
			{
				if (!((*result).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34))) goto LA23_;
				result = (*result)._kind_6.sons->data[((NI) 1)];
			}
			LA23_: ;
		}
		goto LA14_;
		LA19_: ;
		{
			NimStringDesc* T26_;
			NimStringDesc* T27_;
			NimStringDesc* T38_;
			T26_ = NIM_NIL;
			T27_ = NIM_NIL;
			{
				NI T30_;
				T30_ = (NI)0;
				T30_ = len__ast_3155(x);
				if (!((NI)(T30_ - ((NI) 1)) < ((NI) 0))) goto LA31_;
				T27_ = copyString(((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_47));
			}
			goto LA28_;
			LA31_: ;
			{
				NimStringDesc* T34_;
				NimStringDesc* T35_;
				NI T36_;
				NimStringDesc* T37_;
				T34_ = NIM_NIL;
				T35_ = NIM_NIL;
				T35_ = dollar___systemZdollars_6(idx);
				T36_ = (NI)0;
				T36_ = len__ast_3155(x);
				T37_ = NIM_NIL;
				T37_ = dollar___systemZdollars_3((NI)(T36_ - ((NI) 1)));
				T34_ = rawNewString((T35_ ? T35_->Sup.len : 0) + (T37_ ? T37_->Sup.len : 0) + 19);
appendString(T34_, ((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_48));
appendString(T34_, T35_);
appendString(T34_, ((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_49));
appendString(T34_, T37_);
				T27_ = T34_;
			}
			LA28_: ;
			T38_ = NIM_NIL;
			T38_ = dollar___renderer_2116(n);
			T26_ = rawNewString((T27_ ? T27_->Sup.len : 0) + (T38_ ? T38_->Sup.len : 0) + 0);
appendString(T26_, T27_);
appendString(T26_, T38_);
			liMessage__msgs_1128((*g).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T26_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__IRrKIA9aNr9b6S9bSzM79cgt1g_50, NIM_FALSE);
		}
		LA14_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T40_;
		NI64 T41_;
		T40_ = firstOrd__types_1406((*g).config, (*x).typ);
		T41_ = (NI64)0;
		T41_ = toInt64__int495056_88(T40_);
		idx -= T41_;
		{
			NIM_BOOL T44_;
			NI T46_;
			T44_ = (NIM_BOOL)0;
			T44_ = (IL64(0) <= idx);
			if (!(T44_)) goto LA45_;
			T46_ = (NI)0;
			T46_ = len__ast_3155(x);
			T44_ = (idx < ((NI64) (T46_)));
			LA45_: ;
			if (!T44_) goto LA47_;
			result = (*x)._kind_6.sons->data[idx];
		}
		goto LA42_;
		LA47_: ;
		{
			NimStringDesc* T50_;
			NimStringDesc* T51_;
			NimStringDesc* T62_;
			T50_ = NIM_NIL;
			T51_ = NIM_NIL;
			{
				NI T54_;
				T54_ = (NI)0;
				T54_ = len__ast_3155(x);
				if (!((NI)(T54_ - ((NI) 1)) < ((NI) 0))) goto LA55_;
				T51_ = copyString(((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_47));
			}
			goto LA52_;
			LA55_: ;
			{
				NimStringDesc* T58_;
				NimStringDesc* T59_;
				NI T60_;
				NimStringDesc* T61_;
				T58_ = NIM_NIL;
				T59_ = NIM_NIL;
				T59_ = dollar___systemZdollars_6(idx);
				T60_ = (NI)0;
				T60_ = len__ast_3155(x);
				T61_ = NIM_NIL;
				T61_ = dollar___systemZdollars_3((NI)(T60_ - ((NI) 1)));
				T58_ = rawNewString((T59_ ? T59_->Sup.len : 0) + (T61_ ? T61_->Sup.len : 0) + 19);
appendString(T58_, ((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_48));
appendString(T58_, T59_);
appendString(T58_, ((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_49));
appendString(T58_, T61_);
				T51_ = T58_;
			}
			LA52_: ;
			T62_ = NIM_NIL;
			T62_ = dollar___renderer_2116(n);
			T50_ = rawNewString((T51_ ? T51_->Sup.len : 0) + (T62_ ? T62_->Sup.len : 0) + 0);
appendString(T50_, T51_);
appendString(T50_, T62_);
			liMessage__msgs_1128((*g).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T50_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__IRrKIA9aNr9b6S9bSzM79cgt1g_51, NIM_FALSE);
		}
		LA42_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22):
	{
		result = newNodeIT__ast_3342(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5), (*x).info, (*n).typ);
		{
			NIM_BOOL T66_;
			T66_ = (NIM_BOOL)0;
			T66_ = (IL64(0) <= idx);
			if (!(T66_)) goto LA67_;
			T66_ = (idx < ((NI64) (((*x)._kind_3.strVal ? (*x)._kind_3.strVal->Sup.len : 0))));
			LA67_: ;
			if (!T66_) goto LA68_;
			(*result)._kind_1.intVal = ((NI64) (((NU8)((*x)._kind_3.strVal->data[idx]))));
		}
		goto LA64_;
		LA68_: ;
		{
			NimStringDesc* T71_;
			NimStringDesc* T72_;
			NimStringDesc* T81_;
			T71_ = NIM_NIL;
			T72_ = NIM_NIL;
			{
				if (!((NI)(((*x)._kind_3.strVal ? (*x)._kind_3.strVal->Sup.len : 0) - ((NI) 1)) < ((NI) 0))) goto LA75_;
				T72_ = copyString(((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_47));
			}
			goto LA73_;
			LA75_: ;
			{
				NimStringDesc* T78_;
				NimStringDesc* T79_;
				NimStringDesc* T80_;
				T78_ = NIM_NIL;
				T79_ = NIM_NIL;
				T79_ = dollar___systemZdollars_6(idx);
				T80_ = NIM_NIL;
				T80_ = dollar___systemZdollars_3((NI)(((*x)._kind_3.strVal ? (*x)._kind_3.strVal->Sup.len : 0) - ((NI) 1)));
				T78_ = rawNewString((T79_ ? T79_->Sup.len : 0) + (T80_ ? T80_->Sup.len : 0) + 19);
appendString(T78_, ((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_48));
appendString(T78_, T79_);
appendString(T78_, ((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_49));
appendString(T78_, T80_);
				T72_ = T78_;
			}
			LA73_: ;
			T81_ = NIM_NIL;
			T81_ = dollar___renderer_2116(n);
			T71_ = rawNewString((T72_ ? T72_->Sup.len : 0) + (T81_ ? T81_->Sup.len : 0) + 0);
appendString(T71_, T72_);
appendString(T71_, T81_);
			liMessage__msgs_1128((*g).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T71_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__IRrKIA9aNr9b6S9bSzM79cgt1g_52, NIM_FALSE);
		}
		LA64_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, foldFieldAccess__semfold_797)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field;
	NimStringDesc* T26_;
{	result = NIM_NIL;
	{
		if (!!(((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)))) goto LA3_;
		result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
		goto BeforeRet_;
	}
	LA3_: ;
	x = getConstExpr__semfold_81(m, (*n)._kind_6.sons->data[((NI) 0)], idgen, g);
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = (x == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
		if (T7_) goto LA8_;
		T7_ = !(((*x).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 38) || (*x).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 37) || (*x).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 160)));
		LA8_: ;
		if (!T7_) goto LA9_;
		goto BeforeRet_;
	}
	LA9_: ;
	field = (*(*n)._kind_6.sons->data[((NI) 1)])._kind_4.sym;
	{
		NI i;
		NI colontmp_;
		NI colontmp__2;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp__2 = (NI)0;
		colontmp_ = ((*x).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 38));
		colontmp__2 = len__ast_3155(x);
		i_2 = colontmp_;
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
				if (!(i_2 < colontmp__2)) goto LA13;
				i = i_2;
				it = (*x)._kind_6.sons->data[i];
				{
					if (!!(((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34)))) goto LA16_;
					result = (*x)._kind_6.sons->data[(*field).position];
					{
						if (!((*result).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34))) goto LA20_;
						result = (*result)._kind_6.sons->data[((NI) 1)];
					}
					LA20_: ;
					goto BeforeRet_;
				}
				LA16_: ;
				{
					if (!((*(*(*(*it)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).id == (*(*field).name).id)) goto LA24_;
					result = (*(*x)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 1)];
					goto BeforeRet_;
				}
				LA24_: ;
				i_2 += ((NI) 1);
			} LA13: ;
		}
	}
	T26_ = NIM_NIL;
	T26_ = rawNewString(((*(*field).name).s ? (*(*field).name).s->Sup.len : 0) + 17);
appendString(T26_, ((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_53));
appendString(T26_, (*(*field).name).s);
	liMessage__msgs_1128((*g).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T26_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__IRrKIA9aNr9b6S9bSzM79cgt1g_54, NIM_FALSE);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, getConstExpr__semfold_81)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* volatile result;
{	result = NIM_NIL;
	result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
		s = (*n)._kind_4.sym;
		switch ((*s).kind) {
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 20):
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T3_;
			T3_ = toInt128__types_1431((*s).position);
			result = newIntNodeT__semfold_57(T3_, n, idgen, g);
		}
		break;
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 10):
		{
			switch ((*s).magic) {
			case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 201):
			{
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T6_;
				T6_ = toInt128__types_1431((((*m).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 14))&63U)))!=0));
				result = newIntNodeT__semfold_57(T6_, n, idgen, g);
			}
			break;
			case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 202):
			{
				NimStringDesc* T8_;
				T8_ = NIM_NIL;
				T8_ = getDateStr__options_596();
				result = newStrNodeT__semfold_76(T8_, n, g);
			}
			break;
			case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 203):
			{
				NimStringDesc* T10_;
				T10_ = NIM_NIL;
				T10_ = getClockStr__options_604();
				result = newStrNodeT__semfold_76(T10_, n, g);
			}
			break;
			case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 205):
			{
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T12_;
				T12_ = toInt128__types_1431(CPU__platform_705[((*(*g).config).target.targetCPU)- 1].Field2);
				result = newIntNodeT__semfold_57(T12_, n, idgen, g);
			}
			break;
			case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 206):
			{
				NimStringDesc* T14_;
				T14_ = NIM_NIL;
				T14_ = nsuToLowerAsciiStr(OS__platform_518[((*(*g).config).target.targetOS)- 1].Field0);
				result = newStrNodeT__semfold_76(T14_, n, g);
			}
			break;
			case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 207):
			{
				NimStringDesc* T16_;
				T16_ = NIM_NIL;
				T16_ = nsuToLowerAsciiStr(CPU__platform_705[((*(*g).config).target.targetCPU)- 1].Field0);
				result = newStrNodeT__semfold_76(T16_, n, g);
			}
			break;
			case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 208):
			{
				NimStringDesc* T18_;
				T18_ = NIM_NIL;
				T18_ = nsuToLowerAsciiStr(OS__platform_518[((*(*g).config).target.hostOS)- 1].Field0);
				result = newStrNodeT__semfold_76(T18_, n, g);
			}
			break;
			case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 209):
			{
				NimStringDesc* T20_;
				T20_ = NIM_NIL;
				T20_ = nsuToLowerAsciiStr(CPU__platform_705[((*(*g).config).target.hostCPU)- 1].Field0);
				result = newStrNodeT__semfold_76(T20_, n, g);
			}
			break;
			case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 210):
			{
				result = getAppType__semfold_665(n, g);
			}
			break;
			case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 265):
			{
				{
					NIM_BOOL T25_;
					TSafePoint TM__IRrKIA9aNr9b6S9bSzM79cgt1g_19;
					NimStringDesc** T28_;
					NI T29_;
					tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T30_;
					T25_ = (NIM_BOOL)0;
					T25_ = isDefined__options_2292((*g).config, (*(*s).name).s);
					if (!T25_) goto LA26_;
					pushSafePoint(&TM__IRrKIA9aNr9b6S9bSzM79cgt1g_19);
					TM__IRrKIA9aNr9b6S9bSzM79cgt1g_19.status = setjmp(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_19.context);
					if (TM__IRrKIA9aNr9b6S9bSzM79cgt1g_19.status == 0) {
					T28_ = (NimStringDesc**)0;
					T28_ = nstTake((*(*g).config).symbols, (*(*s).name).s);
					T29_ = (NI)0;
					T29_ = nsuParseInt((*T28_));
					T30_ = toInt128__types_1431(T29_);
					result = newIntNodeT__semfold_57(T30_, n, idgen, g);
					popSafePoint();
					}
					else {
						popSafePoint();
						if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIvalueerror__5lcTdgqMq62cNGRwBb0thA_))) {
							NimStringDesc* T33_;
							NimStringDesc** T34_;
							TM__IRrKIA9aNr9b6S9bSzM79cgt1g_19.status = 0;
							T33_ = NIM_NIL;
							T34_ = (NimStringDesc**)0;
							T34_ = nstTake((*(*g).config).symbols, (*(*s).name).s);
							T33_ = rawNewString(((*T34_) ? (*T34_)->Sup.len : 0) + 53);
appendString(T33_, ((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_20));
appendString(T33_, (*T34_));
appendString(T33_, ((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_21));
							liMessage__msgs_1128((*g).config, (*s).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T33_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__IRrKIA9aNr9b6S9bSzM79cgt1g_22, NIM_FALSE);
							popCurrentException();
						}
					}
					if (TM__IRrKIA9aNr9b6S9bSzM79cgt1g_19.status != 0) reraiseException();
				}
				goto LA23_;
				LA26_: ;
				{
					result = copyTree__ast_4432((*s).ast);
				}
				LA23_: ;
			}
			break;
			case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 266):
			{
				{
					NIM_BOOL T39_;
					NimStringDesc** T42_;
					T39_ = (NIM_BOOL)0;
					T39_ = isDefined__options_2292((*g).config, (*(*s).name).s);
					if (!T39_) goto LA40_;
					T42_ = (NimStringDesc**)0;
					T42_ = nstTake((*(*g).config).symbols, (*(*s).name).s);
					result = newStrNodeT__semfold_76((*T42_), n, g);
				}
				goto LA37_;
				LA40_: ;
				{
					result = copyTree__ast_4432((*s).ast);
				}
				LA37_: ;
			}
			break;
			case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 267):
			{
				{
					NIM_BOOL T47_;
					TSafePoint TM__IRrKIA9aNr9b6S9bSzM79cgt1g_23;
					NimStringDesc** T50_;
					NIM_BOOL T51_;
					tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T52_;
					T47_ = (NIM_BOOL)0;
					T47_ = isDefined__options_2292((*g).config, (*(*s).name).s);
					if (!T47_) goto LA48_;
					pushSafePoint(&TM__IRrKIA9aNr9b6S9bSzM79cgt1g_23);
					TM__IRrKIA9aNr9b6S9bSzM79cgt1g_23.status = setjmp(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_23.context);
					if (TM__IRrKIA9aNr9b6S9bSzM79cgt1g_23.status == 0) {
					T50_ = (NimStringDesc**)0;
					T50_ = nstTake((*(*g).config).symbols, (*(*s).name).s);
					T51_ = (NIM_BOOL)0;
					T51_ = parseBool__pureZstrutils_998((*T50_));
					T52_ = toInt128__types_1431(((NI) (T51_)));
					result = newIntNodeT__semfold_57(T52_, n, idgen, g);
					popSafePoint();
					}
					else {
						popSafePoint();
						if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIvalueerror__5lcTdgqMq62cNGRwBb0thA_))) {
							NimStringDesc* T55_;
							NimStringDesc** T56_;
							TM__IRrKIA9aNr9b6S9bSzM79cgt1g_23.status = 0;
							T55_ = NIM_NIL;
							T56_ = (NimStringDesc**)0;
							T56_ = nstTake((*(*g).config).symbols, (*(*s).name).s);
							T55_ = rawNewString(((*T56_) ? (*T56_)->Sup.len : 0) + 51);
appendString(T55_, ((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_24));
appendString(T55_, (*T56_));
appendString(T55_, ((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_21));
							liMessage__msgs_1128((*g).config, (*s).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T55_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__IRrKIA9aNr9b6S9bSzM79cgt1g_25, NIM_FALSE);
							popCurrentException();
						}
					}
					if (TM__IRrKIA9aNr9b6S9bSzM79cgt1g_23.status != 0) reraiseException();
				}
				goto LA45_;
				LA48_: ;
				{
					result = copyTree__ast_4432((*s).ast);
				}
				LA45_: ;
			}
			break;
			default:
			{
				result = copyTree__ast_4432((*s).ast);
			}
			break;
			}
		}
		break;
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 12):
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 13):
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 14):
		{
			result = n;
		}
		break;
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3):
		{
			{
				NIM_BOOL T63_;
				T63_ = (NIM_BOOL)0;
				T63_ = !(((*s).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
				if (!(T63_)) goto LA64_;
				T63_ = ((*(*s).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8));
				LA64_: ;
				if (!T63_) goto LA65_;
				result = newSymNodeTypeDesc__semfold_870(s, idgen, (*n).info);
			}
			LA65_: ;
		}
		break;
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 7):
		{
			{
				if (!!(((*s).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA70_;
				result = newSymNodeTypeDesc__semfold_870(s, idgen, (*n).info);
			}
			LA70_: ;
		}
		break;
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 4):
		{
			{
				if (!((*(*s).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60))) goto LA75_;
				{
					NIM_BOOL T79_;
					T79_ = (NIM_BOOL)0;
					T79_ = !(((*(*s).typ).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
					if (!(T79_)) goto LA80_;
					T79_ = !((((*(*s).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 9))&63U)))!=0));
					LA80_: ;
					if (!T79_) goto LA81_;
					result = (*(*s).typ).n;
					asgnRef((void**) (&(*result).typ), base__types_63((*s).typ));
				}
				LA81_: ;
			}
			goto LA73_;
			LA75_: ;
			{
				NIM_BOOL T84_;
				T84_ = (NIM_BOOL)0;
				T84_ = isIntLit__types_186((*s).typ);
				if (!T84_) goto LA85_;
				result = (*(*s).typ).n;
			}
			goto LA73_;
			LA85_: ;
			{
				result = newSymNodeTypeDesc__semfold_870(s, idgen, (*n).info);
			}
			LA73_: ;
		}
		break;
		default:
		{
		}
		break;
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
	{
		result = copyNode__ast_4324(n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 48):
	{
		result = getConstIfExpr__semfold_584(m, n, idgen, g);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s_2;
		TSafePoint TM__IRrKIA9aNr9b6S9bSzM79cgt1g_28;
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)))) goto LA94_;
			goto BeforeRet_;
		}
		LA94_: ;
		s_2 = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		{
			NIM_BOOL T98_;
			T98_ = (NIM_BOOL)0;
			T98_ = !(((*s_2).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 12)));
			if (!(T98_)) goto LA99_;
			T98_ = !(((*s_2).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 13)));
			LA99_: ;
			if (!T98_) goto LA100_;
			goto BeforeRet_;
		}
		LA100_: ;
		pushSafePoint(&TM__IRrKIA9aNr9b6S9bSzM79cgt1g_28);
		TM__IRrKIA9aNr9b6S9bSzM79cgt1g_28.status = setjmp(TM__IRrKIA9aNr9b6S9bSzM79cgt1g_28.context);
		if (TM__IRrKIA9aNr9b6S9bSzM79cgt1g_28.status == 0) {
		switch ((*s_2).magic) {
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 0):
		{
			popSafePoint();
			goto BeforeRet_;
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 8):
		{
			{
				tyObject_HSlice__5MokM0MxT5ZF4tSog3uzVQ T106_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T107_;
				NIM_BOOL T108_;
				NF T111_;
				T106_ = dotdot___semfold_951(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36), ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 38));
				T107_ = NIM_NIL;
				T107_ = skipTypes__ast_3723((*(*n)._kind_6.sons->data[((NI) 1)]).typ, TM__IRrKIA9aNr9b6S9bSzM79cgt1g_29);
				T108_ = (NIM_BOOL)0;
				T108_ = contains__semfold_973(T106_, (*T107_).kind);
				if (!T108_) goto LA109_;
				T111_ = (NF)0;
				T111_ = firstFloat__types_1505((*(*n)._kind_6.sons->data[((NI) 1)]).typ);
				result = newFloatNodeT__semfold_67(T111_, n, g);
			}
			goto LA104_;
			LA109_: ;
			{
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T113_;
				T113_ = firstOrd__types_1406((*g).config, (*(*n)._kind_6.sons->data[((NI) 1)]).typ);
				result = newIntNodeT__semfold_57(T113_, n, idgen, g);
			}
			LA104_: ;
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 9):
		{
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T117_;
				T117_ = NIM_NIL;
				T117_ = skipTypes__ast_3723((*(*n)._kind_6.sons->data[((NI) 1)]).typ, TM__IRrKIA9aNr9b6S9bSzM79cgt1g_30);
				if (!!(((*T117_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24) || (*T117_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28) || (*T117_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29) || (*T117_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27) || (*T117_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48)))) goto LA118_;
				{
					tyObject_HSlice__5MokM0MxT5ZF4tSog3uzVQ T122_;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T123_;
					NIM_BOOL T124_;
					NF T127_;
					T122_ = dotdot___semfold_951(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36), ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 38));
					T123_ = NIM_NIL;
					T123_ = skipTypes__ast_3723((*(*n)._kind_6.sons->data[((NI) 1)]).typ, TM__IRrKIA9aNr9b6S9bSzM79cgt1g_29);
					T124_ = (NIM_BOOL)0;
					T124_ = contains__semfold_973(T122_, (*T123_).kind);
					if (!T124_) goto LA125_;
					T127_ = (NF)0;
					T127_ = lastFloat__types_1644((*(*n)._kind_6.sons->data[((NI) 1)]).typ);
					result = newFloatNodeT__semfold_67(T127_, n, g);
				}
				goto LA120_;
				LA125_: ;
				{
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T129_;
					tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T130_;
					T129_ = NIM_NIL;
					T129_ = skipTypes__ast_3723((*(*n)._kind_6.sons->data[((NI) 1)]).typ, TM__IRrKIA9aNr9b6S9bSzM79cgt1g_31);
					T130_ = lastOrd__types_1530((*g).config, T129_);
					result = newIntNodeT__semfold_57(T130_, n, idgen, g);
				}
				LA120_: ;
			}
			goto LA115_;
			LA118_: ;
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a;
				a = getArrayConstr__semfold_729(m, (*n)._kind_6.sons->data[((NI) 1)], idgen, g);
				{
					NI T136_;
					tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T137_;
					if (!((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41))) goto LA134_;
					T136_ = (NI)0;
					T136_ = len__ast_3155(a);
					T137_ = toInt128__types_1431((NI)(T136_ - ((NI) 1)));
					result = newIntNodeT__semfold_57(T137_, n, idgen, g);
				}
				LA134_: ;
			}
			LA115_: ;
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 36):
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a_2;
			a_2 = getArrayConstr__semfold_729(m, (*n)._kind_6.sons->data[((NI) 1)], idgen, g);
			{
				NI T143_;
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T144_;
				if (!((*a_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41))) goto LA141_;
				T143_ = (NI)0;
				T143_ = len__ast_3155(a_2);
				T144_ = toInt128__types_1431(T143_);
				result = newIntNodeT__semfold_57(T144_, n, idgen, g);
			}
			goto LA139_;
			LA141_: ;
			{
				result = magicCall__semfold_630(m, n, idgen, g);
			}
			LA139_: ;
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 38):
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T147_;
			T147_ = lengthOrd__types_1717((*g).config, (*(*n)._kind_6.sons->data[((NI) 1)]).typ);
			result = newIntNodeT__semfold_57(T147_, n, idgen, g);
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 10):
		{
			tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* configX60gensym126_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nodeX60gensym126_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typX60gensym126_;
			NI64 sizeX60gensym126_;
			configX60gensym126_ = (*g).config;
			nodeX60gensym126_ = n;
			typX60gensym126_ = (*(*nodeX60gensym126_)._kind_6.sons->data[((NI) 1)]).typ;
			computeSizeAlign__types_2970(configX60gensym126_, typX60gensym126_);
			sizeX60gensym126_ = (*typX60gensym126_).size;
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* resX60gensym126_;
				if (!(IL64(0) <= sizeX60gensym126_)) goto LA151_;
				resX60gensym126_ = newIntNode__ast_3711(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6), sizeX60gensym126_);
				(*resX60gensym126_).info = (*nodeX60gensym126_).info;
				asgnRef((void**) (&(*resX60gensym126_).typ), (*nodeX60gensym126_).typ);
				result = resX60gensym126_;
			}
			goto LA149_;
			LA151_: ;
			{
				result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
			}
			LA149_: ;
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 11):
		{
			tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* configX60gensym129_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nodeX60gensym129_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typX60gensym129_;
			NI16 alignX60gensym129_;
			configX60gensym129_ = (*g).config;
			nodeX60gensym129_ = n;
			typX60gensym129_ = (*(*nodeX60gensym129_)._kind_6.sons->data[((NI) 1)]).typ;
			computeSizeAlign__types_2970(configX60gensym129_, typX60gensym129_);
			alignX60gensym129_ = (*typX60gensym129_).align;
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* resX60gensym129_;
				if (!(((NI16) 0) <= alignX60gensym129_)) goto LA157_;
				resX60gensym129_ = newIntNode__ast_3711(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6), ((NI64) (alignX60gensym129_)));
				(*resX60gensym129_).info = (*nodeX60gensym129_).info;
				asgnRef((void**) (&(*resX60gensym129_).typ), (*nodeX60gensym129_).typ);
				result = resX60gensym129_;
			}
			goto LA155_;
			LA157_: ;
			{
				result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
			}
			LA155_: ;
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 12):
		{
			tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* configX60gensym132_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nodeX60gensym132_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* volatile dotExprX60gensym132_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* valueX60gensym132_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* memberX60gensym132_;
			NI offsetX60gensym132_;
			configX60gensym132_ = (*g).config;
			nodeX60gensym132_ = n;
			dotExprX60gensym132_ = NIM_NIL;
			{
				{
					if (!((*(*nodeX60gensym132_)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45))) goto LA164_;
					dotExprX60gensym132_ = (*nodeX60gensym132_)._kind_6.sons->data[((NI) 1)];
				}
				goto LA162_;
				LA164_: ;
				{
					if (!((*(*nodeX60gensym132_)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 46))) goto LA167_;
					dotExprX60gensym132_ = (*(*nodeX60gensym132_)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 0)];
				}
				goto LA162_;
				LA167_: ;
				{
					liMessage__msgs_1128(configX60gensym132_, (*nodeX60gensym132_).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_32), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__IRrKIA9aNr9b6S9bSzM79cgt1g_33, NIM_FALSE);
				}
				LA162_: ;
			}
			valueX60gensym132_ = (*dotExprX60gensym132_)._kind_6.sons->data[((NI) 0)];
			memberX60gensym132_ = (*dotExprX60gensym132_)._kind_6.sons->data[((NI) 1)];
			computeSizeAlign__types_2970(configX60gensym132_, (*valueX60gensym132_).typ);
			offsetX60gensym132_ = (*(*memberX60gensym132_)._kind_4.sym).offset;
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* tmpX60gensym132_;
				if (!(((NI) 0) <= offsetX60gensym132_)) goto LA172_;
				tmpX60gensym132_ = newIntNode__ast_3711(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6), ((NI64) (offsetX60gensym132_)));
				(*tmpX60gensym132_).info = (*nodeX60gensym132_).info;
				asgnRef((void**) (&(*tmpX60gensym132_).typ), (*nodeX60gensym132_).typ);
				result = tmpX60gensym132_;
			}
			goto LA170_;
			LA172_: ;
			{
				result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
			}
			LA170_: ;
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 140):
		{
			NimStringDesc* T176_;
			T176_ = NIM_NIL;
			T176_ = renderTree__renderer_46((*n)._kind_6.sons->data[((NI) 1)], 4);
			result = newStrNodeT__semfold_76(T176_, n, g);
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 125):
		{
			result = foldConStrStr__semfold_850(m, n, idgen, g);
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 14):
		{
		}
		break;
		default:
		{
			result = magicCall__semfold_630(m, n, idgen, g);
		}
		break;
		}
		popSafePoint();
		}
		else {
			popSafePoint();
			if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIoverflowdefect__CPHzAjT39bZzjUQHYEzAGaw_))) {
				TM__IRrKIA9aNr9b6S9bSzM79cgt1g_28.status = 0;
				liMessage__msgs_1128((*g).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_35), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__IRrKIA9aNr9b6S9bSzM79cgt1g_36, NIM_FALSE);
				popCurrentException();
			}
			else 			if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIdivbyzerodefect__1jktkmId3HEtpgl3NFg3mg_))) {
				TM__IRrKIA9aNr9b6S9bSzM79cgt1g_28.status = 0;
				liMessage__msgs_1128((*g).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_37), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__IRrKIA9aNr9b6S9bSzM79cgt1g_38, NIM_FALSE);
				popCurrentException();
			}
		}
		if (TM__IRrKIA9aNr9b6S9bSzM79cgt1g_28.status != 0) reraiseException();
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a_3;
		a_3 = getConstExpr__semfold_81(m, (*n)._kind_6.sons->data[((NI) 0)], idgen, g);
		{
			if (!!((a_3 == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA186_;
			result = n;
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), a_3);
		}
		LA186_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 39):
	{
		result = copyNode__ast_4324(n);
		{
			NI i;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* son;
			i = (NI)0;
			son = NIM_NIL;
			{
				NI i_2;
				NI colontmp_;
				NI i_3;
				i_2 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(n);
				i_3 = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a_4;
						if (!(i_3 < colontmp_)) goto LA192;
						i_2 = i_3;
						i = i_2;
						son = (*n)._kind_6.sons->data[i_2];
						a_4 = getConstExpr__semfold_81(m, son, idgen, g);
						{
							if (!(a_4 == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA195_;
							result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
							goto BeforeRet_;
						}
						LA195_: ;
						add__ast_4798(result, a_4);
						i_3 += ((NI) 1);
					} LA192: ;
				}
			}
		}
		(*result).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg) 4)) & 31);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 44):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a_5;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b;
		a_5 = getConstExpr__semfold_81(m, (*n)._kind_6.sons->data[((NI) 0)], idgen, g);
		{
			if (!(a_5 == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA200_;
			goto BeforeRet_;
		}
		LA200_: ;
		b = getConstExpr__semfold_81(m, (*n)._kind_6.sons->data[((NI) 1)], idgen, g);
		{
			if (!(b == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA204_;
			goto BeforeRet_;
		}
		LA204_: ;
		result = copyNode__ast_4324(n);
		add__ast_4798(result, a_5);
		add__ast_4798(result, b);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 37):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 160):
	{
		result = copyNode__ast_4324(n);
		{
			NIM_BOOL T209_;
			NI T210_;
			T209_ = (NIM_BOOL)0;
			T210_ = (NI)0;
			T210_ = len__ast_3155(n);
			T209_ = (((NI) 0) < T210_);
			if (!(T209_)) goto LA211_;
			T209_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34));
			LA211_: ;
			if (!T209_) goto LA212_;
			{
				NI i_4;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* expr;
				i_4 = (NI)0;
				expr = NIM_NIL;
				{
					NI i_5;
					NI colontmp__2;
					NI i_6;
					i_5 = (NI)0;
					colontmp__2 = (NI)0;
					colontmp__2 = safeLen__ast_3148(n);
					i_6 = ((NI) 0);
					{
						while (1) {
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* exprNew;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a_6;
							if (!(i_6 < colontmp__2)) goto LA217;
							i_5 = i_6;
							i_4 = i_5;
							expr = (*n)._kind_6.sons->data[i_5];
							exprNew = copyNode__ast_4324(expr);
							add__ast_4798(exprNew, (*expr)._kind_6.sons->data[((NI) 0)]);
							a_6 = getConstExpr__semfold_81(m, (*expr)._kind_6.sons->data[((NI) 1)], idgen, g);
							{
								if (!(a_6 == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA220_;
								result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
								goto BeforeRet_;
							}
							LA220_: ;
							add__ast_4798(exprNew, a_6);
							add__ast_4798(result, exprNew);
							i_6 += ((NI) 1);
						} LA217: ;
					}
				}
			}
		}
		goto LA207_;
		LA212_: ;
		{
			{
				NI i_7;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* expr_2;
				i_7 = (NI)0;
				expr_2 = NIM_NIL;
				{
					NI i_8;
					NI colontmp__3;
					NI i_9;
					i_8 = (NI)0;
					colontmp__3 = (NI)0;
					colontmp__3 = safeLen__ast_3148(n);
					i_9 = ((NI) 0);
					{
						while (1) {
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a_7;
							if (!(i_9 < colontmp__3)) goto LA226;
							i_8 = i_9;
							i_7 = i_8;
							expr_2 = (*n)._kind_6.sons->data[i_8];
							a_7 = getConstExpr__semfold_81(m, expr_2, idgen, g);
							{
								if (!(a_7 == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA229_;
								result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
								goto BeforeRet_;
							}
							LA229_: ;
							add__ast_4798(result, a_7);
							i_9 += ((NI) 1);
						} LA226: ;
					}
				}
			}
		}
		LA207_: ;
		(*result).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg) 4)) & 31);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 68):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 69):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 70):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a_8;
		a_8 = getConstExpr__semfold_81(m, (*n)._kind_6.sons->data[((NI) 0)], idgen, g);
		{
			if (!(a_8 == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA234_;
			goto BeforeRet_;
		}
		LA234_: ;
		{
			NIM_BOOL T238_;
			T238_ = (NIM_BOOL)0;
			T238_ = leValueConv__semfold_626((*n)._kind_6.sons->data[((NI) 1)], a_8);
			if (!(T238_)) goto LA239_;
			T238_ = leValueConv__semfold_626(a_8, (*n)._kind_6.sons->data[((NI) 2)]);
			LA239_: ;
			if (!T238_) goto LA240_;
			result = a_8;
			asgnRef((void**) (&(*result).typ), (*n).typ);
		}
		goto LA236_;
		LA240_: ;
		{
			tyArray__Re75IspeoxXy2oCZHwcRrA T243_;
			NimStringDesc* T244_;
			nimZeroMem((void*)T243_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T243_[0] = typeToString__types_50((*(*n)._kind_6.sons->data[((NI) 0)]).typ, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
			T243_[1] = typeToString__types_50((*n).typ, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
			T244_ = NIM_NIL;
			T244_ = nsuFormatOpenArray(((NimStringDesc*) &TM__IRrKIA9aNr9b6S9bSzM79cgt1g_39), T243_, 2);
			liMessage__msgs_1128((*g).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T244_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__IRrKIA9aNr9b6S9bSzM79cgt1g_40, NIM_FALSE);
		}
		LA236_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 71):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 72):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a_9;
		a_9 = getConstExpr__semfold_81(m, (*n)._kind_6.sons->data[((NI) 0)], idgen, g);
		{
			if (!(a_9 == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA248_;
			goto BeforeRet_;
		}
		LA248_: ;
		result = a_9;
		asgnRef((void**) (&(*result).typ), (*n).typ);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 60):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a_10;
		a_10 = getConstExpr__semfold_81(m, (*n)._kind_6.sons->data[((NI) 1)], idgen, g);
		{
			if (!(a_10 == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA253_;
			goto BeforeRet_;
		}
		LA253_: ;
		result = foldConv__semfold_685(n, a_10, idgen, g, NIM_TRUE);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 47):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a_11;
		a_11 = getConstExpr__semfold_81(m, (*n)._kind_6.sons->data[((NI) 0)], idgen, g);
		{
			NIM_BOOL T258_;
			T258_ = (NIM_BOOL)0;
			T258_ = !((a_11 == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
			if (!(T258_)) goto LA259_;
			T258_ = ((*a_11).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23));
			LA259_: ;
			if (!T258_) goto LA260_;
			result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
		}
		LA260_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 61):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a_12;
		a_12 = getConstExpr__semfold_81(m, (*n)._kind_6.sons->data[((NI) 1)], idgen, g);
		{
			if (!(a_12 == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA265_;
			goto BeforeRet_;
		}
		LA265_: ;
		{
			NIM_BOOL T269_;
			T269_ = (NIM_BOOL)0;
			T269_ = !(((*n).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
			if (!(T269_)) goto LA270_;
			T269_ = ((*(*n).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 26) || (*(*n).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29) || (*(*n).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22) || (*(*n).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21) || (*(*n).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25) || (*(*n).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 50));
			LA270_: ;
			if (!T269_) goto LA271_;
			result = a_12;
			asgnRef((void**) (&(*result).typ), (*n).typ);
		}
		LA271_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42):
	{
		result = foldArrayAccess__semfold_743(m, n, idgen, g);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45):
	{
		result = foldFieldAccess__semfold_797(m, n, idgen, g);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 46):
	{
		result = foldFieldAccess__semfold_797(m, (*n)._kind_6.sons->data[((NI) 0)], idgen, g);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126):
	{
		NI i_10;
		i_10 = ((NI) 0);
		{
			while (1) {
				NI T279_;
				T279_ = (NI)0;
				T279_ = len__ast_3155(n);
				if (!(i_10 <= (NI)(T279_ - ((NI) 2)))) goto LA278;
				{
					if (!((*(*n)._kind_6.sons->data[i_10]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 24) || (*(*n)._kind_6.sons->data[i_10]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 125) || (*(*n)._kind_6.sons->data[i_10]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1))) goto LA282_;
					i_10 += ((NI) 1);
				}
				goto LA280_;
				LA282_: ;
				{
					goto LA277;
				}
				LA280_: ;
			} LA278: ;
		} LA277: ;
		{
			NI T287_;
			T287_ = (NI)0;
			T287_ = len__ast_3155(n);
			if (!(i_10 == (NI)(T287_ - ((NI) 1)))) goto LA288_;
			result = getConstExpr__semfold_81(m, (*n)._kind_6.sons->data[i_10], idgen, g);
		}
		LA288_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
