/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#include <setjmp.h>
#include <stdio.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw;
typedef struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tySequence__RNhZxf20g9beyq5VBOGxhDg tySequence__RNhZxf20g9beyq5VBOGxhDg;
typedef struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ;
typedef struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ tySequence__lFbCtu5P2Kf7YDYtGjkxAQ;
typedef struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA;
typedef struct tySequence__ijtae5OneaLys0hN9alAicA tySequence__ijtae5OneaLys0hN9alAicA;
typedef struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w;
typedef struct tySequence__SerjNoUujW2dUouVBrJiCw tySequence__SerjNoUujW2dUouVBrJiCw;
typedef struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyObject_Table__r0v8BdcBPKhl73K8p2VMUA;
typedef struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g tySequence__K9agbtcb0qPZuSJFXB9cTe6g;
typedef struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg;
typedef struct tySequence__m88qdML9cQOuqGAQn6XWL1A tySequence__m88qdML9cQOuqGAQn6XWL1A;
typedef struct tyObject_Table__1hIWbTQWYT4BmhdESze57A tyObject_Table__1hIWbTQWYT4BmhdESze57A;
typedef struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ tySequence__naEbXEp9b9aiW1zXJorqf9cXQ;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA;
typedef struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw;
typedef struct tySequence__ed0C0uAUZPhvw3RAc5hfYg tySequence__ed0C0uAUZPhvw3RAc5hfYg;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tyObject_Table__imojfg883tkWsWJwyshGqQ tyObject_Table__imojfg883tkWsWJwyshGqQ;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg tyObject_Table__BCPh85PHtwxox9bv7NLFrlg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct RootObj RootObj;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA;
typedef struct tySequence__KgiZ29chkJAD01p9aLRB32qw tySequence__KgiZ29chkJAD01p9aLRB32qw;
typedef struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A tyObject_Table__LM44poVdVEn4Mo4N4L8c3A;
typedef struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw tySequence__rkYRZrbHVYL3nhXlQW3K9bw;
typedef struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ tySequence__IRFEb1e9bxgbJLuB5xrdZsQ;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ;
typedef struct tySequence__YmPd0eWfcTfrVYrthlXPYA tySequence__YmPd0eWfcTfrVYrthlXPYA;
typedef struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q;
typedef struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg tySequence__Hz5SYwQU29b9aFLt09blvVQPg;
typedef struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg tyObject_Table__R7JnJQEipxxOlJWXQz7jWg;
typedef struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ tySequence__3G9aA9cLXaPxuRxMKm3anacQ;
typedef struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q tySequence__bPFv6ypvvCX2A9a9al8utL2Q;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_BModuleListcolonObjectType___9c4b0IbdzIJRabh100GyFtA tyObject_BModuleListcolonObjectType___9c4b0IbdzIJRabh100GyFtA;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tySequence__ukLNp6qJ4FndCViFTz0FGg tySequence__ukLNp6qJ4FndCViFTz0FGg;
typedef struct tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA;
typedef struct tyObject_Table__No9aC1Wmth1NAiZioiz5fTA tyObject_Table__No9aC1Wmth1NAiZioiz5fTA;
typedef struct tySequence__XN3007vuiFWlN1E7IEcusw tySequence__XN3007vuiFWlN1E7IEcusw;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_Table__dHMrTjFDXaK9bwjVxsGCupQ tyObject_Table__dHMrTjFDXaK9bwjVxsGCupQ;
typedef struct tySequence__ElVzGEMtCZvLUQLuuVlE5A tySequence__ElVzGEMtCZvLUQLuuVlE5A;
typedef struct tyObject_HashSet__KYwZ0vHsYO0DQEC4qpQkAQ tyObject_HashSet__KYwZ0vHsYO0DQEC4qpQkAQ;
typedef struct tySequence__WPcy3bORPBFlmk2KIq2pbQ tySequence__WPcy3bORPBFlmk2KIq2pbQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w;
typedef struct tyObject_TNodeTable__pvgAyOR0BNAWS4QLyWEfKg tyObject_TNodeTable__pvgAyOR0BNAWS4QLyWEfKg;
typedef struct tySequence__PPSNlMjxeLUadep32xHHyA tySequence__PPSNlMjxeLUadep32xHHyA;
typedef struct tyObject_CountTable__XawALO1wTnCsJeWBJMYZyg tyObject_CountTable__XawALO1wTnCsJeWBJMYZyg;
typedef struct tySequence__XUL1TrMU0tgXmaMFCIYgFQ tySequence__XUL1TrMU0tgXmaMFCIYgFQ;
typedef struct tyObject_NdiFile__ZdQ0n9cikYC2TzROZ1EnTOA tyObject_NdiFile__ZdQ0n9cikYC2TzROZ1EnTOA;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tySequence__IjAwukZ9aSEsol9c48He4FYQ tySequence__IjAwukZ9aSEsol9c48He4FYQ;
typedef struct tySequence__UQWyowqEA29c6NZ9csQYyjXQ tySequence__UQWyowqEA29c6NZ9csQYyjXQ;
typedef struct tySequence__Y9a9bBybAqzjKkPsvOIQEzpw tySequence__Y9a9bBybAqzjKkPsvOIQEzpw;
typedef struct tyObject_CountTable__QstdiKcmGEpsdJjh0p9cU7Q tyObject_CountTable__QstdiKcmGEpsdJjh0p9cU7Q;
typedef struct tySequence__jwzrUFjG9akTIJTBBFvvqxw tySequence__jwzrUFjG9akTIJTBBFvvqxw;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct tyObject_TBlock__FHXN9cI0ri9bj2d9cKw8iPHZg tyObject_TBlock__FHXN9cI0ri9bj2d9cKw8iPHZg;
typedef struct tyTuple__T1RBf8m9axj9bvJRlYejkpkQ tyTuple__T1RBf8m9axj9bvJRlYejkpkQ;
typedef struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ;
typedef struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g tySequence__qeAsXh2i1GAL5Nl0g3OP8g;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct Exception Exception;
typedef struct tySequence__QbmGqFaLnb1IWWToREeaIA tySequence__QbmGqFaLnb1IWWToREeaIA;
typedef struct TSafePoint TSafePoint;
typedef struct tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ;
typedef struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tyTuple__7q7q3E6Oj24ZNVJb9aonhAg;
typedef struct tyTuple__oa1dFn55BmC688WoXKTtUg tyTuple__oa1dFn55BmC688WoXKTtUg;
typedef struct tyTuple__1DF4qJDR9cG0CgZV1nlkaYw tyTuple__1DF4qJDR9cG0CgZV1nlkaYw;
typedef struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg;
typedef struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg;
typedef struct tySequence__4Murtwnm0Fyc7F9acrytEXw tySequence__4Murtwnm0Fyc7F9acrytEXw;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw;
typedef struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg tySequence__QnmOtn1Iv4LvxOXoMn8Rbg;
typedef struct tySequence__oKtVqsc9bQVCNyrijELM4OQ tySequence__oKtVqsc9bQVCNyrijELM4OQ;
typedef struct tySequence__qy6Iwdy00wN560qud54HTg tySequence__qy6Iwdy00wN560qud54HTg;
typedef struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ tySequence__k67v9bwvvQDmS1ynyGGUbeQ;
typedef struct tySequence__cLsClAAfd0MKkoBQVyvdvw tySequence__cLsClAAfd0MKkoBQVyvdvw;
typedef struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg tySequence__q9bTuOB0JXh1iZ3CSGdRLbg;
typedef struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw;
typedef struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ;
typedef struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ;
typedef struct tySequence__C3r8jsj9chA4sIlYfDN5aDw tySequence__C3r8jsj9chA4sIlYfDN5aDw;
typedef struct tyObject_TTraversalClosure__4DrvOBPCF3NL9akdOcxiJCw tyObject_TTraversalClosure__4DrvOBPCF3NL9akdOcxiJCw;
typedef struct tyTuple__EU9a9btT9bDanvLpyt3NNw3KA tyTuple__EU9a9btT9bDanvLpyt3NNw3KA;
typedef struct tySequence__6H5Oh5UUvVCLiakt9aTwtUQ tySequence__6H5Oh5UUvVCLiakt9aTwtUQ;
typedef struct tySequence__shxop0zPIs5Ec3k71aCLuQ tySequence__shxop0zPIs5Ec3k71aCLuQ;
typedef struct tyTuple__xIPPgKI3s9a9c79aFyHPbe0cg tyTuple__xIPPgKI3s9a9c79aFyHPbe0cg;
typedef struct tySequence__Vz8km29c8JcWq5WOBlnn2aQ tySequence__Vz8km29c8JcWq5WOBlnn2aQ;
typedef struct tyTuple__PCL3pTh9cmlWmhmXAE5IOKQ tyTuple__PCL3pTh9cmlWmhmXAE5IOKQ;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyObject_Env_cgendotnim_genMainProc___MH1VwSLIbfCI9coJDTeX9c2Q tyObject_Env_cgendotnim_genMainProc___MH1VwSLIbfCI9coJDTeX9c2Q;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
typedef struct tyTuple__cyyQdcuoDUp88Doe6rM7kA tyTuple__cyyQdcuoDUp88Doe6rM7kA;
typedef struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ;
typedef struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg tyTuple__UluY8x0Nj6cp9b0o88wJ0lg;
typedef struct tySequence__dlD6tEGzYLLpKVq3XwuFlA tySequence__dlD6tEGzYLLpKVq3XwuFlA;
typedef struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ;
typedef struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg;
typedef struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ;
typedef struct tyTuple__rZZA0skon1OsHdiEvT8RZQ tyTuple__rZZA0skon1OsHdiEvT8RZQ;
typedef struct tySequence__6OFCSvqRaxyEgUqWtnZSlw tySequence__6OFCSvqRaxyEgUqWtnZSlw;
typedef struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q;
typedef struct tySequence__UnGSk9aaLosDroi2QDrlOfQ tySequence__UnGSk9aaLosDroi2QDrlOfQ;
typedef struct tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA;
typedef struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA tyTuple__q13Zt16VkCqu6Zg5jWqwHA;
typedef struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA tyTuple__aWN9bNzF9bubXNJV9ciomgpfA;
typedef struct tySequence__m4PVWjcAAjfxlwJxLkKn8A tySequence__m4PVWjcAAjfxlwJxLkKn8A;
typedef struct tyTuple__RWXAsQlFoGYyEQZp1G65sg tyTuple__RWXAsQlFoGYyEQZp1G65sg;
typedef struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg;
typedef struct tyTuple__RmGJuqOgEaHckHndh0LEsw tyTuple__RmGJuqOgEaHckHndh0LEsw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__J4cxakKjhKxTIJR9bojMmXw tyTuple__J4cxakKjhKxTIJR9bojMmXw;
typedef struct tySequence__i89c5kdtWKzK3OEiI81pkkw tySequence__i89c5kdtWKzK3OEiI81pkkw;
typedef struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A;
typedef struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ;
typedef struct tySequence__GR8qmV1kNRcoQ2g76VFy3A tySequence__GR8qmV1kNRcoQ2g76VFy3A;
typedef struct tyTuple__a7QginWFapakKbWJBJ2vfA tyTuple__a7QginWFapakKbWJBJ2vfA;
typedef struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__kbX6x85REySUrk9auORL0vw tyTuple__kbX6x85REySUrk9auORL0vw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g;
typedef struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q;
typedef struct tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A;
typedef struct tyTuple__nF9cH4hinXgGEUwO4G2bshw tyTuple__nF9cH4hinXgGEUwO4G2bshw;
typedef struct tyTuple__G67QVmVVaUSxoi6cjqMwfw tyTuple__G67QVmVVaUSxoi6cjqMwfw;
typedef struct tyTuple__QoInXc7L9b87jyFPG5wdUcg tyTuple__QoInXc7L9b87jyFPG5wdUcg;
typedef struct tyTuple__a1QJSSO0LTGR9bFH59c2xGCA tyTuple__a1QJSSO0LTGR9bFH59c2xGCA;
typedef struct tyObject_TNodePair__LqlRPj2RevSKiPVchbJI5Q tyObject_TNodePair__LqlRPj2RevSKiPVchbJI5Q;
typedef struct tyTuple__tA7Q8IrfOKH7Mn89cK9cBAIg tyTuple__tA7Q8IrfOKH7Mn89cK9cBAIg;
typedef struct tyTuple__XOVT24GHXwqiEj5GCsEGCA tyTuple__XOVT24GHXwqiEj5GCsEGCA;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA;
typedef struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__PsEhl3dzznmmJiLAuIXZOg tyTuple__PsEhl3dzznmmJiLAuIXZOg;
typedef struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w;
typedef struct tyTuple__Db8CrQifKGIsKc3w71w7Lw tyTuple__Db8CrQifKGIsKc3w71w7Lw;
typedef struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg;
typedef struct tySequence__lo3S1lKyiPLhGGB9cBawd6A tySequence__lo3S1lKyiPLhGGB9cBawd6A;
typedef struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ;
typedef struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw tyTuple__FEYH9alRJhHD0uTKF2vnIqw;
typedef struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA;
typedef struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA;
typedef struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw;
typedef struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg tyTuple__VUJ5Hjm4tKAResBsRHJvYg;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA {
tySequence__ijtae5OneaLys0hN9alAicA* data;
NI counter;
};
struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w {
tySequence__SerjNoUujW2dUouVBrJiCw* data;
NI counter;
};
struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA {
tySequence__K9agbtcb0qPZuSJFXB9cTe6g* data;
NI counter;
};
typedef tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyArray__46hjIasL27aUz9c7kgtWooQ[5];
struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg {
tySequence__m88qdML9cQOuqGAQn6XWL1A* data;
NI counter;
};
struct tyObject_Table__1hIWbTQWYT4BmhdESze57A {
tySequence__naEbXEp9b9aiW1zXJorqf9cXQ* data;
NI counter;
};
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
};
struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw {
NI counter;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* data;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__imojfg883tkWsWJwyshGqQ {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA {
tySequence__KgiZ29chkJAD01p9aLRB32qw* data;
NI counter;
};
struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A {
tySequence__rkYRZrbHVYL3nhXlQW3K9bw* data;
NI counter;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg[65];
struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ {
tySequence__YmPd0eWfcTfrVYrthlXPYA* data;
NI counter;
};
struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__I6rzVhdiYtUh7jwWJQoeyw) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__EQOAUyRkp9c3eeiGlHvCThA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q {
tySequence__Hz5SYwQU29b9aFLt09blvVQPg* data;
NI counter;
};
struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg {
tySequence__3G9aA9cLXaPxuRxMKm3anacQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__1CO5eEh25fBKUWGagpikwg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
typedef N_NIMCALL_PTR(void, tyProc__VcUg5jOhttLagdxUmVN8Tg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__XOkru1xuh2bHzmkw1UYzLA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formal, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* actual);
struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opNot;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opContains;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLe;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLt;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAnd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opOr;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opIsNil;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opEq;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAdd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opSub;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opMul;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opDiv;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg {
tySequence__RNhZxf20g9beyq5VBOGxhDg* ifaces;
tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* packed_0;
tySequence__lFbCtu5P2Kf7YDYtGjkxAQ* encoders;
tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA typeInstCache;
tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w procInstCache;
tyArray__46hjIasL27aUz9c7kgtWooQ attachedOps;
tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg methodsPerType;
tyObject_Table__1hIWbTQWYT4BmhdESze57A enumToStringProcs;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw emittedTypeInfo;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA startupPackedConfig;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw deps;
tyObject_Table__imojfg883tkWsWJwyshGqQ importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__BCPh85PHtwxox9bv7NLFrlg inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* usageSym;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* owners;
tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA suggestSymbols;
tyObject_Table__LM44poVdVEn4Mo4N4L8c3A suggestErrors;
tySequence__IRFEb1e9bxgbJLuB5xrdZsQ* methods;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* systemModule;
tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg sysTypes;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw compilerprocs;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw exposed;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageTypes;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* emptyNode;
tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ canonTypes;
tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw symBodyHashes;
tyProc__I6rzVhdiYtUh7jwWJQoeyw importModuleCallback;
tyProc__EQOAUyRkp9c3eeiGlHvCThA includeFileCallback;
tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q cacheSeqs;
tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g cacheCounters;
tyObject_Table__R7JnJQEipxxOlJWXQz7jWg cacheTables;
tySequence__bPFv6ypvvCX2A9a9al8utL2Q* passes;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinition;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinitionResolveForward;
tyProc__1CO5eEh25fBKUWGagpikwg onUsage;
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* globalDestructors;
tyProc__VcUg5jOhttLagdxUmVN8Tg strongSemCheck;
tyProc__XOkru1xuh2bHzmkw1UYzLA compatibleProps;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg operators;
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_Table__No9aC1Wmth1NAiZioiz5fTA {
tySequence__XN3007vuiFWlN1E7IEcusw* data;
NI counter;
};
struct tyObject_BModuleListcolonObjectType___9c4b0IbdzIJRabh100GyFtA {
  RootObj Sup;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* mainModProcs;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* mainModInit;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* otherModsInit;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* mainDatInit;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* mapping;
tySequence__ukLNp6qJ4FndCViFTz0FGg* modules;
tySequence__ukLNp6qJ4FndCViFTz0FGg* modulesClosed;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* forwardedProcs;
tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* generatedHeader;
tyObject_Table__No9aC1Wmth1NAiZioiz5fTA typeInfoMarker;
tyObject_Table__No9aC1Wmth1NAiZioiz5fTA typeInfoMarkerV2;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph;
NI strVersion;
NI seqVersion;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* nimtv;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* nimtvDeps;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw nimtvDeclared;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw {
  RootObj Sup;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
};
typedef tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tyArray__7rM0tLpIsYC6jb0g8BIVwg[20];
typedef NU8 tySet_tyEnum_CodegenFlag__vPx29bHhk9a7V50u1UO0rM4w;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_Table__dHMrTjFDXaK9bwjVxsGCupQ {
tySequence__ElVzGEMtCZvLUQLuuVlE5A* data;
NI counter;
};
struct tyObject_HashSet__KYwZ0vHsYO0DQEC4qpQkAQ {
tySequence__WPcy3bORPBFlmk2KIq2pbQ* data;
NI counter;
};
struct tyObject_TNodeTable__pvgAyOR0BNAWS4QLyWEfKg {
NI counter;
tySequence__PPSNlMjxeLUadep32xHHyA* data;
};
typedef tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tyArray__rCk89asLRz4agKOwweN9cvXg[10];
struct tyObject_CountTable__XawALO1wTnCsJeWBJMYZyg {
tySequence__XUL1TrMU0tgXmaMFCIYgFQ* data;
NI counter;
NIM_BOOL isSorted;
};
struct tyObject_NdiFile__ZdQ0n9cikYC2TzROZ1EnTOA {
NIM_BOOL enabled;
FILE* f;
NimStringDesc* buf;
NimStringDesc* filename;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* syms;
};
struct tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA {
  tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw Sup;
tyArray__7rM0tLpIsYC6jb0g8BIVwg s;
tySet_tyEnum_CodegenFlag__vPx29bHhk9a7V50u1UO0rM4w flags;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
NimStringDesc* filename;
NimStringDesc* cfilename;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tmpBase;
tyObject_Table__dHMrTjFDXaK9bwjVxsGCupQ typeCache;
tyObject_HashSet__KYwZ0vHsYO0DQEC4qpQkAQ typeABICache;
tyObject_Table__dHMrTjFDXaK9bwjVxsGCupQ forwTypeCache;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw declaredThings;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw declaredProtos;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw alive;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* headerFiles;
tyObject_Table__dHMrTjFDXaK9bwjVxsGCupQ typeInfoMarker;
tyObject_Table__dHMrTjFDXaK9bwjVxsGCupQ typeInfoMarkerV2;
tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* initProc;
tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* preInitProc;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* hcrCreateTypeInfosProc;
NIM_BOOL inHcrInitGuard;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* typeStack;
tyObject_TNodeTable__pvgAyOR0BNAWS4QLyWEfKg dataCache;
NI typeNodes;
NI nimTypes;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* typeNodesName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* nimTypesName;
NI labels;
tyArray__rCk89asLRz4agKOwweN9cvXg extensionLoaders;
tyObject_CountTable__XawALO1wTnCsJeWBJMYZyg sigConflicts;
tyObject_BModuleListcolonObjectType___9c4b0IbdzIJRabh100GyFtA* g;
tyObject_NdiFile__ZdQ0n9cikYC2TzROZ1EnTOA ndi;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ {
  RootObj Sup;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* left;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* right;
NI L;
NimStringDesc* data;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
typedef NU8 tySet_tyEnum_TCProcFlag__Iv1wQAvkoMCW3v9cTnZWvJw;
struct tyObject_CountTable__QstdiKcmGEpsdJjh0p9cU7Q {
tySequence__jwzrUFjG9akTIJTBBFvvqxw* data;
NI counter;
NIM_BOOL isSorted;
};
struct tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc;
tySet_tyEnum_TCProcFlag__Iv1wQAvkoMCW3v9cTnZWvJw flags;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw currLineInfo;
tySequence__IjAwukZ9aSEsol9c48He4FYQ* nestedTryStmts;
tySequence__UQWyowqEA29c6NZ9csQYyjXQ* finallySafePoints;
NI labels;
tySequence__Y9a9bBybAqzjKkPsvOIQEzpw* blocks;
NI breakIdx;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* module;
NI withinLoop;
NI splitDecls;
NI withinTryWithExcept;
NI withinBlockLeaveActions;
tyObject_CountTable__QstdiKcmGEpsdJjh0p9cU7Q sigConflicts;
};
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
typedef NU8 tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU8 tyEnum_TCProcFlag__Iv1wQAvkoMCW3v9cTnZWvJw;
typedef NU8 tyEnum_CodegenFlag__vPx29bHhk9a7V50u1UO0rM4w;
typedef NU8 tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU8 tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg {
NI32 module;
NI32 symId;
NI32 typeId_0;
NIM_BOOL sealed;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
typedef NU8 tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tyArray__ezLPaPcF59bTlk7c0H9buNTA[3];
struct tyObject_TBlock__FHXN9cI0ri9bj2d9cKw8iPHZg {
NI id;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* label;
tyArray__ezLPaPcF59bTlk7c0H9buNTA sections;
NIM_BOOL isLoop;
NI16 nestedTryStmts;
NI16 nestedExceptStmts;
NI16 frameLen;
};
typedef tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tyArray__ts9cf9blICas1QWmw89bglZ7w[1];
typedef tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tyArray__dAmhZbEWrTM5xES2bTVweg[1];
typedef NU8 tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw;
struct tyTuple__T1RBf8m9axj9bvJRlYejkpkQ {
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field0;
NIM_BOOL Field1;
NI Field2;
};
typedef NU8 tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA;
struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg {
NI id;
NimStringDesc* s;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* next;
NI h;
};
struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* converters;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* patterns;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* pureEnums;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interf;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interfHidden;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* uniqueName;
};
typedef NU8 tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
typedef NU8 tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ;
struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg {
tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* path;
};
typedef NU8 tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw;
typedef NU8 tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg[9];
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInst;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg uniqueId;
};
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU8 tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg;
typedef NU8 tySet_tyEnum_ConsiderFlag__GoLTePImz7fvtyywyQa3DQ;
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__QbmGqFaLnb1IWWToREeaIA* trace;
Exception* up;
};
struct TSafePoint {
TSafePoint* prev;
NI status;
jmp_buf context;
};
typedef NU32 tyArray__FleBT9cC2nxhgiXmSYYnEKA[4];
struct tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ {
tyArray__FleBT9cC2nxhgiXmSYYnEKA udata;
};
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
typedef tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tyArray__FKvM4FDhljtt88k8FkGthA[3];
typedef tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tyArray__InO6xIOhXMnkCXPnEYWwWg[4];
typedef tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tyArray__o0h2w7RqUVr9aUhiJaoJjoQ[2];
struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
};
typedef NU8 tySet_tyEnum_TInfoOSProp__zwoAJqKVL5t9aBqjgBrDcAA;
struct tyTuple__oa1dFn55BmC688WoXKTtUg {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
NimStringDesc* Field3;
NimStringDesc* Field4;
NimStringDesc* Field5;
NimStringDesc* Field6;
NimStringDesc* Field7;
NimStringDesc* Field8;
NimStringDesc* Field9;
NimStringDesc* Field10;
NimStringDesc* Field11;
tySet_tyEnum_TInfoOSProp__zwoAJqKVL5t9aBqjgBrDcAA Field12;
};
typedef tyTuple__oa1dFn55BmC688WoXKTtUg tyArray__zAjcTh151RgaydpulQUcEQ[33];
typedef NimStringDesc* tyArray__nHXaesL0DJZHyVS07ARPRA[1];
typedef NU8 tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ;
typedef NU8 tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
typedef tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tyArray__XSZGJHCjWme3CUmFzckT3g[5];
typedef NimStringDesc* tyArray__J4GSVrMkyDLER4Hu9cFBPhg[11];
typedef NU8 tyEnum_ObjConstrMode__fUO6aSwLQdJNwZTWRxqbKg;
typedef NU8 tyEnum_TTypeFieldResult__4qPt3YBfh0N9aL5U7Kssfdg;
struct tyTuple__1DF4qJDR9cG0CgZV1nlkaYw {
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* Field0;
NI32 Field1;
};
typedef NU8 tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg;
struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg {
tySequence__4Murtwnm0Fyc7F9acrytEXw* nodes;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ;
struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ {
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw {
tySequence__IHUFRsFxZNv7YydiUO2esQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag {
NimStringDesc* definedSymbols;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA moduleFlags;
tySequence__PXIzfWocnrafGz5p3CP5LA* includes;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* imports;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg toReplay;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg topLevel;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg bodies;
tySequence__b89aLriiJnVTD186H6zNIgg* exports;
tySequence__b89aLriiJnVTD186H6zNIgg* hidden;
tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw* reexports;
tySequence__b89aLriiJnVTD186H6zNIgg* compilerProcs;
tySequence__48JTohSgTy339bRxHzUD8KA* converters;
tySequence__48JTohSgTy339bRxHzUD8KA* methods;
tySequence__48JTohSgTy339bRxHzUD8KA* trmacros;
tySequence__48JTohSgTy339bRxHzUD8KA* pureEnums;
tySequence__QnmOtn1Iv4LvxOXoMn8Rbg* macroUsages;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* typeInstCache;
tySequence__qy6Iwdy00wN560qud54HTg* procInstCache;
tySequence__k67v9bwvvQDmS1ynyGGUbeQ* attachedOps;
tySequence__cLsClAAfd0MKkoBQVyvdvw* methodsPerType;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* enumToStringProcs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* emittedTypeInfo;
tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ backendFlags;
tySequence__q9bTuOB0JXh1iZ3CSGdRLbg* syms;
tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw* types;
tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ strings;
tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw numbers;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA cfg;
};
struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ {
tySequence__C3r8jsj9chA4sIlYfDN5aDw* data;
NI counter;
};
struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg {
tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg status;
NIM_BOOL symsInit;
NIM_BOOL typesInit;
NIM_BOOL loadedButAliveSetChanged;
tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag fromDisk;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* syms;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* types;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ iface;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ ifaceHidden;
};
typedef NU8 tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ;
typedef tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tyArray__SJIWFUvBTGjESW6tXwR6UA[6];
struct tyObject_TTraversalClosure__4DrvOBPCF3NL9akdOcxiJCw {
tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p;
NimStringDesc* visitorFrmt;
};
typedef NU8 tySet_tyEnum_TInfoCCProp__9biNtFPzjM9c2i62RuZ9c19biA;
struct tyTuple__EU9a9btT9bDanvLpyt3NNw3KA {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
NimStringDesc* Field3;
NimStringDesc* Field4;
NimStringDesc* Field5;
NimStringDesc* Field6;
NimStringDesc* Field7;
NimStringDesc* Field8;
NimStringDesc* Field9;
NimStringDesc* Field10;
NimStringDesc* Field11;
NimStringDesc* Field12;
NimStringDesc* Field13;
NimStringDesc* Field14;
NimStringDesc* Field15;
NimStringDesc* Field16;
NimStringDesc* Field17;
NimStringDesc* Field18;
NimStringDesc* Field19;
NimStringDesc* Field20;
tySet_tyEnum_TInfoCCProp__9biNtFPzjM9c2i62RuZ9c19biA Field21;
};
typedef tyTuple__EU9a9btT9bDanvLpyt3NNw3KA tyArray__BZ5uScSUO7j9awRS7LrncpQ[11];
typedef NU8 tyEnum_TInfoCCProp__9biNtFPzjM9c2i62RuZ9c19biA;
typedef tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tyArray__27u9bjXoGJPnSsktsUHwhCw[7];
typedef NU8 tyEnum_TClosureTypeKind__9cCFzcVQ9cBXhFbAj307bqVg;
typedef NU8 tySet_tyEnum_TAssignmentFlag__A5xFQCIBNzBTAeRylr7rQA;
typedef NU8 tyEnum_TAssignmentFlag__A5xFQCIBNzBTAeRylr7rQA;
typedef NU8 tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA;
typedef NimStringDesc* tyArray__maqUPK0xSxvPlM6fxAqSIw[14];
typedef NU16 tySet_tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA;
typedef NU8 tyEnum_AliasKind__vyyqF5f609aD8pvRKZixr4w;
struct tyTuple__xIPPgKI3s9a9c79aFyHPbe0cg {
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* Field0;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* Field1;
};
typedef NU8 tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA;
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
typedef NimStringDesc* tyArray__OyU7f9aPY4V3Jxs36khP6fw[4];
typedef NimStringDesc* tyArray__2TOvp8OQKJM4nuxy9aPytmQ[7];
typedef NimStringDesc* tyArray__oU05KnNo1VmpSMUvzgvN9ag[2];
typedef tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* tyArray__iegsN9bf6GqRiWprrJjTAoA[1];
typedef NimStringDesc* tyArray__RXSdvX0UuCkXpf4OjqXhcg[5];
typedef NU8 tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU16 tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw;
typedef NU8 tyEnum_TNodeKind__jsmc0lvQl44MLrOvpRmgJQ;
struct tyTuple__PCL3pTh9cmlWmhmXAE5IOKQ {
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw Field0;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* Field1;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyObject_Env_cgendotnim_genMainProc___MH1VwSLIbfCI9coJDTeX9c2Q {
  RootObj Sup;
NI colonstate_;
tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m1;
};
typedef struct {
N_NIMCALL_PTR(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, ClP_0) (NimStringDesc* handle, NimStringDesc* name, void* ClE_0);
void* ClE_0;
} tyProc__XXidWMaHeMLVIvwr9a5WT9ag;
typedef N_CLOSURE_PTR(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_909) (NimStringDesc* handle, NimStringDesc* name);
typedef N_CLOSURE_PTR(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_913) (NimStringDesc* handle, NimStringDesc* name);
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
typedef NU8 tyEnum_Endianness__IxIU7d9c8Q9csHQviYDQM13A;
struct tyTuple__cyyQdcuoDUp88Doe6rM7kA {
NimStringDesc* Field0;
NI Field1;
tyEnum_Endianness__IxIU7d9c8Q9csHQviYDQM13A Field2;
NI Field3;
NI Field4;
};
typedef tyTuple__cyyQdcuoDUp88Doe6rM7kA tyArray__O7sksHvn7BNpHcBD2dBmog[26];
typedef NU8 tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ;
struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ {
tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* data;
NI counter;
};
struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ {
NI32 thisModule;
NI32 lastFile;
NU32 lastLit;
tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ filenames;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* pendingTypes;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* pendingSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw typeMarker;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw symMarker;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
};
struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ {
NU32 module;
NI32 item;
};
struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg {
NI module;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ packed_0;
};
struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
};
struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__dlD6tEGzYLLpKVq3XwuFlA* Field2;
};
struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q {
NI module;
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg sym;
tySequence__UnGSk9aaLosDroi2QDrlOfQ* concreteTypes;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__rZZA0skon1OsHdiEvT8RZQ {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__6OFCSvqRaxyEgUqWtnZSlw* Field2;
};
struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field2;
};
struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
};
struct tyTuple__RWXAsQlFoGYyEQZp1G65sg {
NI Field0;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field1;
};
struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__m4PVWjcAAjfxlwJxLkKn8A* Field2;
};
struct tyTuple__RmGJuqOgEaHckHndh0LEsw {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field2;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
};
struct tyTuple__J4cxakKjhKxTIJR9bojMmXw {
NI Field0;
NI32 Field1;
tySequence__i89c5kdtWKzK3OEiI81pkkw* Field2;
};
struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ {
NI Field0;
NI32 Field1;
tySequence__GR8qmV1kNRcoQ2g76VFy3A* Field2;
};
struct tyTuple__a7QginWFapakKbWJBJ2vfA {
tySequence__ed0C0uAUZPhvw3RAc5hfYg* Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__kbX6x85REySUrk9auORL0vw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q {
tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A* root;
NI entries;
};
struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, tyProc__kqPx9c4py2HW6KcFMhNvxtg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__9c6qRjwy7Es8UkDTIUwAfFA) (tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__mv4BsRs5VEnhcxzV6pQU5w) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
struct tyTuple__nF9cH4hinXgGEUwO4G2bshw {
tyProc__kqPx9c4py2HW6KcFMhNvxtg Field0;
tyProc__9c6qRjwy7Es8UkDTIUwAfFA Field1;
tyProc__mv4BsRs5VEnhcxzV6pQU5w Field2;
NIM_BOOL Field3;
};
struct tyTuple__G67QVmVVaUSxoi6cjqMwfw {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyTuple__1DF4qJDR9cG0CgZV1nlkaYw Field2;
};
struct tyTuple__QoInXc7L9b87jyFPG5wdUcg {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* Field2;
};
struct tyTuple__a1QJSSO0LTGR9bFH59c2xGCA {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
};
struct tyObject_TNodePair__LqlRPj2RevSKiPVchbJI5Q {
NI h;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* key;
NI val;
};
struct tyTuple__tA7Q8IrfOKH7Mn89cK9cBAIg {
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field0;
NI Field1;
};
struct tyTuple__XOVT24GHXwqiEj5GCsEGCA {
NimStringDesc* Field0;
NI Field1;
};
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA {
NCSTRING procname;
NI line;
NCSTRING filename;
};
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
NU32 Field0;
NimStringDesc* Field1;
};
struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA {
NU16 line;
NI16 col;
NU32 file;
};
struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA {
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
NI32 operand;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeId_0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
};
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
NU32 Field0;
NI32 Field1;
};
struct tyTuple__PsEhl3dzznmmJiLAuIXZOg {
NU32 Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA Field1;
};
struct tyTuple__Db8CrQifKGIsKc3w71w7Lw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ key;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* concreteTypes;
};
struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ {
tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
NI Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA {
tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
NU32 name;
NI32 path;
};
struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA {
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
NU32 name;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typ;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
NI32 ast;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ guard;
NI bitsize;
NI alignment;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
NU32 externalName;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw locFlags;
tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA annex;
NI32 constraint;
};
struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw {
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* types;
NI32 n;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeInst;
NI32 nonUniqueId;
};
struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg {
NI Field0;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* Field1;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* Field2;
};
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
NI Field0;
NI32 Field1;
NU32 Field2;
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
struct tySequence__ukLNp6qJ4FndCViFTz0FGg {
  TGenericSeq Sup;
  tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* data[SEQ_DECL_SIZE];
};
struct tySequence__Y9a9bBybAqzjKkPsvOIQEzpw {
  TGenericSeq Sup;
  tyObject_TBlock__FHXN9cI0ri9bj2d9cKw8iPHZg data[SEQ_DECL_SIZE];
};
struct tySequence__ed0C0uAUZPhvw3RAc5hfYg {
  TGenericSeq Sup;
  tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* data[SEQ_DECL_SIZE];
};
struct tySequence__UQWyowqEA29c6NZ9csQYyjXQ {
  TGenericSeq Sup;
  tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* data[SEQ_DECL_SIZE];
};
struct tySequence__6H5Oh5UUvVCLiakt9aTwtUQ {
  TGenericSeq Sup;
  NU8 data[SEQ_DECL_SIZE];
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__shxop0zPIs5Ec3k71aCLuQ {
  TGenericSeq Sup;
  NIM_BOOL data[SEQ_DECL_SIZE];
};
struct tySequence__Vz8km29c8JcWq5WOBlnn2aQ {
  TGenericSeq Sup;
  tyTuple__PCL3pTh9cmlWmhmXAE5IOKQ data[SEQ_DECL_SIZE];
};
struct tySequence__IjAwukZ9aSEsol9c48He4FYQ {
  TGenericSeq Sup;
  tyTuple__T1RBf8m9axj9bvJRlYejkpkQ data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__RNhZxf20g9beyq5VBOGxhDg {
  TGenericSeq Sup;
  tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ data[SEQ_DECL_SIZE];
};
struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ {
  TGenericSeq Sup;
  tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg data[SEQ_DECL_SIZE];
};
struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ {
  TGenericSeq Sup;
  tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ data[SEQ_DECL_SIZE];
};
struct tySequence__dlD6tEGzYLLpKVq3XwuFlA {
  TGenericSeq Sup;
  tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ data[SEQ_DECL_SIZE];
};
struct tySequence__ijtae5OneaLys0hN9alAicA {
  TGenericSeq Sup;
  tyTuple__UluY8x0Nj6cp9b0o88wJ0lg data[SEQ_DECL_SIZE];
};
struct tySequence__6OFCSvqRaxyEgUqWtnZSlw {
  TGenericSeq Sup;
  tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q data[SEQ_DECL_SIZE];
};
struct tySequence__SerjNoUujW2dUouVBrJiCw {
  TGenericSeq Sup;
  tyTuple__rZZA0skon1OsHdiEvT8RZQ data[SEQ_DECL_SIZE];
};
struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g {
  TGenericSeq Sup;
  tyTuple__q13Zt16VkCqu6Zg5jWqwHA data[SEQ_DECL_SIZE];
};
struct tySequence__m4PVWjcAAjfxlwJxLkKn8A {
  TGenericSeq Sup;
  tyTuple__RWXAsQlFoGYyEQZp1G65sg data[SEQ_DECL_SIZE];
};
struct tySequence__m88qdML9cQOuqGAQn6XWL1A {
  TGenericSeq Sup;
  tyTuple__aWN9bNzF9bubXNJV9ciomgpfA data[SEQ_DECL_SIZE];
};
struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ {
  TGenericSeq Sup;
  tyTuple__RmGJuqOgEaHckHndh0LEsw data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__i89c5kdtWKzK3OEiI81pkkw {
  TGenericSeq Sup;
  tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A data[SEQ_DECL_SIZE];
};
struct tySequence__KgiZ29chkJAD01p9aLRB32qw {
  TGenericSeq Sup;
  tyTuple__J4cxakKjhKxTIJR9bojMmXw data[SEQ_DECL_SIZE];
};
struct tySequence__GR8qmV1kNRcoQ2g76VFy3A {
  TGenericSeq Sup;
  tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* data[SEQ_DECL_SIZE];
};
struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw {
  TGenericSeq Sup;
  tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ data[SEQ_DECL_SIZE];
};
struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ {
  TGenericSeq Sup;
  tyTuple__a7QginWFapakKbWJBJ2vfA data[SEQ_DECL_SIZE];
};
struct tySequence__YmPd0eWfcTfrVYrthlXPYA {
  TGenericSeq Sup;
  tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg {
  TGenericSeq Sup;
  tyTuple__kbX6x85REySUrk9auORL0vw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ {
  TGenericSeq Sup;
  tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g data[SEQ_DECL_SIZE];
};
struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q {
  TGenericSeq Sup;
  tyTuple__nF9cH4hinXgGEUwO4G2bshw data[SEQ_DECL_SIZE];
};
struct tySequence__XN3007vuiFWlN1E7IEcusw {
  TGenericSeq Sup;
  tyTuple__G67QVmVVaUSxoi6cjqMwfw data[SEQ_DECL_SIZE];
};
struct tySequence__ElVzGEMtCZvLUQLuuVlE5A {
  TGenericSeq Sup;
  tyTuple__QoInXc7L9b87jyFPG5wdUcg data[SEQ_DECL_SIZE];
};
struct tySequence__WPcy3bORPBFlmk2KIq2pbQ {
  TGenericSeq Sup;
  tyTuple__a1QJSSO0LTGR9bFH59c2xGCA data[SEQ_DECL_SIZE];
};
struct tySequence__PPSNlMjxeLUadep32xHHyA {
  TGenericSeq Sup;
  tyObject_TNodePair__LqlRPj2RevSKiPVchbJI5Q data[SEQ_DECL_SIZE];
};
struct tySequence__XUL1TrMU0tgXmaMFCIYgFQ {
  TGenericSeq Sup;
  tyTuple__tA7Q8IrfOKH7Mn89cK9cBAIg data[SEQ_DECL_SIZE];
};
struct tySequence__jwzrUFjG9akTIJTBBFvvqxw {
  TGenericSeq Sup;
  tyTuple__XOVT24GHXwqiEj5GCsEGCA data[SEQ_DECL_SIZE];
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g {
  TGenericSeq Sup;
  tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg data[SEQ_DECL_SIZE];
};
struct tySequence__QbmGqFaLnb1IWWToREeaIA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA data[SEQ_DECL_SIZE];
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  TGenericSeq Sup;
  tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE];
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  TGenericSeq Sup;
  NU32 data[SEQ_DECL_SIZE];
};
struct tySequence__4Murtwnm0Fyc7F9acrytEXw {
  TGenericSeq Sup;
  tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA data[SEQ_DECL_SIZE];
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  TGenericSeq Sup;
  tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE];
};
struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw {
  TGenericSeq Sup;
  tyTuple__PsEhl3dzznmmJiLAuIXZOg data[SEQ_DECL_SIZE];
};
struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg {
  TGenericSeq Sup;
  tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w data[SEQ_DECL_SIZE];
};
struct tySequence__oKtVqsc9bQVCNyrijELM4OQ {
  TGenericSeq Sup;
  tyTuple__Db8CrQifKGIsKc3w71w7Lw data[SEQ_DECL_SIZE];
};
struct tySequence__qy6Iwdy00wN560qud54HTg {
  TGenericSeq Sup;
  tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg data[SEQ_DECL_SIZE];
};
struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ {
  TGenericSeq Sup;
  tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ data[SEQ_DECL_SIZE];
};
struct tySequence__cLsClAAfd0MKkoBQVyvdvw {
  TGenericSeq Sup;
  tyTuple__FEYH9alRJhHD0uTKF2vnIqw data[SEQ_DECL_SIZE];
};
struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg {
  TGenericSeq Sup;
  tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA data[SEQ_DECL_SIZE];
};
struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw {
  TGenericSeq Sup;
  tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw data[SEQ_DECL_SIZE];
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  TGenericSeq Sup;
  NI64 data[SEQ_DECL_SIZE];
};
struct tySequence__lo3S1lKyiPLhGGB9cBawd6A {
  TGenericSeq Sup;
  tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ data[SEQ_DECL_SIZE];
};
struct tySequence__C3r8jsj9chA4sIlYfDN5aDw {
  TGenericSeq Sup;
  tyTuple__VUJ5Hjm4tKAResBsRHJvYg data[SEQ_DECL_SIZE];
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  TGenericSeq Sup;
  tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE];
};
struct tySequence__UnGSk9aaLosDroi2QDrlOfQ {
  TGenericSeq Sup;
  tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(tyObject_BModuleListcolonObjectType___9c4b0IbdzIJRabh100GyFtA*, newModuleList__cgendata_392)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5319)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5281)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5326)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5324)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5275)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA*, newModule__cgen_28577)(tyObject_BModuleListcolonObjectType___9c4b0IbdzIJRabh100GyFtA* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA*, rawNewModule__cgen_28572)(tyObject_BModuleListcolonObjectType___9c4b0IbdzIJRabh100GyFtA* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA*, rawNewModule__cgen_28479)(tyObject_BModuleListcolonObjectType___9c4b0IbdzIJRabh100GyFtA* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, NimStringDesc* filename);
N_LIB_PRIVATE N_NOINLINE(void*, newObj)(TNimType* typ, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, rope__ropes_109)(NimStringDesc* s);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___modulegraphs_8985)(tyArray__qtqsWM5aXmcpMIVmvq3kAA u);
N_LIB_PRIVATE N_NIMCALL(void, hashOwner__sighashes_518)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyArray__qtqsWM5aXmcpMIVmvq3kAA Result);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(void, initPackedSet__pureZcollectionsZintsets_16)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(void, initTable__cgen_28491)(NI initialSize, tyObject_Table__dHMrTjFDXaK9bwjVxsGCupQ* Result);
N_LIB_PRIVATE N_NIMCALL(void, initCountTable__cgen_28510)(NI initialSize, tyObject_CountTable__XawALO1wTnCsJeWBJMYZyg* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w*, newProc__cgendata_278)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc, tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* module);
N_LIB_PRIVATE N_NIMCALL(tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ, initProcOptions__cgen_28467)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m);
N_LIB_PRIVATE N_NIMCALL(void, initNodeTable__ast_4132)(tyObject_TNodeTable__pvgAyOR0BNAWS4QLyWEfKg* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getTempName__cgen_428)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, amp___ropes_128)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* a, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, rope__ropes_115)(NI64 i);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, noschangeFileExt)(NimStringDesc* filename, NimStringDesc* ext);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, completeCfilePath__extccomp_715)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* cfile, NIM_BOOL createSubDir);
N_LIB_PRIVATE N_NIMCALL(void, open__ndi_24)(tyObject_NdiFile__ZdQ0n9cikYC2TzROZ1EnTOA* f, NimStringDesc* filename, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPath__msgs_548)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(void, genTopLevelStmt__cgen_28702)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NIM_BOOL, skipCodegen__passes_51)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, transformStmt__transf_1888)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, injectDestructorCalls__injectdestructors_10132)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hcrOn__cgen_43)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hcrOn__options_582)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, addHcrInitGuards__cgen_28671)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL* inInitGuard);
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, endBlock__cgen_13329)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p);
N_LIB_PRIVATE N_NIMCALL(void, add__ropes_159)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** a, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_13581)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_13590)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7535)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, endBlock__cgen_13562)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* blockEnd);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, blockBody__cgen_13554)(tyObject_TBlock__FHXN9cI0ri9bj2d9cKw8iPHZg* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_13557)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
static N_INLINE(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**, s__cgendata_225)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw s);
static N_INLINE(tyObject_TBlock__FHXN9cI0ri9bj2d9cKw8iPHZg*, X5BX5D___cgendata_229)(tyObject_TBlock__FHXN9cI0ri9bj2d9cKw8iPHZg* s, NI sLen_0, NI i);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, indentLine__cgen_286)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r);
N_LIB_PRIVATE N_NIMCALL(void, prepend__ropes_265)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** a, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* b);
N_NIMCALL(NimStringDesc*, rawNewString)(NI cap);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(NI, startBlockInternal__cgen_13308)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p);
N_LIB_PRIVATE N_NIMCALL(NI, inExceptBlockLen__cgen_13273)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p);
N_LIB_PRIVATE N_NIMCALL(void, genStmts__cgen_11522)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasHint__options_530)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA note);
N_LIB_PRIVATE N_NIMCALL(void, pushInfoContext__msgs_500)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* detail);
N_LIB_PRIVATE N_NIMCALL(void, expr__cgen_11525)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, fillProcLoc__cgen_11493)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, fillLoc__cgen_71)(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* a, tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r, tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ s);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, mangleName__cgen_646)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, mangle__ccgutils_112)(NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(void, add__ropes_162)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, idOrSig__sighashes_2071)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NimStringDesc* currentModule, tyObject_CountTable__XawALO1wTnCsJeWBJMYZyg* sigCollisions, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, genProcPrototype__cgen_11529)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(void, useHeader__cgen_111)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getStr__ast_4611)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a);
N_LIB_PRIVATE N_NIMCALL(void, includeHeader__cgendata_214)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* this_0, NimStringDesc* header);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__astalgo_402)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(void, cgFormatValue__cgen_151)(NimStringDesc** result, NimStringDesc* value);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isReloadable__cgen_6737)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(void, cgFormatValue__cgen_147)(NimStringDesc** result, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* value);
N_LIB_PRIVATE N_NIMCALL(void*, newSeq)(TNimType* typ, NI len);
static N_INLINE(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, pop__ropes_180)(tySequence__UQWyowqEA29c6NZ9csQYyjXQ** s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getTypeDesc__cgen_6662)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getTypeDescAux__cgen_1332)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* origTyp, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* check, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, skipTypes__ast_3723)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kinds);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isImportedCppType__cgen_1312)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_1441)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, typeToString__types_50)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg prefer);
N_LIB_PRIVATE N_NIMCALL(void, hashType__sighashes_473)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tySet_tyEnum_ConsiderFlag__GoLTePImz7fvtyywyQa3DQ flags, tyArray__qtqsWM5aXmcpMIVmvq3kAA Result);
static N_INLINE(void, pushSafePoint)(TSafePoint* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getTypePre__cgen_3089)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyArray__qtqsWM5aXmcpMIVmvq3kAA sig);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getSimpleTypeDesc__cgen_1830)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, typeNameOrLiteral__cgen_1813)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, NimStringDesc* literal);
N_LIB_PRIVATE N_NIMCALL(NI, detectStrVersion__cgen_490)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getCompilerProc__magicsys_145)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(NI, toInt__int495056_273)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, getInt__ast_4593)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, cgsym__cgen_126)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(void, genProc__cgen_421)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isActivated__cgen_26896)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc);
N_LIB_PRIVATE N_NIMCALL(void, addForwardedProc__cgen_49)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc);
N_LIB_PRIVATE N_NIMCALL(void, genProcNoForward__cgen_26633)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc);
N_LIB_PRIVATE N_NIMCALL(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA*, findPendingModule__cgen_56)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getModule__astalgo_216)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, symInDynamicLib__cgen_25776)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isGetProcAddr__cgen_25635)(tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* lib);
N_LIB_PRIVATE N_NIMCALL(void, loadDynamicLib__cgen_25651)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* lib);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_25669)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, libCandidates__pureZdynlib_37)(NimStringDesc* s, tySequence__sM4lkSb7zS6F7OVMvW9cffQ** dest);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newStrNode__ast_3801)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, NimStringDesc* strVal);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genStringLiteral__cgen_626)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genStringLiteralV1__cgen_525)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NI, nodeTableTestOrSet__treetab_198)(tyObject_TNodeTable__pvgAyOR0BNAWS4QLyWEfKg* t, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* key, NI val);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genStringLiteralDataOnlyV1__cgen_516)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_520)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, makeCString__msgs_50)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(void, cgFormatValue__cgen_154)(NimStringDesc** result, NI64 value);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_167)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genStringLiteralV2__cgen_579)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL isConst);
N_LIB_PRIVATE N_NIMCALL(void, genStringLiteralDataOnlyV2__cgen_560)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, NimStringDesc* s, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result, NIM_BOOL isConst);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_565)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_586)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, initLoc__cgen_66)(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* result, tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode, tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, rdLoc__cgen_435)(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_442)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, mangleDynLibProc__cgen_3812)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatSingleElem)(NimStringDesc* formatstr, NimStringDesc* a);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___systemZdollars_3)(NI x);
N_LIB_PRIVATE N_NIMCALL(void, initLocExpr__cgen_11548)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* result);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, amp___ropes_140)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_25800)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___ropes_250)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, lastSon__ast_4833)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_625)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info);
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_25841)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
static N_INLINE(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, t__cgen_85)(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_26677)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getModuleDllPath__cgen_142)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getModuleDllPath__cgen_131)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m);
N_LIB_PRIVATE N_NIMCALL(void, splitFile__pathutils_27)(NimStringDesc* x, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getCFile__cgen_129)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, mangleModuleName__modulepaths_32)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(void, symInDynamicLibPartial__cgen_25887)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(void, genProcAux__cgen_26283)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genProcHeader__cgen_632)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc, NIM_BOOL asPtr);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isNonReloadable__cgen_6745)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc);
N_LIB_PRIVATE N_NIMCALL(void, genProcParams__cgen_3508)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** rettype, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** params, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* check, NIM_BOOL declareEnvironment, NIM_BOOL weakDep);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInvalidReturnType__cgen_1353)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, NIM_BOOL isProc);
N_LIB_PRIVATE N_NIMCALL(NI64, getSize__types_3388)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ, mapType__cgen_1227)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ, mapSetType__cgen_1223)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__systemZassertions_56)(NimStringDesc* msg);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, lastSon__ast_3731)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___int495056_905)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, NI64 b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, firstOrd__types_1406)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsGarbageCollectedRef__types_612)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
static N_INLINE(NIM_BOOL, isObjLackingTypeField__cgen_1337)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isPureObject__types_132)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_3521)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
static N_INLINE(NIM_BOOL, isCompileTimeOnly__types_3592)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_3546)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, mangleParamName__cgen_658)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isKeyword__cgen_636)(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* w);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__cgen_720)(tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw s, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ, paramStorageLoc__cgen_3501)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* param);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, ccgIntroducedPtr__ccgutils_153)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* retType);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getTypeDescWeak__cgen_3345)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* check, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getTypeForward__cgen_3141)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyArray__qtqsWM5aXmcpMIVmvq3kAA sig);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, cacheGetType__cgen_1380)(tyObject_Table__dHMrTjFDXaK9bwjVxsGCupQ tab, tyArray__qtqsWM5aXmcpMIVmvq3kAA sig);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getOrDefault__cgen_1450)(tyObject_Table__dHMrTjFDXaK9bwjVxsGCupQ t, tyArray__qtqsWM5aXmcpMIVmvq3kAA key);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getTypeName__cgen_1179)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyArray__qtqsWM5aXmcpMIVmvq3kAA sig);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, typeName__cgen_1161)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___cgen_1895)(tyObject_Table__dHMrTjFDXaK9bwjVxsGCupQ* t, tyArray__qtqsWM5aXmcpMIVmvq3kAA key, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* val);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isImportedType__cgen_1301)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(void, addForwardStructFormat__cgen_3112)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* structOrUnion, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* typename_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_3124)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_3129)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, structOrUnion__cgen_3102)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(void, pushType__cgen_3070)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**, X5BX5D___cgen_3258)(tyObject_Table__dHMrTjFDXaK9bwjVxsGCupQ* t, tyArray__qtqsWM5aXmcpMIVmvq3kAA key);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, seqStar__cgen_3134)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_3553)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_3562)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_3571)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_3593)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ, mapReturnType__cgen_1297)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_3624)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, amp___ropes_144)(NimStringDesc* a, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_6783)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, runtimeFormat__ropes_271)(NimStringDesc* frmt, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, transformBody__transf_16)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc, NIM_BOOL cache);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, easyResultAsgn__cgen_26011)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsResult__cgen_25982)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, localVarDecl__cgen_11124)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, mangleLocalName__cgen_744)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
static N_INLINE(void, shallow__system_7445)(NimStringDesc** s);
N_NIMCALL(NimStringDesc*, mnewString)(NI len);
N_LIB_PRIVATE N_NIMCALL(NI, getOrDefault__cgen_830)(tyObject_CountTable__QstdiKcmGEpsdJjh0p9cU7Q t, NimStringDesc* key, NI default_0);
N_LIB_PRIVATE N_NIMCALL(void, inc__cgen_953)(tyObject_CountTable__QstdiKcmGEpsdJjh0p9cU7Q* t, NimStringDesc* key, NI val);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_3760)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genCLineDir__cgen_357)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** r, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, genCLineDir__cgen_340)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** r, NimStringDesc* filename, NI line, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_352)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, makeSingleLineCString__ccgutils_108)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NI, safeLineNm__cgen_337)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
static N_INLINE(NI, toLinenumber__msgs_619)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, initLocExprSingleUse__cgen_11552)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* result);
N_LIB_PRIVATE N_NIMCALL(void, assignLocalVar__cgen_11164)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, initLocalVar__cgen_11052)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* v, NIM_BOOL immediateAsgn);
N_LIB_PRIVATE N_NIMCALL(void, constructLoc__cgen_10987)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* loc, NIM_BOOL isTemp);
static N_INLINE(NIM_BOOL, isComplexValueType__cgen_10585)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(void, genRefAssign__cgen_10581)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw dest, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw src);
static N_INLINE(NIM_BOOL, usesWriteBarrier__options_4033)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, addrLoc__cgen_10337)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a);
N_LIB_PRIVATE N_NIMCALL(void, genObjectInit__cgen_10414)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw section, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* a, tyEnum_ObjConstrMode__fUO6aSwLQdJNwZTWRxqbKg mode);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeFieldResult__4qPt3YBfh0N9aL5U7Kssfdg, analyseObjectWithTypeField__types_585)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genTypeInfoV2__cgen_7958)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, getOrDefault__cgen_8116)(tyObject_Table__No9aC1Wmth1NAiZioiz5fTA t, tyArray__qtqsWM5aXmcpMIVmvq3kAA key, tyTuple__1DF4qJDR9cG0CgZV1nlkaYw* Result);
N_LIB_PRIVATE N_NIMCALL(void, declareNimType__cgen_7814)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, NimStringDesc* name, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* str, NI module);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7820)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7825)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getModuleDllPath__cgen_138)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, NI module);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7830)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_8496)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
static N_INLINE(NIM_BOOL, moduleOpenForCodegen__modulegraphs_9529)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI32 m);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___cgen_8590)(tyObject_Table__No9aC1Wmth1NAiZioiz5fTA* t, tyArray__qtqsWM5aXmcpMIVmvq3kAA key, tyTuple__1DF4qJDR9cG0CgZV1nlkaYw val);
N_LIB_PRIVATE N_NIMCALL(void, genTypeInfoV2Impl__cgen_7906)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* origType, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genTypeInfo2Name__cgen_7835)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7929)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genHook__cgen_7887)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ op);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getAttachedOp__modulegraphs_4049)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ op);
static N_INLINE(NIM_BOOL, isTrivialProc__cgen_7880)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
static N_INLINE(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, getBody__modulegraphs_13094)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, loadProcBody__icZic_8386)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canFormAcycle__types_820)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7937)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
static N_INLINE(NI, len__ast_3990)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genTypeInfoV1__cgen_6798)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_9995)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, typeToC__cgen_9772)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NIM_CHAR, nsuToLowerAsciiChar)(NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NI32, getOrDefault__cgen_10112)(tyObject_Table__9cHFtxtpgztIcDsypRz9byKw t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(void, rememberEmittedTypeInfo__modulegraphs_9541)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI32 m, NimStringDesc* ti);
N_LIB_PRIVATE N_NIMCALL(void, genTypeInfoAuxBase__cgen_6818)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* origType, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* base, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, tiNameForHcr__cgen_6814)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_6838)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_6844)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefined__options_2292)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* symbol);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___msgs_634)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_6858)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_6863)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_6868)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_6873)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_6878)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, fakeClosureType__cgen_7356)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, newType__ast_3884)(tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg id, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner);
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextTypeId__ast_3122)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x);
N_LIB_PRIVATE N_NIMCALL(void, rawAddSon__ast_4276)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* father, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* son, NIM_BOOL propagateHasAsgn);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, createObj__lowerings_293)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NIM_BOOL final);
N_LIB_PRIVATE N_NIMCALL(void, genTupleInfo__cgen_7180)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* origType, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getNimNode__cgen_6802)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_6805)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genTNimNodeArray__cgen_6962)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* size);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_6966)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_6971)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_6976)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7011)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7212)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7020)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7028)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7164)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genTypeInfoAux__cgen_6883)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* origType, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genTraverseProc__cgen_7697)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* origTyp, tyArray__qtqsWM5aXmcpMIVmvq3kAA sig);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7707)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7714)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7719)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genTraverseProcSeq__cgen_7491)(tyObject_TTraversalClosure__4DrvOBPCF3NL9akdOcxiJCw c, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* accessor, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(void, getTemp__cgen_7373)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* result, NIM_BOOL needsInit);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, lodeTyp__cgen_92)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNode__ast_3289)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, getSysType__magicsys_60)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7681)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, lenExpr__cgen_458)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_466)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, lenField__cgen_447)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p);
N_LIB_PRIVATE N_NIMCALL(NI, len__ropes_10)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* a);
N_LIB_PRIVATE N_NIMCALL(void, genTraverseProc__cgen_7366)(tyObject_TTraversalClosure__4DrvOBPCF3NL9akdOcxiJCw c, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* accessor, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, lengthOrd__types_1723)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(void, cgFormatValue__cgen_157)(NimStringDesc** result, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ value);
N_LIB_PRIVATE N_NIMCALL(void, addInt128__int495056_815)(NimStringDesc** result, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ value);
static N_INLINE(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, parentObj__cgen_7474)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* accessor, tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7486)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genTraverseProc__cgen_7378)(tyObject_TTraversalClosure__4DrvOBPCF3NL9akdOcxiJCw c, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* accessor, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(void, fillObjectFields__cgen_3808)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getRecordFields__cgen_3803)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* check);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genRecordFieldsAux__cgen_3665)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* rectype, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* check, NimStringDesc* unionPrefix);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, mangleRecFieldName__cgen_3649)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, mangleField__cgen_642)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_3722)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_3727)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_3740)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_3749)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_3769)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_3780)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, elemType__types_263)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_3789)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_3794)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7412)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genCaseRange__cgen_7370)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* branch);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_15427)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genLiteral__cgen_11538)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genLiteral__cgen_17776)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ty);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, intLiteral__cgen_11536)(NI64 i);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_17756)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_17728)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_17733)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_17786)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_17791)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, int64Literal__cgen_17721)(NI64 i);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, uint64Literal__cgen_17738)(NU64 i);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___systemZdollars_9)(NU64 x);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_17796)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_17819)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_17828)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genNilStringLiteral__cgen_613)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toStrMaxPrecision__cgen_17850)(NF32 f);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toStrMaxPrecision__astalgo_920)(NF f);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, copyNode__ast_4324)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_15437)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7438)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7446)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7451)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7469)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7687)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, dataField__cgen_479)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7746)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7752)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7757)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7762)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_10266)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genArrayInfo__cgen_7350)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, genSetInfo__cgen_7331)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7345)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, rope__cgen_6948)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ arg);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___int495056_53)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a);
N_LIB_PRIVATE N_NIMCALL(void, genEnumInfo__cgen_7235)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7281)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7288)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7296)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7304)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7312)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7317)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genObjectInfo__cgen_7141)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* origType, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, genObjectFields__cgen_6981)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* origType, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* expr, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, discriminatorTableName__cgen_6928)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* objtype, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, lookupInRecord__astalgo_84)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* field);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_6943)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7056)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_6957)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, plus___int495056_987)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, NI64 b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, getOrdValue__types_161)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ onError);
static N_INLINE(NIM_BOOL, isEmptyType__ast_4780)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7127)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, openArrayToTuple__cgen_9747)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(void, add__concepts_23)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* father, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* son);
N_LIB_PRIVATE N_NIMCALL(void, genDeepCopyProc__cgen_7805)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7809)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_10306)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, rawConstExpr__cgen_10399)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_17917)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genBracedInit__cgen_13891)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL isConst, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* optionalType);
N_LIB_PRIVATE N_NIMCALL(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ*, toBitSet__nimsets_103)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genRawSetData__cgen_17896)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ* cs, NI size);
N_LIB_PRIVATE N_NIMCALL(NU64, bitSetToWord__cgen_17880)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ* s, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genConstSeqV2__cgen_25366)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, NIM_BOOL isConst);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_25270)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_25476)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getSeqPayloadType__cgen_3476)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genConstSeq__cgen_25242)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, NIM_BOOL isConst);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_25251)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_25361)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_25521)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_25528)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getClosureType__cgen_6675)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyEnum_TClosureTypeKind__9cCFzcVQ9cBXhFbAj307bqVg kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_5949)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_5954)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genConstSimpleList__cgen_25198)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL isConst);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genConstTuple__cgen_25219)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL isConst, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tup);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_25616)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genConstObjConstr__cgen_25182)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL isConst);
N_LIB_PRIVATE N_NIMCALL(void, getNullValueAuxT__cgen_17707)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* orig, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* obj, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constOrNil, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** result, NI* count, NIM_BOOL isConst, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, getNullValueAux__cgen_25071)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* obj, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constOrNil, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** result, NI* count, NIM_BOOL isConst, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(NI, caseObjDefaultBranch__cgen_25027)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* obj, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ branch);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lteq___int495056_421)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___int495056_425)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getDefaultValue__cgen_24983)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___renderer_2116)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_25193)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genStringLiteralV2Const__cgen_595)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL isConst);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_602)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeIT__ast_3342)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(void, genAssignment__cgen_10403)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw dest, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw src, tySet_tyEnum_TAssignmentFlag__A5xFQCIBNzBTAeRylr7rQA flags);
N_LIB_PRIVATE N_NIMCALL(void, genGenericAsgn__cgen_18127)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw dest, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw src, tySet_tyEnum_TAssignmentFlag__A5xFQCIBNzBTAeRylr7rQA flags);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canMove__cgen_17940)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw dest);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDeepConstExpr__trees_171)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL preventInheritance);
N_LIB_PRIVATE N_NIMCALL(void, optAsgnLoc__cgen_18031)(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* field, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* Result);
N_LIB_PRIVATE N_NIMCALL(void, genOptAsgnTuple__cgen_18043)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw dest, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw src, tySet_tyEnum_TAssignmentFlag__A5xFQCIBNzBTAeRylr7rQA flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_18078)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NI, asgnComplexity__cgen_18019)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genOptAsgnObject__cgen_18093)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw dest, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw src, tySet_tyEnum_TAssignmentFlag__A5xFQCIBNzBTAeRylr7rQA flags, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
static N_INLINE(NIM_BOOL, reifiedOpenArray__cgen_11825)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genOpenArrayConv__cgen_18205)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw d, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, dataFieldAccessor__cgen_471)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* sym);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, byRefLoc__cgen_10353)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isException__types_4064)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(void, fillResult__cgen_1795)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* param, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* proctype);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_1799)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, assignParam__cgen_11482)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* retType);
N_LIB_PRIVATE N_NIMCALL(void, scopeMangledParam__cgen_1137)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* param);
N_LIB_PRIVATE N_NIMCALL(tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA, allPathsAsgnResult__cgen_26066)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, resetLoc__cgen_10897)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* loc);
N_LIB_PRIVATE N_NIMCALL(void, specializeReset__cgen_10894)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a);
N_LIB_PRIVATE N_NIMCALL(void, specializeResetT__cgen_10605)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* accessor, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(void, specializeResetN__cgen_10609)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* accessor, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(void, closureSetup__cgen_25935)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc);
N_LIB_PRIVATE N_NIMCALL(void, genProcBody__cgen_26219)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* procBody);
static N_INLINE(NIM_BOOL, isNoReturn__cgen_26271)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, initFrame__cgen_17621)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* procname, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* filename);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, quotedFilename__msgs_1473)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw i);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_26473)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, deinitFrame__cgen_17691)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_26482)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_26487)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getProcTypeCast__cgen_26203)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_26214)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__astalgo_3489)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_23990)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genVarPrototype__cgen_11516)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, treatGlobalDifferentlyForHCR__cgen_11316)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, declareThreadVar__cgen_11215)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NIM_BOOL isExtern);
static N_INLINE(NIM_BOOL, emulatedThreadVars__cgen_419)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_11265)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, incl__pureZcollectionsZintsets_55)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
static N_INLINE(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**, procSec__cgendata_274)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_24539)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newSymNode__ast_3704)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(void, addActualSuffixForHCR__cgen_12394)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** res, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(void, excl__reorder_273)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
static N_INLINE(void, popSafePoint)(void);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__cgen_4171)(tyObject_HashSet__KYwZ0vHsYO0DQEC4qpQkAQ* s, tyArray__qtqsWM5aXmcpMIVmvq3kAA key);
N_LIB_PRIVATE N_NIMCALL(void, addAbiCheck__cgen_1779)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name);
N_LIB_PRIVATE N_NIMCALL(void, addTypeHeader__types_216)(NimStringDesc** result, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg prefer, NIM_BOOL getDeclarationPath);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__pureZos_449)(NimStringDesc** s, NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_1790)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getOpenArrayDesc__cgen_4046)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* check, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_4110)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_5873)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_5878)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_5883)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_5892)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_6177)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NI64, toInt64__int495056_88)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_6231)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, scanCppGenericSlot__cgen_3986)(NimStringDesc* pat, NI* cursor, NI* outIdx, NI* outStars);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__system_7755)(NimStringDesc* s, NI first, NI last);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, resolveStarsInCppType__cgen_4015)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, NI idx, NI stars);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderTree__renderer_46)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA renderFlags);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__system_7767)(NimStringDesc* s, NI first);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getRecordDesc__cgen_3814)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* check);
static N_INLINE(NIM_BOOL, lacksMTypeField__types_4204)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_3933)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_3943)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_6322)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_6328)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getTupleDesc__cgen_3956)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* check);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_3962)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_3977)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_6621)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_6626)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, nimLeaveFinally)(void);
N_LIB_PRIVATE N_NIMCALL(void, reraiseException)(void);
static N_INLINE(NIM_BOOL, requiresExternC__cgen_26492)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(void, putLocIntoDest__cgen_11532)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw s);
N_LIB_PRIVATE N_NIMCALL(void, genericAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isSimpleConst__cgen_95)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(void, putIntoDest__cgen_18794)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r, tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ s);
N_LIB_PRIVATE N_NIMCALL(void, genConstHeader__cgen_24515)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* q, tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, genConstSetup__cgen_24498)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_24534)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_24544)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genComplexConst__cgen_24238)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, requestConstImpl__cgen_11519)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(void, genConstDefinition__cgen_24558)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* q, tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_24563)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_24572)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genSingleVar__cgen_13925)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* v, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* vn, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* value);
N_LIB_PRIVATE N_NIMCALL(void, genGotoVar__cgen_13879)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* value);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_13886)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, potentialValueInit__cgen_13896)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* v, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* value);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hcrOn__cgen_46)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p);
N_LIB_PRIVATE N_NIMCALL(void, assignGlobalVar__cgen_11336)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* value);
N_LIB_PRIVATE N_NIMCALL(void, varInDynamicLib__cgen_11313)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_25882)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_11465)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getTraverseProc__cgen_13183)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* v);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genTraverseProcForGlobal__cgen_7776)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, accessThreadLocalVar__cgen_416)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_11197)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7788)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7794)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_7800)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, registerTraverseProc__cgen_13195)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* v, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* traverseProc);
static N_INLINE(NIM_BOOL, isAssignedImmediately__cgen_13245)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsHiddenPointer__types_658)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(void, genLineDir__cgen_369)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_377)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, sourceLine__msgs_1111)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw i);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, freshLineInfo__cgen_365)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genOtherArg__cgen_11541)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri, NI i, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genArgNoParam__cgen_12216)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL needsTmp);
static N_INLINE(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genArgStringToCString__cgen_12133)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL needsTmp);
N_LIB_PRIVATE N_NIMCALL(void, withTmpIfNeeded__cgen_12116)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a, NIM_BOOL needsTmp, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_14050)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_14055)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_14060)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_13448)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
static N_INLINE(void, loadInto__cgen_13528)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* le, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* a);
N_LIB_PRIVATE N_NIMCALL(void, genAsgnCall__cgen_13147)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* le, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInactiveDestructorCall__cgen_13133)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e);
static N_INLINE(NIM_BOOL, notYetAlive__cgen_13121)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getRoot__trees_390)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, skipAddr__ast_5230)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genClosureCall__cgen_12459)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* le, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genParams__cgen_12297)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(tySequence__shxop0zPIs5Ec3k71aCLuQ*, newSeq__cgen_12306)(NI len);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, skipTrivialIndirections__cgen_12243)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, potentialAlias__cgen_12227)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySequence__IeU9azYSNIK3V9b36Ir6NZcw* potentialWrites);
N_LIB_PRIVATE N_NIMCALL(tyEnum_AliasKind__vyyqF5f609aD8pvRKZixr4w, aliases__dfa_808)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* obj, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* field);
N_LIB_PRIVATE N_NIMCALL(void, getPotentialReads__cgen_12289)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySequence__IeU9azYSNIK3V9b36Ir6NZcw** result);
N_LIB_PRIVATE N_NIMCALL(void, getPotentialWrites__cgen_12248)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL mutate, tySequence__IeU9azYSNIK3V9b36Ir6NZcw** result);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag, getMagic__trees_137)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* op);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genArg__cgen_12149)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* param, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* call, NIM_BOOL needsTmp);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, openArrayLoc__cgen_11967)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formalType, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, skipConv__types_3661)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genOpenArraySlice__cgen_11842)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* q, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formalType, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* destType, NIM_BOOL prepareForMutation, tyTuple__xIPPgKI3s9a9c79aFyHPbe0cg* Result);
N_LIB_PRIVATE N_NIMCALL(void, genBoundsCheck__cgen_11820)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw arr, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, raiseInstr__cgen_424)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, intLiteral__cgen_17773)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ i);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, rdCharLoc__cgen_10377)(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_10384)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, lastOrd__types_1532)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_11878)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_11885)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_11890)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_11896)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_11901)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_11948)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_11953)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_12024)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_12029)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_12034)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_12082)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_12087)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_12092)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, literalsNeedsTmp__cgen_12129)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* Result);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canRaiseDisp__cgen_11588)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canRaise__ast_5100)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* fn);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canRaiseConservative__ast_5088)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* fn);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, preventNrvo__cgen_11616)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* dest, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* le, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA, isPartOf__aliases_129)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, locationEscapes__cgen_11622)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* le, NIM_BOOL inTryStmt);
static N_INLINE(NIM_BOOL, hasNoInit__cgen_11683)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* call);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_12535)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, addComma__cgen_12464)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_12540)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, raiseExit__cgen_11546)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p);
static N_INLINE(tyTuple__T1RBf8m9axj9bvJRlYejkpkQ*, X5BX5D___cgen_14870)(tyTuple__T1RBf8m9axj9bvJRlYejkpkQ* s, NI sLen_0, NI i);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isHarmlessStore__cgen_11696)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, NIM_BOOL canRaise, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_12576)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_12581)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genInfixCall__cgen_12851)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* le, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__pureZstrutils_1631)(NimStringDesc* s, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genPatternCall__cgen_12746)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri, NimStringDesc* pat, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_11723)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_11768)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genThisArg__cgen_12678)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri, NI i, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, skipAddrDeref__cgen_12656)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* node);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_12919)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, fixupCall__cgen_11710)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* le, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* callee, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* params);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_11757)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, getTempCpp__cgen_11082)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* result, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* value);
N_LIB_PRIVATE N_NIMCALL(void, genNamedParamCall__cgen_12954)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_12960)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
static N_INLINE(NIM_BOOL, contains__pureZos_651)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item);
static N_INLINE(NI, find__pureZos_656)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_12998)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_13083)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_13088)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_13099)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genPrefixCall__cgen_12426)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* le, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, astdef__ast_3462)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, putDataIntoDest__cgen_18780)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r);
N_LIB_PRIVATE N_NIMCALL(void, genMagicExpr__cgen_23524)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag op);
N_LIB_PRIVATE N_NIMCALL(void, genAndOr__cgen_20420)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getLabel__cgen_11501)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_20436)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_20441)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, fixLabel__cgen_11508)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* labl);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_11511)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, unaryArith__cgen_19396)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag op);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19414)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19419)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19424)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19092)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, unaryArithOverflow__cgen_19054)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19087)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19097)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, binaryFloatArith__cgen_23223)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag m);
N_LIB_PRIVATE N_NIMCALL(void, binaryArith__cgen_19108)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag op);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19137)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19142)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19147)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19152)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19157)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19162)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19167)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19172)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19177)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19182)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19187)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19192)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19197)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19202)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19207)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19212)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19217)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19222)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19227)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19232)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19249)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19254)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19271)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19276)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19281)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19310)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genEqProc__cgen_19321)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19349)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, binaryArithOverflow__cgen_18902)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_18935)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19026)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genRepr__cgen_21666)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, gcUsage__cgen_20553)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genGetTypeInfo__cgen_21838)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genGetTypeInfoV2__cgen_21844)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isFinal__types_808)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, rdMType__cgen_21782)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** nilCheck, NIM_BOOL enforceV1);
N_LIB_PRIVATE N_NIMCALL(void, genSwap__cgen_22180)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, cowBracket__cgen_19616)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, binaryStmt__cgen_18809)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, NimStringDesc* op);
N_LIB_PRIVATE N_NIMCALL(void, genStrConcat__cgen_20568)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, strLoc__cgen_20560)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw d);
N_LIB_PRIVATE N_NIMCALL(void, binaryStmtAddr__cgen_18835)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, NimStringDesc* cpname);
N_LIB_PRIVATE N_NIMCALL(void, genStrAppend__cgen_20648)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, makeAddr__cgen_22088)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newTree__ast_3356)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** children, NI childrenLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, makePtrType__cgen_22084)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* baseType, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(void, addSonSkipIntLit__magicsys_136)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* father, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* son, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* id);
N_LIB_PRIVATE N_NIMCALL(void, genCall__cgen_13177)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genSeqElemAppend__cgen_20746)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, getIntTemp__cgen_11104)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* result);
N_LIB_PRIVATE N_NIMCALL(void, genStrEquals__cgen_23155)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genIsNil__cgen_19358)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genEnumToStr__cgen_23511)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getToStringProc__modulegraphs_5686)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, copyTree__ast_4432)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* src);
N_LIB_PRIVATE N_NIMCALL(void, genOf__cgen_21660)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genOf__cgen_21569)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_21632)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genOfHelper__cgen_21502)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* dest, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* a, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_21518)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_21545)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_21555)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genNew__cgen_20982)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e);
N_LIB_PRIVATE N_NIMCALL(void, rawGenNew__cgen_20825)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* a, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* sizeExpr, NIM_BOOL needsInit);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_20848)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_20890)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genNewFinalize__cgen_21471)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genTypeInfo__cgen_10314)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, genNewSeq__cgen_21086)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e);
N_LIB_PRIVATE N_NIMCALL(void, genNewSeqAux__cgen_20992)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw dest, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* length, NIM_BOOL lenIsZero);
N_LIB_PRIVATE N_NIMCALL(void, genNewSeqOfCap__cgen_21125)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_23873)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_23880)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_23909)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genSomeCast__cgen_22901)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_22923)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_22940)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_22953)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_22966)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_22979)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genOrd__cgen_22885)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genArrayLen__cgen_21867)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag op);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_22050)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genSetLengthStr__cgen_22154)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genSetLengthSeq__cgen_22096)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genSetOp__cgen_22352)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag op);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_22377)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, rdSetElemLoc__cgen_17717)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___int495056_952)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, NI64 b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_22205)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_22395)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_22413)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_22431)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_22452)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_22470)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_22488)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_22506)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genInOp__cgen_22275)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, fewCmps__cgen_22210)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_22320)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_22325)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genInExprAux__cgen_19824)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* a, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* b, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_22243)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_22248)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_22253)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_22258)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_22263)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_22737)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_22755)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_22862)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genDefault__cgen_20817)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genReset__cgen_20812)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genEcho__cgen_20455)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genArrToSeq__cgen_21365)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genSeqConstr__cgen_21290)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lhsDoesAlias__cgen_21281)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, wrapProcForSpawn__spawn_510)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* spawnExpr, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* retType, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* barrier, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* dest);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, liftParallel__semparallel_855)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genDeepCopy__cgen_18636)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw dest, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw src);
N_LIB_PRIVATE N_NIMCALL(void, genWasMoved__cgen_23328)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, skipAddr__cgen_23320)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genMove__cgen_23334)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genDestroy__cgen_23376)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genAccessTypeField__cgen_21854)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genSlice__cgen_23471)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genSetNode__cgen_17906)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genSetConstr__cgen_24052)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_24090)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_24095)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___systemZdollars_6)(NI64 x);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_24101)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_24116)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_24121)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, exprComplexConst__cgen_24475)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genArrayConstr__cgen_24216)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, handleConstExpr__cgen_21182)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genClosure__cgen_24173)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
static N_INLINE(NIM_BOOL, isConstClosure__cgen_24159)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NIM_BOOL, isRoutine__ast_4677)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, genTupleConstr__cgen_24126)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_13428)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genObjConstr__cgen_10395)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, lookupFieldAgain__cgen_19728)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ty, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** r, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA** resTyp);
N_LIB_PRIVATE N_NIMCALL(void, genFieldCheck__cgen_19830)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* obj, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field);
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_629)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toMsgFilename__msgs_612)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, genFieldDefect__astmsgs_61)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* field, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* disc);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___cgen_19915)(tyTuple__47w2DboNEPf69aPgubZdd7Q x, tyTuple__47w2DboNEPf69aPgubZdd7Q y);
N_LIB_PRIVATE N_NIMCALL(tyTuple__47w2DboNEPf69aPgubZdd7Q, getStdlibVersion__options_3920)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, genCast__cgen_22997)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_23019)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_23039)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genConv__cgen_23118)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameBackendType__types_689)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* x, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* y);
N_LIB_PRIVATE N_NIMCALL(void, genAddr__cgen_19655)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
static N_INLINE(NIM_BOOL, isCppRef__cgen_19443)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(void, genBracketExpr__cgen_20370)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genUncheckedArrayElem__cgen_20050)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* y, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genArrayElem__cgen_20071)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* y, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isConstExpr__trees_146)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lteq___int495056_945)(NI64 a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___int495056_417)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b);
N_LIB_PRIVATE N_NIMCALL(void, genOpenArrayElem__cgen_20218)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* y, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genSeqElem__cgen_20286)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* y, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genCStringElem__cgen_20138)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* y, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genTupleElem__cgen_19697)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19723)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genDeref__cgen_19488)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, derefBlock__cgen_19463)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, shallowCopy__ast_4414)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newTreeIT__ast_3395)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** children, NI childrenLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genRecordField__cgen_19775)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genRecordFieldAux__cgen_19682)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* a);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_19810)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genCheckedRecordField__cgen_20003)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genBlock__cgen_14665)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genStmtListExpr__cgen_24255)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, initFrameNoDebug__cgen_17649)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* frame, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* procname, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* filename, NI line);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_17656)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, deinitFrameNoDebug__cgen_17674)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* frame);
N_LIB_PRIVATE N_NIMCALL(void, genStmtList__cgen_24309)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genIf__cgen_14186)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_14226)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_14244)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, downConv__cgen_24429)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isLValue__parampatterns_497)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_24416)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NI, inheritanceDiff__types_2737)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* b);
N_LIB_PRIVATE N_NIMCALL(void, upConv__cgen_24363)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genRangeChck__cgen_23044)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, convStrToCStr__cgen_23125)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, convCStrToStr__cgen_23140)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genWhileStmt__cgen_14588)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, stmtsContainPragma__ccgutils_42)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw w);
N_LIB_PRIVATE N_NIMCALL(void, genComputedGoto__cgen_14416)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, flattenStmts__trees_355)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, enumHasHoles__types_287)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___int495056_931)(NI64 a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_14452)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_14458)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_14469)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_14474)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_14489)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_14532)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, transitionSonsKind__ast_4347)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyEnum_TNodeKind__jsmc0lvQl44MLrOvpRmgJQ kind);
static N_INLINE(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, assignLabel__cgen_13551)(tyObject_TBlock__FHXN9cI0ri9bj2d9cKw8iPHZg* b);
N_LIB_PRIVATE N_NIMCALL(void, genVarStmt__cgen_14166)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genSingleVar__cgen_14124)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a);
N_LIB_PRIVATE N_NIMCALL(void, genClosureVar__cgen_14147)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a);
N_LIB_PRIVATE N_NIMCALL(void, genVarTuple__cgen_13331)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, lowerTupleUnpacking__lowerings_116)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__Vz8km29c8JcWq5WOBlnn2aQ)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, genConstStmt__cgen_24590)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genCase__cgen_15603)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genStringCase__cgen_15168)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(NI, nextPowerOfTwo__pureZmath_177)(NI x);
N_LIB_PRIVATE N_NIMCALL(void, genCaseStringBranch__cgen_15118)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw e, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* labl, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** branches, NI branchesLen_0);
N_LIB_PRIVATE N_NIMCALL(NI64, hashString__ccgutils_50)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_15246)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_15264)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genCaseSecondPass__cgen_15059)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, NI labId, NI until);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_15076)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, exprBlock__cgen_13615)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genGotoForCase__cgen_14333)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* caseStmt);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_14374)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genOrdinalCase__cgen_15451)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(NI, ifSwitchSplitPoint__cgen_15377)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, branchHasTooBigRange__cgen_15367)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_13803)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_15590)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genReturnStmt__cgen_14269)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t);
N_LIB_PRIVATE N_NIMCALL(void, blockLeaveActions__cgen_13683)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, NI howManyTrys, NI howManyExcepts);
N_LIB_PRIVATE N_NIMCALL(tySequence__IjAwukZ9aSEsol9c48He4FYQ*, newSeq__cgen_13694)(NI len);
static N_INLINE(void, pop__cgen_13721)(tySequence__IjAwukZ9aSEsol9c48He4FYQ** s, tyTuple__T1RBf8m9axj9bvJRlYejkpkQ* Result);
static N_INLINE(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**, X5BX5D___cgen_14296)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** s, NI sLen_0, NI i);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_14319)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genBreakStmt__cgen_14784)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t);
static N_INLINE(void, cow__cgen_19647)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genAsgn__cgen_17560)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, NIM_BOOL fastAsgn);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDiscriminantField__astalgo_4328)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, asgnFieldDiscriminant__cgen_17539)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e);
N_LIB_PRIVATE N_NIMCALL(void, genDiscriminantCheck__cgen_17425)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tmp, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* objtype, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, discriminatorTableDecl__cgen_6951)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* objtype, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* d);
N_LIB_PRIVATE N_NIMCALL(void, genAsmStmt__cgen_17370)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genAsmOrEmitStmt__cgen_17326)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t, NIM_BOOL isAsmStmt);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuReplaceStr)(NimStringDesc* s, NimStringDesc* sub, NimStringDesc* by);
N_LIB_PRIVATE N_NIMCALL(void, genTryGoto__cgen_16490)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_16614)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, bodyCanRaise__cgen_16470)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genTryCpp__cgen_15773)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genRestoreFrameAfterException__cgen_15720)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_15909)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInfixAs__ast_4936)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isImportedException__ast_4905)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, genTrySetjmp__cgen_16834)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(void, genRaiseStmt__cgen_14965)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t);
N_LIB_PRIVATE N_NIMCALL(void, finallyActions__cgen_14901)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p);
static N_INLINE(void, genSimpleBlock__cgen_13599)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* stmts);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_14983)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_15026)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genTypeSection__cgen_10311)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genPragma__cgen_17418)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw, whichPragma__trees_244)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genEmit__cgen_17407)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw, determineSection__cgen_17385)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuStartsWith)(NimStringDesc* s, NimStringDesc* prefix);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, skipGenericOwner__ast_4659)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, genParForStmt__cgen_14708)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_14747)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_14753)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_14761)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genState__cgen_13635)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genGotoState__cgen_13798)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_13812)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_13820)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_13847)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genBreakState__cgen_13856)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_13868)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_13874)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, popInfoContext__msgs_517)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, finalCodegenActions__cgen_28755)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_4798)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* son);
static N_INLINE(NIM_BOOL, moduleHasChanged__passes_209)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, generateMethodDispatchers__cgmeth_547)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(void, genForwardedProcs__cgen_28835)(tyObject_BModuleListcolonObjectType___9c4b0IbdzIJRabh100GyFtA* g);
static N_INLINE(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, pop__icZic_2462)(tySequence__ed0C0uAUZPhvw3RAc5hfYg** s);
N_LIB_PRIVATE N_NIMCALL(void, writeModule__cgen_28728)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, NIM_BOOL pending);
N_LIB_PRIVATE N_NIMCALL(void, genInitCode__cgen_28147)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getInitName__cgen_27174)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getSomeInitName__cgen_27170)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, NimStringDesc* suffix);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getSomeNameForModule__cgen_27153)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_28082)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_28200)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_28209)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_28214)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_28219)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_28253)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_28093)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_28304)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getHcrInitName__cgen_27184)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, hcrGetProcLoadCode__cgen_27187)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, NimStringDesc* sym, NimStringDesc* prefix, NimStringDesc* handle, NimStringDesc* getProcFunc);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_28137)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_28142)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_28429)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genDatInitCode__cgen_28079)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getDatInitName__cgen_27181)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_28439)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, registerModuleToMain__cgen_27580)(tyObject_BModuleListcolonObjectType___9c4b0IbdzIJRabh100GyFtA* g, tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_27585)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_27597)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
static N_INLINE(NI, rawGet__cgen_27608)(tyObject_Table__imojfg883tkWsWJwyshGqQ t, NI32 key, NI* hc);
static N_INLINE(NI, hash__ast_784)(NI32 x);
static N_INLINE(NI, hashWangYi1__pureZhashes_136)(NU64 x);
static N_INLINE(NU64, hiXorLo__pureZhashes_79)(NU64 a, NU64 b);
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_31)(NI hcode);
static N_INLINE(NI, nextTry__pureZcollectionsZtables_34)(NI h, NI maxHash);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_27929)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_27934)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_27939)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, sigHash__sighashes_535)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyArray__qtqsWM5aXmcpMIVmvq3kAA Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_27948)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_27953)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_27962)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_27967)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_27522)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_27976)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_27981)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_27986)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_27991)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_28001)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_28006)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_27517)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, finishTypeDescriptions__cgen_6711)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m);
N_LIB_PRIVATE N_NIMCALL(void, seqV2ContentType__cgen_3481)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* check);
N_LIB_PRIVATE N_NIMCALL(void, genMainProc__cgen_27193)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m);
static N_NIMCALL(void, Marker_tyRef__9bbPrOZAgwWihvYGa8yXUow)(void* p, NI op);
N_LIB_PRIVATE N_CLOSURE(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, loadLib__cgen_27196)(NimStringDesc* handle, NimStringDesc* name, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_27218)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, closeNamespaceNim__cgen_25933)(void);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, openNamespaceNim__cgen_25930)(NimStringDesc* namespace_0);
N_LIB_PRIVATE N_NIMCALL(void, generateThreadVarsSize__cgen_11293)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_11308)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toObjFile__extccomp_720)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genModule__cgen_28457)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw* cfile);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getFileHeader__cgen_27145)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw* cfile);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getCopyright__cgen_27132)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw* cfile);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, headerTop__cgen_27125)(void);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_27127)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_27140)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getCompileCFileCmd__extccomp_997)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw* cfile, NIM_BOOL isMainFile, NIM_BOOL produceOutput);
static N_INLINE(void, addNimDefines__cgen_27117)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** result, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_27120)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, generateThreadLocalStorage__cgen_11270)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_11288)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, generateHeaders__cgen_25910)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuReplaceChar)(NimStringDesc* s, NIM_CHAR sub, NIM_CHAR by);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_25920)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_25925)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, shouldRecompile__cgen_28719)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* code, tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw* cfile);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, equalsFile__ropes_453)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, writeRope__ropes_241)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* head, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosfileExists)(NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosfileNewer)(NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(void, addFileToCompile__extccomp_724)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw* cf);
N_LIB_PRIVATE N_NIMCALL(void, close__ndi_31)(tyObject_NdiFile__ZdQ0n9cikYC2TzROZ1EnTOA* f, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, writeMapping__extccomp_2663)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* symbolMapping);
N_LIB_PRIVATE N_NIMCALL(void, writeHeader__cgen_28613)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_28616)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_28622)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_28641)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___cgen_28646)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getSomeNameForModule__cgen_27149)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename);
extern TNimType NTIbmodule__AeJVysvbewqqb9ao16aCkYA_;
extern TNimType NTItcgen__LLLbwetkArja9aBhGlHYtvA_;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_2, "TM", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3, "_", 1);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_4, "ndi", 3);
extern TNimType NTIseqLbmoduleT__ukLNp6qJ4FndCViFTz0FGg_;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_5, ".h", 2);
extern TNimType NTIseqLtblockT__Y9a9bBybAqzjKkPsvOIQEzpw_;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_6, "\011", 1);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_7, "if (nim_hcr_do_init_)\012", 22);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8, "{", 1);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9, "\012", 1);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_10, "__", 2);
extern TNimType NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_11, "static", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_12, "extern", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_13, " ", 1);
extern TNimType NTIseqLropeT__UQWyowqEA29c6NZ9csQYyjXQ_;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_14 = {
0x10, 0x2e, 0x10, 0x00, 0x00, 0x40, 0x80, 0x10,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_15 = {
0x10, 0x2e, 0x10, 0x00, 0x00, 0x60, 0x80, 0x10,
0x00}
;
extern NIM_CONST tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw unknownLineInfo__lineinfos_284;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_16, "cannot generate C type for: ", 28);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_18, "/home/runner/work/nightlies/nightlies/nim/compiler/ccgtypes.nim", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_17 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_18),
((NI) 693),
((NI) 19)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_20, "void", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_21, "void*", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_22, "nimStrVersion", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_24, "/home/runner/work/nightlies/nightlies/nim/compiler/cgen.nim", 59);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_23 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_24),
((NI) 719),
((NI) 16)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_25, "||", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26, "(", 1);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27, " = ", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_28, "nimLoadLibrary", 14);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_29, "((", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_30, "NimStringDesc", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_31, "*) NIM_NIL)", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_32, "*) &", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_33, "TGenericSeq", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34, ")", 1);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_35, "const", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_36, "NimStrPayload", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_37, "NimStringV2", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_38, "cannot determine how to produce code for string literal", 55);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_40, "/home/runner/work/nightlies/nightlies/nim/compiler/ccgliterals.nim", 66);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_39 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_40),
((NI) 113),
((NI) 14)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_41, "))", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_42, "if (!(", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_43, ")) ", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_44, "nimLoadLibraryError", 19);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45, ");", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46, ";", 1);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_47, "))) ", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_48, "loadDynamicLib", 14);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_49 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_24),
((NI) 749),
((NI) 35)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_50, "Dl_$1_", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51, ", ", 2);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_52 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_24),
((NI) 782),
((NI) 18)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_53, "wrong index: ", 13);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_54 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_24),
((NI) 789),
((NI) 19)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_55, " = (", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_56, ") ", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_57, "nimGetProcAddr", 14);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_58, ".nim.cpp", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_59, ".nim.m", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_60, ".nim.c", 6);
extern NIM_CONST tyArray__zAjcTh151RgaydpulQUcEQ OS__platform_518;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_61, "/", 1);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_62, "N_LIB_IMPORT ", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_63, "N_LIB_EXPORT ", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_64, "static ", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_65, "N_LIB_PRIVATE ", 14);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_66, "ccgtypes.nim(163, 14) `typ.isResolvedUserTypeClass` ", 52);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_67 = {
0x10, 0xa9, 0x00, 0x00, 0x00, 0x60, 0x90, 0x00,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_68, "ccgtypes.nim(196, 19) `false` mapType: ", 39);
extern TNimType NTIttypekind__b28l2MkhJpnFhatVrsrXpg_;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_69, "ccgtypes.nim(197, 17) `false` mapType: ", 39);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_70, "genProcParams", 13);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_71 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_18),
((NI) 440),
((NI) 42)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_72, "_0", 2);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_73 = {
0x00, 0x01, 0x80, 0x00, 0x00, 0x80, 0x00, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74 = {
0x10, 0xa9, 0x00, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_75, "getTypeName: ", 13);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_76 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_18),
((NI) 139),
((NI) 33)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_77, "union", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_78, "struct", 6);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_79 = {
0x10, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00,
0x00}
;
extern TNimType NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_80, "ccgtypes.nim(361, 14) `m.forwTypeCache[sig] == result` ", 55);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_81, "getTypeForward(", 15);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_82 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_18),
((NI) 362),
((NI) 21)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_83, "cannot map the empty seq type to a C type", 41);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_84 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_18),
((NI) 380),
((NI) 21)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_85, "struct", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_86, "_Content", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_87, "struct ", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_88, " {\012  NI len; ", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_89, "_Content* p;\012};\012", 16);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_90, "*", 1);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_91 = {
0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_92 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_93, "void* ClE_0", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_94, "...", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_95, "void)", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_96, "_PTR", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_97, "_actual", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_98, "N_NIMCALL", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_99, "N_STDCALL", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_100, "N_CDECL", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_101, "N_SAFECALL", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_102, "N_SYSCALL", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_103, "N_INLINE", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_104, "N_NOINLINE", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_105, "N_FASTCALL", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_106, "N_THISCALL", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_107, "N_CLOSURE", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_108, "N_NOCONV", 8);
N_LIB_PRIVATE NIM_CONST tyArray__J4GSVrMkyDLER4Hu9cFBPhg CallingConvToStr__cgen_1379 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_98),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_99),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_100),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_101),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_102),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_103),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_104),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_105),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_106),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_107),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_108)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_109, "(*", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_110, "proc has no result symbol", 25);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_111 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_24),
((NI) 1049),
((NI) 19)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_112, " register", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_113, " volatile", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_114, " NIM_NOALIAS", 12);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_115 = {
0x10, 0xa9, 0x00, 0x00, 0x00, 0x60, 0x80, 0x10,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_116, ".len = 0; ", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_117, ".p = NIM_NIL;", 13);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_118 = {
0x10, 0xa9, 0x00, 0x00, 0x00, 0x60, 0xb0, 0x00,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_119, "NIM_NIL", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_120, "asgnRef", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_121, "((void**) ", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_122, "(&", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_123, "unsureAsgnRef", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_124, ")0;", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_125, "nimZeroMem", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_126, "((void*)", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_127, ", sizeof(", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_128, "));", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_129, ".Sup", 4);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_130 = {
0x10, 0x09, 0xe0, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_131, ".m_type = ", 10);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_132 = {
0x10, 0x0e, 0x10, 0x00, 0x00, 0x60, 0xb0, 0x10,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_133, "TNimTypeV2", 10);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_134 = {
0x10, 0xa9, 0xe0, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_135, "request for RTTI generation for incomplete object: ", 51);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_136 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_18),
((NI) 1330),
((NI) 16)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_137, "|", 1);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_138, ".", 1);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_139, " needs to have the \'nimcall\' calling convention", 47);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_140 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_18),
((NI) 1308),
((NI) 16)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_141 = {
0x10, 0x2e, 0x10, 0x00, 0x00, 0x60, 0xb0, 0x10,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_142, "TNimType", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_143, "TNimNode", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_144, "0", 1);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_145, "void*", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_146, "nimTypeNames", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_147, "ref object", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_148, "anon ref object from ", 21);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_149, "nimTypeRoot", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_150, "genTypeInfoV1(", 14);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_151 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_18),
((NI) 1474),
((NI) 23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_152 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_18),
((NI) 1476),
((NI) 19)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_153, "0", 1);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_154, "Marker_", 7);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_155 = {
0x10, 0xa9, 0x00, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_156, "op", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_157, "T", 1);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_158, ".len", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_159, "len", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_160, "Sup.len", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_161, "for (", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_162, " = 0; ", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_163, " < ", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_164, "; ", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_165, "++) {", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_166, "[", 1);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_167, "]", 1);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_168, "genTraverseProc", 15);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_170, "/home/runner/work/nightlies/nightlies/nim/compiler/ccgtrav.nim", 62);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_169 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_170),
((NI) 34),
((NI) 42)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_171, "genRecordFieldsAux", 18);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_172 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_18),
((NI) 510),
((NI) 40)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_173, "mangleRecFieldName", 18);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_174 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_18),
((NI) 499),
((NI) 33)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_175, "struct {", 8);
extern NIM_CONST tyArray__BZ5uScSUO7j9awRS7LrncpQ CC__extccomp_510;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_176, "struct __attribute__((__packed__)){", 35);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_177, "genRecordFieldsAux(record case branch)", 38);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_178 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_18),
((NI) 536),
((NI) 25)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_179, "genRecordFieldsAux()", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_180 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_18),
((NI) 566),
((NI) 21)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_181, "genTraverseProc()", 17);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_182 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_170),
((NI) 39),
((NI) 19)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_183 = {
0x10, 0xa9, 0x90, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_184, "ULL", 3);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_185 = {
0x10, 0xa9, 0x90, 0x00, 0x00, 0x60, 0xb0, 0x10,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_186, "genLiteral(", 11);
extern TNimType NTItnodekind__clSgDh22o9au33BrVH9bDQZw_;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188, "/home/runner/work/nightlies/nightlies/nim/compiler/ccgexprs.nim", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_187 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 106),
((NI) 17)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_189 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_170),
((NI) 56),
((NI) 19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_190 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_170),
((NI) 58),
((NI) 21)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_191, ".Field", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_192, "nimGCvisit", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_193, "nimGCvisitSeq", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_194, ".ClE_0", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_195, ".p->data", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_196, "->data", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_197, "a", 1);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_198, "(*a)", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_199, ", \012", 3);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_200 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_18),
((NI) 1163),
((NI) 16)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_201 = {
0x10, 0xa9, 0xe0, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_202, "anonymous obj with discriminator", 32);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_203 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_18),
((NI) 1072),
((NI) 17)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_204, "genObjectFields", 15);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_205 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_18),
((NI) 1115),
((NI) 19)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_206, "genObjectFields; nkOfBranch broken", 34);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_207 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_18),
((NI) 1131),
((NI) 23)}
;
extern NIM_CONST tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ Max__int495056_27;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_208, "genObjectFields(nkRecCase)", 26);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_209 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_18),
((NI) 1145),
((NI) 25)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_210 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_18),
((NI) 1153),
((NI) 21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_211 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_18),
((NI) 1158),
((NI) 21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_212 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_18),
((NI) 1509),
((NI) 21)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_213 = {
0x10, 0xa9, 0x40, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_214, "node has no type", 16);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_215 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 3235),
((NI) 21)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_216, "{\012", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_217, "0x", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_218, "0123456789abcdef", 16);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_219, ",\012", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_220, "}\012", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_221, "{", 1);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222, "}", 1);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_223, " struct {", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_224, "  NI cap; ", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_225, " data[", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_226, "];", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_227, "} ", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_228, " = {", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_229, " | NIM_STRLIT_FLAG, ", 20);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_230, "};", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_231, ", {", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_232, "NIM_CONST", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_233, "  ", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_234, " Sup;", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_235, "const openArray expression is not an array construction", 55);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_236 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 3275),
((NI) 21)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_237, "] = ", 4);
extern NIM_CONST tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ Zero__int495056_7;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_238, "._", 2);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_239 = {
0x10, 0xa8, 0x10, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_240, "NIM_FALSE", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_241, "0.0", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_242, "NIM_NIL", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_243, "{0, NIM_NIL}", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_244, "{NIM_NIL, NIM_NIL}", 18);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_245, "{NIM_NIL, 0}", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_246, "{}", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_247, "cannot create null element for: ", 32);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_248 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 3060),
((NI) 15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_249 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 3130),
((NI) 14)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_250, "nimCopyMem", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_251, ", (NIM_CONST void*)&", 20);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_252 = {
0x10, 0xa9, 0x10, 0x00, 0x00, 0x60, 0xb0, 0x10,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_253, ", (NIM_CONST void*)", 19);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_254, "genericShallowAssign", 20);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_255, ", (void*)", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_256, "genericAssign", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_257, "genericSeqAssign", 16);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_258, "copyString", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_259, "copyStringRC1", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260, "if (", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_261, "nimGCunrefNoCycle", 17);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_262, "ClE_0", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_263, ".ClP_0 = ", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_264, ".ClP_0;", 7);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_265 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 372),
((NI) 23)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_266 = {
0x10, 0xa9, 0x80, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_267, ".Field0 = ", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_268, ".Field0; ", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_269, ".Field1 = ", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_270, ".Field1;", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_271, "Len_0;", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_272, ".Field0 = (", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_273, ").p", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_274, ") \? (", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_275, ") : NIM_NIL; ", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_276, "nimPrepareStrMutationV2", 23);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_277, "cannot handle ", 14);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_278 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 308),
((NI) 17)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_279, "genericAssignOpenArray", 22);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_280, "Len_0, ", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_281, "genAssignment: ", 15);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_282 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 410),
((NI) 21)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_283, "memTrackerWrite", 15);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_284, "objectInit", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_285, ".name = ", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_286, "\011return ", 8);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_287 = {
0x10, 0xa8, 0x90, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_288, "->len = 0; ", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_289, "->p = NIM_NIL;", 14);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_290, " = 0;", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_291, "specializeResetN", 16);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_293, "/home/runner/work/nightlies/nightlies/nim/compiler/ccgreset.nim", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_292 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_293),
((NI) 25),
((NI) 42)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_294, "specializeResetN()", 18);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_295 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_293),
((NI) 29),
((NI) 19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_296 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_293),
((NI) 47),
((NI) 19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_297 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_293),
((NI) 49),
((NI) 21)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_298, "((void**)&", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_299, ", NIM_NIL);", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_300, ".ClE_0, NIM_NIL);", 17);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_301, ".ClP_0 = NIM_NIL;", 17);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_302, " = NIM_NIL;", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_303, "ccgreset.nim(98, 16) `false` unexpected set type kind", 53);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_304, "closure generation failed", 25);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_305 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_24),
((NI) 869),
((NI) 17)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_306, ", (", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_307, ") ClE_0);", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_308, ") ClE_0;", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_309, "NIM_BOOL* nimErr_;", 18);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_310, "nimErr_ = ", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_311, "nimErrorFlag", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_312, "();", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_313, "__declspec(noreturn) ", 21);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_314, "__declspec(naked) ", 18);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_315, " {", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_316, "}\012\012", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_317, "#", 1);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_318, "  define nimfr_(proc, file) \\\012      TFrame FR_; \\\012      FR_.procname = proc; FR_.filename = file; FR_.line = 0; FR_.len = 0; ", 125);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_319, "nimFrame", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_320, "(&FR_);\012\012  ", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_321, "  define nimfrs_(proc, file, slots, length) \\\012      struct {TFrame* prev;NCSTRING procname;NI line;NCSTRING filename; NI len; VarSlot s[slots];} FR_; \\\012      FR_.procname = proc; FR_.filename = file; FR_.line = 0; FR_.len = length; ", 232);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_322, "((TFrame*)&FR_);\012\012  ", 20);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_323, "  define nimln_(n, file) \\\012      FR_.line = n; FR_.filename = file;\012  ", 70);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_324, "\011nimfr_(", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_325, "nimProfile", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_326, "popFrame", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_327, "extern ", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_328, "N_LIB_EXPORT_VAR ", 17);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_329, "NIM_THREAD_LOCAL ", 17);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_330, "NIM_THREADVAR ", 14);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_331, "cgsym: ", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_332, ": ", 2);
extern TNimType NTItsymkind__sjiB9b9aO1FRPetW6gPYZbfw_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_333 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_24),
((NI) 821),
((NI) 23)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_334, "system module needs: ", 21);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_335 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_24),
((NI) 826),
((NI) 14)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_336, "NimStringDesc*", 14);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_337, "NCSTRING", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_338, "NIM_BOOL", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_339, "NIM_CHAR", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_340, "NI", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_341, "NI8", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_342, "NI16", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_343, "NI32", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_344, "NI64", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_345, "NF", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_346, "NF32", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_347, "NF64", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_348, "NF128", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_349, "NU", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_350, "NU8", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_351, "NU16", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_352, "NU32", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_353, "NU64", 4);
N_LIB_PRIVATE NIM_CONST tyArray__maqUPK0xSxvPlM6fxAqSIw NumericalTypeToStr__cgen_1834 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_340),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_341),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_342),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_343),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_344),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_345),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_346),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_347),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_348),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_349),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_350),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_351),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_352),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_353)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_354, "tyStatic for getSimpleTypeDesc", 30);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_355 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_18),
((NI) 308),
((NI) 23)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_356, "checkAbi", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_357, "backend & Nim disagree on size for: ", 36);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_358, "&", 1);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_359, "getTypeDescAux: enum", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_360 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_18),
((NI) 765),
((NI) 29)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_361, " : ", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_362, " data[SEQ_DECL_SIZE];", 21);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_363, "ccgtypes.nim(666, 14) `false` invalid apostrophe type parameter index", 69);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_364 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_18),
((NI) 846),
((NI) 25)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_365, "<", 1);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_366, " COMMA ", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_367, "> ", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_368, " __attribute__((__packed__))", 28);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_369, "#pragma pack(push, 1)\012", 22);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_370, "* m_type;", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_371, " : public ", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_372, "};\012", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_373, "#pragma pack(pop)\012", 18);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_374, "char dummy;\012", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_375, "getTypeDescAux(", 15);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_376 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_18),
((NI) 912),
((NI) 17)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_377, "extern \"C\" ", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_378, " __attribute__((naked))", 23);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_379, " __attribute__((noreturn))", 26);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_380, ";\012", 2);
extern TNimType NTItloc__CAJV4zTUpZwr0j6Wy8FiFw_;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_381, "request to generate code for .compileTime proc: ", 48);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_382 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 2805),
((NI) 18)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_383, "expr: proc not init ", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_384 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 2813),
((NI) 21)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_385, "_const", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_386, "\'goto\' target must be a literal value", 37);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_388, "/home/runner/work/nightlies/nightlies/nim/compiler/ccgstmts.nim", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_387 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_388),
((NI) 278),
((NI) 14)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_389, "*) ", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_390, ".dynlib variables cannot have a value", 37);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_391 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_24),
((NI) 581),
((NI) 19)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_392, ".threadvar variables cannot have a value", 40);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_393 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_24),
((NI) 589),
((NI) 21)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_394, "NIM_CONST ", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_395, " = $#;$n", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_396, ";$n", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_397, "\011NimTV_ = (NimThreadVars*) ", 27);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_398, "GetThreadLocalVars", 18);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_399, "NimTV_->", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_400, "nimRegisterThreadLocalMarker", 28);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_401, "nimRegisterGlobalMarker", 23);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_402, "nimln_(", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_403, "nimToCStringConv", 16);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_404, "wrong argument count", 20);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_406, "/home/runner/work/nightlies/nightlies/nim/compiler/ccgcalls.nim", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_405 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_406),
((NI) 517),
((NI) 16)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_407, "hcrRegisterGlobal(", 18);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_408, ", \"", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_409, "\", sizeof(", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_410, "), ", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_411, ", (void**)&", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_412, "if (hcrRegisterGlobal(", 22);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_413, "))\012", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_414, "=destroy", 8);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_415 = {
0x10, 0x08, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00,
0x00}
;
extern TNimType NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_416, "-", 1);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_417, " != -1 && (", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_418, " < 0 || ", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_419, " >= ", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_420, ".Field1 || ", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_421, ".Field1)){ ", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_422, "raiseIndexError4", 16);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_423, ".Field1); ", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_424, "goto BeforeRet_;", 16);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_425, "goto LA", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_426, "_;", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_427, "Len_0 || ", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_428, "Len_0)){ ", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_429, "Len_0); ", 8);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_430 = {
0x10, 0xa9, 0x10, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_431, " < -1 || ", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_432, " || ", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_433, " > ", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_434, ")){ ", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_435, "raiseIndexError", 15);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_436, "(); ", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_437, "); ", 3);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_438 = {
0x10, 0xa9, 0xa0, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_439, "openArrayLoc: ", 14);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_440 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_406),
((NI) 205),
((NI) 17)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_441 = {
0x10, 0xa9, 0x80, 0x00, 0x00, 0xe0, 0x80, 0x10,
0x00}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_442 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_406),
((NI) 262),
((NI) 21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_443 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_406),
((NI) 263),
((NI) 23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_444 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_406),
((NI) 56),
((NI) 13)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_445, "if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;", 44);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_446, "if (NIM_UNLIKELY(*nimErr_)) goto LA", 35);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_447 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_406),
((NI) 678),
((NI) 17)}
;
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__9bddtAaa9cYLwzzzlT9aJ5CKw_448 = {
0x00, 0x00, 0x00, 0x00, 0x88, 0x01, 0x00, 0x00,
0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_449, "call expression expected for C++ pattern", 40);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_450 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_406),
((NI) 641),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_451 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_406),
((NI) 581),
((NI) 17)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_452 = {
0x10, 0x08, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_453, "->", 2);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_454 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_406),
((NI) 726),
((NI) 17)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_455, "varargs for objective C method\?", 31);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_456 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_406),
((NI) 746),
((NI) 19)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_457, "expr: var not init ", 19);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_458 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 2838),
((NI) 22)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_459, "expr: temp not init ", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_460 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 2857),
((NI) 21)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_461, "expr: param not init ", 21);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_462 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 2864),
((NI) 21)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_463, "expr(", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_464, "); unknown symbol", 17);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_465 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 2866),
((NI) 23)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_466, "LA", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_467, " == ", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_468, "){ ", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_469, "raiseOverflow", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_470, ")(", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_471, "+", 1);
N_LIB_PRIVATE NIM_CONST tyArray__OyU7f9aPY4V3Jxs36khP6fw opr__cgen_23236 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_471),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_416),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_90),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_61)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_472, " (", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_473, " != ", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_474, "raiseFloatInvalidOp", 19);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_475, " != 0.0 && ", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_476, "*0.5 == ", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_477, ") { ", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_478, "raiseFloatOverflow", 18);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_479, "%", 1);
N_LIB_PRIVATE NIM_CONST tyArray__2TOvp8OQKJM4nuxy9aPytmQ opr__cgen_18909 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_471),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_416),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_90),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_61),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_479),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_471),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_416)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_480, " == 0){ ", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_481, "raiseDivByZero", 14);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_482, "nimAddInt64", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_483, "nimSubInt64", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_484, "nimMulInt64", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_485, "nimDivInt64", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_486, "nimModInt64", 11);
N_LIB_PRIVATE NIM_CONST tyArray__2TOvp8OQKJM4nuxy9aPytmQ prc64__cgen_18908 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_482),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_483),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_484),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_485),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_486),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_482),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_483)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_487, "nimAddInt", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_488, "nimSubInt", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_489, "nimMulInt", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_490, "nimDivInt", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_491, "nimModInt", 9);
N_LIB_PRIVATE NIM_CONST tyArray__2TOvp8OQKJM4nuxy9aPytmQ prc__cgen_18907 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_487),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_488),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_489),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_490),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_491),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_487),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_488)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_492, ", &", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_493, ")) { ", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_494, "\'repr\' is not available for --newruntime", 40);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_495 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 1687),
((NI) 14)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_496, "reprInt", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_497, "((NI64)", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_498, "reprFloat", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_499, "reprBool", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_500, "reprChar", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_501, "reprEnum", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_502, "((NI)", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_503, "reprStr", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_504, "reprSet", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_505, "genRepr()", 9);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_506 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 1723),
((NI) 23)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_507, "reprOpenArray", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_508, "reprAny", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_509, "\'repr\' doesn\'t support \'void\' type", 34);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_510 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 1732),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_511 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 1191),
((NI) 39)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_512, "getDynamicTypeInfo", 18);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_513, ".m_type", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_514, "->typeInfoV1", 12);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_515 = {
0x10, 0x28, 0x90, 0x00, 0x00, 0xc0, 0x00, 0x00,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_516, "binaryStmt", 10);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_517 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 501),
((NI) 34)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_518, "+=", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_519, "-=", 2);
N_LIB_PRIVATE NIM_CONST tyArray__oU05KnNo1VmpSMUvzgvN9ag opr__cgen_23529 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_518),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_519)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_520 = {
0x10, 0x28, 0x80, 0x00, 0x00, 0xc0, 0x00, 0x00,
0x00}
;
N_LIB_PRIVATE NIM_CONST tyArray__oU05KnNo1VmpSMUvzgvN9ag fun64__cgen_23530 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_482),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_483)}
;
N_LIB_PRIVATE NIM_CONST tyArray__oU05KnNo1VmpSMUvzgvN9ag fun__cgen_23531 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_487),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_488)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_521, "appendChar", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_522, " + ", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_523, "appendString", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_524, "rawNewString", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_525, "binaryStmtAddr", 14);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_526 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 508),
((NI) 34)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_527, "nimAddCharV1", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_528, "addChar", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_529, "prepareAdd", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_530, "resizeString", 12);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_531 = {
0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_532, "incrSeqV3", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_533, "((TGenericSeq*)(", 16);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_534, "NI ", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_535, "++;", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_536, " == 0)", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_537, "eqStrings", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_538, "cmpStrings", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_539, ") <= 0)", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_540, ") < 0)", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_541, ".ClP_0 == 0)", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_542, "nimIntToStr", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_543, "nimInt64ToStr", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_544, "nimBoolToStr", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_545, "nimCharToStr", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_546, "nimFloat32ToStr", 15);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_547, "nimFloatToStr", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_548, "cstrToNimstr", 12);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_549 = {
0x10, 0xa9, 0x10, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_550, "no \'of\' operator available for pure objects", 43);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_551 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 1674),
((NI) 15)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_552, ") && (", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_553, "Nim_OfCheck_CACHE", 17);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_554, "isObjWithCache", 14);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_555, ".m_type, ", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_556, "nimNewObj", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_557, ", NIM_ALIGNOF(", 14);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_558, "nimNewObjUninit", 15);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_559, "the destructor that is turned into a finalizer needs to have the \'nimcall\' calling convention", 93);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_560 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 1356),
((NI) 18)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_561, "nimGCunrefRC1", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_562, " = NIM_NIL; }", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_563, "newObj", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_564, "newObjRC1", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_565, ".len = ", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_566, ".p = (", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_567, "newSeqPayload", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_568, "), NIM_ALIGNOF(", 15);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_569, "newSeq", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_570, "newSeqRC1", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_571, "nimNewSeqOfCap", 14);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_572 = {
0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_573, "unknown ast", 11);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_574 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 2432),
((NI) 19)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_575, "Field", 5);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_576 = {
0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_577 = {
0x10, 0xa9, 0x80, 0x00, 0x00, 0xe0, 0xb0, 0x00,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_578, ")-(", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_579, ")+1", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_580, "Len_0-1)", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_581, "Len_0", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_582, "->Field1-1)", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_583, ".Field1-1)", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_584, "->Field1", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_585, ".Field1", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_586, " \? (", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_587, "nimCStrLen", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_588, ")-1) : -1)", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_589, " \? ", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_590, ") : 0)", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_591, "genArrayLen()", 13);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_592 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 1848),
((NI) 21)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_593, "unaryStmt", 9);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_594 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 515),
((NI) 34)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_595, "nimGCref", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_596, "); }", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_597, "nimGCunref", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_598, "setLengthStrV2", 14);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_599, "genSetLengthStr", 15);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_600 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 1895),
((NI) 36)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_601, "setLengthStr", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_602, "setLengthSeqV2", 14);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_603, ")\?&(", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_604, ")->Sup:NIM_NIL, ", 16);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_605, "countBits32", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_606, "countBits64", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_607, "(((", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_608, " & ~ ", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_609, ")==0)&&(", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_610, ")==0)", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_611, " & ", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_612, " | ", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_613, "genSetOp()", 10);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_614 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 2040),
((NI) 23)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_615, "cardSet", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_616, "++) { ", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_617, " = ((", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_618, "] & ~ ", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_619, "]) == 0);", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_620, "  if (!", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_621, ") break;}", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_622, "nimCmpMem", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_623, ") != 0);", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_624, "for ($1 = 0; $1 < $2; $1++) { $n  $3 = (($4[$1] & ~ $5[$1]) == 0);$n  if (!$3) break;}$n", 88);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_625, "for ($1 = 0; $1 < $2; $1++) { $n  $3 = (($4[$1] & ~ $5[$1]) == 0);$n  if (!$3) break;}$nif ($3) $3 = (#nimCmpMem($4, $5, $2) != 0);$n", 133);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_626, "& ~", 3);
N_LIB_PRIVATE NIM_CONST tyArray__RXSdvX0UuCkXpf4OjqXhcg lookupOpr__cgen_22357 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_624),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_625),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_358),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_137),
((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_626)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_627, "genSetOp", 8);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_628 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 2079),
((NI) 23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_629 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 1157),
((NI) 17)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_630, ", \"\"", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_631, "Genode::Cstring(", 16);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_632, ".p->data, ", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_633, ".len)", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_634, "->data, ", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_635, "->len)", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_636, "<base/log.h>", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_637, "<util/string.h>", 15);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_638, "Genode::log(", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_639, "echoBinSafe", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_640, "(NIM_NIL, ", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_641, "\'$1\' can only be used in compile-time context", 45);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_642 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 2482),
((NI) 14)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_643, "for --gc:arc|orc \'deepcopy\' support has to be enabled with --deepcopy:on", 72);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_644 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 2497),
((NI) 16)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_645 = {
0x10, 0xa9, 0x90, 0x00, 0x00, 0x60, 0x80, 0x10,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_646, "genericDeepCopy", 15);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_647, "genericSeqDeepCopy", 18);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_648, "genericDeepCopyOpenArray", 24);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_649, "genDeepCopy: ", 13);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_650 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 460),
((NI) 21)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_651, ".p != ", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_652, ".p) {", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_653, ".len; ", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_654, ".p = ", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_655, ".p;", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_656, ".p && !(", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_657, ".p->cap & NIM_STRLIT_FLAG)) {", 29);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_658, "deallocShared", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_659, ".p);", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_660, "dealloc", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_661, "alignedDealloc", 14);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_662, ".p, NIM_ALIGNOF(", 16);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_663, "destructor turned out to be not trivial", 39);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_664 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 2290),
((NI) 19)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_665, "genMagicExpr: ", 14);
extern TNimType NTItmagic__3qAy6bDUDlF8Fc2RR6pF9ag_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_666 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 2516),
((NI) 17)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_667, "CNSTCLOSURE", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_668, "closure to closure created", 26);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_669 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 2596),
((NI) 19)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_670, ".ClE_0 = ", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_671, "genCheckedRecordField", 21);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_672 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 863),
((NI) 33)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_673, "genObjConstr", 12);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_674 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 1518),
((NI) 40)}
;
static NIM_CONST tyTuple__47w2DboNEPf69aPgubZdd7Q TM__9bddtAaa9cYLwzzzlT9aJ5CKw_675 = {((NI) 1),
((NI) 5),
((NI) 1)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_676, "{ ", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_677, "raiseFieldError", 15);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_678, "raiseFieldError2", 16);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_679, ", (NI)", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_680, "reprDiscriminant", 16);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_681, "(((NI)", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_682, ") + (NI)", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_683, ")); ", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_684, "union { ", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_685, " source; ", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_686, " dest; } LOC", 12);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_687 = {
0x10, 0x08, 0x80, 0x00, 0x00, 0xc0, 0x00, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_688 = {
0x10, 0xa9, 0x90, 0x00, 0x00, 0x60, 0xb0, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_689 = {
0x10, 0xa9, 0xf0, 0x00, 0x00, 0xe0, 0xb0, 0x00,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_690, "if ((NU)(", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_691, ") > (NU)(", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_692, "raiseIndexError2", 16);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_693, "raiseIndexError3", 16);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_694, "index out of bounds, the container is empty", 43);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_695, "index ", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_696, " not in ", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_697, " .. ", 4);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_698 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 986),
((NI) 18)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_699, "[(", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_700, ")- ", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_701, "Len_0){ ", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_702, ",", 1);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_703, "Len_0-1); ", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_704, ".Field1){ ", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_705, ".Field1-1); ", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_706, ".Field0[", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_707, "-1); ", 5);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9bddtAaa9cYLwzzzlT9aJ5CKw_708 = {
0x10, 0xa9, 0x80, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_709, "genTupleElem", 12);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_710 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 846),
((NI) 21)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_711, "expr(nkBracketExpr, ", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_712 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 1077),
((NI) 21)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_713, "genDeref ", 9);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_714 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 784),
((NI) 21)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_715, "genRecordFieldAux", 17);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_716 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 830),
((NI) 38)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_717, "genRecordField 3 ", 17);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_718 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 880),
((NI) 40)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_719 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 951),
((NI) 19)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_720, "FR", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_721, ".procname = ", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_722, ".filename = ", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_723, ";  ", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_724, ".line = ", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_725, ".len = -1; nimFrame(&", 21);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_726, "popFrameOfAddr", 14);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_727, "genIf()", 7);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_728 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_388),
((NI) 467),
((NI) 23)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_729, "->Sup", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_730, " && !", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_731, "isObj", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_732, "raiseObjectConversionError", 26);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_733, "if (!", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_734, " > (", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_735, "raiseRangeErrorNoArgs", 21);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_736, "raiseRangeErrorU", 16);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_737, "raiseRangeErrorF", 16);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_738, "raiseRangeErrorI", 16);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_739, "csize", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_740, "(NI64)", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_741, ") < ", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_742, ") > ", 4);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_743 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 2935),
((NI) 19)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_744, "case statement must be exhaustive for computed goto", 51);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_745 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_388),
((NI) 520),
((NI) 18)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_746, "case statement cannot work on enums with holes for computed goto", 64);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_747 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_388),
((NI) 524),
((NI) 18)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_748, "case statement has too many cases for computed goto", 51);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_749 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_388),
((NI) 528),
((NI) 18)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_750, "case statement has to start at 0 for computed goto", 50);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_751 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_388),
((NI) 532),
((NI) 18)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_752, "no case statement found for computed goto", 41);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_753 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_388),
((NI) 535),
((NI) 14)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_754, "range notation not available for computed goto", 46);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_755 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_388),
((NI) 559),
((NI) 18)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_756, "while (1) {", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_757, "genVarTuple", 11);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_758 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_388),
((NI) 71),
((NI) 40)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_759 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_388),
((NI) 114),
((NI) 44)}
;
N_LIB_PRIVATE TNimType NTItupleLloc58tloc_tp58ropeT__PCL3pTh9cmlWmhmXAE5IOKQ_;
extern TNimType NTIrope__Ylz2qJFHq2oxQcAA5BJOQg_;
N_LIB_PRIVATE TNimType NTIseqLtupleLloc58tloc_tp58ropeTT__Vz8km29c8JcWq5WOBlnn2aQ_;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_761, "NIM_BOOL ", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_762, " = NIM_FALSE;", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_763, " |= hcrRegisterGlobal(", 22);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_764, ");\012", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_765, "for statement not eliminated", 28);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_766 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 2946),
((NI) 29)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_767, ")) goto ", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_768, "switch (", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_769, "hashString", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_770, ") & ", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_771, ") {", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_772, " && ", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_773, " <= ", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_774, ") goto ", 7);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_775 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_388),
((NI) 491),
((NI) 18)}
;
extern TNimType NTIseqLtupleLfin58pnode_inexcept58bool_label58naturalTT__IjAwukZ9aSEsol9c48He4FYQ_;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_776, "popSafePoint", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_777, "popCurrentException", 19);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_778, ".status != 0) ", 14);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_779, "ccgstmts.nim(698, 13) `sym.loc.k == locOther` ", 46);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_780, "no loop to break", 16);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_781 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_388),
((NI) 704),
((NI) 19)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_782, "FieldDiscriminantCheck", 22);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_783, "((NI)(NU)(", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_784, "), (NI)(NU)(", 12);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_785 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_388),
((NI) 1577),
((NI) 11)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_786, "(void)(", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_787, "\"", 1);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_788, "\\\"", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_789, "\\n\"\012", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_790, "if (NIM_UNLIKELY(*nimErr_)) {", 29);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_791, "_:;", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_792, "*nimErr_ = NIM_FALSE;", 21);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_793, "m_type", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_794, "Sup.m_type", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_795, "nimBorrowCurrentException", 25);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_796, "()->", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_797, "else ", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_798, "NIM_BOOL oldNimErrFin", 21);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_799, "oldNimErrFin", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_800, "_ = *nimErr_; *nimErr_ = NIM_FALSE;", 35);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_801, "*nimErr_ = oldNimErrFin", 23);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_802, "<exception>", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_803, "\011std::exception_ptr T", 21);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_804, "_ = nullptr;", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_805, "try {", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_806, "catch (", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_807, "Exception", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_808, "* T", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_809, "_) {", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_810, "\011TFrame* _nimCurFrame;", 22);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_811, "\011_nimCurFrame = ", 16);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_812, "getFrame", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_813, "setFrame", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_814, "(_nimCurFrame);", 15);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_815, "_ = std::current_exception();", 29);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_816, "else if (", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_817, " = T", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_818, "else throw;", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_819, "catch (...) {", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_820, "& ", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_821, "&) {", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_822, "if (T", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_823, "_) std::rethrow_exception(T", 27);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_824, "_);", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_825, "<setjmp.h>", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_826, "TSafePoint", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_827, "pushSafePoint", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_828, "nimStdSetjmp", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_829, ".status = setjmp(", 17);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_830, ".context);", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_831, "nimSigSetjmp", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_832, ".status = sigsetjmp(", 20);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_833, ".context, 0);", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_834, "nimBuiltinSetjmp", 16);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_835, ".status = __builtin_setjmp(", 27);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_836, "nimRawSetjmp", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_837, "mswindows", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_838, "vcc", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_839, "clangcl", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_840, ".status = _setjmp(", 18);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_841, ".status == 0) {", 15);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_842, "else {", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_843, "()) {", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_844, ".status = 0;", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_845, "nimLeaveFinally", 15);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_846, "reraiseException", 16);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_847, "raiseExceptionEx", 16);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_848, "*)", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_849, "/*TYPESECTION*/", 15);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_850, "/*VARSECTION*/", 14);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_851, "/*INCLUDESECTION*/", 18);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_852 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_388),
((NI) 196),
((NI) 17)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_853, "STATE", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_854, ": ;", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_855, "STATE", 5);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_856, "); unknown node kind", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_857 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_188),
((NI) 3011),
((NI) 21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_858 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_388),
((NI) 1610),
((NI) 17)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_859, "nimTestErrorFlag", 16);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_860, "programResult", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_861, "procAddrError", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_862, "rawWrite", 8);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_863, "initStackBottomWith", 19);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_864, "initThreadVarsEmulation", 23);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_865, "still forwarded: ", 17);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_866 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_24),
((NI) 2132),
((NI) 19)}
;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_867, "NimMainModule", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_868, "Init000", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_869, "N_LIB_EXPORT", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_870, "N_LIB_PRIVATE", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_871, "generated_not_to_break_here", 27);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_872, "* ", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_873, "\011hcrRegisterGlobal(", 19);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_874, "\", sizeof(TNimNode) * ", 22);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_875, ", NULL, (void**)&", 17);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_876, "\011if (nim_hcr_do_init_) {\012\012", 26);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_877, "\012\011} // nim_hcr_do_init_\012", 24);
extern TNimType NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_878, "hcrRegisterProc", 15);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_879, "hcrGetProc", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_880, "hcrRegisterGlobal", 17);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_881, "hcrGetGlobal", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_882, "HcrInit000", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_883, "hcrInit", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_884, "hcrAddModule", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_885, "handle", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_886, "getProcAddr", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_887, "DatInit000", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_888, "stdlib_system", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_889, "stdlib_os", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_890, "\011int* cmd_count;\012", 17);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_891, "\011char*** cmd_line;\012", 19);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_892, "\011*cmd_count = cmdCount;\012", 24);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_893, "\011*cmd_line = cmdLine;\012", 22);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_894, "();\012", 4);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_895, "((void *)&inner);\012", 18);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_896, "\012\012", 2);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_897, "#", 1);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_898, "ifndef ", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_899, "_Content_PP\012", 12);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_900, "define ", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_901, "_Content_PP\012struct ", 19);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_902, "_Content { NI cap; ", 19);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_903, " data[SEQ_DECL_SIZE];};\012", 24);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_904, "endif\012\012      ", 13);
extern TNimType NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_;
N_LIB_PRIVATE TNimType NTIobject__MH1VwSLIbfCI9coJDTeX9c2Q_;
extern TNimType NTIint__xHTZrq9aYs6boc9bCba0JbpQ_;
N_LIB_PRIVATE TNimType NTIrefobject__9bbPrOZAgwWihvYGa8yXUow_;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_906, "\011if (!(", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_907, ")))\012\011\011", 6);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_908, "hcr_handle", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_910, "\011void* rtl_handle;\012", 19);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_911, "rtl_handle", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_912, "nimGC_setStackBottom", 20);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_914, "nimrtl_", 7);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_915, "\011inner = PreMain;\012", 18);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_916, "\011initStackBottomWith_actual((void *)&inner);\012", 45);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_917, "\011(*inner)();\012", 13);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_918, "\011N_LIB_PRIVATE int cmdCount;\012", 29);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_919, "\011N_LIB_PRIVATE char** cmdLine;\012", 31);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_920, "\011N_LIB_PRIVATE char** gEnv;\012", 28);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_921, "<windows.h>", 11);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_922, "<libc/component.h>", 18);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_923, "\012N_LIB_PRIVATE void ", 20);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_924, "PreMainInner(void) {\012", 21);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_925, "N_LIB_PRIVATE void ", 19);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_926, "PreMain(void) {\012\011void (*volatile inner)(void);\012\011inner = ", 56);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_927, "PreMainInner;\012", 14);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_928, "\011(*inner)();\012}\012\012", 16);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_929, "PreMain(void) {\012", 16);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_930, "PreMainInner();\012}\012\012", 19);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_931, "N_LIB_PRIVATE N_CDECL(void, ", 28);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_932, "NimMainInner)(void) {\012", 22);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_933, "}\012\012N_CDECL(void, ", 17);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_934, "NimMain)(void) {\012\011void (*volatile inner)(void);\012", 48);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_935, "\011inner = ", 9);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_936, "NimMainInner;\012", 14);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_937, "}\012\012N_LIB_EXPORT N_CDECL(void, ", 30);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_938, "extern Genode::Env *nim_runtime_env;\012extern \"C\" void nim_component_construct(Genode::Env*);\012\012N_LIB_PRIVATE N_CDECL(void, ", 121);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_939, "NimMain)(void) {\012", 17);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_940, "NimMainInner();\012}\012\012", 19);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_941, "using namespace ", 16);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_942, "N_STDCALL(int, WinMain)(HINSTANCE hCurInstance, \012                        HINSTANCE hPrevInstance, \012                        LPSTR lpCmdLine, int nCmdShow) {\012\011", 157);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_943, "NimMain();\012\011return ", 19);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_944, "nim_program_result;\012}\012\012", 23);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_945, "BOOL WINAPI DllMain(HINSTANCE hinstDLL, DWORD fwdreason, \012                    LPVOID lpvReserved) {\012\011if(fwdreason == DLL_PROCESS_ATTACH) {\012\011", 140);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_946, "NimMain();\012}\012\011return 1;\012}\012\012", 27);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_947, "void Libc::Component::construct(Libc::Env &env) {\012\011// Set Env used during runtime initialization\012\011nim_runtime_env = &env;\012\011Libc::with_libc([&] () {\012\011\011// Initialize runtime and globals\012\011", 185);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_948, "NimMain();\012\011// Call application construct\012\011\011nim_component_construct(&env);\012\011});\012}\012\012", 83);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_949, "N_LIB_PRIVATE void NIM_POSIX_INIT NimMainInit(void) {\012\011", 55);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_950, "NimMain();\012}\012\012", 14);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_951, "int main(void) {\012\011", 18);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_952, "NimMain();\012\011return 0;\012}\012\012", 25);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_953, "int main(int argc, char** args, char** env) {\012\011cmdLine = args;\012\011cmdCount = argc;\012\011gEnv = env;\012\011", 95);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_954, "namespace ", 10);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_955, " {\012", 3);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_956, "1.6.14", 6);
extern NIM_CONST tyArray__O7sksHvn7BNpHcBD2dBmog CPU__platform_705;
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_957, "#define NIM_HOT_CODE_RELOADING\012", 31);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_958, "#define USE_NIM_NAMESPACE ", 26);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_959, "nimEmulateOverflowChecks", 24);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_960, "#define NIM_EmulateOverflowChecks\012", 34);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_961, "\012#include \"nimbase.h\"\012", 22);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_962, "#undef LANGUAGE_C\012#undef MIPSEB\012#undef MIPSEL\012#undef PPC\012#undef R3000\012#undef R4000\012#undef i386\012#undef linux\012#undef mips\012#undef near\012#undef far\012#undef powerpc\012#undef unix\012", 170);
STRING_LITERAL(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_963, "#define nimfr_(x, y)\012#define nimln_(x, y)\012", 42);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_964 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_24),
((NI) 2013),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_965 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_24),
((NI) 2021),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bddtAaa9cYLwzzzlT9aJ5CKw_966 = {((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_24),
((NI) 1944),
((NI) 14)}
;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5228;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5319)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5281)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5324)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5275((&gch__system_5228.zct), c);
}
static N_INLINE(void, decRef__system_5326)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5324(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5281(src);
		incRef__system_5319(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5281((*dest));
		decRef__system_5326(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5281(p);
	decRef__system_5326(T1_);
}
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result) {
	initPackedSet__pureZcollectionsZintsets_16(Result);
}
N_LIB_PRIVATE N_NIMCALL(tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ, initProcOptions__cgen_28467)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m) {
	tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ result;
	tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ opts;
	nimZeroMem((void*)(&result), sizeof(tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ));
	opts = (*(*(*m).g).config).options;
	{
		if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 15))&63U)))!=0)) goto LA3_;
		result = (opts & ~ 131072);
	}
	goto LA1_;
	LA3_: ;
	{
		result = opts;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getTempName__cgen_428)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = rope__ropes_115(((NI64) ((*m).labels)));
	result = amp___ropes_128((*m).tmpBase, T1_);
	(*m).labels += ((NI) 1);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA*, rawNewModule__cgen_28479)(tyObject_BModuleListcolonObjectType___9c4b0IbdzIJRabh100GyFtA* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, NimStringDesc* filename) {
	tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* result;
	NimStringDesc* T1_;
	tyArray__qtqsWM5aXmcpMIVmvq3kAA T2_;
	NimStringDesc* T3_;
	NimStringDesc* T4_;
	NimStringDesc* T5_;
	NimStringDesc* ndiName;
	result = NIM_NIL;
	result = (tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA*) newObj((&NTIbmodule__AeJVysvbewqqb9ao16aCkYA_), sizeof(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA));
	(*result).Sup.Sup.m_type = (&NTItcgen__LLLbwetkArja9aBhGlHYtvA_);
	asgnRef((void**) (&(*result).g), g);
	T1_ = NIM_NIL;
	nimZeroMem((void*)T2_, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
	hashOwner__sighashes_518(module, T2_);
	T3_ = NIM_NIL;
	T3_ = dollar___modulegraphs_8985(T2_);
	T1_ = rawNewString((T3_ ? T3_->Sup.len : 0) + 3);
appendString(T1_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_2));
appendString(T1_, T3_);
appendString(T1_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3));
	asgnRef((void**) (&(*result).tmpBase), rope__ropes_109(T1_));
	if ((*result).headerFiles) { nimGCunrefNoCycle((*result).headerFiles); (*result).headerFiles = NIM_NIL; }
	initIntSet__pureZcollectionsZintsets_238((&(*result).declaredThings));
	initIntSet__pureZcollectionsZintsets_238((&(*result).declaredProtos));
	T4_ = NIM_NIL;
	T4_ = (*result).cfilename; (*result).cfilename = copyStringRC1(filename);
	if (T4_) nimGCunrefNoCycle(T4_);
	T5_ = NIM_NIL;
	T5_ = (*result).filename; (*result).filename = copyStringRC1(filename);
	if (T5_) nimGCunrefNoCycle(T5_);
	initTable__cgen_28491(((NI) 32), (&(*result).typeCache));
	initTable__cgen_28491(((NI) 32), (&(*result).forwTypeCache));
	asgnRef((void**) (&(*result).module), module);
	initTable__cgen_28491(((NI) 32), (&(*result).typeInfoMarker));
	initCountTable__cgen_28510(((NI) 32), (&(*result).sigConflicts));
	asgnRef((void**) (&(*result).initProc), newProc__cgendata_278(((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL), result));
	(*(*result).initProc).options = initProcOptions__cgen_28467(result);
	asgnRef((void**) (&(*result).preInitProc), newProc__cgendata_278(((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL), result));
	(*(*result).preInitProc).flags |= ((NU8)1)<<((((tyEnum_TCProcFlag__Iv1wQAvkoMCW3v9cTnZWvJw) 6)) & 7);
	(*(*result).preInitProc).labels = ((NI) 100000);
	initNodeTable__ast_4132((&(*result).dataCache));
	if ((*result).typeStack) { nimGCunrefNoCycle((*result).typeStack); (*result).typeStack = NIM_NIL; }
	asgnRef((void**) (&(*result).typeNodesName), getTempName__cgen_428(result));
	asgnRef((void**) (&(*result).nimTypesName), getTempName__cgen_428(result));
	{
		if (!(((*module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 15))&63U)))!=0)) goto LA8_;
		(*result).flags |= ((NU8)1)<<((((tyEnum_CodegenFlag__vPx29bHhk9a7V50u1UO0rM4w) 0)) & 7);
		(*(*result).preInitProc).options &= ~(((NU32)1) << ((((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 17)) & 31));
	}
	LA8_: ;
	{
		NimStringDesc* T14_;
		if (!(((*(*g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 6))&63U)))!=0)) goto LA12_;
		T14_ = NIM_NIL;
		T14_ = completeCfilePath__extccomp_715((*g).config, filename, NIM_TRUE);
		ndiName = noschangeFileExt(T14_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_4));
	}
	goto LA10_;
	LA12_: ;
	{
		ndiName = ((NimStringDesc*) NIM_NIL);
	}
	LA10_: ;
	open__ndi_24((&(*result).ndi), ndiName, (*g).config);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA*, rawNewModule__cgen_28572)(tyObject_BModuleListcolonObjectType___9c4b0IbdzIJRabh100GyFtA* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* result;
	NimStringDesc* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = toFullPath__msgs_548(conf, ((NI32) ((*module).position)));
	result = rawNewModule__cgen_28479(g, module, T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA*, newModule__cgen_28577)(tyObject_BModuleListcolonObjectType___9c4b0IbdzIJRabh100GyFtA* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* result;
	result = NIM_NIL;
	result = rawNewModule__cgen_28572(g, module, conf);
	{
		NI T3_;
		T3_ = ((*g).modules ? (*g).modules->Sup.len : 0);
		if (!(T3_ <= (*module).position)) goto LA4_;
		asgnRef((void**) (&(*g).modules), (tySequence__ukLNp6qJ4FndCViFTz0FGg*) setLengthSeqV2(((*g).modules)?&((*g).modules)->Sup:NIM_NIL, (&NTIseqLbmoduleT__ukLNp6qJ4FndCViFTz0FGg_), ((NI) ((NI)((*module).position + ((NI) 1))))));
	}
	LA4_: ;
	asgnRef((void**) (&(*g).modules->data[(*module).position]), result);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, myOpen__cgen_28590)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen) {
	tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* result;
	tyObject_BModuleListcolonObjectType___9c4b0IbdzIJRabh100GyFtA* g;
	tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* T6_;
	result = NIM_NIL;
	{
		tyObject_BModuleListcolonObjectType___9c4b0IbdzIJRabh100GyFtA* T5_;
		if (!((*graph).backend == ((RootObj*) NIM_NIL))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = newModuleList__cgendata_392(graph);
		asgnRef((void**) (&(*graph).backend), &T5_->Sup);
	}
	LA3_: ;
	g = (*((tyObject_BModuleListcolonObjectType___9c4b0IbdzIJRabh100GyFtA**) (&((*graph).backend))));
	T6_ = NIM_NIL;
	T6_ = newModule__cgen_28577(g, module, (*graph).config);
	result = &T6_->Sup;
	asgnRef((void**) (&(*result).idgen), idgen);
	{
		NIM_BOOL T9_;
		NimStringDesc* f;
		NimStringDesc* T18_;
		NimStringDesc* T19_;
		T9_ = (NIM_BOOL)0;
		T9_ = (((*(*graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 27))&63U)))!=0);
		if (!(T9_)) goto LA10_;
		T9_ = ((*g).generatedHeader == ((tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA*) NIM_NIL));
		LA10_: ;
		if (!T9_) goto LA11_;
		{
			if (!(((NI) 0) < ((*(*graph).config).headerFile ? (*(*graph).config).headerFile->Sup.len : 0))) goto LA15_;
			f = (*(*graph).config).headerFile;
		}
		goto LA13_;
		LA15_: ;
		{
			f = (*(*graph).config).projectFull;
		}
		LA13_: ;
		T18_ = NIM_NIL;
		T18_ = completeCfilePath__extccomp_715((*graph).config, f, NIM_TRUE);
		T19_ = NIM_NIL;
		T19_ = noschangeFileExt(T18_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_5));
		asgnRef((void**) (&(*g).generatedHeader), rawNewModule__cgen_28479(g, module, T19_));
		(*(*g).generatedHeader).flags |= ((NU8)1)<<((((tyEnum_CodegenFlag__vPx29bHhk9a7V50u1UO0rM4w) 3)) & 7);
	}
	LA11_: ;
	return result;
}
static N_INLINE(NIM_BOOL, skipCodegen__passes_51)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = (((NI) 0) < (*config).errorCounter);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hcrOn__cgen_43)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = hcrOn__options_582((*(*m).g).config);
	return result;
}
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__ast_3155(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, blockBody__cgen_13554)(tyObject_TBlock__FHXN9cI0ri9bj2d9cKw8iPHZg* b) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	result = (*b).sections[(((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0))- 0];
	{
		tyArray__ts9cf9blICas1QWmw89bglZ7w T5_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
		if (!(((NI16) 0) < (*b).frameLen)) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T5_[0] = rope__ropes_115(((NI64) ((*b).frameLen)));
		T6_ = NIM_NIL;
		T6_ = percent___cgen_13557(T5_, 1);
		add__ropes_159(&result, T6_);
	}
	LA3_: ;
	add__ropes_159(&result, (*b).sections[(((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 1))- 0]);
	add__ropes_159(&result, (*b).sections[(((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2))- 0]);
	return result;
}
static N_INLINE(tyObject_TBlock__FHXN9cI0ri9bj2d9cKw8iPHZg*, X5BX5D___cgendata_229)(tyObject_TBlock__FHXN9cI0ri9bj2d9cKw8iPHZg* s, NI sLen_0, NI i) {
	tyObject_TBlock__FHXN9cI0ri9bj2d9cKw8iPHZg* result;
	result = (tyObject_TBlock__FHXN9cI0ri9bj2d9cKw8iPHZg*)0;
	result = (&s[(NI)(sLen_0 - i)]);
	return result;
}
static N_INLINE(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**, s__cgendata_225)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw s) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** result;
	tyObject_TBlock__FHXN9cI0ri9bj2d9cKw8iPHZg* T1_;
	result = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T1_ = (tyObject_TBlock__FHXN9cI0ri9bj2d9cKw8iPHZg*)0;
	T1_ = X5BX5D___cgendata_229(((*p).blocks) ? ((*p).blocks->data) : NIM_NIL, ((*p).blocks ? (*p).blocks->Sup.len : 0), ((NI) 1));
	result = &(*T1_).sections[(s)- 0];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, indentLine__cgen_286)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	result = r;
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = ((*p).blocks ? (*p).blocks->Sup.len : 0);
		colontmp_ = T2_;
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				T5_ = NIM_NIL;
				T5_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_6));
				prepend__ropes_265(&result, T5_);
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, endBlock__cgen_13562)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* blockEnd) {
	NI topBlock;
	NI T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T2_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T3_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T4_;
	T1_ = ((*p).blocks ? (*p).blocks->Sup.len : 0);
	topBlock = (NI)(T1_ - ((NI) 1));
	T2_ = NIM_NIL;
	T2_ = blockBody__cgen_13554((&(*p).blocks->data[topBlock]));
	add__ropes_159(&(*p).blocks->data[(NI)(topBlock - ((NI) 1))].sections[(((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2))- 0], T2_);
	asgnRef((void**) (&(*p).blocks), (tySequence__Y9a9bBybAqzjKkPsvOIQEzpw*) setLengthSeqV2(((*p).blocks)?&((*p).blocks)->Sup:NIM_NIL, (&NTIseqLtblockT__Y9a9bBybAqzjKkPsvOIQEzpw_), ((NI) (topBlock))));
	T3_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T3_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	T4_ = NIM_NIL;
	T4_ = indentLine__cgen_286(p, blockEnd);
	add__ropes_159(T3_, T4_);
}
N_LIB_PRIVATE N_NIMCALL(void, endBlock__cgen_13329)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p) {
	NI topBlock;
	NI T1_;
	NI16 frameLen;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* blockEnd;
	T1_ = ((*p).blocks ? (*p).blocks->Sup.len : 0);
	topBlock = (NI)(T1_ - ((NI) 1));
	frameLen = (*p).blocks->data[topBlock].frameLen;
	blockEnd = NIM_NIL;
	{
		tyArray__ts9cf9blICas1QWmw89bglZ7w T6_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
		if (!(((NI16) 0) < frameLen)) goto LA4_;
		nimZeroMem((void*)T6_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T6_[0] = rope__ropes_115(((NI64) (frameLen)));
		T7_ = NIM_NIL;
		T7_ = percent___cgen_13581(T6_, 1);
		add__ropes_159(&blockEnd, T7_);
	}
	LA4_: ;
	{
		tyArray__ts9cf9blICas1QWmw89bglZ7w T12_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
		if (!!(((*p).blocks->data[topBlock].label == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA10_;
		nimZeroMem((void*)T12_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T12_[0] = (*p).blocks->data[topBlock].label;
		T13_ = NIM_NIL;
		T13_ = percent___cgen_13590(T12_, 1);
		add__ropes_159(&blockEnd, T13_);
	}
	goto LA8_;
	LA10_: ;
	{
		tyArray__dAmhZbEWrTM5xES2bTVweg T15_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
		nimZeroMem((void*)T15_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		T16_ = NIM_NIL;
		T16_ = percent___cgen_7535(T15_, 0);
		add__ropes_159(&blockEnd, T16_);
	}
	LA8_: ;
	endBlock__cgen_13562(p, blockEnd);
}
N_LIB_PRIVATE N_NIMCALL(NI, inExceptBlockLen__cgen_13273)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p) {
	NI result;
	result = (NI)0;
	{
		tyTuple__T1RBf8m9axj9bvJRlYejkpkQ* x;
		NI i;
		NI L;
		NI T2_;
		x = (tyTuple__T1RBf8m9axj9bvJRlYejkpkQ*)0;
		i = ((NI) 0);
		T2_ = ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				x = (&(*p).nestedTryStmts->data[i]);
				{
					if (!(*x).Field1) goto LA7_;
					result += ((NI) 1);
				}
				LA7_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, startBlockInternal__cgen_13308)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p) {
	NI result;
	NI T1_;
	NI T2_;
	NI T3_;
	result = (NI)0;
	(*p).labels += ((NI) 1);
	T1_ = ((*p).blocks ? (*p).blocks->Sup.len : 0);
	result = T1_;
	asgnRef((void**) (&(*p).blocks), (tySequence__Y9a9bBybAqzjKkPsvOIQEzpw*) setLengthSeqV2(((*p).blocks)?&((*p).blocks)->Sup:NIM_NIL, (&NTIseqLtblockT__Y9a9bBybAqzjKkPsvOIQEzpw_), ((NI) ((NI)(result + ((NI) 1))))));
	(*p).blocks->data[result].id = ((NI) ((*p).labels));
	T2_ = ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0);
	(*p).blocks->data[result].nestedTryStmts = ((NI16) (T2_));
	T3_ = (NI)0;
	T3_ = inExceptBlockLen__cgen_13273(p);
	(*p).blocks->data[result].nestedExceptStmts = ((NI16) (T3_));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, fillLoc__cgen_71)(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* a, tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r, tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ s) {
	{
		if (!((*a).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA3_;
		(*a).k = k;
		unsureAsgnRef((void**) (&(*a).lode), lode);
		(*a).storage = s;
		{
			if (!((*a).r == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA7_;
			unsureAsgnRef((void**) (&(*a).r), r);
		}
		LA7_: ;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, mangleName__cgen_646)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	result = (*s).loc.r;
	{
		NimStringDesc* T5_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
		if (!(result == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = mangle__ccgutils_112((*(*s).name).s);
		result = rope__ropes_109(T5_);
		add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_10));
		add__ropes_159(&result, (*(*(*m).g).graph).ifaces->data[(*s).Sup.itemId.module].uniqueName);
		add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3));
		T6_ = NIM_NIL;
		T6_ = rope__ropes_115(((NI64) ((*s).Sup.itemId.item)));
		add__ropes_159(&result, T6_);
		{
			NIM_BOOL T9_;
			NimStringDesc* T12_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
			T9_ = (NIM_BOOL)0;
			T9_ = hcrOn__cgen_43(m);
			if (!T9_) goto LA10_;
			add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3));
			T12_ = NIM_NIL;
			T12_ = mangle__ccgutils_112((*(*(*m).module).name).s);
			T13_ = NIM_NIL;
			T13_ = idOrSig__sighashes_2071(s, T12_, (&(*m).sigConflicts), (*(*m).g).config);
			add__ropes_159(&result, T13_);
		}
		LA10_: ;
		asgnRef((void**) (&(*s).loc.r), result);
		{
			NI T18_;
			if (!(*m).ndi.enabled) goto LA16_;
			asgnRef((void**) (&(*m).ndi.syms), (tySequence__ed0C0uAUZPhvw3RAc5hfYg*) incrSeqV3((TGenericSeq*)((*m).ndi.syms), (&NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_)));
			T18_ = (*m).ndi.syms->Sup.len++;
			asgnRef((void**) (&(*m).ndi.syms->data[T18_]), s);
		}
		LA16_: ;
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, fillProcLoc__cgen_11493)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
	sym = (*n)._kind_4.sym;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
		if (!((*sym).loc.k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = mangleName__cgen_646(m, sym);
		fillLoc__cgen_71((&(*sym).loc), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 7), n, T5_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 2));
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, useHeader__cgen_111)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	{
		NimStringDesc* str;
		if (!(((*sym).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 6))&15U)))!=0)) goto LA3_;
		str = getStr__ast_4611((*(*sym).annex).path);
		includeHeader__cgendata_214(m, str);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, cgFormatValue__cgen_151)(NimStringDesc** result, NimStringDesc* value) {
	unsureAsgnRef((void**) (&(*result)), resizeString((*result), (value ? value->Sup.len : 0) + 0));
appendString((*result), value);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isReloadable__cgen_6737)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc) {
	NIM_BOOL result;
	NIM_BOOL T1_;
{	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = hcrOn__cgen_43(m);
	if (!(T1_)) goto LA2_;
	T1_ = !((((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 38))&63U)))!=0));
	LA2_: ;
	result = T1_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, pop__ropes_180)(tySequence__UQWyowqEA29c6NZ9csQYyjXQ** s) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	NI L;
	NI T1_;
	result = NIM_NIL;
	T1_ = ((*s) ? (*s)->Sup.len : 0);
	L = (NI)(T1_ - ((NI) 1));
	result = (*s)->data[L];
	unsureAsgnRef((void**) (&(*s)), (tySequence__UQWyowqEA29c6NZ9csQYyjXQ*) setLengthSeqV2(((*s))?&((*s))->Sup:NIM_NIL, (&NTIseqLropeT__UQWyowqEA29c6NZ9csQYyjXQ_), ((NI) (L))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, cgFormatValue__cgen_147)(NimStringDesc** result, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* value) {
	{
		NimStringDesc* str;
		str = NIM_NIL;
		{
			tySequence__UQWyowqEA29c6NZ9csQYyjXQ* stack;
			if (!!((value == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA4_;
			stack = (tySequence__UQWyowqEA29c6NZ9csQYyjXQ*) newSeq((&NTIseqLropeT__UQWyowqEA29c6NZ9csQYyjXQ_), 1);
			asgnRef((void**) (&stack->data[0]), value);
			{
				while (1) {
					NI T8_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* it;
					T8_ = (stack ? stack->Sup.len : 0);
					if (!(((NI) 0) < T8_)) goto LA7;
					it = pop__ropes_180((&stack));
					{
						while (1) {
							NI T11_;
							if (!!(((*it).left == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA10;
							stack = (tySequence__UQWyowqEA29c6NZ9csQYyjXQ*) incrSeqV3((TGenericSeq*)(stack), (&NTIseqLropeT__UQWyowqEA29c6NZ9csQYyjXQ_));
							T11_ = stack->Sup.len++;
							asgnRef((void**) (&stack->data[T11_]), (*it).right);
							it = (*it).left;
						} LA10: ;
					}
					str = (*it).data;
					unsureAsgnRef((void**) (&(*result)), resizeString((*result), (str ? str->Sup.len : 0) + 0));
appendString((*result), str);
				} LA7: ;
			}
		}
		LA4_: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isImportedCppType__cgen_1312)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	NIM_BOOL result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* x;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NIM_BOOL T5_;
	result = (NIM_BOOL)0;
	x = skipTypes__ast_3723(t, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_15);
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = !(((*t).sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
	if (!(T2_)) goto LA3_;
	T2_ = (((*(*t).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
	LA3_: ;
	T1_ = T2_;
	if (T1_) goto LA4_;
	T5_ = (NIM_BOOL)0;
	T5_ = !(((*x).sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
	if (!(T5_)) goto LA6_;
	T5_ = (((*(*x).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
	LA6_: ;
	T1_ = T5_;
	LA4_: ;
	result = T1_;
	return result;
}
static N_INLINE(void, pushSafePoint)(TSafePoint* s) {
	(*s).prev = excHandler__system_2565;
	excHandler__system_2565 = s;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, typeNameOrLiteral__cgen_1813)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, NimStringDesc* literal) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = !(((*t).sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
		if (!(T4_)) goto LA5_;
		T4_ = (((*(*t).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 6))&63U)))!=0);
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA6_;
		T3_ = ((*(*t).sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 0));
		LA6_: ;
		if (!T3_) goto LA7_;
		useHeader__cgen_111(m, (*t).sym);
		result = (*(*t).sym).loc.r;
	}
	goto LA1_;
	LA7_: ;
	{
		result = rope__ropes_109(literal);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, detectStrVersion__cgen_490)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m) {
	NI result;
	result = (NI)0;
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* coreX60gensym68_;
		if (!((*(*m).g).strVersion == ((NI) 0))) goto LA3_;
		coreX60gensym68_ = getCompilerProc__magicsys_145((*(*m).g).graph, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_22));
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = (coreX60gensym68_ == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
			if (T7_) goto LA8_;
			T7_ = !(((*coreX60gensym68_).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 10)));
			LA8_: ;
			if (!T7_) goto LA9_;
			(*(*m).g).strVersion = ((NI) 1);
		}
		goto LA5_;
		LA9_: ;
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T12_;
			T12_ = getInt__ast_4593((*coreX60gensym68_).ast);
			(*(*m).g).strVersion = toInt__int495056_273(T12_);
		}
		LA5_: ;
	}
	LA3_: ;
	result = (*(*m).g).strVersion;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isActivated__cgen_26896)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = !(((*prc).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addForwardedProc__cgen_49)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc) {
	NI T1_;
	asgnRef((void**) (&(*(*m).g).forwardedProcs), (tySequence__ed0C0uAUZPhvw3RAc5hfYg*) incrSeqV3((TGenericSeq*)((*(*m).g).forwardedProcs), (&NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_)));
	T1_ = (*(*m).g).forwardedProcs->Sup.len++;
	asgnRef((void**) (&(*(*m).g).forwardedProcs->data[T1_]), prc);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA*, findPendingModule__cgen_56)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* result;
	result = NIM_NIL;
	{
		NI32 ms;
		if (!((*(*(*m).g).config).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 3))) goto LA3_;
		ms = (*s).Sup.itemId.module;
		result = (*(*m).g).modules->data[ms];
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* ms_2;
		ms_2 = getModule__astalgo_216(s);
		result = (*(*m).g).modules->data[(*ms_2).position];
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isGetProcAddr__cgen_25635)(tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* lib) {
	NIM_BOOL result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	n = (*lib).path;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32));
	if (!(T2_)) goto LA3_;
	T2_ = !(((*n).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = ((*(*n).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 26) || (*(*n).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25));
	LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genStringLiteralDataOnlyV1__cgen_516)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, NimStringDesc* s) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	tyArray__FKvM4FDhljtt88k8FkGthA T2_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T3_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_33));
	(void)(T1_);
	result = getTempName__cgen_428(m);
	nimZeroMem((void*)T2_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
	T2_[0] = result;
	T2_[1] = makeCString__msgs_50(s);
	T2_[2] = rope__ropes_115(((NI64) ((s ? s->Sup.len : 0))));
	T3_ = NIM_NIL;
	T3_ = percent___cgen_520(T2_, 3);
	add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 9))- 0], T3_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, cgFormatValue__cgen_154)(NimStringDesc** result, NI64 value) {
	addInt__stdZprivateZdigitsutils_167(result, value);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genStringLiteralV1__cgen_525)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	{
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
		if (!NIM_FALSE) goto LA3_;
		res = rawNewString(((NI) 80));
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_29));
		T5_ = NIM_NIL;
		T5_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_30));
		cgFormatValue__cgen_147((&res), T5_);
		res = resizeString(res, 11);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_31));
		result = rope__ropes_109(res);
	}
	goto LA1_;
	LA3_: ;
	{
		NI id;
		id = nodeTableTestOrSet__treetab_198((&(*m).dataCache), n, ((NI) ((*m).labels)));
		{
			NimStringDesc* res_2;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
			if (!(id == ((NI) ((*m).labels)))) goto LA9_;
			res_2 = rawNewString(((NI) 80));
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_29));
			T11_ = NIM_NIL;
			T11_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_30));
			cgFormatValue__cgen_147((&res_2), T11_);
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_32));
			T12_ = NIM_NIL;
			T12_ = genStringLiteralDataOnlyV1__cgen_516(m, (*n)._kind_3.strVal);
			cgFormatValue__cgen_147((&res_2), T12_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
			result = rope__ropes_109(res_2);
		}
		goto LA7_;
		LA9_: ;
		{
			NimStringDesc* res_3;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
			res_3 = rawNewString(((NI) 80));
			res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_29));
			T14_ = NIM_NIL;
			T14_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_30));
			cgFormatValue__cgen_147((&res_3), T14_);
			res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_32));
			cgFormatValue__cgen_147((&res_3), (*m).tmpBase);
			cgFormatValue__cgen_154((&res_3), ((NI64) (id)));
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
			result = rope__ropes_109(res_3);
		}
		LA7_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genStringLiteralDataOnlyV2__cgen_560)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, NimStringDesc* s, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result, NIM_BOOL isConst) {
	tyArray__InO6xIOhXMnkCXPnEYWwWg T1_;
	NimStringDesc* T2_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
	nimZeroMem((void*)T1_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
	T1_[0] = result;
	T1_[1] = rope__ropes_115(((NI64) ((s ? s->Sup.len : 0))));
	T1_[2] = makeCString__msgs_50(s);
	T2_ = NIM_NIL;
	{
		if (!isConst) goto LA5_;
		T2_ = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_35));
	}
	goto LA3_;
	LA5_: ;
	{
		T2_ = ((NimStringDesc*) NIM_NIL);
	}
	LA3_: ;
	T1_[3] = rope__ropes_109(T2_);
	T8_ = NIM_NIL;
	T8_ = percent___cgen_565(T1_, 4);
	add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 9))- 0], T8_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genStringLiteralV2__cgen_579)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL isConst) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	NI id;
	result = NIM_NIL;
	id = nodeTableTestOrSet__treetab_198((&(*m).dataCache), n, ((NI) ((*m).labels)));
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* pureLit;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
		tyArray__InO6xIOhXMnkCXPnEYWwWg T7_;
		NimStringDesc* T8_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
		if (!(id == ((NI) ((*m).labels)))) goto LA3_;
		pureLit = getTempName__cgen_428(m);
		genStringLiteralDataOnlyV2__cgen_560(m, (*n)._kind_3.strVal, pureLit, isConst);
		result = getTempName__cgen_428(m);
		T5_ = NIM_NIL;
		T5_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_36));
		(void)(T5_);
		T6_ = NIM_NIL;
		T6_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_37));
		(void)(T6_);
		nimZeroMem((void*)T7_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
		T7_[0] = result;
		T7_[1] = rope__ropes_115(((NI64) (((*n)._kind_3.strVal ? (*n)._kind_3.strVal->Sup.len : 0))));
		T7_[2] = pureLit;
		T8_ = NIM_NIL;
		{
			if (!isConst) goto LA11_;
			T8_ = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_35));
		}
		goto LA9_;
		LA11_: ;
		{
			T8_ = ((NimStringDesc*) NIM_NIL);
		}
		LA9_: ;
		T7_[3] = rope__ropes_109(T8_);
		T14_ = NIM_NIL;
		T14_ = percent___cgen_586(T7_, 4);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 9))- 0], T14_);
	}
	goto LA1_;
	LA3_: ;
	{
		tyArray__InO6xIOhXMnkCXPnEYWwWg T16_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
		NimStringDesc* T18_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
		result = getTempName__cgen_428(m);
		nimZeroMem((void*)T16_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
		T16_[0] = result;
		T16_[1] = rope__ropes_115(((NI64) (((*n)._kind_3.strVal ? (*n)._kind_3.strVal->Sup.len : 0))));
		T17_ = NIM_NIL;
		T17_ = rope__ropes_115(((NI64) (id)));
		T16_[2] = amp___ropes_128((*m).tmpBase, T17_);
		T18_ = NIM_NIL;
		{
			if (!isConst) goto LA21_;
			T18_ = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_35));
		}
		goto LA19_;
		LA21_: ;
		{
			T18_ = ((NimStringDesc*) NIM_NIL);
		}
		LA19_: ;
		T16_[3] = rope__ropes_109(T18_);
		T24_ = NIM_NIL;
		T24_ = percent___cgen_586(T16_, 4);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 9))- 0], T24_);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genStringLiteral__cgen_626)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	NI T1_;
	result = NIM_NIL;
	T1_ = (NI)0;
	T1_ = detectStrVersion__cgen_490(m);
	switch (T1_) {
	case ((NI) 0):
	case ((NI) 1):
	{
		result = genStringLiteralV1__cgen_525(m, n);
	}
	break;
	case ((NI) 2):
	{
		result = genStringLiteralV2__cgen_579(m, n, NIM_TRUE);
	}
	break;
	default:
	{
		liMessage__msgs_1128((*(*m).g).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_38), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_39, NIM_FALSE);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initLoc__cgen_66)(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* result, tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode, tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ s) {
	(*result).k = k;
	(*result).storage = s;
	unsureAsgnRef((void**) (&(*result).lode), lode);
	unsureAsgnRef((void**) (&(*result).r), ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL));
	(*result).flags = 0;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, rdLoc__cgen_435)(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	result = a.r;
	{
		tyArray__ts9cf9blICas1QWmw89bglZ7w T5_;
		if (!((a.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 0))&15U)))!=0)) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T5_[0] = result;
		result = percent___cgen_442(T5_, 1);
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, loadDynamicLib__cgen_25651)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* lib) {
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tmp;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T5_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
		if (!!((*lib).generated)) goto LA3_;
		(*lib).generated = NIM_TRUE;
		tmp = getTempName__cgen_428(m);
		asgnRef((void**) (&(*lib).name), tmp);
		nimZeroMem((void*)T5_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T5_[0] = tmp;
		T6_ = NIM_NIL;
		T6_ = percent___cgen_25669(T5_, 1);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], T6_);
		{
			tySequence__sM4lkSb7zS6F7OVMvW9cffQ* s;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* loadlib;
			NimStringDesc* res_3;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T27_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T32_;
			if (!((*(*lib).path).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) && (*(*lib).path).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22))) goto LA9_;
			s = NIM_NIL;
			libCandidates__pureZdynlib_37((*(*lib).path)._kind_3.strVal, (&s));
			liMessage__msgs_1128((*(*m).g).config, unknownLineInfo__lineinfos_284, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 95), (*(*lib).path)._kind_3.strVal, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_23, NIM_FALSE);
			loadlib = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
			{
				NI i;
				NI colontmp_;
				NI T12_;
				NI res;
				i = (NI)0;
				colontmp_ = (NI)0;
				T12_ = ((s ? s->Sup.len : 0)-1);
				colontmp_ = T12_;
				res = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
						NimStringDesc* res_2;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
						if (!(res <= colontmp_)) goto LA14;
						i = res;
						(*m).labels += ((NI) 1);
						{
							if (!(((NI) 0) < i)) goto LA17_;
							add__ropes_162(&loadlib, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_25));
						}
						LA17_: ;
						n = newStrNode__ast_3801(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20), s->data[i]);
						(*n).info = (*(*lib).path).info;
						res_2 = rawNewString(((NI) 80));
						res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
						cgFormatValue__cgen_147((&res_2), tmp);
						res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
						T19_ = NIM_NIL;
						T19_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_28));
						cgFormatValue__cgen_147((&res_2), T19_);
						res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
						T20_ = NIM_NIL;
						T20_ = genStringLiteral__cgen_626(m, n);
						cgFormatValue__cgen_147((&res_2), T20_);
						res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_41));
						{
							if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA23_;
							res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
						}
						LA23_: ;
						T25_ = NIM_NIL;
						T25_ = rope__ropes_109(res_2);
						add__ropes_159(&loadlib, T25_);
						res += ((NI) 1);
					} LA14: ;
				}
			}
			res_3 = rawNewString(((NI) 80));
			res_3 = resizeString(res_3, 6);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_42));
			cgFormatValue__cgen_147((&res_3), loadlib);
			res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_43));
			T26_ = NIM_NIL;
			T26_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_44));
			cgFormatValue__cgen_147((&res_3), T26_);
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T27_ = NIM_NIL;
			T27_ = genStringLiteral__cgen_626(m, (*lib).path);
			cgFormatValue__cgen_147((&res_3), T27_);
			res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
			{
				if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA30_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA30_: ;
			T32_ = NIM_NIL;
			T32_ = rope__ropes_109(res_3);
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 18))- 0], T32_);
		}
		goto LA7_;
		LA9_: ;
		{
			tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw dest;
			NimStringDesc* res_4;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T34_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T35_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T40_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T41_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T42_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T43_;
			NimStringDesc* res_5;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T44_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T45_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T46_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T47_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T52_;
			p = newProc__cgendata_278(((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL), m);
			(*p).options &= ~(((NU32)1) << ((((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 17)) & 31));
			(*p).flags |= ((NU8)1)<<((((tyEnum_TCProcFlag__Iv1wQAvkoMCW3v9cTnZWvJw) 6)) & 7);
			nimZeroMem((void*)(&dest), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLoc__cgen_66((&dest), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 1), (*lib).path, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 2));
			dest.r = getTempName__cgen_428(m);
			res_4 = rawNewString(((NI) 80));
			T34_ = NIM_NIL;
			T34_ = getTypeDesc__cgen_6662(m, (*(*lib).path).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
			cgFormatValue__cgen_147((&res_4), T34_);
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_13));
			T35_ = NIM_NIL;
			T35_ = rdLoc__cgen_435(dest);
			cgFormatValue__cgen_147((&res_4), T35_);
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
			{
				if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA38_;
				res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA38_: ;
			T40_ = NIM_NIL;
			T40_ = rope__ropes_109(res_4);
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 18))- 0], T40_);
			expr__cgen_11525(p, (*lib).path, (&dest));
			T41_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T41_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], (*T41_));
			T42_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T42_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 1));
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 18))- 0], (*T42_));
			T43_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T43_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 18))- 0], (*T43_));
			res_5 = rawNewString(((NI) 80));
			res_5 = resizeString(res_5, 6);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_42));
			cgFormatValue__cgen_147((&res_5), tmp);
			res_5 = resizeString(res_5, 3);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
			T44_ = NIM_NIL;
			T44_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_28));
			cgFormatValue__cgen_147((&res_5), T44_);
			res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T45_ = NIM_NIL;
			T45_ = rdLoc__cgen_435(dest);
			cgFormatValue__cgen_147((&res_5), T45_);
			res_5 = resizeString(res_5, 4);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_47));
			T46_ = NIM_NIL;
			T46_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_44));
			cgFormatValue__cgen_147((&res_5), T46_);
			res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T47_ = NIM_NIL;
			T47_ = rdLoc__cgen_435(dest);
			cgFormatValue__cgen_147((&res_5), T47_);
			res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
			{
				if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA50_;
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA50_: ;
			T52_ = NIM_NIL;
			T52_ = rope__ropes_109(res_5);
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 18))- 0], T52_);
		}
		LA7_: ;
	}
	LA3_: ;
	{
		if (!((*lib).name == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA55_;
		internalErrorImpl__msgs_1441((*(*m).g).config, unknownLineInfo__lineinfos_284, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_48), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_49);
	}
	LA55_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, mangleDynLibProc__cgen_3812)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	{
		if (!(((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 18))&63U)))!=0)) goto LA3_;
		result = rope__ropes_109((*(*sym).name).s);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym5982_;
		NimStringDesc* T6_;
		NimStringDesc* T7_;
		xX60gensym5982_ = sym;
		T6_ = NIM_NIL;
		T6_ = dollar___systemZdollars_3((NI)((NI)((NU64)(((NI) ((*xX60gensym5982_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym5982_).Sup.itemId.item))));
		T7_ = NIM_NIL;
		T7_ = nsuFormatSingleElem(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_50), T6_);
		result = rope__ropes_109(T7_);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initLocExpr__cgen_11548)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* result) {
	initLoc__cgen_66(result, ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0), e, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	expr__cgen_11525(p, e, result);
}
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x) {
	addInt__stdZprivateZdigitsutils_167(result, ((NI64) (x)));
}
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_625)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = resizeString(result, (info.Field0 ? info.Field0->Sup.len : 0) + 0);
appendString(result, info.Field0);
	{
		if (!(((NI) 0) < info.Field1)) goto LA3_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		addInt__stdZprivateZdigitsutils_189((&result), info.Field1);
		{
			if (!(((NI) 0) < (NI)(info.Field2 + ((NI) 1)))) goto LA7_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			addInt__stdZprivateZdigitsutils_189((&result), (NI)(info.Field2 + ((NI) 1)));
		}
		LA7_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
	}
	LA3_: ;
	return result;
}
static N_INLINE(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, t__cgen_85)(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	result = NIM_NIL;
	{
		if (!((*a.lode).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA3_;
		result = (*(*a.lode)._kind_4.sym).typ;
	}
	goto LA1_;
	LA3_: ;
	{
		result = (*a.lode).typ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, symInDynamicLib__cgen_25776)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* lib;
	NIM_BOOL isCall;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* extname;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tmp;
	tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T47_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T48_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T49_;
	lib = (*sym).annex;
	isCall = isGetProcAddr__cgen_25635(lib);
	extname = (*sym).loc.r;
	{
		if (!!(isCall)) goto LA3_;
		loadDynamicLib__cgen_25651(m, lib);
	}
	LA3_: ;
	tmp = mangleDynLibProc__cgen_3812(sym);
	asgnRef((void**) (&(*sym).loc.r), tmp);
	asgnRef((void**) (&(*(*sym).typ).sym), ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
	(*m).labels += ((NI) 2);
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* params;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* load;
		tyArray__InO6xIOhXMnkCXPnEYWwWg T15_;
		NimStringDesc* T16_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* last;
		NimStringDesc* idx;
		if (!isCall) goto LA7_;
		n = (*lib).path;
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548((*m).initProc, (*n)._kind_6.sons->data[((NI) 0)], (&a));
		T9_ = NIM_NIL;
		T9_ = rdLoc__cgen_435(a);
		params = amp___ropes_140(T9_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		{
			NI i;
			NI colontmp_;
			NI T11_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			T11_ = (NI)0;
			T11_ = len__ast_3155(n);
			colontmp_ = (NI)(T11_ - ((NI) 1));
			i_2 = ((NI) 1);
			{
				while (1) {
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
					if (!(i_2 < colontmp_)) goto LA13;
					i = i_2;
					initLocExpr__cgen_11548((*m).initProc, (*n)._kind_6.sons->data[i], (&a));
					T14_ = NIM_NIL;
					T14_ = rdLoc__cgen_435(a);
					add__ropes_159(&params, T14_);
					add__ropes_162(&params, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
					i_2 += ((NI) 1);
				} LA13: ;
			}
		}
		nimZeroMem((void*)T15_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
		T15_[0] = tmp;
		T15_[1] = getTypeDesc__cgen_6662(m, (*sym).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
		T15_[2] = params;
		T16_ = NIM_NIL;
		T16_ = dollar___ropes_250(extname);
		T15_[3] = makeCString__msgs_50(T16_);
		load = percent___cgen_25800(T15_, 4);
		last = lastSon__ast_4833(n);
		{
			if (!((*last).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58))) goto LA19_;
			last = (*last)._kind_6.sons->data[((NI) 1)];
		}
		LA19_: ;
		{
			NimStringDesc* argX60gensym5987_;
			if (!!(((*last).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20)))) goto LA23_;
			argX60gensym5987_ = toFileLineCol__msgs_625(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_52);
			internalErrorImpl__msgs_1441((*(*m).g).config, unknownLineInfo__lineinfos_284, argX60gensym5987_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_52);
		}
		LA23_: ;
		idx = (*last)._kind_3.strVal;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T29_;
			if (!((idx ? idx->Sup.len : 0) == ((NI) 0))) goto LA27_;
			T29_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T29_ = s__cgendata_225((*m).initProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			add__ropes_159(T29_, load);
		}
		goto LA25_;
		LA27_: ;
		{
			NIM_BOOL T31_;
			T31_ = (NIM_BOOL)0;
			T31_ = ((idx ? idx->Sup.len : 0) == ((NI) 1));
			if (!(T31_)) goto LA32_;
			T31_ = (((NU8)(idx->data[((NI) 0)])) >= ((NU8)(48)) && ((NU8)(idx->data[((NI) 0)])) <= ((NU8)(57)));
			LA32_: ;
			if (!T31_) goto LA33_;
			add__ropes_159(&(*m).extensionLoaders[(((NU8)(idx->data[((NI) 0)])))- 48], load);
		}
		goto LA25_;
		LA33_: ;
		{
			NimStringDesc* T36_;
			T36_ = NIM_NIL;
			T36_ = rawNewString((idx ? idx->Sup.len : 0) + 13);
appendString(T36_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_53));
appendString(T36_, idx);
			internalErrorImpl__msgs_1441((*(*m).g).config, (*sym).info, T36_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_54);
		}
		LA25_: ;
	}
	goto LA5_;
	LA7_: ;
	{
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T39_;
		NimStringDesc* T40_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T41_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T46_;
		res = rawNewString(((NI) 80));
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_6));
		cgFormatValue__cgen_147((&res), tmp);
		res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_55));
		T38_ = NIM_NIL;
		T38_ = getTypeDesc__cgen_6662(m, (*sym).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
		cgFormatValue__cgen_147((&res), T38_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_56));
		T39_ = NIM_NIL;
		T39_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_57));
		cgFormatValue__cgen_147((&res), T39_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		cgFormatValue__cgen_147((&res), (*lib).name);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		T40_ = NIM_NIL;
		T40_ = dollar___ropes_250(extname);
		T41_ = NIM_NIL;
		T41_ = makeCString__msgs_50(T40_);
		cgFormatValue__cgen_147((&res), T41_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
		{
			if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA44_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA44_: ;
		T46_ = NIM_NIL;
		T46_ = rope__ropes_109(res);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 18))- 0], T46_);
	}
	LA5_: ;
	nimZeroMem((void*)T47_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
	T47_[0] = (*sym).loc.r;
	T48_ = NIM_NIL;
	T48_ = t__cgen_85((*sym).loc);
	T47_[1] = getTypeDesc__cgen_6662(m, T48_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
	T49_ = NIM_NIL;
	T49_ = percent___cgen_25841(T47_, 2);
	add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], T49_);
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getCFile__cgen_129)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m) {
	NimStringDesc* result;
	NimStringDesc* ext;
	NimStringDesc* T13_;
	NimStringDesc* T14_;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*(*(*m).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
		if (T3_) goto LA4_;
		T3_ = (((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		ext = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_58));
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = ((*(*(*m).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 4));
		if (T8_) goto LA9_;
		T8_ = (((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 33))&63U)))!=0);
		LA9_: ;
		if (!T8_) goto LA10_;
		ext = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_59));
	}
	goto LA1_;
	LA10_: ;
	{
		ext = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_60));
	}
	LA1_: ;
	T13_ = NIM_NIL;
	T13_ = mangleModuleName__modulepaths_32((*(*m).g).config, (*m).cfilename);
	T14_ = NIM_NIL;
	T14_ = completeCfilePath__extccomp_715((*(*m).g).config, T13_, NIM_TRUE);
	result = noschangeFileExt(T14_, ext);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getModuleDllPath__cgen_131)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	NimStringDesc* T1_;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T2_;
	NimStringDesc* dir;
	NimStringDesc* name;
	NimStringDesc* ext;
	NimStringDesc* filename;
	tyArray__nHXaesL0DJZHyVS07ARPRA T3_;
	NimStringDesc* T4_;
	NimStringDesc* T5_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = getCFile__cgen_129(m);
	nimZeroMem((void*)(&T2_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	splitFile__pathutils_27(T1_, (&T2_));
	dir = NIM_NIL;
	dir = T2_.Field0;
	name = NIM_NIL;
	name = T2_.Field1;
	ext = NIM_NIL;
	ext = T2_.Field2;
	nimZeroMem((void*)T3_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
	T4_ = NIM_NIL;
	T4_ = rawNewString((name ? name->Sup.len : 0) + (ext ? ext->Sup.len : 0) + 0);
appendString(T4_, name);
appendString(T4_, ext);
	T3_[0] = T4_;
	filename = nsuFormatOpenArray(OS__platform_518[((*(*(*m).g).config).target.targetOS)- 1].Field2, T3_, 1);
	T5_ = NIM_NIL;
	T5_ = rawNewString((dir ? dir->Sup.len : 0) + (filename ? filename->Sup.len : 0) + 1);
appendString(T5_, dir);
appendString(T5_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_61));
appendString(T5_, filename);
	result = makeCString__msgs_50(T5_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getModuleDllPath__cgen_142)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	result = getModuleDllPath__cgen_131((*(*m).g).modules->data[(*s).Sup.itemId.module]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, symInDynamicLibPartial__cgen_25887)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	asgnRef((void**) (&(*sym).loc.r), mangleDynLibProc__cgen_3812(sym));
	asgnRef((void**) (&(*(*sym).typ).sym), ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isNonReloadable__cgen_6745)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc) {
	NIM_BOOL result;
	NIM_BOOL T1_;
{	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = hcrOn__cgen_43(m);
	if (!(T1_)) goto LA2_;
	T1_ = (((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 38))&63U)))!=0);
	LA2_: ;
	result = T1_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ, mapSetType__cgen_1223)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ) {
	tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ result;
	NI64 T1_;
	result = (tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ)0;
	T1_ = (NI64)0;
	T1_ = getSize__types_3388(conf, typ);
	switch (((NI) (T1_))) {
	case ((NI) 1):
	{
		result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 4);
	}
	break;
	case ((NI) 2):
	{
		result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 5);
	}
	break;
	case ((NI) 4):
	{
		result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 6);
	}
	break;
	case ((NI) 8):
	{
		result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 7);
	}
	break;
	default:
	{
		result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 17);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ, mapType__cgen_1227)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind) {
	tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ result;
{	result = (tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ)0;
	switch ((*typ).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 0):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 7):
	{
		result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 0);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1):
	{
		result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 2);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2):
	{
		result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 1);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 5):
	{
		result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 20);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 19):
	{
		result = mapSetType__cgen_1223(conf, typ);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48):
	{
		{
			if (!(kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3))) goto LA9_;
			result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 17);
		}
		goto LA7_;
		LA9_: ;
		{
			result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 19);
		}
		LA7_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 49):
	{
		result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 17);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18):
	{
		result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 19);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 52) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 53):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T19_;
		{
			if (!!((((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 10))&63U)))!=0))) goto LA17_;
			failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_66));
		}
		LA17_: ;
		T19_ = NIM_NIL;
		T19_ = lastSon__ast_3731(typ);
		result = mapType__cgen_1227(conf, T19_, kind);
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 10):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 13):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 15):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 4):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 55):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T21_;
		T21_ = NIM_NIL;
		T21_ = lastSon__ast_3731(typ);
		result = mapType__cgen_1227(conf, T21_, kind);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14):
	{
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T25_;
			NIM_BOOL T26_;
			T25_ = firstOrd__types_1406(conf, typ);
			T26_ = (NIM_BOOL)0;
			T26_ = lt___int495056_905(T25_, IL64(0));
			if (!T26_) goto LA27_;
			result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 6);
		}
		goto LA23_;
		LA27_: ;
		{
			NI64 T30_;
			T30_ = (NI64)0;
			T30_ = getSize__types_3388(conf, typ);
			switch (((NI) (T30_))) {
			case ((NI) 1):
			{
				result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 13);
			}
			break;
			case ((NI) 2):
			{
				result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 14);
			}
			break;
			case ((NI) 4):
			{
				result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 6);
			}
			break;
			case ((NI) 8):
			{
				result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 7);
			}
			break;
			default:
			{
				result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 6);
			}
			break;
			}
		}
		LA23_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 20):
	{
		result = mapType__cgen_1227(conf, (*typ).sons->data[((NI) 0)], kind);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* base;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T38_;
		T38_ = NIM_NIL;
		T38_ = lastSon__ast_3731(typ);
		base = skipTypes__ast_3723(T38_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_67);
		switch ((*base).kind) {
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27):
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48):
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 49):
		{
			result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 18);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 19):
		{
			{
				tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ T43_;
				T43_ = (tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ)0;
				T43_ = mapSetType__cgen_1223(conf, base);
				if (!(T43_ == ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 17))) goto LA44_;
				result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 18);
			}
			goto LA41_;
			LA44_: ;
			{
				result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 20);
			}
			LA41_: ;
		}
		break;
		default:
		{
			result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 20);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 26):
	{
		result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 20);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
	{
		result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 22);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25):
	{
		{
			if (!!(((*typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9)))) goto LA53_;
			result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 23);
		}
		goto LA51_;
		LA53_: ;
		{
			result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 19);
		}
		LA51_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
	{
		result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 21);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29):
	{
		result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 24);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44):
	{
		result = ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) ((NI)((NI)((*typ).kind - ((NI) 31)) + ((NI) 3))));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60):
	{
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T64_;
			if (!!(((*typ).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA62_;
			T64_ = NIM_NIL;
			T64_ = lastSon__ast_3731(typ);
			result = mapType__cgen_1227(conf, T64_, kind);
		}
		goto LA60_;
		LA62_: ;
		{
			{
				NimStringDesc* T70_;
				if (!NIM_TRUE) goto LA68_;
				T70_ = NIM_NIL;
				T70_ = rawNewString((reprEnum((NI)(*typ).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)) ? reprEnum((NI)(*typ).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_))->Sup.len : 0) + 39);
appendString(T70_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_68));
appendString(T70_, reprEnum((NI)(*typ).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)));
				failedAssertImpl__systemZassertions_56(T70_);
			}
			LA68_: ;
		}
		LA60_: ;
	}
	break;
	default:
	{
		{
			NimStringDesc* T76_;
			if (!NIM_TRUE) goto LA74_;
			T76_ = NIM_NIL;
			T76_ = rawNewString((reprEnum((NI)(*typ).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)) ? reprEnum((NI)(*typ).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_))->Sup.len : 0) + 39);
appendString(T76_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_69));
appendString(T76_, reprEnum((NI)(*typ).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)));
			failedAssertImpl__systemZassertions_56(T76_);
		}
		LA74_: ;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isObjLackingTypeField__cgen_1337)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	NIM_BOOL T4_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17));
	if (!(T1_)) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T4_ = (NIM_BOOL)0;
	T4_ = (((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 2))&63U)))!=0);
	if (!(T4_)) goto LA5_;
	T4_ = ((*typ).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
	LA5_: ;
	T3_ = T4_;
	if (T3_) goto LA6_;
	T3_ = isPureObject__types_132(typ);
	LA6_: ;
	T1_ = T3_;
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInvalidReturnType__cgen_1353)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, NIM_BOOL isProc) {
	NIM_BOOL result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* rettype;
	NIM_BOOL isAllowedCall;
{	result = (NIM_BOOL)0;
	rettype = typ;
	isAllowedCall = NIM_TRUE;
	{
		if (!isProc) goto LA3_;
		rettype = (*rettype).sons->data[((NI) 0)];
		isAllowedCall = ((545 &((NU16)1<<((NU)((*typ).callConv)&15U)))!=0);
	}
	LA3_: ;
	{
		NIM_BOOL T7_;
		NIM_BOOL T9_;
		NI64 T11_;
		T7_ = (NIM_BOOL)0;
		T7_ = (rettype == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
		if (T7_) goto LA8_;
		T9_ = (NIM_BOOL)0;
		T9_ = isAllowedCall;
		if (!(T9_)) goto LA10_;
		T11_ = (NI64)0;
		T11_ = getSize__types_3388(conf, rettype);
		T9_ = (((NI64) ((NI)((*conf).target.floatSize * ((NI) 3)))) < T11_);
		LA10_: ;
		T7_ = T9_;
		LA8_: ;
		if (!T7_) goto LA12_;
		result = NIM_TRUE;
	}
	goto LA5_;
	LA12_: ;
	{
		tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ T15_;
		T15_ = (tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ)0;
		T15_ = mapType__cgen_1227(conf, rettype, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 11));
		switch (T15_) {
		case ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 17):
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T17_;
			T17_ = NIM_NIL;
			T17_ = skipTypes__ast_3723(rettype, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_67);
			result = !(((*T17_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*T17_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47) || (*T17_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22) || (*T17_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21)));
		}
		break;
		case ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 19):
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
			NIM_BOOL T25_;
			NIM_BOOL T27_;
			NIM_BOOL T29_;
			t = skipTypes__ast_3723(rettype, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_67);
			{
				NIM_BOOL T21_;
				T21_ = (NIM_BOOL)0;
				T21_ = isImportedCppType__cgen_1312(rettype);
				if (T21_) goto LA22_;
				T21_ = isImportedCppType__cgen_1312(t);
				LA22_: ;
				if (!T21_) goto LA23_;
				result = NIM_FALSE;
				goto BeforeRet_;
			}
			LA23_: ;
			T25_ = (NIM_BOOL)0;
			T25_ = containsGarbageCollectedRef__types_612(t);
			if (T25_) goto LA26_;
			T27_ = (NIM_BOOL)0;
			T27_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17));
			if (!(T27_)) goto LA28_;
			T29_ = (NIM_BOOL)0;
			T29_ = isObjLackingTypeField__cgen_1337(t);
			T27_ = !(T29_);
			LA28_: ;
			T25_ = T27_;
			LA26_: ;
			result = T25_;
		}
		break;
		default:
		{
			result = NIM_FALSE;
		}
		break;
		}
	}
	LA5_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isCompileTimeOnly__types_3592)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isKeyword__cgen_636)(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* w) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	switch ((*w).id) {
	case ((NI) 227) ... ((NI) 292):
	case ((NI) 4) ... ((NI) 66):
	case ((NI) 147):
	{
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	break;
	default:
	{
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, mangleParamName__cgen_658)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	result = (*s).loc.r;
	{
		NimStringDesc* res;
		if (!(result == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA3_;
		res = mangle__ccgutils_112((*(*s).name).s);
		{
			NIM_BOOL T7_;
			NIM_BOOL T8_;
			T7_ = (NIM_BOOL)0;
			T8_ = (NIM_BOOL)0;
			T8_ = hcrOn__cgen_43(m);
			if (T8_) goto LA9_;
			T8_ = isKeyword__cgen_636((*s).name);
			LA9_: ;
			T7_ = T8_;
			if (T7_) goto LA10_;
			T7_ = contains__cgen_720((*(*(*m).g).config).cppDefines, res);
			LA10_: ;
			if (!T7_) goto LA11_;
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_72));
		}
		LA11_: ;
		result = rope__ropes_109(res);
		asgnRef((void**) (&(*s).loc.r), result);
		{
			NI T17_;
			if (!(*m).ndi.enabled) goto LA15_;
			asgnRef((void**) (&(*m).ndi.syms), (tySequence__ed0C0uAUZPhvw3RAc5hfYg*) incrSeqV3((TGenericSeq*)((*m).ndi.syms), (&NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_)));
			T17_ = (*m).ndi.syms->Sup.len++;
			asgnRef((void**) (&(*m).ndi.syms->data[T17_]), s);
		}
		LA15_: ;
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ, paramStorageLoc__cgen_3501)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* param) {
	tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ result;
	result = (tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ)0;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T3_;
		T3_ = NIM_NIL;
		T3_ = skipTypes__ast_3723((*param).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_73);
		if (!!(((*T3_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16) || (*T3_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27) || (*T3_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48)))) goto LA4_;
		result = ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 2);
	}
	goto LA1_;
	LA4_: ;
	{
		result = ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, cacheGetType__cgen_1380)(tyObject_Table__dHMrTjFDXaK9bwjVxsGCupQ tab, tyArray__qtqsWM5aXmcpMIVmvq3kAA sig) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	result = getOrDefault__cgen_1450(tab, sig);
	return result;
}
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c) {
	(*dest).data[(*dest).Sup.len] = c;
	(*dest).data[(NI)((*dest).Sup.len + ((NI) 1))] = 0;
	(*dest).Sup.len += ((NI) 1);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, typeName__cgen_1161)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ_2;
	result = NIM_NIL;
	typ_2 = skipTypes__ast_3723(typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_15);
	{
		NIM_BOOL T3_;
		NimStringDesc* T7_;
		NimStringDesc* T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*typ_2).sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((*typ_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17) || (*typ_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14));
		LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = NIM_NIL;
		T8_ = NIM_NIL;
		T8_ = mangle__ccgutils_112((*(*(*typ_2).sym).name).s);
		T7_ = rawNewString((reprEnum((NI)(*typ_2).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)) ? reprEnum((NI)(*typ_2).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_))->Sup.len : 0) + (T8_ ? T8_->Sup.len : 0) + 1);
appendString(T7_, reprEnum((NI)(*typ_2).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)));
appendChar(T7_, 95);
appendString(T7_, T8_);
		result = rope__ropes_109(T7_);
	}
	goto LA1_;
	LA5_: ;
	{
		result = rope__ropes_109(reprEnum((NI)(*typ_2).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getTypeName__cgen_1179)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyArray__qtqsWM5aXmcpMIVmvq3kAA sig) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ_2;
{	result = NIM_NIL;
	t = typ;
	{
		while (1) {
			{
				NIM_BOOL T5_;
				T5_ = (NIM_BOOL)0;
				T5_ = !(((*t).sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
				if (!(T5_)) goto LA6_;
				T5_ = !(((192 & (*(*t).sym).flags) == 0));
				LA6_: ;
				if (!T5_) goto LA7_;
				result = (*(*t).sym).loc.r;
				goto BeforeRet_;
			}
			LA7_: ;
			{
				if (!((TM__9bddtAaa9cYLwzzzlT9aJ5CKw_15[(NU)((*t).kind)>>3] &(1U<<((NU)((*t).kind)&7U)))!=0)) goto LA11_;
				t = lastSon__ast_3731(t);
			}
			goto LA9_;
			LA11_: ;
			{
				goto LA1;
			}
			LA9_: ;
		}
	} LA1: ;
	{
		if (!((*typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 4) || (*typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46) || (*typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45))) goto LA16_;
		typ_2 = lastSon__ast_3731(typ);
	}
	goto LA14_;
	LA16_: ;
	{
		typ_2 = typ;
	}
	LA14_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
		NimStringDesc* T24_;
		if (!((*typ_2).loc.r == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA21_;
		T23_ = NIM_NIL;
		T23_ = typeName__cgen_1161(typ_2);
		T24_ = NIM_NIL;
		T24_ = dollar___modulegraphs_8985(sig);
		asgnRef((void**) (&(*typ_2).loc.r), amp___ropes_140(T23_, T24_));
	}
	goto LA19_;
	LA21_: ;
	{
	}
	LA19_: ;
	result = (*typ_2).loc.r;
	{
		NimStringDesc* T30_;
		if (!(result == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA28_;
		T30_ = NIM_NIL;
		T30_ = rawNewString((reprEnum((NI)(*typ_2).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)) ? reprEnum((NI)(*typ_2).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_))->Sup.len : 0) + 13);
appendString(T30_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_75));
appendString(T30_, reprEnum((NI)(*typ_2).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)));
		internalErrorImpl__msgs_1441((*(*m).g).config, unknownLineInfo__lineinfos_284, T30_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_76);
	}
	LA28_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isImportedType__cgen_1301)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = !(((*t).sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
	if (!(T1_)) goto LA2_;
	T1_ = (((*(*t).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 6))&63U)))!=0);
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addForwardStructFormat__cgen_3112)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* structOrUnion, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* typename_0) {
	{
		NIM_BOOL T3_;
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T7_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*(*(*m).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
		if (T3_) goto LA4_;
		T3_ = (((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		nimZeroMem((void*)T7_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T7_[0] = structOrUnion;
		T7_[1] = typename_0;
		T8_ = NIM_NIL;
		T8_ = percent___cgen_3124(T7_, 2);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 3))- 0], T8_);
	}
	goto LA1_;
	LA5_: ;
	{
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T10_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
		nimZeroMem((void*)T10_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T10_[0] = structOrUnion;
		T10_[1] = typename_0;
		T11_ = NIM_NIL;
		T11_ = percent___cgen_3129(T10_, 2);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 3))- 0], T11_);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, structOrUnion__cgen_3102)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* cachedUnion;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* cachedStruct;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t_2;
	result = NIM_NIL;
	cachedUnion = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_77));
	cachedStruct = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_78));
	t_2 = skipTypes__ast_3723(t, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_79);
	{
		if (!(((*t_2).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 1))&63U)))!=0)) goto LA3_;
		result = cachedUnion;
	}
	goto LA1_;
	LA3_: ;
	{
		result = cachedStruct;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pushType__cgen_3070)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ) {
	NI T9_;
{	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (((*m).typeStack ? (*m).typeStack->Sup.len : 0)-1);
		colontmp_ = T2_;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA4;
				i = res;
				{
					if (!((*m).typeStack->data[i] == typ)) goto LA7_;
					goto BeforeRet_;
				}
				LA7_: ;
				res += ((NI) 1);
			} LA4: ;
		}
	}
	asgnRef((void**) (&(*m).typeStack), (tySequence__vKogasEnJSPhbQmA8r4Y9aA*) incrSeqV3((TGenericSeq*)((*m).typeStack), (&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_)));
	T9_ = (*m).typeStack->Sup.len++;
	asgnRef((void**) (&(*m).typeStack->data[T9_]), typ);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getTypeForward__cgen_3141)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyArray__qtqsWM5aXmcpMIVmvq3kAA sig) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* concrete;
{	result = NIM_NIL;
	result = cacheGetType__cgen_1380((*m).forwTypeCache, sig);
	{
		if (!!((result == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	result = getTypePre__cgen_3089(m, typ, sig);
	{
		if (!!((result == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA7_;
		goto BeforeRet_;
	}
	LA7_: ;
	concrete = skipTypes__ast_3723(typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
	switch ((*concrete).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17):
	{
		result = getTypeName__cgen_1179(m, typ, sig);
		X5BX5Deq___cgen_1895((&(*m).forwTypeCache), sig, result);
		{
			NIM_BOOL T12_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
			T12_ = (NIM_BOOL)0;
			T12_ = isImportedType__cgen_1301(concrete);
			if (!!(T12_)) goto LA13_;
			T15_ = NIM_NIL;
			T15_ = structOrUnion__cgen_3102(typ);
			addForwardStructFormat__cgen_3112(m, T15_, result);
		}
		goto LA10_;
		LA13_: ;
		{
			pushType__cgen_3070(m, concrete);
		}
		LA10_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T19_;
			T19_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T19_ = X5BX5D___cgen_3258((&(*m).forwTypeCache), sig);
			if (!!(((*T19_) == result))) goto LA20_;
			failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_80));
		}
		LA20_: ;
	}
	break;
	default:
	{
		NimStringDesc* T23_;
		T23_ = NIM_NIL;
		T23_ = rawNewString((reprEnum((NI)(*typ).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)) ? reprEnum((NI)(*typ).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_))->Sup.len : 0) + 16);
appendString(T23_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_81));
appendString(T23_, reprEnum((NI)(*typ).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)));
appendChar(T23_, 41);
		internalErrorImpl__msgs_1441((*(*m).g).config, unknownLineInfo__lineinfos_284, T23_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_82);
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, seqStar__cgen_3134)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m) {
	NimStringDesc* result;
	result = NIM_NIL;
	{
		if (!(((*(*(*m).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0)) goto LA3_;
		result = ((NimStringDesc*) NIM_NIL);
	}
	goto LA1_;
	LA3_: ;
	{
		result = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_90));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getTypeDescWeak__cgen_3345)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* check, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* etB;
	result = NIM_NIL;
	etB = skipTypes__ast_3723(t, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
	switch ((*etB).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18):
	{
		{
			NIM_BOOL T4_;
			T4_ = (NIM_BOOL)0;
			T4_ = isImportedCppType__cgen_1312(etB);
			if (!(T4_)) goto LA5_;
			T4_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11));
			LA5_: ;
			if (!T4_) goto LA6_;
			result = getTypeDescAux__cgen_1332(m, t, check, kind);
		}
		goto LA2_;
		LA6_: ;
		{
			tyArray__qtqsWM5aXmcpMIVmvq3kAA T9_;
			nimZeroMem((void*)T9_, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
			hashType__sighashes_473(t, (*(*m).g).config, 2, T9_);
			result = getTypeForward__cgen_3141(m, t, T9_);
			pushType__cgen_3070(m, t);
		}
		LA2_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
	{
		tyArray__qtqsWM5aXmcpMIVmvq3kAA sig;
		nimZeroMem((void*)sig, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
		hashType__sighashes_473(t, (*(*m).g).config, 2, sig);
		{
			if (!(((*(*(*m).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0)) goto LA13_;
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T17_;
				T17_ = NIM_NIL;
				T17_ = skipTypes__ast_3723((*etB).sons->data[((NI) 0)], TM__9bddtAaa9cYLwzzzlT9aJ5CKw_67);
				if (!((*T17_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 3))) goto LA18_;
				internalErrorImpl__msgs_1441((*(*m).g).config, unknownLineInfo__lineinfos_284, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_83), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_84);
			}
			LA18_: ;
			result = cacheGetType__cgen_1380((*m).forwTypeCache, sig);
			{
				if (!(result == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA22_;
				result = getTypeName__cgen_1179(m, t, sig);
				{
					NIM_BOOL T26_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T29_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* payload;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T30_;
					T26_ = (NIM_BOOL)0;
					T26_ = isImportedType__cgen_1301(t);
					if (!!(T26_)) goto LA27_;
					X5BX5Deq___cgen_1895((&(*m).forwTypeCache), sig, result);
					T29_ = NIM_NIL;
					T29_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_85));
					addForwardStructFormat__cgen_3112(m, T29_, result);
					payload = amp___ropes_140(result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_86));
					T30_ = NIM_NIL;
					T30_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_85));
					addForwardStructFormat__cgen_3112(m, T30_, payload);
				}
				LA27_: ;
			}
			LA22_: ;
			{
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T33_;
				NimStringDesc* res;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T36_;
				T33_ = NIM_NIL;
				T33_ = cacheGetType__cgen_1380((*m).typeCache, sig);
				if (!(T33_ == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA34_;
				X5BX5Deq___cgen_1895((&(*m).typeCache), sig, result);
				res = rawNewString(((NI) 80));
				res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_87));
				cgFormatValue__cgen_147((&res), result);
				res = resizeString(res, 13);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_88));
				cgFormatValue__cgen_147((&res), result);
				res = resizeString(res, 16);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_89));
				T36_ = NIM_NIL;
				T36_ = rope__ropes_109(res);
				add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 4))- 0], T36_);
			}
			LA34_: ;
		}
		goto LA11_;
		LA13_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
			NimStringDesc* T39_;
			T38_ = NIM_NIL;
			T38_ = getTypeForward__cgen_3141(m, t, sig);
			T39_ = NIM_NIL;
			T39_ = seqStar__cgen_3134(m);
			result = amp___ropes_140(T38_, T39_);
		}
		LA11_: ;
		pushType__cgen_3070(m, t);
	}
	break;
	default:
	{
		result = getTypeDescAux__cgen_1332(m, t, check, kind);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ, mapReturnType__cgen_1297)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ) {
	tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ result;
	result = (tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ)0;
	result = mapType__cgen_1227(conf, typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 11));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genProcParams__cgen_3508)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** rettype, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** params, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* check, NIM_BOOL declareEnvironment, NIM_BOOL weakDep) {
	unsureAsgnRef((void**) (&(*params)), ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL));
	{
		NIM_BOOL T3_;
		tyArray__dAmhZbEWrTM5xES2bTVweg T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*t).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = isInvalidReturnType__cgen_1353((*(*m).g).config, t, NIM_TRUE);
		LA4_: ;
		if (!T3_) goto LA5_;
		nimZeroMem((void*)T7_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		unsureAsgnRef((void**) (&(*rettype)), percent___cgen_3521(T7_, 0));
	}
	goto LA1_;
	LA5_: ;
	{
		unsureAsgnRef((void**) (&(*rettype)), getTypeDescAux__cgen_1332(m, (*t).sons->data[((NI) 0)], check, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 11)));
	}
	LA1_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155((*t).n);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA11;
				i = i_2;
				{
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* param;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T28_;
					tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ T29_;
					tyArray__dAmhZbEWrTM5xES2bTVweg T44_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T45_;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* arr;
					NI j;
					{
						if (!!(((*(*(*t).n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)))) goto LA15_;
						internalErrorImpl__msgs_1441((*(*m).g).config, (*(*t).n).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_70), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_71);
					}
					LA15_: ;
					param = (*(*(*t).n)._kind_6.sons->data[i])._kind_4.sym;
					{
						NIM_BOOL T19_;
						T19_ = (NIM_BOOL)0;
						T19_ = isCompileTimeOnly__types_3592((*param).typ);
						if (!T19_) goto LA20_;
						goto LA12;
					}
					LA20_: ;
					{
						tyArray__dAmhZbEWrTM5xES2bTVweg T26_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T27_;
						if (!!(((*params) == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA24_;
						nimZeroMem((void*)T26_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
						T27_ = NIM_NIL;
						T27_ = percent___cgen_3546(T26_, 0);
						add__ropes_159(params, T27_);
					}
					LA24_: ;
					T28_ = NIM_NIL;
					T28_ = mangleParamName__cgen_658(m, param);
					T29_ = (tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ)0;
					T29_ = paramStorageLoc__cgen_3501(param);
					fillLoc__cgen_71((&(*param).loc), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 4), (*(*t).n)._kind_6.sons->data[i], T28_, T29_);
					{
						NIM_BOOL T32_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T35_;
						tyArray__dAmhZbEWrTM5xES2bTVweg T36_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T37_;
						T32_ = (NIM_BOOL)0;
						T32_ = ccgIntroducedPtr__ccgutils_153((*(*m).g).config, param, (*t).sons->data[((NI) 0)]);
						if (!T32_) goto LA33_;
						T35_ = NIM_NIL;
						T35_ = getTypeDescWeak__cgen_3345(m, (*param).typ, check, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
						add__ropes_159(params, T35_);
						nimZeroMem((void*)T36_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
						T37_ = NIM_NIL;
						T37_ = percent___cgen_3553(T36_, 0);
						add__ropes_159(params, T37_);
						(*param).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 0)) & 15);
						(*param).loc.storage = ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0);
					}
					goto LA30_;
					LA33_: ;
					{
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T41_;
						if (!weakDep) goto LA39_;
						T41_ = NIM_NIL;
						T41_ = getTypeDescWeak__cgen_3345(m, (*param).typ, check, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
						add__ropes_159(params, T41_);
					}
					goto LA30_;
					LA39_: ;
					{
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T43_;
						T43_ = NIM_NIL;
						T43_ = getTypeDescAux__cgen_1332(m, (*param).typ, check, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
						add__ropes_159(params, T43_);
					}
					LA30_: ;
					nimZeroMem((void*)T44_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
					T45_ = NIM_NIL;
					T45_ = percent___cgen_3562(T44_, 0);
					add__ropes_159(params, T45_);
					{
						tyArray__dAmhZbEWrTM5xES2bTVweg T50_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T51_;
						if (!(((*param).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 46))&63U)))!=0)) goto LA48_;
						nimZeroMem((void*)T50_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
						T51_ = NIM_NIL;
						T51_ = percent___cgen_3571(T50_, 0);
						add__ropes_159(params, T51_);
					}
					LA48_: ;
					add__ropes_159(params, (*param).loc.r);
					arr = skipTypes__ast_3723((*param).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_91);
					{
						if (!((*arr).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*arr).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47) || (*arr).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46))) goto LA54_;
						arr = lastSon__ast_3731(arr);
					}
					LA54_: ;
					j = ((NI) 0);
					{
						while (1) {
							tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T62_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T63_;
							if (!((*arr).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27) || (*arr).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48))) goto LA57;
							{
								if (!((*(*param).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*(*param).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47))) goto LA60_;
								(*param).loc.storage = ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0);
							}
							LA60_: ;
							nimZeroMem((void*)T62_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
							T62_[0] = (*param).loc.r;
							T62_[1] = rope__ropes_115(((NI64) (j)));
							T63_ = NIM_NIL;
							T63_ = percent___cgen_3593(T62_, 2);
							add__ropes_159(params, T63_);
							j += ((NI) 1);
							arr = skipTypes__ast_3723((*arr).sons->data[((NI) 0)], TM__9bddtAaa9cYLwzzzlT9aJ5CKw_92);
						} LA57: ;
					}
				} LA12: ;
				i_2 += ((NI) 1);
			} LA11: ;
		}
	}
	{
		NIM_BOOL T66_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* arr_2;
		tyArray__dAmhZbEWrTM5xES2bTVweg T88_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T89_;
		T66_ = (NIM_BOOL)0;
		T66_ = !(((*t).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		if (!(T66_)) goto LA67_;
		T66_ = isInvalidReturnType__cgen_1353((*(*m).g).config, t, NIM_TRUE);
		LA67_: ;
		if (!T66_) goto LA68_;
		arr_2 = (*t).sons->data[((NI) 0)];
		{
			if (!!(((*params) == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA72_;
			add__ropes_162(params, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		}
		LA72_: ;
		{
			tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ T76_;
			T76_ = (tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ)0;
			T76_ = mapReturnType__cgen_1297((*(*m).g).config, (*t).sons->data[((NI) 0)]);
			if (!!((T76_ == ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 17)))) goto LA77_;
			{
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T83_;
				if (!(((*m).flags &((NU8)1<<((NU)(((tyEnum_CodegenFlag__vPx29bHhk9a7V50u1UO0rM4w) 3))&7U)))!=0)) goto LA81_;
				T83_ = NIM_NIL;
				T83_ = getTypeDescAux__cgen_1332(m, arr_2, check, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 11));
				add__ropes_159(params, T83_);
				add__ropes_162(params, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_90));
			}
			goto LA79_;
			LA81_: ;
			{
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T85_;
				T85_ = NIM_NIL;
				T85_ = getTypeDescWeak__cgen_3345(m, arr_2, check, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 11));
				add__ropes_159(params, T85_);
				add__ropes_162(params, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_90));
			}
			LA79_: ;
		}
		goto LA74_;
		LA77_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T87_;
			T87_ = NIM_NIL;
			T87_ = getTypeDescAux__cgen_1332(m, arr_2, check, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 11));
			add__ropes_159(params, T87_);
		}
		LA74_: ;
		nimZeroMem((void*)T88_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		T89_ = NIM_NIL;
		T89_ = percent___cgen_3624(T88_, 0);
		add__ropes_159(params, T89_);
	}
	LA68_: ;
	{
		NIM_BOOL T92_;
		T92_ = (NIM_BOOL)0;
		T92_ = ((*t).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
		if (!(T92_)) goto LA93_;
		T92_ = declareEnvironment;
		LA93_: ;
		if (!T92_) goto LA94_;
		{
			if (!!(((*params) == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA98_;
			add__ropes_162(params, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		}
		LA98_: ;
		add__ropes_162(params, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_93));
	}
	LA94_: ;
	{
		if (!(((*t).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 0))&63U)))!=0)) goto LA102_;
		{
			if (!!(((*params) == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA106_;
			add__ropes_162(params, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		}
		LA106_: ;
		add__ropes_162(params, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_94));
	}
	LA102_: ;
	{
		if (!((*params) == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA110_;
		add__ropes_162(params, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_95));
	}
	goto LA108_;
	LA110_: ;
	{
		add__ropes_162(params, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
	}
	LA108_: ;
	unsureAsgnRef((void**) (&(*params)), amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26), (*params)));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genProcHeader__cgen_632)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc, NIM_BOOL asPtr) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* rettype;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* params;
	tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw check;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* asPtrStr;
	NimStringDesc* T21_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name;
	result = NIM_NIL;
	rettype = NIM_NIL;
	params = NIM_NIL;
	{
		if (!(((*prc).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 5))&15U)))!=0)) goto LA3_;
		{
			if (!(((*m).flags &((NU8)1<<((NU)(((tyEnum_CodegenFlag__vPx29bHhk9a7V50u1UO0rM4w) 3))&7U)))!=0)) goto LA7_;
			add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_62));
		}
		goto LA5_;
		LA7_: ;
		{
			add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_63));
		}
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T11_;
		NIM_BOOL T12_;
		T11_ = (NIM_BOOL)0;
		T12_ = (NIM_BOOL)0;
		T12_ = ((*(*prc).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 5));
		if (T12_) goto LA13_;
		T12_ = asPtr;
		LA13_: ;
		T11_ = T12_;
		if (T11_) goto LA14_;
		T11_ = isNonReloadable__cgen_6745(m, prc);
		LA14_: ;
		if (!T11_) goto LA15_;
		add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_64));
	}
	goto LA1_;
	LA15_: ;
	{
		if (!!((((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 6))&63U)))!=0))) goto LA18_;
		add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_65));
	}
	goto LA1_;
	LA18_: ;
	LA1_: ;
	nimZeroMem((void*)(&check), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
	initIntSet__pureZcollectionsZintsets_238((&check));
	T20_ = NIM_NIL;
	T20_ = mangleName__cgen_646(m, prc);
	fillLoc__cgen_71((&(*prc).loc), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 7), (*(*prc).ast)._kind_6.sons->data[((NI) 0)], T20_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	genProcParams__cgen_3508(m, (*prc).typ, &rettype, &params, (&check), NIM_TRUE, NIM_FALSE);
	T21_ = NIM_NIL;
	{
		if (!asPtr) goto LA24_;
		T21_ = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_96));
	}
	goto LA22_;
	LA24_: ;
	{
		T21_ = ((NimStringDesc*) NIM_NIL);
	}
	LA22_: ;
	asPtrStr = rope__ropes_109(T21_);
	name = (*prc).loc.r;
	{
		NIM_BOOL T29_;
		T29_ = (NIM_BOOL)0;
		T29_ = isReloadable__cgen_6737(m, prc);
		if (!(T29_)) goto LA30_;
		T29_ = !(asPtr);
		LA30_: ;
		if (!T29_) goto LA31_;
		add__ropes_162(&name, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_97));
	}
	LA31_: ;
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T37_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
		if (!((*prc).constraint == 0)) goto LA35_;
		nimZeroMem((void*)T37_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T37_[0] = rope__ropes_109(CallingConvToStr__cgen_1379[((*(*prc).typ).callConv)- 0]);
		T37_[1] = asPtrStr;
		T37_[2] = rettype;
		T37_[3] = name;
		T37_[4] = params;
		T38_ = NIM_NIL;
		T38_ = percent___cgen_6783(T37_, 5);
		add__ropes_159(&result, T38_);
	}
	goto LA33_;
	LA35_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* asPtrStr_2;
		tyArray__FKvM4FDhljtt88k8FkGthA T47_;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T44_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T45_;
			if (!asPtr) goto LA42_;
			T44_ = NIM_NIL;
			T44_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_109));
			T45_ = NIM_NIL;
			T45_ = amp___ropes_128(T44_, name);
			asPtrStr_2 = amp___ropes_140(T45_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		}
		goto LA40_;
		LA42_: ;
		{
			asPtrStr_2 = name;
		}
		LA40_: ;
		nimZeroMem((void*)T47_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
		T47_[0] = rettype;
		T47_[1] = asPtrStr_2;
		T47_[2] = params;
		result = runtimeFormat__ropes_271((*(*prc).constraint)._kind_3.strVal, T47_, 3);
	}
	LA33_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsResult__cgen_25982)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	result = NIM_FALSE;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 4) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 76):
	{
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		{
			if (!((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 11))) goto LA5_;
			result = NIM_TRUE;
		}
		LA5_: ;
	}
	break;
	default:
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA10;
					i = i_2;
					{
						NIM_BOOL T13_;
						T13_ = (NIM_BOOL)0;
						T13_ = containsResult__cgen_25982((*n)._kind_6.sons->data[i]);
						if (!T13_) goto LA14_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA14_: ;
					i_2 += ((NI) 1);
				} LA10: ;
			}
		}
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, easyResultAsgn__cgen_26011)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
{	result = NIM_NIL;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126):
	{
		NI i;
		i = ((NI) 0);
		{
			while (1) {
				NIM_BOOL T4_;
				NI T5_;
				T4_ = (NIM_BOOL)0;
				T5_ = (NI)0;
				T5_ = len__ast_3155(n);
				T4_ = (i < T5_);
				if (!(T4_)) goto LA6_;
				T4_ = ((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1) || (*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 76) || (*(*n)._kind_6.sons->data[i]).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79) && (*(*n)._kind_6.sons->data[i]).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84) || (*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 98) || (*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 101) || (*(*n)._kind_6.sons->data[i]).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 122) && (*(*n)._kind_6.sons->data[i]).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 123) || (*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 125) || (*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159));
				LA6_: ;
				if (!T4_) goto LA3;
				i += ((NI) 1);
			} LA3: ;
		}
		{
			NI T9_;
			T9_ = (NI)0;
			T9_ = len__ast_3155(n);
			if (!(i < T9_)) goto LA10_;
			result = easyResultAsgn__cgen_26011((*n)._kind_6.sons->data[i]);
		}
		LA10_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 73):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 74):
	{
		{
			NIM_BOOL T15_;
			NIM_BOOL T16_;
			NIM_BOOL T19_;
			T15_ = (NIM_BOOL)0;
			T16_ = (NIM_BOOL)0;
			T16_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
			if (!(T16_)) goto LA17_;
			T16_ = ((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 11));
			LA17_: ;
			T15_ = T16_;
			if (!(T15_)) goto LA18_;
			T19_ = (NIM_BOOL)0;
			T19_ = containsResult__cgen_25982((*n)._kind_6.sons->data[((NI) 1)]);
			T15_ = !(T19_);
			LA18_: ;
			if (!T15_) goto LA20_;
			(*n).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg) 15)) & 31);
			result = (*n)._kind_6.sons->data[((NI) 1)];
			goto BeforeRet_;
		}
		LA20_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 109):
	{
		{
			NI T25_;
			T25_ = (NI)0;
			T25_ = len__ast_3155(n);
			if (!(((NI) 0) < T25_)) goto LA26_;
			result = easyResultAsgn__cgen_26011((*n)._kind_6.sons->data[((NI) 0)]);
			{
				if (!!((result == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA30_;
				(*n).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg) 15)) & 31);
			}
			LA30_: ;
		}
		LA26_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, shallow__system_7445)(NimStringDesc** s) {
	TGenericSeq* s_2;
	s_2 = ((TGenericSeq*) ((*s)));
	{
		NimStringDesc* T5_;
		if (!(s_2 == ((TGenericSeq*) NIM_NIL))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = mnewString(((NI) 0));
		s_2 = ((TGenericSeq*) (T5_));
	}
	LA3_: ;
	{
		if (!((NI)((*s_2).reserved & ((NI) IL64(4611686018427387904))) == ((NI) 0))) goto LA8_;
		(*s_2).reserved = (NI)((*s_2).reserved | ((NI) (IL64(-9223372036854775807) - IL64(1))));
	}
	LA8_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, mangleLocalName__cgen_744)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	result = (*s).loc.r;
	{
		NimStringDesc* key;
		NI counter;
		if (!(result == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA3_;
		key = mangle__ccgutils_112((*(*s).name).s);
		shallow__system_7445((&key));
		counter = getOrDefault__cgen_830((*p).sigConflicts, key, ((NI) 0));
		result = rope__ropes_109(key);
		{
			if (!((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 5))) goto LA7_;
			{
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
				if (!!((counter == ((NI) 0)))) goto LA11_;
				T13_ = NIM_NIL;
				T13_ = rope__ropes_115(((NI64) ((NI)(counter + ((NI) 1)))));
				T14_ = NIM_NIL;
				T14_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3), T13_);
				add__ropes_159(&result, T14_);
			}
			LA11_: ;
		}
		goto LA5_;
		LA7_: ;
		{
			NIM_BOOL T16_;
			NIM_BOOL T17_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
			T16_ = (NIM_BOOL)0;
			T17_ = (NIM_BOOL)0;
			T17_ = !((counter == ((NI) 0)));
			if (T17_) goto LA18_;
			T17_ = isKeyword__cgen_636((*s).name);
			LA18_: ;
			T16_ = T17_;
			if (T16_) goto LA19_;
			T16_ = contains__cgen_720((*(*(*(*p).module).g).config).cppDefines, key);
			LA19_: ;
			if (!T16_) goto LA20_;
			T22_ = NIM_NIL;
			T22_ = rope__ropes_115(((NI64) ((NI)(counter + ((NI) 1)))));
			T23_ = NIM_NIL;
			T23_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3), T22_);
			add__ropes_159(&result, T23_);
		}
		goto LA5_;
		LA20_: ;
		LA5_: ;
		inc__cgen_953((&(*p).sigConflicts), key, ((NI) 1));
		asgnRef((void**) (&(*s).loc.r), result);
		{
			if (!!(((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 5)))) goto LA26_;
			{
				NI T32_;
				if (!(*(*p).module).ndi.enabled) goto LA30_;
				asgnRef((void**) (&(*(*p).module).ndi.syms), (tySequence__ed0C0uAUZPhvw3RAc5hfYg*) incrSeqV3((TGenericSeq*)((*(*p).module).ndi.syms), (&NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_)));
				T32_ = (*(*p).module).ndi.syms->Sup.len++;
				asgnRef((void**) (&(*(*p).module).ndi.syms->data[T32_]), s);
			}
			LA30_: ;
		}
		LA26_: ;
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genCLineDir__cgen_340)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** r, NimStringDesc* filename, NI line, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	{
		NIM_BOOL T3_;
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T7_;
		NimStringDesc* T8_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0);
		if (!(T3_)) goto LA4_;
		T3_ = (((NI) 0) < line);
		LA4_: ;
		if (!T3_) goto LA5_;
		nimZeroMem((void*)T7_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T8_ = NIM_NIL;
		T8_ = makeSingleLineCString__ccgutils_108(filename);
		T7_[0] = rope__ropes_109(T8_);
		T7_[1] = rope__ropes_115(((NI64) (line)));
		T9_ = NIM_NIL;
		T9_ = percent___cgen_352(T7_, 2);
		add__ropes_159(r, T9_);
	}
	LA5_: ;
}
static N_INLINE(NI, toLinenumber__msgs_619)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NI result;
	result = (NI)0;
	result = ((NI) (info.line));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, safeLineNm__cgen_337)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NI result;
	result = (NI)0;
	result = toLinenumber__msgs_619(info);
	{
		if (!(result < ((NI) 0))) goto LA3_;
		result = ((NI) 0);
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genCLineDir__cgen_357)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** r, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	{
		NimStringDesc* T5_;
		NI T6_;
		if (!(((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0)) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = toFullPath__msgs_548(conf, info.fileIndex);
		T6_ = (NI)0;
		T6_ = safeLineNm__cgen_337(info);
		genCLineDir__cgen_340(r, T5_, T6_, conf);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, localVarDecl__cgen_11124)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
	result = NIM_NIL;
	s = (*n)._kind_4.sym;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
		if (!((*s).loc.k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = mangleLocalName__cgen_744(p, s);
		fillLoc__cgen_71((&(*s).loc), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 2), n, T5_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 2));
		{
			if (!((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 9))) goto LA8_;
			(*s).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 2)) & 15);
		}
		LA8_: ;
	}
	LA3_: ;
	{
		NIM_BOOL T12_;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T16_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
		T12_ = (NIM_BOOL)0;
		T12_ = ((2622208 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
		if (!(T12_)) goto LA13_;
		T12_ = (((NI) 0) < (*s)._kind_2.alignment);
		LA13_: ;
		if (!T12_) goto LA14_;
		nimZeroMem((void*)T16_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T16_[0] = rope__ropes_115(((NI64) ((*s)._kind_2.alignment)));
		T17_ = NIM_NIL;
		T17_ = percent___cgen_3760(T16_, 1);
		add__ropes_159(&result, T17_);
	}
	LA14_: ;
	genCLineDir__cgen_357(&result, (*n).info, (*(*(*p).module).g).config);
	T18_ = NIM_NIL;
	T18_ = getTypeDesc__cgen_6662((*p).module, (*s).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
	add__ropes_159(&result, T18_);
	{
		if (!((*s).constraint == 0)) goto LA21_;
		{
			if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 10))&63U)))!=0)) goto LA25_;
			add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_112));
		}
		LA25_: ;
		{
			if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 9))&63U)))!=0)) goto LA29_;
			add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_113));
		}
		LA29_: ;
		{
			if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 46))&63U)))!=0)) goto LA33_;
			add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_114));
		}
		LA33_: ;
		add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_13));
		add__ropes_159(&result, (*s).loc.r);
	}
	goto LA19_;
	LA21_: ;
	{
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T36_;
		nimZeroMem((void*)T36_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T36_[0] = result;
		T36_[1] = (*s).loc.r;
		result = runtimeFormat__ropes_271((*(*s).constraint)._kind_3.strVal, T36_, 2);
	}
	LA19_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initLocExprSingleUse__cgen_11552)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* result) {
	initLoc__cgen_66(result, ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0), e, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*e).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*e).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29) || (*e).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30) || (*e).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31) || (*e).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) || (*e).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28) || (*e).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32));
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = !(((*(*e)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)));
		if (T5_) goto LA6_;
		T5_ = ((*(*(*e)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 0));
		LA6_: ;
		T3_ = T5_;
		LA4_: ;
		if (!T3_) goto LA7_;
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = ((*(*e)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
			if (!(T11_)) goto LA12_;
			T11_ = (((*(*(*e)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
			LA12_: ;
			if (!T11_) goto LA13_;
			(*result).flags |= ((NU16)1)<<((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 8)) & 15);
		}
		LA13_: ;
	}
	goto LA1_;
	LA7_: ;
	{
		(*result).flags |= ((NU16)1)<<((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 8)) & 15);
	}
	LA1_: ;
	expr__cgen_11525(p, e, result);
}
N_LIB_PRIVATE N_NIMCALL(void, assignLocalVar__cgen_11164)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NimStringDesc* nl;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* decl;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T8_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
	{
		if (!(((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0)) goto LA3_;
		nl = ((NimStringDesc*) NIM_NIL);
	}
	goto LA1_;
	LA3_: ;
	{
		nl = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA1_: ;
	T6_ = NIM_NIL;
	T6_ = localVarDecl__cgen_11124(p, n);
	T7_ = NIM_NIL;
	T7_ = amp___ropes_140(T6_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
	decl = amp___ropes_140(T7_, nl);
	T8_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T8_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
	T9_ = NIM_NIL;
	T9_ = indentLine__cgen_286(p, decl);
	add__ropes_159(T8_, T9_);
}
static N_INLINE(NIM_BOOL, isComplexValueType__cgen_10585)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	NIM_BOOL result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t_2;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	result = (NIM_BOOL)0;
	t_2 = skipTypes__ast_3723(t, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_118);
	T1_ = (NIM_BOOL)0;
	T1_ = ((*t_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16) || (*t_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 19) || (*t_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18) || (*t_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17) || (*t_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27));
	if (T1_) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*t_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25));
	if (!(T3_)) goto LA4_;
	T3_ = ((*t_2).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
	LA4_: ;
	T1_ = T3_;
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(NIM_BOOL, usesWriteBarrier__options_4033)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = (((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 8) <= (*conf).selectedGC);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, addrLoc__cgen_10337)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	result = a.r;
	{
		NIM_BOOL T3_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T5_;
		tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw T6_;
		tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ T12_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((a.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 0))&15U)))!=0));
		if (!(T3_)) goto LA4_;
		T5_ = NIM_NIL;
		T5_ = t__cgen_85(a);
		T6_ = (tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw)0;
		{
			if (!((*a.lode).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA9_;
			T6_ = (*(*a.lode)._kind_4.sym).kind;
		}
		goto LA7_;
		LA9_: ;
		{
			T6_ = ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8);
		}
		LA7_: ;
		T12_ = (tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ)0;
		T12_ = mapType__cgen_1227(conf, T5_, T6_);
		T3_ = !((T12_ == ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 17)));
		LA4_: ;
		if (!T3_) goto LA13_;
		T15_ = NIM_NIL;
		T15_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_122), result);
		result = amp___ropes_140(T15_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
	}
	LA13_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genRefAssign__cgen_10581)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw dest, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw src) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NIM_BOOL T7_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T10_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = (dest.storage == ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 2));
		if (!(T4_)) goto LA5_;
		T4_ = !(((*(*(*(*p).module).g).config).selectedGC == ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 10)));
		LA5_: ;
		T3_ = T4_;
		if (T3_) goto LA6_;
		T7_ = (NIM_BOOL)0;
		T7_ = usesWriteBarrier__options_4033((*(*(*p).module).g).config);
		T3_ = !(T7_);
		LA6_: ;
		if (!T3_) goto LA8_;
		T10_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T10_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res = rawNewString(((NI) 80));
		T11_ = NIM_NIL;
		T11_ = rdLoc__cgen_435(dest);
		cgFormatValue__cgen_147((&res), T11_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
		T12_ = NIM_NIL;
		T12_ = rdLoc__cgen_435(src);
		cgFormatValue__cgen_147((&res), T12_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA15_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA15_: ;
		T17_ = NIM_NIL;
		T17_ = rope__ropes_109(res);
		T18_ = NIM_NIL;
		T18_ = indentLine__cgen_286(p, T17_);
		add__ropes_159(T10_, T18_);
	}
	goto LA1_;
	LA8_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T22_;
		NimStringDesc* res_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T30_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T31_;
		if (!(dest.storage == ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 3))) goto LA20_;
		T22_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T22_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_2 = rawNewString(((NI) 80));
		T23_ = NIM_NIL;
		T23_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_120));
		cgFormatValue__cgen_147((&res_2), T23_);
		res_2 = resizeString(res_2, 10);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_121));
		T24_ = NIM_NIL;
		T24_ = addrLoc__cgen_10337((*(*(*p).module).g).config, dest);
		cgFormatValue__cgen_147((&res_2), T24_);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		T25_ = NIM_NIL;
		T25_ = rdLoc__cgen_435(src);
		cgFormatValue__cgen_147((&res_2), T25_);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA28_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA28_: ;
		T30_ = NIM_NIL;
		T30_ = rope__ropes_109(res_2);
		T31_ = NIM_NIL;
		T31_ = indentLine__cgen_286(p, T30_);
		add__ropes_159(T22_, T31_);
	}
	goto LA1_;
	LA20_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T33_;
		NimStringDesc* res_3;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T34_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T35_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T36_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T41_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T42_;
		T33_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T33_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_3 = rawNewString(((NI) 80));
		T34_ = NIM_NIL;
		T34_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_123));
		cgFormatValue__cgen_147((&res_3), T34_);
		res_3 = resizeString(res_3, 10);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_121));
		T35_ = NIM_NIL;
		T35_ = addrLoc__cgen_10337((*(*(*p).module).g).config, dest);
		cgFormatValue__cgen_147((&res_3), T35_);
		res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		T36_ = NIM_NIL;
		T36_ = rdLoc__cgen_435(src);
		cgFormatValue__cgen_147((&res_3), T36_);
		res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA39_;
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA39_: ;
		T41_ = NIM_NIL;
		T41_ = rope__ropes_109(res_3);
		T42_ = NIM_NIL;
		T42_ = indentLine__cgen_286(p, T41_);
		add__ropes_159(T33_, T42_);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getModuleDllPath__cgen_138)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, NI module) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	result = getModuleDllPath__cgen_131((*(*m).g).modules->data[module]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, declareNimType__cgen_7814)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, NimStringDesc* name, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* str, NI module) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* nr;
	nr = rope__ropes_109(name);
	{
		NIM_BOOL T3_;
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T6_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
		tyArray__FKvM4FDhljtt88k8FkGthA T8_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
		T3_ = (NIM_BOOL)0;
		T3_ = hcrOn__cgen_43(m);
		if (!T3_) goto LA4_;
		nimZeroMem((void*)T6_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T6_[0] = str;
		T6_[1] = nr;
		T7_ = NIM_NIL;
		T7_ = percent___cgen_7820(T6_, 2);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 9))- 0], T7_);
		nimZeroMem((void*)T8_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
		T8_[0] = str;
		T8_[1] = getModuleDllPath__cgen_138(m, module);
		T8_[2] = nr;
		T9_ = NIM_NIL;
		T9_ = percent___cgen_7825(T8_, 3);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 14))- 0], T9_);
	}
	goto LA1_;
	LA4_: ;
	{
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T11_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
		nimZeroMem((void*)T11_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T11_[0] = str;
		T11_[1] = nr;
		T12_ = NIM_NIL;
		T12_ = percent___cgen_7830(T11_, 2);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 9))- 0], T12_);
	}
	LA1_: ;
}
static N_INLINE(NIM_BOOL, moduleOpenForCodegen__modulegraphs_9529)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI32 m) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		if (!((*(*g).config).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0))) goto LA3_;
		result = NIM_TRUE;
	}
	goto LA1_;
	LA3_: ;
	{
		result = !(((41 &((NU8)1<<((NU)((*g).packed_0->data[m].status)&7U)))!=0));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genTypeInfo2Name__cgen_7835)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	NimStringDesc* res;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* it;
	result = NIM_NIL;
	res = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_137));
	it = t;
	{
		while (1) {
			if (!!((it == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA2;
			it = skipTypes__ast_3723(it, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_130);
			{
				NIM_BOOL T5_;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m_2;
				T5_ = (NIM_BOOL)0;
				T5_ = !(((*it).sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
				if (!(T5_)) goto LA6_;
				T5_ = !((((*it).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 8))&63U)))!=0));
				LA6_: ;
				if (!T5_) goto LA7_;
				m_2 = (*(*it).sym).owner;
				{
					while (1) {
						NIM_BOOL T11_;
						T11_ = (NIM_BOOL)0;
						T11_ = !((m_2 == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
						if (!(T11_)) goto LA12_;
						T11_ = !(((*m_2).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6)));
						LA12_: ;
						if (!T11_) goto LA10;
						m_2 = (*m_2).owner;
					} LA10: ;
				}
				{
					NIM_BOOL T15_;
					T15_ = (NIM_BOOL)0;
					T15_ = (m_2 == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
					if (T15_) goto LA16_;
					T15_ = (((*m_2).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 15))&63U)))!=0);
					LA16_: ;
					if (!T15_) goto LA17_;
					res = resizeString(res, ((*(*(*it).sym).name).s ? (*(*(*it).sym).name).s->Sup.len : 0) + 0);
appendString(res, (*(*(*it).sym).name).s);
				}
				goto LA13_;
				LA17_: ;
				{
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* p;
					NimStringDesc* T27_;
					p = (*m_2).owner;
					{
						NIM_BOOL T22_;
						NimStringDesc* T26_;
						T22_ = (NIM_BOOL)0;
						T22_ = !((p == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
						if (!(T22_)) goto LA23_;
						T22_ = ((*p).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 24));
						LA23_: ;
						if (!T22_) goto LA24_;
						T26_ = NIM_NIL;
						T26_ = rawNewString(((*(*p).name).s ? (*(*p).name).s->Sup.len : 0) + 1);
appendString(T26_, (*(*p).name).s);
appendString(T26_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_138));
						res = resizeString(res, (T26_ ? T26_->Sup.len : 0) + 0);
appendString(res, T26_);
					}
					LA24_: ;
					T27_ = NIM_NIL;
					T27_ = rawNewString(((*(*m_2).name).s ? (*(*m_2).name).s->Sup.len : 0) + 1);
appendString(T27_, (*(*m_2).name).s);
appendString(T27_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_138));
					res = resizeString(res, (T27_ ? T27_->Sup.len : 0) + 0);
appendString(res, T27_);
					res = resizeString(res, ((*(*(*it).sym).name).s ? (*(*(*it).sym).name).s->Sup.len : 0) + 0);
appendString(res, (*(*(*it).sym).name).s);
				}
				LA13_: ;
			}
			goto LA3_;
			LA7_: ;
			{
				tyArray__qtqsWM5aXmcpMIVmvq3kAA T29_;
				NimStringDesc* T30_;
				nimZeroMem((void*)T29_, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
				hashType__sighashes_473(it, (*(*m).g).config, 2, T29_);
				T30_ = NIM_NIL;
				T30_ = dollar___modulegraphs_8985(T29_);
				res = resizeString(res, (T30_ ? T30_->Sup.len : 0) + 0);
appendString(res, T30_);
			}
			LA3_: ;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_137));
			it = (*it).sons->data[((NI) 0)];
		} LA2: ;
	}
	result = makeCString__msgs_50(res);
	return result;
}
static N_INLINE(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, getBody__modulegraphs_13094)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = (*(*s).ast)._kind_6.sons->data[((NI) 6)];
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (result == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
		if (!(T3_)) goto LA4_;
		T3_ = ((28 &((NU8)1<<((NU)((*(*g).config).symbolFiles)&7U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		result = loadProcBody__icZic_8386((*g).config, (*g).cache, (&(*g).packed_0), s);
		asgnRef((void**) (&(*(*s).ast)._kind_6.sons->data[((NI) 6)]), result);
	}
	LA5_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isTrivialProc__cgen_7880)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NIM_BOOL result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T1_;
	NI T2_;
	result = (NIM_BOOL)0;
	T1_ = NIM_NIL;
	T1_ = getBody__modulegraphs_13094(g, s);
	T2_ = (NI)0;
	T2_ = len__ast_3155(T1_);
	result = (T2_ == ((NI) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genHook__cgen_7887)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ op) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* theProc;
	result = NIM_NIL;
	theProc = getAttachedOp__modulegraphs_4049((*(*m).g).graph, t, op);
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !((theProc == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = isTrivialProc__cgen_7880((*(*m).g).graph, theProc);
		T3_ = !(T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		{
			NIM_BOOL T10_;
			NimStringDesc* T14_;
			T10_ = (NIM_BOOL)0;
			T10_ = ((*theProc).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
			if (T10_) goto LA11_;
			T10_ = !(((*(*theProc).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 0)));
			LA11_: ;
			if (!T10_) goto LA12_;
			T14_ = NIM_NIL;
			T14_ = rawNewString(((*(*theProc).name).s ? (*(*theProc).name).s->Sup.len : 0) + 47);
appendString(T14_, (*(*theProc).name).s);
appendString(T14_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_139));
			liMessage__msgs_1128((*(*m).g).config, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T14_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_140, NIM_FALSE);
		}
		LA12_: ;
		genProc__cgen_421(m, theProc);
		result = (*theProc).loc.r;
	}
	goto LA1_;
	LA6_: ;
	{
		result = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_119));
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI, len__ast_3990)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n).sons ? (*n).sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, typeToC__cgen_9772)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	NimStringDesc* result;
	NimStringDesc* s;
	result = NIM_NIL;
	s = typeToString__types_50(t, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
	result = rawNewString(((NI) ((s ? s->Sup.len : 0))));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (s ? s->Sup.len : 0);
		i_2 = ((NI) 0);
		{
			while (1) {
				NIM_CHAR c;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				c = s->data[i];
				switch (((NU8)(c))) {
				case 97 ... 122:
				{
					result = addChar(result, c);
				}
				break;
				case 65 ... 90:
				{
					NIM_CHAR T6_;
					T6_ = (NIM_CHAR)0;
					T6_ = nsuToLowerAsciiChar(c);
					result = addChar(result, T6_);
				}
				break;
				case 32:
				{
				}
				break;
				case 44:
				{
					result = addChar(result, 95);
				}
				break;
				case 46:
				{
					result = addChar(result, 79);
				}
				break;
				case 91:
				case 40:
				case 123:
				{
					result = addChar(result, 76);
				}
				break;
				case 93:
				case 41:
				case 125:
				{
					result = addChar(result, 84);
				}
				break;
				default:
				{
					addInt__stdZprivateZdigitsutils_189((&result), ((NU8)(c)));
				}
				break;
				}
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, tiNameForHcr__cgen_6814)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
{	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = hcrOn__cgen_43(m);
		if (!T3_) goto LA4_;
		T6_ = NIM_NIL;
		T6_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_109));
		T7_ = NIM_NIL;
		T7_ = amp___ropes_128(T6_, name);
		result = amp___ropes_140(T7_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
	}
	goto LA1_;
	LA4_: ;
	{
		result = name;
	}
	LA1_: ;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genTypeInfoAuxBase__cgen_6818)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* origType, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* base, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NI nimtypeKind;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* nameHcr;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* size;
	tyArray__InO6xIOhXMnkCXPnEYWwWg T12_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
	NI flags;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T30_;
	nimtypeKind = (NI)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isObjLackingTypeField__cgen_1337(typ);
		if (!T3_) goto LA4_;
		nimtypeKind = ((NI) 18);
	}
	goto LA1_;
	LA4_: ;
	{
		nimtypeKind = (*typ).kind;
	}
	LA1_: ;
	nameHcr = tiNameForHcr__cgen_6814(m, name);
	size = NIM_NIL;
	{
		if (!(((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 40))&63U)))!=0)) goto LA9_;
		size = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_145));
	}
	goto LA7_;
	LA9_: ;
	{
		size = getTypeDesc__cgen_6662(m, origType, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
	}
	LA7_: ;
	nimZeroMem((void*)T12_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
	T12_[0] = nameHcr;
	T12_[1] = size;
	T12_[2] = rope__ropes_115(((NI64) (nimtypeKind)));
	T12_[3] = base;
	T13_ = NIM_NIL;
	T13_ = percent___cgen_6838(T12_, 4);
	add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T13_);
	flags = ((NI) 0);
	{
		NIM_BOOL T16_;
		T16_ = (NIM_BOOL)0;
		T16_ = containsGarbageCollectedRef__types_612(typ);
		if (!!(T16_)) goto LA17_;
		flags = (NI)(flags | ((NI) 1));
	}
	LA17_: ;
	{
		NIM_BOOL T21_;
		T21_ = (NIM_BOOL)0;
		T21_ = canFormAcycle__types_820((*(*m).g).graph, typ);
		if (!!(T21_)) goto LA22_;
		flags = (NI)(flags | ((NI) 2));
	}
	LA22_: ;
	{
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T28_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T29_;
		if (!!((flags == ((NI) 0)))) goto LA26_;
		nimZeroMem((void*)T28_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T28_[0] = nameHcr;
		T28_[1] = rope__ropes_115(((NI64) (flags)));
		T29_ = NIM_NIL;
		T29_ = percent___cgen_6844(T28_, 2);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T29_);
	}
	LA26_: ;
	T30_ = NIM_NIL;
	T30_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_142));
	(void)(T30_);
	{
		NIM_BOOL T33_;
		NimStringDesc* typename_1;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T36_;
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T52_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T53_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T54_;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T55_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T56_;
		T33_ = (NIM_BOOL)0;
		T33_ = isDefined__options_2292((*(*m).g).config, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_146));
		if (!T33_) goto LA34_;
		T36_ = NIM_NIL;
		{
			if (!!(((*origType).typeInst == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA39_;
			T36_ = (*origType).typeInst;
		}
		goto LA37_;
		LA39_: ;
		{
			T36_ = origType;
		}
		LA37_: ;
		typename_1 = typeToString__types_50(T36_, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
		{
			NIM_BOOL T44_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T46_;
			NimStringDesc* T49_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T50_;
			NimStringDesc* T51_;
			T44_ = (NIM_BOOL)0;
			T44_ = eqStrings(typename_1, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_147));
			if (!(T44_)) goto LA45_;
			T46_ = NIM_NIL;
			T46_ = skipTypes__ast_3723(origType, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_130);
			T44_ = !(((*T46_).sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
			LA45_: ;
			if (!T44_) goto LA47_;
			T49_ = NIM_NIL;
			T50_ = NIM_NIL;
			T50_ = skipTypes__ast_3723(origType, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_130);
			T51_ = NIM_NIL;
			T51_ = dollar___msgs_634((*(*m).g).config, (*(*T50_).sym).info);
			T49_ = rawNewString((T51_ ? T51_->Sup.len : 0) + 21);
appendString(T49_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_148));
appendString(T49_, T51_);
			typename_1 = T49_;
		}
		LA47_: ;
		nimZeroMem((void*)T52_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T52_[0] = nameHcr;
		T52_[1] = makeCString__msgs_50(typename_1);
		T53_ = NIM_NIL;
		T53_ = percent___cgen_6858(T52_, 2);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T53_);
		T54_ = NIM_NIL;
		T54_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_149));
		(void)(T54_);
		nimZeroMem((void*)T55_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T55_[0] = nameHcr;
		T56_ = NIM_NIL;
		T56_ = percent___cgen_6863(T55_, 1);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T56_);
	}
	LA34_: ;
	{
		NIM_BOOL T59_;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T62_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T63_;
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T64_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T65_;
		T59_ = (NIM_BOOL)0;
		T59_ = hcrOn__cgen_43(m);
		if (!T59_) goto LA60_;
		nimZeroMem((void*)T62_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T62_[0] = name;
		T63_ = NIM_NIL;
		T63_ = percent___cgen_6868(T62_, 1);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 9))- 0], T63_);
		nimZeroMem((void*)T64_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T64_[0] = name;
		T64_[1] = getModuleDllPath__cgen_142(m, (*m).module);
		T65_ = NIM_NIL;
		T65_ = percent___cgen_6873(T64_, 2);
		add__ropes_159(&(*m).hcrCreateTypeInfosProc, T65_);
	}
	goto LA57_;
	LA60_: ;
	{
		tyArray__ts9cf9blICas1QWmw89bglZ7w T67_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T68_;
		nimZeroMem((void*)T67_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T67_[0] = name;
		T68_ = NIM_NIL;
		T68_ = percent___cgen_6878(T67_, 1);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 9))- 0], T68_);
	}
	LA57_: ;
}
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextTypeId__ast_3122)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x) {
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*x).typeId_0 += ((NI) 1);
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	result.module = (*x).module;
	result.item = (*x).typeId_0;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, fakeClosureType__cgen_7356)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T1_;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T2_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T3_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* r;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T4_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* obj;
	result = NIM_NIL;
	T1_ = nextTypeId__ast_3122((*m).Sup.idgen);
	result = newType__ast_3884(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18), T1_, owner);
	T2_ = nextTypeId__ast_3122((*m).Sup.idgen);
	T3_ = NIM_NIL;
	T3_ = newType__ast_3884(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 26), T2_, owner);
	rawAddSon__ast_4276(result, T3_, NIM_TRUE);
	T4_ = nextTypeId__ast_3122((*m).Sup.idgen);
	r = newType__ast_3884(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22), T4_, owner);
	obj = createObj__lowerings_293((*(*m).g).graph, (*m).Sup.idgen, owner, (*owner).info, NIM_FALSE);
	rawAddSon__ast_4276(r, obj, NIM_TRUE);
	rawAddSon__ast_4276(result, r, NIM_TRUE);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getNimNode__cgen_6802)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T1_;
	result = NIM_NIL;
	nimZeroMem((void*)T1_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
	T1_[0] = (*m).typeNodesName;
	T1_[1] = rope__ropes_115(((NI64) ((*m).typeNodes)));
	result = percent___cgen_6805(T1_, 2);
	(*m).typeNodes += ((NI) 1);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genTNimNodeArray__cgen_6962)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* size) {
	{
		NIM_BOOL T3_;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T6_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
		tyArray__FKvM4FDhljtt88k8FkGthA T8_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
		T3_ = (NIM_BOOL)0;
		T3_ = hcrOn__cgen_43(m);
		if (!T3_) goto LA4_;
		nimZeroMem((void*)T6_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T6_[0] = name;
		T7_ = NIM_NIL;
		T7_ = percent___cgen_6966(T6_, 1);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 9))- 0], T7_);
		nimZeroMem((void*)T8_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
		T8_[0] = name;
		T8_[1] = size;
		T8_[2] = getModuleDllPath__cgen_142(m, (*m).module);
		T9_ = NIM_NIL;
		T9_ = percent___cgen_6971(T8_, 3);
		add__ropes_159(&(*m).hcrCreateTypeInfosProc, T9_);
	}
	goto LA1_;
	LA4_: ;
	{
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T11_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
		nimZeroMem((void*)T11_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T11_[0] = name;
		T11_[1] = size;
		T12_ = NIM_NIL;
		T12_ = percent___cgen_6976(T11_, 2);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 14))- 0], T12_);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genTupleInfo__cgen_7180)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* origType, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* expr;
	tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T27_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T28_;
	T1_ = NIM_NIL;
	T1_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_153));
	genTypeInfoAuxBase__cgen_6818(m, typ, typ, name, T1_, info);
	expr = getNimNode__cgen_6802(m);
	{
		NI T4_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tmp;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
		NI T9_;
		NimStringDesc* T10_;
		NI T11_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
		tyArray__FKvM4FDhljtt88k8FkGthA T20_;
		NI T21_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
		T4_ = (NI)0;
		T4_ = len__ast_3990(typ);
		if (!(((NI) 0) < T4_)) goto LA5_;
		T7_ = NIM_NIL;
		T7_ = getTempName__cgen_428(m);
		T8_ = NIM_NIL;
		T8_ = amp___ropes_140(T7_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3));
		T9_ = (NI)0;
		T9_ = len__ast_3990(typ);
		T10_ = NIM_NIL;
		T10_ = dollar___systemZdollars_3(T9_);
		tmp = amp___ropes_140(T8_, T10_);
		T11_ = (NI)0;
		T11_ = len__ast_3990(typ);
		T12_ = NIM_NIL;
		T12_ = rope__ropes_115(((NI64) (T11_)));
		genTNimNodeArray__cgen_6962(m, tmp, T12_);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3990(typ);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tmp2;
					tyArray__FKvM4FDhljtt88k8FkGthA T16_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
					tyArray__InO6xIOhXMnkCXPnEYWwWg T18_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
					if (!(i_2 < colontmp_)) goto LA15;
					i = i_2;
					a = (*typ).sons->data[i];
					tmp2 = getNimNode__cgen_6802(m);
					nimZeroMem((void*)T16_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
					T16_[0] = tmp;
					T16_[1] = rope__ropes_115(((NI64) (i)));
					T16_[2] = tmp2;
					T17_ = NIM_NIL;
					T17_ = percent___cgen_7011(T16_, 3);
					add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T17_);
					nimZeroMem((void*)T18_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
					T18_[0] = tmp2;
					T18_[1] = getTypeDesc__cgen_6662(m, origType, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
					T18_[2] = rope__ropes_115(((NI64) (i)));
					T18_[3] = genTypeInfoV1__cgen_6798(m, a, info);
					T19_ = NIM_NIL;
					T19_ = percent___cgen_7212(T18_, 4);
					add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T19_);
					i_2 += ((NI) 1);
				} LA15: ;
			}
		}
		nimZeroMem((void*)T20_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
		T20_[0] = expr;
		T21_ = (NI)0;
		T21_ = len__ast_3990(typ);
		T20_[1] = rope__ropes_115(((NI64) (T21_)));
		T20_[2] = tmp;
		T22_ = NIM_NIL;
		T22_ = percent___cgen_7020(T20_, 3);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T22_);
	}
	goto LA2_;
	LA5_: ;
	{
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T24_;
		NI T25_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
		nimZeroMem((void*)T24_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T24_[0] = expr;
		T25_ = (NI)0;
		T25_ = len__ast_3990(typ);
		T24_[1] = rope__ropes_115(((NI64) (T25_)));
		T26_ = NIM_NIL;
		T26_ = percent___cgen_7028(T24_, 2);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T26_);
	}
	LA2_: ;
	nimZeroMem((void*)T27_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
	T27_[0] = tiNameForHcr__cgen_6814(m, name);
	T27_[1] = expr;
	T28_ = NIM_NIL;
	T28_ = percent___cgen_7164(T27_, 2);
	add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T28_);
}
N_LIB_PRIVATE N_NIMCALL(void, genTypeInfoAux__cgen_6883)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* origType, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* base;
	base = NIM_NIL;
	{
		NIM_BOOL T3_;
		NI T4_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T6_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* x;
		T3_ = (NIM_BOOL)0;
		T4_ = (NI)0;
		T4_ = len__ast_3990(typ);
		T3_ = (((NI) 0) < T4_);
		if (!(T3_)) goto LA5_;
		T6_ = NIM_NIL;
		T6_ = lastSon__ast_3731(typ);
		T3_ = !((T6_ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		LA5_: ;
		if (!T3_) goto LA7_;
		x = lastSon__ast_3731(typ);
		{
			if (!((*typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17))) goto LA11_;
			x = skipTypes__ast_3723(x, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_130);
		}
		LA11_: ;
		{
			NIM_BOOL T15_;
			NIM_BOOL T16_;
			NIM_BOOL T19_;
			T15_ = (NIM_BOOL)0;
			T16_ = (NIM_BOOL)0;
			T16_ = ((*typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21));
			if (!(T16_)) goto LA17_;
			T16_ = ((*x).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17));
			LA17_: ;
			T15_ = T16_;
			if (!(T15_)) goto LA18_;
			T19_ = (NIM_BOOL)0;
			T19_ = !(((*x).sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
			if (!(T19_)) goto LA20_;
			T19_ = ((1040 & (*(*x).sym).flags) == 16);
			LA20_: ;
			T15_ = T19_;
			LA18_: ;
			if (!T15_) goto LA21_;
			base = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_153));
		}
		goto LA13_;
		LA21_: ;
		{
			base = genTypeInfoV1__cgen_6798(m, x, info);
		}
		LA13_: ;
	}
	goto LA1_;
	LA7_: ;
	{
		base = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_153));
	}
	LA1_: ;
	genTypeInfoAuxBase__cgen_6818(m, typ, origType, name, base, info);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, lodeTyp__cgen_92)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = newNode__ast_3289(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1));
	asgnRef((void**) (&(*result).typ), t);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, getTemp__cgen_7373)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* result, NIM_BOOL needsInit) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T2_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T3_;
	NimStringDesc* res;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T4_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
	(*p).labels += ((NI) 1);
	T1_ = NIM_NIL;
	T1_ = rope__ropes_115(((NI64) ((*p).labels)));
	T2_ = NIM_NIL;
	T2_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_157), T1_);
	unsureAsgnRef((void**) (&(*result).r), amp___ropes_140(T2_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3)));
	T3_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T3_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
	res = rawNewString(((NI) 80));
	T4_ = NIM_NIL;
	T4_ = getTypeDesc__cgen_6662((*p).module, t, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
	cgFormatValue__cgen_147((&res), T4_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_13));
	cgFormatValue__cgen_147((&res), (*result).r);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA7_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA7_: ;
	T9_ = NIM_NIL;
	T9_ = rope__ropes_109(res);
	T10_ = NIM_NIL;
	T10_ = indentLine__cgen_286(p, T9_);
	add__ropes_159(T3_, T10_);
	(*result).k = ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 1);
	unsureAsgnRef((void**) (&(*result).lode), lodeTyp__cgen_92(t));
	(*result).storage = ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 2);
	(*result).flags = 0;
	constructLoc__cgen_10987(p, result, !(needsInit));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, lenField__cgen_447)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	NimStringDesc* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
		if (T4_) goto LA5_;
		T4_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
		LA5_: ;
		if (!T4_) goto LA6_;
		T1_ = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_159));
	}
	goto LA2_;
	LA6_: ;
	{
		T1_ = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_160));
	}
	LA2_: ;
	result = rope__ropes_109(T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, lenExpr__cgen_458)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0)) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = rdLoc__cgen_435(a);
		result = amp___ropes_140(T5_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_158));
	}
	goto LA1_;
	LA3_: ;
	{
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T7_;
		nimZeroMem((void*)T7_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T7_[0] = rdLoc__cgen_435(a);
		T7_[1] = lenField__cgen_447(p);
		result = percent___cgen_466(T7_, 2);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, cgFormatValue__cgen_157)(NimStringDesc** result, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ value) {
	addInt128__int495056_815(result, value);
}
static N_INLINE(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, parentObj__cgen_7474)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* accessor, tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*(*(*m).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
		if (T3_) goto LA4_;
		T3_ = (((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
		LA4_: ;
		if (!!(T3_)) goto LA5_;
		nimZeroMem((void*)T7_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T7_[0] = accessor;
		result = percent___cgen_7486(T7_, 1);
	}
	goto LA1_;
	LA5_: ;
	{
		result = accessor;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, mangleField__cgen_642)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = mangle__ccgutils_112((*name).s);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isKeyword__cgen_636(name);
		if (!T3_) goto LA4_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_72));
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, mangleRecFieldName__cgen_3649)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	{
		if (!!(((192 & (*field).flags) == 0))) goto LA3_;
		result = (*field).loc.r;
	}
	goto LA1_;
	LA3_: ;
	{
		NimStringDesc* T6_;
		T6_ = NIM_NIL;
		T6_ = mangleField__cgen_642(m, (*field).name);
		result = rope__ropes_109(T6_);
	}
	LA1_: ;
	{
		if (!(result == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA9_;
		internalErrorImpl__msgs_1441((*(*m).g).config, (*field).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_173), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_174);
	}
	LA9_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genRecordFieldsAux__cgen_3665)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* rectype, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* check, NimStringDesc* unionPrefix) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
{	result = NIM_NIL;
	result = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 138):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					T5_ = NIM_NIL;
					T5_ = genRecordFieldsAux__cgen_3665(m, (*n)._kind_6.sons->data[i], rectype, check, unionPrefix);
					add__ropes_159(&result, T5_);
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 139):
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* unionBody;
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)))) goto LA9_;
			internalErrorImpl__msgs_1441((*(*m).g).config, (*n).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_171), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_172);
		}
		LA9_: ;
		T11_ = NIM_NIL;
		T11_ = genRecordFieldsAux__cgen_3665(m, (*n)._kind_6.sons->data[((NI) 0)], rectype, check, unionPrefix);
		add__ropes_159(&result, T11_);
		unionBody = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3155(n);
			i_4 = ((NI) 1);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA14;
					i_3 = i_4;
					switch ((*(*n)._kind_6.sons->data[i_3]).kind) {
					case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 85):
					case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 88):
					{
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* k;
						k = lastSon__ast_4833((*n)._kind_6.sons->data[i_3]);
						{
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* structName;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T21_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
							NimStringDesc* T23_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* a;
							NimStringDesc* T24_;
							NimStringDesc* T25_;
							if (!!(((*k).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)))) goto LA18_;
							T20_ = NIM_NIL;
							T20_ = mangleRecFieldName__cgen_3649(m, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
							T21_ = NIM_NIL;
							T21_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3), T20_);
							T22_ = NIM_NIL;
							T22_ = amp___ropes_140(T21_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3));
							T23_ = NIM_NIL;
							T23_ = dollar___systemZdollars_3(i_3);
							structName = amp___ropes_140(T22_, T23_);
							T24_ = NIM_NIL;
							T25_ = NIM_NIL;
							T25_ = dollar___ropes_250(structName);
							T24_ = rawNewString((unionPrefix ? unionPrefix->Sup.len : 0) + (T25_ ? T25_->Sup.len : 0) + 1);
appendString(T24_, unionPrefix);
appendString(T24_, T25_);
appendString(T24_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_138));
							a = genRecordFieldsAux__cgen_3665(m, k, rectype, check, T24_);
							{
								tyArray__ts9cf9blICas1QWmw89bglZ7w T42_;
								tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T43_;
								if (!!((a == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA28_;
								{
									if (!!((((*rectype).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 23))&63U)))!=0))) goto LA32_;
									add__ropes_162(&unionBody, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_175));
								}
								goto LA30_;
								LA32_: ;
								{
									{
										if (!((CC__extccomp_510[((*(*(*m).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__9biNtFPzjM9c2i62RuZ9c19biA) 7))&7U)))!=0)) goto LA37_;
										add__ropes_162(&unionBody, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_176));
									}
									goto LA35_;
									LA37_: ;
									{
										tyArray__dAmhZbEWrTM5xES2bTVweg T40_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T41_;
										nimZeroMem((void*)T40_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
										T41_ = NIM_NIL;
										T41_ = percent___cgen_3722(T40_, 0);
										add__ropes_159(&unionBody, T41_);
									}
									LA35_: ;
								}
								LA30_: ;
								add__ropes_159(&unionBody, a);
								nimZeroMem((void*)T42_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
								T42_[0] = structName;
								T43_ = NIM_NIL;
								T43_ = percent___cgen_3727(T42_, 1);
								add__ropes_159(&unionBody, T43_);
								{
									NIM_BOOL T46_;
									tyArray__dAmhZbEWrTM5xES2bTVweg T50_;
									tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T51_;
									T46_ = (NIM_BOOL)0;
									T46_ = (((*rectype).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 23))&63U)))!=0);
									if (!(T46_)) goto LA47_;
									T46_ = !(((CC__extccomp_510[((*(*(*m).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__9biNtFPzjM9c2i62RuZ9c19biA) 7))&7U)))!=0));
									LA47_: ;
									if (!T46_) goto LA48_;
									nimZeroMem((void*)T50_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
									T51_ = NIM_NIL;
									T51_ = percent___cgen_3740(T50_, 0);
									add__ropes_159(&unionBody, T51_);
								}
								LA48_: ;
							}
							LA28_: ;
						}
						goto LA16_;
						LA18_: ;
						{
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T53_;
							T53_ = NIM_NIL;
							T53_ = genRecordFieldsAux__cgen_3665(m, k, rectype, check, unionPrefix);
							add__ropes_159(&unionBody, T53_);
						}
						LA16_: ;
					}
					break;
					default:
					{
						internalErrorImpl__msgs_1441((*(*m).g).config, unknownLineInfo__lineinfos_284, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_177), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_178);
					}
					break;
					}
					i_4 += ((NI) 1);
				} LA14: ;
			}
		}
		{
			tyArray__ts9cf9blICas1QWmw89bglZ7w T59_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T60_;
			if (!!((unionBody == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA57_;
			nimZeroMem((void*)T59_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T59_[0] = unionBody;
			T60_ = NIM_NIL;
			T60_ = percent___cgen_3749(T59_, 1);
			add__ropes_159(&result, T60_);
		}
		LA57_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* sname;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T66_;
		field = (*n)._kind_4.sym;
		{
			if (!((*(*field).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 63))) goto LA64_;
			goto BeforeRet_;
		}
		LA64_: ;
		sname = mangleRecFieldName__cgen_3649(m, field);
		T66_ = NIM_NIL;
		T66_ = amp___ropes_144(unionPrefix, sname);
		fillLoc__cgen_71((&(*field).loc), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 5), n, T66_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
		{
			tyArray__ts9cf9blICas1QWmw89bglZ7w T71_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T72_;
			if (!(((NI) 0) < (*field)._kind_2.alignment)) goto LA69_;
			nimZeroMem((void*)T71_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T71_[0] = rope__ropes_115(((NI64) ((*field)._kind_2.alignment)));
			T72_ = NIM_NIL;
			T72_ = percent___cgen_3760(T71_, 1);
			add__ropes_159(&result, T72_);
		}
		LA69_: ;
		{
			NIM_BOOL T75_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* noAlias;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* fieldType;
			T75_ = (NIM_BOOL)0;
			T75_ = isImportedCppType__cgen_1312(rectype);
			if (!!(T75_)) goto LA76_;
			{
				tyArray__dAmhZbEWrTM5xES2bTVweg T82_;
				if (!(((*field).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 46))&63U)))!=0)) goto LA80_;
				nimZeroMem((void*)T82_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
				noAlias = percent___cgen_3769(T82_, 0);
			}
			goto LA78_;
			LA80_: ;
			{
				noAlias = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
			}
			LA78_: ;
			fieldType = skipTypes__ast_3723((*(*field).loc.lode).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
			{
				tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T88_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T89_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T90_;
				if (!((*fieldType).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 49))) goto LA86_;
				nimZeroMem((void*)T88_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
				T89_ = NIM_NIL;
				T89_ = elemType__types_263(fieldType);
				T88_[0] = getTypeDescAux__cgen_1332(m, T89_, check, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19));
				T88_[1] = sname;
				T90_ = NIM_NIL;
				T90_ = percent___cgen_3780(T88_, 2);
				add__ropes_159(&result, T90_);
			}
			goto LA84_;
			LA86_: ;
			{
				tyArray__FKvM4FDhljtt88k8FkGthA T94_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T95_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T96_;
				if (!((*fieldType).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24))) goto LA92_;
				nimZeroMem((void*)T94_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
				T95_ = NIM_NIL;
				T95_ = t__cgen_85((*field).loc);
				T94_[0] = getTypeDescWeak__cgen_3345(m, T95_, check, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19));
				T94_[1] = sname;
				T94_[2] = noAlias;
				T96_ = NIM_NIL;
				T96_ = percent___cgen_3789(T94_, 3);
				add__ropes_159(&result, T96_);
			}
			goto LA84_;
			LA92_: ;
			{
				tyArray__InO6xIOhXMnkCXPnEYWwWg T100_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T101_;
				NimStringDesc* T102_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T103_;
				if (!!(((*field)._kind_2.bitsize == ((NI) 0)))) goto LA98_;
				nimZeroMem((void*)T100_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
				T101_ = NIM_NIL;
				T101_ = t__cgen_85((*field).loc);
				T100_[0] = getTypeDescAux__cgen_1332(m, T101_, check, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19));
				T100_[1] = sname;
				T102_ = NIM_NIL;
				T102_ = dollar___systemZdollars_3((*field)._kind_2.bitsize);
				T100_[2] = rope__ropes_109(T102_);
				T100_[3] = noAlias;
				T103_ = NIM_NIL;
				T103_ = percent___cgen_3794(T100_, 4);
				add__ropes_159(&result, T103_);
			}
			goto LA84_;
			LA98_: ;
			{
				tyArray__FKvM4FDhljtt88k8FkGthA T105_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T106_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T107_;
				nimZeroMem((void*)T105_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
				T106_ = NIM_NIL;
				T106_ = t__cgen_85((*field).loc);
				T105_[0] = getTypeDescAux__cgen_1332(m, T106_, check, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19));
				T105_[1] = sname;
				T105_[2] = noAlias;
				T107_ = NIM_NIL;
				T107_ = percent___cgen_3789(T105_, 3);
				add__ropes_159(&result, T107_);
			}
			LA84_: ;
		}
		LA76_: ;
	}
	break;
	default:
	{
		internalErrorImpl__msgs_1441((*(*m).g).config, (*n).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_179), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_180);
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getRecordFields__cgen_3803)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* check) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	result = genRecordFieldsAux__cgen_3665(m, (*typ).n, typ, check, ((NimStringDesc*) NIM_NIL));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, fillObjectFields__cgen_3808)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ) {
	tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw check;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	nimZeroMem((void*)(&check), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
	initIntSet__pureZcollectionsZintsets_238((&check));
	T1_ = NIM_NIL;
	T1_ = getRecordFields__cgen_3803(m, typ, (&check));
	(void)(T1_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, intLiteral__cgen_11536)(NI64 i) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (IL64(-2147483648) < i);
		if (!(T3_)) goto LA4_;
		T3_ = (i <= IL64(2147483647));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = rope__ropes_115(i);
	}
	goto LA1_;
	LA5_: ;
	{
		tyArray__dAmhZbEWrTM5xES2bTVweg T10_;
		if (!(i == IL64(-2147483648))) goto LA8_;
		nimZeroMem((void*)T10_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		result = percent___cgen_17756(T10_, 0);
	}
	goto LA1_;
	LA8_: ;
	{
		tyArray__ts9cf9blICas1QWmw89bglZ7w T14_;
		if (!((IL64(-9223372036854775807) - IL64(1)) < i)) goto LA12_;
		nimZeroMem((void*)T14_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T14_[0] = rope__ropes_115(i);
		result = percent___cgen_17728(T14_, 1);
	}
	goto LA1_;
	LA12_: ;
	{
		tyArray__dAmhZbEWrTM5xES2bTVweg T16_;
		nimZeroMem((void*)T16_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		result = percent___cgen_17733(T16_, 0);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, int64Literal__cgen_17721)(NI64 i) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	{
		tyArray__ts9cf9blICas1QWmw89bglZ7w T5_;
		if (!((IL64(-9223372036854775807) - IL64(1)) < i)) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T5_[0] = rope__ropes_115(i);
		result = percent___cgen_17728(T5_, 1);
	}
	goto LA1_;
	LA3_: ;
	{
		tyArray__dAmhZbEWrTM5xES2bTVweg T7_;
		nimZeroMem((void*)T7_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		result = percent___cgen_17733(T7_, 0);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, uint64Literal__cgen_17738)(NU64 i) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T2_ = NIM_NIL;
	T2_ = dollar___systemZdollars_9(i);
	T1_ = rawNewString((T2_ ? T2_->Sup.len : 0) + 3);
appendString(T1_, T2_);
appendString(T1_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_184));
	result = rope__ropes_109(T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genNilStringLiteral__cgen_613)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	NimStringDesc* res;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	result = NIM_NIL;
	res = rawNewString(((NI) 80));
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_29));
	T1_ = NIM_NIL;
	T1_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_30));
	cgFormatValue__cgen_147((&res), T1_);
	res = resizeString(res, 11);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_31));
	result = rope__ropes_109(res);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genLiteral__cgen_17776)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ty) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 15):
	{
		tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg k;
		k = (tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg)0;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T6_;
			if (!!((ty == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA4_;
			T6_ = NIM_NIL;
			T6_ = skipTypes__ast_3723(ty, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_183);
			k = (*T6_).kind;
		}
		goto LA2_;
		LA4_: ;
		{
			switch ((*n).kind) {
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5):
			{
				k = ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2);
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 15):
			{
				k = ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44);
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 10):
			{
				k = ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35);
			}
			break;
			default:
			{
				k = ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 5);
			}
			break;
			}
		}
		LA2_: ;
		switch (k) {
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2):
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 5):
		{
			result = intLiteral__cgen_11536((*n)._kind_1.intVal);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1):
		{
			{
				tyArray__dAmhZbEWrTM5xES2bTVweg T18_;
				if (!!(((*n)._kind_1.intVal == IL64(0)))) goto LA16_;
				nimZeroMem((void*)T18_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
				result = percent___cgen_17786(T18_, 0);
			}
			goto LA14_;
			LA16_: ;
			{
				tyArray__dAmhZbEWrTM5xES2bTVweg T20_;
				nimZeroMem((void*)T20_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
				result = percent___cgen_17791(T20_, 0);
			}
			LA14_: ;
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35):
		{
			result = int64Literal__cgen_17721((*n)._kind_1.intVal);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44):
		{
			result = uint64Literal__cgen_17738(((NU64) ((*n)._kind_1.intVal)));
		}
		break;
		default:
		{
			tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T24_;
			nimZeroMem((void*)T24_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
			T24_[0] = getTypeDesc__cgen_6662((*p).module, ty, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			T24_[1] = intLiteral__cgen_11536((*n)._kind_1.intVal);
			result = percent___cgen_17796(T24_, 2);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
	{
		tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg k_2;
		{
			if (!(ty == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA28_;
			k_2 = ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 26);
		}
		goto LA26_;
		LA28_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T31_;
			T31_ = NIM_NIL;
			T31_ = skipTypes__ast_3723(ty, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_183);
			k_2 = (*T31_).kind;
		}
		LA26_: ;
		{
			NIM_BOOL T34_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T36_;
			NI id;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T39_;
			T34_ = (NIM_BOOL)0;
			T34_ = (k_2 == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25));
			if (!(T34_)) goto LA35_;
			T36_ = NIM_NIL;
			T36_ = skipTypes__ast_3723(ty, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_183);
			T34_ = ((*T36_).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
			LA35_: ;
			if (!T34_) goto LA37_;
			id = nodeTableTestOrSet__treetab_198((&(*(*p).module).dataCache), n, ((NI) ((*(*p).module).labels)));
			T39_ = NIM_NIL;
			T39_ = rope__ropes_115(((NI64) (id)));
			result = amp___ropes_128((*(*p).module).tmpBase, T39_);
			{
				tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T44_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T45_;
				if (!(id == ((NI) ((*(*p).module).labels)))) goto LA42_;
				(*(*p).module).labels += ((NI) 1);
				nimZeroMem((void*)T44_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
				T44_[0] = getTypeDesc__cgen_6662((*p).module, ty, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
				T44_[1] = result;
				T45_ = NIM_NIL;
				T45_ = percent___cgen_17819(T44_, 2);
				add__ropes_159(&(*(*p).module).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 9))- 0], T45_);
			}
			LA42_: ;
		}
		goto LA32_;
		LA37_: ;
		{
			if (!(k_2 == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 26) || k_2 == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 5) || k_2 == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25))) goto LA47_;
			result = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_119));
		}
		goto LA32_;
		LA47_: ;
		{
			tyArray__ts9cf9blICas1QWmw89bglZ7w T50_;
			nimZeroMem((void*)T50_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T50_[0] = getTypeDesc__cgen_6662((*p).module, ty, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			result = percent___cgen_17828(T50_, 1);
		}
		LA32_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22):
	{
		tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg k_3;
		{
			if (!(ty == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA54_;
			k_3 = ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28);
		}
		goto LA52_;
		LA54_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T57_;
			T57_ = NIM_NIL;
			T57_ = skipTypes__ast_3723(ty, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_185);
			k_3 = (*T57_).kind;
		}
		LA52_: ;
		switch (k_3) {
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 5):
		{
			result = genNilStringLiteral__cgen_613((*p).module, (*n).info);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
		{
			{
				NIM_BOOL T62_;
				T62_ = (NIM_BOOL)0;
				T62_ = (((*n)._kind_3.strVal ? (*n)._kind_3.strVal->Sup.len : 0) == ((NI) 0));
				if (!(T62_)) goto LA63_;
				T62_ = !((((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0));
				LA63_: ;
				if (!T62_) goto LA64_;
				result = genNilStringLiteral__cgen_613((*p).module, (*n).info);
			}
			goto LA60_;
			LA64_: ;
			{
				result = genStringLiteral__cgen_626((*p).module, n);
			}
			LA60_: ;
		}
		break;
		default:
		{
			result = makeCString__msgs_50((*n)._kind_3.strVal);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 16):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 18):
	{
		{
			NimStringDesc* T73_;
			if (!((*ty).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 37))) goto LA71_;
			T73_ = NIM_NIL;
			T73_ = toStrMaxPrecision__cgen_17850(((NF32) ((*n)._kind_2.floatVal)));
			result = rope__ropes_109(T73_);
		}
		goto LA69_;
		LA71_: ;
		{
			NimStringDesc* T75_;
			T75_ = NIM_NIL;
			T75_ = toStrMaxPrecision__astalgo_920((*n)._kind_2.floatVal);
			result = rope__ropes_109(T75_);
		}
		LA69_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 17):
	{
		NimStringDesc* T77_;
		T77_ = NIM_NIL;
		T77_ = toStrMaxPrecision__cgen_17850(((NF32) ((*n)._kind_2.floatVal)));
		result = rope__ropes_109(T77_);
	}
	break;
	default:
	{
		NimStringDesc* T79_;
		T79_ = NIM_NIL;
		T79_ = rawNewString((reprEnum((NI)(*n).kind, (&NTItnodekind__clSgDh22o9au33BrVH9bDQZw_)) ? reprEnum((NI)(*n).kind, (&NTItnodekind__clSgDh22o9au33BrVH9bDQZw_))->Sup.len : 0) + 12);
appendString(T79_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_186));
appendString(T79_, reprEnum((NI)(*n).kind, (&NTItnodekind__clSgDh22o9au33BrVH9bDQZw_)));
appendChar(T79_, 41);
		internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*n).info, T79_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_187);
		result = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genLiteral__cgen_11538)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	result = genLiteral__cgen_17776(p, n, (*n).typ);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genCaseRange__cgen_7370)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* branch) {
	{
		NI j;
		NI colontmp_;
		NI T2_;
		NI i;
		j = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (NI)0;
		T2_ = len__ast_3155(branch);
		colontmp_ = (NI)(T2_ - ((NI) 1));
		i = ((NI) 0);
		{
			while (1) {
				if (!(i < colontmp_)) goto LA4;
				j = i;
				{
					if (!((*(*branch)._kind_6.sons->data[j]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 44))) goto LA7_;
					{
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T13_;
						tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T14_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
						if (!((CC__extccomp_510[((*(*(*(*p).module).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__9biNtFPzjM9c2i62RuZ9c19biA) 0))&7U)))!=0)) goto LA11_;
						T13_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
						T13_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
						nimZeroMem((void*)T14_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
						T14_[0] = genLiteral__cgen_11538(p, (*(*branch)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 0)]);
						T14_[1] = genLiteral__cgen_11538(p, (*(*branch)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 1)]);
						T15_ = NIM_NIL;
						T15_ = percent___cgen_15427(T14_, 2);
						T16_ = NIM_NIL;
						T16_ = indentLine__cgen_286(p, T15_);
						add__ropes_159(T13_, T16_);
					}
					goto LA9_;
					LA11_: ;
					{
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* v;
						v = copyNode__ast_4324((*(*branch)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 0)]);
						{
							while (1) {
								tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T20_;
								tyArray__ts9cf9blICas1QWmw89bglZ7w T21_;
								tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
								tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
								if (!((*v)._kind_1.intVal <= (*(*(*branch)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 1)])._kind_1.intVal)) goto LA19;
								T20_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
								T20_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
								nimZeroMem((void*)T21_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
								T21_[0] = genLiteral__cgen_11538(p, v);
								T22_ = NIM_NIL;
								T22_ = percent___cgen_15437(T21_, 1);
								T23_ = NIM_NIL;
								T23_ = indentLine__cgen_286(p, T22_);
								add__ropes_159(T20_, T23_);
								(*v)._kind_1.intVal += ((NI) 1);
							} LA19: ;
						}
					}
					LA9_: ;
				}
				goto LA5_;
				LA7_: ;
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T25_;
					tyArray__ts9cf9blICas1QWmw89bglZ7w T26_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T27_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T28_;
					T25_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T25_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					nimZeroMem((void*)T26_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
					T26_[0] = genLiteral__cgen_11538(p, (*branch)._kind_6.sons->data[j]);
					T27_ = NIM_NIL;
					T27_ = percent___cgen_15437(T26_, 1);
					T28_ = NIM_NIL;
					T28_ = indentLine__cgen_286(p, T27_);
					add__ropes_159(T25_, T28_);
				}
				LA5_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genTraverseProc__cgen_7378)(tyObject_TTraversalClosure__4DrvOBPCF3NL9akdOcxiJCw c, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* accessor, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ) {
{	{
		if (!(n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 138):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA8;
					i = i_2;
					genTraverseProc__cgen_7378(c, accessor, (*n)._kind_6.sons->data[i], typ);
					i_2 += ((NI) 1);
				} LA8: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 139):
	{
		tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* disc;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T23_;
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T24_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T44_;
		tyArray__dAmhZbEWrTM5xES2bTVweg T45_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T46_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T47_;
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)))) goto LA12_;
			internalErrorImpl__msgs_1441((*(*(*c.p).module).g).config, (*n).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_168), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_169);
		}
		LA12_: ;
		p = c.p;
		disc = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		{
			if (!((*disc).loc.r == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA16_;
			fillObjectFields__cgen_3808((*c.p).module, typ);
		}
		LA16_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T20_;
			T20_ = NIM_NIL;
			T20_ = t__cgen_85((*disc).loc);
			if (!(T20_ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA21_;
			internalErrorImpl__msgs_1441((*(*(*c.p).module).g).config, (*n).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_181), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_182);
		}
		LA21_: ;
		T23_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T23_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		nimZeroMem((void*)T24_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T24_[0] = accessor;
		T24_[1] = (*disc).loc.r;
		T25_ = NIM_NIL;
		T25_ = percent___cgen_7412(T24_, 2);
		T26_ = NIM_NIL;
		T26_ = indentLine__cgen_286(p, T25_);
		add__ropes_159(T23_, T26_);
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3155(n);
			i_4 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* branch;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T39_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T40_;
					tyArray__dAmhZbEWrTM5xES2bTVweg T41_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T42_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T43_;
					if (!(i_4 < colontmp__2)) goto LA29;
					i_3 = i_4;
					branch = (*n)._kind_6.sons->data[i_3];
					{
						if (!((*branch).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 85))) goto LA32_;
						genCaseRange__cgen_7370(c.p, branch);
					}
					goto LA30_;
					LA32_: ;
					{
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T35_;
						tyArray__dAmhZbEWrTM5xES2bTVweg T36_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T37_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
						T35_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
						T35_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
						nimZeroMem((void*)T36_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
						T37_ = NIM_NIL;
						T37_ = percent___cgen_7438(T36_, 0);
						T38_ = NIM_NIL;
						T38_ = indentLine__cgen_286(p, T37_);
						add__ropes_159(T35_, T38_);
					}
					LA30_: ;
					T39_ = NIM_NIL;
					T39_ = lastSon__ast_4833(branch);
					genTraverseProc__cgen_7378(c, accessor, T39_, typ);
					T40_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T40_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					nimZeroMem((void*)T41_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
					T42_ = NIM_NIL;
					T42_ = percent___cgen_7446(T41_, 0);
					T43_ = NIM_NIL;
					T43_ = indentLine__cgen_286(p, T42_);
					add__ropes_159(T40_, T43_);
					i_4 += ((NI) 1);
				} LA29: ;
			}
		}
		T44_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T44_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		nimZeroMem((void*)T45_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		T46_ = NIM_NIL;
		T46_ = percent___cgen_7451(T45_, 0);
		T47_ = NIM_NIL;
		T47_ = indentLine__cgen_286(p, T46_);
		add__ropes_159(T44_, T47_);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field;
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T62_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T63_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T64_;
		field = (*n)._kind_4.sym;
		{
			if (!((*(*field).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 63))) goto LA51_;
			goto BeforeRet_;
		}
		LA51_: ;
		{
			if (!((*field).loc.r == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA55_;
			fillObjectFields__cgen_3808((*c.p).module, typ);
		}
		LA55_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T59_;
			T59_ = NIM_NIL;
			T59_ = t__cgen_85((*field).loc);
			if (!(T59_ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA60_;
			internalErrorImpl__msgs_1441((*(*(*c.p).module).g).config, (*n).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_181), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_189);
		}
		LA60_: ;
		nimZeroMem((void*)T62_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T62_[0] = accessor;
		T62_[1] = (*field).loc.r;
		T63_ = NIM_NIL;
		T63_ = percent___cgen_7469(T62_, 2);
		T64_ = NIM_NIL;
		T64_ = t__cgen_85((*field).loc);
		genTraverseProc__cgen_7366(c, T63_, T64_);
	}
	break;
	default:
	{
		internalErrorImpl__msgs_1441((*(*(*c.p).module).g).config, (*n).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_181), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_190);
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genTraverseProc__cgen_7366)(tyObject_TTraversalClosure__4DrvOBPCF3NL9akdOcxiJCw c, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* accessor, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ) {
	tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p;
{	{
		if (!(typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	p = c.p;
	switch ((*typ).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 10):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 4):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 13):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 55):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T6_;
		T6_ = NIM_NIL;
		T6_ = lastSon__ast_3731(typ);
		genTraverseProc__cgen_7366(c, accessor, T6_);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ arraySize;
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw i;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T8_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* oldCode;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T9_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T10_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
		NI oldLen;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T17_;
		NimStringDesc* res_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
		arraySize = lengthOrd__types_1723((*(*(*c.p).module).g).config, (*typ).sons->data[((NI) 0)]);
		nimZeroMem((void*)(&i), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		T8_ = NIM_NIL;
		T8_ = getSysType__magicsys_60((*(*(*c.p).module).g).graph, unknownLineInfo__lineinfos_284, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31));
		getTemp__cgen_7373(p, T8_, (&i), NIM_FALSE);
		T9_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T9_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		oldCode = (*T9_);
		T10_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T10_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 5);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_161));
		cgFormatValue__cgen_147((&res), i.r);
		res = resizeString(res, 6);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_162));
		cgFormatValue__cgen_147((&res), i.r);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_163));
		cgFormatValue__cgen_157((&res), arraySize);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_164));
		cgFormatValue__cgen_147((&res), i.r);
		res = resizeString(res, 5);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_165));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA13_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA13_: ;
		T15_ = NIM_NIL;
		T15_ = rope__ropes_109(res);
		T16_ = NIM_NIL;
		T16_ = indentLine__cgen_286(p, T15_);
		add__ropes_159(T10_, T16_);
		T17_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T17_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		oldLen = len__ropes_10((*T17_));
		res_2 = rawNewString(((NI) 80));
		cgFormatValue__cgen_147((&res_2), accessor);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_166));
		cgFormatValue__cgen_147((&res_2), i.r);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_167));
		T18_ = NIM_NIL;
		T18_ = rope__ropes_109(res_2);
		genTraverseProc__cgen_7366(c, T18_, (*typ).sons->data[((NI) 1)]);
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T21_;
			NI T22_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T25_;
			T21_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T21_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			T22_ = (NI)0;
			T22_ = len__ropes_10((*T21_));
			if (!(T22_ == oldLen)) goto LA23_;
			T25_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T25_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			unsureAsgnRef((void**) (&(*T25_)), oldCode);
		}
		goto LA19_;
		LA23_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T27_;
			tyArray__dAmhZbEWrTM5xES2bTVweg T28_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T29_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T30_;
			T27_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T27_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			nimZeroMem((void*)T28_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
			T29_ = NIM_NIL;
			T29_ = percent___cgen_7535(T28_, 0);
			T30_ = NIM_NIL;
			T30_ = indentLine__cgen_286(p, T29_);
			add__ropes_159(T27_, T30_);
		}
		LA19_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17):
	{
		{
			NI i_2;
			NI colontmp_;
			NI i_3;
			i_2 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3990(typ);
			i_3 = ((NI) 0);
			{
				while (1) {
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* x;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T39_;
					if (!(i_3 < colontmp_)) goto LA34;
					i_2 = i_3;
					x = (*typ).sons->data[i_2];
					{
						if (!!((x == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA37_;
						x = skipTypes__ast_3723(x, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_130);
					}
					LA37_: ;
					T39_ = NIM_NIL;
					T39_ = parentObj__cgen_7474(accessor, (*c.p).module);
					genTraverseProc__cgen_7366(c, T39_, x);
					i_3 += ((NI) 1);
				} LA34: ;
			}
		}
		{
			if (!!(((*typ).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA42_;
			genTraverseProc__cgen_7378(c, accessor, (*typ).n, typ);
		}
		LA42_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ_2;
		typ_2 = typ;
		{
			NI i_4;
			NI colontmp__2;
			NI i_5;
			i_4 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3990(typ_2);
			i_5 = ((NI) 0);
			{
				while (1) {
					NimStringDesc* res_3;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T48_;
					if (!(i_5 < colontmp__2)) goto LA47;
					i_4 = i_5;
					res_3 = rawNewString(((NI) 80));
					cgFormatValue__cgen_147((&res_3), accessor);
					res_3 = resizeString(res_3, 6);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_191));
					cgFormatValue__cgen_154((&res_3), ((NI64) (i_4)));
					T48_ = NIM_NIL;
					T48_ = rope__ropes_109(res_3);
					genTraverseProc__cgen_7366(c, T48_, (*typ_2).sons->data[i_4]);
					i_5 += ((NI) 1);
				} LA47: ;
			}
		}
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22):
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T50_;
		NimStringDesc* res_4;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T51_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T56_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T57_;
		T50_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T50_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_4 = rawNewString(((NI) 80));
		T51_ = NIM_NIL;
		T51_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_192));
		cgFormatValue__cgen_147((&res_4), T51_);
		res_4 = resizeString(res_4, 8);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_126));
		cgFormatValue__cgen_147((&res_4), accessor);
		res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		cgFormatValue__cgen_151((&res_4), c.visitorFrmt);
		res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA54_;
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA54_: ;
		T56_ = NIM_NIL;
		T56_ = rope__ropes_109(res_4);
		T57_ = NIM_NIL;
		T57_ = indentLine__cgen_286(p, T56_);
		add__ropes_159(T50_, T57_);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
	{
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T63_;
			NimStringDesc* res_5;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T64_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T69_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T70_;
			if (!!((((*(*(*(*c.p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0))) goto LA61_;
			T63_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T63_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_5 = rawNewString(((NI) 80));
			T64_ = NIM_NIL;
			T64_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_192));
			cgFormatValue__cgen_147((&res_5), T64_);
			res_5 = resizeString(res_5, 8);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_126));
			cgFormatValue__cgen_147((&res_5), accessor);
			res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			cgFormatValue__cgen_151((&res_5), c.visitorFrmt);
			res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA67_;
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA67_: ;
			T69_ = NIM_NIL;
			T69_ = rope__ropes_109(res_5);
			T70_ = NIM_NIL;
			T70_ = indentLine__cgen_286(p, T69_);
			add__ropes_159(T63_, T70_);
		}
		goto LA59_;
		LA61_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T72_;
			NIM_BOOL T73_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T76_;
			NimStringDesc* res_6;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T77_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T82_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T83_;
			T72_ = NIM_NIL;
			T72_ = lastSon__ast_3731(typ);
			T73_ = (NIM_BOOL)0;
			T73_ = containsGarbageCollectedRef__types_612(T72_);
			if (!T73_) goto LA74_;
			T76_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T76_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_6 = rawNewString(((NI) 80));
			T77_ = NIM_NIL;
			T77_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_193));
			cgFormatValue__cgen_147((&res_6), T77_);
			res_6 = resizeString(res_6, 8);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_126));
			cgFormatValue__cgen_147((&res_6), accessor);
			res_6 = resizeString(res_6, 2);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			cgFormatValue__cgen_151((&res_6), c.visitorFrmt);
			res_6 = resizeString(res_6, 2);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA80_;
				res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA80_: ;
			T82_ = NIM_NIL;
			T82_ = rope__ropes_109(res_6);
			T83_ = NIM_NIL;
			T83_ = indentLine__cgen_286(p, T82_);
			add__ropes_159(T76_, T83_);
		}
		goto LA59_;
		LA74_: ;
		LA59_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
	{
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T89_;
			NimStringDesc* res_7;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T90_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T95_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T96_;
			if (!!((((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 31))&63U)))!=0))) goto LA87_;
			T89_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T89_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_7 = rawNewString(((NI) 80));
			T90_ = NIM_NIL;
			T90_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_192));
			cgFormatValue__cgen_147((&res_7), T90_);
			res_7 = resizeString(res_7, 8);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_126));
			cgFormatValue__cgen_147((&res_7), accessor);
			res_7 = resizeString(res_7, 2);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			cgFormatValue__cgen_151((&res_7), c.visitorFrmt);
			res_7 = resizeString(res_7, 2);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA93_;
				res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA93_: ;
			T95_ = NIM_NIL;
			T95_ = rope__ropes_109(res_7);
			T96_ = NIM_NIL;
			T96_ = indentLine__cgen_286(p, T95_);
			add__ropes_159(T89_, T96_);
		}
		LA87_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25):
	{
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T102_;
			NimStringDesc* res_8;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T103_;
			NimStringDesc* res_9;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T104_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T109_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T110_;
			if (!((*typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9))) goto LA100_;
			T102_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T102_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_8 = rawNewString(((NI) 80));
			T103_ = NIM_NIL;
			T103_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_192));
			cgFormatValue__cgen_147((&res_8), T103_);
			res_8 = resizeString(res_8, 8);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_126));
			res_9 = rawNewString(((NI) 80));
			cgFormatValue__cgen_147((&res_9), accessor);
			res_9 = resizeString(res_9, 6);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_194));
			T104_ = NIM_NIL;
			T104_ = rope__ropes_109(res_9);
			cgFormatValue__cgen_147((&res_8), T104_);
			res_8 = resizeString(res_8, 2);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			cgFormatValue__cgen_151((&res_8), c.visitorFrmt);
			res_8 = resizeString(res_8, 2);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA107_;
				res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA107_: ;
			T109_ = NIM_NIL;
			T109_ = rope__ropes_109(res_8);
			T110_ = NIM_NIL;
			T110_ = indentLine__cgen_286(p, T109_);
			add__ropes_159(T102_, T110_);
		}
		LA100_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, dataField__cgen_479)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	{
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0)) goto LA3_;
		result = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_195));
	}
	goto LA1_;
	LA3_: ;
	{
		result = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_196));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genTraverseProcSeq__cgen_7491)(tyObject_TTraversalClosure__4DrvOBPCF3NL9akdOcxiJCw c, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* accessor, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ) {
	tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw i;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* oldCode;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T2_;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T3_;
	tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T4_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
	NI oldLen;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T7_;
	tyArray__FKvM4FDhljtt88k8FkGthA T8_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
	p = c.p;
	nimZeroMem((void*)(&i), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	T1_ = NIM_NIL;
	T1_ = getSysType__magicsys_60((*(*(*c.p).module).g).graph, unknownLineInfo__lineinfos_284, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31));
	getTemp__cgen_7373(p, T1_, (&i), NIM_FALSE);
	T2_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T2_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	oldCode = (*T2_);
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	a.r = accessor;
	T3_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T3_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	nimZeroMem((void*)T4_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
	T4_[0] = i.r;
	T4_[1] = lenExpr__cgen_458(c.p, a);
	T5_ = NIM_NIL;
	T5_ = percent___cgen_7681(T4_, 2);
	T6_ = NIM_NIL;
	T6_ = indentLine__cgen_286(p, T5_);
	add__ropes_159(T3_, T6_);
	T7_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T7_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	oldLen = len__ropes_10((*T7_));
	nimZeroMem((void*)T8_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
	T8_[0] = accessor;
	T8_[1] = i.r;
	T8_[2] = dataField__cgen_479(c.p);
	T9_ = NIM_NIL;
	T9_ = percent___cgen_7687(T8_, 3);
	genTraverseProc__cgen_7366(c, T9_, (*typ).sons->data[((NI) 0)]);
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T12_;
		NI T13_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T16_;
		T12_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T12_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		T13_ = (NI)0;
		T13_ = len__ropes_10((*T12_));
		if (!(T13_ == oldLen)) goto LA14_;
		T16_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T16_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		unsureAsgnRef((void**) (&(*T16_)), oldCode);
	}
	goto LA10_;
	LA14_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T18_;
		tyArray__dAmhZbEWrTM5xES2bTVweg T19_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T21_;
		T18_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T18_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		nimZeroMem((void*)T19_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		T20_ = NIM_NIL;
		T20_ = percent___cgen_7535(T19_, 0);
		T21_ = NIM_NIL;
		T21_ = indentLine__cgen_286(p, T20_);
		add__ropes_159(T18_, T21_);
	}
	LA10_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genTraverseProc__cgen_7697)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* origTyp, tyArray__qtqsWM5aXmcpMIVmvq3kAA sig) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_TTraversalClosure__4DrvOBPCF3NL9akdOcxiJCw c;
	tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	NIM_BOOL hcrOn;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* markerName;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* header;
	tyArray__ts9cf9blICas1QWmw89bglZ7w T7_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* t;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T8_;
	tyArray__ts9cf9blICas1QWmw89bglZ7w T9_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T12_;
	tyArray__ts9cf9blICas1QWmw89bglZ7w T13_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* generatedProc;
	tyArray__InO6xIOhXMnkCXPnEYWwWg T30_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T31_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T32_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T33_;
	tyArray__ts9cf9blICas1QWmw89bglZ7w T34_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T35_;
	result = NIM_NIL;
	nimZeroMem((void*)(&c), sizeof(tyObject_TTraversalClosure__4DrvOBPCF3NL9akdOcxiJCw));
	p = newProc__cgendata_278(((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL), m);
	T1_ = NIM_NIL;
	T1_ = getTypeName__cgen_1179(m, origTyp, sig);
	result = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_154), T1_);
	hcrOn = hcrOn__cgen_43(m);
	typ = skipTypes__ast_3723(origTyp, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_155);
	{
		if (!hcrOn) goto LA4_;
		markerName = amp___ropes_140(result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_97));
	}
	goto LA2_;
	LA4_: ;
	{
		markerName = result;
	}
	LA2_: ;
	nimZeroMem((void*)T7_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
	T7_[0] = markerName;
	header = percent___cgen_7707(T7_, 1);
	t = getTypeDesc__cgen_6662(m, typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
	T8_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T8_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
	nimZeroMem((void*)T9_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
	T9_[0] = t;
	T10_ = NIM_NIL;
	T10_ = percent___cgen_7714(T9_, 1);
	T11_ = NIM_NIL;
	T11_ = indentLine__cgen_286(p, T10_);
	add__ropes_159(T8_, T11_);
	T12_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T12_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 1));
	nimZeroMem((void*)T13_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
	T13_[0] = t;
	T14_ = NIM_NIL;
	T14_ = percent___cgen_7719(T13_, 1);
	T15_ = NIM_NIL;
	T15_ = indentLine__cgen_286(p, T14_);
	add__ropes_159(T12_, T15_);
	c.p = p;
	c.visitorFrmt = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_156));
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
		if (!((*typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24))) goto LA18_;
		T20_ = NIM_NIL;
		T20_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_197));
		genTraverseProcSeq__cgen_7491(c, T20_, typ);
	}
	goto LA16_;
	LA18_: ;
	{
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T24_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T27_;
			T24_ = NIM_NIL;
			T24_ = skipTypes__ast_3723((*typ).sons->data[((NI) 0)], TM__9bddtAaa9cYLwzzzlT9aJ5CKw_67);
			if (!((*T24_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16))) goto LA25_;
			T27_ = NIM_NIL;
			T27_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_197));
			genTraverseProc__cgen_7366(c, T27_, (*typ).sons->data[((NI) 0)]);
		}
		goto LA22_;
		LA25_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T29_;
			T29_ = NIM_NIL;
			T29_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_198));
			genTraverseProc__cgen_7366(c, T29_, (*typ).sons->data[((NI) 0)]);
		}
		LA22_: ;
	}
	LA16_: ;
	nimZeroMem((void*)T30_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
	T30_[0] = header;
	T31_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T31_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
	T30_[1] = (*T31_);
	T32_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T32_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 1));
	T30_[2] = (*T32_);
	T33_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T33_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	T30_[3] = (*T33_);
	generatedProc = percent___cgen_7746(T30_, 4);
	nimZeroMem((void*)T34_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
	T34_[0] = header;
	T35_ = NIM_NIL;
	T35_ = percent___cgen_7752(T34_, 1);
	add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 8))- 0], T35_);
	add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 11))- 0], generatedProc);
	{
		tyArray__ts9cf9blICas1QWmw89bglZ7w T40_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T41_;
		tyArray__FKvM4FDhljtt88k8FkGthA T42_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T43_;
		if (!hcrOn) goto LA38_;
		nimZeroMem((void*)T40_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T40_[0] = result;
		T41_ = NIM_NIL;
		T41_ = percent___cgen_7757(T40_, 1);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 8))- 0], T41_);
		nimZeroMem((void*)T42_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
		T42_[0] = result;
		T42_[1] = markerName;
		T42_[2] = getModuleDllPath__cgen_131(m);
		T43_ = NIM_NIL;
		T43_ = percent___cgen_7762(T42_, 3);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 18))- 0], T43_);
	}
	LA38_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genArrayInfo__cgen_7350)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	T1_ = NIM_NIL;
	T1_ = genTypeInfoV1__cgen_6798(m, (*typ).sons->data[((NI) 1)], info);
	genTypeInfoAuxBase__cgen_6818(m, typ, typ, name, T1_, info);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, rope__cgen_6948)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ arg) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	NimStringDesc* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = dollar___int495056_53(arg);
	result = rope__ropes_109(T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genSetInfo__cgen_7331)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tmp;
	tyArray__FKvM4FDhljtt88k8FkGthA T1_;
	tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T2_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T3_;
	genTypeInfoAux__cgen_6883(m, typ, typ, name, info);
	tmp = getNimNode__cgen_6802(m);
	nimZeroMem((void*)T1_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
	T1_[0] = tmp;
	T2_ = firstOrd__types_1406((*(*m).g).config, typ);
	T1_[1] = rope__cgen_6948(T2_);
	T1_[2] = tiNameForHcr__cgen_6814(m, name);
	T3_ = NIM_NIL;
	T3_ = percent___cgen_7345(T1_, 3);
	add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T3_);
}
N_LIB_PRIVATE N_NIMCALL(void, genEnumInfo__cgen_7235)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* nodePtrs;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T2_;
	NI T3_;
	NimStringDesc* T4_;
	NI T5_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* enumNames;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* specialCases;
	NI firstNimNode;
	NIM_BOOL hasHoles;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* enumArray;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* counter;
	tyArray__ts9cf9blICas1QWmw89bglZ7w T30_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T31_;
	tyArray__FKvM4FDhljtt88k8FkGthA T32_;
	NI T33_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T34_;
	tyArray__SJIWFUvBTGjESW6tXwR6UA T35_;
	NI T36_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T37_;
	tyArray__InO6xIOhXMnkCXPnEYWwWg T38_;
	NI T39_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T40_;
	genTypeInfoAux__cgen_6883(m, typ, typ, name, info);
	T1_ = NIM_NIL;
	T1_ = getTempName__cgen_428(m);
	T2_ = NIM_NIL;
	T2_ = amp___ropes_140(T1_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3));
	T3_ = (NI)0;
	T3_ = len__ast_3155((*typ).n);
	T4_ = NIM_NIL;
	T4_ = dollar___systemZdollars_3(T3_);
	nodePtrs = amp___ropes_140(T2_, T4_);
	T5_ = (NI)0;
	T5_ = len__ast_3155((*typ).n);
	T6_ = NIM_NIL;
	T6_ = rope__ropes_115(((NI64) (T5_)));
	genTNimNodeArray__cgen_6962(m, nodePtrs, T6_);
	enumNames = NIM_NIL;
	specialCases = NIM_NIL;
	firstNimNode = (*m).typeNodes;
	hasHoles = NIM_FALSE;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155((*typ).n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* elemNode;
				if (!(i_2 < colontmp_)) goto LA9;
				i = i_2;
				field = (*(*(*typ).n)._kind_6.sons->data[i])._kind_4.sym;
				elemNode = getNimNode__cgen_6802(m);
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
					if (!((*field).ast == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA12_;
					T14_ = NIM_NIL;
					T14_ = makeCString__msgs_50((*(*field).name).s);
					add__ropes_159(&enumNames, T14_);
				}
				goto LA10_;
				LA12_: ;
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
					T16_ = NIM_NIL;
					T16_ = makeCString__msgs_50((*(*field).ast)._kind_3.strVal);
					add__ropes_159(&enumNames, T16_);
				}
				LA10_: ;
				{
					NI T19_;
					T19_ = (NI)0;
					T19_ = len__ast_3155((*typ).n);
					if (!(i < (NI)(T19_ - ((NI) 1)))) goto LA20_;
					add__ropes_162(&enumNames, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_199));
				}
				LA20_: ;
				{
					NIM_BOOL T24_;
					tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T28_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T29_;
					T24_ = (NIM_BOOL)0;
					T24_ = !(((*field).position == i));
					if (T24_) goto LA25_;
					T24_ = (((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 5))&63U)))!=0);
					LA25_: ;
					if (!T24_) goto LA26_;
					nimZeroMem((void*)T28_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
					T28_[0] = elemNode;
					T28_[1] = rope__ropes_115(((NI64) ((*field).position)));
					T29_ = NIM_NIL;
					T29_ = percent___cgen_7281(T28_, 2);
					add__ropes_159(&specialCases, T29_);
					hasHoles = NIM_TRUE;
				}
				LA26_: ;
				i_2 += ((NI) 1);
			} LA9: ;
		}
	}
	enumArray = getTempName__cgen_428(m);
	counter = getTempName__cgen_428(m);
	nimZeroMem((void*)T30_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
	T30_[0] = counter;
	T31_ = NIM_NIL;
	T31_ = percent___cgen_7288(T30_, 1);
	add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 14))- 0], T31_);
	nimZeroMem((void*)T32_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
	T32_[0] = enumArray;
	T33_ = (NI)0;
	T33_ = len__ast_3155((*typ).n);
	T32_[1] = rope__ropes_115(((NI64) (T33_)));
	T32_[2] = enumNames;
	T34_ = NIM_NIL;
	T34_ = percent___cgen_7296(T32_, 3);
	add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 14))- 0], T34_);
	nimZeroMem((void*)T35_, sizeof(tyArray__SJIWFUvBTGjESW6tXwR6UA));
	T35_[0] = counter;
	T36_ = (NI)0;
	T36_ = len__ast_3155((*typ).n);
	T35_[1] = rope__ropes_115(((NI64) (T36_)));
	T35_[2] = (*m).typeNodesName;
	T35_[3] = rope__ropes_115(((NI64) (firstNimNode)));
	T35_[4] = enumArray;
	T35_[5] = nodePtrs;
	T37_ = NIM_NIL;
	T37_ = percent___cgen_7304(T35_, 6);
	add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T37_);
	add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], specialCases);
	nimZeroMem((void*)T38_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
	T38_[0] = getNimNode__cgen_6802(m);
	T39_ = (NI)0;
	T39_ = len__ast_3155((*typ).n);
	T38_[1] = rope__ropes_115(((NI64) (T39_)));
	T38_[2] = nodePtrs;
	T38_[3] = tiNameForHcr__cgen_6814(m, name);
	T40_ = NIM_NIL;
	T40_ = percent___cgen_7312(T38_, 4);
	add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T40_);
	{
		tyArray__ts9cf9blICas1QWmw89bglZ7w T45_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T46_;
		if (!hasHoles) goto LA43_;
		nimZeroMem((void*)T45_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T45_[0] = tiNameForHcr__cgen_6814(m, name);
		T46_ = NIM_NIL;
		T46_ = percent___cgen_7317(T45_, 1);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T46_);
	}
	LA43_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, discriminatorTableName__cgen_6928)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* objtype, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* d) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* objtype_2;
	tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T8_;
	tyArray__qtqsWM5aXmcpMIVmvq3kAA T9_;
	NimStringDesc* T10_;
	NimStringDesc* T11_;
	result = NIM_NIL;
	objtype_2 = skipTypes__ast_3723(objtype, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_201);
	{
		while (1) {
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T3_;
			T3_ = NIM_NIL;
			T3_ = lookupInRecord__astalgo_84((*objtype_2).n, (*d).name);
			if (!(T3_ == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA2;
			objtype_2 = skipTypes__ast_3723((*objtype_2).sons->data[((NI) 0)], TM__9bddtAaa9cYLwzzzlT9aJ5CKw_201);
		} LA2: ;
	}
	{
		if (!((*objtype_2).sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA6_;
		internalErrorImpl__msgs_1441((*(*m).g).config, (*d).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_202), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_203);
	}
	LA6_: ;
	nimZeroMem((void*)T8_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
	nimZeroMem((void*)T9_, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
	hashType__sighashes_473(objtype_2, (*(*m).g).config, 2, T9_);
	T10_ = NIM_NIL;
	T10_ = dollar___modulegraphs_8985(T9_);
	T8_[0] = rope__ropes_109(T10_);
	T11_ = NIM_NIL;
	T11_ = mangle__ccgutils_112((*(*d).name).s);
	T8_[1] = rope__ropes_109(T11_);
	result = percent___cgen_6943(T8_, 2);
	return result;
}
static N_INLINE(NIM_BOOL, isEmptyType__ast_4780)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (t == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
	if (T1_) goto LA2_;
	T1_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 63) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 7));
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genObjectFields__cgen_6981)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* origType, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* expr, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
{	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 138):
	{
		{
			NI T4_;
			T4_ = (NI)0;
			T4_ = len__ast_3155(n);
			if (!(T4_ == ((NI) 1))) goto LA5_;
			genObjectFields__cgen_6981(m, typ, origType, (*n)._kind_6.sons->data[((NI) 0)], expr, info);
		}
		goto LA2_;
		LA5_: ;
		{
			NI T8_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tmp;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
			NI T13_;
			NimStringDesc* T14_;
			NI T15_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
			tyArray__FKvM4FDhljtt88k8FkGthA T22_;
			NI T23_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
			T8_ = (NI)0;
			T8_ = len__ast_3155(n);
			if (!(((NI) 0) < T8_)) goto LA9_;
			T11_ = NIM_NIL;
			T11_ = getTempName__cgen_428(m);
			T12_ = NIM_NIL;
			T12_ = amp___ropes_140(T11_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3));
			T13_ = (NI)0;
			T13_ = len__ast_3155(n);
			T14_ = NIM_NIL;
			T14_ = dollar___systemZdollars_3(T13_);
			tmp = amp___ropes_140(T12_, T14_);
			T15_ = (NI)0;
			T15_ = len__ast_3155(n);
			T16_ = NIM_NIL;
			T16_ = rope__ropes_115(((NI64) (T15_)));
			genTNimNodeArray__cgen_6962(m, tmp, T16_);
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_3155(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tmp2;
						tyArray__FKvM4FDhljtt88k8FkGthA T20_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T21_;
						if (!(i_2 < colontmp_)) goto LA19;
						i = i_2;
						tmp2 = getNimNode__cgen_6802(m);
						nimZeroMem((void*)T20_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
						T20_[0] = tmp;
						T20_[1] = rope__ropes_115(((NI64) (i)));
						T20_[2] = tmp2;
						T21_ = NIM_NIL;
						T21_ = percent___cgen_7011(T20_, 3);
						add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T21_);
						genObjectFields__cgen_6981(m, typ, origType, (*n)._kind_6.sons->data[i], tmp2, info);
						i_2 += ((NI) 1);
					} LA19: ;
				}
			}
			nimZeroMem((void*)T22_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
			T22_[0] = expr;
			T23_ = (NI)0;
			T23_ = len__ast_3155(n);
			T22_[1] = rope__ropes_115(((NI64) (T23_)));
			T22_[2] = tmp;
			T24_ = NIM_NIL;
			T24_ = percent___cgen_7020(T22_, 3);
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T24_);
		}
		goto LA2_;
		LA9_: ;
		{
			tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T26_;
			NI T27_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T28_;
			nimZeroMem((void*)T26_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
			T26_[0] = expr;
			T27_ = (NI)0;
			T27_ = len__ast_3155(n);
			T26_[1] = rope__ropes_115(((NI64) (T27_)));
			T28_ = NIM_NIL;
			T28_ = percent___cgen_7028(T26_, 2);
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T28_);
		}
		LA2_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 139):
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tmp_2;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ L;
		tyArray__27u9bjXoGJPnSsktsUHwhCw T39_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T40_;
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T41_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T42_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T43_;
		field = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		tmp_2 = discriminatorTableName__cgen_6928(m, typ, field);
		L = lengthOrd__types_1723((*(*m).g).config, (*field).typ);
		{
			if (!((*field).loc.r == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA32_;
			fillObjectFields__cgen_3808(m, typ);
		}
		LA32_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T36_;
			T36_ = NIM_NIL;
			T36_ = t__cgen_85((*field).loc);
			if (!(T36_ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA37_;
			internalErrorImpl__msgs_1441((*(*m).g).config, (*n).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_204), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_205);
		}
		LA37_: ;
		nimZeroMem((void*)T39_, sizeof(tyArray__27u9bjXoGJPnSsktsUHwhCw));
		T39_[0] = expr;
		T39_[1] = getTypeDesc__cgen_6662(m, origType, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
		T39_[2] = (*field).loc.r;
		T39_[3] = genTypeInfoV1__cgen_6798(m, (*field).typ, info);
		T39_[4] = makeCString__msgs_50((*(*field).name).s);
		T39_[5] = tmp_2;
		T39_[6] = rope__cgen_6948(L);
		T40_ = NIM_NIL;
		T40_ = percent___cgen_7056(T39_, 7);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T40_);
		nimZeroMem((void*)T41_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T41_[0] = tmp_2;
		T42_ = plus___int495056_987(L, IL64(1));
		T41_[1] = rope__cgen_6948(T42_);
		T43_ = NIM_NIL;
		T43_ = percent___cgen_6957(T41_, 2);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 9))- 0], T43_);
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3155(n);
			i_4 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tmp2_2;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T47_;
					if (!(i_4 < colontmp__2)) goto LA46;
					i_3 = i_4;
					b = (*n)._kind_6.sons->data[i_3];
					tmp2_2 = getNimNode__cgen_6802(m);
					T47_ = NIM_NIL;
					T47_ = lastSon__ast_4833(b);
					genObjectFields__cgen_6981(m, typ, origType, T47_, tmp2_2, info);
					switch ((*b).kind) {
					case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 85):
					{
						{
							NI T51_;
							T51_ = (NI)0;
							T51_ = len__ast_3155(b);
							if (!(T51_ < ((NI) 2))) goto LA52_;
							internalErrorImpl__msgs_1441((*(*m).g).config, (*b).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_206), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_207);
						}
						LA52_: ;
						{
							NI j;
							NI colontmp__3;
							NI T55_;
							NI i_5;
							j = (NI)0;
							colontmp__3 = (NI)0;
							T55_ = (NI)0;
							T55_ = len__ast_3155(b);
							colontmp__3 = (NI)(T55_ - ((NI) 1));
							i_5 = ((NI) 0);
							{
								while (1) {
									if (!(i_5 < colontmp__3)) goto LA57;
									j = i_5;
									{
										NI x;
										tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T62_;
										NI y;
										tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T63_;
										if (!((*(*b)._kind_6.sons->data[j]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 44))) goto LA60_;
										T62_ = getOrdValue__types_161((*(*b)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 0)], Max__int495056_27);
										x = toInt__int495056_273(T62_);
										T63_ = getOrdValue__types_161((*(*b)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 1)], Max__int495056_27);
										y = toInt__int495056_273(T63_);
										{
											while (1) {
												tyArray__FKvM4FDhljtt88k8FkGthA T66_;
												tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T67_;
												if (!(x <= y)) goto LA65;
												nimZeroMem((void*)T66_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
												T66_[0] = tmp_2;
												T66_[1] = rope__ropes_115(((NI64) (x)));
												T66_[2] = tmp2_2;
												T67_ = NIM_NIL;
												T67_ = percent___cgen_7011(T66_, 3);
												add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T67_);
												x += ((NI) 1);
											} LA65: ;
										}
									}
									goto LA58_;
									LA60_: ;
									{
										tyArray__FKvM4FDhljtt88k8FkGthA T69_;
										tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T70_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T71_;
										nimZeroMem((void*)T69_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
										T69_[0] = tmp_2;
										T70_ = getOrdValue__types_161((*b)._kind_6.sons->data[j], Max__int495056_27);
										T69_[1] = rope__cgen_6948(T70_);
										T69_[2] = tmp2_2;
										T71_ = NIM_NIL;
										T71_ = percent___cgen_7011(T69_, 3);
										add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T71_);
									}
									LA58_: ;
									i_5 += ((NI) 1);
								} LA57: ;
							}
						}
					}
					break;
					case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 88):
					{
						tyArray__FKvM4FDhljtt88k8FkGthA T73_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T74_;
						nimZeroMem((void*)T73_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
						T73_[0] = tmp_2;
						T73_[1] = rope__cgen_6948(L);
						T73_[2] = tmp2_2;
						T74_ = NIM_NIL;
						T74_ = percent___cgen_7011(T73_, 3);
						add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T74_);
					}
					break;
					default:
					{
						internalErrorImpl__msgs_1441((*(*m).g).config, (*n).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_208), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_209);
					}
					break;
					}
					i_4 += ((NI) 1);
				} LA46: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field_2;
		field_2 = (*n)._kind_4.sym;
		{
			NIM_BOOL T79_;
			T79_ = (NIM_BOOL)0;
			T79_ = isEmptyType__ast_4780((*field_2).typ);
			if (!T79_) goto LA80_;
			goto BeforeRet_;
		}
		LA80_: ;
		{
			tyArray__XSZGJHCjWme3CUmFzckT3g T95_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T96_;
			if (!((*field_2)._kind_2.bitsize == ((NI) 0))) goto LA84_;
			{
				if (!((*field_2).loc.r == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA88_;
				fillObjectFields__cgen_3808(m, typ);
			}
			LA88_: ;
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T92_;
				T92_ = NIM_NIL;
				T92_ = t__cgen_85((*field_2).loc);
				if (!(T92_ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA93_;
				internalErrorImpl__msgs_1441((*(*m).g).config, (*n).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_204), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_210);
			}
			LA93_: ;
			nimZeroMem((void*)T95_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
			T95_[0] = expr;
			T95_[1] = getTypeDesc__cgen_6662(m, origType, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
			T95_[2] = (*field_2).loc.r;
			T95_[3] = genTypeInfoV1__cgen_6798(m, (*field_2).typ, info);
			T95_[4] = makeCString__msgs_50((*(*field_2).name).s);
			T96_ = NIM_NIL;
			T96_ = percent___cgen_7127(T95_, 5);
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T96_);
		}
		LA84_: ;
	}
	break;
	default:
	{
		internalErrorImpl__msgs_1441((*(*m).g).config, (*n).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_204), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_211);
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genObjectInfo__cgen_7141)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* origType, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tmp;
	tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T20_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T21_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	{
		if (!((*typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17))) goto LA3_;
		{
			NIM_BOOL T7_;
			NimStringDesc* T11_;
			NimStringDesc* T12_;
			T7_ = (NIM_BOOL)0;
			T7_ = !(((*typ).sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
			if (!(T7_)) goto LA8_;
			T7_ = ((1040 & (*(*typ).sym).flags) == 16);
			LA8_: ;
			if (!T7_) goto LA9_;
			T11_ = NIM_NIL;
			T12_ = NIM_NIL;
			T12_ = typeToString__types_50(typ, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
			T11_ = rawNewString((T12_ ? T12_->Sup.len : 0) + 51);
appendString(T11_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_135));
appendString(T11_, T12_);
			liMessage__msgs_1128((*(*m).g).config, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T11_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_200, NIM_FALSE);
		}
		LA9_: ;
		genTypeInfoAux__cgen_6883(m, typ, origType, name, info);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
		T14_ = NIM_NIL;
		T14_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_153));
		genTypeInfoAuxBase__cgen_6818(m, typ, origType, name, T14_, info);
	}
	LA1_: ;
	tmp = getNimNode__cgen_6802(m);
	{
		NIM_BOOL T17_;
		T17_ = (NIM_BOOL)0;
		T17_ = isImportedType__cgen_1301(typ);
		if (!!(T17_)) goto LA18_;
		genObjectFields__cgen_6981(m, typ, origType, (*typ).n, tmp, info);
	}
	LA18_: ;
	nimZeroMem((void*)T20_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
	T20_[0] = tiNameForHcr__cgen_6814(m, name);
	T20_[1] = tmp;
	T21_ = NIM_NIL;
	T21_ = percent___cgen_7164(T20_, 2);
	add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T21_);
	t = (*typ).sons->data[((NI) 0)];
	{
		while (1) {
			if (!!((t == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA23;
			t = skipTypes__ast_3723(t, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_130);
			(*t).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 5)) & 63);
			t = (*t).sons->data[((NI) 0)];
		} LA23: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, openArrayToTuple__cgen_9747)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T1_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* p;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T2_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T3_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T4_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T5_;
	result = NIM_NIL;
	T1_ = nextTypeId__ast_3122((*m).Sup.idgen);
	result = newType__ast_3884(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18), T1_, (*t).owner);
	T2_ = nextTypeId__ast_3122((*m).Sup.idgen);
	p = newType__ast_3884(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21), T2_, (*t).owner);
	T3_ = nextTypeId__ast_3122((*m).Sup.idgen);
	a = newType__ast_3884(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 49), T3_, (*t).owner);
	T4_ = NIM_NIL;
	T4_ = lastSon__ast_3731(t);
	add__concepts_23(a, T4_);
	add__concepts_23(p, a);
	add__concepts_23(result, p);
	T5_ = NIM_NIL;
	T5_ = getSysType__magicsys_60((*(*m).g).graph, (*(*t).owner).info, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31));
	add__concepts_23(result, T5_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genDeepCopyProc__cgen_7805)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result) {
	tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T2_;
	genProc__cgen_421(m, s);
	nimZeroMem((void*)T1_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
	T1_[0] = result;
	T1_[1] = (*s).loc.r;
	T2_ = NIM_NIL;
	T2_ = percent___cgen_7809(T1_, 2);
	add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T2_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genTypeInfoV1__cgen_6798)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* origType;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t_2;
	NimStringDesc* prefixTI;
	tyArray__qtqsWM5aXmcpMIVmvq3kAA sig;
	tyTuple__1DF4qJDR9cG0CgZV1nlkaYw marker;
	tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T23_;
	NimStringDesc* T24_;
	NimStringDesc* T25_;
	NI32 old;
	NimStringDesc* T26_;
	NI32 owner;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T36_;
	tyTuple__1DF4qJDR9cG0CgZV1nlkaYw T50_;
	NimStringDesc* T51_;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* op;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T117_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T118_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T119_;
{	result = NIM_NIL;
	origType = t;
	t_2 = skipTypes__ast_3723(origType, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_141);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = hcrOn__cgen_43(m);
		if (!T3_) goto LA4_;
		prefixTI = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
	}
	goto LA1_;
	LA4_: ;
	{
		prefixTI = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_122));
	}
	LA1_: ;
	nimZeroMem((void*)sig, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
	hashType__sighashes_473(origType, (*(*m).g).config, 2, sig);
	result = getOrDefault__cgen_1450((*m).typeInfoMarker, sig);
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
		if (!!((result == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA9_;
		T11_ = NIM_NIL;
		T11_ = rope__ropes_109(prefixTI);
		T12_ = NIM_NIL;
		T12_ = amp___ropes_128(T11_, result);
		T13_ = NIM_NIL;
		T13_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		result = amp___ropes_128(T12_, T13_);
		goto BeforeRet_;
	}
	LA9_: ;
	nimZeroMem((void*)(&marker), sizeof(tyTuple__1DF4qJDR9cG0CgZV1nlkaYw));
	getOrDefault__cgen_8116((*(*m).g).typeInfoMarker, sig, (&marker));
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T21_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
		if (!!((marker.Field0 == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA16_;
		T18_ = NIM_NIL;
		T18_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_142));
		(void)(T18_);
		T19_ = NIM_NIL;
		T19_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_143));
		(void)(T19_);
		declareNimType__cgen_7814(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_142), marker.Field0, ((NI) (marker.Field1)));
		X5BX5Deq___cgen_1895((&(*m).typeInfoMarker), sig, marker.Field0);
		T20_ = NIM_NIL;
		T20_ = rope__ropes_109(prefixTI);
		T21_ = NIM_NIL;
		T21_ = amp___ropes_128(T20_, marker.Field0);
		T22_ = NIM_NIL;
		T22_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		result = amp___ropes_128(T21_, T22_);
		goto BeforeRet_;
	}
	LA16_: ;
	nimZeroMem((void*)T23_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
	T24_ = NIM_NIL;
	T24_ = typeToC__cgen_9772(t_2);
	T23_[0] = rope__ropes_109(T24_);
	T25_ = NIM_NIL;
	T25_ = dollar___modulegraphs_8985(sig);
	T23_[1] = rope__ropes_109(T25_);
	result = percent___cgen_9995(T23_, 2);
	X5BX5Deq___cgen_1895((&(*m).typeInfoMarker), sig, result);
	T26_ = NIM_NIL;
	T26_ = dollar___ropes_250(result);
	old = getOrDefault__cgen_10112((*(*(*m).g).graph).emittedTypeInfo, T26_);
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T31_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T32_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T33_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T34_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T35_;
		if (!!((old == ((NI32) 0)))) goto LA29_;
		T31_ = NIM_NIL;
		T31_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_142));
		(void)(T31_);
		T32_ = NIM_NIL;
		T32_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_143));
		(void)(T32_);
		declareNimType__cgen_7814(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_142), result, ((NI) (old)));
		T33_ = NIM_NIL;
		T33_ = rope__ropes_109(prefixTI);
		T34_ = NIM_NIL;
		T34_ = amp___ropes_128(T33_, result);
		T35_ = NIM_NIL;
		T35_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		result = amp___ropes_128(T34_, T35_);
		goto BeforeRet_;
	}
	LA29_: ;
	T36_ = NIM_NIL;
	T36_ = skipTypes__ast_3723(t_2, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_134);
	owner = (*T36_).Sup.itemId.module;
	{
		NIM_BOOL T39_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T43_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T44_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T45_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T46_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T47_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T48_;
		T39_ = (NIM_BOOL)0;
		T39_ = !((((NI) (owner)) == (*(*m).module).position));
		if (!(T39_)) goto LA40_;
		T39_ = moduleOpenForCodegen__modulegraphs_9529((*(*m).g).graph, owner);
		LA40_: ;
		if (!T39_) goto LA41_;
		T43_ = NIM_NIL;
		T43_ = genTypeInfoV1__cgen_6798((*(*m).g).modules->data[owner], origType, info);
		(void)(T43_);
		T44_ = NIM_NIL;
		T44_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_142));
		(void)(T44_);
		T45_ = NIM_NIL;
		T45_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_143));
		(void)(T45_);
		declareNimType__cgen_7814(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_142), result, ((NI) (owner)));
		T46_ = NIM_NIL;
		T46_ = rope__ropes_109(prefixTI);
		T47_ = NIM_NIL;
		T47_ = amp___ropes_128(T46_, result);
		T48_ = NIM_NIL;
		T48_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		result = amp___ropes_128(T47_, T48_);
		goto BeforeRet_;
	}
	goto LA37_;
	LA41_: ;
	{
		owner = ((NI32) ((*(*m).module).position));
	}
	LA37_: ;
	nimZeroMem((void*)(&T50_), sizeof(tyTuple__1DF4qJDR9cG0CgZV1nlkaYw));
	T50_.Field0 = result;
	T50_.Field1 = owner;
	X5BX5Deq___cgen_8590((&(*(*m).g).typeInfoMarker), sig, T50_);
	T51_ = NIM_NIL;
	T51_ = dollar___ropes_250(result);
	rememberEmittedTypeInfo__modulegraphs_9541((*(*m).g).graph, owner, T51_);
	switch ((*t_2).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 3):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 63):
	{
		result = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_144));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 26):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47):
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T54_;
		T54_ = NIM_NIL;
		T54_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_144));
		genTypeInfoAuxBase__cgen_6818(m, t_2, t_2, result, T54_, info);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60):
	{
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T60_;
			if (!!(((*t_2).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA58_;
			T60_ = NIM_NIL;
			T60_ = lastSon__ast_3731(t_2);
			result = genTypeInfoV1__cgen_6798(m, T60_, info);
		}
		goto LA56_;
		LA58_: ;
		{
			NimStringDesc* T62_;
			T62_ = NIM_NIL;
			T62_ = rawNewString((reprEnum((NI)(*t_2).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)) ? reprEnum((NI)(*t_2).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_))->Sup.len : 0) + 15);
appendString(T62_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_150));
appendString(T62_, reprEnum((NI)(*t_2).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)));
appendChar(T62_, 41);
			internalErrorImpl__msgs_1441((*(*m).g).config, unknownLineInfo__lineinfos_284, T62_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_151);
		}
		LA56_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 52) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 53):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T68_;
		{
			NimStringDesc* argX60gensym817_;
			if (!!((((*t_2).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 10))&63U)))!=0))) goto LA66_;
			argX60gensym817_ = toFileLineCol__msgs_625(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_152);
			internalErrorImpl__msgs_1441((*(*m).g).config, unknownLineInfo__lineinfos_284, argX60gensym817_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_152);
		}
		LA66_: ;
		T68_ = NIM_NIL;
		T68_ = lastSon__ast_3731(t_2);
		result = genTypeInfoV1__cgen_6798(m, T68_, info);
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25):
	{
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T74_;
			if (!!(((*t_2).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9)))) goto LA72_;
			T74_ = NIM_NIL;
			T74_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_144));
			genTypeInfoAuxBase__cgen_6818(m, t_2, t_2, result, T74_, info);
		}
		goto LA70_;
		LA72_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* x;
			x = fakeClosureType__cgen_7356(m, (*t_2).owner);
			genTupleInfo__cgen_7180(m, x, x, result, info);
		}
		LA70_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
	{
		genTypeInfoAux__cgen_6883(m, t_2, t_2, result, info);
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* markerProc;
			tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T81_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T82_;
			if (!((1856 &((NU16)1<<((NU)((*(*(*m).g).config).selectedGC)&15U)))!=0)) goto LA79_;
			markerProc = genTraverseProc__cgen_7697(m, origType, sig);
			nimZeroMem((void*)T81_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
			T81_[0] = tiNameForHcr__cgen_6814(m, result);
			T81_[1] = markerProc;
			T82_ = NIM_NIL;
			T82_ = percent___cgen_10266(T81_, 2);
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T82_);
		}
		LA79_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22):
	{
		genTypeInfoAux__cgen_6883(m, t_2, t_2, result, info);
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* markerProc_2;
			tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T88_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T89_;
			if (!((1856 &((NU16)1<<((NU)((*(*(*m).g).config).selectedGC)&15U)))!=0)) goto LA86_;
			markerProc_2 = genTraverseProc__cgen_7697(m, origType, sig);
			nimZeroMem((void*)T88_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
			T88_[0] = tiNameForHcr__cgen_6814(m, result);
			T88_[1] = markerProc_2;
			T89_ = NIM_NIL;
			T89_ = percent___cgen_10266(T88_, 2);
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T89_);
		}
		LA86_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 20):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 49):
	{
		genTypeInfoAux__cgen_6883(m, t_2, t_2, result, info);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
	{
		genArrayInfo__cgen_7350(m, t_2, result, info);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 19):
	{
		genSetInfo__cgen_7331(m, t_2, result, info);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14):
	{
		genEnumInfo__cgen_7235(m, t_2, result, info);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17):
	{
		genObjectInfo__cgen_7141(m, t_2, origType, result, info);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18):
	{
		genTupleInfo__cgen_7180(m, t_2, origType, result, info);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* x_2;
		x_2 = openArrayToTuple__cgen_9747(m, t_2);
		genTupleInfo__cgen_7180(m, x_2, origType, result, info);
	}
	break;
	default:
	{
		NimStringDesc* T98_;
		T98_ = NIM_NIL;
		T98_ = rawNewString((reprEnum((NI)(*t_2).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)) ? reprEnum((NI)(*t_2).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_))->Sup.len : 0) + 15);
appendString(T98_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_150));
appendString(T98_, reprEnum((NI)(*t_2).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)));
appendChar(T98_, 41);
		internalErrorImpl__msgs_1441((*(*m).g).config, unknownLineInfo__lineinfos_284, T98_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_212);
	}
	break;
	}
	op = getAttachedOp__modulegraphs_4049((*(*m).g).graph, t_2, ((tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ) 4));
	{
		if (!(op == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA101_;
		op = getAttachedOp__modulegraphs_4049((*(*m).g).graph, origType, ((tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ) 4));
	}
	LA101_: ;
	{
		if (!!((op == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA105_;
		genDeepCopyProc__cgen_7805(m, op, result);
	}
	LA105_: ;
	{
		NIM_BOOL T109_;
		NIM_BOOL T110_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* v2info;
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T115_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T116_;
		T109_ = (NIM_BOOL)0;
		T110_ = (NIM_BOOL)0;
		T110_ = (((*(*(*m).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 41))&63U)))!=0);
		if (!(T110_)) goto LA111_;
		T110_ = ((*t_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17));
		LA111_: ;
		T109_ = T110_;
		if (!(T109_)) goto LA112_;
		T109_ = !((((*(*t_2).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 6))&63U)))!=0));
		LA112_: ;
		if (!T109_) goto LA113_;
		v2info = genTypeInfoV2__cgen_7958(m, origType, info);
		nimZeroMem((void*)T115_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T115_[0] = v2info;
		T115_[1] = result;
		T116_ = NIM_NIL;
		T116_ = percent___cgen_10306(T115_, 2);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T116_);
	}
	LA113_: ;
	T117_ = NIM_NIL;
	T117_ = rope__ropes_109(prefixTI);
	T118_ = NIM_NIL;
	T118_ = amp___ropes_128(T117_, result);
	T119_ = NIM_NIL;
	T119_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
	result = amp___ropes_128(T118_, T119_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genTypeInfoV2Impl__cgen_7906)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* origType, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* typeName_1;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
	tyArray__ts9cf9blICas1QWmw89bglZ7w T15_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* destroyImpl;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* traceImpl;
	NI flags;
	tyArray__SJIWFUvBTGjESW6tXwR6UA T22_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
	typeName_1 = NIM_NIL;
	{
		if (!((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 13))) goto LA3_;
		{
			NIM_BOOL T7_;
			NimStringDesc* T11_;
			NimStringDesc* T12_;
			T7_ = (NIM_BOOL)0;
			T7_ = !(((*t).sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
			if (!(T7_)) goto LA8_;
			T7_ = ((1040 & (*(*t).sym).flags) == 16);
			LA8_: ;
			if (!T7_) goto LA9_;
			T11_ = NIM_NIL;
			T12_ = NIM_NIL;
			T12_ = typeToString__types_50(t, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
			T11_ = rawNewString((T12_ ? T12_->Sup.len : 0) + 51);
appendString(T11_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_135));
appendString(T11_, T12_);
			liMessage__msgs_1128((*(*m).g).config, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T11_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_136, NIM_FALSE);
		}
		LA9_: ;
		typeName_1 = genTypeInfo2Name__cgen_7835(m, t);
	}
	goto LA1_;
	LA3_: ;
	{
		typeName_1 = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_119));
	}
	LA1_: ;
	T14_ = NIM_NIL;
	T14_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_133));
	(void)(T14_);
	nimZeroMem((void*)T15_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
	T15_[0] = name;
	T16_ = NIM_NIL;
	T16_ = percent___cgen_7929(T15_, 1);
	add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 9))- 0], T16_);
	destroyImpl = genHook__cgen_7887(m, t, info, ((tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ) 0));
	traceImpl = genHook__cgen_7887(m, t, info, ((tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ) 3));
	flags = ((NI) 0);
	{
		NIM_BOOL T19_;
		T19_ = (NIM_BOOL)0;
		T19_ = canFormAcycle__types_820((*(*m).g).graph, t);
		if (!!(T19_)) goto LA20_;
		flags = (NI)(flags | ((NI) 1));
	}
	LA20_: ;
	nimZeroMem((void*)T22_, sizeof(tyArray__SJIWFUvBTGjESW6tXwR6UA));
	T22_[0] = name;
	T22_[1] = destroyImpl;
	T22_[2] = getTypeDesc__cgen_6662(m, t, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
	T22_[3] = typeName_1;
	T22_[4] = traceImpl;
	T22_[5] = rope__ropes_115(((NI64) (flags)));
	T23_ = NIM_NIL;
	T23_ = percent___cgen_7937(T22_, 6);
	add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T23_);
	{
		NIM_BOOL T26_;
		NIM_BOOL T27_;
		NIM_BOOL T28_;
		NI T30_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T35_;
		T26_ = (NIM_BOOL)0;
		T27_ = (NIM_BOOL)0;
		T28_ = (NIM_BOOL)0;
		T28_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17));
		if (!(T28_)) goto LA29_;
		T30_ = (NI)0;
		T30_ = len__ast_3990(t);
		T28_ = (((NI) 0) < T30_);
		LA29_: ;
		T27_ = T28_;
		if (!(T27_)) goto LA31_;
		T27_ = !(((*t).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		LA31_: ;
		T26_ = T27_;
		if (!(T26_)) goto LA32_;
		T26_ = (((*(*(*m).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 51))&63U)))!=0);
		LA32_: ;
		if (!T26_) goto LA33_;
		T35_ = NIM_NIL;
		T35_ = genTypeInfoV1__cgen_6798(m, t, info);
		(void)(T35_);
	}
	LA33_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genTypeInfoV2__cgen_7958)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* origType;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t_2;
	NimStringDesc* prefixTI;
	tyArray__qtqsWM5aXmcpMIVmvq3kAA sig;
	tyTuple__1DF4qJDR9cG0CgZV1nlkaYw marker;
	tyArray__ts9cf9blICas1QWmw89bglZ7w T22_;
	NimStringDesc* T23_;
	NI32 owner;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T24_;
	tyTuple__1DF4qJDR9cG0CgZV1nlkaYw T36_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T37_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T39_;
{	result = NIM_NIL;
	origType = t;
	t_2 = skipTypes__ast_3723(origType, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_132);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = hcrOn__cgen_43(m);
		if (!T3_) goto LA4_;
		prefixTI = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
	}
	goto LA1_;
	LA4_: ;
	{
		prefixTI = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_122));
	}
	LA1_: ;
	nimZeroMem((void*)sig, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
	hashType__sighashes_473(origType, (*(*m).g).config, 2, sig);
	result = getOrDefault__cgen_1450((*m).typeInfoMarkerV2, sig);
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
		if (!!((result == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA9_;
		T11_ = NIM_NIL;
		T11_ = rope__ropes_109(prefixTI);
		T12_ = NIM_NIL;
		T12_ = amp___ropes_128(T11_, result);
		T13_ = NIM_NIL;
		T13_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		result = amp___ropes_128(T12_, T13_);
		goto BeforeRet_;
	}
	LA9_: ;
	nimZeroMem((void*)(&marker), sizeof(tyTuple__1DF4qJDR9cG0CgZV1nlkaYw));
	getOrDefault__cgen_8116((*(*m).g).typeInfoMarkerV2, sig, (&marker));
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T21_;
		if (!!((marker.Field0 == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA16_;
		T18_ = NIM_NIL;
		T18_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_133));
		(void)(T18_);
		declareNimType__cgen_7814(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_133), marker.Field0, ((NI) (marker.Field1)));
		X5BX5Deq___cgen_1895((&(*m).typeInfoMarkerV2), sig, marker.Field0);
		T19_ = NIM_NIL;
		T19_ = rope__ropes_109(prefixTI);
		T20_ = NIM_NIL;
		T20_ = amp___ropes_128(T19_, marker.Field0);
		T21_ = NIM_NIL;
		T21_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		result = amp___ropes_128(T20_, T21_);
		goto BeforeRet_;
	}
	LA16_: ;
	nimZeroMem((void*)T22_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
	T23_ = NIM_NIL;
	T23_ = dollar___modulegraphs_8985(sig);
	T22_[0] = rope__ropes_109(T23_);
	result = percent___cgen_8496(T22_, 1);
	X5BX5Deq___cgen_1895((&(*m).typeInfoMarkerV2), sig, result);
	T24_ = NIM_NIL;
	T24_ = skipTypes__ast_3723(t_2, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_134);
	owner = (*T24_).Sup.itemId.module;
	{
		NIM_BOOL T27_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T31_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T32_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T33_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T34_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T35_;
		T27_ = (NIM_BOOL)0;
		T27_ = !((((NI) (owner)) == (*(*m).module).position));
		if (!(T27_)) goto LA28_;
		T27_ = moduleOpenForCodegen__modulegraphs_9529((*(*m).g).graph, owner);
		LA28_: ;
		if (!T27_) goto LA29_;
		T31_ = NIM_NIL;
		T31_ = genTypeInfoV2__cgen_7958((*(*m).g).modules->data[owner], origType, info);
		(void)(T31_);
		T32_ = NIM_NIL;
		T32_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_133));
		(void)(T32_);
		declareNimType__cgen_7814(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_133), result, ((NI) (owner)));
		T33_ = NIM_NIL;
		T33_ = rope__ropes_109(prefixTI);
		T34_ = NIM_NIL;
		T34_ = amp___ropes_128(T33_, result);
		T35_ = NIM_NIL;
		T35_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		result = amp___ropes_128(T34_, T35_);
		goto BeforeRet_;
	}
	LA29_: ;
	nimZeroMem((void*)(&T36_), sizeof(tyTuple__1DF4qJDR9cG0CgZV1nlkaYw));
	T36_.Field0 = result;
	T36_.Field1 = owner;
	X5BX5Deq___cgen_8590((&(*(*m).g).typeInfoMarkerV2), sig, T36_);
	genTypeInfoV2Impl__cgen_7906(m, t_2, origType, result, info);
	T37_ = NIM_NIL;
	T37_ = rope__ropes_109(prefixTI);
	T38_ = NIM_NIL;
	T38_ = amp___ropes_128(T37_, result);
	T39_ = NIM_NIL;
	T39_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
	result = amp___ropes_128(T38_, T39_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NU64, bitSetToWord__cgen_17880)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ* s, NI size) {
	NU64 result;
	result = (NU64)0;
	result = 0ULL;
	{
		NI j;
		NI i;
		j = (NI)0;
		i = ((NI) 0);
		{
			while (1) {
				if (!(i < size)) goto LA3;
				j = i;
				{
					NI T6_;
					T6_ = (s ? s->Sup.len : 0);
					if (!(j < T6_)) goto LA7_;
					result = (NU64)(result | (NU64)((NU64)(((NU64) (s->data[j]))) << (NU64)((NI)(j * ((NI) 8)))));
				}
				LA7_: ;
				i += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genRawSetData__cgen_17896)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ* cs, NI size) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	{
		NimStringDesc* res;
		if (!(((NI) 8) < size)) goto LA3_;
		res = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_216));
		{
			NI i;
			NI i_2;
			i = (NI)0;
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < size)) goto LA7;
					i = i_2;
					res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_217));
					res = addChar(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_218)->data[(NU8)((NU8)(cs->data[i]) / (NU8)(((NU8) 16)))]);
					res = addChar(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_218)->data[(NU8)((NU8)(cs->data[i]) % (NU8)(((NU8) 16)))]);
					{
						if (!(i < (NI)(size - ((NI) 1)))) goto LA10_;
						{
							if (!((NI)(i % ((NI) 8)) == ((NI) 7))) goto LA14_;
							res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_219));
						}
						goto LA12_;
						LA14_: ;
						{
							res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
						}
						LA12_: ;
					}
					goto LA8_;
					LA10_: ;
					{
						res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_220));
					}
					LA8_: ;
					i_2 += ((NI) 1);
				} LA7: ;
			}
		}
		result = rope__ropes_109(res);
	}
	goto LA1_;
	LA3_: ;
	{
		NU64 T19_;
		T19_ = (NU64)0;
		T19_ = bitSetToWord__cgen_17880(cs, size);
		result = intLiteral__cgen_11536(((NI64) (T19_)));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getSeqPayloadType__cgen_3476)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw check;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	result = NIM_NIL;
	nimZeroMem((void*)(&check), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
	initIntSet__pureZcollectionsZintsets_238((&check));
	T1_ = NIM_NIL;
	T1_ = getTypeDescWeak__cgen_3345(m, t, (&check), ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
	result = amp___ropes_140(T1_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_86));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genConstSeqV2__cgen_25366)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, NIM_BOOL isConst) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* base;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* data;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* payload;
	NimStringDesc* res;
	NimStringDesc* T12_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
	NI T23_;
	NI T28_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T33_;
	tyArray__FKvM4FDhljtt88k8FkGthA T34_;
	NI T35_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = skipTypes__ast_3723(t, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
	base = (*T1_).sons->data[((NI) 0)];
	data = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_221));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				{
					tyArray__dAmhZbEWrTM5xES2bTVweg T9_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
					if (!(((NI) 0) < i)) goto LA7_;
					nimZeroMem((void*)T9_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
					T10_ = NIM_NIL;
					T10_ = percent___cgen_25270(T9_, 0);
					add__ropes_159(&data, T10_);
				}
				LA7_: ;
				T11_ = NIM_NIL;
				T11_ = genBracedInit__cgen_13891(p, (*n)._kind_6.sons->data[i], isConst, base);
				add__ropes_159(&data, T11_);
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	add__ropes_162(&data, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
	payload = getTempName__cgen_428((*p).module);
	res = rawNewString(((NI) 80));
	res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_64));
	T12_ = NIM_NIL;
	{
		if (!isConst) goto LA15_;
		T12_ = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_35));
	}
	goto LA13_;
	LA15_: ;
	{
		T12_ = ((NimStringDesc*) NIM_NIL);
	}
	LA13_: ;
	cgFormatValue__cgen_151((&res), T12_);
	res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_223));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA20_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA20_: ;
	res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_224));
	T22_ = NIM_NIL;
	T22_ = getTypeDesc__cgen_6662((*p).module, base, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
	cgFormatValue__cgen_147((&res), T22_);
	res = resizeString(res, 6);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_225));
	T23_ = (NI)0;
	T23_ = len__ast_3155(n);
	cgFormatValue__cgen_154((&res), ((NI64) (T23_)));
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_226));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA26_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA26_: ;
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_227));
	cgFormatValue__cgen_147((&res), payload);
	res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_228));
	T28_ = (NI)0;
	T28_ = len__ast_3155(n);
	cgFormatValue__cgen_154((&res), ((NI64) (T28_)));
	res = resizeString(res, 20);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_229));
	cgFormatValue__cgen_147((&res), data);
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_230));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA31_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA31_: ;
	T33_ = NIM_NIL;
	T33_ = rope__ropes_109(res);
	add__ropes_159(&(*(*p).module).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 9))- 0], T33_);
	nimZeroMem((void*)T34_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
	T35_ = (NI)0;
	T35_ = len__ast_3155(n);
	T34_[0] = rope__ropes_115(((NI64) (T35_)));
	T34_[1] = getSeqPayloadType__cgen_3476((*p).module, t);
	T34_[2] = payload;
	result = percent___cgen_25476(T34_, 3);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genConstSeq__cgen_25242)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, NIM_BOOL isConst) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* data;
	tyArray__ts9cf9blICas1QWmw89bglZ7w T1_;
	NI T2_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* base;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T3_;
	NimStringDesc* res;
	NimStringDesc* T19_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T29_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T34_;
	NI T35_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T44_;
	tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T45_;
	result = NIM_NIL;
	nimZeroMem((void*)T1_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
	T2_ = (NI)0;
	T2_ = len__ast_3155(n);
	T1_[0] = rope__ropes_115(((NI64) (T2_)));
	data = percent___cgen_25251(T1_, 1);
	T3_ = NIM_NIL;
	T3_ = skipTypes__ast_3723(t, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
	base = (*T3_).sons->data[((NI) 0)];
	{
		NI T6_;
		T6_ = (NI)0;
		T6_ = len__ast_3155(n);
		if (!(((NI) 0) < T6_)) goto LA7_;
		add__ropes_162(&data, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_231));
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
					if (!(i_2 < colontmp_)) goto LA11;
					i = i_2;
					{
						tyArray__dAmhZbEWrTM5xES2bTVweg T16_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
						if (!(((NI) 0) < i)) goto LA14_;
						nimZeroMem((void*)T16_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
						T17_ = NIM_NIL;
						T17_ = percent___cgen_25270(T16_, 0);
						add__ropes_159(&data, T17_);
					}
					LA14_: ;
					T18_ = NIM_NIL;
					T18_ = genBracedInit__cgen_13891(p, (*n)._kind_6.sons->data[i], isConst, base);
					add__ropes_159(&data, T18_);
					i_2 += ((NI) 1);
				} LA11: ;
			}
		}
		add__ropes_162(&data, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
	}
	LA7_: ;
	add__ropes_162(&data, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
	result = getTempName__cgen_428((*p).module);
	res = rawNewString(((NI) 80));
	res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_64));
	T19_ = NIM_NIL;
	{
		if (!isConst) goto LA22_;
		T19_ = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_232));
	}
	goto LA20_;
	LA22_: ;
	{
		T19_ = ((NimStringDesc*) NIM_NIL);
	}
	LA20_: ;
	cgFormatValue__cgen_151((&res), T19_);
	res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_223));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA27_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA27_: ;
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_233));
	T29_ = NIM_NIL;
	T29_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_33));
	cgFormatValue__cgen_147((&res), T29_);
	res = resizeString(res, 5);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_234));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA32_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA32_: ;
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_233));
	T34_ = NIM_NIL;
	T34_ = getTypeDesc__cgen_6662((*p).module, base, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
	cgFormatValue__cgen_147((&res), T34_);
	res = resizeString(res, 6);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_225));
	T35_ = (NI)0;
	T35_ = len__ast_3155(n);
	cgFormatValue__cgen_154((&res), ((NI64) (T35_)));
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_226));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA38_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA38_: ;
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_227));
	cgFormatValue__cgen_147((&res), result);
	res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
	cgFormatValue__cgen_147((&res), data);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA42_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA42_: ;
	T44_ = NIM_NIL;
	T44_ = rope__ropes_109(res);
	add__ropes_159(&(*(*p).module).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 9))- 0], T44_);
	nimZeroMem((void*)T45_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
	T45_[0] = getTypeDesc__cgen_6662((*p).module, t, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
	T45_[1] = result;
	result = percent___cgen_25361(T45_, 2);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getClosureType__cgen_6675)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyEnum_TClosureTypeKind__9cCFzcVQ9cBXhFbAj307bqVg kind) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw check;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* rettype;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* desc;
	result = NIM_NIL;
	nimZeroMem((void*)(&check), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
	initIntSet__pureZcollectionsZintsets_238((&check));
	result = getTempName__cgen_428(m);
	rettype = NIM_NIL;
	desc = NIM_NIL;
	genProcParams__cgen_3508(m, t, &rettype, &desc, (&check), !((kind == ((tyEnum_TClosureTypeKind__9cCFzcVQ9cBXhFbAj307bqVg) 0))), NIM_FALSE);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isImportedType__cgen_1301(t);
		if (!!(T3_)) goto LA4_;
		{
			NIM_BOOL T8_;
			tyArray__InO6xIOhXMnkCXPnEYWwWg T12_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
			T8_ = (NIM_BOOL)0;
			T8_ = !(((*t).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9)));
			if (T8_) goto LA9_;
			T8_ = !((kind == ((tyEnum_TClosureTypeKind__9cCFzcVQ9cBXhFbAj307bqVg) 2)));
			LA9_: ;
			if (!T8_) goto LA10_;
			nimZeroMem((void*)T12_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
			T12_[0] = rope__ropes_109(CallingConvToStr__cgen_1379[((*t).callConv)- 0]);
			T12_[1] = rettype;
			T12_[2] = result;
			T12_[3] = desc;
			T13_ = NIM_NIL;
			T13_ = percent___cgen_5949(T12_, 4);
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 4))- 0], T13_);
		}
		goto LA6_;
		LA10_: ;
		{
			tyArray__FKvM4FDhljtt88k8FkGthA T15_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
			nimZeroMem((void*)T15_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
			T15_[0] = result;
			T15_[1] = rettype;
			T15_[2] = desc;
			T16_ = NIM_NIL;
			T16_ = percent___cgen_5954(T15_, 3);
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 4))- 0], T16_);
		}
		LA6_: ;
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genConstSimpleList__cgen_25198)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL isConst) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	result = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				it = (*n)._kind_6.sons->data[i];
				{
					if (!(((NI) 0) < i)) goto LA6_;
					add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_219));
				}
				LA6_: ;
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
					if (!((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34))) goto LA10_;
					T12_ = NIM_NIL;
					T12_ = genBracedInit__cgen_13891(p, (*it)._kind_6.sons->data[((NI) 1)], isConst, (*(*it)._kind_6.sons->data[((NI) 0)]).typ);
					add__ropes_159(&result, T12_);
				}
				goto LA8_;
				LA10_: ;
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
					T14_ = NIM_NIL;
					T14_ = genBracedInit__cgen_13891(p, it, isConst, (*it).typ);
					add__ropes_159(&result, T14_);
				}
				LA8_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_220));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genConstTuple__cgen_25219)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL isConst, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tup) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	result = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				it = (*n)._kind_6.sons->data[i];
				{
					if (!(((NI) 0) < i)) goto LA6_;
					add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_219));
				}
				LA6_: ;
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
					if (!((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34))) goto LA10_;
					T12_ = NIM_NIL;
					T12_ = genBracedInit__cgen_13891(p, (*it)._kind_6.sons->data[((NI) 1)], isConst, (*tup).sons->data[i]);
					add__ropes_159(&result, T12_);
				}
				goto LA8_;
				LA10_: ;
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
					T14_ = NIM_NIL;
					T14_ = genBracedInit__cgen_13891(p, it, isConst, (*tup).sons->data[i]);
					add__ropes_159(&result, T14_);
				}
				LA8_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_220));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, caseObjDefaultBranch__cgen_25027)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* obj, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ branch) {
	NI result;
{	result = (NI)0;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(obj);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					NI j;
					NI colontmp__2;
					NI T5_;
					NI res;
					j = (NI)0;
					colontmp__2 = (NI)0;
					T5_ = (NI)0;
					T5_ = len__ast_3155((*obj)._kind_6.sons->data[i]);
					colontmp__2 = (NI)(T5_ - ((NI) 2));
					res = ((NI) 0);
					{
						while (1) {
							if (!(res <= colontmp__2)) goto LA7;
							j = res;
							{
								tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ x;
								tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ y;
								if (!((*(*(*obj)._kind_6.sons->data[i])._kind_6.sons->data[j]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 44))) goto LA10_;
								x = getOrdValue__types_161((*(*(*obj)._kind_6.sons->data[i])._kind_6.sons->data[j])._kind_6.sons->data[((NI) 0)], Max__int495056_27);
								y = getOrdValue__types_161((*(*(*obj)._kind_6.sons->data[i])._kind_6.sons->data[j])._kind_6.sons->data[((NI) 1)], Max__int495056_27);
								{
									NIM_BOOL T14_;
									T14_ = (NIM_BOOL)0;
									T14_ = lteq___int495056_421(x, branch);
									if (!(T14_)) goto LA15_;
									T14_ = lteq___int495056_421(branch, y);
									LA15_: ;
									if (!T14_) goto LA16_;
									result = i;
									goto BeforeRet_;
								}
								LA16_: ;
							}
							goto LA8_;
							LA10_: ;
							{
								tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T19_;
								NIM_BOOL T20_;
								T19_ = getOrdValue__types_161((*(*obj)._kind_6.sons->data[i])._kind_6.sons->data[j], Max__int495056_27);
								T20_ = (NIM_BOOL)0;
								T20_ = eqeq___int495056_425(T19_, branch);
								if (!T20_) goto LA21_;
								result = i;
								goto BeforeRet_;
							}
							goto LA8_;
							LA21_: ;
							LA8_: ;
							res += ((NI) 1);
						} LA7: ;
					}
				}
				{
					NI T25_;
					T25_ = (NI)0;
					T25_ = len__ast_3155((*obj)._kind_6.sons->data[i]);
					if (!(T25_ == ((NI) 1))) goto LA26_;
					result = i;
					goto BeforeRet_;
				}
				LA26_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getDefaultValue__cgen_24983)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	result = NIM_NIL;
	t = skipTypes__ast_3723(typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_239);
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1):
	{
		result = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_240));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44):
	{
		result = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_144));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 39):
	{
		result = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_241));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 26):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 6):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 7):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 5):
	{
		result = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_242));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
	{
		{
			if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0)) goto LA8_;
			result = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_243));
		}
		goto LA6_;
		LA8_: ;
		{
			result = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_242));
		}
		LA6_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25):
	{
		{
			if (!!(((*t).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9)))) goto LA14_;
			result = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_242));
		}
		goto LA12_;
		LA14_: ;
		{
			result = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_244));
		}
		LA12_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17):
	{
		NI count;
		count = ((NI) 0);
		add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8));
		getNullValueAuxT__cgen_17707(p, t, t, (*t).n, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), &result, (&count), NIM_TRUE, info);
		add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18):
	{
		result = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_221));
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3990(t);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
					if (!(i_2 < colontmp_)) goto LA21;
					i = i_2;
					{
						if (!(((NI) 0) < i)) goto LA24_;
						add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
					}
					LA24_: ;
					T26_ = NIM_NIL;
					T26_ = getDefaultValue__cgen_24983(p, (*t).sons->data[i], info);
					add__ropes_159(&result, T26_);
					i_2 += ((NI) 1);
				} LA21: ;
			}
		}
		add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
	{
		result = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_221));
		{
			NI i_3;
			NI colontmp__2;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T29_;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			T29_ = lengthOrd__types_1723((*(*(*p).module).g).config, (*t).sons->data[((NI) 0)]);
			colontmp__2 = toInt__int495056_273(T29_);
			i_4 = ((NI) 0);
			{
				while (1) {
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T36_;
					if (!(i_4 < colontmp__2)) goto LA31;
					i_3 = i_4;
					{
						if (!(((NI) 0) < i_3)) goto LA34_;
						add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
					}
					LA34_: ;
					T36_ = NIM_NIL;
					T36_ = getDefaultValue__cgen_24983(p, (*t).sons->data[((NI) 1)], info);
					add__ropes_159(&result, T36_);
					i_4 += ((NI) 1);
				} LA31: ;
			}
		}
		add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48):
	{
		result = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_245));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 19):
	{
		{
			tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ T41_;
			T41_ = (tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ)0;
			T41_ = mapSetType__cgen_1223((*(*(*p).module).g).config, t);
			if (!(T41_ == ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 17))) goto LA42_;
			result = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_246));
		}
		goto LA39_;
		LA42_: ;
		{
			result = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_144));
		}
		LA39_: ;
	}
	break;
	default:
	{
		NimStringDesc* T46_;
		T46_ = NIM_NIL;
		T46_ = rawNewString((reprEnum((NI)(*t).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)) ? reprEnum((NI)(*t).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_))->Sup.len : 0) + 32);
appendString(T46_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_247));
appendString(T46_, reprEnum((NI)(*t).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)));
		liMessage__msgs_1128((*(*(*p).module).g).config, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T46_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 2), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_248, NIM_FALSE);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, getNullValueAux__cgen_25071)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* obj, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constOrNil, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** result, NI* count, NIM_BOOL isConst, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
{	switch ((*obj).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 138):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** it;
			tySequence__IeU9azYSNIK3V9b36Ir6NZcw* colontmp_;
			NI i;
			NI L;
			NI T3_;
			it = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
			colontmp_ = NIM_NIL;
			colontmp_ = (*obj)._kind_6.sons;
			i = ((NI) 0);
			T3_ = (colontmp_ ? colontmp_->Sup.len : 0);
			L = T3_;
			{
				while (1) {
					if (!(i < L)) goto LA5;
					it = &colontmp_->data[i];
					getNullValueAux__cgen_25071(p, t, (*it), constOrNil, result, count, isConst, info);
					i += ((NI) 1);
				} LA5: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 139):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ branch;
		NI selectedBranch;
		NI countB;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b;
		getNullValueAux__cgen_25071(p, t, (*obj)._kind_6.sons->data[((NI) 0)], constOrNil, result, count, isConst, info);
		{
			if (!(((NI) 0) < (*count))) goto LA9_;
			add__ropes_162(result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		}
		LA9_: ;
		branch = Zero__int495056_7;
		{
			if (!!((constOrNil == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA13_;
			{
				NI i_2;
				NI colontmp__2;
				NI i_3;
				i_2 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = len__ast_3155(constOrNil);
				i_3 = ((NI) 1);
				{
					while (1) {
						if (!(i_3 < colontmp__2)) goto LA17;
						i_2 = i_3;
						{
							if (!((*(*constOrNil)._kind_6.sons->data[i_2]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34))) goto LA20_;
							{
								if (!((*(*(*(*(*constOrNil)._kind_6.sons->data[i_2])._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).id == (*(*(*(*obj)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).id)) goto LA24_;
								branch = getOrdValue__types_161((*(*constOrNil)._kind_6.sons->data[i_2])._kind_6.sons->data[((NI) 1)], Max__int495056_27);
								goto LA15;
							}
							LA24_: ;
						}
						goto LA18_;
						LA20_: ;
						{
							if (!(i_2 == (*(*(*obj)._kind_6.sons->data[((NI) 0)])._kind_4.sym).position)) goto LA27_;
							branch = getOrdValue__types_161((*constOrNil)._kind_6.sons->data[i_2], Max__int495056_27);
							goto LA15;
						}
						goto LA18_;
						LA27_: ;
						LA18_: ;
						i_3 += ((NI) 1);
					} LA17: ;
				}
			} LA15: ;
		}
		LA13_: ;
		selectedBranch = caseObjDefaultBranch__cgen_25027(obj, branch);
		add__ropes_162(result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8));
		countB = ((NI) 0);
		b = lastSon__ast_4833((*obj)._kind_6.sons->data[selectedBranch]);
		{
			NIM_BOOL T31_;
			NI T33_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T36_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T37_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
			NimStringDesc* T39_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T40_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T41_;
			T31_ = (NIM_BOOL)0;
			T31_ = ((*b).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 138));
			if (!(T31_)) goto LA32_;
			T33_ = (NI)0;
			T33_ = len__ast_3155(b);
			T31_ = (((NI) 0) < T33_);
			LA32_: ;
			if (!T31_) goto LA34_;
			T36_ = NIM_NIL;
			T36_ = mangleRecFieldName__cgen_3649((*p).module, (*(*obj)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
			T37_ = NIM_NIL;
			T37_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_238), T36_);
			T38_ = NIM_NIL;
			T38_ = amp___ropes_140(T37_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3));
			T39_ = NIM_NIL;
			T39_ = dollar___systemZdollars_3(selectedBranch);
			T40_ = NIM_NIL;
			T40_ = amp___ropes_140(T38_, T39_);
			T41_ = NIM_NIL;
			T41_ = amp___ropes_140(T40_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_228));
			add__ropes_159(result, T41_);
			getNullValueAux__cgen_25071(p, t, b, constOrNil, result, (&countB), isConst, info);
			add__ropes_162(result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
		}
		goto LA29_;
		LA34_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T45_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T46_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T47_;
			if (!((*b).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA43_;
			T45_ = NIM_NIL;
			T45_ = mangleRecFieldName__cgen_3649((*p).module, (*b)._kind_4.sym);
			T46_ = NIM_NIL;
			T46_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_138), T45_);
			T47_ = NIM_NIL;
			T47_ = amp___ropes_140(T46_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
			add__ropes_159(result, T47_);
			getNullValueAux__cgen_25071(p, t, b, constOrNil, result, (&countB), isConst, info);
		}
		goto LA29_;
		LA43_: ;
		LA29_: ;
		add__ropes_162(result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T73_;
		{
			if (!(((NI) 0) < (*count))) goto LA51_;
			add__ropes_162(result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		}
		LA51_: ;
		(*count) += ((NI) 1);
		field = (*obj)._kind_4.sym;
		{
			if (!!((constOrNil == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA55_;
			{
				NI i_4;
				NI colontmp__3;
				NI i_5;
				i_4 = (NI)0;
				colontmp__3 = (NI)0;
				colontmp__3 = len__ast_3155(constOrNil);
				i_5 = ((NI) 1);
				{
					while (1) {
						if (!(i_5 < colontmp__3)) goto LA59;
						i_4 = i_5;
						{
							if (!((*(*constOrNil)._kind_6.sons->data[i_4]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34))) goto LA62_;
							{
								tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T68_;
								if (!((*(*(*(*(*constOrNil)._kind_6.sons->data[i_4])._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).id == (*(*field).name).id)) goto LA66_;
								T68_ = NIM_NIL;
								T68_ = genBracedInit__cgen_13891(p, (*(*constOrNil)._kind_6.sons->data[i_4])._kind_6.sons->data[((NI) 1)], isConst, (*field).typ);
								add__ropes_159(result, T68_);
								goto BeforeRet_;
							}
							LA66_: ;
						}
						goto LA60_;
						LA62_: ;
						{
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T72_;
							if (!(i_4 == (*field).position)) goto LA70_;
							T72_ = NIM_NIL;
							T72_ = genBracedInit__cgen_13891(p, (*constOrNil)._kind_6.sons->data[i_4], isConst, (*field).typ);
							add__ropes_159(result, T72_);
							goto BeforeRet_;
						}
						goto LA60_;
						LA70_: ;
						LA60_: ;
						i_5 += ((NI) 1);
					} LA59: ;
				}
			}
		}
		LA55_: ;
		T73_ = NIM_NIL;
		T73_ = getDefaultValue__cgen_24983(p, (*field).typ, info);
		add__ropes_159(result, T73_);
	}
	break;
	default:
	{
		NimStringDesc* T75_;
		NimStringDesc* T76_;
		T75_ = NIM_NIL;
		T76_ = NIM_NIL;
		T76_ = dollar___renderer_2116(obj);
		T75_ = rawNewString((T76_ ? T76_->Sup.len : 0) + 32);
appendString(T75_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_247));
appendString(T75_, T76_);
		liMessage__msgs_1128((*(*(*p).module).g).config, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T75_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_249, NIM_FALSE);
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, getNullValueAuxT__cgen_17707)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* orig, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* obj, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constOrNil, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** result, NI* count, NIM_BOOL isConst, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* base;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* oldRes;
	NI oldcount;
	base = (*t).sons->data[((NI) 0)];
	oldRes = (*result);
	oldcount = (*count);
	{
		if (!!((base == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA3_;
		add__ropes_162(result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8));
		base = skipTypes__ast_3723(base, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_130);
		getNullValueAuxT__cgen_17707(p, orig, base, (*base).n, constOrNil, result, count, isConst, info);
		add__ropes_162(result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T6_;
		T6_ = (NIM_BOOL)0;
		T6_ = isObjLackingTypeField__cgen_1337(t);
		if (!!(T6_)) goto LA7_;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
			if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 41))&63U)))!=0)) goto LA11_;
			T13_ = NIM_NIL;
			T13_ = genTypeInfoV2__cgen_7958((*p).module, orig, (*obj).info);
			add__ropes_159(result, T13_);
		}
		goto LA9_;
		LA11_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
			T15_ = NIM_NIL;
			T15_ = genTypeInfoV1__cgen_6798((*p).module, orig, (*obj).info);
			add__ropes_159(result, T15_);
		}
		LA9_: ;
		(*count) += ((NI) 1);
	}
	goto LA1_;
	LA7_: ;
	LA1_: ;
	getNullValueAux__cgen_25071(p, t, obj, constOrNil, result, count, isConst, info);
	{
		if (!(oldcount == (*count))) goto LA18_;
		unsureAsgnRef((void**) (&(*result)), oldRes);
	}
	LA18_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genConstObjConstr__cgen_25182)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL isConst) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	NI count;
	tyArray__ts9cf9blICas1QWmw89bglZ7w T5_;
	result = NIM_NIL;
	result = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
	t = skipTypes__ast_3723((*n).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_155);
	count = ((NI) 0);
	{
		if (!((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17))) goto LA3_;
		getNullValueAuxT__cgen_17707(p, t, t, (*t).n, n, &result, (&count), isConst, (*n).info);
	}
	LA3_: ;
	nimZeroMem((void*)T5_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
	T5_[0] = result;
	result = percent___cgen_25193(T5_, 1);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genStringLiteralV2Const__cgen_595)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL isConst) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	NI id;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* pureLit;
	tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T9_;
	result = NIM_NIL;
	id = nodeTableTestOrSet__treetab_198((&(*m).dataCache), n, ((NI) ((*m).labels)));
	pureLit = NIM_NIL;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
		if (!(id == ((NI) ((*m).labels)))) goto LA3_;
		pureLit = getTempName__cgen_428(m);
		T5_ = NIM_NIL;
		T5_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_36));
		(void)(T5_);
		T6_ = NIM_NIL;
		T6_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_37));
		(void)(T6_);
		genStringLiteralDataOnlyV2__cgen_560(m, (*n)._kind_3.strVal, pureLit, isConst);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
		T8_ = NIM_NIL;
		T8_ = rope__ropes_115(((NI64) (id)));
		pureLit = amp___ropes_128((*m).tmpBase, T8_);
	}
	LA1_: ;
	nimZeroMem((void*)T9_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
	T9_[0] = rope__ropes_115(((NI64) (((*n)._kind_3.strVal ? (*n)._kind_3.strVal->Sup.len : 0))));
	T9_[1] = pureLit;
	result = percent___cgen_602(T9_, 2);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genBracedInit__cgen_13891)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL isConst, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* optionalType) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59):
	{
		result = genBracedInit__cgen_13891(p, (*n)._kind_6.sons->data[((NI) 1)], isConst, (*n).typ);
	}
	break;
	default:
	{
		tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg ty;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
		ty = ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 0);
		typ = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL);
		{
			if (!(optionalType == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA5_;
			{
				if (!((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22))) goto LA9_;
				ty = ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28);
			}
			goto LA7_;
			LA9_: ;
			{
				internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_214), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_215);
			}
			LA7_: ;
		}
		goto LA3_;
		LA5_: ;
		{
			typ = skipTypes__ast_3723(optionalType, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_115);
			ty = (*typ).kind;
		}
		LA3_: ;
		switch (ty) {
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 19):
		{
			tySequence__6H5Oh5UUvVCLiakt9aTwtUQ* cs;
			NI64 T14_;
			cs = toBitSet__nimsets_103((*(*(*p).module).g).config, n);
			T14_ = (NI64)0;
			T14_ = getSize__types_3388((*(*(*p).module).g).config, (*n).typ);
			result = genRawSetData__cgen_17896(cs, ((NI) (T14_)));
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
		{
			{
				if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0)) goto LA18_;
				result = genConstSeqV2__cgen_25366(p, n, typ, isConst);
			}
			goto LA16_;
			LA18_: ;
			{
				result = genConstSeq__cgen_25242(p, n, typ, isConst);
			}
			LA16_: ;
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25):
		{
			{
				NIM_BOOL T24_;
				NIM_BOOL T25_;
				NI T27_;
				T24_ = (NIM_BOOL)0;
				T25_ = (NIM_BOOL)0;
				T25_ = ((*typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
				if (!(T25_)) goto LA26_;
				T27_ = (NI)0;
				T27_ = safeLen__ast_3148(n);
				T25_ = (((NI) 1) < T27_);
				LA26_: ;
				T24_ = T25_;
				if (!(T24_)) goto LA28_;
				T24_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23));
				LA28_: ;
				if (!T24_) goto LA29_;
				{
					tyArray__dAmhZbEWrTM5xES2bTVweg T35_;
					if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA33_;
					nimZeroMem((void*)T35_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
					result = percent___cgen_25521(T35_, 0);
				}
				goto LA31_;
				LA33_: ;
				{
					tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw d;
					tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T37_;
					nimZeroMem((void*)(&d), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
					initLocExpr__cgen_11548(p, (*n)._kind_6.sons->data[((NI) 0)], (&d));
					nimZeroMem((void*)T37_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
					T37_[0] = getClosureType__cgen_6675((*p).module, typ, ((tyEnum_TClosureTypeKind__9cCFzcVQ9cBXhFbAj307bqVg) 1));
					T37_[1] = rdLoc__cgen_435(d);
					result = percent___cgen_25528(T37_, 2);
				}
				LA31_: ;
			}
			goto LA22_;
			LA29_: ;
			{
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw d_2;
				nimZeroMem((void*)(&d_2), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				initLocExpr__cgen_11548(p, n, (&d_2));
				result = rdLoc__cgen_435(d_2);
			}
			LA22_: ;
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48):
		{
			result = genConstSimpleList__cgen_25198(p, n, isConst);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18):
		{
			result = genConstTuple__cgen_25219(p, n, isConst, typ);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27):
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* data;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* payload;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* ctype;
			NI arrLen;
			NimStringDesc* res;
			NimStringDesc* T46_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T56_;
			tyArray__FKvM4FDhljtt88k8FkGthA T57_;
			{
				if (!!(((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41)))) goto LA44_;
				internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_235), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_236);
			}
			LA44_: ;
			data = genConstSimpleList__cgen_25198(p, n, isConst);
			payload = getTempName__cgen_428((*p).module);
			ctype = getTypeDesc__cgen_6662((*p).module, (*typ).sons->data[((NI) 0)], ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			arrLen = len__ast_3155(n);
			res = rawNewString(((NI) 80));
			res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_64));
			T46_ = NIM_NIL;
			{
				if (!isConst) goto LA49_;
				T46_ = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_35));
			}
			goto LA47_;
			LA49_: ;
			{
				T46_ = ((NimStringDesc*) NIM_NIL);
			}
			LA47_: ;
			cgFormatValue__cgen_151((&res), T46_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_13));
			cgFormatValue__cgen_147((&res), ctype);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_13));
			cgFormatValue__cgen_147((&res), payload);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_166));
			cgFormatValue__cgen_154((&res), ((NI64) (arrLen)));
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_237));
			cgFormatValue__cgen_147((&res), data);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA54_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA54_: ;
			T56_ = NIM_NIL;
			T56_ = rope__ropes_109(res);
			add__ropes_159(&(*(*p).module).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 9))- 0], T56_);
			nimZeroMem((void*)T57_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
			T57_[0] = ctype;
			T57_[1] = payload;
			T57_[2] = rope__ropes_115(((NI64) (arrLen)));
			result = percent___cgen_25616(T57_, 3);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17):
		{
			result = genConstObjConstr__cgen_25182(p, n, isConst);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29):
		{
			{
				NIM_BOOL T62_;
				NIM_BOOL T63_;
				T62_ = (NIM_BOOL)0;
				T63_ = (NIM_BOOL)0;
				T63_ = (((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0);
				if (!(T63_)) goto LA64_;
				T63_ = !(((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23)));
				LA64_: ;
				T62_ = T63_;
				if (!(T62_)) goto LA65_;
				T62_ = (ty == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28));
				LA65_: ;
				if (!T62_) goto LA66_;
				result = genStringLiteralV2Const__cgen_595((*p).module, n, isConst);
			}
			goto LA60_;
			LA66_: ;
			{
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw d_3;
				nimZeroMem((void*)(&d_3), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				initLocExpr__cgen_11548(p, n, (&d_3));
				result = rdLoc__cgen_435(d_3);
			}
			LA60_: ;
		}
		break;
		default:
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw d_4;
			nimZeroMem((void*)(&d_4), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLocExpr__cgen_11548(p, n, (&d_4));
			result = rdLoc__cgen_435(d_4);
		}
		break;
		}
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawConstExpr__cgen_10399)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	NI id;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T2_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T3_;
	t = (*n).typ;
	T1_ = NIM_NIL;
	T1_ = getTypeDesc__cgen_6662((*p).module, t, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
	(void)(T1_);
	id = nodeTableTestOrSet__treetab_198((&(*(*p).module).dataCache), n, ((NI) ((*(*p).module).labels)));
	T2_ = NIM_NIL;
	T2_ = rope__ropes_115(((NI64) (id)));
	T3_ = NIM_NIL;
	T3_ = amp___ropes_128((*(*p).module).tmpBase, T2_);
	fillLoc__cgen_71(d, ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 8), n, T3_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 1));
	{
		tyArray__FKvM4FDhljtt88k8FkGthA T8_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
		if (!(id == ((NI) ((*(*p).module).labels)))) goto LA6_;
		(*(*p).module).labels += ((NI) 1);
		nimZeroMem((void*)T8_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
		T8_[0] = getTypeDesc__cgen_6662((*p).module, t, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		T8_[1] = (*d).r;
		T8_[2] = genBracedInit__cgen_13891(p, n, NIM_TRUE, t);
		T9_ = NIM_NIL;
		T9_ = percent___cgen_17917(T8_, 3);
		add__ropes_159(&(*(*p).module).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 9))- 0], T9_);
	}
	LA6_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genGenericAsgn__cgen_18127)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw dest, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw src, tySet_tyEnum_TAssignmentFlag__A5xFQCIBNzBTAeRylr7rQA flags) {
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T5_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0)) goto LA3_;
		T5_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T5_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res = rawNewString(((NI) 80));
		T6_ = NIM_NIL;
		T6_ = rdLoc__cgen_435(dest);
		cgFormatValue__cgen_147((&res), T6_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
		T7_ = NIM_NIL;
		T7_ = rdLoc__cgen_435(src);
		cgFormatValue__cgen_147((&res), T7_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA10_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA10_: ;
		T12_ = NIM_NIL;
		T12_ = rope__ropes_109(res);
		T13_ = NIM_NIL;
		T13_ = indentLine__cgen_286(p, T12_);
		add__ropes_159(T5_, T13_);
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T15_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T17_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T18_;
		T15_ = (NIM_BOOL)0;
		T15_ = !(((flags &((NU8)1<<((NU)(((tyEnum_TAssignmentFlag__A5xFQCIBNzBTAeRylr7rQA) 0))&7U)))!=0));
		if (T15_) goto LA16_;
		T17_ = NIM_NIL;
		T17_ = t__cgen_85(dest);
		T18_ = NIM_NIL;
		T18_ = skipTypes__ast_3723(T17_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_183);
		T15_ = (((*T18_).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 6))&63U)))!=0);
		LA16_: ;
		if (!T15_) goto LA19_;
		{
			NIM_BOOL T23_;
			NIM_BOOL T24_;
			NIM_BOOL T27_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T30_;
			NimStringDesc* res_2;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T31_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T32_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T33_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T34_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T39_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T40_;
			T23_ = (NIM_BOOL)0;
			T24_ = (NIM_BOOL)0;
			T24_ = (dest.storage == ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 2));
			if (!(T24_)) goto LA25_;
			T24_ = !(((*(*(*(*p).module).g).config).selectedGC == ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 10)));
			LA25_: ;
			T23_ = T24_;
			if (T23_) goto LA26_;
			T27_ = (NIM_BOOL)0;
			T27_ = usesWriteBarrier__options_4033((*(*(*p).module).g).config);
			T23_ = !(T27_);
			LA26_: ;
			if (!T23_) goto LA28_;
			T30_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T30_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_2 = rawNewString(((NI) 80));
			T31_ = NIM_NIL;
			T31_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_250));
			cgFormatValue__cgen_147((&res_2), T31_);
			res_2 = resizeString(res_2, 8);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_126));
			T32_ = NIM_NIL;
			T32_ = addrLoc__cgen_10337((*(*(*p).module).g).config, dest);
			cgFormatValue__cgen_147((&res_2), T32_);
			res_2 = resizeString(res_2, 19);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_253));
			T33_ = NIM_NIL;
			T33_ = addrLoc__cgen_10337((*(*(*p).module).g).config, src);
			cgFormatValue__cgen_147((&res_2), T33_);
			res_2 = resizeString(res_2, 9);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_127));
			T34_ = NIM_NIL;
			T34_ = rdLoc__cgen_435(dest);
			cgFormatValue__cgen_147((&res_2), T34_);
			res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_128));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA37_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA37_: ;
			T39_ = NIM_NIL;
			T39_ = rope__ropes_109(res_2);
			T40_ = NIM_NIL;
			T40_ = indentLine__cgen_286(p, T39_);
			add__ropes_159(T30_, T40_);
		}
		goto LA21_;
		LA28_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T42_;
			NimStringDesc* res_3;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T43_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T44_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T45_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T46_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T47_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T52_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T53_;
			T42_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T42_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_3 = rawNewString(((NI) 80));
			T43_ = NIM_NIL;
			T43_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_254));
			cgFormatValue__cgen_147((&res_3), T43_);
			res_3 = resizeString(res_3, 8);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_126));
			T44_ = NIM_NIL;
			T44_ = addrLoc__cgen_10337((*(*(*p).module).g).config, dest);
			cgFormatValue__cgen_147((&res_3), T44_);
			res_3 = resizeString(res_3, 9);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_255));
			T45_ = NIM_NIL;
			T45_ = addrLoc__cgen_10337((*(*(*p).module).g).config, src);
			cgFormatValue__cgen_147((&res_3), T45_);
			res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			T46_ = NIM_NIL;
			T46_ = t__cgen_85(dest);
			T47_ = NIM_NIL;
			T47_ = genTypeInfoV1__cgen_6798((*p).module, T46_, (*dest.lode).info);
			cgFormatValue__cgen_147((&res_3), T47_);
			res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA50_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA50_: ;
			T52_ = NIM_NIL;
			T52_ = rope__ropes_109(res_3);
			T53_ = NIM_NIL;
			T53_ = indentLine__cgen_286(p, T52_);
			add__ropes_159(T42_, T53_);
		}
		LA21_: ;
	}
	goto LA1_;
	LA19_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T55_;
		NimStringDesc* res_4;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T56_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T57_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T58_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T59_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T60_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T65_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T66_;
		T55_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T55_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_4 = rawNewString(((NI) 80));
		T56_ = NIM_NIL;
		T56_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_256));
		cgFormatValue__cgen_147((&res_4), T56_);
		res_4 = resizeString(res_4, 8);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_126));
		T57_ = NIM_NIL;
		T57_ = addrLoc__cgen_10337((*(*(*p).module).g).config, dest);
		cgFormatValue__cgen_147((&res_4), T57_);
		res_4 = resizeString(res_4, 9);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_255));
		T58_ = NIM_NIL;
		T58_ = addrLoc__cgen_10337((*(*(*p).module).g).config, src);
		cgFormatValue__cgen_147((&res_4), T58_);
		res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		T59_ = NIM_NIL;
		T59_ = t__cgen_85(dest);
		T60_ = NIM_NIL;
		T60_ = genTypeInfoV1__cgen_6798((*p).module, T59_, (*dest.lode).info);
		cgFormatValue__cgen_147((&res_4), T60_);
		res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA63_;
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA63_: ;
		T65_ = NIM_NIL;
		T65_ = rope__ropes_109(res_4);
		T66_ = NIM_NIL;
		T66_ = indentLine__cgen_286(p, T65_);
		add__ropes_159(T55_, T66_);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canMove__cgen_17940)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw dest) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41))) goto LA3_;
		{
			NIM_BOOL T7_;
			NIM_BOOL T8_;
			NI T10_;
			T7_ = (NIM_BOOL)0;
			T8_ = (NIM_BOOL)0;
			T8_ = isDeepConstExpr__trees_171(n, NIM_FALSE);
			T7_ = !(T8_);
			if (T7_) goto LA9_;
			T10_ = (NI)0;
			T10_ = len__ast_3155(n);
			T7_ = (T10_ == ((NI) 0));
			LA9_: ;
			if (!T7_) goto LA11_;
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T15_;
				T15_ = NIM_NIL;
				T15_ = skipTypes__ast_3723((*n).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_183);
				if (!((*T15_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24))) goto LA16_;
				result = NIM_TRUE;
				goto BeforeRet_;
			}
			LA16_: ;
		}
		LA11_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T19_;
		T19_ = (NIM_BOOL)0;
		T19_ = ((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22));
		if (!(T19_)) goto LA20_;
		T19_ = (((*n)._kind_3.strVal ? (*n)._kind_3.strVal->Sup.len : 0) == ((NI) 0));
		LA20_: ;
		if (!T19_) goto LA21_;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	goto LA1_;
	LA21_: ;
	LA1_: ;
	result = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, optAsgnLoc__cgen_18031)(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* field, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* Result) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T2_;
	(*Result).k = 0;
	(*Result).storage = 0;
	(*Result).flags = 0;
	unsureAsgnRef((void**)&(*Result).lode, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).r, NIM_NIL);
	(*Result).k = ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 5);
	(*Result).storage = a.storage;
	unsureAsgnRef((void**) (&(*Result).lode), lodeTyp__cgen_92(t));
	T1_ = NIM_NIL;
	T1_ = rdLoc__cgen_435(a);
	T2_ = NIM_NIL;
	T2_ = amp___ropes_140(T1_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_138));
	unsureAsgnRef((void**) (&(*Result).r), amp___ropes_128(T2_, field));
}
N_LIB_PRIVATE N_NIMCALL(void, genOptAsgnTuple__cgen_18043)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw dest, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw src, tySet_tyEnum_TAssignmentFlag__A5xFQCIBNzBTAeRylr7rQA flags) {
	tySet_tyEnum_TAssignmentFlag__A5xFQCIBNzBTAeRylr7rQA newflags;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T10_;
	{
		if (!(src.storage == ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 1))) goto LA3_;
		newflags = (flags | 1);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T6_;
		T6_ = NIM_NIL;
		T6_ = t__cgen_85(dest);
		if (!(((*T6_).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 6))&63U)))!=0)) goto LA7_;
		newflags = (flags & ~ 1);
	}
	goto LA1_;
	LA7_: ;
	{
		newflags = flags;
	}
	LA1_: ;
	T10_ = NIM_NIL;
	T10_ = t__cgen_85(dest);
	t = skipTypes__ast_3723(T10_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3990(t);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t_2;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* field;
				tyArray__ts9cf9blICas1QWmw89bglZ7w T14_;
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw T15_;
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw T16_;
				if (!(i_2 < colontmp_)) goto LA13;
				i = i_2;
				t_2 = (*t).sons->data[i];
				nimZeroMem((void*)T14_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
				T14_[0] = rope__ropes_115(((NI64) (i)));
				field = percent___cgen_18078(T14_, 1);
				nimZeroMem((void*)(&T15_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				optAsgnLoc__cgen_18031(dest, t_2, field, (&T15_));
				nimZeroMem((void*)(&T16_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				optAsgnLoc__cgen_18031(src, t_2, field, (&T16_));
				genAssignment__cgen_10403(p, T15_, T16_, newflags);
				i_2 += ((NI) 1);
			} LA13: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(NI, asgnComplexity__cgen_18019)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	{
		if (!!((n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA3_;
		switch ((*n).kind) {
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
		{
			result = ((NI) 1);
		}
		break;
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 139):
		{
			result = ((NI) 100);
		}
		break;
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 138):
		{
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t;
				t = NIM_NIL;
				{
					NI i;
					NI colontmp_;
					NI i_2;
					i = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = safeLen__ast_3148(n);
					i_2 = ((NI) 0);
					{
						while (1) {
							NI T12_;
							if (!(i_2 < colontmp_)) goto LA11;
							i = i_2;
							t = (*n)._kind_6.sons->data[i];
							T12_ = (NI)0;
							T12_ = asgnComplexity__cgen_18019(t);
							result += T12_;
							i_2 += ((NI) 1);
						} LA11: ;
					}
				}
			}
		}
		break;
		default:
		{
		}
		break;
		}
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genOptAsgnObject__cgen_18093)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw dest, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw src, tySet_tyEnum_TAssignmentFlag__A5xFQCIBNzBTAeRylr7rQA flags, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ) {
	tySet_tyEnum_TAssignmentFlag__A5xFQCIBNzBTAeRylr7rQA newflags;
{	{
		if (!(t == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		if (!(src.storage == ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 1))) goto LA7_;
		newflags = (flags | 1);
	}
	goto LA5_;
	LA7_: ;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T10_;
		T10_ = NIM_NIL;
		T10_ = t__cgen_85(dest);
		if (!(((*T10_).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 6))&63U)))!=0)) goto LA11_;
		newflags = (flags & ~ 1);
	}
	goto LA5_;
	LA11_: ;
	{
		newflags = flags;
	}
	LA5_: ;
	switch ((*t).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field;
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw T19_;
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw T20_;
		field = (*t)._kind_4.sym;
		{
			if (!((*field).loc.r == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA17_;
			fillObjectFields__cgen_3808((*p).module, typ);
		}
		LA17_: ;
		nimZeroMem((void*)(&T19_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		optAsgnLoc__cgen_18031(dest, (*field).typ, (*field).loc.r, (&T19_));
		nimZeroMem((void*)(&T20_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		optAsgnLoc__cgen_18031(src, (*field).typ, (*field).loc.r, (&T20_));
		genAssignment__cgen_10403(p, T19_, T20_, newflags);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 138):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child;
			child = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(t);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA25;
						i = i_2;
						child = (*t)._kind_6.sons->data[i];
						genOptAsgnObject__cgen_18093(p, dest, src, newflags, child, typ);
						i_2 += ((NI) 1);
					} LA25: ;
				}
			}
		}
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, reifiedOpenArray__cgen_11825)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x;
	result = (NIM_BOOL)0;
	x = n;
	{
		while (1) {
			if (!((*x).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63) || (*x).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64) || (*x).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58) || (*x).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65))) goto LA2;
			x = (*x)._kind_6.sons->data[((NI) 0)];
		} LA2: ;
	}
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = ((*x).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		if (!(T5_)) goto LA6_;
		T5_ = ((*(*x)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		LA6_: ;
		if (!T5_) goto LA7_;
		result = NIM_FALSE;
	}
	goto LA3_;
	LA7_: ;
	{
		result = NIM_TRUE;
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, dataFieldAccessor__cgen_471)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* sym) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0)) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26), sym);
		result = amp___ropes_140(T5_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_273));
	}
	goto LA1_;
	LA3_: ;
	{
		result = sym;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, byRefLoc__cgen_10353)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	result = a.r;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T6_;
		tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw T7_;
		tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ T13_;
		NIM_BOOL T15_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = !(((a.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 0))&15U)))!=0));
		if (!(T4_)) goto LA5_;
		T6_ = NIM_NIL;
		T6_ = t__cgen_85(a);
		T7_ = (tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw)0;
		{
			if (!((*a.lode).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA10_;
			T7_ = (*(*a.lode)._kind_4.sym).kind;
		}
		goto LA8_;
		LA10_: ;
		{
			T7_ = ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8);
		}
		LA8_: ;
		T13_ = (tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ)0;
		T13_ = mapType__cgen_1227((*(*(*p).module).g).config, T6_, T7_);
		T4_ = !((T13_ == ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 17)));
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA14_;
		T15_ = (NIM_BOOL)0;
		T15_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
		if (T15_) goto LA16_;
		T15_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
		LA16_: ;
		T3_ = !(T15_);
		LA14_: ;
		if (!T3_) goto LA17_;
		T19_ = NIM_NIL;
		T19_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_122), result);
		result = amp___ropes_140(T19_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
	}
	LA17_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genOpenArrayConv__cgen_18205)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw d, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T2_;
	T1_ = NIM_NIL;
	T1_ = t__cgen_85(a);
	T2_ = NIM_NIL;
	T2_ = skipTypes__ast_3723(T1_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_266);
	switch ((*T2_).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48):
	{
		{
			NIM_BOOL T6_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T9_;
			NimStringDesc* res;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
			T6_ = (NIM_BOOL)0;
			T6_ = reifiedOpenArray__cgen_11825(a.lode);
			if (!T6_) goto LA7_;
			T9_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T9_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res = rawNewString(((NI) 80));
			T10_ = NIM_NIL;
			T10_ = rdLoc__cgen_435(d);
			cgFormatValue__cgen_147((&res), T10_);
			res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_267));
			T11_ = NIM_NIL;
			T11_ = rdLoc__cgen_435(a);
			cgFormatValue__cgen_147((&res), T11_);
			res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_268));
			T12_ = NIM_NIL;
			T12_ = rdLoc__cgen_435(d);
			cgFormatValue__cgen_147((&res), T12_);
			res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_269));
			T13_ = NIM_NIL;
			T13_ = rdLoc__cgen_435(a);
			cgFormatValue__cgen_147((&res), T13_);
			res = resizeString(res, 8);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_270));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA16_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA16_: ;
			T18_ = NIM_NIL;
			T18_ = rope__ropes_109(res);
			T19_ = NIM_NIL;
			T19_ = indentLine__cgen_286(p, T18_);
			add__ropes_159(T9_, T19_);
		}
		goto LA4_;
		LA7_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T21_;
			NimStringDesc* res_2;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T30_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T31_;
			T21_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T21_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_2 = rawNewString(((NI) 80));
			T22_ = NIM_NIL;
			T22_ = rdLoc__cgen_435(d);
			cgFormatValue__cgen_147((&res_2), T22_);
			res_2 = resizeString(res_2, 10);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_267));
			T23_ = NIM_NIL;
			T23_ = rdLoc__cgen_435(a);
			cgFormatValue__cgen_147((&res_2), T23_);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_164));
			T24_ = NIM_NIL;
			T24_ = rdLoc__cgen_435(d);
			cgFormatValue__cgen_147((&res_2), T24_);
			res_2 = resizeString(res_2, 10);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_269));
			T25_ = NIM_NIL;
			T25_ = rdLoc__cgen_435(a);
			cgFormatValue__cgen_147((&res_2), T25_);
			res_2 = resizeString(res_2, 6);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_271));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA28_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA28_: ;
			T30_ = NIM_NIL;
			T30_ = rope__ropes_109(res_2);
			T31_ = NIM_NIL;
			T31_ = indentLine__cgen_286(p, T30_);
			add__ropes_159(T21_, T31_);
		}
		LA4_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T33_;
		NimStringDesc* res_3;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T34_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T35_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T36_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T37_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T39_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T40_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T45_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T46_;
		T33_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T33_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_3 = rawNewString(((NI) 80));
		T34_ = NIM_NIL;
		T34_ = rdLoc__cgen_435(d);
		cgFormatValue__cgen_147((&res_3), T34_);
		res_3 = resizeString(res_3, 11);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_272));
		T35_ = NIM_NIL;
		T35_ = rdLoc__cgen_435(a);
		T36_ = NIM_NIL;
		T36_ = dataFieldAccessor__cgen_471(p, T35_);
		cgFormatValue__cgen_147((&res_3), T36_);
		res_3 = resizeString(res_3, 5);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_274));
		T37_ = NIM_NIL;
		T37_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res_3), T37_);
		T38_ = NIM_NIL;
		T38_ = dataField__cgen_479(p);
		cgFormatValue__cgen_147((&res_3), T38_);
		res_3 = resizeString(res_3, 13);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_275));
		T39_ = NIM_NIL;
		T39_ = rdLoc__cgen_435(d);
		cgFormatValue__cgen_147((&res_3), T39_);
		res_3 = resizeString(res_3, 10);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_269));
		T40_ = NIM_NIL;
		T40_ = lenExpr__cgen_458(p, a);
		cgFormatValue__cgen_147((&res_3), T40_);
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA43_;
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA43_: ;
		T45_ = NIM_NIL;
		T45_ = rope__ropes_109(res_3);
		T46_ = NIM_NIL;
		T46_ = indentLine__cgen_286(p, T45_);
		add__ropes_159(T33_, T46_);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T48_;
		NimStringDesc* res_4;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T49_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T50_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T51_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T52_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T53_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T54_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T59_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T60_;
		T48_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T48_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_4 = rawNewString(((NI) 80));
		T49_ = NIM_NIL;
		T49_ = rdLoc__cgen_435(d);
		cgFormatValue__cgen_147((&res_4), T49_);
		res_4 = resizeString(res_4, 10);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_267));
		T50_ = NIM_NIL;
		T50_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res_4), T50_);
		res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_164));
		T51_ = NIM_NIL;
		T51_ = rdLoc__cgen_435(d);
		cgFormatValue__cgen_147((&res_4), T51_);
		res_4 = resizeString(res_4, 10);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_269));
		T52_ = NIM_NIL;
		T52_ = t__cgen_85(a);
		T53_ = lengthOrd__types_1723((*(*(*p).module).g).config, T52_);
		T54_ = NIM_NIL;
		T54_ = rope__cgen_6948(T53_);
		cgFormatValue__cgen_147((&res_4), T54_);
		res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA57_;
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA57_: ;
		T59_ = NIM_NIL;
		T59_ = rope__ropes_109(res_4);
		T60_ = NIM_NIL;
		T60_ = indentLine__cgen_286(p, T59_);
		add__ropes_159(T48_, T60_);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* etyp;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T62_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T78_;
		NimStringDesc* res_6;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T79_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T80_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T81_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T82_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T83_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T84_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T85_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T90_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T91_;
		T62_ = NIM_NIL;
		T62_ = t__cgen_85(a);
		etyp = skipTypes__ast_3723(T62_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
		{
			NIM_BOOL T65_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T69_;
			NimStringDesc* res_5;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T70_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T71_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T76_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T77_;
			T65_ = (NIM_BOOL)0;
			T65_ = ((*etyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23));
			if (!(T65_)) goto LA66_;
			T65_ = (((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0);
			LA66_: ;
			if (!T65_) goto LA67_;
			T69_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T69_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_5 = rawNewString(((NI) 80));
			T70_ = NIM_NIL;
			T70_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_276));
			cgFormatValue__cgen_147((&res_5), T70_);
			res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T71_ = NIM_NIL;
			T71_ = byRefLoc__cgen_10353(p, a);
			cgFormatValue__cgen_147((&res_5), T71_);
			res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA74_;
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA74_: ;
			T76_ = NIM_NIL;
			T76_ = rope__ropes_109(res_5);
			T77_ = NIM_NIL;
			T77_ = indentLine__cgen_286(p, T76_);
			add__ropes_159(T69_, T77_);
		}
		LA67_: ;
		T78_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T78_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_6 = rawNewString(((NI) 80));
		T79_ = NIM_NIL;
		T79_ = rdLoc__cgen_435(d);
		cgFormatValue__cgen_147((&res_6), T79_);
		res_6 = resizeString(res_6, 11);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_272));
		T80_ = NIM_NIL;
		T80_ = rdLoc__cgen_435(a);
		T81_ = NIM_NIL;
		T81_ = dataFieldAccessor__cgen_471(p, T80_);
		cgFormatValue__cgen_147((&res_6), T81_);
		res_6 = resizeString(res_6, 5);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_274));
		T82_ = NIM_NIL;
		T82_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res_6), T82_);
		T83_ = NIM_NIL;
		T83_ = dataField__cgen_479(p);
		cgFormatValue__cgen_147((&res_6), T83_);
		res_6 = resizeString(res_6, 13);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_275));
		T84_ = NIM_NIL;
		T84_ = rdLoc__cgen_435(d);
		cgFormatValue__cgen_147((&res_6), T84_);
		res_6 = resizeString(res_6, 10);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_269));
		T85_ = NIM_NIL;
		T85_ = lenExpr__cgen_458(p, a);
		cgFormatValue__cgen_147((&res_6), T85_);
		res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA88_;
			res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA88_: ;
		T90_ = NIM_NIL;
		T90_ = rope__ropes_109(res_6);
		T91_ = NIM_NIL;
		T91_ = indentLine__cgen_286(p, T90_);
		add__ropes_159(T78_, T91_);
	}
	break;
	default:
	{
		NimStringDesc* T93_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T94_;
		T93_ = NIM_NIL;
		T94_ = NIM_NIL;
		T94_ = t__cgen_85(a);
		T93_ = rawNewString((reprEnum((NI)(*T94_).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)) ? reprEnum((NI)(*T94_).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_))->Sup.len : 0) + 14);
appendString(T93_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_277));
appendString(T93_, reprEnum((NI)(*T94_).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)));
		internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*a.lode).info, T93_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_278);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genAssignment__cgen_10403)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw dest, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw src, tySet_tyEnum_TAssignmentFlag__A5xFQCIBNzBTAeRylr7rQA flags) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ty;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T18_;
{	{
		NIM_BOOL T3_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T4_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T6_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T9_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
		T3_ = (NIM_BOOL)0;
		T4_ = NIM_NIL;
		T4_ = t__cgen_85(src);
		T3_ = !((T4_ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		if (!(T3_)) goto LA5_;
		T6_ = NIM_NIL;
		T6_ = t__cgen_85(src);
		T3_ = ((*T6_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21));
		LA5_: ;
		if (!T3_) goto LA7_;
		T9_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T9_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res = rawNewString(((NI) 80));
		T10_ = NIM_NIL;
		T10_ = rdLoc__cgen_435(dest);
		cgFormatValue__cgen_147((&res), T10_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
		T11_ = NIM_NIL;
		T11_ = rdLoc__cgen_435(src);
		cgFormatValue__cgen_147((&res), T11_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA14_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA14_: ;
		T16_ = NIM_NIL;
		T16_ = rope__ropes_109(res);
		T17_ = NIM_NIL;
		T17_ = indentLine__cgen_286(p, T16_);
		add__ropes_159(T9_, T17_);
		goto BeforeRet_;
	}
	LA7_: ;
	T18_ = NIM_NIL;
	T18_ = t__cgen_85(dest);
	ty = skipTypes__ast_3723(T18_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_252);
	switch ((*ty).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22):
	{
		genRefAssign__cgen_10581(p, dest, src);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
	{
		{
			if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0)) goto LA23_;
			genGenericAsgn__cgen_18127(p, dest, src, flags);
		}
		goto LA21_;
		LA23_: ;
		{
			NIM_BOOL T26_;
			NIM_BOOL T27_;
			T26_ = (NIM_BOOL)0;
			T27_ = (NIM_BOOL)0;
			T27_ = !(((flags &((NU8)1<<((NU)(((tyEnum_TAssignmentFlag__A5xFQCIBNzBTAeRylr7rQA) 0))&7U)))!=0));
			if (!(T27_)) goto LA28_;
			T27_ = !((src.storage == ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 1)));
			LA28_: ;
			T26_ = T27_;
			if (T26_) goto LA29_;
			T26_ = canMove__cgen_17940(p, src.lode, dest);
			LA29_: ;
			if (!T26_) goto LA30_;
			genRefAssign__cgen_10581(p, dest, src);
		}
		goto LA21_;
		LA30_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T33_;
			NimStringDesc* res_2;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T34_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T35_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T36_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T37_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T43_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T44_;
			T33_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T33_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_2 = rawNewString(((NI) 80));
			T34_ = NIM_NIL;
			T34_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_257));
			cgFormatValue__cgen_147((&res_2), T34_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T35_ = NIM_NIL;
			T35_ = addrLoc__cgen_10337((*(*(*p).module).g).config, dest);
			cgFormatValue__cgen_147((&res_2), T35_);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			T36_ = NIM_NIL;
			T36_ = rdLoc__cgen_435(src);
			cgFormatValue__cgen_147((&res_2), T36_);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			T37_ = NIM_NIL;
			T37_ = t__cgen_85(dest);
			T38_ = NIM_NIL;
			T38_ = genTypeInfoV1__cgen_6798((*p).module, T37_, (*dest.lode).info);
			cgFormatValue__cgen_147((&res_2), T38_);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA41_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA41_: ;
			T43_ = NIM_NIL;
			T43_ = rope__ropes_109(res_2);
			T44_ = NIM_NIL;
			T44_ = indentLine__cgen_286(p, T43_);
			add__ropes_159(T33_, T44_);
		}
		LA21_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
	{
		{
			if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0)) goto LA48_;
			genGenericAsgn__cgen_18127(p, dest, src, flags);
		}
		goto LA46_;
		LA48_: ;
		{
			NIM_BOOL T51_;
			NIM_BOOL T52_;
			T51_ = (NIM_BOOL)0;
			T52_ = (NIM_BOOL)0;
			T52_ = !(((flags &((NU8)1<<((NU)(((tyEnum_TAssignmentFlag__A5xFQCIBNzBTAeRylr7rQA) 0))&7U)))!=0));
			if (!(T52_)) goto LA53_;
			T52_ = !((src.storage == ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 1)));
			LA53_: ;
			T51_ = T52_;
			if (T51_) goto LA54_;
			T51_ = canMove__cgen_17940(p, src.lode, dest);
			LA54_: ;
			if (!T51_) goto LA55_;
			genRefAssign__cgen_10581(p, dest, src);
		}
		goto LA46_;
		LA55_: ;
		{
			{
				NIM_BOOL T60_;
				NIM_BOOL T61_;
				NIM_BOOL T64_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T67_;
				NimStringDesc* res_3;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T68_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T69_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T70_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T75_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T76_;
				T60_ = (NIM_BOOL)0;
				T61_ = (NIM_BOOL)0;
				T61_ = (dest.storage == ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 2));
				if (!(T61_)) goto LA62_;
				T61_ = !(((*(*(*(*p).module).g).config).selectedGC == ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 10)));
				LA62_: ;
				T60_ = T61_;
				if (T60_) goto LA63_;
				T64_ = (NIM_BOOL)0;
				T64_ = usesWriteBarrier__options_4033((*(*(*p).module).g).config);
				T60_ = !(T64_);
				LA63_: ;
				if (!T60_) goto LA65_;
				T67_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T67_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_3 = rawNewString(((NI) 80));
				T68_ = NIM_NIL;
				T68_ = rdLoc__cgen_435(dest);
				cgFormatValue__cgen_147((&res_3), T68_);
				res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
				T69_ = NIM_NIL;
				T69_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_258));
				cgFormatValue__cgen_147((&res_3), T69_);
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
				T70_ = NIM_NIL;
				T70_ = rdLoc__cgen_435(src);
				cgFormatValue__cgen_147((&res_3), T70_);
				res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA73_;
					res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA73_: ;
				T75_ = NIM_NIL;
				T75_ = rope__ropes_109(res_3);
				T76_ = NIM_NIL;
				T76_ = indentLine__cgen_286(p, T75_);
				add__ropes_159(T67_, T76_);
			}
			goto LA58_;
			LA65_: ;
			{
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tmp;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T80_;
				NimStringDesc* res_4;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T81_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T82_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T83_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T84_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T85_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T90_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T91_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T92_;
				NimStringDesc* res_5;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T93_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T94_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T95_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T100_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T101_;
				if (!(dest.storage == ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 3))) goto LA78_;
				nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				getTemp__cgen_7373(p, ty, (&tmp), NIM_FALSE);
				T80_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T80_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_4 = rawNewString(((NI) 80));
				T81_ = NIM_NIL;
				T81_ = rdLoc__cgen_435(tmp);
				cgFormatValue__cgen_147((&res_4), T81_);
				res_4 = resizeString(res_4, 3);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
				T82_ = NIM_NIL;
				T82_ = rdLoc__cgen_435(dest);
				cgFormatValue__cgen_147((&res_4), T82_);
				res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_164));
				T83_ = NIM_NIL;
				T83_ = rdLoc__cgen_435(dest);
				cgFormatValue__cgen_147((&res_4), T83_);
				res_4 = resizeString(res_4, 3);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
				T84_ = NIM_NIL;
				T84_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_259));
				cgFormatValue__cgen_147((&res_4), T84_);
				res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
				T85_ = NIM_NIL;
				T85_ = rdLoc__cgen_435(src);
				cgFormatValue__cgen_147((&res_4), T85_);
				res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA88_;
					res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA88_: ;
				T90_ = NIM_NIL;
				T90_ = rope__ropes_109(res_4);
				T91_ = NIM_NIL;
				T91_ = indentLine__cgen_286(p, T90_);
				add__ropes_159(T80_, T91_);
				T92_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T92_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_5 = rawNewString(((NI) 80));
				res_5 = resizeString(res_5, 4);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
				T93_ = NIM_NIL;
				T93_ = rdLoc__cgen_435(tmp);
				cgFormatValue__cgen_147((&res_5), T93_);
				res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_56));
				T94_ = NIM_NIL;
				T94_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_261));
				cgFormatValue__cgen_147((&res_5), T94_);
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
				T95_ = NIM_NIL;
				T95_ = rdLoc__cgen_435(tmp);
				cgFormatValue__cgen_147((&res_5), T95_);
				res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA98_;
					res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA98_: ;
				T100_ = NIM_NIL;
				T100_ = rope__ropes_109(res_5);
				T101_ = NIM_NIL;
				T101_ = indentLine__cgen_286(p, T100_);
				add__ropes_159(T92_, T101_);
			}
			goto LA58_;
			LA78_: ;
			{
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T103_;
				NimStringDesc* res_6;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T104_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T105_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T106_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T107_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T112_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T113_;
				T103_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T103_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_6 = rawNewString(((NI) 80));
				T104_ = NIM_NIL;
				T104_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_123));
				cgFormatValue__cgen_147((&res_6), T104_);
				res_6 = resizeString(res_6, 10);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_121));
				T105_ = NIM_NIL;
				T105_ = addrLoc__cgen_10337((*(*(*p).module).g).config, dest);
				cgFormatValue__cgen_147((&res_6), T105_);
				res_6 = resizeString(res_6, 2);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
				T106_ = NIM_NIL;
				T106_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_258));
				cgFormatValue__cgen_147((&res_6), T106_);
				res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
				T107_ = NIM_NIL;
				T107_ = rdLoc__cgen_435(src);
				cgFormatValue__cgen_147((&res_6), T107_);
				res_6 = resizeString(res_6, 3);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_128));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA110_;
					res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA110_: ;
				T112_ = NIM_NIL;
				T112_ = rope__ropes_109(res_6);
				T113_ = NIM_NIL;
				T113_ = indentLine__cgen_286(p, T112_);
				add__ropes_159(T103_, T113_);
			}
			LA58_: ;
		}
		LA46_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25):
	{
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T117_;
			NIM_BOOL T118_;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T121_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T122_;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw T123_;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T124_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T125_;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw T126_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T127_;
			NimStringDesc* res_7;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T128_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T129_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T134_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T135_;
			T117_ = NIM_NIL;
			T117_ = t__cgen_85(dest);
			T118_ = (NIM_BOOL)0;
			T118_ = containsGarbageCollectedRef__types_612(T117_);
			if (!T118_) goto LA119_;
			nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			T121_ = NIM_NIL;
			T121_ = t__cgen_85(dest);
			T122_ = NIM_NIL;
			T122_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_262));
			nimZeroMem((void*)(&T123_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			optAsgnLoc__cgen_18031(dest, T121_, T122_, (&T123_));
			nimCopyMem((void*)(&a), (NIM_CONST void*)(&T123_), sizeof(a));
			nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			T124_ = NIM_NIL;
			T124_ = t__cgen_85(dest);
			T125_ = NIM_NIL;
			T125_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_262));
			nimZeroMem((void*)(&T126_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			optAsgnLoc__cgen_18031(src, T124_, T125_, (&T126_));
			nimCopyMem((void*)(&b), (NIM_CONST void*)(&T126_), sizeof(b));
			genRefAssign__cgen_10581(p, a, b);
			T127_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T127_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_7 = rawNewString(((NI) 80));
			T128_ = NIM_NIL;
			T128_ = rdLoc__cgen_435(dest);
			cgFormatValue__cgen_147((&res_7), T128_);
			res_7 = resizeString(res_7, 9);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_263));
			T129_ = NIM_NIL;
			T129_ = rdLoc__cgen_435(src);
			cgFormatValue__cgen_147((&res_7), T129_);
			res_7 = resizeString(res_7, 7);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_264));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA132_;
				res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA132_: ;
			T134_ = NIM_NIL;
			T134_ = rope__ropes_109(res_7);
			T135_ = NIM_NIL;
			T135_ = indentLine__cgen_286(p, T134_);
			add__ropes_159(T127_, T135_);
		}
		goto LA115_;
		LA119_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T137_;
			NimStringDesc* res_8;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T138_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T139_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T144_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T145_;
			T137_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T137_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_8 = rawNewString(((NI) 80));
			T138_ = NIM_NIL;
			T138_ = rdLoc__cgen_435(dest);
			cgFormatValue__cgen_147((&res_8), T138_);
			res_8 = resizeString(res_8, 3);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
			T139_ = NIM_NIL;
			T139_ = rdLoc__cgen_435(src);
			cgFormatValue__cgen_147((&res_8), T139_);
			res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA142_;
				res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA142_: ;
			T144_ = NIM_NIL;
			T144_ = rope__ropes_109(res_8);
			T145_ = NIM_NIL;
			T145_ = indentLine__cgen_286(p, T144_);
			add__ropes_159(T137_, T145_);
		}
		LA115_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18):
	{
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T149_;
			NIM_BOOL T150_;
			T149_ = NIM_NIL;
			T149_ = t__cgen_85(dest);
			T150_ = (NIM_BOOL)0;
			T150_ = containsGarbageCollectedRef__types_612(T149_);
			if (!T150_) goto LA151_;
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T155_;
				NI T156_;
				T155_ = NIM_NIL;
				T155_ = t__cgen_85(dest);
				T156_ = (NI)0;
				T156_ = len__ast_3990(T155_);
				if (!(T156_ <= ((NI) 4))) goto LA157_;
				genOptAsgnTuple__cgen_18043(p, dest, src, flags);
			}
			goto LA153_;
			LA157_: ;
			{
				genGenericAsgn__cgen_18127(p, dest, src, flags);
			}
			LA153_: ;
		}
		goto LA147_;
		LA151_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T161_;
			NimStringDesc* res_9;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T162_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T163_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T168_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T169_;
			T161_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T161_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_9 = rawNewString(((NI) 80));
			T162_ = NIM_NIL;
			T162_ = rdLoc__cgen_435(dest);
			cgFormatValue__cgen_147((&res_9), T162_);
			res_9 = resizeString(res_9, 3);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
			T163_ = NIM_NIL;
			T163_ = rdLoc__cgen_435(src);
			cgFormatValue__cgen_147((&res_9), T163_);
			res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA166_;
				res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA166_: ;
			T168_ = NIM_NIL;
			T168_ = rope__ropes_109(res_9);
			T169_ = NIM_NIL;
			T169_ = indentLine__cgen_286(p, T168_);
			add__ropes_159(T161_, T169_);
		}
		LA147_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17):
	{
		{
			NIM_BOOL T173_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T176_;
			NimStringDesc* res_10;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T177_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T178_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T183_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T184_;
			T173_ = (NIM_BOOL)0;
			T173_ = isImportedCppType__cgen_1312(ty);
			if (!T173_) goto LA174_;
			T176_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T176_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_10 = rawNewString(((NI) 80));
			T177_ = NIM_NIL;
			T177_ = rdLoc__cgen_435(dest);
			cgFormatValue__cgen_147((&res_10), T177_);
			res_10 = resizeString(res_10, 3);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
			T178_ = NIM_NIL;
			T178_ = rdLoc__cgen_435(src);
			cgFormatValue__cgen_147((&res_10), T178_);
			res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA181_;
				res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA181_: ;
			T183_ = NIM_NIL;
			T183_ = rope__ropes_109(res_10);
			T184_ = NIM_NIL;
			T184_ = indentLine__cgen_286(p, T183_);
			add__ropes_159(T176_, T184_);
		}
		goto LA171_;
		LA174_: ;
		{
			NIM_BOOL T186_;
			T186_ = (NIM_BOOL)0;
			T186_ = isObjLackingTypeField__cgen_1337(ty);
			if (!!(T186_)) goto LA187_;
			genGenericAsgn__cgen_18127(p, dest, src, flags);
		}
		goto LA171_;
		LA187_: ;
		{
			NIM_BOOL T190_;
			T190_ = (NIM_BOOL)0;
			T190_ = containsGarbageCollectedRef__types_612(ty);
			if (!T190_) goto LA191_;
			{
				NIM_BOOL T195_;
				NI T197_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T200_;
				T195_ = (NIM_BOOL)0;
				T195_ = ((*ty).sons->data[((NI) 0)] == 0);
				if (!(T195_)) goto LA196_;
				T197_ = (NI)0;
				T197_ = asgnComplexity__cgen_18019((*ty).n);
				T195_ = (T197_ <= ((NI) 4));
				LA196_: ;
				if (!T195_) goto LA198_;
				T200_ = NIM_NIL;
				T200_ = getTypeDesc__cgen_6662((*p).module, ty, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
				(void)(T200_);
				{
					NimStringDesc* argX60gensym3505_;
					if (!!(!(((*ty).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))))) goto LA203_;
					argX60gensym3505_ = toFileLineCol__msgs_625(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_265);
					internalErrorImpl__msgs_1441((*(*(*p).module).g).config, unknownLineInfo__lineinfos_284, argX60gensym3505_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_265);
				}
				LA203_: ;
				genOptAsgnObject__cgen_18093(p, dest, src, flags, (*ty).n, ty);
			}
			goto LA193_;
			LA198_: ;
			{
				genGenericAsgn__cgen_18127(p, dest, src, flags);
			}
			LA193_: ;
		}
		goto LA171_;
		LA191_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T207_;
			NimStringDesc* res_11;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T208_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T209_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T214_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T215_;
			T207_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T207_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_11 = rawNewString(((NI) 80));
			T208_ = NIM_NIL;
			T208_ = rdLoc__cgen_435(dest);
			cgFormatValue__cgen_147((&res_11), T208_);
			res_11 = resizeString(res_11, 3);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
			T209_ = NIM_NIL;
			T209_ = rdLoc__cgen_435(src);
			cgFormatValue__cgen_147((&res_11), T209_);
			res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA212_;
				res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA212_: ;
			T214_ = NIM_NIL;
			T214_ = rope__ropes_109(res_11);
			T215_ = NIM_NIL;
			T215_ = indentLine__cgen_286(p, T214_);
			add__ropes_159(T207_, T215_);
		}
		LA171_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
	{
		{
			NIM_BOOL T219_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T220_;
			T219_ = (NIM_BOOL)0;
			T220_ = NIM_NIL;
			T220_ = t__cgen_85(dest);
			T219_ = containsGarbageCollectedRef__types_612(T220_);
			if (!(T219_)) goto LA221_;
			T219_ = !(((176 &((NU16)1<<((NU)((*(*(*(*p).module).g).config).selectedGC)&15U)))!=0));
			LA221_: ;
			if (!T219_) goto LA222_;
			genGenericAsgn__cgen_18127(p, dest, src, flags);
		}
		goto LA217_;
		LA222_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T225_;
			NimStringDesc* res_12;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T226_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T227_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T228_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T229_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T230_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T235_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T236_;
			T225_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T225_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_12 = rawNewString(((NI) 80));
			T226_ = NIM_NIL;
			T226_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_250));
			cgFormatValue__cgen_147((&res_12), T226_);
			res_12 = resizeString(res_12, 8);
appendString(res_12, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_126));
			T227_ = NIM_NIL;
			T227_ = rdLoc__cgen_435(dest);
			cgFormatValue__cgen_147((&res_12), T227_);
			res_12 = resizeString(res_12, 19);
appendString(res_12, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_253));
			T228_ = NIM_NIL;
			T228_ = rdLoc__cgen_435(src);
			cgFormatValue__cgen_147((&res_12), T228_);
			res_12 = resizeString(res_12, 9);
appendString(res_12, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_127));
			T229_ = NIM_NIL;
			T229_ = t__cgen_85(dest);
			T230_ = NIM_NIL;
			T230_ = getTypeDesc__cgen_6662((*p).module, T229_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			cgFormatValue__cgen_147((&res_12), T230_);
			res_12 = resizeString(res_12, 3);
appendString(res_12, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_128));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA233_;
				res_12 = resizeString(res_12, 1);
appendString(res_12, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA233_: ;
			T235_ = NIM_NIL;
			T235_ = rope__ropes_109(res_12);
			T236_ = NIM_NIL;
			T236_ = indentLine__cgen_286(p, T235_);
			add__ropes_159(T225_, T236_);
		}
		LA217_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48):
	{
		{
			NIM_BOOL T240_;
			T240_ = (NIM_BOOL)0;
			T240_ = reifiedOpenArray__cgen_11825(dest.lode);
			if (!T240_) goto LA241_;
			genOpenArrayConv__cgen_18205(p, dest, src);
		}
		goto LA238_;
		LA241_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T244_;
			NIM_BOOL T245_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T248_;
			NimStringDesc* res_13;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T249_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T250_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T251_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T252_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T253_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T254_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T259_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T260_;
			T244_ = NIM_NIL;
			T244_ = t__cgen_85(dest);
			T245_ = (NIM_BOOL)0;
			T245_ = containsGarbageCollectedRef__types_612(T244_);
			if (!T245_) goto LA246_;
			T248_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T248_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_13 = rawNewString(((NI) 80));
			T249_ = NIM_NIL;
			T249_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_279));
			cgFormatValue__cgen_147((&res_13), T249_);
			res_13 = resizeString(res_13, 8);
appendString(res_13, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_126));
			T250_ = NIM_NIL;
			T250_ = addrLoc__cgen_10337((*(*(*p).module).g).config, dest);
			cgFormatValue__cgen_147((&res_13), T250_);
			res_13 = resizeString(res_13, 9);
appendString(res_13, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_255));
			T251_ = NIM_NIL;
			T251_ = addrLoc__cgen_10337((*(*(*p).module).g).config, src);
			cgFormatValue__cgen_147((&res_13), T251_);
			res_13 = resizeString(res_13, 2);
appendString(res_13, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			T252_ = NIM_NIL;
			T252_ = addrLoc__cgen_10337((*(*(*p).module).g).config, dest);
			cgFormatValue__cgen_147((&res_13), T252_);
			res_13 = resizeString(res_13, 7);
appendString(res_13, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_280));
			T253_ = NIM_NIL;
			T253_ = t__cgen_85(dest);
			T254_ = NIM_NIL;
			T254_ = genTypeInfoV1__cgen_6798((*p).module, T253_, (*dest.lode).info);
			cgFormatValue__cgen_147((&res_13), T254_);
			res_13 = resizeString(res_13, 2);
appendString(res_13, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA257_;
				res_13 = resizeString(res_13, 1);
appendString(res_13, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA257_: ;
			T259_ = NIM_NIL;
			T259_ = rope__ropes_109(res_13);
			T260_ = NIM_NIL;
			T260_ = indentLine__cgen_286(p, T259_);
			add__ropes_159(T248_, T260_);
		}
		goto LA238_;
		LA246_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T262_;
			NimStringDesc* res_14;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T263_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T264_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T269_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T270_;
			T262_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T262_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_14 = rawNewString(((NI) 80));
			T263_ = NIM_NIL;
			T263_ = rdLoc__cgen_435(dest);
			cgFormatValue__cgen_147((&res_14), T263_);
			res_14 = resizeString(res_14, 3);
appendString(res_14, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
			T264_ = NIM_NIL;
			T264_ = rdLoc__cgen_435(src);
			cgFormatValue__cgen_147((&res_14), T264_);
			res_14 = resizeString(res_14, 1);
appendString(res_14, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA267_;
				res_14 = resizeString(res_14, 1);
appendString(res_14, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA267_: ;
			T269_ = NIM_NIL;
			T269_ = rope__ropes_109(res_14);
			T270_ = NIM_NIL;
			T270_ = indentLine__cgen_286(p, T269_);
			add__ropes_159(T262_, T270_);
		}
		LA238_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 19):
	{
		{
			tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ T274_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T277_;
			NimStringDesc* res_15;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T278_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T279_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T280_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T281_;
			NI64 T282_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T287_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T288_;
			T274_ = (tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ)0;
			T274_ = mapSetType__cgen_1223((*(*(*p).module).g).config, ty);
			if (!(T274_ == ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 17))) goto LA275_;
			T277_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T277_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_15 = rawNewString(((NI) 80));
			T278_ = NIM_NIL;
			T278_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_250));
			cgFormatValue__cgen_147((&res_15), T278_);
			res_15 = resizeString(res_15, 8);
appendString(res_15, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_126));
			T279_ = NIM_NIL;
			T279_ = rdLoc__cgen_435(dest);
			cgFormatValue__cgen_147((&res_15), T279_);
			res_15 = resizeString(res_15, 19);
appendString(res_15, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_253));
			T280_ = NIM_NIL;
			T280_ = rdLoc__cgen_435(src);
			cgFormatValue__cgen_147((&res_15), T280_);
			res_15 = resizeString(res_15, 2);
appendString(res_15, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			T281_ = NIM_NIL;
			T281_ = t__cgen_85(dest);
			T282_ = (NI64)0;
			T282_ = getSize__types_3388((*(*(*p).module).g).config, T281_);
			cgFormatValue__cgen_154((&res_15), T282_);
			res_15 = resizeString(res_15, 2);
appendString(res_15, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA285_;
				res_15 = resizeString(res_15, 1);
appendString(res_15, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA285_: ;
			T287_ = NIM_NIL;
			T287_ = rope__ropes_109(res_15);
			T288_ = NIM_NIL;
			T288_ = indentLine__cgen_286(p, T287_);
			add__ropes_159(T277_, T288_);
		}
		goto LA272_;
		LA275_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T290_;
			NimStringDesc* res_16;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T291_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T292_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T297_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T298_;
			T290_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T290_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_16 = rawNewString(((NI) 80));
			T291_ = NIM_NIL;
			T291_ = rdLoc__cgen_435(dest);
			cgFormatValue__cgen_147((&res_16), T291_);
			res_16 = resizeString(res_16, 3);
appendString(res_16, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
			T292_ = NIM_NIL;
			T292_ = rdLoc__cgen_435(src);
			cgFormatValue__cgen_147((&res_16), T292_);
			res_16 = resizeString(res_16, 1);
appendString(res_16, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA295_;
				res_16 = resizeString(res_16, 1);
appendString(res_16, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA295_: ;
			T297_ = NIM_NIL;
			T297_ = rope__ropes_109(res_16);
			T298_ = NIM_NIL;
			T298_ = indentLine__cgen_286(p, T297_);
			add__ropes_159(T290_, T298_);
		}
		LA272_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 26):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 20):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 5):
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T300_;
		NimStringDesc* res_17;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T301_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T302_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T307_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T308_;
		T300_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T300_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_17 = rawNewString(((NI) 80));
		T301_ = NIM_NIL;
		T301_ = rdLoc__cgen_435(dest);
		cgFormatValue__cgen_147((&res_17), T301_);
		res_17 = resizeString(res_17, 3);
appendString(res_17, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
		T302_ = NIM_NIL;
		T302_ = rdLoc__cgen_435(src);
		cgFormatValue__cgen_147((&res_17), T302_);
		res_17 = resizeString(res_17, 1);
appendString(res_17, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA305_;
			res_17 = resizeString(res_17, 1);
appendString(res_17, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA305_: ;
		T307_ = NIM_NIL;
		T307_ = rope__ropes_109(res_17);
		T308_ = NIM_NIL;
		T308_ = indentLine__cgen_286(p, T307_);
		add__ropes_159(T300_, T308_);
	}
	break;
	default:
	{
		NimStringDesc* T310_;
		T310_ = NIM_NIL;
		T310_ = rawNewString((reprEnum((NI)(*ty).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)) ? reprEnum((NI)(*ty).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_))->Sup.len : 0) + 15);
appendString(T310_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_281));
appendString(T310_, reprEnum((NI)(*ty).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)));
		internalErrorImpl__msgs_1441((*(*(*p).module).g).config, unknownLineInfo__lineinfos_284, T310_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_282);
	}
	break;
	}
	{
		NIM_BOOL T313_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T317_;
		NimStringDesc* res_18;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T318_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T319_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T320_;
		NI64 T321_;
		NimStringDesc* T322_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T323_;
		NI T324_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T329_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T330_;
		T313_ = (NIM_BOOL)0;
		T313_ = (((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 24))&31U)))!=0);
		if (!(T313_)) goto LA314_;
		T313_ = ((9 &((NU8)1<<((NU)(dest.storage)&7U)))!=0);
		LA314_: ;
		if (!T313_) goto LA315_;
		T317_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T317_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_18 = rawNewString(((NI) 80));
		T318_ = NIM_NIL;
		T318_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_283));
		cgFormatValue__cgen_147((&res_18), T318_);
		res_18 = resizeString(res_18, 8);
appendString(res_18, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_126));
		T319_ = NIM_NIL;
		T319_ = addrLoc__cgen_10337((*(*(*p).module).g).config, dest);
		cgFormatValue__cgen_147((&res_18), T319_);
		res_18 = resizeString(res_18, 2);
appendString(res_18, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		T320_ = NIM_NIL;
		T320_ = t__cgen_85(dest);
		T321_ = (NI64)0;
		T321_ = getSize__types_3388((*(*(*p).module).g).config, T320_);
		cgFormatValue__cgen_154((&res_18), T321_);
		res_18 = resizeString(res_18, 2);
appendString(res_18, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		T322_ = NIM_NIL;
		T322_ = toFullPath__msgs_548((*(*(*p).module).g).config, (*p).currLineInfo.fileIndex);
		T323_ = NIM_NIL;
		T323_ = makeCString__msgs_50(T322_);
		cgFormatValue__cgen_147((&res_18), T323_);
		res_18 = resizeString(res_18, 2);
appendString(res_18, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		T324_ = (NI)0;
		T324_ = safeLineNm__cgen_337((*p).currLineInfo);
		cgFormatValue__cgen_154((&res_18), ((NI64) (T324_)));
		res_18 = resizeString(res_18, 2);
appendString(res_18, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA327_;
			res_18 = resizeString(res_18, 1);
appendString(res_18, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA327_: ;
		T329_ = NIM_NIL;
		T329_ = rope__ropes_109(res_18);
		T330_ = NIM_NIL;
		T330_ = indentLine__cgen_286(p, T329_);
		add__ropes_159(T317_, T330_);
	}
	LA315_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genObjectInit__cgen_10414)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw section, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* a, tyEnum_ObjConstrMode__fUO6aSwLQdJNwZTWRxqbKg mode) {
	tyEnum_TTypeFieldResult__4qPt3YBfh0N9aL5U7Kssfdg T1_;
	T1_ = (tyEnum_TTypeFieldResult__4qPt3YBfh0N9aL5U7Kssfdg)0;
	T1_ = analyseObjectWithTypeField__types_585(t);
	switch (T1_) {
	case ((tyEnum_TTypeFieldResult__4qPt3YBfh0N9aL5U7Kssfdg) 0):
	{
	}
	break;
	case ((tyEnum_TTypeFieldResult__4qPt3YBfh0N9aL5U7Kssfdg) 1):
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* s;
		r = rdLoc__cgen_435((*a));
		{
			tyArray__ts9cf9blICas1QWmw89bglZ7w T8_;
			if (!(mode == ((tyEnum_ObjConstrMode__fUO6aSwLQdJNwZTWRxqbKg) 1))) goto LA6_;
			nimZeroMem((void*)T8_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T8_[0] = r;
			r = percent___cgen_442(T8_, 1);
		}
		LA6_: ;
		s = skipTypes__ast_3723(t, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
			if (T11_) goto LA12_;
			T11_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
			LA12_: ;
			if (!!(T11_)) goto LA13_;
			{
				while (1) {
					NIM_BOOL T17_;
					T17_ = (NIM_BOOL)0;
					T17_ = ((*s).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17));
					if (!(T17_)) goto LA18_;
					T17_ = !(((*s).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
					LA18_: ;
					if (!T17_) goto LA16;
					add__ropes_162(&r, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_129));
					s = skipTypes__ast_3723((*s).sons->data[((NI) 0)], TM__9bddtAaa9cYLwzzzlT9aJ5CKw_130);
				} LA16: ;
			}
		}
		LA13_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T23_;
			NimStringDesc* res;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T29_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T30_;
			if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 41))&63U)))!=0)) goto LA21_;
			T23_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T23_ = s__cgendata_225(p, section);
			res = rawNewString(((NI) 80));
			cgFormatValue__cgen_147((&res), r);
			res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_131));
			T24_ = NIM_NIL;
			T24_ = genTypeInfoV2__cgen_7958((*p).module, t, (*(*a).lode).info);
			cgFormatValue__cgen_147((&res), T24_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA27_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA27_: ;
			T29_ = NIM_NIL;
			T29_ = rope__ropes_109(res);
			T30_ = NIM_NIL;
			T30_ = indentLine__cgen_286(p, T29_);
			add__ropes_159(T23_, T30_);
		}
		goto LA19_;
		LA21_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T32_;
			NimStringDesc* res_2;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T33_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T39_;
			T32_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T32_ = s__cgendata_225(p, section);
			res_2 = rawNewString(((NI) 80));
			cgFormatValue__cgen_147((&res_2), r);
			res_2 = resizeString(res_2, 10);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_131));
			T33_ = NIM_NIL;
			T33_ = genTypeInfoV1__cgen_6798((*p).module, t, (*(*a).lode).info);
			cgFormatValue__cgen_147((&res_2), T33_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA36_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA36_: ;
			T38_ = NIM_NIL;
			T38_ = rope__ropes_109(res_2);
			T39_ = NIM_NIL;
			T39_ = indentLine__cgen_286(p, T38_);
			add__ropes_159(T32_, T39_);
		}
		LA19_: ;
	}
	break;
	case ((tyEnum_TTypeFieldResult__4qPt3YBfh0N9aL5U7Kssfdg) 2):
	{
		{
			NIM_BOOL T43_;
			NIM_BOOL T44_;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tmp;
			T43_ = (NIM_BOOL)0;
			T44_ = (NIM_BOOL)0;
			T44_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
			if (T44_) goto LA45_;
			T44_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
			LA45_: ;
			T43_ = !(T44_);
			if (!(T43_)) goto LA46_;
			T43_ = (((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 41))&63U)))!=0);
			LA46_: ;
			if (!T43_) goto LA47_;
			nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* objType;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T53_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T54_;
				NimStringDesc* res_3;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T55_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T56_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T57_;
				tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw T58_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T64_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T69_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T70_;
				if (!(mode == ((tyEnum_ObjConstrMode__fUO6aSwLQdJNwZTWRxqbKg) 1))) goto LA51_;
				objType = skipTypes__ast_3723(t, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_213);
				T53_ = NIM_NIL;
				T53_ = newNodeIT__ast_3342(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 4), (*(*a).lode).info, objType);
				rawConstExpr__cgen_10399(p, T53_, (&tmp));
				T54_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T54_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_3 = rawNewString(((NI) 80));
				T55_ = NIM_NIL;
				T55_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_250));
				cgFormatValue__cgen_147((&res_3), T55_);
				res_3 = resizeString(res_3, 8);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_126));
				T56_ = NIM_NIL;
				T56_ = rdLoc__cgen_435((*a));
				cgFormatValue__cgen_147((&res_3), T56_);
				res_3 = resizeString(res_3, 20);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_251));
				T57_ = NIM_NIL;
				T57_ = rdLoc__cgen_435(tmp);
				cgFormatValue__cgen_147((&res_3), T57_);
				res_3 = resizeString(res_3, 9);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_127));
				T58_ = (tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw)0;
				{
					if (!((*(*a).lode).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA61_;
					T58_ = (*(*(*a).lode)._kind_4.sym).kind;
				}
				goto LA59_;
				LA61_: ;
				{
					T58_ = ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8);
				}
				LA59_: ;
				T64_ = NIM_NIL;
				T64_ = getTypeDesc__cgen_6662((*p).module, objType, T58_);
				cgFormatValue__cgen_147((&res_3), T64_);
				res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_128));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA67_;
					res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA67_: ;
				T69_ = NIM_NIL;
				T69_ = rope__ropes_109(res_3);
				T70_ = NIM_NIL;
				T70_ = indentLine__cgen_286(p, T69_);
				add__ropes_159(T54_, T70_);
			}
			goto LA49_;
			LA51_: ;
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T72_;
				T72_ = NIM_NIL;
				T72_ = newNodeIT__ast_3342(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 4), (*(*a).lode).info, t);
				rawConstExpr__cgen_10399(p, T72_, (&tmp));
				genAssignment__cgen_10403(p, (*a), tmp, 0);
			}
			LA49_: ;
		}
		goto LA41_;
		LA47_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r_2;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T79_;
			NimStringDesc* res_4;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T80_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T81_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T86_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T87_;
			{
				if (!(mode == ((tyEnum_ObjConstrMode__fUO6aSwLQdJNwZTWRxqbKg) 0))) goto LA76_;
				r_2 = addrLoc__cgen_10337((*(*(*p).module).g).config, (*a));
			}
			goto LA74_;
			LA76_: ;
			{
				r_2 = rdLoc__cgen_435((*a));
			}
			LA74_: ;
			T79_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T79_ = s__cgendata_225(p, section);
			res_4 = rawNewString(((NI) 80));
			T80_ = NIM_NIL;
			T80_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_284));
			cgFormatValue__cgen_147((&res_4), T80_);
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			cgFormatValue__cgen_147((&res_4), r_2);
			res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			T81_ = NIM_NIL;
			T81_ = genTypeInfoV1__cgen_6798((*p).module, t, (*(*a).lode).info);
			cgFormatValue__cgen_147((&res_4), T81_);
			res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA84_;
				res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA84_: ;
			T86_ = NIM_NIL;
			T86_ = rope__ropes_109(res_4);
			T87_ = NIM_NIL;
			T87_ = indentLine__cgen_286(p, T86_);
			add__ropes_159(T79_, T87_);
		}
		LA41_: ;
	}
	break;
	}
	{
		NIM_BOOL T90_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r_3;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* s_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T110_;
		NimStringDesc* res_5;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T111_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T112_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T117_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T118_;
		T90_ = (NIM_BOOL)0;
		T90_ = isException__types_4064(t);
		if (!T90_) goto LA91_;
		r_3 = rdLoc__cgen_435((*a));
		{
			tyArray__ts9cf9blICas1QWmw89bglZ7w T97_;
			if (!(mode == ((tyEnum_ObjConstrMode__fUO6aSwLQdJNwZTWRxqbKg) 1))) goto LA95_;
			nimZeroMem((void*)T97_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T97_[0] = r_3;
			r_3 = percent___cgen_442(T97_, 1);
		}
		LA95_: ;
		s_2 = skipTypes__ast_3723(t, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
		{
			NIM_BOOL T100_;
			T100_ = (NIM_BOOL)0;
			T100_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
			if (T100_) goto LA101_;
			T100_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
			LA101_: ;
			if (!!(T100_)) goto LA102_;
			{
				while (1) {
					NIM_BOOL T106_;
					NIM_BOOL T107_;
					T106_ = (NIM_BOOL)0;
					T107_ = (NIM_BOOL)0;
					T107_ = ((*s_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17));
					if (!(T107_)) goto LA108_;
					T107_ = !(((*s_2).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
					LA108_: ;
					T106_ = T107_;
					if (!(T106_)) goto LA109_;
					T106_ = !(((*(*s_2).sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 269)));
					LA109_: ;
					if (!T106_) goto LA105;
					add__ropes_162(&r_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_129));
					s_2 = skipTypes__ast_3723((*s_2).sons->data[((NI) 0)], TM__9bddtAaa9cYLwzzzlT9aJ5CKw_130);
				} LA105: ;
			}
		}
		LA102_: ;
		T110_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T110_ = s__cgendata_225(p, section);
		res_5 = rawNewString(((NI) 80));
		cgFormatValue__cgen_147((&res_5), r_3);
		res_5 = resizeString(res_5, 8);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_285));
		T111_ = NIM_NIL;
		T111_ = skipTypes__ast_3723(t, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
		T112_ = NIM_NIL;
		T112_ = makeCString__msgs_50((*(*(*T111_).sym).name).s);
		cgFormatValue__cgen_147((&res_5), T112_);
		res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA115_;
			res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA115_: ;
		T117_ = NIM_NIL;
		T117_ = rope__ropes_109(res_5);
		T118_ = NIM_NIL;
		T118_ = indentLine__cgen_286(p, T117_);
		add__ropes_159(T110_, T118_);
	}
	LA91_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, constructLoc__cgen_10987)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* loc, NIM_BOOL isTemp) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
	typ = t__cgen_85((*loc));
	{
		NIM_BOOL T3_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T5_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T8_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0);
		if (!(T3_)) goto LA4_;
		T5_ = NIM_NIL;
		T5_ = skipTypes__ast_3723(typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_115);
		T3_ = ((*T5_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28) || (*T5_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24));
		LA4_: ;
		if (!T3_) goto LA6_;
		T8_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T8_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res = rawNewString(((NI) 80));
		T9_ = NIM_NIL;
		T9_ = rdLoc__cgen_435((*loc));
		cgFormatValue__cgen_147((&res), T9_);
		res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_116));
		T10_ = NIM_NIL;
		T10_ = rdLoc__cgen_435((*loc));
		cgFormatValue__cgen_147((&res), T10_);
		res = resizeString(res, 13);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_117));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA13_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA13_: ;
		T15_ = NIM_NIL;
		T15_ = rope__ropes_109(res);
		T16_ = NIM_NIL;
		T16_ = indentLine__cgen_286(p, T15_);
		add__ropes_159(T8_, T16_);
	}
	goto LA1_;
	LA6_: ;
	{
		NIM_BOOL T18_;
		T18_ = (NIM_BOOL)0;
		T18_ = isComplexValueType__cgen_10585(typ);
		if (!!(T18_)) goto LA19_;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T23_;
			NIM_BOOL T24_;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw nilLoc;
			T23_ = NIM_NIL;
			T23_ = t__cgen_85((*loc));
			T24_ = (NIM_BOOL)0;
			T24_ = containsGarbageCollectedRef__types_612(T23_);
			if (!T24_) goto LA25_;
			nimZeroMem((void*)(&nilLoc), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLoc__cgen_66((&nilLoc), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 1), (*loc).lode, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 2));
			nilLoc.r = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_119));
			genRefAssign__cgen_10581(p, (*loc), nilLoc);
		}
		goto LA21_;
		LA25_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T28_;
			NimStringDesc* res_2;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T29_;
			tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw T30_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T36_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T41_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T42_;
			T28_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T28_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_2 = rawNewString(((NI) 80));
			T29_ = NIM_NIL;
			T29_ = rdLoc__cgen_435((*loc));
			cgFormatValue__cgen_147((&res_2), T29_);
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_55));
			T30_ = (tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw)0;
			{
				if (!((*(*loc).lode).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA33_;
				T30_ = (*(*(*loc).lode)._kind_4.sym).kind;
			}
			goto LA31_;
			LA33_: ;
			{
				T30_ = ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8);
			}
			LA31_: ;
			T36_ = NIM_NIL;
			T36_ = getTypeDesc__cgen_6662((*p).module, typ, T30_);
			cgFormatValue__cgen_147((&res_2), T36_);
			res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_124));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA39_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA39_: ;
			T41_ = NIM_NIL;
			T41_ = rope__ropes_109(res_2);
			T42_ = NIM_NIL;
			T42_ = indentLine__cgen_286(p, T41_);
			add__ropes_159(T28_, T42_);
		}
		LA21_: ;
	}
	goto LA1_;
	LA19_: ;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T72_;
		{
			NIM_BOOL T46_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T48_;
			T46_ = (NIM_BOOL)0;
			T46_ = !(isTemp);
			if (T46_) goto LA47_;
			T48_ = NIM_NIL;
			T48_ = t__cgen_85((*loc));
			T46_ = containsGarbageCollectedRef__types_612(T48_);
			LA47_: ;
			if (!T46_) goto LA49_;
			{
				NIM_BOOL T53_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T56_;
				NimStringDesc* res_3;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T57_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T58_;
				tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw T59_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T65_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T70_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T71_;
				T53_ = (NIM_BOOL)0;
				T53_ = isImportedCppType__cgen_1312(typ);
				if (!!(T53_)) goto LA54_;
				T56_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T56_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_3 = rawNewString(((NI) 80));
				T57_ = NIM_NIL;
				T57_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_125));
				cgFormatValue__cgen_147((&res_3), T57_);
				res_3 = resizeString(res_3, 8);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_126));
				T58_ = NIM_NIL;
				T58_ = addrLoc__cgen_10337((*(*(*p).module).g).config, (*loc));
				cgFormatValue__cgen_147((&res_3), T58_);
				res_3 = resizeString(res_3, 9);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_127));
				T59_ = (tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw)0;
				{
					if (!((*(*loc).lode).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA62_;
					T59_ = (*(*(*loc).lode)._kind_4.sym).kind;
				}
				goto LA60_;
				LA62_: ;
				{
					T59_ = ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8);
				}
				LA60_: ;
				T65_ = NIM_NIL;
				T65_ = getTypeDesc__cgen_6662((*p).module, typ, T59_);
				cgFormatValue__cgen_147((&res_3), T65_);
				res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_128));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA68_;
					res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA68_: ;
				T70_ = NIM_NIL;
				T70_ = rope__ropes_109(res_3);
				T71_ = NIM_NIL;
				T71_ = indentLine__cgen_286(p, T70_);
				add__ropes_159(T56_, T71_);
			}
			LA54_: ;
		}
		LA49_: ;
		T72_ = NIM_NIL;
		T72_ = t__cgen_85((*loc));
		genObjectInit__cgen_10414(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2), T72_, loc, ((tyEnum_ObjConstrMode__fUO6aSwLQdJNwZTWRxqbKg) 0));
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, initLocalVar__cgen_11052)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* v, NIM_BOOL immediateAsgn) {
	{
		if (!!((((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 14))&63U)))!=0))) goto LA3_;
		{
			if (!!(immediateAsgn)) goto LA7_;
			constructLoc__cgen_10987(p, (&(*v).loc), NIM_FALSE);
		}
		LA7_: ;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, fillResult__cgen_1795)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* param, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* proctype) {
	tyArray__dAmhZbEWrTM5xES2bTVweg T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T2_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	nimZeroMem((void*)T1_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
	T2_ = NIM_NIL;
	T2_ = percent___cgen_1799(T1_, 0);
	fillLoc__cgen_71((&(*(*param)._kind_4.sym).loc), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 4), param, T2_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 2));
	t = (*(*param)._kind_4.sym).typ;
	{
		NIM_BOOL T5_;
		tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ T6_;
		T5_ = (NIM_BOOL)0;
		T6_ = (tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ)0;
		T6_ = mapReturnType__cgen_1297(conf, t);
		T5_ = !((T6_ == ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 17)));
		if (!(T5_)) goto LA7_;
		T5_ = isInvalidReturnType__cgen_1353(conf, proctype, NIM_TRUE);
		LA7_: ;
		if (!T5_) goto LA8_;
		(*(*param)._kind_4.sym).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 0)) & 15);
		(*(*param)._kind_4.sym).loc.storage = ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0);
	}
	LA8_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, scopeMangledParam__cgen_1137)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* param) {
	NimStringDesc* key;
	key = mangle__ccgutils_112((*(*param).name).s);
	shallow__system_7445((&key));
	inc__cgen_953((&(*p).sigConflicts), key, ((NI) 1));
}
N_LIB_PRIVATE N_NIMCALL(void, assignParam__cgen_11482)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* retType) {
	scopeMangledParam__cgen_1137(p, s);
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA, allPathsAsgnResult__cgen_26066)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA result;
{	result = (tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA)0;
	result = ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 0);
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
			it = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA5;
						i = i_2;
						it = (*n)._kind_6.sons->data[i];
						result = allPathsAsgnResult__cgen_26066(it);
						{
							if (!!((result == ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 0)))) goto LA8_;
							goto BeforeRet_;
						}
						LA8_: ;
						i_2 += ((NI) 1);
					} LA5: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 73):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 74):
	{
		{
			NIM_BOOL T13_;
			T13_ = (NIM_BOOL)0;
			T13_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
			if (!(T13_)) goto LA14_;
			T13_ = ((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 11));
			LA14_: ;
			if (!T13_) goto LA15_;
			{
				NIM_BOOL T19_;
				T19_ = (NIM_BOOL)0;
				T19_ = containsResult__cgen_25982((*n)._kind_6.sons->data[((NI) 1)]);
				if (!!(T19_)) goto LA20_;
				result = ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 1);
			}
			goto LA17_;
			LA20_: ;
			{
				result = ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 2);
			}
			LA17_: ;
		}
		goto LA11_;
		LA15_: ;
		{
			NIM_BOOL T24_;
			T24_ = (NIM_BOOL)0;
			T24_ = containsResult__cgen_25982(n);
			if (!T24_) goto LA25_;
			result = ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 2);
		}
		goto LA11_;
		LA25_: ;
		LA11_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 109):
	{
		{
			NI T30_;
			T30_ = (NI)0;
			T30_ = len__ast_3155(n);
			if (!(((NI) 0) < T30_)) goto LA31_;
			{
				NIM_BOOL T35_;
				T35_ = (NIM_BOOL)0;
				T35_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1));
				if (!(T35_)) goto LA36_;
				T35_ = !((result == ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 1)));
				LA36_: ;
				if (!T35_) goto LA37_;
				result = ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 2);
			}
			goto LA33_;
			LA37_: ;
			{
				result = allPathsAsgnResult__cgen_26066((*n)._kind_6.sons->data[((NI) 0)]);
			}
			LA33_: ;
		}
		LA31_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 92):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 48):
	{
		NIM_BOOL exhaustive;
		exhaustive = NIM_FALSE;
		result = ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 1);
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it_2;
			it_2 = NIM_NIL;
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = safeLen__ast_3148(n);
				i_4 = ((NI) 0);
				{
					while (1) {
						tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA aX60gensym6067_;
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T57_;
						if (!(i_4 < colontmp__2)) goto LA44;
						i_3 = i_4;
						it_2 = (*n)._kind_6.sons->data[i_3];
						{
							NIM_BOOL T47_;
							NI T48_;
							T47_ = (NIM_BOOL)0;
							T48_ = (NI)0;
							T48_ = len__ast_3155(it_2);
							T47_ = (T48_ == ((NI) 2));
							if (!(T47_)) goto LA49_;
							T47_ = containsResult__cgen_25982((*it_2)._kind_6.sons->data[((NI) 0)]);
							LA49_: ;
							if (!T47_) goto LA50_;
							result = ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 2);
							goto BeforeRet_;
						}
						LA50_: ;
						{
							NI T54_;
							T54_ = (NI)0;
							T54_ = len__ast_3155(it_2);
							if (!(T54_ == ((NI) 1))) goto LA55_;
							exhaustive = NIM_TRUE;
						}
						LA55_: ;
						T57_ = NIM_NIL;
						T57_ = lastSon__ast_4833(it_2);
						aX60gensym6067_ = allPathsAsgnResult__cgen_26066(T57_);
						switch (aX60gensym6067_) {
						case ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 2):
						{
							result = ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 2);
							goto BeforeRet_;
						}
						break;
						case ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 1):
						{
						}
						break;
						case ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 0):
						{
							result = ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 0);
						}
						break;
						}
						i_4 += ((NI) 1);
					} LA44: ;
				}
			}
		}
		{
			if (!!(exhaustive)) goto LA63_;
			result = ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 0);
		}
		LA63_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 97):
	{
		NIM_BOOL exhaustive_2;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T71_;
		{
			NIM_BOOL T68_;
			T68_ = (NIM_BOOL)0;
			T68_ = containsResult__cgen_25982((*n)._kind_6.sons->data[((NI) 0)]);
			if (!T68_) goto LA69_;
			result = ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 2);
			goto BeforeRet_;
		}
		LA69_: ;
		result = ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 1);
		T71_ = NIM_NIL;
		T71_ = skipTypes__ast_3723((*(*n)._kind_6.sons->data[((NI) 0)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_287);
		exhaustive_2 = !(((*T71_).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36) && (*T71_).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 39) || (*T71_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28)));
		{
			NI i_5;
			NI colontmp__3;
			NI i_6;
			i_5 = (NI)0;
			colontmp__3 = (NI)0;
			colontmp__3 = len__ast_3155(n);
			i_6 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it_3;
					tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA aX60gensym6072_;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T75_;
					if (!(i_6 < colontmp__3)) goto LA74;
					i_5 = i_6;
					it_3 = (*n)._kind_6.sons->data[i_5];
					T75_ = NIM_NIL;
					T75_ = lastSon__ast_4833(it_3);
					aX60gensym6072_ = allPathsAsgnResult__cgen_26066(T75_);
					switch (aX60gensym6072_) {
					case ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 2):
					{
						result = ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 2);
						goto BeforeRet_;
					}
					break;
					case ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 1):
					{
					}
					break;
					case ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 0):
					{
						result = ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 0);
					}
					break;
					}
					{
						if (!((*it_3).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 88))) goto LA81_;
						exhaustive_2 = NIM_TRUE;
					}
					LA81_: ;
					i_6 += ((NI) 1);
				} LA74: ;
			}
		}
		{
			if (!!(exhaustive_2)) goto LA85_;
			result = ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 0);
		}
		LA85_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 96):
	{
		result = allPathsAsgnResult__cgen_26066((*n)._kind_6.sons->data[((NI) 0)]);
		{
			if (!(result == ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 0))) goto LA90_;
			result = allPathsAsgnResult__cgen_26066((*n)._kind_6.sons->data[((NI) 1)]);
			{
				if (!(result == ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 1))) goto LA94_;
				result = ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 0);
			}
			LA94_: ;
		}
		LA90_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 76):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 98):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 101):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 122) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 123):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 125):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159):
	{
		result = ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 0);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 156):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 158):
	{
		result = ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 2);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		{
			if (!((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 11))) goto LA101_;
			result = ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 2);
		}
		LA101_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 106):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 154):
	{
		tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA aX60gensym6075_;
		result = ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 1);
		aX60gensym6075_ = allPathsAsgnResult__cgen_26066((*n)._kind_6.sons->data[((NI) 0)]);
		switch (aX60gensym6075_) {
		case ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 2):
		{
			result = ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 2);
			goto BeforeRet_;
		}
		break;
		case ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 1):
		{
		}
		break;
		case ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 0):
		{
			result = ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 0);
		}
		break;
		}
		{
			NI i_7;
			NI colontmp__4;
			NI i_8;
			i_7 = (NI)0;
			colontmp__4 = (NI)0;
			colontmp__4 = len__ast_3155(n);
			i_8 = ((NI) 1);
			{
				while (1) {
					if (!(i_8 < colontmp__4)) goto LA109;
					i_7 = i_8;
					{
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T114_;
						if (!((*(*n)._kind_6.sons->data[i_7]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 107))) goto LA112_;
						T114_ = NIM_NIL;
						T114_ = lastSon__ast_4833((*n)._kind_6.sons->data[i_7]);
						result = allPathsAsgnResult__cgen_26066(T114_);
					}
					goto LA110_;
					LA112_: ;
					{
						tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA aX60gensym6079_;
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T116_;
						T116_ = NIM_NIL;
						T116_ = lastSon__ast_4833((*n)._kind_6.sons->data[i_7]);
						aX60gensym6079_ = allPathsAsgnResult__cgen_26066(T116_);
						switch (aX60gensym6079_) {
						case ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 2):
						{
							result = ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 2);
							goto BeforeRet_;
						}
						break;
						case ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 1):
						{
						}
						break;
						case ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 0):
						{
							result = ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 0);
						}
						break;
						}
					}
					LA110_: ;
					i_8 += ((NI) 1);
				} LA109: ;
			}
		}
	}
	break;
	default:
	{
		{
			NI i_9;
			NI colontmp__5;
			NI i_10;
			i_9 = (NI)0;
			colontmp__5 = (NI)0;
			colontmp__5 = safeLen__ast_3148(n);
			i_10 = ((NI) 0);
			{
				while (1) {
					tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA aX60gensym6081_;
					if (!(i_10 < colontmp__5)) goto LA123;
					i_9 = i_10;
					aX60gensym6081_ = allPathsAsgnResult__cgen_26066((*n)._kind_6.sons->data[i_9]);
					switch (aX60gensym6081_) {
					case ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 2):
					{
						result = ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 2);
						goto BeforeRet_;
					}
					break;
					case ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 1):
					{
					}
					break;
					case ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 0):
					{
						result = ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 0);
					}
					break;
					}
					i_10 += ((NI) 1);
				} LA123: ;
			}
		}
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, specializeResetN__cgen_10609)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* accessor, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ) {
{	{
		if (!(n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 138):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA8;
					i = i_2;
					specializeResetN__cgen_10609(p, accessor, (*n)._kind_6.sons->data[i], typ);
					i_2 += ((NI) 1);
				} LA8: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 139):
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* disc;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T23_;
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T24_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T44_;
		tyArray__dAmhZbEWrTM5xES2bTVweg T45_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T46_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T47_;
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T48_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T49_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T50_;
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)))) goto LA12_;
			internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_291), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_292);
		}
		LA12_: ;
		disc = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		{
			if (!((*disc).loc.r == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA16_;
			fillObjectFields__cgen_3808((*p).module, typ);
		}
		LA16_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T20_;
			T20_ = NIM_NIL;
			T20_ = t__cgen_85((*disc).loc);
			if (!(T20_ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA21_;
			internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_294), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_295);
		}
		LA21_: ;
		T23_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T23_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		nimZeroMem((void*)T24_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T24_[0] = accessor;
		T24_[1] = (*disc).loc.r;
		T25_ = NIM_NIL;
		T25_ = percent___cgen_7412(T24_, 2);
		T26_ = NIM_NIL;
		T26_ = indentLine__cgen_286(p, T25_);
		add__ropes_159(T23_, T26_);
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3155(n);
			i_4 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* branch;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T39_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T40_;
					tyArray__dAmhZbEWrTM5xES2bTVweg T41_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T42_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T43_;
					if (!(i_4 < colontmp__2)) goto LA29;
					i_3 = i_4;
					branch = (*n)._kind_6.sons->data[i_3];
					{
						if (!((*branch).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 85))) goto LA32_;
						genCaseRange__cgen_7370(p, branch);
					}
					goto LA30_;
					LA32_: ;
					{
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T35_;
						tyArray__dAmhZbEWrTM5xES2bTVweg T36_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T37_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
						T35_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
						T35_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
						nimZeroMem((void*)T36_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
						T37_ = NIM_NIL;
						T37_ = percent___cgen_7438(T36_, 0);
						T38_ = NIM_NIL;
						T38_ = indentLine__cgen_286(p, T37_);
						add__ropes_159(T35_, T38_);
					}
					LA30_: ;
					T39_ = NIM_NIL;
					T39_ = lastSon__ast_4833(branch);
					specializeResetN__cgen_10609(p, accessor, T39_, typ);
					T40_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T40_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					nimZeroMem((void*)T41_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
					T42_ = NIM_NIL;
					T42_ = percent___cgen_7446(T41_, 0);
					T43_ = NIM_NIL;
					T43_ = indentLine__cgen_286(p, T42_);
					add__ropes_159(T40_, T43_);
					i_4 += ((NI) 1);
				} LA29: ;
			}
		}
		T44_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T44_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		nimZeroMem((void*)T45_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		T46_ = NIM_NIL;
		T46_ = percent___cgen_7451(T45_, 0);
		T47_ = NIM_NIL;
		T47_ = indentLine__cgen_286(p, T46_);
		add__ropes_159(T44_, T47_);
		nimZeroMem((void*)T48_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T48_[0] = accessor;
		T48_[1] = (*disc).loc.r;
		T49_ = NIM_NIL;
		T49_ = percent___cgen_7469(T48_, 2);
		T50_ = NIM_NIL;
		T50_ = t__cgen_85((*disc).loc);
		specializeResetT__cgen_10605(p, T49_, T50_);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field;
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T65_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T66_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T67_;
		field = (*n)._kind_4.sym;
		{
			if (!((*(*field).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 63))) goto LA54_;
			goto BeforeRet_;
		}
		LA54_: ;
		{
			if (!((*field).loc.r == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA58_;
			fillObjectFields__cgen_3808((*p).module, typ);
		}
		LA58_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T62_;
			T62_ = NIM_NIL;
			T62_ = t__cgen_85((*field).loc);
			if (!(T62_ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA63_;
			internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_294), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_296);
		}
		LA63_: ;
		nimZeroMem((void*)T65_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T65_[0] = accessor;
		T65_[1] = (*field).loc.r;
		T66_ = NIM_NIL;
		T66_ = percent___cgen_7469(T65_, 2);
		T67_ = NIM_NIL;
		T67_ = t__cgen_85((*field).loc);
		specializeResetT__cgen_10605(p, T66_, T67_);
	}
	break;
	default:
	{
		internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_294), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_297);
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, specializeResetT__cgen_10605)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* accessor, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ) {
{	{
		if (!(typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	switch ((*typ).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 10):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 4):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 13):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 55):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T6_;
		T6_ = NIM_NIL;
		T6_ = lastSon__ast_3731(typ);
		specializeResetT__cgen_10605(p, accessor, T6_);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ arraySize;
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw i;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T8_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T9_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
		NimStringDesc* res_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T17_;
		tyArray__dAmhZbEWrTM5xES2bTVweg T18_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
		arraySize = lengthOrd__types_1723((*(*(*p).module).g).config, (*typ).sons->data[((NI) 0)]);
		nimZeroMem((void*)(&i), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		T8_ = NIM_NIL;
		T8_ = getSysType__magicsys_60((*(*(*p).module).g).graph, unknownLineInfo__lineinfos_284, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31));
		getTemp__cgen_7373(p, T8_, (&i), NIM_FALSE);
		T9_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T9_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 5);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_161));
		cgFormatValue__cgen_147((&res), i.r);
		res = resizeString(res, 6);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_162));
		cgFormatValue__cgen_147((&res), i.r);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_163));
		cgFormatValue__cgen_157((&res), arraySize);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_164));
		cgFormatValue__cgen_147((&res), i.r);
		res = resizeString(res, 5);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_165));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA12_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA12_: ;
		T14_ = NIM_NIL;
		T14_ = rope__ropes_109(res);
		T15_ = NIM_NIL;
		T15_ = indentLine__cgen_286(p, T14_);
		add__ropes_159(T9_, T15_);
		res_2 = rawNewString(((NI) 80));
		cgFormatValue__cgen_147((&res_2), accessor);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_166));
		cgFormatValue__cgen_147((&res_2), i.r);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_167));
		T16_ = NIM_NIL;
		T16_ = rope__ropes_109(res_2);
		specializeResetT__cgen_10605(p, T16_, (*typ).sons->data[((NI) 1)]);
		T17_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T17_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		nimZeroMem((void*)T18_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		T19_ = NIM_NIL;
		T19_ = percent___cgen_7535(T18_, 0);
		T20_ = NIM_NIL;
		T20_ = indentLine__cgen_286(p, T19_);
		add__ropes_159(T17_, T20_);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17):
	{
		{
			NI i_2;
			NI colontmp_;
			NI i_3;
			i_2 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3990(typ);
			i_3 = ((NI) 0);
			{
				while (1) {
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* x;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T29_;
					if (!(i_3 < colontmp_)) goto LA24;
					i_2 = i_3;
					x = (*typ).sons->data[i_2];
					{
						if (!!((x == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA27_;
						x = skipTypes__ast_3723(x, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_130);
					}
					LA27_: ;
					T29_ = NIM_NIL;
					T29_ = parentObj__cgen_7474(accessor, (*p).module);
					specializeResetT__cgen_10605(p, T29_, x);
					i_3 += ((NI) 1);
				} LA24: ;
			}
		}
		{
			if (!!(((*typ).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA32_;
			specializeResetN__cgen_10609(p, accessor, (*typ).n, typ);
		}
		LA32_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ_2;
		typ_2 = typ;
		{
			NI i_4;
			NI colontmp__2;
			NI i_5;
			i_4 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3990(typ_2);
			i_5 = ((NI) 0);
			{
				while (1) {
					NimStringDesc* res_3;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
					if (!(i_5 < colontmp__2)) goto LA37;
					i_4 = i_5;
					res_3 = rawNewString(((NI) 80));
					cgFormatValue__cgen_147((&res_3), accessor);
					res_3 = resizeString(res_3, 6);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_191));
					cgFormatValue__cgen_154((&res_3), ((NI64) (i_4)));
					T38_ = NIM_NIL;
					T38_ = rope__ropes_109(res_3);
					specializeResetT__cgen_10605(p, T38_, (*typ_2).sons->data[i_4]);
					i_5 += ((NI) 1);
				} LA37: ;
			}
		}
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T40_;
		NimStringDesc* res_4;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T41_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T46_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T47_;
		T40_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T40_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_4 = rawNewString(((NI) 80));
		T41_ = NIM_NIL;
		T41_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_123));
		cgFormatValue__cgen_147((&res_4), T41_);
		res_4 = resizeString(res_4, 10);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_298));
		cgFormatValue__cgen_147((&res_4), accessor);
		res_4 = resizeString(res_4, 11);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_299));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA44_;
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA44_: ;
		T46_ = NIM_NIL;
		T46_ = rope__ropes_109(res_4);
		T47_ = NIM_NIL;
		T47_ = indentLine__cgen_286(p, T46_);
		add__ropes_159(T40_, T47_);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25):
	{
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T53_;
			NimStringDesc* res_5;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T54_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T59_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T60_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T61_;
			NimStringDesc* res_6;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T66_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T67_;
			if (!((*typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9))) goto LA51_;
			T53_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T53_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_5 = rawNewString(((NI) 80));
			T54_ = NIM_NIL;
			T54_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_123));
			cgFormatValue__cgen_147((&res_5), T54_);
			res_5 = resizeString(res_5, 10);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_298));
			cgFormatValue__cgen_147((&res_5), accessor);
			res_5 = resizeString(res_5, 17);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_300));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA57_;
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA57_: ;
			T59_ = NIM_NIL;
			T59_ = rope__ropes_109(res_5);
			T60_ = NIM_NIL;
			T60_ = indentLine__cgen_286(p, T59_);
			add__ropes_159(T53_, T60_);
			T61_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T61_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_6 = rawNewString(((NI) 80));
			cgFormatValue__cgen_147((&res_6), accessor);
			res_6 = resizeString(res_6, 17);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_301));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA64_;
				res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA64_: ;
			T66_ = NIM_NIL;
			T66_ = rope__ropes_109(res_6);
			T67_ = NIM_NIL;
			T67_ = indentLine__cgen_286(p, T66_);
			add__ropes_159(T61_, T67_);
		}
		goto LA49_;
		LA51_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T69_;
			NimStringDesc* res_7;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T74_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T75_;
			T69_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T69_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_7 = rawNewString(((NI) 80));
			cgFormatValue__cgen_147((&res_7), accessor);
			res_7 = resizeString(res_7, 11);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_302));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA72_;
				res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA72_: ;
			T74_ = NIM_NIL;
			T74_ = rope__ropes_109(res_7);
			T75_ = NIM_NIL;
			T75_ = indentLine__cgen_286(p, T74_);
			add__ropes_159(T69_, T75_);
		}
		LA49_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44):
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T77_;
		NimStringDesc* res_8;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T82_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T83_;
		T77_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T77_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_8 = rawNewString(((NI) 80));
		cgFormatValue__cgen_147((&res_8), accessor);
		res_8 = resizeString(res_8, 5);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_290));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA80_;
			res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA80_: ;
		T82_ = NIM_NIL;
		T82_ = rope__ropes_109(res_8);
		T83_ = NIM_NIL;
		T83_ = indentLine__cgen_286(p, T82_);
		add__ropes_159(T77_, T83_);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 26):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47):
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T85_;
		NimStringDesc* res_9;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T90_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T91_;
		T85_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T85_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_9 = rawNewString(((NI) 80));
		cgFormatValue__cgen_147((&res_9), accessor);
		res_9 = resizeString(res_9, 11);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_302));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA88_;
			res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA88_: ;
		T90_ = NIM_NIL;
		T90_ = rope__ropes_109(res_9);
		T91_ = NIM_NIL;
		T91_ = indentLine__cgen_286(p, T90_);
		add__ropes_159(T85_, T91_);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 19):
	{
		tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ T93_;
		T93_ = (tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ)0;
		T93_ = mapSetType__cgen_1223((*(*(*p).module).g).config, typ);
		switch (T93_) {
		case ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 17):
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T95_;
			NimStringDesc* res_10;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T96_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T97_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T102_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T103_;
			T95_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T95_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_10 = rawNewString(((NI) 80));
			T96_ = NIM_NIL;
			T96_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_125));
			cgFormatValue__cgen_147((&res_10), T96_);
			res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			cgFormatValue__cgen_147((&res_10), accessor);
			res_10 = resizeString(res_10, 9);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_127));
			T97_ = NIM_NIL;
			T97_ = getTypeDesc__cgen_6662((*p).module, typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			cgFormatValue__cgen_147((&res_10), T97_);
			res_10 = resizeString(res_10, 3);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_128));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA100_;
				res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA100_: ;
			T102_ = NIM_NIL;
			T102_ = rope__ropes_109(res_10);
			T103_ = NIM_NIL;
			T103_ = indentLine__cgen_286(p, T102_);
			add__ropes_159(T95_, T103_);
		}
		break;
		case ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 4):
		case ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 5):
		case ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 6):
		case ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 7):
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T105_;
			NimStringDesc* res_11;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T110_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T111_;
			T105_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T105_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_11 = rawNewString(((NI) 80));
			cgFormatValue__cgen_147((&res_11), accessor);
			res_11 = resizeString(res_11, 5);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_290));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA108_;
				res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA108_: ;
			T110_ = NIM_NIL;
			T110_ = rope__ropes_109(res_11);
			T111_ = NIM_NIL;
			T111_ = indentLine__cgen_286(p, T110_);
			add__ropes_159(T105_, T111_);
		}
		break;
		default:
		{
			{
				if (!NIM_TRUE) goto LA115_;
				failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_303));
			}
			LA115_: ;
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 0):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 3):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 5) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 7):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 9):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 15):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 20):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 30):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 54):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 56) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 64):
	{
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, specializeReset__cgen_10894)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T2_;
	T1_ = NIM_NIL;
	T1_ = rdLoc__cgen_435(a);
	T2_ = NIM_NIL;
	T2_ = t__cgen_85(a);
	specializeResetT__cgen_10605(p, T1_, T2_);
}
N_LIB_PRIVATE N_NIMCALL(void, resetLoc__cgen_10897)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* loc) {
	NIM_BOOL containsGcRef;
	NIM_BOOL T1_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T3_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T4_;
{	T1_ = (NIM_BOOL)0;
	T1_ = !((((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0));
	if (!(T1_)) goto LA2_;
	T3_ = NIM_NIL;
	T3_ = t__cgen_85((*loc));
	T1_ = containsGarbageCollectedRef__types_612(T3_);
	LA2_: ;
	containsGcRef = T1_;
	T4_ = NIM_NIL;
	T4_ = t__cgen_85((*loc));
	typ = skipTypes__ast_3723(T4_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_183);
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = isImportedCppType__cgen_1312(typ);
		if (!T7_) goto LA8_;
		goto BeforeRet_;
	}
	LA8_: ;
	{
		NIM_BOOL T12_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* atyp;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T16_;
		T12_ = (NIM_BOOL)0;
		T12_ = (((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0);
		if (!(T12_)) goto LA13_;
		T12_ = ((*typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28) || (*typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24));
		LA13_: ;
		if (!T12_) goto LA14_;
		T16_ = NIM_NIL;
		T16_ = t__cgen_85((*loc));
		atyp = skipTypes__ast_3723(T16_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T21_;
			NimStringDesc* res;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T28_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T29_;
			if (!((*atyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*atyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47))) goto LA19_;
			T21_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T21_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res = rawNewString(((NI) 80));
			T22_ = NIM_NIL;
			T22_ = rdLoc__cgen_435((*loc));
			cgFormatValue__cgen_147((&res), T22_);
			res = resizeString(res, 11);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_288));
			T23_ = NIM_NIL;
			T23_ = rdLoc__cgen_435((*loc));
			cgFormatValue__cgen_147((&res), T23_);
			res = resizeString(res, 14);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_289));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA26_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA26_: ;
			T28_ = NIM_NIL;
			T28_ = rope__ropes_109(res);
			T29_ = NIM_NIL;
			T29_ = indentLine__cgen_286(p, T28_);
			add__ropes_159(T21_, T29_);
		}
		goto LA17_;
		LA19_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T31_;
			NimStringDesc* res_2;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T32_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T33_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T39_;
			T31_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T31_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_2 = rawNewString(((NI) 80));
			T32_ = NIM_NIL;
			T32_ = rdLoc__cgen_435((*loc));
			cgFormatValue__cgen_147((&res_2), T32_);
			res_2 = resizeString(res_2, 10);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_116));
			T33_ = NIM_NIL;
			T33_ = rdLoc__cgen_435((*loc));
			cgFormatValue__cgen_147((&res_2), T33_);
			res_2 = resizeString(res_2, 13);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_117));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA36_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA36_: ;
			T38_ = NIM_NIL;
			T38_ = rope__ropes_109(res_2);
			T39_ = NIM_NIL;
			T39_ = indentLine__cgen_286(p, T38_);
			add__ropes_159(T31_, T39_);
		}
		LA17_: ;
	}
	goto LA10_;
	LA14_: ;
	{
		NIM_BOOL T41_;
		T41_ = (NIM_BOOL)0;
		T41_ = isComplexValueType__cgen_10585(typ);
		if (!!(T41_)) goto LA42_;
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw nilLoc;
			if (!containsGcRef) goto LA46_;
			nimZeroMem((void*)(&nilLoc), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLoc__cgen_66((&nilLoc), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 1), (*loc).lode, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 2));
			nilLoc.r = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_119));
			genRefAssign__cgen_10581(p, (*loc), nilLoc);
		}
		goto LA44_;
		LA46_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T49_;
			NimStringDesc* res_3;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T50_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T55_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T56_;
			T49_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T49_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_3 = rawNewString(((NI) 80));
			T50_ = NIM_NIL;
			T50_ = rdLoc__cgen_435((*loc));
			cgFormatValue__cgen_147((&res_3), T50_);
			res_3 = resizeString(res_3, 5);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_290));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA53_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA53_: ;
			T55_ = NIM_NIL;
			T55_ = rope__ropes_109(res_3);
			T56_ = NIM_NIL;
			T56_ = indentLine__cgen_286(p, T55_);
			add__ropes_159(T49_, T56_);
		}
		LA44_: ;
	}
	goto LA10_;
	LA42_: ;
	{
		{
			NIM_BOOL T60_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T64_;
			T60_ = (NIM_BOOL)0;
			T60_ = !(((*loc).storage == ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 2)));
			if (!(T60_)) goto LA61_;
			T60_ = containsGcRef;
			LA61_: ;
			if (!T60_) goto LA62_;
			specializeReset__cgen_10894(p, (*loc));
			T64_ = NIM_NIL;
			T64_ = t__cgen_85((*loc));
			genObjectInit__cgen_10414(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2), T64_, loc, ((tyEnum_ObjConstrMode__fUO6aSwLQdJNwZTWRxqbKg) 0));
		}
		goto LA58_;
		LA62_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T66_;
			NimStringDesc* res_4;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T67_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T68_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T69_;
			tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw T70_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T76_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T81_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T82_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T83_;
			T66_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T66_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_4 = rawNewString(((NI) 80));
			T67_ = NIM_NIL;
			T67_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_125));
			cgFormatValue__cgen_147((&res_4), T67_);
			res_4 = resizeString(res_4, 8);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_126));
			T68_ = NIM_NIL;
			T68_ = addrLoc__cgen_10337((*(*(*p).module).g).config, (*loc));
			cgFormatValue__cgen_147((&res_4), T68_);
			res_4 = resizeString(res_4, 9);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_127));
			T69_ = NIM_NIL;
			T69_ = t__cgen_85((*loc));
			T70_ = (tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw)0;
			{
				if (!((*(*loc).lode).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA73_;
				T70_ = (*(*(*loc).lode)._kind_4.sym).kind;
			}
			goto LA71_;
			LA73_: ;
			{
				T70_ = ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8);
			}
			LA71_: ;
			T76_ = NIM_NIL;
			T76_ = getTypeDesc__cgen_6662((*p).module, T69_, T70_);
			cgFormatValue__cgen_147((&res_4), T76_);
			res_4 = resizeString(res_4, 3);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_128));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA79_;
				res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA79_: ;
			T81_ = NIM_NIL;
			T81_ = rope__ropes_109(res_4);
			T82_ = NIM_NIL;
			T82_ = indentLine__cgen_286(p, T81_);
			add__ropes_159(T66_, T82_);
			T83_ = NIM_NIL;
			T83_ = t__cgen_85((*loc));
			genObjectInit__cgen_10414(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2), T83_, loc, ((tyEnum_ObjConstrMode__fUO6aSwLQdJNwZTWRxqbKg) 0));
		}
		LA58_: ;
	}
	LA10_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, closureSetup__cgen_25935)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ls;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* env;
{	{
		if (!!((((*(*prc).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 12))&63U)))!=0))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	ls = lastSon__ast_4833((*(*prc).ast)._kind_6.sons->data[((NI) 3)]);
	{
		if (!!(((*ls).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)))) goto LA7_;
		internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*prc).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_304), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_305);
	}
	LA7_: ;
	env = (*ls)._kind_4.sym;
	assignLocalVar__cgen_11164(p, ls);
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T13_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T21_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
		if (!((*(*(*(*p).module).g).config).selectedGC == ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 10))) goto LA11_;
		T13_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T13_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res = rawNewString(((NI) 80));
		T14_ = NIM_NIL;
		T14_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_123));
		cgFormatValue__cgen_147((&res), T14_);
		res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_121));
		T15_ = NIM_NIL;
		T15_ = addrLoc__cgen_10337((*(*(*p).module).g).config, (*env).loc);
		cgFormatValue__cgen_147((&res), T15_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_306));
		T16_ = NIM_NIL;
		T16_ = getTypeDesc__cgen_6662((*p).module, (*env).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		cgFormatValue__cgen_147((&res), T16_);
		res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_307));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA19_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA19_: ;
		T21_ = NIM_NIL;
		T21_ = rope__ropes_109(res);
		T22_ = NIM_NIL;
		T22_ = indentLine__cgen_286(p, T21_);
		add__ropes_159(T13_, T22_);
	}
	goto LA9_;
	LA11_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T24_;
		NimStringDesc* res_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T31_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T32_;
		T24_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T24_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_2 = rawNewString(((NI) 80));
		T25_ = NIM_NIL;
		T25_ = rdLoc__cgen_435((*env).loc);
		cgFormatValue__cgen_147((&res_2), T25_);
		res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_55));
		T26_ = NIM_NIL;
		T26_ = getTypeDesc__cgen_6662((*p).module, (*env).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		cgFormatValue__cgen_147((&res_2), T26_);
		res_2 = resizeString(res_2, 8);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_308));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA29_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA29_: ;
		T31_ = NIM_NIL;
		T31_ = rope__ropes_109(res_2);
		T32_ = NIM_NIL;
		T32_ = indentLine__cgen_286(p, T31_);
		add__ropes_159(T24_, T32_);
	}
	LA9_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genProcBody__cgen_26219)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* procBody) {
	genStmts__cgen_11522(p, procBody);
	{
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
		NimStringDesc* res_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
		if (!((48 & (*p).flags) == 16)) goto LA3_;
		(*p).flags |= ((NU8)1)<<((((tyEnum_TCProcFlag__Iv1wQAvkoMCW3v9cTnZWvJw) 5)) & 7);
		res = rawNewString(((NI) 80));
		res = resizeString(res, 18);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_309));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA7_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA7_: ;
		T9_ = NIM_NIL;
		T9_ = rope__ropes_109(res);
		add__ropes_159(&(*p).blocks->data[((NI) 0)].sections[(((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0))- 0], T9_);
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 10);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_310));
		T10_ = NIM_NIL;
		T10_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_311));
		cgFormatValue__cgen_147((&res_2), T10_);
		res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_312));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA13_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA13_: ;
		T15_ = NIM_NIL;
		T15_ = rope__ropes_109(res_2);
		add__ropes_159(&(*p).blocks->data[((NI) 0)].sections[(((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 1))- 0], T15_);
	}
	LA3_: ;
}
static N_INLINE(NIM_BOOL, isNoReturn__cgen_26271)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 16))&63U)))!=0);
	if (!(T1_)) goto LA2_;
	T1_ = !(((*(*(*m).g).config).exc == ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 3)));
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, initFrame__cgen_17621)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* procname, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* filename) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
	NimStringDesc* res_2;
	result = NIM_NIL;
	{
		NI T3_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
		T3_ = (NI)0;
		T3_ = len__ropes_10((*(*p).module).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 2))- 0]);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		res = rawNewString(((NI) 80));
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_233));
		cgFormatValue__cgen_151((&res), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_317));
		res = resizeString(res, 125);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_318));
		T6_ = NIM_NIL;
		T6_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_319));
		cgFormatValue__cgen_147((&res), T6_);
		res = resizeString(res, 11);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_320));
		cgFormatValue__cgen_151((&res), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_317));
		res = resizeString(res, 232);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_321));
		T7_ = NIM_NIL;
		T7_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_319));
		cgFormatValue__cgen_147((&res), T7_);
		res = resizeString(res, 20);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_322));
		cgFormatValue__cgen_151((&res), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_317));
		res = resizeString(res, 70);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_323));
		T8_ = NIM_NIL;
		T8_ = rope__ropes_109(res);
		add__ropes_159(&(*(*p).module).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 2))- 0], T8_);
	}
	LA4_: ;
	T9_ = NIM_NIL;
	T9_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_319));
	(void)(T9_);
	res_2 = rawNewString(((NI) 80));
	res_2 = resizeString(res_2, 8);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_324));
	cgFormatValue__cgen_147((&res_2), procname);
	res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
	cgFormatValue__cgen_147((&res_2), filename);
	res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA12_;
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA12_: ;
	result = rope__ropes_109(res_2);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, deinitFrame__cgen_17691)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	NimStringDesc* res;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	result = NIM_NIL;
	res = rawNewString(((NI) 80));
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_6));
	T1_ = NIM_NIL;
	T1_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_326));
	cgFormatValue__cgen_147((&res), T1_);
	res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_312));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA4_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA4_: ;
	result = rope__ropes_109(res);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getProcTypeCast__cgen_26203)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = t__cgen_85((*prc).loc);
	result = getTypeDesc__cgen_6662(m, T1_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* rettype;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* params;
		tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw check;
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T6_;
		if (!((*(*prc).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9))) goto LA4_;
		rettype = NIM_NIL;
		params = NIM_NIL;
		nimZeroMem((void*)(&check), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
		initIntSet__pureZcollectionsZintsets_238((&check));
		genProcParams__cgen_3508(m, (*prc).typ, &rettype, &params, (&check), NIM_TRUE, NIM_FALSE);
		nimZeroMem((void*)T6_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T6_[0] = rettype;
		T6_[1] = params;
		result = percent___cgen_26214(T6_, 2);
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genProcAux__cgen_26283)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc) {
	tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* header;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* returnStmt;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* procBody;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* generatedProc;
	p = newProc__cgendata_278(prc, m);
	header = genProcHeader__cgen_632(m, prc, NIM_FALSE);
	returnStmt = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
	procBody = transformBody__transf_16((*(*m).g).graph, (*m).Sup.idgen, prc, NIM_FALSE);
	{
		if (!(((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 42))&63U)))!=0)) goto LA3_;
		procBody = injectDestructorCalls__injectdestructors_10132((*(*m).g).graph, (*m).Sup.idgen, prc, procBody);
	}
	LA3_: ;
	{
		NIM_BOOL T7_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* resNode;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* res;
		T7_ = (NIM_BOOL)0;
		T7_ = !((((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 11))&63U)))!=0));
		if (!(T7_)) goto LA8_;
		T7_ = !(((*(*prc).typ).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		LA8_: ;
		if (!T7_) goto LA9_;
		{
			NI T13_;
			T13_ = (NI)0;
			T13_ = len__ast_3155((*prc).ast);
			if (!(T13_ <= ((NI) 7))) goto LA14_;
			internalErrorImpl__msgs_1441((*(*m).g).config, (*prc).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_110), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_111);
		}
		LA14_: ;
		resNode = (*(*prc).ast)._kind_6.sons->data[((NI) 7)];
		res = (*resNode)._kind_4.sym;
		{
			NIM_BOOL T18_;
			NimStringDesc* res_3;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T44_;
			T18_ = (NIM_BOOL)0;
			T18_ = isInvalidReturnType__cgen_1353((*(*m).g).config, (*prc).typ, NIM_TRUE);
			if (!!(T18_)) goto LA19_;
			{
				if (!(((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 14))&63U)))!=0)) goto LA23_;
				(*res).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 14)) & 63);
			}
			LA23_: ;
			{
				NIM_BOOL T27_;
				NIM_BOOL T28_;
				NIM_BOOL T30_;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* val;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* decl;
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T35_;
				NimStringDesc* res_2;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T36_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T41_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T42_;
				T27_ = (NIM_BOOL)0;
				T28_ = (NIM_BOOL)0;
				T28_ = (((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 14))&63U)))!=0);
				if (!(T28_)) goto LA29_;
				T30_ = (NIM_BOOL)0;
				T30_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
				if (T30_) goto LA31_;
				T30_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
				LA31_: ;
				T28_ = T30_;
				LA29_: ;
				T27_ = T28_;
				if (!(T27_)) goto LA32_;
				val = easyResultAsgn__cgen_26011(procBody);
				T27_ = !((val == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
				LA32_: ;
				if (!T27_) goto LA33_;
				decl = localVarDecl__cgen_11124(p, resNode);
				nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				initLocExprSingleUse__cgen_11552(p, val, (&a));
				T35_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T35_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_2 = rawNewString(((NI) 80));
				cgFormatValue__cgen_147((&res_2), decl);
				res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
				T36_ = NIM_NIL;
				T36_ = rdLoc__cgen_435(a);
				cgFormatValue__cgen_147((&res_2), T36_);
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA39_;
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA39_: ;
				T41_ = NIM_NIL;
				T41_ = rope__ropes_109(res_2);
				T42_ = NIM_NIL;
				T42_ = indentLine__cgen_286(p, T41_);
				add__ropes_159(T35_, T42_);
			}
			goto LA25_;
			LA33_: ;
			{
				assignLocalVar__cgen_11164(p, resNode);
				initLocalVar__cgen_11052(p, res, NIM_FALSE);
			}
			LA25_: ;
			res_3 = rawNewString(((NI) 80));
			res_3 = resizeString(res_3, 8);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_286));
			T44_ = NIM_NIL;
			T44_ = rdLoc__cgen_435((*res).loc);
			cgFormatValue__cgen_147((&res_3), T44_);
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA47_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA47_: ;
			returnStmt = rope__ropes_109(res_3);
		}
		goto LA16_;
		LA19_: ;
		{
			fillResult__cgen_1795((*(*(*p).module).g).config, resNode, (*prc).typ);
			assignParam__cgen_11482(p, res, (*(*prc).typ).sons->data[((NI) 0)]);
			{
				if (!(((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 14))&63U)))!=0)) goto LA52_;
			}
			goto LA50_;
			LA52_: ;
			{
				tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA T55_;
				T55_ = (tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA)0;
				T55_ = allPathsAsgnResult__cgen_26066(procBody);
				if (!(T55_ == ((tyEnum_InitResultEnum__2o7uIiE6lt9aMcaowPMLlLA) 1))) goto LA56_;
			}
			goto LA50_;
			LA56_: ;
			{
				resetLoc__cgen_10897(p, (&(*res).loc));
			}
			LA50_: ;
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T61_;
				T61_ = NIM_NIL;
				T61_ = skipTypes__ast_3723((*res).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
				if (!((*T61_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16))) goto LA62_;
				(*res).loc.storage = ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0);
			}
			LA62_: ;
		}
		LA16_: ;
	}
	LA9_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155((*(*prc).typ).n);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA66;
				i = i_2;
				{
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* param;
					param = (*(*(*(*prc).typ).n)._kind_6.sons->data[i])._kind_4.sym;
					{
						NIM_BOOL T70_;
						T70_ = (NIM_BOOL)0;
						T70_ = isCompileTimeOnly__types_3592((*param).typ);
						if (!T70_) goto LA71_;
						goto LA67;
					}
					LA71_: ;
					assignParam__cgen_11482(p, param, (*(*prc).typ).sons->data[((NI) 0)]);
				} LA67: ;
				i_2 += ((NI) 1);
			} LA66: ;
		}
	}
	closureSetup__cgen_25935(p, prc);
	genProcBody__cgen_26219(p, procBody);
	generatedProc = NIM_NIL;
	genCLineDir__cgen_357(&generatedProc, (*prc).info, (*(*m).g).config);
	{
		NIM_BOOL T75_;
		T75_ = (NIM_BOOL)0;
		T75_ = isNoReturn__cgen_26271((*p).module, prc);
		if (!T75_) goto LA76_;
		{
			if (!((CC__extccomp_510[((*(*(*(*p).module).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__9biNtFPzjM9c2i62RuZ9c19biA) 6))&7U)))!=0)) goto LA80_;
			header = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_313), header);
		}
		LA80_: ;
	}
	LA76_: ;
	{
		NimStringDesc* res_4;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T94_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T95_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T96_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T97_;
		if (!(((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 11))&63U)))!=0)) goto LA84_;
		{
			if (!((CC__extccomp_510[((*(*(*(*p).module).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__9biNtFPzjM9c2i62RuZ9c19biA) 6))&7U)))!=0)) goto LA88_;
			header = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_314), header);
		}
		LA88_: ;
		res_4 = rawNewString(((NI) 80));
		cgFormatValue__cgen_147((&res_4), header);
		res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_315));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA92_;
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA92_: ;
		T94_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T94_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
		cgFormatValue__cgen_147((&res_4), (*T94_));
		T95_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T95_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 1));
		cgFormatValue__cgen_147((&res_4), (*T95_));
		T96_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T96_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		cgFormatValue__cgen_147((&res_4), (*T96_));
		res_4 = resizeString(res_4, 3);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_316));
		T97_ = NIM_NIL;
		T97_ = rope__ropes_109(res_4);
		add__ropes_159(&generatedProc, T97_);
	}
	goto LA82_;
	LA84_: ;
	{
		NimStringDesc* res_5;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T111_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T136_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T137_;
		tyArray__dAmhZbEWrTM5xES2bTVweg T149_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T150_;
		{
			NIM_BOOL T101_;
			tyArray__ts9cf9blICas1QWmw89bglZ7w T105_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T106_;
			T101_ = (NIM_BOOL)0;
			T101_ = hcrOn__cgen_43(m);
			if (!(T101_)) goto LA102_;
			T101_ = isReloadable__cgen_6737(m, prc);
			LA102_: ;
			if (!T101_) goto LA103_;
			nimZeroMem((void*)T105_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T105_[0] = header;
			T106_ = NIM_NIL;
			T106_ = percent___cgen_7752(T105_, 1);
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 8))- 0], T106_);
		}
		LA103_: ;
		res_5 = rawNewString(((NI) 80));
		cgFormatValue__cgen_147((&res_5), header);
		res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_315));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA109_;
			res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA109_: ;
		T111_ = NIM_NIL;
		T111_ = rope__ropes_109(res_5);
		add__ropes_159(&generatedProc, T111_);
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T116_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* procname;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T117_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T118_;
			if (!(((*prc).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 17))&31U)))!=0)) goto LA114_;
			T116_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T116_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
			add__ropes_159(&generatedProc, (*T116_));
			procname = makeCString__msgs_50((*(*prc).name).s);
			T117_ = NIM_NIL;
			T117_ = quotedFilename__msgs_1473((*(*(*p).module).g).config, (*prc).info);
			T118_ = NIM_NIL;
			T118_ = initFrame__cgen_17621(p, procname, T117_);
			add__ropes_159(&generatedProc, T118_);
		}
		goto LA112_;
		LA114_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T120_;
			T120_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T120_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
			add__ropes_159(&generatedProc, (*T120_));
		}
		LA112_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T125_;
			NimStringDesc* res_6;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T126_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T131_;
			if (!(((*prc).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 21))&31U)))!=0)) goto LA123_;
			T125_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T125_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 1));
			res_6 = rawNewString(((NI) 80));
			res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_6));
			T126_ = NIM_NIL;
			T126_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_325));
			cgFormatValue__cgen_147((&res_6), T126_);
			res_6 = resizeString(res_6, 3);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_312));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA129_;
				res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA129_: ;
			T131_ = NIM_NIL;
			T131_ = rope__ropes_109(res_6);
			add__ropes_159(T125_, T131_);
		}
		LA123_: ;
		{
			if (!(((*p).flags &((NU8)1<<((NU)(((tyEnum_TCProcFlag__Iv1wQAvkoMCW3v9cTnZWvJw) 0))&7U)))!=0)) goto LA134_;
			add__ropes_162(&generatedProc, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8));
		}
		LA134_: ;
		T136_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T136_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 1));
		add__ropes_159(&generatedProc, (*T136_));
		T137_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T137_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		add__ropes_159(&generatedProc, (*T137_));
		{
			tyArray__dAmhZbEWrTM5xES2bTVweg T142_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T143_;
			if (!(((*p).flags &((NU8)1<<((NU)(((tyEnum_TCProcFlag__Iv1wQAvkoMCW3v9cTnZWvJw) 0))&7U)))!=0)) goto LA140_;
			nimZeroMem((void*)T142_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
			T143_ = NIM_NIL;
			T143_ = percent___cgen_26473(T142_, 0);
			add__ropes_159(&generatedProc, T143_);
		}
		LA140_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T148_;
			if (!(((*prc).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 17))&31U)))!=0)) goto LA146_;
			T148_ = NIM_NIL;
			T148_ = deinitFrame__cgen_17691(p);
			add__ropes_159(&generatedProc, T148_);
		}
		LA146_: ;
		add__ropes_159(&generatedProc, returnStmt);
		nimZeroMem((void*)T149_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		T150_ = NIM_NIL;
		T150_ = percent___cgen_26482(T149_, 0);
		add__ropes_159(&generatedProc, T150_);
	}
	LA82_: ;
	add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 11))- 0], generatedProc);
	{
		NIM_BOOL T153_;
		tyArray__InO6xIOhXMnkCXPnEYWwWg T156_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T157_;
		T153_ = (NIM_BOOL)0;
		T153_ = isReloadable__cgen_6737(m, prc);
		if (!T153_) goto LA154_;
		nimZeroMem((void*)T156_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
		T156_[0] = (*prc).loc.r;
		T156_[1] = amp___ropes_140((*prc).loc.r, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_97));
		T156_[2] = getProcTypeCast__cgen_26203(m, prc);
		T156_[3] = getModuleDllPath__cgen_142(m, prc);
		T157_ = NIM_NIL;
		T157_ = percent___cgen_26487(T156_, 4);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 18))- 0], T157_);
	}
	LA154_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genProcNoForward__cgen_26633)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc) {
{	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
		if (!(((*prc).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 7))&15U)))!=0)) goto LA3_;
		fillProcLoc__cgen_11493(m, (*(*prc).ast)._kind_6.sons->data[((NI) 0)]);
		useHeader__cgen_111(m, prc);
		T5_ = NIM_NIL;
		T5_ = cgsym__cgen_126(m, (*(*prc).name).s);
		(void)(T5_);
		goto BeforeRet_;
	}
	LA3_: ;
	{
		if (!(((*prc).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 3))&15U)))!=0)) goto LA8_;
		fillProcLoc__cgen_11493(m, (*(*prc).ast)._kind_6.sons->data[((NI) 0)]);
		genProcPrototype__cgen_11529(m, prc);
	}
	goto LA6_;
	LA8_: ;
	{
		tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* q;
		if (!(((*prc).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 4))&15U)))!=0)) goto LA11_;
		q = findPendingModule__cgen_56(m, prc);
		fillProcLoc__cgen_11493(q, (*(*prc).ast)._kind_6.sons->data[((NI) 0)]);
		genProcPrototype__cgen_11529(m, prc);
		{
			NIM_BOOL T15_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym6218_;
			NIM_BOOL T17_;
			T15_ = (NIM_BOOL)0;
			T15_ = !((q == ((tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA*) NIM_NIL)));
			if (!(T15_)) goto LA16_;
			xX60gensym6218_ = prc;
			T17_ = (NIM_BOOL)0;
			T17_ = containsOrIncl__astalgo_402((&(*q).declaredThings), (NI)((NI)((NU64)(((NI) ((*xX60gensym6218_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym6218_).Sup.itemId.item))));
			T15_ = !(T17_);
			LA16_: ;
			if (!T15_) goto LA18_;
			symInDynamicLib__cgen_25776(q, prc);
			{
				NIM_BOOL T22_;
				tyArray__FKvM4FDhljtt88k8FkGthA T25_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T26_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T27_;
				T22_ = (NIM_BOOL)0;
				T22_ = isReloadable__cgen_6737(q, prc);
				if (!T22_) goto LA23_;
				nimZeroMem((void*)T25_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
				T25_[0] = (*prc).loc.r;
				T26_ = NIM_NIL;
				T26_ = t__cgen_85((*prc).loc);
				T25_[1] = getTypeDesc__cgen_6662(q, T26_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
				T25_[2] = getModuleDllPath__cgen_142(m, (*q).module);
				T27_ = NIM_NIL;
				T27_ = percent___cgen_26677(T25_, 3);
				add__ropes_159(&(*q).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 18))- 0], T27_);
			}
			LA23_: ;
		}
		goto LA13_;
		LA18_: ;
		{
			symInDynamicLibPartial__cgen_25887(m, prc);
		}
		LA13_: ;
	}
	goto LA6_;
	LA11_: ;
	{
		if (!((*(*prc).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 5))) goto LA30_;
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym6220_;
			NIM_BOOL T34_;
			tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m2;
			xX60gensym6220_ = prc;
			T34_ = (NIM_BOOL)0;
			T34_ = containsOrIncl__astalgo_402((&(*m).declaredThings), (NI)((NI)((NU64)(((NI) ((*xX60gensym6220_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym6220_).Sup.itemId.item))));
			if (!!(T34_)) goto LA35_;
			{
				if (!!(((*(*(*m).g).config).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0)))) goto LA39_;
				m2 = m;
			}
			goto LA37_;
			LA39_: ;
			{
				m2 = findPendingModule__cgen_56(m, prc);
			}
			LA37_: ;
			fillProcLoc__cgen_11493(m2, (*(*prc).ast)._kind_6.sons->data[((NI) 0)]);
			genProcPrototype__cgen_11529(m, prc);
			genProcAux__cgen_26283(m, prc);
		}
		LA35_: ;
	}
	goto LA6_;
	LA30_: ;
	{
		tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* q_2;
		if (!!((((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 6))&63U)))!=0))) goto LA43_;
		q_2 = findPendingModule__cgen_56(m, prc);
		fillProcLoc__cgen_11493(q_2, (*(*prc).ast)._kind_6.sons->data[((NI) 0)]);
		{
			NIM_BOOL T47_;
			NIM_BOOL T48_;
			NIM_BOOL T49_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym6227_;
			NIM_BOOL T51_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym6230_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym6231_;
			tyArray__FKvM4FDhljtt88k8FkGthA T56_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T57_;
			T47_ = (NIM_BOOL)0;
			T48_ = (NIM_BOOL)0;
			T49_ = (NIM_BOOL)0;
			T49_ = isReloadable__cgen_6737(m, prc);
			if (!(T49_)) goto LA50_;
			xX60gensym6227_ = prc;
			T51_ = (NIM_BOOL)0;
			T51_ = contains__astalgo_3489((&(*m).declaredProtos), (NI)((NI)((NU64)(((NI) ((*xX60gensym6227_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym6227_).Sup.itemId.item))));
			T49_ = !(T51_);
			LA50_: ;
			T48_ = T49_;
			if (!(T48_)) goto LA52_;
			T48_ = !((q_2 == ((tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA*) NIM_NIL)));
			LA52_: ;
			T47_ = T48_;
			if (!(T47_)) goto LA53_;
			xX60gensym6230_ = (*q_2).module;
			xX60gensym6231_ = (*m).module;
			T47_ = !(((NI)((NI)((NU64)(((NI) ((*xX60gensym6230_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym6230_).Sup.itemId.item))) == (NI)((NI)((NU64)(((NI) ((*xX60gensym6231_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym6231_).Sup.itemId.item)))));
			LA53_: ;
			if (!T47_) goto LA54_;
			nimZeroMem((void*)T56_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
			T56_[0] = (*prc).loc.r;
			T56_[1] = getProcTypeCast__cgen_26203(m, prc);
			T56_[2] = getModuleDllPath__cgen_142(m, prc);
			T57_ = NIM_NIL;
			T57_ = percent___cgen_23990(T56_, 3);
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 18))- 0], T57_);
		}
		LA54_: ;
		genProcPrototype__cgen_11529(m, prc);
		{
			NIM_BOOL T60_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym6234_;
			NIM_BOOL T62_;
			T60_ = (NIM_BOOL)0;
			T60_ = !((q_2 == ((tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA*) NIM_NIL)));
			if (!(T60_)) goto LA61_;
			xX60gensym6234_ = prc;
			T62_ = (NIM_BOOL)0;
			T62_ = containsOrIncl__astalgo_402((&(*q_2).declaredThings), (NI)((NI)((NU64)(((NI) ((*xX60gensym6234_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym6234_).Sup.itemId.item))));
			T60_ = !(T62_);
			LA61_: ;
			if (!T60_) goto LA63_;
			{
				NIM_BOOL T67_;
				T67_ = (NIM_BOOL)0;
				T67_ = isReloadable__cgen_6737(m, prc);
				if (!T67_) goto LA68_;
				genProcPrototype__cgen_11529(q_2, prc);
			}
			LA68_: ;
			genProcAux__cgen_26283(q_2, prc);
		}
		LA63_: ;
	}
	goto LA6_;
	LA43_: ;
	{
		fillProcLoc__cgen_11493(m, (*(*prc).ast)._kind_6.sons->data[((NI) 0)]);
		useHeader__cgen_111(m, prc);
		{
			if (!!((((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0))) goto LA73_;
			genProcPrototype__cgen_11529(m, prc);
		}
		LA73_: ;
	}
	LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genProc__cgen_421)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc) {
{	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 31))&63U)))!=0);
		if (T3_) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = isActivated__cgen_26896(prc);
		T3_ = !(T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		goto BeforeRet_;
	}
	LA6_: ;
	{
		if (!(((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 4))&63U)))!=0)) goto LA10_;
		addForwardedProc__cgen_49(m, prc);
		fillProcLoc__cgen_11493(m, (*(*prc).ast)._kind_6.sons->data[((NI) 0)]);
	}
	goto LA8_;
	LA10_: ;
	{
		genProcNoForward__cgen_26633(m, prc);
		{
			NIM_BOOL T15_;
			NIM_BOOL T16_;
			T15_ = (NIM_BOOL)0;
			T16_ = (NIM_BOOL)0;
			T16_ = ((262272 & (*prc).flags) == 128);
			if (!(T16_)) goto LA17_;
			T16_ = !(((*(*m).g).generatedHeader == ((tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA*) NIM_NIL)));
			LA17_: ;
			T15_ = T16_;
			if (!(T15_)) goto LA18_;
			T15_ = !((((*prc).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 3))&15U)))!=0));
			LA18_: ;
			if (!T15_) goto LA19_;
			genProcPrototype__cgen_11529((*(*m).g).generatedHeader, prc);
			{
				if (!((*(*prc).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 5))) goto LA23_;
				{
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym6249_;
					NIM_BOOL T27_;
					xX60gensym6249_ = prc;
					T27_ = (NIM_BOOL)0;
					T27_ = containsOrIncl__astalgo_402((&(*(*(*m).g).generatedHeader).declaredThings), (NI)((NI)((NU64)(((NI) ((*xX60gensym6249_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym6249_).Sup.itemId.item))));
					if (!!(T27_)) goto LA28_;
					genProcAux__cgen_26283((*(*m).g).generatedHeader, prc);
				}
				LA28_: ;
			}
			LA23_: ;
		}
		LA19_: ;
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, treatGlobalDifferentlyForHCR__cgen_11316)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
{	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = hcrOn__cgen_43(m);
	if (!(T2_)) goto LA3_;
	T2_ = ((67108872 & (*s).flags) == 8);
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = ((72 & (*s).loc.flags) == 0);
	LA4_: ;
	result = T1_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, emulatedThreadVars__cgen_419)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((75497472 & ~ (*conf).globalOptions)==0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, declareThreadVar__cgen_11215)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NIM_BOOL isExtern) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = emulatedThreadVars__cgen_419((*(*m).g).config);
		if (!T3_) goto LA4_;
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym1151_;
			NIM_BOOL T8_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T11_;
			NI T12_;
			tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T13_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T14_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
			xX60gensym1151_ = s;
			T8_ = (NIM_BOOL)0;
			T8_ = containsOrIncl__astalgo_402((&(*(*m).g).nimtvDeclared), (NI)((NI)((NU64)(((NI) ((*xX60gensym1151_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym1151_).Sup.itemId.item))));
			if (!!(T8_)) goto LA9_;
			T11_ = NIM_NIL;
			T11_ = t__cgen_85((*s).loc);
			asgnRef((void**) (&(*(*m).g).nimtvDeps), (tySequence__vKogasEnJSPhbQmA8r4Y9aA*) incrSeqV3((TGenericSeq*)((*(*m).g).nimtvDeps), (&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_)));
			T12_ = (*(*m).g).nimtvDeps->Sup.len++;
			asgnRef((void**) (&(*(*m).g).nimtvDeps->data[T12_]), T11_);
			nimZeroMem((void*)T13_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
			T14_ = NIM_NIL;
			T14_ = t__cgen_85((*s).loc);
			T13_[0] = getTypeDesc__cgen_6662(m, T14_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			T13_[1] = (*s).loc.r;
			T15_ = NIM_NIL;
			T15_ = percent___cgen_3124(T13_, 2);
			add__ropes_159(&(*(*m).g).nimtv, T15_);
		}
		LA9_: ;
	}
	goto LA1_;
	LA4_: ;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T36_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T37_;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T38_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T39_;
		{
			if (!isExtern) goto LA19_;
			add__ropes_162(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_327));
		}
		goto LA17_;
		LA19_: ;
		{
			if (!(((*s).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 5))&15U)))!=0)) goto LA22_;
			add__ropes_162(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_328));
		}
		goto LA17_;
		LA22_: ;
		{
			add__ropes_162(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_65));
		}
		LA17_: ;
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
			if (!(((*(*(*m).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 23))&63U)))!=0)) goto LA27_;
			sym = (*(*s).typ).sym;
			{
				NIM_BOOL T31_;
				T31_ = (NIM_BOOL)0;
				T31_ = !((sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
				if (!(T31_)) goto LA32_;
				T31_ = (((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 27))&63U)))!=0);
				LA32_: ;
				if (!T31_) goto LA33_;
				add__ropes_162(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_329));
			}
			goto LA29_;
			LA33_: ;
			{
				add__ropes_162(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_330));
			}
			LA29_: ;
		}
		LA27_: ;
		T36_ = NIM_NIL;
		T36_ = t__cgen_85((*s).loc);
		T37_ = NIM_NIL;
		T37_ = getTypeDesc__cgen_6662(m, T36_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], T37_);
		nimZeroMem((void*)T38_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T38_[0] = (*s).loc.r;
		T39_ = NIM_NIL;
		T39_ = percent___cgen_11265(T38_, 1);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], T39_);
	}
	LA1_: ;
}
static N_INLINE(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**, procSec__cgendata_274)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw s) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** result;
	result = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	result = &(*p).blocks->data[((NI) 0)].sections[(s)- 0];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genVarPrototype__cgen_11516)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
{	sym = (*n)._kind_4.sym;
	useHeader__cgen_111(m, sym);
	T1_ = NIM_NIL;
	T1_ = mangleName__cgen_646(m, sym);
	fillLoc__cgen_71((&(*sym).loc), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 3), n, T1_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 3));
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = treatGlobalDifferentlyForHCR__cgen_11316(m, sym);
		if (!T4_) goto LA5_;
		(*sym).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 0)) & 15);
	}
	LA5_: ;
	{
		NIM_BOOL T9_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym6251_;
		T9_ = (NIM_BOOL)0;
		T9_ = (((*sym).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 3))&15U)))!=0);
		if (T9_) goto LA10_;
		xX60gensym6251_ = sym;
		T9_ = contains__astalgo_3489((&(*m).declaredThings), (NI)((NI)((NU64)(((NI) ((*xX60gensym6251_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym6251_).Sup.itemId.item))));
		LA10_: ;
		if (!T9_) goto LA11_;
		goto BeforeRet_;
	}
	LA11_: ;
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym6253_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym6254_;
		xX60gensym6253_ = (*sym).owner;
		xX60gensym6254_ = (*m).module;
		if (!!(((NI)((NI)((NU64)(((NI) ((*xX60gensym6253_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym6253_).Sup.itemId.item))) == (NI)((NI)((NU64)(((NI) ((*xX60gensym6254_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym6254_).Sup.itemId.item)))))) goto LA15_;
		{
			if (!(((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 26))&63U)))!=0)) goto LA19_;
			declareThreadVar__cgen_11215(m, sym, NIM_TRUE);
		}
		goto LA17_;
		LA19_: ;
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym6259_;
			NimStringDesc* T30_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T37_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
			tyArray__ts9cf9blICas1QWmw89bglZ7w T60_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T61_;
			xX60gensym6259_ = sym;
			incl__pureZcollectionsZintsets_55((&(*m).declaredThings), (NI)((NI)((NU64)(((NI) ((*xX60gensym6259_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym6259_).Sup.itemId.item))));
			{
				NIM_BOOL T24_;
				tyArray__ts9cf9blICas1QWmw89bglZ7w T28_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T29_;
				T24_ = (NIM_BOOL)0;
				T24_ = ((2622208 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0);
				if (!(T24_)) goto LA25_;
				T24_ = (((NI) 0) < (*sym)._kind_2.alignment);
				LA25_: ;
				if (!T24_) goto LA26_;
				nimZeroMem((void*)T28_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
				T28_[0] = rope__ropes_115(((NI64) ((*sym)._kind_2.alignment)));
				T29_ = NIM_NIL;
				T29_ = percent___cgen_3760(T28_, 1);
				add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], T29_);
			}
			LA26_: ;
			T30_ = NIM_NIL;
			{
				NIM_BOOL T33_;
				T33_ = (NIM_BOOL)0;
				T33_ = hcrOn__cgen_43(m);
				if (!T33_) goto LA34_;
				T30_ = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_64));
			}
			goto LA31_;
			LA34_: ;
			{
				T30_ = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_327));
			}
			LA31_: ;
			add__ropes_162(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], T30_);
			T37_ = NIM_NIL;
			T37_ = t__cgen_85((*sym).loc);
			T38_ = NIM_NIL;
			T38_ = getTypeDesc__cgen_6662(m, T37_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], T38_);
			{
				NIM_BOOL T41_;
				T41_ = (NIM_BOOL)0;
				T41_ = hcrOn__cgen_43(m);
				if (!T41_) goto LA42_;
				add__ropes_162(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_90));
			}
			LA42_: ;
			{
				if (!(((*sym).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 4))&15U)))!=0)) goto LA46_;
				add__ropes_162(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_90));
			}
			LA46_: ;
			{
				if (!(((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 10))&63U)))!=0)) goto LA50_;
				add__ropes_162(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_112));
			}
			LA50_: ;
			{
				if (!(((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 9))&63U)))!=0)) goto LA54_;
				add__ropes_162(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_113));
			}
			LA54_: ;
			{
				if (!(((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 46))&63U)))!=0)) goto LA58_;
				add__ropes_162(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_114));
			}
			LA58_: ;
			nimZeroMem((void*)T60_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T60_[0] = (*sym).loc.r;
			T61_ = NIM_NIL;
			T61_ = percent___cgen_11265(T60_, 1);
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], T61_);
			{
				NIM_BOOL T64_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T67_;
				tyArray__FKvM4FDhljtt88k8FkGthA T68_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T69_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T70_;
				T64_ = (NIM_BOOL)0;
				T64_ = hcrOn__cgen_43(m);
				if (!T64_) goto LA65_;
				T67_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T67_ = procSec__cgendata_274((*m).initProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
				nimZeroMem((void*)T68_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
				T68_[0] = (*sym).loc.r;
				T69_ = NIM_NIL;
				T69_ = t__cgen_85((*sym).loc);
				T68_[1] = getTypeDesc__cgen_6662(m, T69_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
				T68_[2] = getModuleDllPath__cgen_142(m, sym);
				T70_ = NIM_NIL;
				T70_ = percent___cgen_24539(T68_, 3);
				add__ropes_159(T67_, T70_);
			}
			LA65_: ;
		}
		LA17_: ;
	}
	LA15_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addActualSuffixForHCR__cgen_12394)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** res, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NIM_BOOL T7_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym1383_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym1384_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = (((*sym).flags & IL64(274877907008)) == 0);
		if (!(T4_)) goto LA5_;
		T4_ = ((*sym).loc.k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 7));
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA6_;
		T7_ = (NIM_BOOL)0;
		T7_ = ((*(*sym).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 5));
		if (T7_) goto LA8_;
		xX60gensym1383_ = (*sym).owner;
		xX60gensym1384_ = module;
		T7_ = ((NI)((NI)((NU64)(((NI) ((*xX60gensym1383_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym1383_).Sup.itemId.item))) == (NI)((NI)((NU64)(((NI) ((*xX60gensym1384_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym1384_).Sup.itemId.item))));
		LA8_: ;
		T3_ = T7_;
		LA6_: ;
		if (!T3_) goto LA9_;
		T11_ = NIM_NIL;
		T11_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_97));
		unsureAsgnRef((void**) (&(*res)), amp___ropes_128((*res), T11_));
	}
	LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, cgsym__cgen_126)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, NimStringDesc* name) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
	result = NIM_NIL;
	sym = getCompilerProc__magicsys_145((*(*m).g).graph, name);
	{
		if (!!((sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA3_;
		switch ((*sym).kind) {
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 12):
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 13):
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 14):
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 16):
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 15):
		{
			genProc__cgen_421(m, sym);
		}
		break;
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8):
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 11):
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 9):
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T7_;
			T7_ = NIM_NIL;
			T7_ = newSymNode__ast_3704(sym);
			genVarPrototype__cgen_11516(m, T7_);
		}
		break;
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 7):
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
			T9_ = NIM_NIL;
			T9_ = getTypeDesc__cgen_6662(m, (*sym).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			(void)(T9_);
		}
		break;
		default:
		{
			NimStringDesc* T11_;
			T11_ = NIM_NIL;
			T11_ = rawNewString((name ? name->Sup.len : 0) + (reprEnum((NI)(*sym).kind, (&NTItsymkind__sjiB9b9aO1FRPetW6gPYZbfw_)) ? reprEnum((NI)(*sym).kind, (&NTItsymkind__sjiB9b9aO1FRPetW6gPYZbfw_))->Sup.len : 0) + 9);
appendString(T11_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_331));
appendString(T11_, name);
appendString(T11_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_332));
appendString(T11_, reprEnum((NI)(*sym).kind, (&NTItsymkind__sjiB9b9aO1FRPetW6gPYZbfw_)));
			internalErrorImpl__msgs_1441((*(*m).g).config, unknownLineInfo__lineinfos_284, T11_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_333);
		}
		break;
		}
	}
	goto LA1_;
	LA3_: ;
	{
		NimStringDesc* T13_;
		T13_ = NIM_NIL;
		T13_ = rawNewString((name ? name->Sup.len : 0) + 21);
appendString(T13_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_334));
appendString(T13_, name);
		liMessage__msgs_1128((*(*m).g).config, unknownLineInfo__lineinfos_284, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T13_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_335, NIM_FALSE);
	}
	LA1_: ;
	result = (*sym).loc.r;
	{
		NIM_BOOL T16_;
		NIM_BOOL T17_;
		T16_ = (NIM_BOOL)0;
		T17_ = (NIM_BOOL)0;
		T17_ = hcrOn__cgen_43(m);
		if (!(T17_)) goto LA18_;
		T17_ = !((sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
		LA18_: ;
		T16_ = T17_;
		if (!(T16_)) goto LA19_;
		T16_ = ((61440 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0);
		LA19_: ;
		if (!T16_) goto LA20_;
		addActualSuffixForHCR__cgen_12394(&result, (*m).module, sym);
	}
	LA20_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getSimpleTypeDesc__cgen_1830)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	switch ((*typ).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 26):
	{
		result = typeNameOrLiteral__cgen_1813(m, typ, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_21));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = detectStrVersion__cgen_490(m);
		switch (T3_) {
		case ((NI) 2):
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
			T5_ = NIM_NIL;
			T5_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_36));
			(void)(T5_);
			T6_ = NIM_NIL;
			T6_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_37));
			(void)(T6_);
			result = typeNameOrLiteral__cgen_1813(m, typ, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_37));
		}
		break;
		default:
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
			T8_ = NIM_NIL;
			T8_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_30));
			(void)(T8_);
			result = typeNameOrLiteral__cgen_1813(m, typ, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_336));
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29):
	{
		result = typeNameOrLiteral__cgen_1813(m, typ, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_337));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1):
	{
		result = typeNameOrLiteral__cgen_1813(m, typ, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_338));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2):
	{
		result = typeNameOrLiteral__cgen_1813(m, typ, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_339));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 5):
	{
		result = typeNameOrLiteral__cgen_1813(m, typ, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_21));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44):
	{
		result = typeNameOrLiteral__cgen_1813(m, typ, NumericalTypeToStr__cgen_1834[((*typ).kind)- 31]);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 13):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 20):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 15):
	{
		result = getSimpleTypeDesc__cgen_1830(m, (*typ).sons->data[((NI) 0)]);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60):
	{
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T20_;
			if (!!(((*typ).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA18_;
			T20_ = NIM_NIL;
			T20_ = lastSon__ast_3731(typ);
			result = getSimpleTypeDesc__cgen_1830(m, T20_);
		}
		goto LA16_;
		LA18_: ;
		{
			internalErrorImpl__msgs_1441((*(*m).g).config, unknownLineInfo__lineinfos_284, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_354), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_355);
		}
		LA16_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 4):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T23_;
		T23_ = NIM_NIL;
		T23_ = lastSon__ast_3731(typ);
		result = getSimpleTypeDesc__cgen_1830(m, T23_);
	}
	break;
	default:
	{
		result = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
	}
	break;
	}
	{
		NIM_BOOL T27_;
		tyArray__qtqsWM5aXmcpMIVmvq3kAA sig;
		T27_ = (NIM_BOOL)0;
		T27_ = !((result == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)));
		if (!(T27_)) goto LA28_;
		T27_ = isImportedType__cgen_1301(typ);
		LA28_: ;
		if (!T27_) goto LA29_;
		nimZeroMem((void*)sig, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
		hashType__sighashes_473(typ, (*(*m).g).config, 2, sig);
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T33_;
			T33_ = NIM_NIL;
			T33_ = cacheGetType__cgen_1380((*m).typeCache, sig);
			if (!(T33_ == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA34_;
			X5BX5Deq___cgen_1895((&(*m).typeCache), sig, result);
		}
		LA34_: ;
	}
	LA29_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getTypePre__cgen_3089)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyArray__qtqsWM5aXmcpMIVmvq3kAA sig) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	{
		if (!(typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA3_;
		result = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_20));
	}
	goto LA1_;
	LA3_: ;
	{
		result = getSimpleTypeDesc__cgen_1830(m, typ);
		{
			if (!(result == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA8_;
			result = cacheGetType__cgen_1380((*m).typeCache, sig);
		}
		LA8_: ;
	}
	LA1_: ;
	return result;
}
static N_INLINE(void, popSafePoint)(void) {
	excHandler__system_2565 = (*excHandler__system_2565).prev;
}
N_LIB_PRIVATE N_NIMCALL(void, addAbiCheck__cgen_1779)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name) {
	{
		NIM_BOOL T3_;
		NI64 size;
		NimStringDesc* msg;
		NimStringDesc* msg2;
		tyArray__FKvM4FDhljtt88k8FkGthA T7_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = isDefined__options_2292((*(*m).g).config, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_356));
		if (!(T3_)) goto LA4_;
		size = getSize__types_3388((*(*m).g).config, t);
		T3_ = !((size == IL64(-3)));
		LA4_: ;
		if (!T3_) goto LA5_;
		msg = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_357));
		addTypeHeader__types_216((&msg), (*(*m).g).config, t, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 7), NIM_TRUE);
		msg2 = ((NimStringDesc*) NIM_NIL);
		addQuoted__pureZos_449((&msg2), msg);
		nimZeroMem((void*)T7_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
		T7_[0] = name;
		T7_[1] = rope__ropes_115(size);
		T7_[2] = rope__ropes_109(msg2);
		T8_ = NIM_NIL;
		T8_ = percent___cgen_1790(T7_, 3);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 7))- 0], T8_);
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getOpenArrayDesc__cgen_4046)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* check, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyArray__qtqsWM5aXmcpMIVmvq3kAA sig;
	result = NIM_NIL;
	nimZeroMem((void*)sig, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
	hashType__sighashes_473(t, (*(*m).g).config, 2, sig);
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
		if (!(kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = getTypeDescWeak__cgen_3345(m, (*t).sons->data[((NI) 0)], check, kind);
		result = amp___ropes_140(T5_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_90));
	}
	goto LA1_;
	LA3_: ;
	{
		result = cacheGetType__cgen_1380((*m).typeCache, sig);
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* elemType;
			tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T11_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
			if (!(result == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA9_;
			result = getTypeName__cgen_1179(m, t, sig);
			X5BX5Deq___cgen_1895((&(*m).typeCache), sig, result);
			elemType = getTypeDescWeak__cgen_3345(m, (*t).sons->data[((NI) 0)], check, kind);
			nimZeroMem((void*)T11_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
			T11_[0] = result;
			T11_[1] = elemType;
			T12_ = NIM_NIL;
			T12_ = percent___cgen_4110(T11_, 2);
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 4))- 0], T12_);
		}
		LA9_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, scanCppGenericSlot__cgen_3986)(NimStringDesc* pat, NI* cursor, NI* outIdx, NI* outStars) {
	NIM_BOOL result;
	NI begin;
{	result = (NIM_BOOL)0;
	(*cursor) += ((NI) 1);
	begin = (*cursor);
	{
		while (1) {
			if (!((NU8)(pat->data[(*cursor)]) == (NU8)(42))) goto LA2;
			(*cursor) += ((NI) 1);
		} LA2: ;
	}
	{
		if (!(((NU8)(pat->data[(*cursor)])) >= ((NU8)(48)) && ((NU8)(pat->data[(*cursor)])) <= ((NU8)(57)))) goto LA5_;
		(*outIdx) = (NI)(((NU8)(pat->data[(*cursor)])) - ((NI) 48));
		(*outStars) = (NI)((*cursor) - begin);
		(*cursor) += ((NI) 1);
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	goto LA3_;
	LA5_: ;
	{
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, resolveStarsInCppType__cgen_4015)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, NI idx, NI stars) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	result = NIM_NIL;
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__ast_3990(typ);
		if (!(T3_ <= idx)) goto LA4_;
		{
			if (!NIM_TRUE) goto LA8_;
			failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_363));
		}
		LA8_: ;
	}
	LA4_: ;
	result = (*typ).sons->data[idx];
	{
		NI i;
		NI res;
		i = (NI)0;
		res = ((NI) 1);
		{
			while (1) {
				if (!(res <= stars)) goto LA12;
				i = res;
				{
					NIM_BOOL T15_;
					NI T17_;
					T15_ = (NIM_BOOL)0;
					T15_ = !((result == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
					if (!(T15_)) goto LA16_;
					T17_ = (NI)0;
					T17_ = len__ast_3990(result);
					T15_ = (((NI) 0) < T17_);
					LA16_: ;
					if (!T15_) goto LA18_;
					{
						if (!((*result).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11))) goto LA22_;
						result = (*result).sons->data[((NI) 1)];
					}
					goto LA20_;
					LA22_: ;
					{
						result = elemType__types_263(result);
					}
					LA20_: ;
				}
				LA18_: ;
				res += ((NI) 1);
			} LA12: ;
		}
	}
	return result;
}
static N_INLINE(NIM_BOOL, lacksMTypeField__types_4204)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = !(((*typ).sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
	if (!(T2_)) goto LA3_;
	T2_ = (((*(*typ).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 11))&63U)))!=0);
	LA3_: ;
	T1_ = T2_;
	if (T1_) goto LA4_;
	T1_ = (((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 2))&63U)))!=0);
	LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getRecordDesc__cgen_3814)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* check) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	NIM_BOOL hasField;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* desc;
	result = NIM_NIL;
	hasField = NIM_FALSE;
	{
		if (!(((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 23))&63U)))!=0)) goto LA3_;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
			if (!((CC__extccomp_510[((*(*(*m).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__9biNtFPzjM9c2i62RuZ9c19biA) 7))&7U)))!=0)) goto LA7_;
			T9_ = NIM_NIL;
			T9_ = structOrUnion__cgen_3102(typ);
			result = amp___ropes_140(T9_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_368));
		}
		goto LA5_;
		LA7_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
			T11_ = NIM_NIL;
			T11_ = structOrUnion__cgen_3102(typ);
			result = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_369), T11_);
		}
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		result = structOrUnion__cgen_3102(typ);
	}
	LA1_: ;
	add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_13));
	add__ropes_159(&result, name);
	{
		if (!((*typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17))) goto LA15_;
		{
			if (!((*typ).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA19_;
			{
				NIM_BOOL T23_;
				NimStringDesc* res;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T30_;
				T23_ = (NIM_BOOL)0;
				T23_ = lacksMTypeField__types_4204(typ);
				if (!T23_) goto LA24_;
				res = rawNewString(((NI) 80));
				res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_315));
				{
					if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA28_;
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA28_: ;
				T30_ = NIM_NIL;
				T30_ = rope__ropes_109(res);
				add__ropes_159(&result, T30_);
			}
			goto LA21_;
			LA24_: ;
			{
				{
					NimStringDesc* res_2;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T40_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T45_;
					if (!(((*(*(*m).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 41))&63U)))!=0)) goto LA34_;
					res_2 = rawNewString(((NI) 80));
					res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_315));
					{
						if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA38_;
						res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
					}
					LA38_: ;
					T40_ = NIM_NIL;
					T40_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_133));
					cgFormatValue__cgen_147((&res_2), T40_);
					res_2 = resizeString(res_2, 9);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_370));
					{
						if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA43_;
						res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
					}
					LA43_: ;
					T45_ = NIM_NIL;
					T45_ = rope__ropes_109(res_2);
					add__ropes_159(&result, T45_);
				}
				goto LA32_;
				LA34_: ;
				{
					NimStringDesc* res_3;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T51_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T56_;
					res_3 = rawNewString(((NI) 80));
					res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_315));
					{
						if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA49_;
						res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
					}
					LA49_: ;
					T51_ = NIM_NIL;
					T51_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_142));
					cgFormatValue__cgen_147((&res_3), T51_);
					res_3 = resizeString(res_3, 9);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_370));
					{
						if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA54_;
						res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
					}
					LA54_: ;
					T56_ = NIM_NIL;
					T56_ = rope__ropes_109(res_3);
					add__ropes_159(&result, T56_);
				}
				LA32_: ;
				hasField = NIM_TRUE;
			}
			LA21_: ;
		}
		goto LA17_;
		LA19_: ;
		{
			NIM_BOOL T58_;
			NimStringDesc* res_4;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T62_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T63_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T68_;
			T58_ = (NIM_BOOL)0;
			T58_ = ((*(*(*m).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
			if (T58_) goto LA59_;
			T58_ = (((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
			LA59_: ;
			if (!T58_) goto LA60_;
			res_4 = rawNewString(((NI) 80));
			res_4 = resizeString(res_4, 10);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_371));
			T62_ = NIM_NIL;
			T62_ = skipTypes__ast_3723((*typ).sons->data[((NI) 0)], TM__9bddtAaa9cYLwzzzlT9aJ5CKw_130);
			T63_ = NIM_NIL;
			T63_ = getTypeDescAux__cgen_1332(m, T62_, check, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19));
			cgFormatValue__cgen_147((&res_4), T63_);
			res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_315));
			{
				if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA66_;
				res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA66_: ;
			T68_ = NIM_NIL;
			T68_ = rope__ropes_109(res_4);
			add__ropes_159(&result, T68_);
			{
				NIM_BOOL T71_;
				T71_ = (NIM_BOOL)0;
				T71_ = isException__types_4064(typ);
				if (!(T71_)) goto LA72_;
				T71_ = ((*(*(*m).g).config).exc == ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 2));
				LA72_: ;
				if (!T71_) goto LA73_;
			}
			LA73_: ;
			hasField = NIM_TRUE;
		}
		goto LA17_;
		LA60_: ;
		{
			NimStringDesc* res_5;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T80_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T81_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T86_;
			res_5 = rawNewString(((NI) 80));
			res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_315));
			{
				if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA78_;
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA78_: ;
			res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_233));
			T80_ = NIM_NIL;
			T80_ = skipTypes__ast_3723((*typ).sons->data[((NI) 0)], TM__9bddtAaa9cYLwzzzlT9aJ5CKw_130);
			T81_ = NIM_NIL;
			T81_ = getTypeDescAux__cgen_1332(m, T80_, check, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19));
			cgFormatValue__cgen_147((&res_5), T81_);
			res_5 = resizeString(res_5, 5);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_234));
			{
				if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA84_;
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA84_: ;
			T86_ = NIM_NIL;
			T86_ = rope__ropes_109(res_5);
			add__ropes_159(&result, T86_);
			hasField = NIM_TRUE;
		}
		LA17_: ;
	}
	goto LA13_;
	LA15_: ;
	{
		tyArray__ts9cf9blICas1QWmw89bglZ7w T88_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T89_;
		nimZeroMem((void*)T88_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T88_[0] = name;
		T89_ = NIM_NIL;
		T89_ = percent___cgen_3933(T88_, 1);
		add__ropes_159(&result, T89_);
	}
	LA13_: ;
	desc = getRecordFields__cgen_3803(m, typ, check);
	{
		NIM_BOOL T92_;
		tyArray__dAmhZbEWrTM5xES2bTVweg T96_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T97_;
		T92_ = (NIM_BOOL)0;
		T92_ = (desc == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL));
		if (!(T92_)) goto LA93_;
		T92_ = !(hasField);
		LA93_: ;
		if (!T92_) goto LA94_;
		nimZeroMem((void*)T96_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		T97_ = NIM_NIL;
		T97_ = percent___cgen_3943(T96_, 0);
		add__ropes_159(&result, T97_);
	}
	goto LA90_;
	LA94_: ;
	{
		add__ropes_159(&result, desc);
	}
	LA90_: ;
	add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_372));
	{
		NIM_BOOL T101_;
		T101_ = (NIM_BOOL)0;
		T101_ = (((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 23))&63U)))!=0);
		if (!(T101_)) goto LA102_;
		T101_ = !(((CC__extccomp_510[((*(*(*m).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__9biNtFPzjM9c2i62RuZ9c19biA) 7))&7U)))!=0));
		LA102_: ;
		if (!T101_) goto LA103_;
		add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_373));
	}
	LA103_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getTupleDesc__cgen_3956)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* check) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* desc;
	result = NIM_NIL;
	nimZeroMem((void*)T1_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
	T1_[0] = structOrUnion__cgen_3102(typ);
	T1_[1] = name;
	result = percent___cgen_3962(T1_, 2);
	desc = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3990(typ);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T5_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				nimZeroMem((void*)T5_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
				T5_[0] = getTypeDescAux__cgen_1332(m, (*typ).sons->data[i], check, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19));
				T5_[1] = rope__ropes_115(((NI64) (i)));
				T6_ = NIM_NIL;
				T6_ = percent___cgen_3977(T5_, 2);
				add__ropes_159(&desc, T6_);
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	{
		if (!(desc == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA9_;
		add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_374));
	}
	goto LA7_;
	LA9_: ;
	{
		add__ropes_159(&result, desc);
	}
	LA7_: ;
	add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_372));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getTypeDescAux__cgen_1332)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* origTyp, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* check, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	tyArray__qtqsWM5aXmcpMIVmvq3kAA sig;
	TSafePoint TM__9bddtAaa9cYLwzzzlT9aJ5CKw_19;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* xX60gensym513_;
{	result = NIM_NIL;
	t = skipTypes__ast_3723(origTyp, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_14);
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* xX60gensym381_;
		NIM_BOOL T3_;
		xX60gensym381_ = t;
		T3_ = (NIM_BOOL)0;
		T3_ = containsOrIncl__astalgo_402(check, (NI)((NI)((NU64)(((NI) ((*xX60gensym381_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym381_).Sup.itemId.item))));
		if (!T3_) goto LA4_;
		{
			NIM_BOOL T8_;
			NimStringDesc* T12_;
			NimStringDesc* T13_;
			T8_ = (NIM_BOOL)0;
			T8_ = isImportedCppType__cgen_1312(origTyp);
			if (T8_) goto LA9_;
			T8_ = isImportedCppType__cgen_1312(t);
			LA9_: ;
			if (!!(T8_)) goto LA10_;
			T12_ = NIM_NIL;
			T13_ = NIM_NIL;
			T13_ = typeToString__types_50(origTyp, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
			T12_ = rawNewString((T13_ ? T13_->Sup.len : 0) + 28);
appendString(T12_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_16));
appendString(T12_, T13_);
			internalErrorImpl__msgs_1441((*(*m).g).config, unknownLineInfo__lineinfos_284, T12_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_17);
		}
		LA10_: ;
	}
	LA4_: ;
	{
		if (!!(((*t).sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA16_;
		useHeader__cgen_111(m, (*t).sym);
	}
	LA16_: ;
	{
		NIM_BOOL T20_;
		T20_ = (NIM_BOOL)0;
		T20_ = !((t == origTyp));
		if (!(T20_)) goto LA21_;
		T20_ = !(((*origTyp).sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
		LA21_: ;
		if (!T20_) goto LA22_;
		useHeader__cgen_111(m, (*origTyp).sym);
	}
	LA22_: ;
	nimZeroMem((void*)sig, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
	hashType__sighashes_473(origTyp, (*(*m).g).config, 2, sig);
	pushSafePoint(&TM__9bddtAaa9cYLwzzzlT9aJ5CKw_19);
	TM__9bddtAaa9cYLwzzzlT9aJ5CKw_19.status = setjmp(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_19.context);
	if (TM__9bddtAaa9cYLwzzzlT9aJ5CKw_19.status == 0) {
	result = getTypePre__cgen_3089(m, t, sig);
	{
		NIM_BOOL T26_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* xX60gensym401_;
		T26_ = (NIM_BOOL)0;
		T26_ = !((result == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)));
		if (!(T26_)) goto LA27_;
		T26_ = !(((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27)));
		LA27_: ;
		if (!T26_) goto LA28_;
		xX60gensym401_ = t;
		excl__reorder_273(check, (NI)((NI)((NU64)(((NI) ((*xX60gensym401_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym401_).Sup.itemId.item))));
		popSafePoint();
		{
			NIM_BOOL T32_;
			NIM_BOOL T34_;
			T32_ = (NIM_BOOL)0;
			T32_ = isImportedType__cgen_1301(t);
			if (!(T32_)) goto LA33_;
			T34_ = (NIM_BOOL)0;
			T34_ = containsOrIncl__cgen_4171((&(*m).typeABICache), sig);
			T32_ = !(T34_);
			LA33_: ;
			if (!T32_) goto LA35_;
			addAbiCheck__cgen_1779(m, t, result);
		}
		LA35_: ;
		goto BeforeRet_;
	}
	LA28_: ;
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47):
	{
		NimStringDesc* star;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* et;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T49_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* etB;
		{
			NIM_BOOL T40_;
			NIM_BOOL T41_;
			NIM_BOOL T44_;
			T40_ = (NIM_BOOL)0;
			T41_ = (NIM_BOOL)0;
			T41_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23));
			if (!(T41_)) goto LA42_;
			T41_ = !((((*origTyp).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 20))&63U)))!=0));
			LA42_: ;
			T40_ = T41_;
			if (!(T40_)) goto LA43_;
			T44_ = (NIM_BOOL)0;
			T44_ = ((*(*(*m).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
			if (T44_) goto LA45_;
			T44_ = (((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
			LA45_: ;
			T40_ = T44_;
			LA43_: ;
			if (!T40_) goto LA46_;
			star = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_358));
		}
		goto LA38_;
		LA46_: ;
		{
			star = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_90));
		}
		LA38_: ;
		T49_ = NIM_NIL;
		T49_ = skipTypes__ast_3723(origTyp, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
		et = lastSon__ast_3731(T49_);
		etB = skipTypes__ast_3723(et, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
		{
			NIM_BOOL T52_;
			tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ T53_;
			NIM_BOOL T55_;
			T52_ = (NIM_BOOL)0;
			T53_ = (tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ)0;
			T53_ = mapType__cgen_1227((*(*m).g).config, t, kind);
			T52_ = (T53_ == ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 18));
			if (!(T52_)) goto LA54_;
			T55_ = (NIM_BOOL)0;
			T55_ = !(((*etB).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27)));
			if (T55_) goto LA56_;
			T55_ = (kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			LA56_: ;
			T52_ = T55_;
			LA54_: ;
			if (!T52_) goto LA57_;
			{
				if (!((*etB).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 19))) goto LA61_;
				et = getSysType__magicsys_60((*(*m).g).graph, unknownLineInfo__lineinfos_284, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 41));
			}
			goto LA59_;
			LA61_: ;
			{
				et = elemType__types_263(etB);
			}
			LA59_: ;
			etB = skipTypes__ast_3723(et, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
			star->data[((NI) 0)] = 42;
		}
		LA57_: ;
		switch ((*etB).kind) {
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17):
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18):
		{
			{
				NIM_BOOL T67_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T71_;
				T67_ = (NIM_BOOL)0;
				T67_ = isImportedCppType__cgen_1312(etB);
				if (!(T67_)) goto LA68_;
				T67_ = ((*et).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11));
				LA68_: ;
				if (!T67_) goto LA69_;
				T71_ = NIM_NIL;
				T71_ = getTypeDescAux__cgen_1332(m, et, check, kind);
				result = amp___ropes_140(T71_, star);
			}
			goto LA65_;
			LA69_: ;
			{
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name;
				tyArray__qtqsWM5aXmcpMIVmvq3kAA T73_;
				nimZeroMem((void*)T73_, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
				hashType__sighashes_473(et, (*(*m).g).config, 2, T73_);
				name = getTypeForward__cgen_3141(m, et, T73_);
				result = amp___ropes_140(name, star);
				X5BX5Deq___cgen_1895((&(*m).typeCache), sig, result);
			}
			LA65_: ;
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
		{
			{
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T79_;
				if (!(((*(*(*m).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0)) goto LA77_;
				T79_ = NIM_NIL;
				T79_ = getTypeDescWeak__cgen_3345(m, et, check, kind);
				result = amp___ropes_140(T79_, star);
				X5BX5Deq___cgen_1895((&(*m).typeCache), sig, result);
			}
			goto LA75_;
			LA77_: ;
			{
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name_2;
				tyArray__qtqsWM5aXmcpMIVmvq3kAA T81_;
				NimStringDesc* T82_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T83_;
				nimZeroMem((void*)T81_, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
				hashType__sighashes_473(et, (*(*m).g).config, 2, T81_);
				name_2 = getTypeForward__cgen_3141(m, et, T81_);
				T82_ = NIM_NIL;
				T82_ = seqStar__cgen_3134(m);
				T83_ = NIM_NIL;
				T83_ = amp___ropes_140(name_2, T82_);
				result = amp___ropes_140(T83_, star);
				X5BX5Deq___cgen_1895((&(*m).typeCache), sig, result);
				pushType__cgen_3070(m, et);
			}
			LA75_: ;
		}
		break;
		default:
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T85_;
			T85_ = NIM_NIL;
			T85_ = getTypeDescAux__cgen_1332(m, et, check, kind);
			result = amp___ropes_140(T85_, star);
			X5BX5Deq___cgen_1895((&(*m).typeCache), sig, result);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48):
	{
		result = getOpenArrayDesc__cgen_4046(m, t, check, kind);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14):
	{
		result = cacheGetType__cgen_1380((*m).typeCache, sig);
		{
			if (!(result == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA90_;
			result = getTypeName__cgen_1179(m, origTyp, sig);
			{
				NIM_BOOL T94_;
				NIM_BOOL T96_;
				NI size;
				T94_ = (NIM_BOOL)0;
				T94_ = isImportedCppType__cgen_1312(t);
				if (T94_) goto LA95_;
				T96_ = (NIM_BOOL)0;
				T96_ = (((*(*t).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 6))&63U)))!=0);
				if (!(T96_)) goto LA97_;
				T96_ = ((*(*t).sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 0));
				LA97_: ;
				T94_ = T96_;
				LA95_: ;
				if (!!(T94_)) goto LA98_;
				X5BX5Deq___cgen_1895((&(*m).typeCache), sig, result);
				size = (NI)0;
				{
					tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T102_;
					NIM_BOOL T103_;
					tyArray__ts9cf9blICas1QWmw89bglZ7w T106_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T107_;
					T102_ = firstOrd__types_1406((*(*m).g).config, t);
					T103_ = (NIM_BOOL)0;
					T103_ = lt___int495056_905(T102_, IL64(0));
					if (!T103_) goto LA104_;
					nimZeroMem((void*)T106_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
					T106_[0] = result;
					T107_ = NIM_NIL;
					T107_ = percent___cgen_5873(T106_, 1);
					add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 4))- 0], T107_);
					size = ((NI) 4);
				}
				goto LA100_;
				LA104_: ;
				{
					NI64 T109_;
					T109_ = (NI64)0;
					T109_ = getSize__types_3388((*(*m).g).config, t);
					size = ((NI) (T109_));
					switch (size) {
					case ((NI) 1):
					{
						tyArray__ts9cf9blICas1QWmw89bglZ7w T111_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T112_;
						nimZeroMem((void*)T111_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
						T111_[0] = result;
						T112_ = NIM_NIL;
						T112_ = percent___cgen_5878(T111_, 1);
						add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 4))- 0], T112_);
					}
					break;
					case ((NI) 2):
					{
						tyArray__ts9cf9blICas1QWmw89bglZ7w T114_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T115_;
						nimZeroMem((void*)T114_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
						T114_[0] = result;
						T115_ = NIM_NIL;
						T115_ = percent___cgen_5883(T114_, 1);
						add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 4))- 0], T115_);
					}
					break;
					case ((NI) 4):
					{
						tyArray__ts9cf9blICas1QWmw89bglZ7w T117_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T118_;
						nimZeroMem((void*)T117_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
						T117_[0] = result;
						T118_ = NIM_NIL;
						T118_ = percent___cgen_5873(T117_, 1);
						add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 4))- 0], T118_);
					}
					break;
					case ((NI) 8):
					{
						tyArray__ts9cf9blICas1QWmw89bglZ7w T120_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T121_;
						nimZeroMem((void*)T120_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
						T120_[0] = result;
						T121_ = NIM_NIL;
						T121_ = percent___cgen_5892(T120_, 1);
						add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 4))- 0], T121_);
					}
					break;
					default:
					{
						internalErrorImpl__msgs_1441((*(*m).g).config, (*(*t).sym).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_359), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_360);
					}
					break;
					}
				}
				LA100_: ;
			}
			LA98_: ;
		}
		LA90_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25):
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* rettype;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* desc;
		result = getTypeName__cgen_1179(m, origTyp, sig);
		X5BX5Deq___cgen_1895((&(*m).typeCache), sig, result);
		rettype = NIM_NIL;
		desc = NIM_NIL;
		genProcParams__cgen_3508(m, t, &rettype, &desc, check, NIM_TRUE, NIM_TRUE);
		{
			NIM_BOOL T126_;
			T126_ = (NIM_BOOL)0;
			T126_ = isImportedType__cgen_1301(t);
			if (!!(T126_)) goto LA127_;
			{
				tyArray__InO6xIOhXMnkCXPnEYWwWg T133_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T134_;
				if (!!(((*t).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9)))) goto LA131_;
				nimZeroMem((void*)T133_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
				T133_[0] = rope__ropes_109(CallingConvToStr__cgen_1379[((*t).callConv)- 0]);
				T133_[1] = rettype;
				T133_[2] = result;
				T133_[3] = desc;
				T134_ = NIM_NIL;
				T134_ = percent___cgen_5949(T133_, 4);
				add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 4))- 0], T134_);
			}
			goto LA129_;
			LA131_: ;
			{
				tyArray__FKvM4FDhljtt88k8FkGthA T136_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T137_;
				nimZeroMem((void*)T136_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
				T136_[0] = result;
				T136_[1] = rettype;
				T136_[2] = desc;
				T137_ = NIM_NIL;
				T137_ = percent___cgen_5954(T136_, 3);
				add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 4))- 0], T137_);
			}
			LA129_: ;
		}
		LA127_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
	{
		{
			if (!(((*(*(*m).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0)) goto LA141_;
			result = getTypeDescWeak__cgen_3345(m, t, check, kind);
		}
		goto LA139_;
		LA141_: ;
		{
			NimStringDesc* T154_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T155_;
			NimStringDesc* T208_;
			result = cacheGetType__cgen_1380((*m).forwTypeCache, sig);
			{
				if (!(result == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA146_;
				result = getTypeName__cgen_1179(m, origTyp, sig);
				{
					NIM_BOOL T150_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T153_;
					T150_ = (NIM_BOOL)0;
					T150_ = isImportedType__cgen_1301(t);
					if (!!(T150_)) goto LA151_;
					T153_ = NIM_NIL;
					T153_ = structOrUnion__cgen_3102(t);
					addForwardStructFormat__cgen_3112(m, T153_, result);
				}
				LA151_: ;
				X5BX5Deq___cgen_1895((&(*m).forwTypeCache), sig, result);
			}
			LA146_: ;
			T154_ = NIM_NIL;
			T154_ = seqStar__cgen_3134(m);
			T155_ = NIM_NIL;
			T155_ = amp___ropes_140(result, T154_);
			X5BX5Deq___cgen_1895((&(*m).typeCache), sig, T155_);
			{
				NIM_BOOL T158_;
				T158_ = (NIM_BOOL)0;
				T158_ = isImportedType__cgen_1301(t);
				if (!!(T158_)) goto LA159_;
				{
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T163_;
					T163_ = NIM_NIL;
					T163_ = skipTypes__ast_3723((*t).sons->data[((NI) 0)], TM__9bddtAaa9cYLwzzzlT9aJ5CKw_67);
					if (!!(((*T163_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 3)))) goto LA164_;
					{
						NIM_BOOL T168_;
						NimStringDesc* res;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T172_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T177_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T186_;
						T168_ = (NIM_BOOL)0;
						T168_ = ((*(*(*m).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
						if (T168_) goto LA169_;
						T168_ = (((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
						LA169_: ;
						if (!T168_) goto LA170_;
						res = rawNewString(((NI) 80));
						res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_87));
						cgFormatValue__cgen_147((&res), result);
						res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_361));
						T172_ = NIM_NIL;
						T172_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_33));
						cgFormatValue__cgen_147((&res), T172_);
						res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_315));
						{
							if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA175_;
							res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
						}
						LA175_: ;
						res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_233));
						T177_ = NIM_NIL;
						T177_ = getTypeDescAux__cgen_1332(m, (*t).sons->data[((NI) 0)], check, kind);
						cgFormatValue__cgen_147((&res), T177_);
						res = resizeString(res, 21);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_362));
						{
							if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA180_;
							res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
						}
						LA180_: ;
						res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_230));
						{
							if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA184_;
							res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
						}
						LA184_: ;
						T186_ = NIM_NIL;
						T186_ = rope__ropes_109(res);
						add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 5))- 0], T186_);
					}
					goto LA166_;
					LA170_: ;
					{
						NimStringDesc* res_2;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T192_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T197_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T206_;
						res_2 = rawNewString(((NI) 80));
						res_2 = resizeString(res_2, 7);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_87));
						cgFormatValue__cgen_147((&res_2), result);
						res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_315));
						{
							if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA190_;
							res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
						}
						LA190_: ;
						res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_233));
						T192_ = NIM_NIL;
						T192_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_33));
						cgFormatValue__cgen_147((&res_2), T192_);
						res_2 = resizeString(res_2, 5);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_234));
						{
							if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA195_;
							res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
						}
						LA195_: ;
						res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_233));
						T197_ = NIM_NIL;
						T197_ = getTypeDescAux__cgen_1332(m, (*t).sons->data[((NI) 0)], check, kind);
						cgFormatValue__cgen_147((&res_2), T197_);
						res_2 = resizeString(res_2, 21);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_362));
						{
							if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA200_;
							res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
						}
						LA200_: ;
						res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_230));
						{
							if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA204_;
							res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
						}
						LA204_: ;
						T206_ = NIM_NIL;
						T206_ = rope__ropes_109(res_2);
						add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 5))- 0], T206_);
					}
					LA166_: ;
				}
				goto LA161_;
				LA164_: ;
				{
					result = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_33));
				}
				LA161_: ;
			}
			LA159_: ;
			T208_ = NIM_NIL;
			T208_ = seqStar__cgen_3134(m);
			add__ropes_162(&result, T208_);
		}
		LA139_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 49):
	{
		result = getTypeName__cgen_1179(m, origTyp, sig);
		X5BX5Deq___cgen_1895((&(*m).typeCache), sig, result);
		{
			NIM_BOOL T212_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* foo;
			tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T215_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T216_;
			T212_ = (NIM_BOOL)0;
			T212_ = isImportedType__cgen_1301(t);
			if (!!(T212_)) goto LA213_;
			foo = getTypeDescAux__cgen_1332(m, (*t).sons->data[((NI) 0)], check, kind);
			nimZeroMem((void*)T215_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
			T215_[0] = foo;
			T215_[1] = result;
			T216_ = NIM_NIL;
			T216_ = percent___cgen_6177(T215_, 2);
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 4))- 0], T216_);
		}
		LA213_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
	{
		NI64 n;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T218_;
		T218_ = lengthOrd__types_1723((*(*m).g).config, t);
		n = toInt64__int495056_88(T218_);
		{
			if (!(n <= IL64(0))) goto LA221_;
			n = IL64(1);
		}
		LA221_: ;
		result = getTypeName__cgen_1179(m, origTyp, sig);
		X5BX5Deq___cgen_1895((&(*m).typeCache), sig, result);
		{
			NIM_BOOL T225_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* foo_2;
			tyArray__FKvM4FDhljtt88k8FkGthA T228_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T229_;
			T225_ = (NIM_BOOL)0;
			T225_ = isImportedType__cgen_1301(t);
			if (!!(T225_)) goto LA226_;
			foo_2 = getTypeDescAux__cgen_1332(m, (*t).sons->data[((NI) 1)], check, kind);
			nimZeroMem((void*)T228_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
			T228_[0] = foo_2;
			T228_[1] = result;
			T228_[2] = rope__ropes_115(n);
			T229_ = NIM_NIL;
			T229_ = percent___cgen_6231(T228_, 3);
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 4))- 0], T229_);
		}
		LA226_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18):
	{
		{
			NIM_BOOL T233_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* cppName;
			NI i;
			NI chunkStart;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T300_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* typedefName;
			tyArray__dAmhZbEWrTM5xES2bTVweg T301_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T302_;
			NimStringDesc* T303_;
			tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T304_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T305_;
			T233_ = (NIM_BOOL)0;
			T233_ = isImportedCppType__cgen_1312(t);
			if (!(T233_)) goto LA234_;
			T233_ = ((*origTyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11));
			LA234_: ;
			if (!T233_) goto LA235_;
			cppName = getTypeName__cgen_1179(m, t, sig);
			i = ((NI) 0);
			chunkStart = ((NI) 0);
			{
				while (1) {
					if (!(i < ((*cppName).data ? (*cppName).data->Sup.len : 0))) goto LA238;
					{
						NI chunkEnd;
						NI idx;
						NI stars;
						if (!((NU8)((*cppName).data->data[i]) == (NU8)(39))) goto LA241_;
						chunkEnd = (NI)(i - ((NI) 1));
						idx = (NI)0;
						stars = (NI)0;
						{
							NIM_BOOL T245_;
							NimStringDesc* T248_;
							tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInSlot;
							T245_ = (NIM_BOOL)0;
							T245_ = scanCppGenericSlot__cgen_3986((*cppName).data, (&i), (&idx), (&stars));
							if (!T245_) goto LA246_;
							T248_ = NIM_NIL;
							T248_ = substr__system_7755((*cppName).data, chunkStart, chunkEnd);
							add__ropes_162(&result, T248_);
							chunkStart = i;
							typeInSlot = resolveStarsInCppType__cgen_4015(origTyp, (NI)(idx + ((NI) 1)), stars);
							{
								NIM_BOOL T251_;
								tyArray__dAmhZbEWrTM5xES2bTVweg T255_;
								tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T256_;
								T251_ = (NIM_BOOL)0;
								T251_ = (typeInSlot == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
								if (T251_) goto LA252_;
								T251_ = ((*typeInSlot).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 63));
								LA252_: ;
								if (!T251_) goto LA253_;
								nimZeroMem((void*)T255_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
								T256_ = NIM_NIL;
								T256_ = percent___cgen_3521(T255_, 0);
								add__ropes_159(&result, T256_);
							}
							goto LA249_;
							LA253_: ;
							{
								NimStringDesc* T264_;
								if (!((*typeInSlot).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60))) goto LA258_;
								{
									NimStringDesc* argX60gensym478_;
									if (!!(!(((*typeInSlot).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))))) goto LA262_;
									argX60gensym478_ = toFileLineCol__msgs_625(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_364);
									internalErrorImpl__msgs_1441((*(*m).g).config, unknownLineInfo__lineinfos_284, argX60gensym478_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_364);
								}
								LA262_: ;
								T264_ = NIM_NIL;
								T264_ = renderTree__renderer_46((*typeInSlot).n, 0);
								add__ropes_162(&result, T264_);
							}
							goto LA249_;
							LA258_: ;
							{
								tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T266_;
								T266_ = NIM_NIL;
								T266_ = getTypeDescAux__cgen_1332(m, typeInSlot, check, kind);
								add__ropes_159(&result, T266_);
							}
							LA249_: ;
						}
						LA246_: ;
					}
					goto LA239_;
					LA241_: ;
					{
						i += ((NI) 1);
					}
					LA239_: ;
				} LA238: ;
			}
			{
				NimStringDesc* T272_;
				if (!!((chunkStart == ((NI) 0)))) goto LA270_;
				T272_ = NIM_NIL;
				T272_ = substr__system_7767((*cppName).data, chunkStart);
				add__ropes_162(&result, T272_);
			}
			goto LA268_;
			LA270_: ;
			{
				result = amp___ropes_140(cppName, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_365));
				{
					NI i_2;
					NI colontmp_;
					NI T275_;
					NI i_3;
					i_2 = (NI)0;
					colontmp_ = (NI)0;
					T275_ = (NI)0;
					T275_ = len__ast_3990(origTyp);
					colontmp_ = (NI)(T275_ - ((NI) 1));
					i_3 = ((NI) 1);
					{
						while (1) {
							if (!(i_3 < colontmp_)) goto LA277;
							i_2 = i_3;
							{
								if (!(((NI) 1) < i_2)) goto LA280_;
								add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_366));
							}
							LA280_: ;
							{
								NIM_BOOL T284_;
								tyArray__dAmhZbEWrTM5xES2bTVweg T288_;
								tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T289_;
								T284_ = (NIM_BOOL)0;
								T284_ = ((*origTyp).sons->data[i_2] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
								if (T284_) goto LA285_;
								T284_ = ((*(*origTyp).sons->data[i_2]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 63));
								LA285_: ;
								if (!T284_) goto LA286_;
								nimZeroMem((void*)T288_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
								T289_ = NIM_NIL;
								T289_ = percent___cgen_3521(T288_, 0);
								add__ropes_159(&result, T289_);
							}
							goto LA282_;
							LA286_: ;
							{
								NimStringDesc* T297_;
								if (!((*(*origTyp).sons->data[i_2]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60))) goto LA291_;
								{
									NimStringDesc* argX60gensym490_;
									if (!!(!(((*(*origTyp).sons->data[i_2]).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))))) goto LA295_;
									argX60gensym490_ = toFileLineCol__msgs_625(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_364);
									internalErrorImpl__msgs_1441((*(*m).g).config, unknownLineInfo__lineinfos_284, argX60gensym490_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_364);
								}
								LA295_: ;
								T297_ = NIM_NIL;
								T297_ = renderTree__renderer_46((*(*origTyp).sons->data[i_2]).n, 0);
								add__ropes_162(&result, T297_);
							}
							goto LA282_;
							LA291_: ;
							{
								tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T299_;
								T299_ = NIM_NIL;
								T299_ = getTypeDescAux__cgen_1332(m, (*origTyp).sons->data[i_2], check, kind);
								add__ropes_159(&result, T299_);
							}
							LA282_: ;
							i_3 += ((NI) 1);
						} LA277: ;
					}
				}
				add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_367));
			}
			LA268_: ;
			T300_ = NIM_NIL;
			T300_ = getRecordDesc__cgen_3814(m, t, result, check);
			(void)(T300_);
			nimZeroMem((void*)T301_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
			T302_ = NIM_NIL;
			T302_ = percent___cgen_6322(T301_, 0);
			T303_ = NIM_NIL;
			T303_ = dollar___modulegraphs_8985(sig);
			typedefName = amp___ropes_140(T302_, T303_);
			nimZeroMem((void*)T304_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
			T304_[0] = result;
			T304_[1] = typedefName;
			T305_ = NIM_NIL;
			T305_ = percent___cgen_6328(T304_, 2);
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 4))- 0], T305_);
			X5BX5Deq___cgen_1895((&(*m).typeCache), sig, typedefName);
			result = typedefName;
		}
		goto LA231_;
		LA235_: ;
		{
			result = cacheGetType__cgen_1380((*m).forwTypeCache, sig);
			{
				if (!(result == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA309_;
				result = getTypeName__cgen_1179(m, origTyp, sig);
				X5BX5Deq___cgen_1895((&(*m).forwTypeCache), sig, result);
				{
					NIM_BOOL T313_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T316_;
					T313_ = (NIM_BOOL)0;
					T313_ = isImportedType__cgen_1301(t);
					if (!!(T313_)) goto LA314_;
					T316_ = NIM_NIL;
					T316_ = structOrUnion__cgen_3102(t);
					addForwardStructFormat__cgen_3112(m, T316_, result);
				}
				LA314_: ;
			}
			LA309_: ;
			X5BX5Deq___cgen_1895((&(*m).typeCache), sig, result);
			{
				NIM_BOOL T319_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* recdesc;
				T319_ = (NIM_BOOL)0;
				T319_ = !(((*t).sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
				if (!(T319_)) goto LA320_;
				T319_ = ((1040 & (*(*t).sym).flags) == 16);
				LA320_: ;
				if (!!(T319_)) goto LA321_;
				{
					if (!!(((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18)))) goto LA325_;
					recdesc = getRecordDesc__cgen_3814(m, t, result, check);
				}
				goto LA323_;
				LA325_: ;
				{
					recdesc = getTupleDesc__cgen_3956(m, t, result, check);
				}
				LA323_: ;
				{
					NIM_BOOL T330_;
					T330_ = (NIM_BOOL)0;
					T330_ = isImportedType__cgen_1301(t);
					if (!!(T330_)) goto LA331_;
					add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 4))- 0], recdesc);
				}
				goto LA328_;
				LA331_: ;
				{
					if (!!((((*t).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 40))&63U)))!=0))) goto LA334_;
				}
				goto LA328_;
				LA334_: ;
				LA328_: ;
			}
			LA321_: ;
		}
		LA231_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 19):
	{
		NimStringDesc* T337_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T338_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T339_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T340_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T341_;
		tyArray__qtqsWM5aXmcpMIVmvq3kAA T342_;
		NimStringDesc* T343_;
		T337_ = NIM_NIL;
		T337_ = rawNewString((reprEnum((NI)(*t).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)) ? reprEnum((NI)(*t).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_))->Sup.len : 0) + 1);
appendString(T337_, reprEnum((NI)(*t).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)));
appendChar(T337_, 95);
		T338_ = NIM_NIL;
		T338_ = lastSon__ast_3731(t);
		T339_ = NIM_NIL;
		T339_ = typeName__cgen_1161(T338_);
		T340_ = NIM_NIL;
		T340_ = amp___ropes_144(T337_, T339_);
		T341_ = NIM_NIL;
		T341_ = lastSon__ast_3731(t);
		nimZeroMem((void*)T342_, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
		hashType__sighashes_473(T341_, (*(*m).g).config, 2, T342_);
		T343_ = NIM_NIL;
		T343_ = dollar___modulegraphs_8985(T342_);
		result = amp___ropes_140(T340_, T343_);
		X5BX5Deq___cgen_1895((&(*m).typeCache), sig, result);
		{
			NIM_BOOL T346_;
			NI s;
			NI64 T349_;
			T346_ = (NIM_BOOL)0;
			T346_ = isImportedType__cgen_1301(t);
			if (!!(T346_)) goto LA347_;
			T349_ = (NI64)0;
			T349_ = getSize__types_3388((*(*m).g).config, t);
			s = ((NI) (T349_));
			switch (s) {
			case ((NI) 1):
			case ((NI) 2):
			case ((NI) 4):
			case ((NI) 8):
			{
				tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T351_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T352_;
				nimZeroMem((void*)T351_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
				T351_[0] = result;
				T351_[1] = rope__ropes_115(((NI64) ((NI)(s * ((NI) 8)))));
				T352_ = NIM_NIL;
				T352_ = percent___cgen_6621(T351_, 2);
				add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 4))- 0], T352_);
			}
			break;
			default:
			{
				tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T354_;
				NI64 T355_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T356_;
				nimZeroMem((void*)T354_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
				T354_[0] = result;
				T355_ = (NI64)0;
				T355_ = getSize__types_3388((*(*m).g).config, t);
				T354_[1] = rope__ropes_115(T355_);
				T356_ = NIM_NIL;
				T356_ = percent___cgen_6626(T354_, 2);
				add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 4))- 0], T356_);
			}
			break;
			}
		}
		LA347_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 13):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 15):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 4):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 52):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 53):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 55):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T358_;
		T358_ = NIM_NIL;
		T358_ = lastSon__ast_3731(t);
		result = getTypeDescAux__cgen_1332(m, T358_, check, kind);
	}
	break;
	default:
	{
		NimStringDesc* T360_;
		T360_ = NIM_NIL;
		T360_ = rawNewString((reprEnum((NI)(*t).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)) ? reprEnum((NI)(*t).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_))->Sup.len : 0) + 16);
appendString(T360_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_375));
appendString(T360_, reprEnum((NI)(*t).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)));
appendChar(T360_, 41);
		internalErrorImpl__msgs_1441((*(*m).g).config, unknownLineInfo__lineinfos_284, T360_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_376);
		result = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
	}
	break;
	}
	xX60gensym513_ = t;
	excl__reorder_273(check, (NI)((NI)((NU64)(((NI) ((*xX60gensym513_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym513_).Sup.itemId.item))));
	popSafePoint();
	}
	else {
		popSafePoint();
	}
	{
		{
			NIM_BOOL T365_;
			NIM_BOOL T367_;
			T365_ = (NIM_BOOL)0;
			T365_ = isImportedType__cgen_1301(t);
			if (!(T365_)) goto LA366_;
			T367_ = (NIM_BOOL)0;
			T367_ = containsOrIncl__cgen_4171((&(*m).typeABICache), sig);
			T365_ = !(T367_);
			LA366_: ;
			if (!T365_) goto LA368_;
			addAbiCheck__cgen_1779(m, t, result);
		}
		LA368_: ;
		if (TM__9bddtAaa9cYLwzzzlT9aJ5CKw_19.status != 0) nimLeaveFinally();
	}
	if (TM__9bddtAaa9cYLwzzzlT9aJ5CKw_19.status != 0) reraiseException();
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getTypeDesc__cgen_6662)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw check;
	result = NIM_NIL;
	nimZeroMem((void*)(&check), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
	initIntSet__pureZcollectionsZintsets_238((&check));
	result = getTypeDescAux__cgen_1332(m, typ, (&check), kind);
	return result;
}
static N_INLINE(NIM_BOOL, requiresExternC__cgen_26492)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NIM_BOOL T3_;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T5_;
	NIM_BOOL T8_;
	NIM_BOOL T9_;
	NIM_BOOL T10_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T3_ = (NIM_BOOL)0;
	T3_ = (((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
	if (!(T3_)) goto LA4_;
	T5_ = NIM_NIL;
	T5_ = getModule__astalgo_216(sym);
	T3_ = !((((*T5_).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0));
	LA4_: ;
	T2_ = T3_;
	if (!(T2_)) goto LA6_;
	T2_ = !(((*(*(*m).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2)));
	LA6_: ;
	T1_ = T2_;
	if (T1_) goto LA7_;
	T8_ = (NIM_BOOL)0;
	T9_ = (NIM_BOOL)0;
	T10_ = (NIM_BOOL)0;
	T10_ = (((*sym).flags & IL64(4295229696)) == 0);
	if (!(T10_)) goto LA11_;
	T10_ = !((((*sym).flags & 192) == 0));
	LA11_: ;
	T9_ = T10_;
	if (!(T9_)) goto LA12_;
	T9_ = ((*sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 0));
	LA12_: ;
	T8_ = T9_;
	if (!(T8_)) goto LA13_;
	T8_ = ((*(*(*m).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
	LA13_: ;
	T1_ = T8_;
	LA7_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genProcPrototype__cgen_11529)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
{	useHeader__cgen_111(m, sym);
	{
		if (!(((*sym).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 3))&15U)))!=0)) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		if (!(((*sym).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 4))&15U)))!=0)) goto LA7_;
		{
			NIM_BOOL T11_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym6189_;
			NIM_BOOL T13_;
			NimStringDesc* res;
			NimStringDesc* T16_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T23_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T30_;
			T11_ = (NIM_BOOL)0;
			T11_ = !((((NI) ((*sym).Sup.itemId.module)) == (*(*m).module).position));
			if (!(T11_)) goto LA12_;
			xX60gensym6189_ = sym;
			T13_ = (NIM_BOOL)0;
			T13_ = containsOrIncl__astalgo_402((&(*m).declaredThings), (NI)((NI)((NU64)(((NI) ((*xX60gensym6189_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym6189_).Sup.itemId.item))));
			T11_ = !(T13_);
			LA12_: ;
			if (!T11_) goto LA14_;
			res = rawNewString(((NI) 80));
			T16_ = NIM_NIL;
			{
				NIM_BOOL T19_;
				T19_ = (NIM_BOOL)0;
				T19_ = isReloadable__cgen_6737(m, sym);
				if (!T19_) goto LA20_;
				T16_ = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_11));
			}
			goto LA17_;
			LA20_: ;
			{
				T16_ = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_12));
			}
			LA17_: ;
			cgFormatValue__cgen_151((&res), T16_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_13));
			T23_ = NIM_NIL;
			T23_ = t__cgen_85((*sym).loc);
			T24_ = NIM_NIL;
			T24_ = getTypeDesc__cgen_6662(m, T23_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			cgFormatValue__cgen_147((&res), T24_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_13));
			T25_ = NIM_NIL;
			T25_ = mangleDynLibProc__cgen_3812(sym);
			cgFormatValue__cgen_147((&res), T25_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
			{
				if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA28_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA28_: ;
			T30_ = NIM_NIL;
			T30_ = rope__ropes_109(res);
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], T30_);
			{
				NIM_BOOL T33_;
				tyArray__FKvM4FDhljtt88k8FkGthA T36_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T37_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
				T33_ = (NIM_BOOL)0;
				T33_ = isReloadable__cgen_6737(m, sym);
				if (!T33_) goto LA34_;
				nimZeroMem((void*)T36_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
				T36_[0] = mangleDynLibProc__cgen_3812(sym);
				T37_ = NIM_NIL;
				T37_ = t__cgen_85((*sym).loc);
				T36_[1] = getTypeDesc__cgen_6662(m, T37_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
				T36_[2] = getModuleDllPath__cgen_142(m, sym);
				T38_ = NIM_NIL;
				T38_ = percent___cgen_23990(T36_, 3);
				add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 18))- 0], T38_);
			}
			LA34_: ;
		}
		LA14_: ;
	}
	goto LA5_;
	LA7_: ;
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym6198_;
		NIM_BOOL T40_;
		NIM_BOOL asPtr;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* header;
		NimStringDesc* res_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T71_;
		xX60gensym6198_ = sym;
		T40_ = (NIM_BOOL)0;
		T40_ = containsOrIncl__astalgo_402((&(*m).declaredProtos), (NI)((NI)((NU64)(((NI) ((*xX60gensym6198_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym6198_).Sup.itemId.item))));
		if (!!(T40_)) goto LA41_;
		asPtr = isReloadable__cgen_6737(m, sym);
		header = genProcHeader__cgen_632(m, sym, asPtr);
		{
			if (!!(asPtr)) goto LA45_;
			{
				NIM_BOOL T49_;
				T49_ = (NIM_BOOL)0;
				T49_ = isNoReturn__cgen_26271(m, sym);
				if (!(T49_)) goto LA50_;
				T49_ = ((CC__extccomp_510[((*(*(*m).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__9biNtFPzjM9c2i62RuZ9c19biA) 6))&7U)))!=0);
				LA50_: ;
				if (!T49_) goto LA51_;
				header = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_313), header);
			}
			LA51_: ;
			{
				NIM_BOOL T55_;
				T55_ = (NIM_BOOL)0;
				T55_ = !(((*(*sym).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 5)));
				if (!(T55_)) goto LA56_;
				T55_ = requiresExternC__cgen_26492(m, sym);
				LA56_: ;
				if (!T55_) goto LA57_;
				header = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_377), header);
			}
			LA57_: ;
			{
				NIM_BOOL T61_;
				T61_ = (NIM_BOOL)0;
				T61_ = (((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 11))&63U)))!=0);
				if (!(T61_)) goto LA62_;
				T61_ = ((CC__extccomp_510[((*(*(*m).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__9biNtFPzjM9c2i62RuZ9c19biA) 7))&7U)))!=0);
				LA62_: ;
				if (!T61_) goto LA63_;
				add__ropes_162(&header, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_378));
			}
			LA63_: ;
			{
				NIM_BOOL T67_;
				T67_ = (NIM_BOOL)0;
				T67_ = isNoReturn__cgen_26271(m, sym);
				if (!(T67_)) goto LA68_;
				T67_ = ((CC__extccomp_510[((*(*(*m).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__9biNtFPzjM9c2i62RuZ9c19biA) 7))&7U)))!=0);
				LA68_: ;
				if (!T67_) goto LA69_;
				add__ropes_162(&header, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_379));
			}
			LA69_: ;
		}
		LA45_: ;
		res_2 = rawNewString(((NI) 80));
		cgFormatValue__cgen_147((&res_2), header);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_380));
		T71_ = NIM_NIL;
		T71_ = rope__ropes_109(res_2);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 8))- 0], T71_);
	}
	goto LA5_;
	LA41_: ;
	LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, putLocIntoDest__cgen_11532)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw s) {
	{
		if (!!(((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0)))) goto LA3_;
		{
			if (!(((*d).flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 2))&15U)))!=0)) goto LA7_;
			genAssignment__cgen_10403(p, (*d), s, 0);
		}
		goto LA5_;
		LA7_: ;
		{
			genAssignment__cgen_10403(p, (*d), s, 1);
		}
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		genericAssign((void*)(&(*d)), (void*)(&s), (&NTItloc__CAJV4zTUpZwr0j6Wy8FiFw_));
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isSimpleConst__cgen_95)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ) {
	NIM_BOOL result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	result = (NIM_BOOL)0;
	t = skipTypes__ast_3723(typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_266);
	T1_ = (NIM_BOOL)0;
	T1_ = !(((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 19) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24)));
	if (!(T1_)) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25));
	if (!(T3_)) goto LA4_;
	T3_ = ((*t).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
	LA4_: ;
	T1_ = !(T3_);
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, putIntoDest__cgen_18794)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r, tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ s) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	{
		if (!!(((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0)))) goto LA3_;
		initLoc__cgen_66((&a), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 6), n, s);
		a.r = r;
		{
			if (!(((*d).flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 2))&15U)))!=0)) goto LA7_;
			genAssignment__cgen_10403(p, (*d), a, 0);
		}
		goto LA5_;
		LA7_: ;
		{
			genAssignment__cgen_10403(p, (*d), a, 1);
		}
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		(*d).k = ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 6);
		unsureAsgnRef((void**) (&(*d).lode), n);
		unsureAsgnRef((void**) (&(*d).r), r);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, genConstSetup__cgen_24498)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	NIM_BOOL result;
	tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m;
	result = (NIM_BOOL)0;
	m = (*p).module;
	useHeader__cgen_111(m, sym);
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
		if (!((*sym).loc.k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = mangleName__cgen_646((*p).module, sym);
		fillLoc__cgen_71((&(*sym).loc), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 8), (*sym).ast, T5_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 1));
	}
	LA3_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = hcrOn__cgen_43(m);
		if (!T8_) goto LA9_;
		(*sym).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 0)) & 15);
	}
	LA9_: ;
	result = !((((*sym).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 3))&15U)))!=0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genConstHeader__cgen_24515)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* q, tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
{	{
		if (!((*sym).loc.r == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = genConstSetup__cgen_24498(p, sym);
			if (!!(T7_)) goto LA8_;
			goto BeforeRet_;
		}
		LA8_: ;
	}
	LA3_: ;
	{
		NIM_BOOL T12_;
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T15_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T16_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T18_;
		tyArray__FKvM4FDhljtt88k8FkGthA T19_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T20_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T21_;
		T12_ = (NIM_BOOL)0;
		T12_ = hcrOn__cgen_43(m);
		if (!T12_) goto LA13_;
		nimZeroMem((void*)T15_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T16_ = NIM_NIL;
		T16_ = t__cgen_85((*sym).loc);
		T15_[0] = getTypeDesc__cgen_6662(m, T16_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
		T15_[1] = (*sym).loc.r;
		T17_ = NIM_NIL;
		T17_ = percent___cgen_24534(T15_, 2);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], T17_);
		T18_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T18_ = procSec__cgendata_274((*m).initProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
		nimZeroMem((void*)T19_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
		T19_[0] = (*sym).loc.r;
		T20_ = NIM_NIL;
		T20_ = t__cgen_85((*sym).loc);
		T19_[1] = getTypeDesc__cgen_6662(m, T20_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
		T19_[2] = getModuleDllPath__cgen_142(q, sym);
		T21_ = NIM_NIL;
		T21_ = percent___cgen_24539(T19_, 3);
		add__ropes_159(T18_, T21_);
	}
	goto LA10_;
	LA13_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* headerDecl;
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T23_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T24_;
		nimZeroMem((void*)T23_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T24_ = NIM_NIL;
		T24_ = t__cgen_85((*sym).loc);
		T23_[0] = getTypeDesc__cgen_6662(m, T24_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
		T23_[1] = (*sym).loc.r;
		headerDecl = percent___cgen_24544(T23_, 2);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 9))- 0], headerDecl);
		{
			NIM_BOOL T27_;
			T27_ = (NIM_BOOL)0;
			T27_ = (((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 7))&63U)))!=0);
			if (!(T27_)) goto LA28_;
			T27_ = !(((*(*(*p).module).g).generatedHeader == ((tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA*) NIM_NIL)));
			LA28_: ;
			if (!T27_) goto LA29_;
			add__ropes_159(&(*(*(*(*p).module).g).generatedHeader).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 9))- 0], headerDecl);
		}
		LA29_: ;
	}
	LA10_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genConstDefinition__cgen_24558)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* q, tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* actualConstName;
	tyArray__FKvM4FDhljtt88k8FkGthA T7_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = hcrOn__cgen_43(q);
		if (!T3_) goto LA4_;
		actualConstName = amp___ropes_140((*sym).loc.r, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_385));
	}
	goto LA1_;
	LA4_: ;
	{
		actualConstName = (*sym).loc.r;
	}
	LA1_: ;
	nimZeroMem((void*)T7_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
	T7_[0] = getTypeDesc__cgen_6662(q, (*sym).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
	T7_[1] = actualConstName;
	T7_[2] = genBracedInit__cgen_13891((*q).initProc, (*sym).ast, NIM_TRUE, (*sym).typ);
	T8_ = NIM_NIL;
	T8_ = percent___cgen_24563(T7_, 3);
	add__ropes_159(&(*q).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 9))- 0], T8_);
	{
		NIM_BOOL T11_;
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T14_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T15_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T17_;
		tyArray__FKvM4FDhljtt88k8FkGthA T18_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T20_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T21_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T27_;
		T11_ = (NIM_BOOL)0;
		T11_ = hcrOn__cgen_43(q);
		if (!T11_) goto LA12_;
		nimZeroMem((void*)T14_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T15_ = NIM_NIL;
		T15_ = t__cgen_85((*sym).loc);
		T14_[0] = getTypeDesc__cgen_6662(q, T15_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
		T14_[1] = (*sym).loc.r;
		T16_ = NIM_NIL;
		T16_ = percent___cgen_24534(T14_, 2);
		add__ropes_159(&(*q).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], T16_);
		T17_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T17_ = procSec__cgendata_274((*q).initProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
		nimZeroMem((void*)T18_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
		T18_[0] = getModuleDllPath__cgen_142(q, sym);
		T18_[1] = (*sym).loc.r;
		T18_[2] = rdLoc__cgen_435((*sym).loc);
		T19_ = NIM_NIL;
		T19_ = percent___cgen_24572(T18_, 3);
		add__ropes_159(T17_, T19_);
		T20_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T20_ = procSec__cgendata_274((*q).initProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_6));
		T21_ = NIM_NIL;
		T21_ = cgsym__cgen_126(q, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_250));
		cgFormatValue__cgen_147((&res), T21_);
		res = resizeString(res, 8);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_126));
		cgFormatValue__cgen_147((&res), (*sym).loc.r);
		res = resizeString(res, 20);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_251));
		cgFormatValue__cgen_147((&res), actualConstName);
		res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_127));
		T22_ = NIM_NIL;
		T22_ = rdLoc__cgen_435((*sym).loc);
		cgFormatValue__cgen_147((&res), T22_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_128));
		{
			if (!!((((*(*(*q).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA25_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA25_: ;
		T27_ = NIM_NIL;
		T27_ = rope__ropes_109(res);
		add__ropes_159(T20_, T27_);
	}
	LA12_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, requestConstImpl__cgen_11519)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	{
		NIM_BOOL T3_;
		tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m;
		tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* q;
		T3_ = (NIM_BOOL)0;
		T3_ = genConstSetup__cgen_24498(p, sym);
		if (!T3_) goto LA4_;
		m = (*p).module;
		q = findPendingModule__cgen_56(m, sym);
		{
			NIM_BOOL T8_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym6238_;
			NIM_BOOL T10_;
			T8_ = (NIM_BOOL)0;
			T8_ = !((q == ((tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA*) NIM_NIL)));
			if (!(T8_)) goto LA9_;
			xX60gensym6238_ = sym;
			T10_ = (NIM_BOOL)0;
			T10_ = containsOrIncl__astalgo_402((&(*q).declaredThings), (NI)((NI)((NU64)(((NI) ((*xX60gensym6238_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym6238_).Sup.itemId.item))));
			T8_ = !(T10_);
			LA9_: ;
			if (!T8_) goto LA11_;
			genConstDefinition__cgen_24558(q, p, sym);
		}
		LA11_: ;
		{
			NIM_BOOL T15_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym6242_;
			NIM_BOOL T17_;
			T15_ = (NIM_BOOL)0;
			T15_ = !((q == m));
			if (!(T15_)) goto LA16_;
			xX60gensym6242_ = sym;
			T17_ = (NIM_BOOL)0;
			T17_ = containsOrIncl__astalgo_402((&(*m).declaredThings), (NI)((NI)((NU64)(((NI) ((*xX60gensym6242_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym6242_).Sup.itemId.item))));
			T15_ = !(T17_);
			LA16_: ;
			if (!T15_) goto LA18_;
			genConstHeader__cgen_24515(m, q, p, sym);
		}
		LA18_: ;
	}
	LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genComplexConst__cgen_24238)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	requestConstImpl__cgen_11519(p, sym);
	putLocIntoDest__cgen_11532(p, d, (*sym).loc);
}
N_LIB_PRIVATE N_NIMCALL(void, genGotoVar__cgen_13879)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* value) {
	{
		if (!!(((*value).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) && (*value).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 15)))) goto LA3_;
		liMessage__msgs_1128((*(*(*p).module).g).config, (*value).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_386), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_387, NIM_FALSE);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T6_;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T7_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
		T6_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T6_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		nimZeroMem((void*)T7_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T7_[0] = rope__ropes_115((*value)._kind_1.intVal);
		T8_ = NIM_NIL;
		T8_ = percent___cgen_13886(T7_, 1);
		T9_ = NIM_NIL;
		T9_ = indentLine__cgen_286(p, T8_);
		add__ropes_159(T6_, T9_);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hcrOn__cgen_46)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = hcrOn__options_582((*(*(*p).module).g).config);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, potentialValueInit__cgen_13896)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* v, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* value) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = (((*v).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 4))&15U)))!=0);
		if (T4_) goto LA5_;
		T4_ = (((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 26))&63U)))!=0);
		LA5_: ;
		T3_ = T4_;
		if (T3_) goto LA6_;
		T3_ = hcrOn__cgen_46(p);
		LA6_: ;
		if (!T3_) goto LA7_;
		result = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
	}
	goto LA1_;
	LA7_: ;
	{
		NIM_BOOL T10_;
		NIM_BOOL T11_;
		NIM_BOOL T12_;
		NIM_BOOL T13_;
		NIM_BOOL T16_;
		NIM_BOOL T20_;
		T10_ = (NIM_BOOL)0;
		T11_ = (NIM_BOOL)0;
		T12_ = (NIM_BOOL)0;
		T13_ = (NIM_BOOL)0;
		T13_ = (((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 3))&63U)))!=0);
		if (!(T13_)) goto LA14_;
		T13_ = !((value == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
		LA14_: ;
		T12_ = T13_;
		if (!(T12_)) goto LA15_;
		T16_ = (NIM_BOOL)0;
		T16_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
		if (T16_) goto LA17_;
		T16_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
		LA17_: ;
		T12_ = isDeepConstExpr__trees_171(value, T16_);
		LA15_: ;
		T11_ = T12_;
		if (!(T11_)) goto LA18_;
		T11_ = ((*p).withinLoop == ((NI) 0));
		LA18_: ;
		T10_ = T11_;
		if (!(T10_)) goto LA19_;
		T20_ = (NIM_BOOL)0;
		T20_ = containsGarbageCollectedRef__types_612((*v).typ);
		T10_ = !(T20_);
		LA19_: ;
		if (!T10_) goto LA21_;
		result = genBracedInit__cgen_13891(p, value, NIM_FALSE, (*v).typ);
	}
	goto LA1_;
	LA21_: ;
	{
		result = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, varInDynamicLib__cgen_11313)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* lib;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* extname;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tmp;
	NimStringDesc* res;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T2_;
	NimStringDesc* T3_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T4_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
	tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T10_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T11_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
	lib = (*sym).annex;
	extname = (*sym).loc.r;
	loadDynamicLib__cgen_25651(m, lib);
	(*sym).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 0)) & 15);
	tmp = mangleDynLibProc__cgen_3812(sym);
	asgnRef((void**) (&(*sym).loc.r), tmp);
	(*m).labels += ((NI) 2);
	res = rawNewString(((NI) 80));
	cgFormatValue__cgen_147((&res), tmp);
	res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_55));
	T1_ = NIM_NIL;
	T1_ = getTypeDesc__cgen_6662(m, (*sym).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
	cgFormatValue__cgen_147((&res), T1_);
	res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_389));
	T2_ = NIM_NIL;
	T2_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_57));
	cgFormatValue__cgen_147((&res), T2_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
	cgFormatValue__cgen_147((&res), (*lib).name);
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
	T3_ = NIM_NIL;
	T3_ = dollar___ropes_250(extname);
	T4_ = NIM_NIL;
	T4_ = makeCString__msgs_50(T3_);
	cgFormatValue__cgen_147((&res), T4_);
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
	{
		if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA7_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA7_: ;
	T9_ = NIM_NIL;
	T9_ = rope__ropes_109(res);
	add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 18))- 0], T9_);
	nimZeroMem((void*)T10_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
	T10_[0] = (*sym).loc.r;
	T11_ = NIM_NIL;
	T11_ = t__cgen_85((*sym).loc);
	T10_[1] = getTypeDesc__cgen_6662(m, T11_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
	T12_ = NIM_NIL;
	T12_ = percent___cgen_25882(T10_, 2);
	add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], T12_);
}
N_LIB_PRIVATE N_NIMCALL(void, assignGlobalVar__cgen_11336)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* value) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
{	s = (*n)._kind_4.sym;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
		if (!((*s).loc.k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = mangleName__cgen_646((*p).module, s);
		fillLoc__cgen_71((&(*s).loc), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 3), n, T5_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 3));
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = treatGlobalDifferentlyForHCR__cgen_11316((*p).module, s);
			if (!T8_) goto LA9_;
			(*s).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 0)) & 15);
		}
		LA9_: ;
	}
	LA3_: ;
	{
		tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* q;
		if (!(((*s).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 4))&15U)))!=0)) goto LA13_;
		q = findPendingModule__cgen_56((*p).module, s);
		{
			NIM_BOOL T17_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym1169_;
			NIM_BOOL T19_;
			T17_ = (NIM_BOOL)0;
			T17_ = !((q == ((tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA*) NIM_NIL)));
			if (!(T17_)) goto LA18_;
			xX60gensym1169_ = s;
			T19_ = (NIM_BOOL)0;
			T19_ = containsOrIncl__astalgo_402((&(*q).declaredThings), (NI)((NI)((NU64)(((NI) ((*xX60gensym1169_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym1169_).Sup.itemId.item))));
			T17_ = !(T19_);
			LA18_: ;
			if (!T17_) goto LA20_;
			varInDynamicLib__cgen_11313(q, s);
		}
		goto LA15_;
		LA20_: ;
		{
			asgnRef((void**) (&(*s).loc.r), mangleDynLibProc__cgen_3812(s));
		}
		LA15_: ;
		{
			if (!!((value == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA25_;
			internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_390), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_391);
		}
		LA25_: ;
		goto BeforeRet_;
	}
	LA13_: ;
	useHeader__cgen_111((*p).module, s);
	{
		if (!(((*s).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 3))&15U)))!=0)) goto LA29_;
		goto BeforeRet_;
	}
	LA29_: ;
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym1175_;
		NIM_BOOL T33_;
		xX60gensym1175_ = s;
		T33_ = (NIM_BOOL)0;
		T33_ = containsOrIncl__astalgo_402((&(*(*p).module).declaredThings), (NI)((NI)((NU64)(((NI) ((*xX60gensym1175_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym1175_).Sup.itemId.item))));
		if (!!(T33_)) goto LA34_;
		{
			if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 26))&63U)))!=0)) goto LA38_;
			declareThreadVar__cgen_11215((*p).module, s, (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 6))&63U)))!=0));
			{
				if (!!((value == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA42_;
				internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_392), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_393);
			}
			LA42_: ;
		}
		goto LA36_;
		LA38_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* decl;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* td;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T45_;
			decl = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
			T45_ = NIM_NIL;
			T45_ = t__cgen_85((*s).loc);
			td = getTypeDesc__cgen_6662((*p).module, T45_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
			{
				if (!((*s).constraint == 0)) goto LA48_;
				{
					NIM_BOOL T52_;
					tyArray__ts9cf9blICas1QWmw89bglZ7w T56_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T57_;
					T52_ = (NIM_BOOL)0;
					T52_ = ((2622208 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
					if (!(T52_)) goto LA53_;
					T52_ = (((NI) 0) < (*s)._kind_2.alignment);
					LA53_: ;
					if (!T52_) goto LA54_;
					nimZeroMem((void*)T56_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
					T56_[0] = rope__ropes_115(((NI64) ((*s)._kind_2.alignment)));
					T57_ = NIM_NIL;
					T57_ = percent___cgen_3760(T56_, 1);
					add__ropes_159(&decl, T57_);
				}
				LA54_: ;
				{
					NIM_BOOL T60_;
					T60_ = (NIM_BOOL)0;
					T60_ = hcrOn__cgen_46(p);
					if (!T60_) goto LA61_;
					add__ropes_162(&decl, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_64));
				}
				goto LA58_;
				LA61_: ;
				{
					if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 6))&63U)))!=0)) goto LA64_;
					add__ropes_162(&decl, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_327));
				}
				goto LA58_;
				LA64_: ;
				{
					if (!(((*s).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 5))&15U)))!=0)) goto LA67_;
					add__ropes_162(&decl, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_328));
				}
				goto LA58_;
				LA67_: ;
				{
					add__ropes_162(&decl, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_65));
				}
				LA58_: ;
				{
					NIM_BOOL T72_;
					T72_ = (NIM_BOOL)0;
					T72_ = ((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 9));
					if (!(T72_)) goto LA73_;
					T72_ = !((value == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)));
					LA73_: ;
					if (!T72_) goto LA74_;
					add__ropes_162(&decl, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_394));
				}
				LA74_: ;
				add__ropes_159(&decl, td);
				{
					NIM_BOOL T78_;
					T78_ = (NIM_BOOL)0;
					T78_ = hcrOn__cgen_46(p);
					if (!T78_) goto LA79_;
					add__ropes_162(&decl, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_90));
				}
				LA79_: ;
				{
					if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 10))&63U)))!=0)) goto LA83_;
					add__ropes_162(&decl, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_112));
				}
				LA83_: ;
				{
					if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 9))&63U)))!=0)) goto LA87_;
					add__ropes_162(&decl, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_113));
				}
				LA87_: ;
				{
					if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 46))&63U)))!=0)) goto LA91_;
					add__ropes_162(&decl, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_114));
				}
				LA91_: ;
				{
					tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T97_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T98_;
					if (!!((value == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA95_;
					nimZeroMem((void*)T97_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
					T97_[0] = (*s).loc.r;
					T97_[1] = value;
					T98_ = NIM_NIL;
					T98_ = percent___cgen_11465(T97_, 2);
					add__ropes_159(&decl, T98_);
				}
				goto LA93_;
				LA95_: ;
				{
					tyArray__ts9cf9blICas1QWmw89bglZ7w T100_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T101_;
					nimZeroMem((void*)T100_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
					T100_[0] = (*s).loc.r;
					T101_ = NIM_NIL;
					T101_ = percent___cgen_11265(T100_, 1);
					add__ropes_159(&decl, T101_);
				}
				LA93_: ;
			}
			goto LA46_;
			LA48_: ;
			{
				{
					NimStringDesc* T107_;
					tyArray__FKvM4FDhljtt88k8FkGthA T108_;
					if (!!((value == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA105_;
					T107_ = NIM_NIL;
					T107_ = rawNewString(((*(*s).constraint)._kind_3.strVal ? (*(*s).constraint)._kind_3.strVal->Sup.len : 0) + 8);
appendString(T107_, (*(*s).constraint)._kind_3.strVal);
appendString(T107_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_395));
					nimZeroMem((void*)T108_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
					T108_[0] = td;
					T108_[1] = (*s).loc.r;
					T108_[2] = value;
					decl = runtimeFormat__ropes_271(T107_, T108_, 3);
				}
				goto LA103_;
				LA105_: ;
				{
					NimStringDesc* T110_;
					tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T111_;
					T110_ = NIM_NIL;
					T110_ = rawNewString(((*(*s).constraint)._kind_3.strVal ? (*(*s).constraint)._kind_3.strVal->Sup.len : 0) + 3);
appendString(T110_, (*(*s).constraint)._kind_3.strVal);
appendString(T110_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_396));
					nimZeroMem((void*)T111_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
					T111_[0] = td;
					T111_[1] = (*s).loc.r;
					decl = runtimeFormat__ropes_271(T110_, T111_, 2);
				}
				LA103_: ;
			}
			LA46_: ;
			add__ropes_159(&(*(*p).module).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], decl);
		}
		LA36_: ;
	}
	LA34_: ;
	{
		NIM_BOOL T114_;
		T114_ = (NIM_BOOL)0;
		T114_ = (((NI) 0) < (*p).withinLoop);
		if (!(T114_)) goto LA115_;
		T114_ = (value == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL));
		LA115_: ;
		if (!T114_) goto LA116_;
		resetLoc__cgen_10897(p, (&(*s).loc));
	}
	LA116_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, accessThreadLocalVar__cgen_416)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	{
		NIM_BOOL T3_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T7_;
		tyArray__dAmhZbEWrTM5xES2bTVweg T8_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T10_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
		T3_ = (NIM_BOOL)0;
		T3_ = emulatedThreadVars__cgen_419((*(*(*p).module).g).config);
		if (!(T3_)) goto LA4_;
		T3_ = !((((*p).flags &((NU8)1<<((NU)(((tyEnum_TCProcFlag__Iv1wQAvkoMCW3v9cTnZWvJw) 1))&7U)))!=0));
		LA4_: ;
		if (!T3_) goto LA5_;
		(*p).flags |= ((NU8)1)<<((((tyEnum_TCProcFlag__Iv1wQAvkoMCW3v9cTnZWvJw) 1)) & 7);
		(*(*p).module).flags |= ((NU8)1)<<((((tyEnum_CodegenFlag__vPx29bHhk9a7V50u1UO0rM4w) 1)) & 7);
		T7_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T7_ = procSec__cgendata_274(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
		nimZeroMem((void*)T8_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		T9_ = NIM_NIL;
		T9_ = percent___cgen_11197(T8_, 0);
		add__ropes_159(T7_, T9_);
		T10_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T10_ = procSec__cgendata_274(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 1));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 27);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_397));
		T11_ = NIM_NIL;
		T11_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_398));
		cgFormatValue__cgen_147((&res), T11_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_312));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA14_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA14_: ;
		T16_ = NIM_NIL;
		T16_ = rope__ropes_109(res);
		add__ropes_159(T10_, T16_);
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genTraverseProcForGlobal__cgen_7776)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T2_;
	tyObject_TTraversalClosure__4DrvOBPCF3NL9akdOcxiJCw c;
	tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* sLoc;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* header;
	tyArray__ts9cf9blICas1QWmw89bglZ7w T9_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T10_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* generatedProc;
	tyArray__InO6xIOhXMnkCXPnEYWwWg T11_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T12_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T13_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T14_;
	tyArray__ts9cf9blICas1QWmw89bglZ7w T15_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = t__cgen_85((*s).loc);
	T2_ = NIM_NIL;
	T2_ = genTypeInfoV1__cgen_6798(m, T1_, info);
	(void)(T2_);
	nimZeroMem((void*)(&c), sizeof(tyObject_TTraversalClosure__4DrvOBPCF3NL9akdOcxiJCw));
	p = newProc__cgendata_278(((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL), m);
	sLoc = rdLoc__cgen_435((*s).loc);
	result = getTempName__cgen_428(m);
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 26))&63U)))!=0);
		if (!(T5_)) goto LA6_;
		T5_ = emulatedThreadVars__cgen_419((*(*m).g).config);
		LA6_: ;
		if (!T5_) goto LA7_;
		accessThreadLocalVar__cgen_416(p, s);
		sLoc = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_399), sLoc);
	}
	LA7_: ;
	c.visitorFrmt = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_153));
	c.p = p;
	nimZeroMem((void*)T9_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
	T9_[0] = result;
	header = percent___cgen_7788(T9_, 1);
	T10_ = NIM_NIL;
	T10_ = t__cgen_85((*s).loc);
	genTraverseProc__cgen_7366(c, sLoc, T10_);
	nimZeroMem((void*)T11_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
	T11_[0] = header;
	T12_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T12_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
	T11_[1] = (*T12_);
	T13_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T13_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 1));
	T11_[2] = (*T13_);
	T14_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T14_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	T11_[3] = (*T14_);
	generatedProc = percent___cgen_7794(T11_, 4);
	nimZeroMem((void*)T15_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
	T15_[0] = header;
	T16_ = NIM_NIL;
	T16_ = percent___cgen_7800(T15_, 1);
	add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 8))- 0], T16_);
	add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 11))- 0], generatedProc);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getTraverseProc__cgen_13183)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* v) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T7_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((960 &((NU16)1<<((NU)((*(*(*(*p).module).g).config).selectedGC)&15U)))!=0);
		if (!(T4_)) goto LA5_;
		T4_ = !((((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 42))&63U)))!=0));
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA6_;
		T7_ = NIM_NIL;
		T7_ = t__cgen_85((*v).loc);
		T3_ = containsGarbageCollectedRef__types_612(T7_);
		LA6_: ;
		if (!T3_) goto LA8_;
		result = genTraverseProcForGlobal__cgen_7776((*p).module, v, (*v).info);
	}
	LA8_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, registerTraverseProc__cgen_13195)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* v, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* traverseProc) {
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T5_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
		if (!(((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 26))&63U)))!=0)) goto LA3_;
		T5_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T5_ = procSec__cgendata_274((*(*p).module).preInitProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 1));
		res = rawNewString(((NI) 80));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA8_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA8_: ;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_6));
		T10_ = NIM_NIL;
		T10_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_400));
		cgFormatValue__cgen_147((&res), T10_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		cgFormatValue__cgen_147((&res), traverseProc);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA13_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA13_: ;
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA17_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA17_: ;
		T19_ = NIM_NIL;
		T19_ = rope__ropes_109(res);
		add__ropes_159(T5_, T19_);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T21_;
		NimStringDesc* res_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T35_;
		T21_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T21_ = procSec__cgendata_274((*(*p).module).preInitProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 1));
		res_2 = rawNewString(((NI) 80));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA24_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA24_: ;
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_6));
		T26_ = NIM_NIL;
		T26_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_401));
		cgFormatValue__cgen_147((&res_2), T26_);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		cgFormatValue__cgen_147((&res_2), traverseProc);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA29_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA29_: ;
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA33_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA33_: ;
		T35_ = NIM_NIL;
		T35_ = rope__ropes_109(res_2);
		add__ropes_159(T21_, T35_);
	}
	LA1_: ;
}
static N_INLINE(NIM_BOOL, isAssignedImmediately__cgen_13245)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1))) goto LA3_;
		result = NIM_FALSE;
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T6_;
		NIM_BOOL T7_;
		NIM_BOOL T8_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T12_;
		T6_ = (NIM_BOOL)0;
		T7_ = (NIM_BOOL)0;
		T8_ = (NIM_BOOL)0;
		T8_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32));
		if (!(T8_)) goto LA9_;
		T8_ = !(((*n)._kind_6.sons->data[((NI) 0)] == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
		LA9_: ;
		T7_ = T8_;
		if (!(T7_)) goto LA10_;
		T7_ = !(((*(*n)._kind_6.sons->data[((NI) 0)]).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		LA10_: ;
		T6_ = T7_;
		if (!(T6_)) goto LA11_;
		T12_ = NIM_NIL;
		T12_ = skipTypes__ast_3723((*(*n)._kind_6.sons->data[((NI) 0)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
		T6_ = ((*T12_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25));
		LA11_: ;
		if (!T6_) goto LA13_;
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = isInvalidReturnType__cgen_1353(conf, (*(*n)._kind_6.sons->data[((NI) 0)]).typ, NIM_TRUE);
			if (!T17_) goto LA18_;
			result = NIM_FALSE;
		}
		goto LA15_;
		LA18_: ;
		{
			result = NIM_TRUE;
		}
		LA15_: ;
	}
	goto LA1_;
	LA13_: ;
	{
		NIM_BOOL T22_;
		T22_ = (NIM_BOOL)0;
		T22_ = isInvalidReturnType__cgen_1353(conf, (*n).typ, NIM_FALSE);
		if (!T22_) goto LA23_;
		result = NIM_FALSE;
	}
	goto LA1_;
	LA23_: ;
	{
		result = NIM_TRUE;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, freshLineInfo__cgen_365)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*p).lastLineInfo.line == info.line));
		if (T3_) goto LA4_;
		T3_ = !(((*p).lastLineInfo.fileIndex == info.fileIndex));
		LA4_: ;
		if (!T3_) goto LA5_;
		(*p).lastLineInfo.line = info.line;
		(*p).lastLineInfo.fileIndex = info.fileIndex;
		result = NIM_TRUE;
	}
	LA5_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genLineDir__cgen_369)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t) {
	NI line;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T11_;
	line = safeLineNm__cgen_337((*t).info);
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T5_;
		tyArray__dAmhZbEWrTM5xES2bTVweg T6_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
		NimStringDesc* T8_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 28))&63U)))!=0)) goto LA3_;
		T5_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T5_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		nimZeroMem((void*)T6_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		T7_ = NIM_NIL;
		T7_ = percent___cgen_377(T6_, 0);
		T8_ = NIM_NIL;
		T8_ = sourceLine__msgs_1111((*(*(*p).module).g).config, (*t).info);
		T9_ = NIM_NIL;
		T9_ = amp___ropes_140(T7_, T8_);
		T10_ = NIM_NIL;
		T10_ = amp___ropes_140(T9_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		add__ropes_159(T5_, T10_);
	}
	LA3_: ;
	T11_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T11_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	genCLineDir__cgen_357(T11_, (*t).info, (*(*(*p).module).g).config);
	{
		NIM_BOOL T14_;
		NIM_BOOL T15_;
		NIM_BOOL T17_;
		T14_ = (NIM_BOOL)0;
		T15_ = (NIM_BOOL)0;
		T15_ = ((655360 & (*p).options) == 655360);
		if (!(T15_)) goto LA16_;
		T17_ = (NIM_BOOL)0;
		T17_ = ((*p).prc == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
		if (T17_) goto LA18_;
		T17_ = !((((*(*p).prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 11))&63U)))!=0));
		LA18_: ;
		T15_ = T17_;
		LA16_: ;
		T14_ = T15_;
		if (!(T14_)) goto LA19_;
		T14_ = !(((*t).info.fileIndex == ((NI32) -1)));
		LA19_: ;
		if (!T14_) goto LA20_;
		{
			NIM_BOOL T24_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T27_;
			NimStringDesc* res;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T28_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T33_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T34_;
			T24_ = (NIM_BOOL)0;
			T24_ = freshLineInfo__cgen_365(p, (*t).info);
			if (!T24_) goto LA25_;
			T27_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T27_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res = rawNewString(((NI) 80));
			res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_402));
			cgFormatValue__cgen_154((&res), ((NI64) (line)));
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			T28_ = NIM_NIL;
			T28_ = quotedFilename__msgs_1473((*(*(*p).module).g).config, (*t).info);
			cgFormatValue__cgen_147((&res), T28_);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA31_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA31_: ;
			T33_ = NIM_NIL;
			T33_ = rope__ropes_109(res);
			T34_ = NIM_NIL;
			T34_ = indentLine__cgen_286(p, T33_);
			add__ropes_159(T27_, T34_);
		}
		LA25_: ;
	}
	LA20_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, withTmpIfNeeded__cgen_12116)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a, NIM_BOOL needsTmp, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* Result) {
	(*Result).k = 0;
	(*Result).storage = 0;
	(*Result).flags = 0;
	unsureAsgnRef((void**)&(*Result).lode, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).r, NIM_NIL);
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		NI64 T9_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T5_ = needsTmp;
		if (!(T5_)) goto LA6_;
		T5_ = !(((*a.lode).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		LA6_: ;
		T4_ = T5_;
		if (!(T4_)) goto LA7_;
		T4_ = ((48 &((NU16)1<<((NU)((*(*(*(*p).module).g).config).selectedGC)&15U)))!=0);
		LA7_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA8_;
		T9_ = (NI64)0;
		T9_ = getSize__types_3388((*(*(*p).module).g).config, (*a.lode).typ);
		T3_ = (T9_ < IL64(1024));
		LA8_: ;
		if (!T3_) goto LA10_;
		getTemp__cgen_7373(p, (*a.lode).typ, Result, NIM_FALSE);
		genAssignment__cgen_10403(p, (*Result), a, 0);
	}
	goto LA1_;
	LA10_: ;
	{
		genericAssign((void*)Result, (void*)(&a), (&NTItloc__CAJV4zTUpZwr0j6Wy8FiFw_));
	}
	LA1_: ;
}
static N_INLINE(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genArgStringToCString__cgen_12133)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL needsTmp) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	NimStringDesc* res;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw T2_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T3_;
	result = NIM_NIL;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, (*n)._kind_6.sons->data[((NI) 0)], (&a));
	res = rawNewString(((NI) 80));
	T1_ = NIM_NIL;
	T1_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_403));
	cgFormatValue__cgen_147((&res), T1_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
	nimZeroMem((void*)(&T2_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	withTmpIfNeeded__cgen_12116(p, a, needsTmp, (&T2_));
	T3_ = NIM_NIL;
	T3_ = rdLoc__cgen_435(T2_);
	cgFormatValue__cgen_147((&res), T3_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
	result = rope__ropes_109(res);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genArgNoParam__cgen_12216)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL needsTmp) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	result = NIM_NIL;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 71))) goto LA3_;
		result = genArgStringToCString__cgen_12133(p, n, needsTmp);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw T6_;
		initLocExprSingleUse__cgen_11552(p, n, (&a));
		nimZeroMem((void*)(&T6_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		withTmpIfNeeded__cgen_12116(p, a, needsTmp, (&T6_));
		result = rdLoc__cgen_435(T6_);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genOtherArg__cgen_11541)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri, NI i, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	{
		NI T3_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* paramType;
		T3_ = (NI)0;
		T3_ = len__ast_3990(typ);
		if (!(i < T3_)) goto LA4_;
		paramType = (*(*typ).n)._kind_6.sons->data[i];
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = isCompileTimeOnly__types_3592((*paramType).typ);
			if (!T8_) goto LA9_;
			result = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
		}
		goto LA6_;
		LA9_: ;
		{
			NIM_BOOL T12_;
			T12_ = (NIM_BOOL)0;
			T12_ = ((*(*typ).sons->data[i]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23));
			if (!(T12_)) goto LA13_;
			T12_ = ((*(*ri)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64));
			LA13_: ;
			if (!T12_) goto LA14_;
			result = genArgNoParam__cgen_12216(p, (*(*ri)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)], NIM_FALSE);
		}
		goto LA6_;
		LA14_: ;
		{
			result = genArgNoParam__cgen_12216(p, (*ri)._kind_6.sons->data[i], NIM_FALSE);
		}
		LA6_: ;
	}
	goto LA1_;
	LA4_: ;
	{
		{
			if (!!((((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 0))&63U)))!=0))) goto LA20_;
			liMessage__msgs_1128((*(*(*p).module).g).config, (*ri).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_404), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_405, NIM_FALSE);
			result = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
		}
		goto LA18_;
		LA20_: ;
		{
			result = genArgNoParam__cgen_12216(p, (*ri)._kind_6.sons->data[i], NIM_FALSE);
		}
		LA18_: ;
	}
	LA1_: ;
	return result;
}
static N_INLINE(NIM_BOOL, notYetAlive__cgen_13121)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* r;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	r = getRoot__trees_390(n);
	T1_ = (NIM_BOOL)0;
	T1_ = !((r == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
	if (!(T1_)) goto LA2_;
	T1_ = ((*r).loc.lode == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, skipAddr__ast_5230)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64))) goto LA3_;
		result = (*n)._kind_6.sons->data[((NI) 0)];
	}
	goto LA1_;
	LA3_: ;
	{
		result = n;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInactiveDestructorCall__cgen_13133)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NIM_BOOL T3_;
	NI T4_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T8_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T3_ = (NIM_BOOL)0;
	T4_ = (NI)0;
	T4_ = len__ast_3155(e);
	T3_ = (T4_ == ((NI) 2));
	if (!(T3_)) goto LA5_;
	T3_ = ((*(*e)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
	LA5_: ;
	T2_ = T3_;
	if (!(T2_)) goto LA6_;
	T2_ = eqStrings((*(*(*(*e)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).s, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_414));
	LA6_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA7_;
	T8_ = NIM_NIL;
	T8_ = skipAddr__ast_5230((*e)._kind_6.sons->data[((NI) 1)]);
	T1_ = notYetAlive__cgen_13121(T8_);
	LA7_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, skipTrivialIndirections__cgen_12243)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = n;
	{
		while (1) {
			switch ((*result).kind) {
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 47):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 66):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 67):
			{
				result = (*result)._kind_6.sons->data[((NI) 0)];
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59):
			{
				result = (*result)._kind_6.sons->data[((NI) 1)];
			}
			break;
			default:
			{
				goto LA1;
			}
			break;
			}
		}
	} LA1: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, potentialAlias__cgen_12227)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySequence__IeU9azYSNIK3V9b36Ir6NZcw* potentialWrites) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** p;
		NI i;
		NI L;
		NI T2_;
		p = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
		i = ((NI) 0);
		T2_ = (potentialWrites ? potentialWrites->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				p = &potentialWrites->data[i];
				{
					NIM_BOOL T7_;
					tyEnum_AliasKind__vyyqF5f609aD8pvRKZixr4w T8_;
					tyEnum_AliasKind__vyyqF5f609aD8pvRKZixr4w T10_;
					T7_ = (NIM_BOOL)0;
					T8_ = (tyEnum_AliasKind__vyyqF5f609aD8pvRKZixr4w)0;
					T8_ = aliases__dfa_808((*p), n);
					T7_ = !((T8_ == ((tyEnum_AliasKind__vyyqF5f609aD8pvRKZixr4w) 1)));
					if (T7_) goto LA9_;
					T10_ = (tyEnum_AliasKind__vyyqF5f609aD8pvRKZixr4w)0;
					T10_ = aliases__dfa_808(n, (*p));
					T7_ = !((T10_ == ((tyEnum_AliasKind__vyyqF5f609aD8pvRKZixr4w) 1)));
					LA9_: ;
					if (!T7_) goto LA11_;
					result = NIM_TRUE;
					goto BeforeRet_;
				}
				LA11_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, getPotentialReads__cgen_12289)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySequence__IeU9azYSNIK3V9b36Ir6NZcw** result) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 76):
	{
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		NI T3_;
		unsureAsgnRef((void**) (&(*result)), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) incrSeqV3((TGenericSeq*)((*result)), (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_)));
		T3_ = (*result)->Sup.len++;
		asgnRef((void**) (&(*result)->data[T3_]), n);
	}
	break;
	default:
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* s;
			s = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA8;
						i = i_2;
						s = (*n)._kind_6.sons->data[i];
						getPotentialReads__cgen_12289(s, result);
						i_2 += ((NI) 1);
					} LA8: ;
				}
			}
		}
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, getPotentialWrites__cgen_12248)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL mutate, tySequence__IeU9azYSNIK3V9b36Ir6NZcw** result) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 76):
	{
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		{
			NI T7_;
			if (!mutate) goto LA5_;
			unsureAsgnRef((void**) (&(*result)), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) incrSeqV3((TGenericSeq*)((*result)), (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_)));
			T7_ = (*result)->Sup.len++;
			asgnRef((void**) (&(*result)->data[T7_]), n);
		}
		LA5_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 73):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 74):
	{
		getPotentialWrites__cgen_12248((*n)._kind_6.sons->data[((NI) 0)], NIM_TRUE, result);
		getPotentialWrites__cgen_12248((*n)._kind_6.sons->data[((NI) 1)], mutate, result);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64):
	{
		getPotentialWrites__cgen_12248((*n)._kind_6.sons->data[((NI) 0)], NIM_TRUE, result);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 46):
	{
		getPotentialWrites__cgen_12248((*n)._kind_6.sons->data[((NI) 0)], mutate, result);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
	{
		tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag T12_;
		T12_ = (tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag)0;
		T12_ = getMagic__trees_137(n);
		switch (T12_) {
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 40):
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 41):
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 29):
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 30):
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 131):
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 132):
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 133):
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 16):
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 32):
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 33):
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 150):
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 151):
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 159):
		{
			getPotentialWrites__cgen_12248((*n)._kind_6.sons->data[((NI) 1)], NIM_TRUE, result);
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_3155(n);
				i_2 = ((NI) 2);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA16;
						i = i_2;
						getPotentialWrites__cgen_12248((*n)._kind_6.sons->data[i], mutate, result);
						i_2 += ((NI) 1);
					} LA16: ;
				}
			}
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 142):
		{
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = len__ast_3155(n);
				i_4 = ((NI) 1);
				{
					while (1) {
						if (!(i_4 < colontmp__2)) goto LA20;
						i_3 = i_4;
						getPotentialWrites__cgen_12248((*n)._kind_6.sons->data[i_3], NIM_TRUE, result);
						i_4 += ((NI) 1);
					} LA20: ;
				}
			}
		}
		break;
		default:
		{
			{
				NI i_5;
				NI colontmp__3;
				NI i_6;
				i_5 = (NI)0;
				colontmp__3 = (NI)0;
				colontmp__3 = len__ast_3155(n);
				i_6 = ((NI) 1);
				{
					while (1) {
						if (!(i_6 < colontmp__3)) goto LA24;
						i_5 = i_6;
						getPotentialWrites__cgen_12248((*n)._kind_6.sons->data[i_5], mutate, result);
						i_6 += ((NI) 1);
					} LA24: ;
				}
			}
		}
		break;
		}
	}
	break;
	default:
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* s;
			s = NIM_NIL;
			{
				NI i_7;
				NI colontmp__4;
				NI i_8;
				i_7 = (NI)0;
				colontmp__4 = (NI)0;
				colontmp__4 = safeLen__ast_3148(n);
				i_8 = ((NI) 0);
				{
					while (1) {
						if (!(i_8 < colontmp__4)) goto LA29;
						i_7 = i_8;
						s = (*n)._kind_6.sons->data[i_7];
						getPotentialWrites__cgen_12248(s, mutate, result);
						i_8 += ((NI) 1);
					} LA29: ;
				}
			}
		}
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, raiseInstr__cgen_424)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	{
		NI L;
		NI T5_;
		if (!((*(*(*(*p).module).g).config).exc == ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 3))) goto LA3_;
		T5_ = ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0);
		L = T5_;
		{
			NimStringDesc* res;
			if (!(L == ((NI) 0))) goto LA8_;
			(*p).flags |= ((NU8)1)<<((((tyEnum_TCProcFlag__Iv1wQAvkoMCW3v9cTnZWvJw) 0)) & 7);
			res = rawNewString(((NI) 80));
			res = resizeString(res, 16);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_424));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA12_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA12_: ;
			result = rope__ropes_109(res);
		}
		goto LA6_;
		LA8_: ;
		{
			NimStringDesc* res_2;
			res_2 = rawNewString(((NI) 80));
			res_2 = resizeString(res_2, 7);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_425));
			cgFormatValue__cgen_154((&res_2), ((NI64) ((*p).nestedTryStmts->data[(NI)(L - ((NI) 1))].Field2)));
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_426));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA17_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA17_: ;
			result = rope__ropes_109(res_2);
		}
		LA6_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		result = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, intLiteral__cgen_17773)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ i) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	NI64 T1_;
	result = NIM_NIL;
	T1_ = (NI64)0;
	T1_ = toInt64__int495056_88(i);
	result = intLiteral__cgen_11536(T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, rdCharLoc__cgen_10377)(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	result = rdLoc__cgen_435(a);
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T3_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T4_;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T7_;
		T3_ = NIM_NIL;
		T3_ = t__cgen_85(a);
		T4_ = NIM_NIL;
		T4_ = skipTypes__ast_3723(T3_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_430);
		if (!((*T4_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2))) goto LA5_;
		nimZeroMem((void*)T7_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T7_[0] = result;
		result = percent___cgen_10384(T7_, 1);
	}
	LA5_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genBoundsCheck__cgen_11820)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw arr, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ty;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1_;
	T1_ = NIM_NIL;
	T1_ = t__cgen_85(arr);
	ty = skipTypes__ast_3723(T1_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_183);
	switch ((*ty).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48):
	{
		{
			NIM_BOOL T5_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T8_;
			NimStringDesc* res;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T21_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T27_;
			T5_ = (NIM_BOOL)0;
			T5_ = reifiedOpenArray__cgen_11825(arr.lode);
			if (!T5_) goto LA6_;
			T8_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T8_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res = rawNewString(((NI) 80));
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
			T9_ = NIM_NIL;
			T9_ = rdLoc__cgen_435(b);
			cgFormatValue__cgen_147((&res), T9_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_416));
			T10_ = NIM_NIL;
			T10_ = rdLoc__cgen_435(a);
			cgFormatValue__cgen_147((&res), T10_);
			res = resizeString(res, 11);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_417));
			T11_ = NIM_NIL;
			T11_ = rdLoc__cgen_435(a);
			cgFormatValue__cgen_147((&res), T11_);
			res = resizeString(res, 8);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_418));
			T12_ = NIM_NIL;
			T12_ = rdLoc__cgen_435(a);
			cgFormatValue__cgen_147((&res), T12_);
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_419));
			T13_ = NIM_NIL;
			T13_ = rdLoc__cgen_435(arr);
			cgFormatValue__cgen_147((&res), T13_);
			res = resizeString(res, 11);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_420));
			T14_ = NIM_NIL;
			T14_ = rdLoc__cgen_435(b);
			cgFormatValue__cgen_147((&res), T14_);
			res = resizeString(res, 8);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_418));
			T15_ = NIM_NIL;
			T15_ = rdLoc__cgen_435(b);
			cgFormatValue__cgen_147((&res), T15_);
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_419));
			T16_ = NIM_NIL;
			T16_ = rdLoc__cgen_435(arr);
			cgFormatValue__cgen_147((&res), T16_);
			res = resizeString(res, 11);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_421));
			T17_ = NIM_NIL;
			T17_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_422));
			cgFormatValue__cgen_147((&res), T17_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T18_ = NIM_NIL;
			T18_ = rdLoc__cgen_435(a);
			cgFormatValue__cgen_147((&res), T18_);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			T19_ = NIM_NIL;
			T19_ = rdLoc__cgen_435(b);
			cgFormatValue__cgen_147((&res), T19_);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			T20_ = NIM_NIL;
			T20_ = rdLoc__cgen_435(arr);
			cgFormatValue__cgen_147((&res), T20_);
			res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_423));
			T21_ = NIM_NIL;
			T21_ = raiseInstr__cgen_424(p);
			cgFormatValue__cgen_147((&res), T21_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA24_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA24_: ;
			T26_ = NIM_NIL;
			T26_ = rope__ropes_109(res);
			T27_ = NIM_NIL;
			T27_ = indentLine__cgen_286(p, T26_);
			add__ropes_159(T8_, T27_);
		}
		goto LA3_;
		LA6_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T29_;
			NimStringDesc* res_2;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T30_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T31_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T32_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T33_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T34_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T35_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T36_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T37_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T39_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T40_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T41_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T42_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T47_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T48_;
			T29_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T29_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_2 = rawNewString(((NI) 80));
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
			T30_ = NIM_NIL;
			T30_ = rdLoc__cgen_435(b);
			cgFormatValue__cgen_147((&res_2), T30_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_416));
			T31_ = NIM_NIL;
			T31_ = rdLoc__cgen_435(a);
			cgFormatValue__cgen_147((&res_2), T31_);
			res_2 = resizeString(res_2, 11);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_417));
			T32_ = NIM_NIL;
			T32_ = rdLoc__cgen_435(a);
			cgFormatValue__cgen_147((&res_2), T32_);
			res_2 = resizeString(res_2, 8);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_418));
			T33_ = NIM_NIL;
			T33_ = rdLoc__cgen_435(a);
			cgFormatValue__cgen_147((&res_2), T33_);
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_419));
			T34_ = NIM_NIL;
			T34_ = rdLoc__cgen_435(arr);
			cgFormatValue__cgen_147((&res_2), T34_);
			res_2 = resizeString(res_2, 9);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_427));
			T35_ = NIM_NIL;
			T35_ = rdLoc__cgen_435(b);
			cgFormatValue__cgen_147((&res_2), T35_);
			res_2 = resizeString(res_2, 8);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_418));
			T36_ = NIM_NIL;
			T36_ = rdLoc__cgen_435(b);
			cgFormatValue__cgen_147((&res_2), T36_);
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_419));
			T37_ = NIM_NIL;
			T37_ = rdLoc__cgen_435(arr);
			cgFormatValue__cgen_147((&res_2), T37_);
			res_2 = resizeString(res_2, 9);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_428));
			T38_ = NIM_NIL;
			T38_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_422));
			cgFormatValue__cgen_147((&res_2), T38_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T39_ = NIM_NIL;
			T39_ = rdLoc__cgen_435(a);
			cgFormatValue__cgen_147((&res_2), T39_);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			T40_ = NIM_NIL;
			T40_ = rdLoc__cgen_435(b);
			cgFormatValue__cgen_147((&res_2), T40_);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			T41_ = NIM_NIL;
			T41_ = rdLoc__cgen_435(arr);
			cgFormatValue__cgen_147((&res_2), T41_);
			res_2 = resizeString(res_2, 8);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_429));
			T42_ = NIM_NIL;
			T42_ = raiseInstr__cgen_424(p);
			cgFormatValue__cgen_147((&res_2), T42_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA45_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA45_: ;
			T47_ = NIM_NIL;
			T47_ = rope__ropes_109(res_2);
			T48_ = NIM_NIL;
			T48_ = indentLine__cgen_286(p, T47_);
			add__ropes_159(T29_, T48_);
		}
		LA3_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* first;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T50_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T51_;
		NimStringDesc* res_3;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T52_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T53_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T54_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T55_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T56_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T57_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T58_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T59_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T60_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T61_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T62_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T63_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T64_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T65_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T70_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T71_;
		T50_ = firstOrd__types_1406((*(*(*p).module).g).config, ty);
		first = intLiteral__cgen_17773(T50_);
		T51_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T51_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_3 = rawNewString(((NI) 80));
		res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
		T52_ = NIM_NIL;
		T52_ = rdCharLoc__cgen_10377(b);
		cgFormatValue__cgen_147((&res_3), T52_);
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_416));
		T53_ = NIM_NIL;
		T53_ = rdCharLoc__cgen_10377(a);
		cgFormatValue__cgen_147((&res_3), T53_);
		res_3 = resizeString(res_3, 11);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_417));
		T54_ = NIM_NIL;
		T54_ = rdCharLoc__cgen_10377(b);
		cgFormatValue__cgen_147((&res_3), T54_);
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_416));
		T55_ = NIM_NIL;
		T55_ = rdCharLoc__cgen_10377(a);
		cgFormatValue__cgen_147((&res_3), T55_);
		res_3 = resizeString(res_3, 9);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_431));
		T56_ = NIM_NIL;
		T56_ = rdCharLoc__cgen_10377(a);
		cgFormatValue__cgen_147((&res_3), T56_);
		res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_163));
		cgFormatValue__cgen_147((&res_3), first);
		res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_432));
		T57_ = NIM_NIL;
		T57_ = rdCharLoc__cgen_10377(a);
		cgFormatValue__cgen_147((&res_3), T57_);
		res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_433));
		T58_ = lastOrd__types_1532((*(*(*p).module).g).config, ty);
		T59_ = NIM_NIL;
		T59_ = intLiteral__cgen_17773(T58_);
		cgFormatValue__cgen_147((&res_3), T59_);
		res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_432));
		T60_ = NIM_NIL;
		T60_ = rdCharLoc__cgen_10377(b);
		cgFormatValue__cgen_147((&res_3), T60_);
		res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_163));
		cgFormatValue__cgen_147((&res_3), first);
		res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_432));
		T61_ = NIM_NIL;
		T61_ = rdCharLoc__cgen_10377(b);
		cgFormatValue__cgen_147((&res_3), T61_);
		res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_433));
		T62_ = lastOrd__types_1532((*(*(*p).module).g).config, ty);
		T63_ = NIM_NIL;
		T63_ = intLiteral__cgen_17773(T62_);
		cgFormatValue__cgen_147((&res_3), T63_);
		res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_434));
		T64_ = NIM_NIL;
		T64_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_435));
		cgFormatValue__cgen_147((&res_3), T64_);
		res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_436));
		T65_ = NIM_NIL;
		T65_ = raiseInstr__cgen_424(p);
		cgFormatValue__cgen_147((&res_3), T65_);
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA68_;
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA68_: ;
		T70_ = NIM_NIL;
		T70_ = rope__ropes_109(res_3);
		T71_ = NIM_NIL;
		T71_ = indentLine__cgen_286(p, T70_);
		add__ropes_159(T51_, T71_);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T73_;
		NimStringDesc* res_4;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T74_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T75_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T76_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T77_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T78_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T79_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T80_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T81_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T82_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T83_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T84_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T85_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T86_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T91_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T92_;
		T73_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T73_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_4 = rawNewString(((NI) 80));
		res_4 = resizeString(res_4, 4);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
		T74_ = NIM_NIL;
		T74_ = rdLoc__cgen_435(b);
		cgFormatValue__cgen_147((&res_4), T74_);
		res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_416));
		T75_ = NIM_NIL;
		T75_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res_4), T75_);
		res_4 = resizeString(res_4, 11);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_417));
		T76_ = NIM_NIL;
		T76_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res_4), T76_);
		res_4 = resizeString(res_4, 8);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_418));
		T77_ = NIM_NIL;
		T77_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res_4), T77_);
		res_4 = resizeString(res_4, 4);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_419));
		T78_ = NIM_NIL;
		T78_ = lenExpr__cgen_458(p, arr);
		cgFormatValue__cgen_147((&res_4), T78_);
		res_4 = resizeString(res_4, 4);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_432));
		T79_ = NIM_NIL;
		T79_ = rdLoc__cgen_435(b);
		cgFormatValue__cgen_147((&res_4), T79_);
		res_4 = resizeString(res_4, 8);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_418));
		T80_ = NIM_NIL;
		T80_ = rdLoc__cgen_435(b);
		cgFormatValue__cgen_147((&res_4), T80_);
		res_4 = resizeString(res_4, 4);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_419));
		T81_ = NIM_NIL;
		T81_ = lenExpr__cgen_458(p, arr);
		cgFormatValue__cgen_147((&res_4), T81_);
		res_4 = resizeString(res_4, 4);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_434));
		T82_ = NIM_NIL;
		T82_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_422));
		cgFormatValue__cgen_147((&res_4), T82_);
		res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T83_ = NIM_NIL;
		T83_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res_4), T83_);
		res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		T84_ = NIM_NIL;
		T84_ = rdLoc__cgen_435(b);
		cgFormatValue__cgen_147((&res_4), T84_);
		res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		T85_ = NIM_NIL;
		T85_ = lenExpr__cgen_458(p, arr);
		cgFormatValue__cgen_147((&res_4), T85_);
		res_4 = resizeString(res_4, 3);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_437));
		T86_ = NIM_NIL;
		T86_ = raiseInstr__cgen_424(p);
		cgFormatValue__cgen_147((&res_4), T86_);
		res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA89_;
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA89_: ;
		T91_ = NIM_NIL;
		T91_ = rope__ropes_109(res_4);
		T92_ = NIM_NIL;
		T92_ = indentLine__cgen_286(p, T91_);
		add__ropes_159(T73_, T92_);
	}
	break;
	default:
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genOpenArraySlice__cgen_11842)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* q, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formalType, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* destType, NIM_BOOL prepareForMutation, tyTuple__xIPPgKI3s9a9c79aFyHPbe0cg* Result) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw c;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ty;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T18_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* dest;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* lengthExpr;
	tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T19_;
	unsureAsgnRef((void**)&(*Result).Field0, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).Field1, NIM_NIL);
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&c), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, (*q)._kind_6.sons->data[((NI) 1)], (&a));
	initLocExpr__cgen_11548(p, (*q)._kind_6.sons->data[((NI) 2)], (&b));
	initLocExpr__cgen_11548(p, (*q)._kind_6.sons->data[((NI) 3)], (&c));
	{
		if (!(((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 4))&31U)))!=0)) goto LA3_;
		genBoundsCheck__cgen_11820(p, a, b, c);
	}
	LA3_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T9_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
		if (!prepareForMutation) goto LA7_;
		T9_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T9_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res = rawNewString(((NI) 80));
		T10_ = NIM_NIL;
		T10_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_276));
		cgFormatValue__cgen_147((&res), T10_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T11_ = NIM_NIL;
		T11_ = byRefLoc__cgen_10353(p, a);
		cgFormatValue__cgen_147((&res), T11_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA14_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA14_: ;
		T16_ = NIM_NIL;
		T16_ = rope__ropes_109(res);
		T17_ = NIM_NIL;
		T17_ = indentLine__cgen_286(p, T16_);
		add__ropes_159(T9_, T17_);
	}
	LA7_: ;
	T18_ = NIM_NIL;
	T18_ = t__cgen_85(a);
	ty = skipTypes__ast_3723(T18_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_438);
	dest = getTypeDesc__cgen_6662((*p).module, destType, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
	nimZeroMem((void*)T19_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
	T19_[0] = rdLoc__cgen_435(c);
	T19_[1] = rdLoc__cgen_435(b);
	lengthExpr = percent___cgen_11878(T19_, 2);
	switch ((*ty).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
	{
		NI64 first;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T21_;
		T21_ = firstOrd__types_1406((*(*(*p).module).g).config, ty);
		first = toInt64__int495056_88(T21_);
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* colontmp_;
			tyArray__FKvM4FDhljtt88k8FkGthA T26_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* colontmp__2;
			if (!(first == IL64(0))) goto LA24_;
			nimZeroMem((void*)T26_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
			T26_[0] = rdLoc__cgen_435(a);
			T26_[1] = rdLoc__cgen_435(b);
			T26_[2] = dest;
			colontmp_ = percent___cgen_11885(T26_, 3);
			colontmp__2 = lengthExpr;
			unsureAsgnRef((void**) (&(*Result).Field0), colontmp_);
			unsureAsgnRef((void**) (&(*Result).Field1), colontmp__2);
		}
		goto LA22_;
		LA24_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* colontmp__3;
			tyArray__InO6xIOhXMnkCXPnEYWwWg T28_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* colontmp__4;
			nimZeroMem((void*)T28_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
			T28_[0] = rdLoc__cgen_435(a);
			T28_[1] = rdLoc__cgen_435(b);
			T28_[2] = intLiteral__cgen_11536(first);
			T28_[3] = dest;
			colontmp__3 = percent___cgen_11890(T28_, 4);
			colontmp__4 = lengthExpr;
			unsureAsgnRef((void**) (&(*Result).Field0), colontmp__3);
			unsureAsgnRef((void**) (&(*Result).Field1), colontmp__4);
		}
		LA22_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48):
	{
		{
			NIM_BOOL T32_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* colontmp__5;
			tyArray__FKvM4FDhljtt88k8FkGthA T35_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* colontmp__6;
			T32_ = (NIM_BOOL)0;
			T32_ = reifiedOpenArray__cgen_11825((*q)._kind_6.sons->data[((NI) 1)]);
			if (!T32_) goto LA33_;
			nimZeroMem((void*)T35_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
			T35_[0] = rdLoc__cgen_435(a);
			T35_[1] = rdLoc__cgen_435(b);
			T35_[2] = dest;
			colontmp__5 = percent___cgen_11896(T35_, 3);
			colontmp__6 = lengthExpr;
			unsureAsgnRef((void**) (&(*Result).Field0), colontmp__5);
			unsureAsgnRef((void**) (&(*Result).Field1), colontmp__6);
		}
		goto LA30_;
		LA33_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* colontmp__7;
			tyArray__FKvM4FDhljtt88k8FkGthA T37_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* colontmp__8;
			nimZeroMem((void*)T37_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
			T37_[0] = rdLoc__cgen_435(a);
			T37_[1] = rdLoc__cgen_435(b);
			T37_[2] = dest;
			colontmp__7 = percent___cgen_11901(T37_, 3);
			colontmp__8 = lengthExpr;
			unsureAsgnRef((void**) (&(*Result).Field0), colontmp__7);
			unsureAsgnRef((void**) (&(*Result).Field1), colontmp__8);
		}
		LA30_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 49):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29):
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* colontmp__9;
		tyArray__FKvM4FDhljtt88k8FkGthA T39_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* colontmp__10;
		nimZeroMem((void*)T39_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
		T39_[0] = rdLoc__cgen_435(a);
		T39_[1] = rdLoc__cgen_435(b);
		T39_[2] = dest;
		colontmp__9 = percent___cgen_11901(T39_, 3);
		colontmp__10 = lengthExpr;
		unsureAsgnRef((void**) (&(*Result).Field0), colontmp__9);
		unsureAsgnRef((void**) (&(*Result).Field1), colontmp__10);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* atyp;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T41_;
		T41_ = NIM_NIL;
		T41_ = t__cgen_85(a);
		atyp = skipTypes__ast_3723(T41_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
		{
			NIM_BOOL T44_;
			NIM_BOOL T45_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T46_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T51_;
			NimStringDesc* res_2;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T52_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T53_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T58_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T59_;
			T44_ = (NIM_BOOL)0;
			T45_ = (NIM_BOOL)0;
			T46_ = NIM_NIL;
			T46_ = skipTypes__ast_3723(formalType, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
			T45_ = ((*T46_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23));
			if (!(T45_)) goto LA47_;
			T45_ = ((*atyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28));
			LA47_: ;
			T44_ = T45_;
			if (!(T44_)) goto LA48_;
			T44_ = (((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0);
			LA48_: ;
			if (!T44_) goto LA49_;
			T51_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T51_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_2 = rawNewString(((NI) 80));
			T52_ = NIM_NIL;
			T52_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_276));
			cgFormatValue__cgen_147((&res_2), T52_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T53_ = NIM_NIL;
			T53_ = byRefLoc__cgen_10353(p, a);
			cgFormatValue__cgen_147((&res_2), T53_);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA56_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA56_: ;
			T58_ = NIM_NIL;
			T58_ = rope__ropes_109(res_2);
			T59_ = NIM_NIL;
			T59_ = indentLine__cgen_286(p, T58_);
			add__ropes_159(T51_, T59_);
		}
		LA49_: ;
		{
			NIM_BOOL T62_;
			NIM_BOOL T64_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* colontmp__11;
			tyArray__XSZGJHCjWme3CUmFzckT3g T68_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T69_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T70_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* colontmp__12;
			T62_ = (NIM_BOOL)0;
			T62_ = ((*atyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23));
			if (!(T62_)) goto LA63_;
			T64_ = (NIM_BOOL)0;
			T64_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
			if (T64_) goto LA65_;
			T64_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
			LA65_: ;
			T62_ = !(T64_);
			LA63_: ;
			if (!T62_) goto LA66_;
			nimZeroMem((void*)T68_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
			T68_[0] = rdLoc__cgen_435(a);
			T68_[1] = rdLoc__cgen_435(b);
			T68_[2] = dataField__cgen_479(p);
			T68_[3] = dest;
			T69_ = NIM_NIL;
			T69_ = rdLoc__cgen_435(a);
			T70_ = NIM_NIL;
			T70_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_90), T69_);
			T68_[4] = dataFieldAccessor__cgen_471(p, T70_);
			colontmp__11 = percent___cgen_11948(T68_, 5);
			colontmp__12 = lengthExpr;
			unsureAsgnRef((void**) (&(*Result).Field0), colontmp__11);
			unsureAsgnRef((void**) (&(*Result).Field1), colontmp__12);
		}
		goto LA60_;
		LA66_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* colontmp__13;
			tyArray__XSZGJHCjWme3CUmFzckT3g T72_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T73_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* colontmp__14;
			nimZeroMem((void*)T72_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
			T72_[0] = rdLoc__cgen_435(a);
			T72_[1] = rdLoc__cgen_435(b);
			T72_[2] = dataField__cgen_479(p);
			T72_[3] = dest;
			T73_ = NIM_NIL;
			T73_ = rdLoc__cgen_435(a);
			T72_[4] = dataFieldAccessor__cgen_471(p, T73_);
			colontmp__13 = percent___cgen_11953(T72_, 5);
			colontmp__14 = lengthExpr;
			unsureAsgnRef((void**) (&(*Result).Field0), colontmp__13);
			unsureAsgnRef((void**) (&(*Result).Field1), colontmp__14);
		}
		LA60_: ;
	}
	break;
	default:
	{
		NimStringDesc* T75_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T76_;
		NimStringDesc* T77_;
		T75_ = NIM_NIL;
		T76_ = NIM_NIL;
		T76_ = t__cgen_85(a);
		T77_ = NIM_NIL;
		T77_ = typeToString__types_50(T76_, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
		T75_ = rawNewString((T77_ ? T77_->Sup.len : 0) + 14);
appendString(T75_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_439));
appendString(T75_, T77_);
		internalErrorImpl__msgs_1441((*(*(*p).module).g).config, unknownLineInfo__lineinfos_284, T75_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_440);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, openArrayLoc__cgen_11967)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formalType, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* q;
	NIM_BOOL skipped;
	result = NIM_NIL;
	q = skipConv__types_3661(n);
	skipped = NIM_FALSE;
	{
		while (1) {
			NIM_BOOL T3_;
			NI T5_;
			T3_ = (NIM_BOOL)0;
			T3_ = ((*q).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126));
			if (!(T3_)) goto LA4_;
			T5_ = (NI)0;
			T5_ = len__ast_3155(q);
			T3_ = (((NI) 0) < T5_);
			LA4_: ;
			if (!T3_) goto LA2;
			skipped = NIM_TRUE;
			q = lastSon__ast_4833(q);
		} LA2: ;
	}
	{
		tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag T8_;
		tyTuple__xIPPgKI3s9a9c79aFyHPbe0cg T24_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* x;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* y;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
		T8_ = (tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag)0;
		T8_ = getMagic__trees_137(q);
		if (!(T8_ == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 126))) goto LA9_;
		{
			if (!skipped) goto LA13_;
			q = skipConv__types_3661(n);
			{
				while (1) {
					NIM_BOOL T17_;
					NI T19_;
					T17_ = (NIM_BOOL)0;
					T17_ = ((*q).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126));
					if (!(T17_)) goto LA18_;
					T19_ = (NI)0;
					T19_ = len__ast_3155(q);
					T17_ = (((NI) 0) < T19_);
					LA18_: ;
					if (!T17_) goto LA16;
					{
						NI i;
						NI colontmp_;
						NI T21_;
						NI i_2;
						i = (NI)0;
						colontmp_ = (NI)0;
						T21_ = (NI)0;
						T21_ = len__ast_3155(q);
						colontmp_ = (NI)(T21_ - ((NI) 1));
						i_2 = ((NI) 0);
						{
							while (1) {
								if (!(i_2 < colontmp_)) goto LA23;
								i = i_2;
								genStmts__cgen_11522(p, (*q)._kind_6.sons->data[i]);
								i_2 += ((NI) 1);
							} LA23: ;
						}
					}
					q = lastSon__ast_4833(q);
				} LA16: ;
			}
		}
		LA13_: ;
		nimZeroMem((void*)(&T24_), sizeof(tyTuple__xIPPgKI3s9a9c79aFyHPbe0cg));
		genOpenArraySlice__cgen_11842(p, q, formalType, (*(*n).typ).sons->data[((NI) 0)], NIM_FALSE, (&T24_));
		x = NIM_NIL;
		x = T24_.Field0;
		y = NIM_NIL;
		y = T24_.Field1;
		T25_ = NIM_NIL;
		T25_ = amp___ropes_140(x, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		result = amp___ropes_128(T25_, y);
	}
	goto LA6_;
	LA9_: ;
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T27_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T33_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T34_;
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		T27_ = NIM_NIL;
		{
			if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58))) goto LA30_;
			T27_ = (*n)._kind_6.sons->data[((NI) 1)];
		}
		goto LA28_;
		LA30_: ;
		{
			T27_ = n;
		}
		LA28_: ;
		initLocExpr__cgen_11548(p, T27_, (&a));
		T33_ = NIM_NIL;
		T33_ = t__cgen_85(a);
		T34_ = NIM_NIL;
		T34_ = skipTypes__ast_3723(T33_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_441);
		switch ((*T34_).kind) {
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27):
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48):
		{
			{
				NIM_BOOL T38_;
				T38_ = (NIM_BOOL)0;
				T38_ = reifiedOpenArray__cgen_11825(n);
				if (!T38_) goto LA39_;
				{
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T43_;
					tyArray__ts9cf9blICas1QWmw89bglZ7w T46_;
					T43_ = NIM_NIL;
					T43_ = t__cgen_85(a);
					if (!((*T43_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*T43_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47))) goto LA44_;
					nimZeroMem((void*)T46_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
					T46_[0] = rdLoc__cgen_435(a);
					result = percent___cgen_12024(T46_, 1);
				}
				goto LA41_;
				LA44_: ;
				{
					tyArray__ts9cf9blICas1QWmw89bglZ7w T48_;
					nimZeroMem((void*)T48_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
					T48_[0] = rdLoc__cgen_435(a);
					result = percent___cgen_12029(T48_, 1);
				}
				LA41_: ;
			}
			goto LA36_;
			LA39_: ;
			{
				tyArray__ts9cf9blICas1QWmw89bglZ7w T50_;
				nimZeroMem((void*)T50_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
				T50_[0] = rdLoc__cgen_435(a);
				result = percent___cgen_12034(T50_, 1);
			}
			LA36_: ;
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ntyp;
			ntyp = skipTypes__ast_3723((*n).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
			{
				NIM_BOOL T54_;
				NIM_BOOL T55_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T56_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T61_;
				NimStringDesc* res;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T62_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T63_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T68_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T69_;
				T54_ = (NIM_BOOL)0;
				T55_ = (NIM_BOOL)0;
				T56_ = NIM_NIL;
				T56_ = skipTypes__ast_3723(formalType, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
				T55_ = ((*T56_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23));
				if (!(T55_)) goto LA57_;
				T55_ = ((*ntyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28));
				LA57_: ;
				T54_ = T55_;
				if (!(T54_)) goto LA58_;
				T54_ = (((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0);
				LA58_: ;
				if (!T54_) goto LA59_;
				T61_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T61_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res = rawNewString(((NI) 80));
				T62_ = NIM_NIL;
				T62_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_276));
				cgFormatValue__cgen_147((&res), T62_);
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
				T63_ = NIM_NIL;
				T63_ = byRefLoc__cgen_10353(p, a);
				cgFormatValue__cgen_147((&res), T63_);
				res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA66_;
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA66_: ;
				T68_ = NIM_NIL;
				T68_ = rope__ropes_109(res);
				T69_ = NIM_NIL;
				T69_ = indentLine__cgen_286(p, T68_);
				add__ropes_159(T61_, T69_);
			}
			LA59_: ;
			{
				NIM_BOOL T72_;
				NIM_BOOL T74_;
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw t;
				tyArray__ts9cf9blICas1QWmw89bglZ7w T78_;
				tyArray__InO6xIOhXMnkCXPnEYWwWg T79_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T80_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T81_;
				T72_ = (NIM_BOOL)0;
				T72_ = ((*ntyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23));
				if (!(T72_)) goto LA73_;
				T74_ = (NIM_BOOL)0;
				T74_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
				if (T74_) goto LA75_;
				T74_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
				LA75_: ;
				T72_ = !(T74_);
				LA73_: ;
				if (!T72_) goto LA76_;
				nimZeroMem((void*)(&t), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				nimZeroMem((void*)T78_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
				T78_[0] = rdLoc__cgen_435(a);
				t.r = percent___cgen_442(T78_, 1);
				nimZeroMem((void*)T79_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
				T79_[0] = rdLoc__cgen_435(a);
				T79_[1] = lenExpr__cgen_458(p, t);
				T79_[2] = dataField__cgen_479(p);
				T80_ = NIM_NIL;
				T80_ = rdLoc__cgen_435(a);
				T81_ = NIM_NIL;
				T81_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_90), T80_);
				T79_[3] = dataFieldAccessor__cgen_471(p, T81_);
				result = percent___cgen_12082(T79_, 4);
			}
			goto LA70_;
			LA76_: ;
			{
				tyArray__InO6xIOhXMnkCXPnEYWwWg T83_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T84_;
				nimZeroMem((void*)T83_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
				T83_[0] = rdLoc__cgen_435(a);
				T83_[1] = lenExpr__cgen_458(p, a);
				T83_[2] = dataField__cgen_479(p);
				T84_ = NIM_NIL;
				T84_ = rdLoc__cgen_435(a);
				T83_[3] = dataFieldAccessor__cgen_471(p, T84_);
				result = percent___cgen_12087(T83_, 4);
			}
			LA70_: ;
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
		{
			tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T86_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T87_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T88_;
			nimZeroMem((void*)T86_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
			T86_[0] = rdLoc__cgen_435(a);
			T87_ = NIM_NIL;
			T87_ = t__cgen_85(a);
			T88_ = lengthOrd__types_1723((*(*(*p).module).g).config, T87_);
			T86_[1] = rope__cgen_6948(T88_);
			result = percent___cgen_12092(T86_, 2);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21):
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22):
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T90_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T91_;
			T90_ = NIM_NIL;
			T90_ = t__cgen_85(a);
			T91_ = NIM_NIL;
			T91_ = lastSon__ast_3731(T90_);
			switch ((*T91_).kind) {
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
			{
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw t_2;
				tyArray__ts9cf9blICas1QWmw89bglZ7w T93_;
				tyArray__InO6xIOhXMnkCXPnEYWwWg T94_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T95_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T96_;
				nimZeroMem((void*)(&t_2), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				nimZeroMem((void*)T93_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
				T93_[0] = rdLoc__cgen_435(a);
				t_2.r = percent___cgen_442(T93_, 1);
				nimZeroMem((void*)T94_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
				T94_[0] = rdLoc__cgen_435(a);
				T94_[1] = lenExpr__cgen_458(p, t_2);
				T94_[2] = dataField__cgen_479(p);
				T95_ = NIM_NIL;
				T95_ = rdLoc__cgen_435(a);
				T96_ = NIM_NIL;
				T96_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_90), T95_);
				T94_[3] = dataFieldAccessor__cgen_471(p, T96_);
				result = percent___cgen_12082(T94_, 4);
			}
			break;
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
			{
				tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T98_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T99_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T100_;
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T101_;
				nimZeroMem((void*)T98_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
				T98_[0] = rdLoc__cgen_435(a);
				T99_ = NIM_NIL;
				T99_ = t__cgen_85(a);
				T100_ = NIM_NIL;
				T100_ = lastSon__ast_3731(T99_);
				T101_ = lengthOrd__types_1723((*(*(*p).module).g).config, T100_);
				T98_[1] = rope__cgen_6948(T101_);
				result = percent___cgen_12092(T98_, 2);
			}
			break;
			default:
			{
				NimStringDesc* T103_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T104_;
				NimStringDesc* T105_;
				T103_ = NIM_NIL;
				T104_ = NIM_NIL;
				T104_ = t__cgen_85(a);
				T105_ = NIM_NIL;
				T105_ = typeToString__types_50(T104_, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
				T103_ = rawNewString((T105_ ? T105_->Sup.len : 0) + 14);
appendString(T103_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_439));
appendString(T103_, T105_);
				internalErrorImpl__msgs_1441((*(*(*p).module).g).config, unknownLineInfo__lineinfos_284, T103_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_442);
			}
			break;
			}
		}
		break;
		default:
		{
			NimStringDesc* T107_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T108_;
			NimStringDesc* T109_;
			T107_ = NIM_NIL;
			T108_ = NIM_NIL;
			T108_ = t__cgen_85(a);
			T109_ = NIM_NIL;
			T109_ = typeToString__types_50(T108_, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
			T107_ = rawNewString((T109_ ? T109_->Sup.len : 0) + 14);
appendString(T107_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_439));
appendString(T107_, T109_);
			internalErrorImpl__msgs_1441((*(*(*p).module).g).config, unknownLineInfo__lineinfos_284, T107_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_443);
		}
		break;
		}
	}
	LA6_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, literalsNeedsTmp__cgen_12129)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* Result) {
	(*Result).k = 0;
	(*Result).storage = 0;
	(*Result).flags = 0;
	unsureAsgnRef((void**)&(*Result).lode, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).r, NIM_NIL);
	getTemp__cgen_7373(p, (*a.lode).typ, Result, NIM_FALSE);
	genAssignment__cgen_10403(p, (*Result), a, 0);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genArg__cgen_12149)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* param, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* call, NIM_BOOL needsTmp) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	result = NIM_NIL;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 71))) goto LA3_;
		result = genArgStringToCString__cgen_12133(p, n, needsTmp);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T6_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n_2;
		T6_ = NIM_NIL;
		T6_ = skipTypes__ast_3723((*param).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_266);
		if (!((*T6_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27) || (*T6_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48))) goto LA7_;
		{
			if (!!(((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64)))) goto LA11_;
			n_2 = n;
		}
		goto LA9_;
		LA11_: ;
		{
			n_2 = (*n)._kind_6.sons->data[((NI) 0)];
		}
		LA9_: ;
		result = openArrayLoc__cgen_11967(p, (*param).typ, n_2);
	}
	goto LA1_;
	LA7_: ;
	{
		NIM_BOOL T15_;
		T15_ = (NIM_BOOL)0;
		T15_ = ccgIntroducedPtr__ccgutils_153((*(*(*p).module).g).config, param, (*(*(*call)._kind_6.sons->data[((NI) 0)]).typ).sons->data[((NI) 0)]);
		if (!T15_) goto LA16_;
		initLocExpr__cgen_11548(p, n, (&a));
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw T22_;
			if (!((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA20_;
			nimZeroMem((void*)(&T22_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			literalsNeedsTmp__cgen_12129(p, a, (&T22_));
			result = addrLoc__cgen_10337((*(*(*p).module).g).config, T22_);
		}
		goto LA18_;
		LA20_: ;
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw T24_;
			nimZeroMem((void*)(&T24_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			withTmpIfNeeded__cgen_12116(p, a, needsTmp, (&T24_));
			result = addrLoc__cgen_10337((*(*(*p).module).g).config, T24_);
		}
		LA18_: ;
	}
	goto LA1_;
	LA16_: ;
	{
		NIM_BOOL T26_;
		NIM_BOOL T27_;
		NIM_BOOL T28_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* callee;
		T26_ = (NIM_BOOL)0;
		T27_ = (NIM_BOOL)0;
		T28_ = (NIM_BOOL)0;
		T28_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
		if (T28_) goto LA29_;
		T28_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
		LA29_: ;
		T27_ = T28_;
		if (!(T27_)) goto LA30_;
		T27_ = ((*(*param).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23));
		LA30_: ;
		T26_ = T27_;
		if (!(T26_)) goto LA31_;
		T26_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64));
		LA31_: ;
		if (!T26_) goto LA32_;
		initLocExprSingleUse__cgen_11552(p, (*n)._kind_6.sons->data[((NI) 0)], (&a));
		callee = (*call)._kind_6.sons->data[((NI) 0)];
		{
			NIM_BOOL T36_;
			NIM_BOOL T37_;
			T36_ = (NIM_BOOL)0;
			T37_ = (NIM_BOOL)0;
			T37_ = ((*callee).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
			if (!(T37_)) goto LA38_;
			T37_ = ((IL64(4295229504) & (*(*callee)._kind_4.sym).flags) == 64);
			LA38_: ;
			T36_ = T37_;
			if (!(T36_)) goto LA39_;
			T36_ = !(((72 & (*(*callee)._kind_4.sym).loc.flags) == 0));
			LA39_: ;
			if (!T36_) goto LA40_;
			result = addrLoc__cgen_10337((*(*(*p).module).g).config, a);
		}
		goto LA34_;
		LA40_: ;
		{
			result = rdLoc__cgen_435(a);
		}
		LA34_: ;
	}
	goto LA1_;
	LA32_: ;
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw T44_;
		initLocExprSingleUse__cgen_11552(p, n, (&a));
		nimZeroMem((void*)(&T44_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		withTmpIfNeeded__cgen_12116(p, a, needsTmp, (&T44_));
		result = rdLoc__cgen_435(T44_);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genParams__cgen_12297)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tySequence__shxop0zPIs5Ec3k71aCLuQ* needTmp;
	NI T1_;
	tySequence__IeU9azYSNIK3V9b36Ir6NZcw* potentialWrites;
	result = NIM_NIL;
	T1_ = (NI)0;
	T1_ = len__ast_3155(ri);
	needTmp = newSeq__cgen_12306(((NI) ((NI)(T1_ - ((NI) 1)))));
	potentialWrites = NIM_NIL;
	{
		NI i;
		NI colontmp_;
		NI T3_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T3_ = (NI)0;
		T3_ = len__ast_3155(ri);
		colontmp_ = (NI)(T3_ - ((NI) 1));
		res = colontmp_;
		{
			while (1) {
				if (!(((NI) 1) <= res)) goto LA5;
				i = res;
				{
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T8_;
					T8_ = NIM_NIL;
					T8_ = skipTrivialIndirections__cgen_12243((*ri)._kind_6.sons->data[i]);
					if (!((*T8_).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA9_;
					needTmp->data[(NI)(i - ((NI) 1))] = potentialAlias__cgen_12227((*ri)._kind_6.sons->data[i], potentialWrites);
				}
				goto LA6_;
				LA9_: ;
				{
					tySequence__IeU9azYSNIK3V9b36Ir6NZcw* potentialReads;
					potentialReads = NIM_NIL;
					getPotentialReads__cgen_12289((*ri)._kind_6.sons->data[i], (&potentialReads));
					{
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** n;
						NI i_2;
						NI L;
						NI T13_;
						n = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
						i_2 = ((NI) 0);
						T13_ = (potentialReads ? potentialReads->Sup.len : 0);
						L = T13_;
						{
							while (1) {
								if (!(i_2 < L)) goto LA15;
								n = &potentialReads->data[i_2];
								{
									if (!!(needTmp->data[(NI)(i - ((NI) 1))])) goto LA18_;
									needTmp->data[(NI)(i - ((NI) 1))] = potentialAlias__cgen_12227((*n), potentialWrites);
								}
								LA18_: ;
								i_2 += ((NI) 1);
							} LA15: ;
						}
					}
					getPotentialWrites__cgen_12248((*ri)._kind_6.sons->data[i], NIM_FALSE, (&potentialWrites));
				}
				LA6_: ;
				{
					if (!((*(*ri)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64) || (*(*ri)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63))) goto LA22_;
					needTmp->data[(NI)(i - ((NI) 1))] = NIM_FALSE;
				}
				LA22_: ;
				res -= ((NI) 1);
			} LA5: ;
		}
	}
	{
		NI i_3;
		NI colontmp__2;
		NI i_4;
		i_3 = (NI)0;
		colontmp__2 = (NI)0;
		colontmp__2 = len__ast_3155(ri);
		i_4 = ((NI) 1);
		{
			while (1) {
				if (!(i_4 < colontmp__2)) goto LA26;
				i_3 = i_4;
				{
					NI T29_;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* paramType;
					T29_ = (NI)0;
					T29_ = len__ast_3990(typ);
					if (!(i_3 < T29_)) goto LA30_;
					paramType = (*(*typ).n)._kind_6.sons->data[i_3];
					{
						NIM_BOOL T34_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T43_;
						T34_ = (NIM_BOOL)0;
						T34_ = isCompileTimeOnly__types_3592((*paramType).typ);
						if (!!(T34_)) goto LA35_;
						{
							tyArray__dAmhZbEWrTM5xES2bTVweg T41_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T42_;
							if (!!((result == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA39_;
							nimZeroMem((void*)T41_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
							T42_ = NIM_NIL;
							T42_ = percent___cgen_3546(T41_, 0);
							add__ropes_159(&result, T42_);
						}
						LA39_: ;
						T43_ = NIM_NIL;
						T43_ = genArg__cgen_12149(p, (*ri)._kind_6.sons->data[i_3], (*paramType)._kind_4.sym, ri, needTmp->data[(NI)(i_3 - ((NI) 1))]);
						add__ropes_159(&result, T43_);
					}
					LA35_: ;
				}
				goto LA27_;
				LA30_: ;
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T51_;
					{
						tyArray__dAmhZbEWrTM5xES2bTVweg T49_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T50_;
						if (!!((result == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA47_;
						nimZeroMem((void*)T49_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
						T50_ = NIM_NIL;
						T50_ = percent___cgen_3546(T49_, 0);
						add__ropes_159(&result, T50_);
					}
					LA47_: ;
					T51_ = NIM_NIL;
					T51_ = genArgNoParam__cgen_12216(p, (*ri)._kind_6.sons->data[i_3], needTmp->data[(NI)(i_3 - ((NI) 1))]);
					add__ropes_159(&result, T51_);
				}
				LA27_: ;
				i_4 += ((NI) 1);
			} LA26: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canRaiseDisp__cgen_11588)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		if (!(T3_)) goto LA4_;
		T3_ = !(((IL64(8796093284416) & (*(*n)._kind_4.sym).flags) == 0));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = NIM_FALSE;
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T8_;
		NIM_BOOL T10_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T12_;
		T8_ = (NIM_BOOL)0;
		T8_ = (((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 46))&63U)))!=0);
		if (T8_) goto LA9_;
		T10_ = (NIM_BOOL)0;
		T10_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		if (!(T10_)) goto LA11_;
		T12_ = NIM_NIL;
		T12_ = getModule__astalgo_216((*n)._kind_4.sym);
		T10_ = (((*T12_).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 15))&63U)))!=0);
		LA11_: ;
		T8_ = T10_;
		LA9_: ;
		if (!T8_) goto LA13_;
		result = canRaise__ast_5100(n);
	}
	goto LA1_;
	LA13_: ;
	{
		result = canRaiseConservative__ast_5088(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, locationEscapes__cgen_11622)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* le, NIM_BOOL inTryStmt) {
	NIM_BOOL result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
{	result = (NIM_BOOL)0;
	n = le;
	{
		while (1) {
			switch ((*n).kind) {
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
			{
				{
					if (!!(((*(*n)._kind_4.sym).owner == (*p).prc))) goto LA6_;
					result = NIM_TRUE;
					goto BeforeRet_;
				}
				goto LA4_;
				LA6_: ;
				{
					NIM_BOOL T9_;
					T9_ = (NIM_BOOL)0;
					T9_ = inTryStmt;
					if (!(T9_)) goto LA10_;
					T9_ = (((*(*n)._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 44))&63U)))!=0);
					LA10_: ;
					if (!T9_) goto LA11_;
					result = NIM_TRUE;
					goto BeforeRet_;
				}
				goto LA4_;
				LA11_: ;
				LA4_: ;
				result = NIM_FALSE;
				goto BeforeRet_;
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 67):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 66):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 46):
			{
				n = (*n)._kind_6.sons->data[((NI) 0)];
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 60):
			{
				n = (*n)._kind_6.sons->data[((NI) 1)];
			}
			break;
			default:
			{
				result = NIM_TRUE;
				goto BeforeRet_;
			}
			break;
			}
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, preventNrvo__cgen_11616)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* dest, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* le, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		if (!!((le == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA3_;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(ri);
			i_2 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* r;
					if (!(i_2 < colontmp_)) goto LA7;
					i = i_2;
					r = (*ri)._kind_6.sons->data[i];
					{
						tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA T10_;
						T10_ = (tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA)0;
						T10_ = isPartOf__aliases_129(le, r);
						if (!!((T10_ == ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 0)))) goto LA11_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA11_: ;
					i_2 += ((NI) 1);
				} LA7: ;
			}
		}
		{
			NIM_BOOL T15_;
			NI T17_;
			NimStringDesc* T20_;
			T15_ = (NIM_BOOL)0;
			T15_ = canRaise__ast_5100((*ri)._kind_6.sons->data[((NI) 0)]);
			if (!(T15_)) goto LA16_;
			T17_ = ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0);
			T15_ = locationEscapes__cgen_11622(p, le, (((NI) 0) < T17_));
			LA16_: ;
			if (!T15_) goto LA18_;
			T20_ = NIM_NIL;
			T20_ = dollar___renderer_2116(le);
			liMessage__msgs_1128((*(*(*p).module).g).config, (*le).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 58), T20_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_444, NIM_FALSE);
		}
		LA18_: ;
	}
	LA3_: ;
	{
		NIM_BOOL T23_;
		T23_ = (NIM_BOOL)0;
		T23_ = !((dest == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
		if (!(T23_)) goto LA24_;
		T23_ = !((dest == le));
		LA24_: ;
		if (!T23_) goto LA25_;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3155(ri);
			i_4 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* r_2;
					if (!(i_4 < colontmp__2)) goto LA29;
					i_3 = i_4;
					r_2 = (*ri)._kind_6.sons->data[i_3];
					{
						tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA T32_;
						T32_ = (tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA)0;
						T32_ = isPartOf__aliases_129(dest, r_2);
						if (!!((T32_ == ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 0)))) goto LA33_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA33_: ;
					i_4 += ((NI) 1);
				} LA29: ;
			}
		}
	}
	LA25_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, hasNoInit__cgen_11683)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* call) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*(*call)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
	if (!(T1_)) goto LA2_;
	T1_ = (((*(*(*call)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 14))&63U)))!=0);
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, addComma__cgen_12464)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	{
		if (!(r == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA3_;
		result = r;
	}
	goto LA1_;
	LA3_: ;
	{
		tyArray__dAmhZbEWrTM5xES2bTVweg T6_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
		nimZeroMem((void*)T6_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		T7_ = NIM_NIL;
		T7_ = percent___cgen_3546(T6_, 0);
		result = amp___ropes_128(r, T7_);
	}
	LA1_: ;
	return result;
}
static N_INLINE(tyTuple__T1RBf8m9axj9bvJRlYejkpkQ*, X5BX5D___cgen_14870)(tyTuple__T1RBf8m9axj9bvJRlYejkpkQ* s, NI sLen_0, NI i) {
	tyTuple__T1RBf8m9axj9bvJRlYejkpkQ* result;
	result = (tyTuple__T1RBf8m9axj9bvJRlYejkpkQ*)0;
	result = (&s[(NI)(sLen_0 - i)]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, raiseExit__cgen_11546)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p) {
	{
		if (!!((((*p).flags &((NU8)1<<((NU)(((tyEnum_TCProcFlag__Iv1wQAvkoMCW3v9cTnZWvJw) 6))&7U)))!=0))) goto LA3_;
		(*p).flags |= ((NU8)1)<<((((tyEnum_TCProcFlag__Iv1wQAvkoMCW3v9cTnZWvJw) 4)) & 7);
		{
			NI T7_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T10_;
			NimStringDesc* res;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
			T7_ = ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0);
			if (!(T7_ == ((NI) 0))) goto LA8_;
			(*p).flags |= ((NU8)1)<<((((tyEnum_TCProcFlag__Iv1wQAvkoMCW3v9cTnZWvJw) 0)) & 7);
			T10_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T10_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res = rawNewString(((NI) 80));
			res = resizeString(res, 44);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_445));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA13_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA13_: ;
			T15_ = NIM_NIL;
			T15_ = rope__ropes_109(res);
			T16_ = NIM_NIL;
			T16_ = indentLine__cgen_286(p, T15_);
			add__ropes_159(T10_, T16_);
		}
		goto LA5_;
		LA8_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T18_;
			NimStringDesc* res_2;
			tyTuple__T1RBf8m9axj9bvJRlYejkpkQ* T19_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
			T18_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T18_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_2 = rawNewString(((NI) 80));
			res_2 = resizeString(res_2, 35);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_446));
			T19_ = (tyTuple__T1RBf8m9axj9bvJRlYejkpkQ*)0;
			T19_ = X5BX5D___cgen_14870(((*p).nestedTryStmts) ? ((*p).nestedTryStmts->data) : NIM_NIL, ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0), ((NI) 1));
			cgFormatValue__cgen_154((&res_2), ((NI64) ((*T19_).Field2)));
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_426));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA22_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA22_: ;
			T24_ = NIM_NIL;
			T24_ = rope__ropes_109(res_2);
			T25_ = NIM_NIL;
			T25_ = indentLine__cgen_286(p, T24_);
			add__ropes_159(T18_, T25_);
		}
		LA5_: ;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isHarmlessStore__cgen_11696)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, NIM_BOOL canRaise, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw d) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((3 &((NU16)1<<((NU)(d.k)&15U)))!=0);
		if (T3_) goto LA4_;
		T3_ = !(canRaise);
		LA4_: ;
		if (!T3_) goto LA5_;
		result = NIM_TRUE;
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = (d.k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 2));
		if (!(T8_)) goto LA9_;
		T8_ = ((*p).withinTryWithExcept == ((NI) 0));
		LA9_: ;
		if (!T8_) goto LA10_;
		result = NIM_TRUE;
	}
	goto LA1_;
	LA10_: ;
	{
		result = NIM_FALSE;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genClosureCall__cgen_12459)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* le, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw op;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* pl;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* rawProc;
	NIM_BOOL canRaise;
	NIM_BOOL T1_;
	nimZeroMem((void*)(&op), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, (*ri)._kind_6.sons->data[((NI) 0)], (&op));
	typ = skipTypes__ast_3723((*(*ri)._kind_6.sons->data[((NI) 0)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_155);
	pl = genParams__cgen_12297(p, ri, typ);
	rawProc = getClosureType__cgen_6675((*p).module, typ, ((tyEnum_TClosureTypeKind__9cCFzcVQ9cBXhFbAj307bqVg) 0));
	T1_ = (NIM_BOOL)0;
	T1_ = ((*(*(*(*p).module).g).config).exc == ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 3));
	if (!(T1_)) goto LA2_;
	T1_ = canRaiseDisp__cgen_11588(p, (*ri)._kind_6.sons->data[((NI) 0)]);
	LA2_: ;
	canRaise = T1_;
	{
		if (!!(((*typ).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA5_;
		{
			NIM_BOOL T9_;
			T9_ = (NIM_BOOL)0;
			T9_ = isInvalidReturnType__cgen_1353((*(*(*p).module).g).config, typ, NIM_TRUE);
			if (!T9_) goto LA10_;
			{
				NI T14_;
				tyArray__dAmhZbEWrTM5xES2bTVweg T17_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
				T14_ = (NI)0;
				T14_ = len__ast_3155(ri);
				if (!(((NI) 1) < T14_)) goto LA15_;
				nimZeroMem((void*)T17_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
				T18_ = NIM_NIL;
				T18_ = percent___cgen_3546(T17_, 0);
				add__ropes_159(&pl, T18_);
			}
			LA15_: ;
			{
				NIM_BOOL T21_;
				NIM_BOOL T23_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T36_;
				T21_ = (NIM_BOOL)0;
				T21_ = ((3 &((NU16)1<<((NU)((*d).k)&15U)))!=0);
				if (T21_) goto LA22_;
				T23_ = (NIM_BOOL)0;
				T23_ = preventNrvo__cgen_11616(p, (*d).lode, le, ri);
				T21_ = !(T23_);
				LA22_: ;
				if (!T21_) goto LA24_;
				{
					if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA28_;
					getTemp__cgen_7373(p, (*typ).sons->data[((NI) 0)], d, NIM_TRUE);
				}
				goto LA26_;
				LA28_: ;
				{
					NIM_BOOL T31_;
					NIM_BOOL T33_;
					T31_ = (NIM_BOOL)0;
					T31_ = !(((2 &((NU16)1<<((NU)((*d).k)&15U)))!=0));
					if (!(T31_)) goto LA32_;
					T33_ = (NIM_BOOL)0;
					T33_ = hasNoInit__cgen_11683(ri);
					T31_ = !(T33_);
					LA32_: ;
					if (!T31_) goto LA34_;
				}
				goto LA26_;
				LA34_: ;
				LA26_: ;
				T36_ = NIM_NIL;
				T36_ = addrLoc__cgen_10337((*(*(*p).module).g).config, (*d));
				add__ropes_159(&pl, T36_);
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T41_;
					tyArray__InO6xIOhXMnkCXPnEYWwWg T42_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T43_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T44_;
					if (!(((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 15))&63U)))!=0)) goto LA39_;
					T41_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T41_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					nimZeroMem((void*)T42_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
					T42_[0] = rdLoc__cgen_435(op);
					T42_[1] = pl;
					T42_[2] = addComma__cgen_12464(pl);
					T42_[3] = rawProc;
					T43_ = NIM_NIL;
					T43_ = percent___cgen_12535(T42_, 4);
					T44_ = NIM_NIL;
					T44_ = indentLine__cgen_286(p, T43_);
					add__ropes_159(T41_, T44_);
				}
				goto LA37_;
				LA39_: ;
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T46_;
					tyArray__InO6xIOhXMnkCXPnEYWwWg T47_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T48_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T49_;
					T46_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T46_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					nimZeroMem((void*)T47_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
					T47_[0] = rdLoc__cgen_435(op);
					T47_[1] = pl;
					T47_[2] = addComma__cgen_12464(pl);
					T47_[3] = rawProc;
					T48_ = NIM_NIL;
					T48_ = percent___cgen_12540(T47_, 4);
					T49_ = NIM_NIL;
					T49_ = indentLine__cgen_286(p, T48_);
					add__ropes_159(T46_, T49_);
				}
				LA37_: ;
			}
			goto LA19_;
			LA24_: ;
			{
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tmp;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T51_;
				nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				getTemp__cgen_7373(p, (*typ).sons->data[((NI) 0)], (&tmp), NIM_TRUE);
				T51_ = NIM_NIL;
				T51_ = addrLoc__cgen_10337((*(*(*p).module).g).config, tmp);
				add__ropes_159(&pl, T51_);
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T56_;
					tyArray__InO6xIOhXMnkCXPnEYWwWg T57_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T58_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T59_;
					if (!(((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 15))&63U)))!=0)) goto LA54_;
					T56_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T56_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					nimZeroMem((void*)T57_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
					T57_[0] = rdLoc__cgen_435(op);
					T57_[1] = pl;
					T57_[2] = addComma__cgen_12464(pl);
					T57_[3] = rawProc;
					T58_ = NIM_NIL;
					T58_ = percent___cgen_12535(T57_, 4);
					T59_ = NIM_NIL;
					T59_ = indentLine__cgen_286(p, T58_);
					add__ropes_159(T56_, T59_);
				}
				goto LA52_;
				LA54_: ;
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T61_;
					tyArray__InO6xIOhXMnkCXPnEYWwWg T62_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T63_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T64_;
					T61_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T61_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					nimZeroMem((void*)T62_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
					T62_[0] = rdLoc__cgen_435(op);
					T62_[1] = pl;
					T62_[2] = addComma__cgen_12464(pl);
					T62_[3] = rawProc;
					T63_ = NIM_NIL;
					T63_ = percent___cgen_12540(T62_, 4);
					T64_ = NIM_NIL;
					T64_ = indentLine__cgen_286(p, T63_);
					add__ropes_159(T61_, T64_);
				}
				LA52_: ;
				{
					if (!canRaise) goto LA67_;
					raiseExit__cgen_11546(p);
				}
				LA67_: ;
				genAssignment__cgen_10403(p, (*d), tmp, 0);
			}
			LA19_: ;
		}
		goto LA7_;
		LA10_: ;
		{
			NIM_BOOL T70_;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw list;
			T70_ = (NIM_BOOL)0;
			T70_ = isHarmlessStore__cgen_11696(p, canRaise, (*d));
			if (!T70_) goto LA71_;
			{
				if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA75_;
				getTemp__cgen_7373(p, (*typ).sons->data[((NI) 0)], d, NIM_FALSE);
			}
			LA75_: ;
			nimZeroMem((void*)(&list), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLoc__cgen_66((&list), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 9), (*d).lode, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
			{
				tyArray__InO6xIOhXMnkCXPnEYWwWg T81_;
				if (!(((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 15))&63U)))!=0)) goto LA79_;
				nimZeroMem((void*)T81_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
				T81_[0] = rdLoc__cgen_435(op);
				T81_[1] = pl;
				T81_[2] = addComma__cgen_12464(pl);
				T81_[3] = rawProc;
				list.r = percent___cgen_12576(T81_, 4);
			}
			goto LA77_;
			LA79_: ;
			{
				tyArray__InO6xIOhXMnkCXPnEYWwWg T83_;
				nimZeroMem((void*)T83_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
				T83_[0] = rdLoc__cgen_435(op);
				T83_[1] = pl;
				T83_[2] = addComma__cgen_12464(pl);
				T83_[3] = rawProc;
				list.r = percent___cgen_12581(T83_, 4);
			}
			LA77_: ;
			genAssignment__cgen_10403(p, (*d), list, 0);
			{
				if (!canRaise) goto LA86_;
				raiseExit__cgen_11546(p);
			}
			LA86_: ;
		}
		goto LA7_;
		LA71_: ;
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tmp_2;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw list_2;
			nimZeroMem((void*)(&tmp_2), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			getTemp__cgen_7373(p, (*typ).sons->data[((NI) 0)], (&tmp_2), NIM_FALSE);
			nimZeroMem((void*)(&list_2), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLoc__cgen_66((&list_2), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 9), (*d).lode, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
			{
				tyArray__InO6xIOhXMnkCXPnEYWwWg T93_;
				if (!(((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 15))&63U)))!=0)) goto LA91_;
				nimZeroMem((void*)T93_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
				T93_[0] = rdLoc__cgen_435(op);
				T93_[1] = pl;
				T93_[2] = addComma__cgen_12464(pl);
				T93_[3] = rawProc;
				list_2.r = percent___cgen_12576(T93_, 4);
			}
			goto LA89_;
			LA91_: ;
			{
				tyArray__InO6xIOhXMnkCXPnEYWwWg T95_;
				nimZeroMem((void*)T95_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
				T95_[0] = rdLoc__cgen_435(op);
				T95_[1] = pl;
				T95_[2] = addComma__cgen_12464(pl);
				T95_[3] = rawProc;
				list_2.r = percent___cgen_12581(T95_, 4);
			}
			LA89_: ;
			genAssignment__cgen_10403(p, tmp_2, list_2, 0);
			{
				if (!canRaise) goto LA98_;
				raiseExit__cgen_11546(p);
			}
			LA98_: ;
			genAssignment__cgen_10403(p, (*d), tmp_2, 0);
		}
		LA7_: ;
	}
	goto LA3_;
	LA5_: ;
	{
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T105_;
			tyArray__InO6xIOhXMnkCXPnEYWwWg T106_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T107_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T108_;
			if (!(((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 15))&63U)))!=0)) goto LA103_;
			T105_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T105_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			nimZeroMem((void*)T106_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
			T106_[0] = rdLoc__cgen_435(op);
			T106_[1] = pl;
			T106_[2] = addComma__cgen_12464(pl);
			T106_[3] = rawProc;
			T107_ = NIM_NIL;
			T107_ = percent___cgen_12535(T106_, 4);
			T108_ = NIM_NIL;
			T108_ = indentLine__cgen_286(p, T107_);
			add__ropes_159(T105_, T108_);
		}
		goto LA101_;
		LA103_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T110_;
			tyArray__InO6xIOhXMnkCXPnEYWwWg T111_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T112_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T113_;
			T110_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T110_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			nimZeroMem((void*)T111_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
			T111_[0] = rdLoc__cgen_435(op);
			T111_[1] = pl;
			T111_[2] = addComma__cgen_12464(pl);
			T111_[3] = rawProc;
			T112_ = NIM_NIL;
			T112_ = percent___cgen_12540(T111_, 4);
			T113_ = NIM_NIL;
			T113_ = indentLine__cgen_286(p, T112_);
			add__ropes_159(T110_, T113_);
		}
		LA101_: ;
		{
			if (!canRaise) goto LA116_;
			raiseExit__cgen_11546(p);
		}
		LA116_: ;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, skipAddrDeref__cgen_12656)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* node) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
	NIM_BOOL isAddr;
{	result = NIM_NIL;
	n = node;
	isAddr = NIM_FALSE;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64):
	{
		n = (*n)._kind_6.sons->data[((NI) 0)];
		isAddr = NIM_TRUE;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 47):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65):
	{
		n = (*n)._kind_6.sons->data[((NI) 0)];
	}
	break;
	default:
	{
		result = n;
		goto BeforeRet_;
	}
	break;
	}
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 66))) goto LA6_;
		n = (*n)._kind_6.sons->data[((NI) 0)];
	}
	LA6_: ;
	{
		NIM_BOOL T10_;
		T10_ = (NIM_BOOL)0;
		T10_ = isAddr;
		if (!(T10_)) goto LA11_;
		T10_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 47) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65));
		LA11_: ;
		if (!T10_) goto LA12_;
		result = (*n)._kind_6.sons->data[((NI) 0)];
	}
	goto LA8_;
	LA12_: ;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64))) goto LA15_;
		result = (*n)._kind_6.sons->data[((NI) 0)];
	}
	goto LA8_;
	LA15_: ;
	{
		result = node;
	}
	LA8_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genThisArg__cgen_12678)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri, NI i, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri_2;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	result = NIM_NIL;
	{
		NI T3_;
		NimStringDesc* argX60gensym1457_;
		T3_ = (NI)0;
		T3_ = len__ast_3990(typ);
		if (!!((i < T3_))) goto LA4_;
		argX60gensym1457_ = toFileLineCol__msgs_625(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_451);
		internalErrorImpl__msgs_1441((*(*(*p).module).g).config, unknownLineInfo__lineinfos_284, argX60gensym1457_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_451);
	}
	LA4_: ;
	ri_2 = (*ri)._kind_6.sons->data[i];
	{
		while (1) {
			if (!((*ri_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 66))) goto LA7;
			ri_2 = (*ri_2)._kind_6.sons->data[((NI) 0)];
		} LA7: ;
	}
	t = skipTypes__ast_3723((*typ).sons->data[i], TM__9bddtAaa9cYLwzzzlT9aJ5CKw_452);
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x;
		if (!((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23))) goto LA10_;
		{
			if (!((*ri_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64))) goto LA14_;
			x = (*ri_2)._kind_6.sons->data[((NI) 0)];
		}
		goto LA12_;
		LA14_: ;
		{
			x = ri_2;
		}
		LA12_: ;
		{
			if (!((*(*x).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21))) goto LA19_;
			result = genArgNoParam__cgen_12216(p, x, NIM_FALSE);
			add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_453));
		}
		goto LA17_;
		LA19_: ;
		{
			NIM_BOOL T22_;
			T22_ = (NIM_BOOL)0;
			T22_ = ((*x).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65) || (*x).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 47));
			if (!(T22_)) goto LA23_;
			T22_ = ((*(*(*x)._kind_6.sons->data[((NI) 0)]).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21));
			LA23_: ;
			if (!T22_) goto LA24_;
			result = genArgNoParam__cgen_12216(p, (*x)._kind_6.sons->data[((NI) 0)], NIM_FALSE);
			add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_453));
		}
		goto LA17_;
		LA24_: ;
		{
			result = genArgNoParam__cgen_12216(p, x, NIM_FALSE);
			add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_138));
		}
		LA17_: ;
	}
	goto LA8_;
	LA10_: ;
	{
		if (!((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21))) goto LA28_;
		{
			if (!((*ri_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63) || (*ri_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64))) goto LA32_;
			result = genArgNoParam__cgen_12216(p, (*ri_2)._kind_6.sons->data[((NI) 0)], NIM_FALSE);
			add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_138));
		}
		goto LA30_;
		LA32_: ;
		{
			result = genArgNoParam__cgen_12216(p, ri_2, NIM_FALSE);
			add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_453));
		}
		LA30_: ;
	}
	goto LA8_;
	LA28_: ;
	{
		ri_2 = skipAddrDeref__cgen_12656(ri_2);
		{
			if (!((*ri_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63) || (*ri_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64))) goto LA38_;
			ri_2 = (*ri_2)._kind_6.sons->data[((NI) 0)];
		}
		LA38_: ;
		result = genArgNoParam__cgen_12216(p, ri_2, NIM_FALSE);
		add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_138));
	}
	LA8_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genPatternCall__cgen_12746)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri, NimStringDesc* pat, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	NI i;
	NI j;
	result = NIM_NIL;
	i = ((NI) 0);
	j = ((NI) 1);
	{
		while (1) {
			if (!(i < (pat ? pat->Sup.len : 0))) goto LA2;
			switch (((NU8)(pat->data[i]))) {
			case 64:
			{
				NIM_BOOL first;
				first = NIM_TRUE;
				{
					NI k;
					NI colontmp_;
					NI i_2;
					k = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = len__ast_3155(ri);
					i_2 = j;
					{
						while (1) {
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* arg;
							if (!(i_2 < colontmp_)) goto LA6;
							k = i_2;
							arg = genOtherArg__cgen_11541(p, ri, k, typ);
							{
								NI T9_;
								T9_ = (NI)0;
								T9_ = len__ropes_10(arg);
								if (!(((NI) 0) < T9_)) goto LA10_;
								{
									tyArray__dAmhZbEWrTM5xES2bTVweg T16_;
									tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
									if (!!(first)) goto LA14_;
									nimZeroMem((void*)T16_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
									T17_ = NIM_NIL;
									T17_ = percent___cgen_3546(T16_, 0);
									add__ropes_159(&result, T17_);
								}
								LA14_: ;
								first = NIM_FALSE;
								add__ropes_159(&result, arg);
							}
							LA10_: ;
							i_2 += ((NI) 1);
						} LA6: ;
					}
				}
				i += ((NI) 1);
			}
			break;
			case 35:
			{
				{
					NIM_BOOL T21_;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri_2;
					T21_ = (NIM_BOOL)0;
					T21_ = ((NI)(i + ((NI) 1)) < (pat ? pat->Sup.len : 0));
					if (!(T21_)) goto LA22_;
					T21_ = (((NU8)(pat->data[(NI)(i + ((NI) 1))])) == ((NU8)(43)) || ((NU8)(pat->data[(NI)(i + ((NI) 1))])) == ((NU8)(64)));
					LA22_: ;
					if (!T21_) goto LA23_;
					ri_2 = (*ri)._kind_6.sons->data[j];
					{
						tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ_2;
						tyArray__dAmhZbEWrTM5xES2bTVweg T34_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T35_;
						tyArray__dAmhZbEWrTM5xES2bTVweg T48_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T49_;
						if (!((*ri_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*ri_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29) || (*ri_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30) || (*ri_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31) || (*ri_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) || (*ri_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28) || (*ri_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32))) goto LA27_;
						typ_2 = skipTypes__ast_3723((*(*ri_2)._kind_6.sons->data[((NI) 0)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
						{
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T33_;
							if (!((NU8)(pat->data[(NI)(i + ((NI) 1))]) == (NU8)(43))) goto LA31_;
							T33_ = NIM_NIL;
							T33_ = genArgNoParam__cgen_12216(p, (*ri_2)._kind_6.sons->data[((NI) 0)], NIM_FALSE);
							add__ropes_159(&result, T33_);
						}
						LA31_: ;
						nimZeroMem((void*)T34_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
						T35_ = NIM_NIL;
						T35_ = percent___cgen_11723(T34_, 0);
						add__ropes_159(&result, T35_);
						{
							NI T38_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T41_;
							T38_ = (NI)0;
							T38_ = len__ast_3155(ri_2);
							if (!(((NI) 1) < T38_)) goto LA39_;
							T41_ = NIM_NIL;
							T41_ = genOtherArg__cgen_11541(p, ri_2, ((NI) 1), typ_2);
							add__ropes_159(&result, T41_);
						}
						LA39_: ;
						{
							NI k_2;
							NI colontmp__2;
							NI colontmp__3;
							NI i_3;
							k_2 = (NI)0;
							colontmp__2 = (NI)0;
							colontmp__3 = (NI)0;
							colontmp__2 = (NI)(j + ((NI) 1));
							colontmp__3 = len__ast_3155(ri_2);
							i_3 = colontmp__2;
							{
								while (1) {
									tyArray__dAmhZbEWrTM5xES2bTVweg T45_;
									tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T46_;
									tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T47_;
									if (!(i_3 < colontmp__3)) goto LA44;
									k_2 = i_3;
									nimZeroMem((void*)T45_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
									T46_ = NIM_NIL;
									T46_ = percent___cgen_3546(T45_, 0);
									add__ropes_159(&result, T46_);
									T47_ = NIM_NIL;
									T47_ = genOtherArg__cgen_11541(p, ri_2, k_2, typ_2);
									add__ropes_159(&result, T47_);
									i_3 += ((NI) 1);
								} LA44: ;
							}
						}
						nimZeroMem((void*)T48_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
						T49_ = NIM_NIL;
						T49_ = percent___cgen_11768(T48_, 0);
						add__ropes_159(&result, T49_);
					}
					goto LA25_;
					LA27_: ;
					{
						liMessage__msgs_1128((*(*(*p).module).g).config, (*ri_2).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_449), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_450, NIM_FALSE);
					}
					LA25_: ;
					i += ((NI) 1);
				}
				goto LA19_;
				LA23_: ;
				{
					NIM_BOOL T52_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T56_;
					T52_ = (NIM_BOOL)0;
					T52_ = ((NI)(i + ((NI) 1)) < (pat ? pat->Sup.len : 0));
					if (!(T52_)) goto LA53_;
					T52_ = ((NU8)(pat->data[(NI)(i + ((NI) 1))]) == (NU8)(46));
					LA53_: ;
					if (!T52_) goto LA54_;
					T56_ = NIM_NIL;
					T56_ = genThisArg__cgen_12678(p, ri, j, typ);
					add__ropes_159(&result, T56_);
					i += ((NI) 1);
				}
				goto LA19_;
				LA54_: ;
				{
					NIM_BOOL T58_;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg_2;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T64_;
					T58_ = (NIM_BOOL)0;
					T58_ = ((NI)(i + ((NI) 1)) < (pat ? pat->Sup.len : 0));
					if (!(T58_)) goto LA59_;
					T58_ = ((NU8)(pat->data[(NI)(i + ((NI) 1))]) == (NU8)(91));
					LA59_: ;
					if (!T58_) goto LA60_;
					arg_2 = skipAddrDeref__cgen_12656((*ri)._kind_6.sons->data[j]);
					{
						while (1) {
							if (!((*arg_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63) || (*arg_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64) || (*arg_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 66))) goto LA63;
							arg_2 = (*arg_2)._kind_6.sons->data[((NI) 0)];
						} LA63: ;
					}
					T64_ = NIM_NIL;
					T64_ = genArgNoParam__cgen_12216(p, arg_2, NIM_FALSE);
					add__ropes_159(&result, T64_);
				}
				goto LA19_;
				LA60_: ;
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T66_;
					T66_ = NIM_NIL;
					T66_ = genOtherArg__cgen_11541(p, ri, j, typ);
					add__ropes_159(&result, T66_);
				}
				LA19_: ;
				j += ((NI) 1);
				i += ((NI) 1);
			}
			break;
			case 39:
			{
				NI idx;
				NI stars;
				idx = (NI)0;
				stars = (NI)0;
				{
					NIM_BOOL T70_;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
					T70_ = (NIM_BOOL)0;
					T70_ = scanCppGenericSlot__cgen_3986(pat, (&i), (&idx), (&stars));
					if (!T70_) goto LA71_;
					t = resolveStarsInCppType__cgen_4015(typ, idx, stars);
					{
						tyArray__dAmhZbEWrTM5xES2bTVweg T77_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T78_;
						if (!(t == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA75_;
						nimZeroMem((void*)T77_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
						T78_ = NIM_NIL;
						T78_ = percent___cgen_3521(T77_, 0);
						add__ropes_159(&result, T78_);
					}
					goto LA73_;
					LA75_: ;
					{
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T80_;
						T80_ = NIM_NIL;
						T80_ = getTypeDesc__cgen_6662((*p).module, t, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
						add__ropes_159(&result, T80_);
					}
					LA73_: ;
				}
				LA71_: ;
			}
			break;
			default:
			{
				NI start;
				start = i;
				{
					while (1) {
						if (!(i < (pat ? pat->Sup.len : 0))) goto LA83;
						{
							if (!!((((NU8)(pat->data[i])) == ((NU8)(64)) || ((NU8)(pat->data[i])) == ((NU8)(35)) || ((NU8)(pat->data[i])) == ((NU8)(39))))) goto LA86_;
							i += ((NI) 1);
						}
						goto LA84_;
						LA86_: ;
						{
							goto LA82;
						}
						LA84_: ;
					} LA83: ;
				} LA82: ;
				{
					NimStringDesc* T93_;
					if (!(start <= (NI)(i - ((NI) 1)))) goto LA91_;
					T93_ = NIM_NIL;
					T93_ = substr__system_7755(pat, start, (NI)(i - ((NI) 1)));
					add__ropes_162(&result, T93_);
				}
				LA91_: ;
			}
			break;
			}
		} LA2: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, getTempCpp__cgen_11082)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* result, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* value) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T2_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T3_;
	NimStringDesc* res;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T4_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
	(*p).labels += ((NI) 1);
	T1_ = NIM_NIL;
	T1_ = rope__ropes_115(((NI64) ((*p).labels)));
	T2_ = NIM_NIL;
	T2_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_157), T1_);
	unsureAsgnRef((void**) (&(*result).r), amp___ropes_140(T2_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3)));
	T3_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T3_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	res = rawNewString(((NI) 80));
	T4_ = NIM_NIL;
	T4_ = getTypeDesc__cgen_6662((*p).module, t, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
	cgFormatValue__cgen_147((&res), T4_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_13));
	cgFormatValue__cgen_147((&res), (*result).r);
	res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
	cgFormatValue__cgen_147((&res), value);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA7_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA7_: ;
	T9_ = NIM_NIL;
	T9_ = rope__ropes_109(res);
	T10_ = NIM_NIL;
	T10_ = indentLine__cgen_286(p, T9_);
	add__ropes_159(T3_, T10_);
	(*result).k = ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 1);
	unsureAsgnRef((void**) (&(*result).lode), lodeTyp__cgen_92(t));
	(*result).storage = ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 2);
	(*result).flags = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, fixupCall__cgen_11710)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* le, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* callee, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* params) {
	NIM_BOOL canRaise;
	NIM_BOOL T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* pl;
	tyArray__dAmhZbEWrTM5xES2bTVweg T3_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T4_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*(*(*(*p).module).g).config).exc == ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 3));
	if (!(T1_)) goto LA2_;
	T1_ = canRaiseDisp__cgen_11588(p, (*ri)._kind_6.sons->data[((NI) 0)]);
	LA2_: ;
	canRaise = T1_;
	genLineDir__cgen_369(p, ri);
	nimZeroMem((void*)T3_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
	T4_ = NIM_NIL;
	T4_ = percent___cgen_11723(T3_, 0);
	T5_ = NIM_NIL;
	T5_ = amp___ropes_128(callee, T4_);
	pl = amp___ropes_128(T5_, params);
	typ = skipTypes__ast_3723((*(*ri)._kind_6.sons->data[((NI) 0)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
	{
		if (!!(((*typ).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA8_;
		{
			NIM_BOOL T12_;
			T12_ = (NIM_BOOL)0;
			T12_ = isInvalidReturnType__cgen_1353((*(*(*p).module).g).config, typ, NIM_TRUE);
			if (!T12_) goto LA13_;
			{
				tyArray__dAmhZbEWrTM5xES2bTVweg T19_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
				if (!!((params == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA17_;
				nimZeroMem((void*)T19_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
				T20_ = NIM_NIL;
				T20_ = percent___cgen_3546(T19_, 0);
				add__ropes_159(&pl, T20_);
			}
			LA17_: ;
			{
				NIM_BOOL T23_;
				NIM_BOOL T25_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
				tyArray__dAmhZbEWrTM5xES2bTVweg T39_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T40_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T41_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T42_;
				T23_ = (NIM_BOOL)0;
				T23_ = ((3 &((NU16)1<<((NU)((*d).k)&15U)))!=0);
				if (T23_) goto LA24_;
				T25_ = (NIM_BOOL)0;
				T25_ = preventNrvo__cgen_11616(p, (*d).lode, le, ri);
				T23_ = !(T25_);
				LA24_: ;
				if (!T23_) goto LA26_;
				{
					if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA30_;
					getTemp__cgen_7373(p, (*typ).sons->data[((NI) 0)], d, NIM_TRUE);
				}
				goto LA28_;
				LA30_: ;
				{
					NIM_BOOL T33_;
					NIM_BOOL T35_;
					T33_ = (NIM_BOOL)0;
					T33_ = !(((2 &((NU16)1<<((NU)((*d).k)&15U)))!=0));
					if (!(T33_)) goto LA34_;
					T35_ = (NIM_BOOL)0;
					T35_ = hasNoInit__cgen_11683(ri);
					T33_ = !(T35_);
					LA34_: ;
					if (!T33_) goto LA36_;
				}
				goto LA28_;
				LA36_: ;
				LA28_: ;
				T38_ = NIM_NIL;
				T38_ = addrLoc__cgen_10337((*(*(*p).module).g).config, (*d));
				add__ropes_159(&pl, T38_);
				nimZeroMem((void*)T39_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
				T40_ = NIM_NIL;
				T40_ = percent___cgen_11757(T39_, 0);
				add__ropes_159(&pl, T40_);
				T41_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T41_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				T42_ = NIM_NIL;
				T42_ = indentLine__cgen_286(p, pl);
				add__ropes_159(T41_, T42_);
			}
			goto LA21_;
			LA26_: ;
			{
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tmp;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T44_;
				tyArray__dAmhZbEWrTM5xES2bTVweg T45_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T46_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T47_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T48_;
				nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				getTemp__cgen_7373(p, (*typ).sons->data[((NI) 0)], (&tmp), NIM_TRUE);
				T44_ = NIM_NIL;
				T44_ = addrLoc__cgen_10337((*(*(*p).module).g).config, tmp);
				add__ropes_159(&pl, T44_);
				nimZeroMem((void*)T45_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
				T46_ = NIM_NIL;
				T46_ = percent___cgen_11757(T45_, 0);
				add__ropes_159(&pl, T46_);
				T47_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T47_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				T48_ = NIM_NIL;
				T48_ = indentLine__cgen_286(p, pl);
				add__ropes_159(T47_, T48_);
				genAssignment__cgen_10403(p, (*d), tmp, 0);
			}
			LA21_: ;
			{
				if (!canRaise) goto LA51_;
				raiseExit__cgen_11546(p);
			}
			LA51_: ;
		}
		goto LA10_;
		LA13_: ;
		{
			tyArray__dAmhZbEWrTM5xES2bTVweg T54_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T55_;
			nimZeroMem((void*)T54_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
			T55_ = NIM_NIL;
			T55_ = percent___cgen_11768(T54_, 0);
			add__ropes_159(&pl, T55_);
			{
				NIM_BOOL T58_;
				T58_ = (NIM_BOOL)0;
				T58_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
				if (T58_) goto LA59_;
				T58_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
				LA59_: ;
				if (!T58_) goto LA60_;
				{
					if (!(((*d).flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 8))&15U)))!=0)) goto LA64_;
					(*d).k = ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 9);
					unsureAsgnRef((void**) (&(*d).r), pl);
					(*d).flags &= ~(((NU16)1) << ((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 8)) & 15));
				}
				goto LA62_;
				LA64_: ;
				{
					{
						NIM_BOOL T69_;
						T69_ = (NIM_BOOL)0;
						T69_ = ((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0));
						if (!(T69_)) goto LA70_;
						T69_ = ((*p).splitDecls == ((NI) 0));
						LA70_: ;
						if (!T69_) goto LA71_;
						getTempCpp__cgen_11082(p, (*typ).sons->data[((NI) 0)], d, pl);
					}
					goto LA67_;
					LA71_: ;
					{
						tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw list;
						{
							if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA76_;
							getTemp__cgen_7373(p, (*typ).sons->data[((NI) 0)], d, NIM_FALSE);
						}
						LA76_: ;
						nimZeroMem((void*)(&list), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
						initLoc__cgen_66((&list), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 9), (*d).lode, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
						list.r = pl;
						genAssignment__cgen_10403(p, (*d), list, 0);
						{
							if (!canRaise) goto LA80_;
							raiseExit__cgen_11546(p);
						}
						LA80_: ;
					}
					LA67_: ;
				}
				LA62_: ;
			}
			goto LA56_;
			LA60_: ;
			{
				NIM_BOOL T83_;
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw list_2;
				T83_ = (NIM_BOOL)0;
				T83_ = isHarmlessStore__cgen_11696(p, canRaise, (*d));
				if (!T83_) goto LA84_;
				{
					if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA88_;
					getTemp__cgen_7373(p, (*typ).sons->data[((NI) 0)], d, NIM_FALSE);
				}
				LA88_: ;
				nimZeroMem((void*)(&list_2), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				initLoc__cgen_66((&list_2), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 9), (*d).lode, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
				list_2.r = pl;
				genAssignment__cgen_10403(p, (*d), list_2, 0);
				{
					if (!canRaise) goto LA92_;
					raiseExit__cgen_11546(p);
				}
				LA92_: ;
			}
			goto LA56_;
			LA84_: ;
			{
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tmp_2;
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw list_3;
				nimZeroMem((void*)(&tmp_2), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				getTemp__cgen_7373(p, (*typ).sons->data[((NI) 0)], (&tmp_2), NIM_TRUE);
				nimZeroMem((void*)(&list_3), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				initLoc__cgen_66((&list_3), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 9), (*d).lode, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
				list_3.r = pl;
				genAssignment__cgen_10403(p, tmp_2, list_3, 0);
				{
					if (!canRaise) goto LA97_;
					raiseExit__cgen_11546(p);
				}
				LA97_: ;
				genAssignment__cgen_10403(p, (*d), tmp_2, 0);
			}
			LA56_: ;
		}
		LA10_: ;
	}
	goto LA6_;
	LA8_: ;
	{
		tyArray__dAmhZbEWrTM5xES2bTVweg T100_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T101_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T102_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T103_;
		nimZeroMem((void*)T100_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		T101_ = NIM_NIL;
		T101_ = percent___cgen_11757(T100_, 0);
		add__ropes_159(&pl, T101_);
		T102_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T102_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		T103_ = NIM_NIL;
		T103_ = indentLine__cgen_286(p, pl);
		add__ropes_159(T102_, T103_);
		{
			if (!canRaise) goto LA106_;
			raiseExit__cgen_11546(p);
		}
		LA106_: ;
	}
	LA6_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genInfixCall__cgen_12851)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* le, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw op;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
	NimStringDesc* pat;
	nimZeroMem((void*)(&op), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, (*ri)._kind_6.sons->data[((NI) 0)], (&op));
	typ = skipTypes__ast_3723((*(*ri)._kind_6.sons->data[((NI) 0)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
	pat = (*(*(*(*ri)._kind_6.sons->data[((NI) 0)])._kind_4.sym).loc.r).data;
	{
		NimStringDesc* argX60gensym1502_;
		if (!!((((NI) 0) < (pat ? pat->Sup.len : 0)))) goto LA3_;
		argX60gensym1502_ = toFileLineCol__msgs_625(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_447);
		internalErrorImpl__msgs_1441((*(*(*p).module).g).config, unknownLineInfo__lineinfos_284, argX60gensym1502_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_447);
	}
	LA3_: ;
	{
		NIM_BOOL T7_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* pl;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ_2;
		T7_ = (NIM_BOOL)0;
		T7_ = contains__pureZstrutils_1631(pat, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_448);
		if (!T7_) goto LA8_;
		pl = genPatternCall__cgen_12746(p, ri, pat, typ);
		typ_2 = skipTypes__ast_3723((*(*ri)._kind_6.sons->data[((NI) 0)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
		{
			if (!!(((*typ_2).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA12_;
			{
				NIM_BOOL T16_;
				NIM_BOOL T17_;
				T16_ = (NIM_BOOL)0;
				T17_ = (NIM_BOOL)0;
				T17_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
				if (T17_) goto LA18_;
				T17_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
				LA18_: ;
				T16_ = T17_;
				if (!(T16_)) goto LA19_;
				T16_ = (((*d).flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 8))&15U)))!=0);
				LA19_: ;
				if (!T16_) goto LA20_;
				(*d).k = ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 9);
				unsureAsgnRef((void**) (&(*d).r), pl);
				(*d).flags &= ~(((NU16)1) << ((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 8)) & 15));
			}
			goto LA14_;
			LA20_: ;
			{
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw list;
				{
					if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA25_;
					getTemp__cgen_7373(p, (*typ_2).sons->data[((NI) 0)], d, NIM_FALSE);
				}
				LA25_: ;
				nimZeroMem((void*)(&list), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				initLoc__cgen_66((&list), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 9), (*d).lode, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
				list.r = pl;
				genAssignment__cgen_10403(p, (*d), list, 0);
			}
			LA14_: ;
		}
		goto LA10_;
		LA12_: ;
		{
			tyArray__dAmhZbEWrTM5xES2bTVweg T28_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T29_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T30_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T31_;
			nimZeroMem((void*)T28_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
			T29_ = NIM_NIL;
			T29_ = percent___cgen_12919(T28_, 0);
			add__ropes_159(&pl, T29_);
			T30_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T30_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			T31_ = NIM_NIL;
			T31_ = indentLine__cgen_286(p, pl);
			add__ropes_159(T30_, T31_);
		}
		LA10_: ;
	}
	goto LA5_;
	LA8_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* pl_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* params;
		pl_2 = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
		{
			NI T35_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
			T35_ = (NI)0;
			T35_ = len__ast_3155(ri);
			if (!(((NI) 1) < T35_)) goto LA36_;
			T38_ = NIM_NIL;
			T38_ = genThisArg__cgen_12678(p, ri, ((NI) 1), typ);
			add__ropes_159(&pl_2, T38_);
		}
		LA36_: ;
		add__ropes_159(&pl_2, op.r);
		params = NIM_NIL;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(ri);
			i_2 = ((NI) 2);
			{
				while (1) {
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T48_;
					if (!(i_2 < colontmp_)) goto LA41;
					i = i_2;
					{
						tyArray__dAmhZbEWrTM5xES2bTVweg T46_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T47_;
						if (!!((params == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA44_;
						nimZeroMem((void*)T46_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
						T47_ = NIM_NIL;
						T47_ = percent___cgen_3546(T46_, 0);
						add__ropes_159(&params, T47_);
					}
					LA44_: ;
					T48_ = NIM_NIL;
					T48_ = genOtherArg__cgen_11541(p, ri, i, typ);
					add__ropes_159(&params, T48_);
					i_2 += ((NI) 1);
				} LA41: ;
			}
		}
		fixupCall__cgen_11710(p, le, ri, d, pl_2, params);
	}
	LA5_: ;
}
static N_INLINE(NI, find__pureZos_656)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item) {
	NI result;
{	result = (NI)0;
	result = ((NI) 0);
	{
		NIM_CHAR i;
		NI i_2;
		i = (NIM_CHAR)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < aLen_0)) goto LA3;
				i = a[i_2];
				{
					if (!((NU8)(i) == (NU8)(item))) goto LA6_;
					goto BeforeRet_;
				}
				LA6_: ;
				result += ((NI) 1);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__pureZos_651)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item) {
	NIM_BOOL result;
	NI T1_;
{	result = (NIM_BOOL)0;
	T1_ = (NI)0;
	T1_ = find__pureZos_656(a, aLen_0, item);
	result = (((NI) 0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genNamedParamCall__cgen_12954)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw op;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* pl;
	tyArray__dAmhZbEWrTM5xES2bTVweg T1_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
	NimStringDesc* pat;
	NI start;
	nimZeroMem((void*)(&op), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, (*ri)._kind_6.sons->data[((NI) 0)], (&op));
	nimZeroMem((void*)T1_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
	pl = percent___cgen_12960(T1_, 0);
	typ = skipTypes__ast_3723((*(*ri)._kind_6.sons->data[((NI) 0)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
	pat = (*(*(*(*ri)._kind_6.sons->data[((NI) 0)])._kind_4.sym).loc.r).data;
	{
		NimStringDesc* argX60gensym1531_;
		if (!!((((NI) 0) < (pat ? pat->Sup.len : 0)))) goto LA4_;
		argX60gensym1531_ = toFileLineCol__msgs_625(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_454);
		internalErrorImpl__msgs_1441((*(*(*p).module).g).config, unknownLineInfo__lineinfos_284, argX60gensym1531_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_454);
	}
	LA4_: ;
	start = ((NI) 3);
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = contains__pureZos_651((pat) ? (pat->data) : NIM_NIL, (pat ? pat->Sup.len : 0), 32);
		if (!T8_) goto LA9_;
		start = ((NI) 1);
		add__ropes_159(&pl, op.r);
		{
			NI T13_;
			tyArray__dAmhZbEWrTM5xES2bTVweg T16_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
			T13_ = (NI)0;
			T13_ = len__ast_3155(ri);
			if (!(((NI) 1) < T13_)) goto LA14_;
			nimZeroMem((void*)T16_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
			T17_ = NIM_NIL;
			T17_ = percent___cgen_12998(T16_, 0);
			add__ropes_159(&pl, T17_);
			T18_ = NIM_NIL;
			T18_ = genArg__cgen_12149(p, (*ri)._kind_6.sons->data[((NI) 1)], (*(*(*typ).n)._kind_6.sons->data[((NI) 1)])._kind_4.sym, ri, NIM_FALSE);
			add__ropes_159(&pl, T18_);
			start = ((NI) 2);
		}
		LA14_: ;
	}
	goto LA6_;
	LA9_: ;
	{
		{
			NI T22_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
			tyArray__dAmhZbEWrTM5xES2bTVweg T26_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T27_;
			T22_ = (NI)0;
			T22_ = len__ast_3155(ri);
			if (!(((NI) 1) < T22_)) goto LA23_;
			T25_ = NIM_NIL;
			T25_ = genArg__cgen_12149(p, (*ri)._kind_6.sons->data[((NI) 1)], (*(*(*typ).n)._kind_6.sons->data[((NI) 1)])._kind_4.sym, ri, NIM_FALSE);
			add__ropes_159(&pl, T25_);
			nimZeroMem((void*)T26_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
			T27_ = NIM_NIL;
			T27_ = percent___cgen_3562(T26_, 0);
			add__ropes_159(&pl, T27_);
		}
		LA23_: ;
		add__ropes_159(&pl, op.r);
		{
			NI T30_;
			tyArray__dAmhZbEWrTM5xES2bTVweg T33_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T34_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T35_;
			T30_ = (NI)0;
			T30_ = len__ast_3155(ri);
			if (!(((NI) 2) < T30_)) goto LA31_;
			nimZeroMem((void*)T33_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
			T34_ = NIM_NIL;
			T34_ = percent___cgen_12998(T33_, 0);
			add__ropes_159(&pl, T34_);
			T35_ = NIM_NIL;
			T35_ = genArg__cgen_12149(p, (*ri)._kind_6.sons->data[((NI) 2)], (*(*(*typ).n)._kind_6.sons->data[((NI) 2)])._kind_4.sym, ri, NIM_FALSE);
			add__ropes_159(&pl, T35_);
		}
		LA31_: ;
	}
	LA6_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(ri);
		i_2 = start;
		{
			while (1) {
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* param;
				tyArray__dAmhZbEWrTM5xES2bTVweg T44_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T45_;
				tyArray__dAmhZbEWrTM5xES2bTVweg T46_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T47_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T48_;
				if (!(i_2 < colontmp_)) goto LA38;
				i = i_2;
				{
					NI T41_;
					T41_ = (NI)0;
					T41_ = len__ast_3990(typ);
					if (!(T41_ <= i)) goto LA42_;
					internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*ri).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_455), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_456);
				}
				LA42_: ;
				param = (*(*(*typ).n)._kind_6.sons->data[i])._kind_4.sym;
				nimZeroMem((void*)T44_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
				T45_ = NIM_NIL;
				T45_ = percent___cgen_3562(T44_, 0);
				add__ropes_159(&pl, T45_);
				add__ropes_162(&pl, (*(*param).name).s);
				nimZeroMem((void*)T46_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
				T47_ = NIM_NIL;
				T47_ = percent___cgen_12998(T46_, 0);
				add__ropes_159(&pl, T47_);
				T48_ = NIM_NIL;
				T48_ = genArg__cgen_12149(p, (*ri)._kind_6.sons->data[i], param, ri, NIM_FALSE);
				add__ropes_159(&pl, T48_);
				i_2 += ((NI) 1);
			} LA38: ;
		}
	}
	{
		if (!!(((*typ).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA51_;
		{
			NIM_BOOL T55_;
			T55_ = (NIM_BOOL)0;
			T55_ = isInvalidReturnType__cgen_1353((*(*(*p).module).g).config, typ, NIM_TRUE);
			if (!T55_) goto LA56_;
			{
				NI T60_;
				tyArray__dAmhZbEWrTM5xES2bTVweg T63_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T64_;
				T60_ = (NI)0;
				T60_ = len__ast_3155(ri);
				if (!(((NI) 1) < T60_)) goto LA61_;
				nimZeroMem((void*)T63_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
				T64_ = NIM_NIL;
				T64_ = percent___cgen_3562(T63_, 0);
				add__ropes_159(&pl, T64_);
			}
			LA61_: ;
			{
				tyArray__dAmhZbEWrTM5xES2bTVweg T73_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T74_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T75_;
				tyArray__dAmhZbEWrTM5xES2bTVweg T76_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T77_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T78_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T79_;
				if (!((3 &((NU16)1<<((NU)((*d).k)&15U)))!=0)) goto LA67_;
				{
					if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA71_;
					getTemp__cgen_7373(p, (*typ).sons->data[((NI) 0)], d, NIM_TRUE);
				}
				LA71_: ;
				nimZeroMem((void*)T73_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
				T74_ = NIM_NIL;
				T74_ = percent___cgen_13083(T73_, 0);
				add__ropes_159(&pl, T74_);
				T75_ = NIM_NIL;
				T75_ = addrLoc__cgen_10337((*(*(*p).module).g).config, (*d));
				add__ropes_159(&pl, T75_);
				nimZeroMem((void*)T76_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
				T77_ = NIM_NIL;
				T77_ = percent___cgen_13088(T76_, 0);
				add__ropes_159(&pl, T77_);
				T78_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T78_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				T79_ = NIM_NIL;
				T79_ = indentLine__cgen_286(p, pl);
				add__ropes_159(T78_, T79_);
			}
			goto LA65_;
			LA67_: ;
			{
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tmp;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T81_;
				tyArray__dAmhZbEWrTM5xES2bTVweg T82_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T83_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T84_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T85_;
				nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				getTemp__cgen_7373(p, (*typ).sons->data[((NI) 0)], (&tmp), NIM_TRUE);
				T81_ = NIM_NIL;
				T81_ = addrLoc__cgen_10337((*(*(*p).module).g).config, tmp);
				add__ropes_159(&pl, T81_);
				nimZeroMem((void*)T82_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
				T83_ = NIM_NIL;
				T83_ = percent___cgen_13088(T82_, 0);
				add__ropes_159(&pl, T83_);
				T84_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T84_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				T85_ = NIM_NIL;
				T85_ = indentLine__cgen_286(p, pl);
				add__ropes_159(T84_, T85_);
				genAssignment__cgen_10403(p, (*d), tmp, 0);
			}
			LA65_: ;
		}
		goto LA53_;
		LA56_: ;
		{
			tyArray__dAmhZbEWrTM5xES2bTVweg T87_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T88_;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw list;
			nimZeroMem((void*)T87_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
			T88_ = NIM_NIL;
			T88_ = percent___cgen_13099(T87_, 0);
			add__ropes_159(&pl, T88_);
			{
				if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA91_;
				getTemp__cgen_7373(p, (*typ).sons->data[((NI) 0)], d, NIM_FALSE);
			}
			LA91_: ;
			nimZeroMem((void*)(&list), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLoc__cgen_66((&list), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 9), ri, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
			list.r = pl;
			genAssignment__cgen_10403(p, (*d), list, 0);
		}
		LA53_: ;
	}
	goto LA49_;
	LA51_: ;
	{
		tyArray__dAmhZbEWrTM5xES2bTVweg T94_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T95_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T96_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T97_;
		nimZeroMem((void*)T94_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		T95_ = NIM_NIL;
		T95_ = percent___cgen_13088(T94_, 0);
		add__ropes_159(&pl, T95_);
		T96_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T96_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		T97_ = NIM_NIL;
		T97_ = indentLine__cgen_286(p, pl);
		add__ropes_159(T96_, T97_);
	}
	LA49_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genPrefixCall__cgen_12426)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* le, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw op;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* params;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* callee;
	nimZeroMem((void*)(&op), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, (*ri)._kind_6.sons->data[((NI) 0)], (&op));
	typ = skipTypes__ast_3723((*(*ri)._kind_6.sons->data[((NI) 0)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_155);
	params = genParams__cgen_12297(p, ri, typ);
	callee = rdLoc__cgen_435(op);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = hcrOn__cgen_46(p);
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*ri)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		LA4_: ;
		if (!T3_) goto LA5_;
		addActualSuffixForHCR__cgen_12394(&callee, (*(*p).module).module, (*(*ri)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
	}
	LA5_: ;
	fixupCall__cgen_11710(p, le, ri, d, callee, params);
}
N_LIB_PRIVATE N_NIMCALL(void, genAsgnCall__cgen_13147)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* le, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
{	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((NI) 0) < (*p).withinBlockLeaveActions);
		if (!(T3_)) goto LA4_;
		T3_ = isInactiveDestructorCall__cgen_13133(p, ri);
		LA4_: ;
		if (!T3_) goto LA5_;
		goto BeforeRet_;
	}
	LA5_: ;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T9_;
		T9_ = NIM_NIL;
		T9_ = skipTypes__ast_3723((*(*ri)._kind_6.sons->data[((NI) 0)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_415);
		if (!((*T9_).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9))) goto LA10_;
		genClosureCall__cgen_12459(p, le, ri, d);
	}
	goto LA7_;
	LA10_: ;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = ((*(*ri)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		if (!(T13_)) goto LA14_;
		T13_ = (((*(*(*ri)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
		LA14_: ;
		if (!T13_) goto LA15_;
		genInfixCall__cgen_12851(p, le, ri, d);
	}
	goto LA7_;
	LA15_: ;
	{
		NIM_BOOL T18_;
		T18_ = (NIM_BOOL)0;
		T18_ = ((*(*ri)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		if (!(T18_)) goto LA19_;
		T18_ = (((*(*(*ri)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 33))&63U)))!=0);
		LA19_: ;
		if (!T18_) goto LA20_;
		genNamedParamCall__cgen_12954(p, ri, d);
	}
	goto LA7_;
	LA20_: ;
	{
		genPrefixCall__cgen_12426(p, le, ri, d);
	}
	LA7_: ;
	}BeforeRet_: ;
}
static N_INLINE(void, loadInto__cgen_13528)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* le, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* a) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*ri).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*ri).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29) || (*ri).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30) || (*ri).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31) || (*ri).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) || (*ri).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28) || (*ri).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32));
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = !(((*(*ri)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)));
		if (T5_) goto LA6_;
		T5_ = ((*(*(*ri)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 0));
		LA6_: ;
		T3_ = T5_;
		LA4_: ;
		if (!T3_) goto LA7_;
		genAsgnCall__cgen_13147(p, le, ri, a);
	}
	goto LA1_;
	LA7_: ;
	{
		(*a).flags |= ((NU16)1)<<((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 9)) & 15);
		expr__cgen_11525(p, ri, a);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSingleVar__cgen_13925)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* v, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* vn, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* value) {
	tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* targetProc;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* traverseProc;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* valueAsRope;
	NIM_BOOL forHcr;
{	{
		if (!(((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 35))&63U)))!=0)) goto LA3_;
		genGotoVar__cgen_13879(p, value);
		goto BeforeRet_;
	}
	LA3_: ;
	targetProc = p;
	traverseProc = NIM_NIL;
	valueAsRope = potentialValueInit__cgen_13896(p, v, value);
	{
		if (!(((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 3))&63U)))!=0)) goto LA7_;
		{
			NIM_BOOL T11_;
			NIM_BOOL T12_;
			T11_ = (NIM_BOOL)0;
			T12_ = (NIM_BOOL)0;
			T12_ = (((*v).flags & 192) == 64);
			if (!(T12_)) goto LA13_;
			T12_ = ((*value).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1));
			LA13_: ;
			T11_ = T12_;
			if (!(T11_)) goto LA14_;
			T11_ = !((((*v).loc.flags & 72) == 0));
			LA14_: ;
			if (!T11_) goto LA15_;
			goto BeforeRet_;
		}
		LA15_: ;
		{
			if (!(((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 11))&63U)))!=0)) goto LA19_;
			targetProc = (*(*p).module).preInitProc;
		}
		LA19_: ;
		assignGlobalVar__cgen_11336(targetProc, vn, valueAsRope);
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
			if (!(valueAsRope == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA23_;
			nimZeroMem((void*)(&loc), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			genericAssign((void*)(&loc), (void*)(&(*v).loc), (&NTItloc__CAJV4zTUpZwr0j6Wy8FiFw_));
			{
				NIM_BOOL T27_;
				NIM_BOOL T28_;
				T27_ = (NIM_BOOL)0;
				T28_ = (NIM_BOOL)0;
				T28_ = (((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 26))&63U)))!=0);
				if (!(T28_)) goto LA29_;
				T28_ = emulatedThreadVars__cgen_419((*(*(*p).module).g).config);
				LA29_: ;
				T27_ = T28_;
				if (!(T27_)) goto LA30_;
				T27_ = isComplexValueType__cgen_10585((*v).typ);
				LA30_: ;
				if (!T27_) goto LA31_;
				initLocExprSingleUse__cgen_11552((*(*p).module).preInitProc, vn, (&loc));
			}
			LA31_: ;
			genObjectInit__cgen_10414((*(*p).module).preInitProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 1), (*v).typ, (&loc), ((tyEnum_ObjConstrMode__fUO6aSwLQdJNwZTWRxqbKg) 0));
		}
		LA23_: ;
		{
			NIM_BOOL T35_;
			T35_ = (NIM_BOOL)0;
			T35_ = (((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 7))&63U)))!=0);
			if (!(T35_)) goto LA36_;
			T35_ = !(((*(*(*p).module).g).generatedHeader == ((tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA*) NIM_NIL)));
			LA36_: ;
			if (!T35_) goto LA37_;
			genVarPrototype__cgen_11516((*(*(*p).module).g).generatedHeader, vn);
		}
		LA37_: ;
		traverseProc = getTraverseProc__cgen_13183(p, v);
		{
			NIM_BOOL T41_;
			NIM_BOOL T43_;
			T41_ = (NIM_BOOL)0;
			T41_ = !((traverseProc == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)));
			if (!(T41_)) goto LA42_;
			T43_ = (NIM_BOOL)0;
			T43_ = hcrOn__cgen_46(p);
			T41_ = !(T43_);
			LA42_: ;
			if (!T41_) goto LA44_;
			registerTraverseProc__cgen_13195(p, v, traverseProc);
		}
		LA44_: ;
	}
	goto LA5_;
	LA7_: ;
	{
		NIM_BOOL imm;
		imm = isAssignedImmediately__cgen_13245((*(*(*p).module).g).config, value);
		{
			NIM_BOOL T49_;
			NIM_BOOL T50_;
			NIM_BOOL T51_;
			NIM_BOOL T53_;
			NIM_BOOL T57_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* decl;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tmp;
			T49_ = (NIM_BOOL)0;
			T50_ = (NIM_BOOL)0;
			T51_ = (NIM_BOOL)0;
			T51_ = imm;
			if (!(T51_)) goto LA52_;
			T53_ = (NIM_BOOL)0;
			T53_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
			if (T53_) goto LA54_;
			T53_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
			LA54_: ;
			T51_ = T53_;
			LA52_: ;
			T50_ = T51_;
			if (!(T50_)) goto LA55_;
			T50_ = ((*p).splitDecls == ((NI) 0));
			LA55_: ;
			T49_ = T50_;
			if (!(T49_)) goto LA56_;
			T57_ = (NIM_BOOL)0;
			T57_ = containsHiddenPointer__types_658((*v).typ);
			T49_ = !(T57_);
			LA56_: ;
			if (!T49_) goto LA58_;
			genLineDir__cgen_369(p, vn);
			decl = localVarDecl__cgen_11124(p, vn);
			nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			{
				NIM_BOOL T62_;
				NIM_BOOL T63_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* params;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
				T62_ = (NIM_BOOL)0;
				T63_ = (NIM_BOOL)0;
				T63_ = ((*value).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*value).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29) || (*value).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30) || (*value).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31) || (*value).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) || (*value).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28) || (*value).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32));
				if (!(T63_)) goto LA64_;
				T63_ = ((*(*value)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
				LA64_: ;
				T62_ = T63_;
				if (!(T62_)) goto LA65_;
				T62_ = (((*(*(*value)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 29))&63U)))!=0);
				LA65_: ;
				if (!T62_) goto LA66_;
				params = NIM_NIL;
				typ = skipTypes__ast_3723((*(*value)._kind_6.sons->data[((NI) 0)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
				{
					NI i;
					NI colontmp_;
					NI i_2;
					i = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = len__ast_3155(value);
					i_2 = ((NI) 1);
					{
						while (1) {
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T77_;
							if (!(i_2 < colontmp_)) goto LA70;
							i = i_2;
							{
								tyArray__dAmhZbEWrTM5xES2bTVweg T75_;
								tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T76_;
								if (!!((params == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA73_;
								nimZeroMem((void*)T75_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
								T76_ = NIM_NIL;
								T76_ = percent___cgen_3546(T75_, 0);
								add__ropes_159(&params, T76_);
							}
							LA73_: ;
							T77_ = NIM_NIL;
							T77_ = genOtherArg__cgen_11541(p, value, i, typ);
							add__ropes_159(&params, T77_);
							i_2 += ((NI) 1);
						} LA70: ;
					}
				}
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T82_;
					tyArray__ts9cf9blICas1QWmw89bglZ7w T83_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T84_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T85_;
					if (!(params == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA80_;
					T82_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T82_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					nimZeroMem((void*)T83_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
					T83_[0] = decl;
					T84_ = NIM_NIL;
					T84_ = percent___cgen_14050(T83_, 1);
					T85_ = NIM_NIL;
					T85_ = indentLine__cgen_286(p, T84_);
					add__ropes_159(T82_, T85_);
				}
				goto LA78_;
				LA80_: ;
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T87_;
					tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T88_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T89_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T90_;
					T87_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T87_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					nimZeroMem((void*)T88_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
					T88_[0] = decl;
					T88_[1] = params;
					T89_ = NIM_NIL;
					T89_ = percent___cgen_14055(T88_, 2);
					T90_ = NIM_NIL;
					T90_ = indentLine__cgen_286(p, T89_);
					add__ropes_159(T87_, T90_);
				}
				LA78_: ;
			}
			goto LA60_;
			LA66_: ;
			{
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T92_;
				tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T93_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T94_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T95_;
				initLocExprSingleUse__cgen_11552(p, value, (&tmp));
				T92_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T92_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				nimZeroMem((void*)T93_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
				T93_[0] = decl;
				T93_[1] = rdLoc__cgen_435(tmp);
				T94_ = NIM_NIL;
				T94_ = percent___cgen_14060(T93_, 2);
				T95_ = NIM_NIL;
				T95_ = indentLine__cgen_286(p, T94_);
				add__ropes_159(T92_, T95_);
			}
			LA60_: ;
			goto BeforeRet_;
		}
		LA58_: ;
		assignLocalVar__cgen_11164(p, vn);
		initLocalVar__cgen_11052(p, v, imm);
	}
	LA5_: ;
	{
		tyArray__dAmhZbEWrTM5xES2bTVweg T100_;
		if (!(traverseProc == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA98_;
		nimZeroMem((void*)T100_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		traverseProc = percent___cgen_13448(T100_, 0);
	}
	LA98_: ;
	forHcr = treatGlobalDifferentlyForHCR__cgen_11316((*p).module, v);
	{
		NIM_BOOL T103_;
		NIM_BOOL T104_;
		NI T106_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T110_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T111_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T112_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T117_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T118_;
		T103_ = (NIM_BOOL)0;
		T104_ = (NIM_BOOL)0;
		T104_ = forHcr;
		if (!(T104_)) goto LA105_;
		T106_ = ((*targetProc).blocks ? (*targetProc).blocks->Sup.len : 0);
		T104_ = (((NI) 3) < T106_);
		LA105_: ;
		T103_ = T104_;
		if (!(T103_)) goto LA107_;
		T103_ = ((*(*v).owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6));
		LA107_: ;
		if (!T103_) goto LA108_;
		T110_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T110_ = s__cgendata_225(targetProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 18);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_407));
		T111_ = NIM_NIL;
		T111_ = getModuleDllPath__cgen_142((*p).module, v);
		cgFormatValue__cgen_147((&res), T111_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_408));
		cgFormatValue__cgen_147((&res), (*v).loc.r);
		res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_409));
		T112_ = NIM_NIL;
		T112_ = rdLoc__cgen_435((*v).loc);
		cgFormatValue__cgen_147((&res), T112_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_410));
		cgFormatValue__cgen_147((&res), traverseProc);
		res = resizeString(res, 11);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_411));
		cgFormatValue__cgen_147((&res), (*v).loc.r);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
		{
			if (!!((((*(*(*(*targetProc).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA115_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA115_: ;
		T117_ = NIM_NIL;
		T117_ = rope__ropes_109(res);
		T118_ = NIM_NIL;
		T118_ = indentLine__cgen_286(targetProc, T117_);
		add__ropes_159(T110_, T118_);
		forHcr = NIM_FALSE;
	}
	LA108_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T123_;
		NimStringDesc* res_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T124_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T125_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T126_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T127_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T128_;
		NimStringDesc* res_3;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T133_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T134_;
		NI T135_;
		if (!forHcr) goto LA121_;
		T123_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T123_ = s__cgendata_225(targetProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 22);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_412));
		T124_ = NIM_NIL;
		T124_ = getModuleDllPath__cgen_142((*p).module, v);
		cgFormatValue__cgen_147((&res_2), T124_);
		res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_408));
		cgFormatValue__cgen_147((&res_2), (*v).loc.r);
		res_2 = resizeString(res_2, 10);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_409));
		T125_ = NIM_NIL;
		T125_ = rdLoc__cgen_435((*v).loc);
		cgFormatValue__cgen_147((&res_2), T125_);
		res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_410));
		cgFormatValue__cgen_147((&res_2), traverseProc);
		res_2 = resizeString(res_2, 11);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_411));
		cgFormatValue__cgen_147((&res_2), (*v).loc.r);
		res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_413));
		T126_ = NIM_NIL;
		T126_ = rope__ropes_109(res_2);
		T127_ = NIM_NIL;
		T127_ = indentLine__cgen_286(targetProc, T126_);
		add__ropes_159(T123_, T127_);
		T128_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T128_ = s__cgendata_225(targetProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_3 = rawNewString(((NI) 80));
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8));
		{
			if (!!((((*(*(*(*targetProc).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA131_;
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA131_: ;
		T133_ = NIM_NIL;
		T133_ = rope__ropes_109(res_3);
		T134_ = NIM_NIL;
		T134_ = indentLine__cgen_286(targetProc, T133_);
		add__ropes_159(T128_, T134_);
		T135_ = (NI)0;
		T135_ = startBlockInternal__cgen_13308(targetProc);
	}
	LA121_: ;
	{
		NIM_BOOL T138_;
		T138_ = (NIM_BOOL)0;
		T138_ = !(((*value).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)));
		if (!(T138_)) goto LA139_;
		T138_ = (valueAsRope == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL));
		LA139_: ;
		if (!T138_) goto LA140_;
		genLineDir__cgen_369(targetProc, vn);
		loadInto__cgen_13528(targetProc, vn, value, (&(*v).loc));
	}
	LA140_: ;
	{
		if (!forHcr) goto LA144_;
		endBlock__cgen_13329(targetProc);
	}
	LA144_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, putDataIntoDest__cgen_18780)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	{
		if (!!(((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0)))) goto LA3_;
		initLoc__cgen_66((&a), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 8), n, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 1));
		a.r = r;
		{
			if (!(((*d).flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 2))&15U)))!=0)) goto LA7_;
			genAssignment__cgen_10403(p, (*d), a, 0);
		}
		goto LA5_;
		LA7_: ;
		{
			genAssignment__cgen_10403(p, (*d), a, 1);
		}
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		(*d).k = ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 8);
		unsureAsgnRef((void**) (&(*d).lode), n);
		unsureAsgnRef((void**) (&(*d).r), r);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getLabel__cgen_11501)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T2_;
	result = NIM_NIL;
	(*p).labels += ((NI) 1);
	T1_ = NIM_NIL;
	T1_ = rope__ropes_115(((NI64) ((*p).labels)));
	T2_ = NIM_NIL;
	T2_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_466), T1_);
	result = amp___ropes_140(T2_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, fixLabel__cgen_11508)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* labl) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T1_;
	tyArray__ts9cf9blICas1QWmw89bglZ7w T2_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T3_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T4_;
	T1_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T1_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	nimZeroMem((void*)T2_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
	T2_[0] = labl;
	T3_ = NIM_NIL;
	T3_ = percent___cgen_11511(T2_, 1);
	T4_ = NIM_NIL;
	T4_ = indentLine__cgen_286(p, T3_);
	add__ropes_159(T1_, T4_);
}
N_LIB_PRIVATE N_NIMCALL(void, genAndOr__cgen_20420)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag m) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* L;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tmp;
	L = NIM_NIL;
	nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	getTemp__cgen_7373(p, (*e).typ, (&tmp), NIM_FALSE);
	(*p).splitDecls += ((NI) 1);
	expr__cgen_11525(p, (*e)._kind_6.sons->data[((NI) 1)], (&tmp));
	L = getLabel__cgen_11501(p);
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T5_;
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T6_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
		if (!(m == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 110))) goto LA3_;
		T5_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T5_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		nimZeroMem((void*)T6_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T6_[0] = rdLoc__cgen_435(tmp);
		T6_[1] = L;
		T7_ = NIM_NIL;
		T7_ = percent___cgen_20436(T6_, 2);
		T8_ = NIM_NIL;
		T8_ = indentLine__cgen_286(p, T7_);
		add__ropes_159(T5_, T8_);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T10_;
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T11_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
		T10_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T10_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		nimZeroMem((void*)T11_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T11_[0] = rdLoc__cgen_435(tmp);
		T11_[1] = L;
		T12_ = NIM_NIL;
		T12_ = percent___cgen_20441(T11_, 2);
		T13_ = NIM_NIL;
		T13_ = indentLine__cgen_286(p, T12_);
		add__ropes_159(T10_, T13_);
	}
	LA1_: ;
	expr__cgen_11525(p, (*e)._kind_6.sons->data[((NI) 2)], (&tmp));
	fixLabel__cgen_11508(p, L);
	{
		if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA16_;
		genericAssign((void*)(&(*d)), (void*)(&tmp), (&NTItloc__CAJV4zTUpZwr0j6Wy8FiFw_));
	}
	goto LA14_;
	LA16_: ;
	{
		genAssignment__cgen_10403(p, (*d), tmp, 0);
	}
	LA14_: ;
	(*p).splitDecls -= ((NI) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, unaryArith__cgen_19396)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag op) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	t = NIM_NIL;
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	t = skipTypes__ast_3723((*e).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_430);
	switch (op) {
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 96):
	{
		tyArray__FKvM4FDhljtt88k8FkGthA T2_;
		NI64 T3_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T4_;
		nimZeroMem((void*)T2_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
		T2_[0] = rdLoc__cgen_435(a);
		T3_ = (NI64)0;
		T3_ = getSize__types_3388((*(*(*p).module).g).config, t);
		T2_[1] = rope__ropes_115((NI64)(T3_ * IL64(8)));
		T2_[2] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T4_ = NIM_NIL;
		T4_ = percent___cgen_19414(T2_, 3);
		putIntoDest__cgen_18794(p, d, e, T4_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 97):
	{
		tyArray__FKvM4FDhljtt88k8FkGthA T6_;
		NI64 T7_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
		nimZeroMem((void*)T6_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
		T6_[0] = rdLoc__cgen_435(a);
		T7_ = (NI64)0;
		T7_ = getSize__types_3388((*(*(*p).module).g).config, t);
		T6_[1] = rope__ropes_115((NI64)(T7_ * IL64(8)));
		T6_[2] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T8_ = NIM_NIL;
		T8_ = percent___cgen_19419(T6_, 3);
		putIntoDest__cgen_18794(p, d, e, T8_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 98):
	{
		tyArray__FKvM4FDhljtt88k8FkGthA T10_;
		NI64 T11_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
		nimZeroMem((void*)T10_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
		T10_[0] = rdLoc__cgen_435(a);
		T11_ = (NI64)0;
		T11_ = getSize__types_3388((*(*(*p).module).g).config, t);
		T10_[1] = rope__ropes_115((NI64)(T11_ * IL64(8)));
		T10_[2] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T12_ = NIM_NIL;
		T12_ = percent___cgen_19424(T10_, 3);
		putIntoDest__cgen_18794(p, d, e, T12_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 99):
	{
		tyArray__FKvM4FDhljtt88k8FkGthA T14_;
		NI64 T15_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
		nimZeroMem((void*)T14_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
		T14_[0] = rdLoc__cgen_435(a);
		T15_ = (NI64)0;
		T15_ = getSize__types_3388((*(*(*p).module).g).config, t);
		T14_[1] = rope__ropes_115((NI64)(T15_ * IL64(8)));
		T14_[2] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T16_ = NIM_NIL;
		T16_ = percent___cgen_19419(T14_, 3);
		putIntoDest__cgen_18794(p, d, e, T16_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 100):
	{
		tyArray__FKvM4FDhljtt88k8FkGthA T18_;
		NI64 T19_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
		nimZeroMem((void*)T18_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
		T18_[0] = rdLoc__cgen_435(a);
		T19_ = (NI64)0;
		T19_ = getSize__types_3388((*(*(*p).module).g).config, t);
		T18_[1] = rope__ropes_115((NI64)(T19_ * IL64(8)));
		T18_[2] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T20_ = NIM_NIL;
		T20_ = percent___cgen_19092(T18_, 3);
		putIntoDest__cgen_18794(p, d, e, T20_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	default:
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, unaryArithOverflow__cgen_19054)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag m) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	t = NIM_NIL;
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	t = skipTypes__ast_3723((*e).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_430);
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T5_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T7_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
		if (!(((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 5))&31U)))!=0)) goto LA3_;
		T5_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T5_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
		T6_ = NIM_NIL;
		T6_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res), T6_);
		res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_467));
		T7_ = firstOrd__types_1406((*(*(*p).module).g).config, t);
		T8_ = NIM_NIL;
		T8_ = intLiteral__cgen_17773(T7_);
		cgFormatValue__cgen_147((&res), T8_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_468));
		T9_ = NIM_NIL;
		T9_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_469));
		cgFormatValue__cgen_147((&res), T9_);
		res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_436));
		T10_ = NIM_NIL;
		T10_ = raiseInstr__cgen_424(p);
		cgFormatValue__cgen_147((&res), T10_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA13_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA13_: ;
		T15_ = NIM_NIL;
		T15_ = rope__ropes_109(res);
		T16_ = NIM_NIL;
		T16_ = indentLine__cgen_286(p, T15_);
		add__ropes_159(T5_, T16_);
	}
	LA3_: ;
	switch (m) {
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 93):
	{
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T18_;
		NI64 T19_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
		nimZeroMem((void*)T18_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T18_[0] = rdLoc__cgen_435(a);
		T19_ = (NI64)0;
		T19_ = getSize__types_3388((*(*(*p).module).g).config, t);
		T18_[1] = rope__ropes_115((NI64)(T19_ * IL64(8)));
		T20_ = NIM_NIL;
		T20_ = percent___cgen_19087(T18_, 2);
		putIntoDest__cgen_18794(p, d, e, T20_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 94):
	{
		tyArray__ts9cf9blICas1QWmw89bglZ7w T22_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
		nimZeroMem((void*)T22_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T22_[0] = rdLoc__cgen_435(a);
		T23_ = NIM_NIL;
		T23_ = percent___cgen_19092(T22_, 1);
		putIntoDest__cgen_18794(p, d, e, T23_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 95):
	{
		tyArray__ts9cf9blICas1QWmw89bglZ7w T25_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
		nimZeroMem((void*)T25_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T25_[0] = rdLoc__cgen_435(a);
		T26_ = NIM_NIL;
		T26_ = percent___cgen_19097(T25_, 1);
		putIntoDest__cgen_18794(p, d, e, T26_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	default:
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, binaryArith__cgen_19108)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag op) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
	NI64 s;
	NI64 k;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1_;
	NI64 T2_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T3_;
	NI64 T4_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T5_;
	NI64 T6_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	s = (NI64)0;
	k = (NI64)0;
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
	T1_ = NIM_NIL;
	T1_ = t__cgen_85(a);
	T2_ = (NI64)0;
	T2_ = getSize__types_3388((*(*(*p).module).g).config, T1_);
	T3_ = NIM_NIL;
	T3_ = t__cgen_85(b);
	T4_ = (NI64)0;
	T4_ = getSize__types_3388((*(*(*p).module).g).config, T3_);
	s = (NI64)(((T2_ >= T4_) ? T2_ : T4_) * IL64(8));
	T5_ = NIM_NIL;
	T5_ = t__cgen_85(a);
	T6_ = (NI64)0;
	T6_ = getSize__types_3388((*(*(*p).module).g).config, T5_);
	k = (NI64)(T6_ * IL64(8));
	switch (op) {
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 53):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T8_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
		nimZeroMem((void*)T8_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T8_[0] = rdLoc__cgen_435(a);
		T8_[1] = rdLoc__cgen_435(b);
		T8_[2] = rope__ropes_115(s);
		T8_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T8_[4] = rope__ropes_115(k);
		T9_ = NIM_NIL;
		T9_ = percent___cgen_19137(T8_, 5);
		putIntoDest__cgen_18794(p, d, e, T9_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 54):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T11_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
		nimZeroMem((void*)T11_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T11_[0] = rdLoc__cgen_435(a);
		T11_[1] = rdLoc__cgen_435(b);
		T11_[2] = rope__ropes_115(s);
		T11_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T11_[4] = rope__ropes_115(k);
		T12_ = NIM_NIL;
		T12_ = percent___cgen_19142(T11_, 5);
		putIntoDest__cgen_18794(p, d, e, T12_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 55):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T14_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
		nimZeroMem((void*)T14_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T14_[0] = rdLoc__cgen_435(a);
		T14_[1] = rdLoc__cgen_435(b);
		T14_[2] = rope__ropes_115(s);
		T14_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T14_[4] = rope__ropes_115(k);
		T15_ = NIM_NIL;
		T15_ = percent___cgen_19147(T14_, 5);
		putIntoDest__cgen_18794(p, d, e, T15_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 56):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T17_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
		nimZeroMem((void*)T17_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T17_[0] = rdLoc__cgen_435(a);
		T17_[1] = rdLoc__cgen_435(b);
		T17_[2] = rope__ropes_115(s);
		T17_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T17_[4] = rope__ropes_115(k);
		T18_ = NIM_NIL;
		T18_ = percent___cgen_19152(T17_, 5);
		putIntoDest__cgen_18794(p, d, e, T18_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 57):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T20_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T21_;
		nimZeroMem((void*)T20_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T20_[0] = rdLoc__cgen_435(a);
		T20_[1] = rdLoc__cgen_435(b);
		T20_[2] = rope__ropes_115(s);
		T20_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T20_[4] = rope__ropes_115(k);
		T21_ = NIM_NIL;
		T21_ = percent___cgen_19157(T20_, 5);
		putIntoDest__cgen_18794(p, d, e, T21_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 58):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T23_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
		nimZeroMem((void*)T23_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T23_[0] = rdLoc__cgen_435(a);
		T23_[1] = rdLoc__cgen_435(b);
		T23_[2] = rope__ropes_115(s);
		T23_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T23_[4] = rope__ropes_115(k);
		T24_ = NIM_NIL;
		T24_ = percent___cgen_19162(T23_, 5);
		putIntoDest__cgen_18794(p, d, e, T24_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 59):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T26_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T27_;
		nimZeroMem((void*)T26_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T26_[0] = rdLoc__cgen_435(a);
		T26_[1] = rdLoc__cgen_435(b);
		T26_[2] = rope__ropes_115(s);
		T26_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T26_[4] = rope__ropes_115(k);
		T27_ = NIM_NIL;
		T27_ = percent___cgen_19167(T26_, 5);
		putIntoDest__cgen_18794(p, d, e, T27_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 60):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T29_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T30_;
		nimZeroMem((void*)T29_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T29_[0] = rdLoc__cgen_435(a);
		T29_[1] = rdLoc__cgen_435(b);
		T29_[2] = rope__ropes_115(s);
		T29_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T29_[4] = rope__ropes_115(k);
		T30_ = NIM_NIL;
		T30_ = percent___cgen_19172(T29_, 5);
		putIntoDest__cgen_18794(p, d, e, T30_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 61):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T32_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T33_;
		nimZeroMem((void*)T32_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T32_[0] = rdLoc__cgen_435(a);
		T32_[1] = rdLoc__cgen_435(b);
		T32_[2] = rope__ropes_115(s);
		T32_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T32_[4] = rope__ropes_115(k);
		T33_ = NIM_NIL;
		T33_ = percent___cgen_19177(T32_, 5);
		putIntoDest__cgen_18794(p, d, e, T33_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 62):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T35_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T36_;
		nimZeroMem((void*)T35_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T35_[0] = rdLoc__cgen_435(a);
		T35_[1] = rdLoc__cgen_435(b);
		T35_[2] = rope__ropes_115(s);
		T35_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T35_[4] = rope__ropes_115(k);
		T36_ = NIM_NIL;
		T36_ = percent___cgen_19182(T35_, 5);
		putIntoDest__cgen_18794(p, d, e, T36_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 63):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T38_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T39_;
		nimZeroMem((void*)T38_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T38_[0] = rdLoc__cgen_435(a);
		T38_[1] = rdLoc__cgen_435(b);
		T38_[2] = rope__ropes_115(s);
		T38_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T38_[4] = rope__ropes_115(k);
		T39_ = NIM_NIL;
		T39_ = percent___cgen_19187(T38_, 5);
		putIntoDest__cgen_18794(p, d, e, T39_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 64):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T41_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T42_;
		nimZeroMem((void*)T41_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T41_[0] = rdLoc__cgen_435(a);
		T41_[1] = rdLoc__cgen_435(b);
		T41_[2] = rope__ropes_115(s);
		T41_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T41_[4] = rope__ropes_115(k);
		T42_ = NIM_NIL;
		T42_ = percent___cgen_19192(T41_, 5);
		putIntoDest__cgen_18794(p, d, e, T42_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 65):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T44_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T45_;
		nimZeroMem((void*)T44_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T44_[0] = rdLoc__cgen_435(a);
		T44_[1] = rdLoc__cgen_435(b);
		T44_[2] = rope__ropes_115(s);
		T44_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T44_[4] = rope__ropes_115(k);
		T45_ = NIM_NIL;
		T45_ = percent___cgen_19197(T44_, 5);
		putIntoDest__cgen_18794(p, d, e, T45_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 66):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T47_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T48_;
		nimZeroMem((void*)T47_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T47_[0] = rdLoc__cgen_435(a);
		T47_[1] = rdLoc__cgen_435(b);
		T47_[2] = rope__ropes_115(s);
		T47_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T47_[4] = rope__ropes_115(k);
		T48_ = NIM_NIL;
		T48_ = percent___cgen_19202(T47_, 5);
		putIntoDest__cgen_18794(p, d, e, T48_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 67):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T50_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T51_;
		nimZeroMem((void*)T50_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T50_[0] = rdLoc__cgen_435(a);
		T50_[1] = rdLoc__cgen_435(b);
		T50_[2] = rope__ropes_115(s);
		T50_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T50_[4] = rope__ropes_115(k);
		T51_ = NIM_NIL;
		T51_ = percent___cgen_19207(T50_, 5);
		putIntoDest__cgen_18794(p, d, e, T51_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 68):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T53_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T54_;
		nimZeroMem((void*)T53_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T53_[0] = rdLoc__cgen_435(a);
		T53_[1] = rdLoc__cgen_435(b);
		T53_[2] = rope__ropes_115(s);
		T53_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T53_[4] = rope__ropes_115(k);
		T54_ = NIM_NIL;
		T54_ = percent___cgen_19212(T53_, 5);
		putIntoDest__cgen_18794(p, d, e, T54_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 69):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T56_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T57_;
		nimZeroMem((void*)T56_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T56_[0] = rdLoc__cgen_435(a);
		T56_[1] = rdLoc__cgen_435(b);
		T56_[2] = rope__ropes_115(s);
		T56_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T56_[4] = rope__ropes_115(k);
		T57_ = NIM_NIL;
		T57_ = percent___cgen_19217(T56_, 5);
		putIntoDest__cgen_18794(p, d, e, T57_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 70):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T59_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T60_;
		nimZeroMem((void*)T59_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T59_[0] = rdLoc__cgen_435(a);
		T59_[1] = rdLoc__cgen_435(b);
		T59_[2] = rope__ropes_115(s);
		T59_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T59_[4] = rope__ropes_115(k);
		T60_ = NIM_NIL;
		T60_ = percent___cgen_19222(T59_, 5);
		putIntoDest__cgen_18794(p, d, e, T60_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 71):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T62_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T63_;
		nimZeroMem((void*)T62_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T62_[0] = rdLoc__cgen_435(a);
		T62_[1] = rdLoc__cgen_435(b);
		T62_[2] = rope__ropes_115(s);
		T62_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T62_[4] = rope__ropes_115(k);
		T63_ = NIM_NIL;
		T63_ = percent___cgen_19227(T62_, 5);
		putIntoDest__cgen_18794(p, d, e, T63_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 72):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T65_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T66_;
		nimZeroMem((void*)T65_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T65_[0] = rdLoc__cgen_435(a);
		T65_[1] = rdLoc__cgen_435(b);
		T65_[2] = rope__ropes_115(s);
		T65_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T65_[4] = rope__ropes_115(k);
		T66_ = NIM_NIL;
		T66_ = percent___cgen_19232(T65_, 5);
		putIntoDest__cgen_18794(p, d, e, T66_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 73):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T68_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T69_;
		nimZeroMem((void*)T68_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T68_[0] = rdLoc__cgen_435(a);
		T68_[1] = rdLoc__cgen_435(b);
		T68_[2] = rope__ropes_115(s);
		T68_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T68_[4] = rope__ropes_115(k);
		T69_ = NIM_NIL;
		T69_ = percent___cgen_19222(T68_, 5);
		putIntoDest__cgen_18794(p, d, e, T69_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 74):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T71_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T72_;
		nimZeroMem((void*)T71_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T71_[0] = rdLoc__cgen_435(a);
		T71_[1] = rdLoc__cgen_435(b);
		T71_[2] = rope__ropes_115(s);
		T71_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T71_[4] = rope__ropes_115(k);
		T72_ = NIM_NIL;
		T72_ = percent___cgen_19227(T71_, 5);
		putIntoDest__cgen_18794(p, d, e, T72_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 75):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T74_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T75_;
		nimZeroMem((void*)T74_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T74_[0] = rdLoc__cgen_435(a);
		T74_[1] = rdLoc__cgen_435(b);
		T74_[2] = rope__ropes_115(s);
		T74_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T74_[4] = rope__ropes_115(k);
		T75_ = NIM_NIL;
		T75_ = percent___cgen_19232(T74_, 5);
		putIntoDest__cgen_18794(p, d, e, T75_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 76):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T77_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T78_;
		nimZeroMem((void*)T77_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T77_[0] = rdLoc__cgen_435(a);
		T77_[1] = rdLoc__cgen_435(b);
		T77_[2] = rope__ropes_115(s);
		T77_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T77_[4] = rope__ropes_115(k);
		T78_ = NIM_NIL;
		T78_ = percent___cgen_19249(T77_, 5);
		putIntoDest__cgen_18794(p, d, e, T78_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 77):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T80_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T81_;
		nimZeroMem((void*)T80_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T80_[0] = rdLoc__cgen_435(a);
		T80_[1] = rdLoc__cgen_435(b);
		T80_[2] = rope__ropes_115(s);
		T80_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T80_[4] = rope__ropes_115(k);
		T81_ = NIM_NIL;
		T81_ = percent___cgen_19254(T80_, 5);
		putIntoDest__cgen_18794(p, d, e, T81_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 78):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T83_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T84_;
		nimZeroMem((void*)T83_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T83_[0] = rdLoc__cgen_435(a);
		T83_[1] = rdLoc__cgen_435(b);
		T83_[2] = rope__ropes_115(s);
		T83_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T83_[4] = rope__ropes_115(k);
		T84_ = NIM_NIL;
		T84_ = percent___cgen_19222(T83_, 5);
		putIntoDest__cgen_18794(p, d, e, T84_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 79):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T86_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T87_;
		nimZeroMem((void*)T86_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T86_[0] = rdLoc__cgen_435(a);
		T86_[1] = rdLoc__cgen_435(b);
		T86_[2] = rope__ropes_115(s);
		T86_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T86_[4] = rope__ropes_115(k);
		T87_ = NIM_NIL;
		T87_ = percent___cgen_19227(T86_, 5);
		putIntoDest__cgen_18794(p, d, e, T87_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 80):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T89_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T90_;
		nimZeroMem((void*)T89_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T89_[0] = rdLoc__cgen_435(a);
		T89_[1] = rdLoc__cgen_435(b);
		T89_[2] = rope__ropes_115(s);
		T89_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T89_[4] = rope__ropes_115(k);
		T90_ = NIM_NIL;
		T90_ = percent___cgen_19232(T89_, 5);
		putIntoDest__cgen_18794(p, d, e, T90_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 81):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T92_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T93_;
		nimZeroMem((void*)T92_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T92_[0] = rdLoc__cgen_435(a);
		T92_[1] = rdLoc__cgen_435(b);
		T92_[2] = rope__ropes_115(s);
		T92_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T92_[4] = rope__ropes_115(k);
		T93_ = NIM_NIL;
		T93_ = percent___cgen_19271(T92_, 5);
		putIntoDest__cgen_18794(p, d, e, T93_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 82):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T95_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T96_;
		nimZeroMem((void*)T95_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T95_[0] = rdLoc__cgen_435(a);
		T95_[1] = rdLoc__cgen_435(b);
		T95_[2] = rope__ropes_115(s);
		T95_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T95_[4] = rope__ropes_115(k);
		T96_ = NIM_NIL;
		T96_ = percent___cgen_19276(T95_, 5);
		putIntoDest__cgen_18794(p, d, e, T96_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 83):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T98_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T99_;
		nimZeroMem((void*)T98_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T98_[0] = rdLoc__cgen_435(a);
		T98_[1] = rdLoc__cgen_435(b);
		T98_[2] = rope__ropes_115(s);
		T98_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T98_[4] = rope__ropes_115(k);
		T99_ = NIM_NIL;
		T99_ = percent___cgen_19281(T98_, 5);
		putIntoDest__cgen_18794(p, d, e, T99_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 84):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T101_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T102_;
		nimZeroMem((void*)T101_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T101_[0] = rdLoc__cgen_435(a);
		T101_[1] = rdLoc__cgen_435(b);
		T101_[2] = rope__ropes_115(s);
		T101_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T101_[4] = rope__ropes_115(k);
		T102_ = NIM_NIL;
		T102_ = percent___cgen_19222(T101_, 5);
		putIntoDest__cgen_18794(p, d, e, T102_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 85):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T104_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T105_;
		nimZeroMem((void*)T104_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T104_[0] = rdLoc__cgen_435(a);
		T104_[1] = rdLoc__cgen_435(b);
		T104_[2] = rope__ropes_115(s);
		T104_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T104_[4] = rope__ropes_115(k);
		T105_ = NIM_NIL;
		T105_ = percent___cgen_19227(T104_, 5);
		putIntoDest__cgen_18794(p, d, e, T105_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 86):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T107_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T108_;
		nimZeroMem((void*)T107_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T107_[0] = rdLoc__cgen_435(a);
		T107_[1] = rdLoc__cgen_435(b);
		T107_[2] = rope__ropes_115(s);
		T107_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T107_[4] = rope__ropes_115(k);
		T108_ = NIM_NIL;
		T108_ = percent___cgen_19232(T107_, 5);
		putIntoDest__cgen_18794(p, d, e, T108_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 87):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T110_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T111_;
		nimZeroMem((void*)T110_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T110_[0] = rdLoc__cgen_435(a);
		T110_[1] = rdLoc__cgen_435(b);
		T110_[2] = rope__ropes_115(s);
		T110_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T110_[4] = rope__ropes_115(k);
		T111_ = NIM_NIL;
		T111_ = percent___cgen_19222(T110_, 5);
		putIntoDest__cgen_18794(p, d, e, T111_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 88):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T113_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T114_;
		nimZeroMem((void*)T113_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T113_[0] = rdLoc__cgen_435(a);
		T113_[1] = rdLoc__cgen_435(b);
		T113_[2] = rope__ropes_115(s);
		T113_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T113_[4] = rope__ropes_115(k);
		T114_ = NIM_NIL;
		T114_ = percent___cgen_19227(T113_, 5);
		putIntoDest__cgen_18794(p, d, e, T114_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 89):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T116_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T117_;
		nimZeroMem((void*)T116_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T116_[0] = rdLoc__cgen_435(a);
		T116_[1] = rdLoc__cgen_435(b);
		T116_[2] = rope__ropes_115(s);
		T116_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T116_[4] = rope__ropes_115(k);
		T117_ = NIM_NIL;
		T117_ = percent___cgen_19232(T116_, 5);
		putIntoDest__cgen_18794(p, d, e, T117_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 90):
	{
		tyArray__XSZGJHCjWme3CUmFzckT3g T119_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T120_;
		nimZeroMem((void*)T119_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T119_[0] = rdLoc__cgen_435(a);
		T119_[1] = rdLoc__cgen_435(b);
		T119_[2] = rope__ropes_115(s);
		T119_[3] = getSimpleTypeDesc__cgen_1830((*p).module, (*e).typ);
		T119_[4] = rope__ropes_115(k);
		T120_ = NIM_NIL;
		T120_ = percent___cgen_19310(T119_, 5);
		putIntoDest__cgen_18794(p, d, e, T120_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	default:
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, binaryFloatArith__cgen_23223)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag m) {
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
		if (!!(((384 & (*p).options) == 0))) goto LA3_;
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_29));
		T5_ = NIM_NIL;
		T5_ = getSimpleTypeDesc__cgen_1830((*p).module, (*(*e)._kind_6.sons->data[((NI) 1)]).typ);
		cgFormatValue__cgen_147((&res), T5_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_470));
		T6_ = NIM_NIL;
		T6_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res), T6_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_56));
		cgFormatValue__cgen_151((&res), opr__cgen_23236[(m)- 53]);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_472));
		T7_ = NIM_NIL;
		T7_ = getSimpleTypeDesc__cgen_1830((*p).module, (*(*e)._kind_6.sons->data[((NI) 1)]).typ);
		cgFormatValue__cgen_147((&res), T7_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_470));
		T8_ = NIM_NIL;
		T8_ = rdLoc__cgen_435(b);
		cgFormatValue__cgen_147((&res), T8_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_41));
		T9_ = NIM_NIL;
		T9_ = rope__ropes_109(res);
		putIntoDest__cgen_18794(p, d, e, T9_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T14_;
			NimStringDesc* res_2;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
			if (!(((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 7))&31U)))!=0)) goto LA12_;
			T14_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T14_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_2 = rawNewString(((NI) 80));
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
			T15_ = NIM_NIL;
			T15_ = rdLoc__cgen_435((*d));
			cgFormatValue__cgen_147((&res_2), T15_);
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_473));
			T16_ = NIM_NIL;
			T16_ = rdLoc__cgen_435((*d));
			cgFormatValue__cgen_147((&res_2), T16_);
			res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_468));
			T17_ = NIM_NIL;
			T17_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_474));
			cgFormatValue__cgen_147((&res_2), T17_);
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_436));
			T18_ = NIM_NIL;
			T18_ = raiseInstr__cgen_424(p);
			cgFormatValue__cgen_147((&res_2), T18_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA21_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA21_: ;
			T23_ = NIM_NIL;
			T23_ = rope__ropes_109(res_2);
			T24_ = NIM_NIL;
			T24_ = indentLine__cgen_286(p, T23_);
			add__ropes_159(T14_, T24_);
		}
		LA12_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T29_;
			NimStringDesc* res_3;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T30_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T31_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T32_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T33_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T34_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T35_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T40_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T41_;
			if (!(((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 8))&31U)))!=0)) goto LA27_;
			T29_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T29_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_3 = rawNewString(((NI) 80));
			res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
			T30_ = NIM_NIL;
			T30_ = rdLoc__cgen_435((*d));
			cgFormatValue__cgen_147((&res_3), T30_);
			res_3 = resizeString(res_3, 11);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_475));
			T31_ = NIM_NIL;
			T31_ = rdLoc__cgen_435((*d));
			cgFormatValue__cgen_147((&res_3), T31_);
			res_3 = resizeString(res_3, 8);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_476));
			T32_ = NIM_NIL;
			T32_ = rdLoc__cgen_435((*d));
			cgFormatValue__cgen_147((&res_3), T32_);
			res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_477));
			T33_ = NIM_NIL;
			T33_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_478));
			cgFormatValue__cgen_147((&res_3), T33_);
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T34_ = NIM_NIL;
			T34_ = rdLoc__cgen_435((*d));
			cgFormatValue__cgen_147((&res_3), T34_);
			res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_437));
			T35_ = NIM_NIL;
			T35_ = raiseInstr__cgen_424(p);
			cgFormatValue__cgen_147((&res_3), T35_);
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA38_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA38_: ;
			T40_ = NIM_NIL;
			T40_ = rope__ropes_109(res_3);
			T41_ = NIM_NIL;
			T41_ = indentLine__cgen_286(p, T40_);
			add__ropes_159(T29_, T41_);
		}
		LA27_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		binaryArith__cgen_19108(p, e, d, m);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genEqProc__cgen_19321)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T3_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T4_;
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T7_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
		T3_ = NIM_NIL;
		T3_ = t__cgen_85(a);
		T4_ = NIM_NIL;
		T4_ = skipTypes__ast_3723(T3_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_155);
		if (!((*T4_).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9))) goto LA5_;
		nimZeroMem((void*)T7_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T7_[0] = rdLoc__cgen_435(a);
		T7_[1] = rdLoc__cgen_435(b);
		T8_ = NIM_NIL;
		T8_ = percent___cgen_19349(T7_, 2);
		putIntoDest__cgen_18794(p, d, e, T8_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	goto LA1_;
	LA5_: ;
	{
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T10_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
		nimZeroMem((void*)T10_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T10_[0] = rdLoc__cgen_435(a);
		T10_[1] = rdLoc__cgen_435(b);
		T11_ = NIM_NIL;
		T11_ = percent___cgen_19222(T10_, 2);
		putIntoDest__cgen_18794(p, d, e, T11_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, binaryArithOverflow__cgen_18902)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag m) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
	t = skipTypes__ast_3723((*e).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_430);
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* res;
		tyArray__InO6xIOhXMnkCXPnEYWwWg T5_;
		if (!!((((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 5))&31U)))!=0))) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
		T5_[0] = getTypeDesc__cgen_6662((*p).module, (*e).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		T5_[1] = rdLoc__cgen_435(a);
		T5_[2] = rope__ropes_109(opr__cgen_18909[(m)- 46]);
		T5_[3] = rdLoc__cgen_435(b);
		res = percent___cgen_18935(T5_, 4);
		putIntoDest__cgen_18794(p, d, e, res, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL needsOverflowCheck;
		needsOverflowCheck = NIM_TRUE;
		{
			NIM_BOOL canBeZero;
			if (!(m == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 49) || m == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 50))) goto LA9_;
			canBeZero = NIM_TRUE;
			{
				if (!((*(*e)._kind_6.sons->data[((NI) 2)]).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6) && (*(*e)._kind_6.sons->data[((NI) 2)]).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 15))) goto LA13_;
				canBeZero = ((*(*e)._kind_6.sons->data[((NI) 2)])._kind_1.intVal == IL64(0));
			}
			LA13_: ;
			{
				if (!((*(*e)._kind_6.sons->data[((NI) 2)]).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6) && (*(*e)._kind_6.sons->data[((NI) 2)]).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 10))) goto LA17_;
				needsOverflowCheck = ((*(*e)._kind_6.sons->data[((NI) 2)])._kind_1.intVal == IL64(-1));
			}
			LA17_: ;
			{
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T23_;
				NimStringDesc* res_2;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T31_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T32_;
				if (!canBeZero) goto LA21_;
				T23_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T23_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_2 = rawNewString(((NI) 80));
				res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
				T24_ = NIM_NIL;
				T24_ = rdLoc__cgen_435(b);
				cgFormatValue__cgen_147((&res_2), T24_);
				res_2 = resizeString(res_2, 8);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_480));
				T25_ = NIM_NIL;
				T25_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_481));
				cgFormatValue__cgen_147((&res_2), T25_);
				res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_436));
				T26_ = NIM_NIL;
				T26_ = raiseInstr__cgen_424(p);
				cgFormatValue__cgen_147((&res_2), T26_);
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA29_;
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA29_: ;
				T31_ = NIM_NIL;
				T31_ = rope__ropes_109(res_2);
				T32_ = NIM_NIL;
				T32_ = indentLine__cgen_286(p, T31_);
				add__ropes_159(T23_, T32_);
			}
			LA21_: ;
		}
		LA9_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* res_3;
			NI64 sizeX60gensym3724_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* storageX60gensym3724_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* resultX60gensym3724_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T42_;
			NimStringDesc* res_4;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T47_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T48_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T49_;
			NimStringDesc* res_5;
			NimStringDesc* T50_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T56_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T57_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T58_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T59_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T60_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T65_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T66_;
			tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T86_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T87_;
			if (!needsOverflowCheck) goto LA35_;
			sizeX60gensym3724_ = getSize__types_3388((*(*(*p).module).g).config, t);
			{
				if (!(sizeX60gensym3724_ < ((NI64) ((*(*(*(*p).module).g).config).target.intSize)))) goto LA39_;
				storageX60gensym3724_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_340));
			}
			goto LA37_;
			LA39_: ;
			{
				storageX60gensym3724_ = getTypeDesc__cgen_6662((*p).module, t, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			}
			LA37_: ;
			resultX60gensym3724_ = getTempName__cgen_428((*p).module);
			T42_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T42_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
			res_4 = rawNewString(((NI) 80));
			cgFormatValue__cgen_147((&res_4), storageX60gensym3724_);
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_13));
			cgFormatValue__cgen_147((&res_4), resultX60gensym3724_);
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA45_;
				res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA45_: ;
			T47_ = NIM_NIL;
			T47_ = rope__ropes_109(res_4);
			T48_ = NIM_NIL;
			T48_ = indentLine__cgen_286(p, T47_);
			add__ropes_159(T42_, T48_);
			T49_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T49_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_5 = rawNewString(((NI) 80));
			res_5 = resizeString(res_5, 4);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
			T50_ = NIM_NIL;
			{
				if (!((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35))) goto LA53_;
				T50_ = copyString(prc64__cgen_18908[(m)- 46]);
			}
			goto LA51_;
			LA53_: ;
			{
				T50_ = copyString(prc__cgen_18907[(m)- 46]);
			}
			LA51_: ;
			T56_ = NIM_NIL;
			T56_ = cgsym__cgen_126((*p).module, T50_);
			cgFormatValue__cgen_147((&res_5), T56_);
			res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T57_ = NIM_NIL;
			T57_ = rdCharLoc__cgen_10377(a);
			cgFormatValue__cgen_147((&res_5), T57_);
			res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			T58_ = NIM_NIL;
			T58_ = rdCharLoc__cgen_10377(b);
			cgFormatValue__cgen_147((&res_5), T58_);
			res_5 = resizeString(res_5, 3);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_492));
			cgFormatValue__cgen_147((&res_5), resultX60gensym3724_);
			res_5 = resizeString(res_5, 5);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_493));
			T59_ = NIM_NIL;
			T59_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_469));
			cgFormatValue__cgen_147((&res_5), T59_);
			res_5 = resizeString(res_5, 4);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_436));
			T60_ = NIM_NIL;
			T60_ = raiseInstr__cgen_424(p);
			cgFormatValue__cgen_147((&res_5), T60_);
			res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_230));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA63_;
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA63_: ;
			T65_ = NIM_NIL;
			T65_ = rope__ropes_109(res_5);
			T66_ = NIM_NIL;
			T66_ = indentLine__cgen_286(p, T65_);
			add__ropes_159(T49_, T66_);
			{
				NIM_BOOL T69_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T73_;
				NimStringDesc* res_6;
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T74_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T75_;
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T76_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T77_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T78_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T79_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T84_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T85_;
				T69_ = (NIM_BOOL)0;
				T69_ = (sizeX60gensym3724_ < ((NI64) ((*(*(*(*p).module).g).config).target.intSize)));
				if (T69_) goto LA70_;
				T69_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 20) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14));
				LA70_: ;
				if (!T69_) goto LA71_;
				T73_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T73_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_6 = rawNewString(((NI) 80));
				res_6 = resizeString(res_6, 4);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
				cgFormatValue__cgen_147((&res_6), resultX60gensym3724_);
				res_6 = resizeString(res_6, 3);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_163));
				T74_ = firstOrd__types_1406((*(*(*p).module).g).config, t);
				T75_ = NIM_NIL;
				T75_ = intLiteral__cgen_17773(T74_);
				cgFormatValue__cgen_147((&res_6), T75_);
				res_6 = resizeString(res_6, 4);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_432));
				cgFormatValue__cgen_147((&res_6), resultX60gensym3724_);
				res_6 = resizeString(res_6, 3);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_433));
				T76_ = lastOrd__types_1532((*(*(*p).module).g).config, t);
				T77_ = NIM_NIL;
				T77_ = intLiteral__cgen_17773(T76_);
				cgFormatValue__cgen_147((&res_6), T77_);
				res_6 = resizeString(res_6, 3);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_468));
				T78_ = NIM_NIL;
				T78_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_469));
				cgFormatValue__cgen_147((&res_6), T78_);
				res_6 = resizeString(res_6, 4);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_436));
				T79_ = NIM_NIL;
				T79_ = raiseInstr__cgen_424(p);
				cgFormatValue__cgen_147((&res_6), T79_);
				res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA82_;
					res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA82_: ;
				T84_ = NIM_NIL;
				T84_ = rope__ropes_109(res_6);
				T85_ = NIM_NIL;
				T85_ = indentLine__cgen_286(p, T84_);
				add__ropes_159(T73_, T85_);
			}
			LA71_: ;
			res_3 = resultX60gensym3724_;
			nimZeroMem((void*)T86_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
			T86_[0] = getTypeDesc__cgen_6662((*p).module, (*e).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			T86_[1] = res_3;
			T87_ = NIM_NIL;
			T87_ = percent___cgen_19026(T86_, 2);
			putIntoDest__cgen_18794(p, d, e, T87_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
		}
		goto LA33_;
		LA35_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* res_7;
			tyArray__InO6xIOhXMnkCXPnEYWwWg T89_;
			nimZeroMem((void*)T89_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
			T89_[0] = getTypeDesc__cgen_6662((*p).module, (*e).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			T89_[1] = rdLoc__cgen_435(a);
			T89_[2] = rope__ropes_109(opr__cgen_18909[(m)- 46]);
			T89_[3] = rdLoc__cgen_435(b);
			res_7 = percent___cgen_18935(T89_, 4);
			putIntoDest__cgen_18794(p, d, e, res_7, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
		}
		LA33_: ;
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, gcUsage__cgen_20553)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NimStringDesc* T5_;
		if (!((*conf).selectedGC == ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 1))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = renderTree__renderer_46(n, 0);
		liMessage__msgs_1128(conf, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 51), T5_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_511, NIM_FALSE);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genRepr__cgen_21666)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	{
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 41))&63U)))!=0)) goto LA3_;
		liMessage__msgs_1128((*(*(*p).module).g).config, (*e).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_494), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_495, NIM_FALSE);
	}
	LA3_: ;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	t = skipTypes__ast_3723((*(*e)._kind_6.sons->data[((NI) 1)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_183);
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44):
	{
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
		res = rawNewString(((NI) 80));
		T6_ = NIM_NIL;
		T6_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_496));
		cgFormatValue__cgen_147((&res), T6_);
		res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_497));
		T7_ = NIM_NIL;
		T7_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res), T7_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		T8_ = NIM_NIL;
		T8_ = rope__ropes_109(res);
		putIntoDest__cgen_18794(p, d, e, T8_, a.storage);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 39):
	{
		NimStringDesc* res_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
		res_2 = rawNewString(((NI) 80));
		T10_ = NIM_NIL;
		T10_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_498));
		cgFormatValue__cgen_147((&res_2), T10_);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T11_ = NIM_NIL;
		T11_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res_2), T11_);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		T12_ = NIM_NIL;
		T12_ = rope__ropes_109(res_2);
		putIntoDest__cgen_18794(p, d, e, T12_, a.storage);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1):
	{
		NimStringDesc* res_3;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
		res_3 = rawNewString(((NI) 80));
		T14_ = NIM_NIL;
		T14_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_499));
		cgFormatValue__cgen_147((&res_3), T14_);
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T15_ = NIM_NIL;
		T15_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res_3), T15_);
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		T16_ = NIM_NIL;
		T16_ = rope__ropes_109(res_3);
		putIntoDest__cgen_18794(p, d, e, T16_, a.storage);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2):
	{
		NimStringDesc* res_4;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
		res_4 = rawNewString(((NI) 80));
		T18_ = NIM_NIL;
		T18_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_500));
		cgFormatValue__cgen_147((&res_4), T18_);
		res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T19_ = NIM_NIL;
		T19_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res_4), T19_);
		res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		T20_ = NIM_NIL;
		T20_ = rope__ropes_109(res_4);
		putIntoDest__cgen_18794(p, d, e, T20_, a.storage);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 15):
	{
		NimStringDesc* res_5;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
		res_5 = rawNewString(((NI) 80));
		T22_ = NIM_NIL;
		T22_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_501));
		cgFormatValue__cgen_147((&res_5), T22_);
		res_5 = resizeString(res_5, 5);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_502));
		T23_ = NIM_NIL;
		T23_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res_5), T23_);
		res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		T24_ = NIM_NIL;
		T24_ = genTypeInfoV1__cgen_6798((*p).module, t, (*e).info);
		cgFormatValue__cgen_147((&res_5), T24_);
		res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		T25_ = NIM_NIL;
		T25_ = rope__ropes_109(res_5);
		putIntoDest__cgen_18794(p, d, e, T25_, a.storage);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
	{
		NimStringDesc* res_6;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T27_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T28_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T29_;
		res_6 = rawNewString(((NI) 80));
		T27_ = NIM_NIL;
		T27_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_503));
		cgFormatValue__cgen_147((&res_6), T27_);
		res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T28_ = NIM_NIL;
		T28_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res_6), T28_);
		res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		T29_ = NIM_NIL;
		T29_ = rope__ropes_109(res_6);
		putIntoDest__cgen_18794(p, d, e, T29_, a.storage);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 19):
	{
		NimStringDesc* res_7;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T31_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T32_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T33_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T34_;
		res_7 = rawNewString(((NI) 80));
		T31_ = NIM_NIL;
		T31_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_504));
		cgFormatValue__cgen_147((&res_7), T31_);
		res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T32_ = NIM_NIL;
		T32_ = addrLoc__cgen_10337((*(*(*p).module).g).config, a);
		cgFormatValue__cgen_147((&res_7), T32_);
		res_7 = resizeString(res_7, 2);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		T33_ = NIM_NIL;
		T33_ = genTypeInfoV1__cgen_6798((*p).module, t, (*e).info);
		cgFormatValue__cgen_147((&res_7), T33_);
		res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		T34_ = NIM_NIL;
		T34_ = rope__ropes_109(res_7);
		putIntoDest__cgen_18794(p, d, e, T34_, a.storage);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48):
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T36_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T37_;
		NimStringDesc* res_8;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T51_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T52_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T53_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T54_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T55_;
		nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		T36_ = NIM_NIL;
		T36_ = t__cgen_85(a);
		T37_ = NIM_NIL;
		T37_ = skipTypes__ast_3723(T36_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_183);
		switch ((*T37_).kind) {
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27):
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48):
		{
			tyArray__ts9cf9blICas1QWmw89bglZ7w T39_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T40_;
			nimZeroMem((void*)T39_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T39_[0] = rdLoc__cgen_435(a);
			T40_ = NIM_NIL;
			T40_ = percent___cgen_12034(T39_, 1);
			putIntoDest__cgen_18794(p, (&b), e, T40_, a.storage);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
		{
			tyArray__InO6xIOhXMnkCXPnEYWwWg T42_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T43_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T44_;
			nimZeroMem((void*)T42_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
			T42_[0] = rdLoc__cgen_435(a);
			T42_[1] = lenExpr__cgen_458(p, a);
			T42_[2] = dataField__cgen_479(p);
			T43_ = NIM_NIL;
			T43_ = rdLoc__cgen_435(a);
			T42_[3] = dataFieldAccessor__cgen_471(p, T43_);
			T44_ = NIM_NIL;
			T44_ = percent___cgen_12087(T42_, 4);
			putIntoDest__cgen_18794(p, (&b), e, T44_, a.storage);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
		{
			tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T46_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T47_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T48_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T49_;
			nimZeroMem((void*)T46_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
			T46_[0] = rdLoc__cgen_435(a);
			T47_ = NIM_NIL;
			T47_ = t__cgen_85(a);
			T48_ = lengthOrd__types_1723((*(*(*p).module).g).config, T47_);
			T46_[1] = rope__cgen_6948(T48_);
			T49_ = NIM_NIL;
			T49_ = percent___cgen_12092(T46_, 2);
			putIntoDest__cgen_18794(p, (&b), e, T49_, a.storage);
		}
		break;
		default:
		{
			internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*(*e)._kind_6.sons->data[((NI) 0)]).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_505), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_506);
		}
		break;
		}
		res_8 = rawNewString(((NI) 80));
		T51_ = NIM_NIL;
		T51_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_507));
		cgFormatValue__cgen_147((&res_8), T51_);
		res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T52_ = NIM_NIL;
		T52_ = rdLoc__cgen_435(b);
		cgFormatValue__cgen_147((&res_8), T52_);
		res_8 = resizeString(res_8, 2);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		T53_ = NIM_NIL;
		T53_ = elemType__types_263(t);
		T54_ = NIM_NIL;
		T54_ = genTypeInfoV1__cgen_6798((*p).module, T53_, (*e).info);
		cgFormatValue__cgen_147((&res_8), T54_);
		res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		T55_ = NIM_NIL;
		T55_ = rope__ropes_109(res_8);
		putIntoDest__cgen_18794(p, d, e, T55_, a.storage);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 26):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 5):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
	{
		NimStringDesc* res_9;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T57_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T58_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T59_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T60_;
		res_9 = rawNewString(((NI) 80));
		T57_ = NIM_NIL;
		T57_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_508));
		cgFormatValue__cgen_147((&res_9), T57_);
		res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T58_ = NIM_NIL;
		T58_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res_9), T58_);
		res_9 = resizeString(res_9, 2);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		T59_ = NIM_NIL;
		T59_ = genTypeInfoV1__cgen_6798((*p).module, t, (*e).info);
		cgFormatValue__cgen_147((&res_9), T59_);
		res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		T60_ = NIM_NIL;
		T60_ = rope__ropes_109(res_9);
		putIntoDest__cgen_18794(p, d, e, T60_, a.storage);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 3):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 63):
	{
		liMessage__msgs_1128((*(*(*p).module).g).config, (*e).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_509), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_510, NIM_FALSE);
	}
	break;
	default:
	{
		NimStringDesc* res_10;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T63_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T64_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T65_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T66_;
		res_10 = rawNewString(((NI) 80));
		T63_ = NIM_NIL;
		T63_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_508));
		cgFormatValue__cgen_147((&res_10), T63_);
		res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T64_ = NIM_NIL;
		T64_ = addrLoc__cgen_10337((*(*(*p).module).g).config, a);
		cgFormatValue__cgen_147((&res_10), T64_);
		res_10 = resizeString(res_10, 2);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		T65_ = NIM_NIL;
		T65_ = genTypeInfoV1__cgen_6798((*p).module, t, (*e).info);
		cgFormatValue__cgen_147((&res_10), T65_);
		res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		T66_ = NIM_NIL;
		T66_ = rope__ropes_109(res_10);
		putIntoDest__cgen_18794(p, d, e, T66_, a.storage);
	}
	break;
	}
	gcUsage__cgen_20553((*(*(*p).module).g).config, e);
}
N_LIB_PRIVATE N_NIMCALL(void, genGetTypeInfo__cgen_21838)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T2_;
	T1_ = NIM_NIL;
	T1_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_142));
	(void)(T1_);
	t = (*(*e)._kind_6.sons->data[((NI) 1)]).typ;
	T2_ = NIM_NIL;
	T2_ = genTypeInfoV1__cgen_6798((*p).module, t, (*e).info);
	putIntoDest__cgen_18794(p, d, e, T2_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, rdMType__cgen_21782)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** nilCheck, NIM_BOOL enforceV1) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
	result = NIM_NIL;
	result = rdLoc__cgen_435(a);
	T1_ = NIM_NIL;
	T1_ = t__cgen_85(a);
	t = skipTypes__ast_3723(T1_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
	{
		while (1) {
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T17_;
			if (!((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22))) goto LA3;
			{
				if (!!(((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47)))) goto LA6_;
				unsureAsgnRef((void**) (&(*nilCheck)), result);
			}
			LA6_: ;
			{
				NIM_BOOL T10_;
				NIM_BOOL T12_;
				tyArray__ts9cf9blICas1QWmw89bglZ7w T16_;
				T10_ = (NIM_BOOL)0;
				T10_ = !(((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47)));
				if (T10_) goto LA11_;
				T12_ = (NIM_BOOL)0;
				T12_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
				if (T12_) goto LA13_;
				T12_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
				LA13_: ;
				T10_ = !(T12_);
				LA11_: ;
				if (!T10_) goto LA14_;
				nimZeroMem((void*)T16_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
				T16_[0] = result;
				result = percent___cgen_442(T16_, 1);
			}
			LA14_: ;
			T17_ = NIM_NIL;
			T17_ = lastSon__ast_3731(t);
			t = skipTypes__ast_3723(T17_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
		} LA3: ;
	}
	T18_ = NIM_NIL;
	T18_ = getTypeDesc__cgen_6662((*p).module, t, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
	(void)(T18_);
	{
		NIM_BOOL T21_;
		T21_ = (NIM_BOOL)0;
		T21_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
		if (T21_) goto LA22_;
		T21_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
		LA22_: ;
		if (!!(T21_)) goto LA23_;
		{
			while (1) {
				NIM_BOOL T27_;
				T27_ = (NIM_BOOL)0;
				T27_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17));
				if (!(T27_)) goto LA28_;
				T27_ = !(((*t).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
				LA28_: ;
				if (!T27_) goto LA26;
				add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_129));
				t = skipTypes__ast_3723((*t).sons->data[((NI) 0)], TM__9bddtAaa9cYLwzzzlT9aJ5CKw_130);
			} LA26: ;
		}
	}
	LA23_: ;
	add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_513));
	{
		NIM_BOOL T31_;
		T31_ = (NIM_BOOL)0;
		T31_ = (((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 41))&63U)))!=0);
		if (!(T31_)) goto LA32_;
		T31_ = enforceV1;
		LA32_: ;
		if (!T31_) goto LA33_;
		add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_514));
	}
	LA33_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genGetTypeInfoV2__cgen_21844)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	t = (*(*e)._kind_6.sons->data[((NI) 1)]).typ;
	{
		NIM_BOOL T3_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = isFinal__types_808(t);
		if (T3_) goto LA4_;
		T3_ = !(eqStrings((*(*(*(*e)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).s, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_512)));
		LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = NIM_NIL;
		T7_ = genTypeInfoV2__cgen_7958((*p).module, t, (*e).info);
		putIntoDest__cgen_18794(p, d, e, T7_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	goto LA1_;
	LA5_: ;
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* nilCheck;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
		nilCheck = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
		T9_ = NIM_NIL;
		T9_ = rdMType__cgen_21782(p, a, &nilCheck, NIM_FALSE);
		putIntoDest__cgen_18794(p, d, e, T9_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, cowBracket__cgen_19616)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NIM_BOOL T3_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* strCandidate;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42));
		if (!(T3_)) goto LA4_;
		T3_ = (((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		strCandidate = (*n)._kind_6.sons->data[((NI) 0)];
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T9_;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T12_;
			NimStringDesc* res;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
			T9_ = NIM_NIL;
			T9_ = skipTypes__ast_3723((*strCandidate).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
			if (!((*T9_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28))) goto LA10_;
			nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLocExpr__cgen_11548(p, strCandidate, (&a));
			T12_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T12_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res = rawNewString(((NI) 80));
			T13_ = NIM_NIL;
			T13_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_276));
			cgFormatValue__cgen_147((&res), T13_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T14_ = NIM_NIL;
			T14_ = byRefLoc__cgen_10353(p, a);
			cgFormatValue__cgen_147((&res), T14_);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA17_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA17_: ;
			T19_ = NIM_NIL;
			T19_ = rope__ropes_109(res);
			T20_ = NIM_NIL;
			T20_ = indentLine__cgen_286(p, T19_);
			add__ropes_159(T12_, T20_);
		}
		LA10_: ;
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSwap__cgen_22180)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tmp;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1_;
	cowBracket__cgen_19616(p, (*e)._kind_6.sons->data[((NI) 1)]);
	cowBracket__cgen_19616(p, (*e)._kind_6.sons->data[((NI) 2)]);
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	T1_ = NIM_NIL;
	T1_ = skipTypes__ast_3723((*(*e)._kind_6.sons->data[((NI) 1)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_266);
	getTemp__cgen_7373(p, T1_, (&tmp), NIM_FALSE);
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
	genAssignment__cgen_10403(p, tmp, a, 0);
	genAssignment__cgen_10403(p, a, b, 0);
	genAssignment__cgen_10403(p, b, tmp, 0);
}
N_LIB_PRIVATE N_NIMCALL(void, binaryStmt__cgen_18809)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, NimStringDesc* op) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T5_;
	NimStringDesc* res;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	{
		if (!!(((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0)))) goto LA3_;
		internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*e).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_516), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_517);
	}
	LA3_: ;
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
	T5_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T5_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	res = rawNewString(((NI) 80));
	T6_ = NIM_NIL;
	T6_ = rdLoc__cgen_435(a);
	cgFormatValue__cgen_147((&res), T6_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_13));
	cgFormatValue__cgen_151((&res), op);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_13));
	T7_ = NIM_NIL;
	T7_ = rdLoc__cgen_435(b);
	cgFormatValue__cgen_147((&res), T7_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA10_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA10_: ;
	T12_ = NIM_NIL;
	T12_ = rope__ropes_109(res);
	T13_ = NIM_NIL;
	T13_ = indentLine__cgen_286(p, T12_);
	add__ropes_159(T5_, T13_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, strLoc__cgen_20560)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw d) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	{
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0)) goto LA3_;
		result = byRefLoc__cgen_10353(p, d);
	}
	goto LA1_;
	LA3_: ;
	{
		result = rdLoc__cgen_435(d);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genStrConcat__cgen_20568)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tmp;
	NI L;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* appends;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* lens;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T33_;
	NimStringDesc* res_3;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T34_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T39_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T40_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T41_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	getTemp__cgen_7373(p, (*e).typ, (&tmp), NIM_FALSE);
	L = ((NI) 0);
	appends = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
	lens = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (NI)0;
		T2_ = len__ast_3155(e);
		colontmp_ = (NI)(T2_ - ((NI) 1));
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[(NI)(i + ((NI) 1))], (&a));
				{
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T7_;
					NimStringDesc* res;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
					T7_ = NIM_NIL;
					T7_ = skipTypes__ast_3723((*(*e)._kind_6.sons->data[(NI)(i + ((NI) 1))]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_183);
					if (!((*T7_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2))) goto LA8_;
					L += ((NI) 1);
					res = rawNewString(((NI) 80));
					T10_ = NIM_NIL;
					T10_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_521));
					cgFormatValue__cgen_147((&res), T10_);
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
					T11_ = NIM_NIL;
					T11_ = strLoc__cgen_20560(p, tmp);
					cgFormatValue__cgen_147((&res), T11_);
					res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
					T12_ = NIM_NIL;
					T12_ = rdLoc__cgen_435(a);
					cgFormatValue__cgen_147((&res), T12_);
					res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA15_;
						res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
					}
					LA15_: ;
					T17_ = NIM_NIL;
					T17_ = rope__ropes_109(res);
					add__ropes_159(&appends, T17_);
				}
				goto LA5_;
				LA8_: ;
				{
					NimStringDesc* res_2;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T27_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T32_;
					{
						if (!((*(*e)._kind_6.sons->data[(NI)(i + ((NI) 1))]).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) && (*(*e)._kind_6.sons->data[(NI)(i + ((NI) 1))]).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22))) goto LA21_;
						L += ((*(*e)._kind_6.sons->data[(NI)(i + ((NI) 1))])._kind_3.strVal ? (*(*e)._kind_6.sons->data[(NI)(i + ((NI) 1))])._kind_3.strVal->Sup.len : 0);
					}
					goto LA19_;
					LA21_: ;
					{
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
						T24_ = NIM_NIL;
						T24_ = lenExpr__cgen_458(p, a);
						add__ropes_159(&lens, T24_);
						add__ropes_162(&lens, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_522));
					}
					LA19_: ;
					res_2 = rawNewString(((NI) 80));
					T25_ = NIM_NIL;
					T25_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_523));
					cgFormatValue__cgen_147((&res_2), T25_);
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
					T26_ = NIM_NIL;
					T26_ = strLoc__cgen_20560(p, tmp);
					cgFormatValue__cgen_147((&res_2), T26_);
					res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
					T27_ = NIM_NIL;
					T27_ = rdLoc__cgen_435(a);
					cgFormatValue__cgen_147((&res_2), T27_);
					res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA30_;
						res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
					}
					LA30_: ;
					T32_ = NIM_NIL;
					T32_ = rope__ropes_109(res_2);
					add__ropes_159(&appends, T32_);
				}
				LA5_: ;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	T33_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T33_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	res_3 = rawNewString(((NI) 80));
	cgFormatValue__cgen_147((&res_3), tmp.r);
	res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
	T34_ = NIM_NIL;
	T34_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_524));
	cgFormatValue__cgen_147((&res_3), T34_);
	res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
	cgFormatValue__cgen_147((&res_3), lens);
	cgFormatValue__cgen_154((&res_3), ((NI64) (L)));
	res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA37_;
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA37_: ;
	T39_ = NIM_NIL;
	T39_ = rope__ropes_109(res_3);
	T40_ = NIM_NIL;
	T40_ = indentLine__cgen_286(p, T39_);
	add__ropes_159(T33_, T40_);
	T41_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T41_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	add__ropes_159(T41_, appends);
	{
		if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA44_;
		genericAssign((void*)(&(*d)), (void*)(&tmp), (&NTItloc__CAJV4zTUpZwr0j6Wy8FiFw_));
	}
	goto LA42_;
	LA44_: ;
	{
		genAssignment__cgen_10403(p, (*d), tmp, 0);
	}
	LA42_: ;
	gcUsage__cgen_20553((*(*(*p).module).g).config, e);
}
N_LIB_PRIVATE N_NIMCALL(void, binaryStmtAddr__cgen_18835)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, NimStringDesc* cpname) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T5_;
	NimStringDesc* res;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	{
		if (!!(((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0)))) goto LA3_;
		internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*e).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_525), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_526);
	}
	LA3_: ;
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
	T5_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T5_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	res = rawNewString(((NI) 80));
	T6_ = NIM_NIL;
	T6_ = cgsym__cgen_126((*p).module, cpname);
	cgFormatValue__cgen_147((&res), T6_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
	T7_ = NIM_NIL;
	T7_ = byRefLoc__cgen_10353(p, a);
	cgFormatValue__cgen_147((&res), T7_);
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
	T8_ = NIM_NIL;
	T8_ = rdLoc__cgen_435(b);
	cgFormatValue__cgen_147((&res), T8_);
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA11_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA11_: ;
	T13_ = NIM_NIL;
	T13_ = rope__ropes_109(res);
	T14_ = NIM_NIL;
	T14_ = indentLine__cgen_286(p, T13_);
	add__ropes_159(T5_, T14_);
}
N_LIB_PRIVATE N_NIMCALL(void, genStrAppend__cgen_20648)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw dest;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw call;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* appends;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* lens;
	NI L;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T49_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&dest), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&call), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	appends = NIM_NIL;
	lens = NIM_NIL;
	L = ((NI) 0);
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&dest));
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (NI)0;
		T2_ = len__ast_3155(e);
		colontmp_ = (NI)(T2_ - ((NI) 2));
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[(NI)(i + ((NI) 2))], (&a));
				{
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T7_;
					NimStringDesc* res;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
					T7_ = NIM_NIL;
					T7_ = skipTypes__ast_3723((*(*e)._kind_6.sons->data[(NI)(i + ((NI) 2))]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_183);
					if (!((*T7_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2))) goto LA8_;
					L += ((NI) 1);
					res = rawNewString(((NI) 80));
					T10_ = NIM_NIL;
					T10_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_521));
					cgFormatValue__cgen_147((&res), T10_);
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
					T11_ = NIM_NIL;
					T11_ = strLoc__cgen_20560(p, dest);
					cgFormatValue__cgen_147((&res), T11_);
					res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
					T12_ = NIM_NIL;
					T12_ = rdLoc__cgen_435(a);
					cgFormatValue__cgen_147((&res), T12_);
					res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA15_;
						res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
					}
					LA15_: ;
					T17_ = NIM_NIL;
					T17_ = rope__ropes_109(res);
					add__ropes_159(&appends, T17_);
				}
				goto LA5_;
				LA8_: ;
				{
					NimStringDesc* res_2;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T27_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T32_;
					{
						if (!((*(*e)._kind_6.sons->data[(NI)(i + ((NI) 2))]).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) && (*(*e)._kind_6.sons->data[(NI)(i + ((NI) 2))]).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22))) goto LA21_;
						L += ((*(*e)._kind_6.sons->data[(NI)(i + ((NI) 2))])._kind_3.strVal ? (*(*e)._kind_6.sons->data[(NI)(i + ((NI) 2))])._kind_3.strVal->Sup.len : 0);
					}
					goto LA19_;
					LA21_: ;
					{
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
						T24_ = NIM_NIL;
						T24_ = lenExpr__cgen_458(p, a);
						add__ropes_159(&lens, T24_);
						add__ropes_162(&lens, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_522));
					}
					LA19_: ;
					res_2 = rawNewString(((NI) 80));
					T25_ = NIM_NIL;
					T25_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_523));
					cgFormatValue__cgen_147((&res_2), T25_);
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
					T26_ = NIM_NIL;
					T26_ = strLoc__cgen_20560(p, dest);
					cgFormatValue__cgen_147((&res_2), T26_);
					res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
					T27_ = NIM_NIL;
					T27_ = rdLoc__cgen_435(a);
					cgFormatValue__cgen_147((&res_2), T27_);
					res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA30_;
						res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
					}
					LA30_: ;
					T32_ = NIM_NIL;
					T32_ = rope__ropes_109(res_2);
					add__ropes_159(&appends, T32_);
				}
				LA5_: ;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T37_;
		NimStringDesc* res_3;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T39_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T44_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T45_;
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0)) goto LA35_;
		T37_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T37_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_3 = rawNewString(((NI) 80));
		T38_ = NIM_NIL;
		T38_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_529));
		cgFormatValue__cgen_147((&res_3), T38_);
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T39_ = NIM_NIL;
		T39_ = byRefLoc__cgen_10353(p, dest);
		cgFormatValue__cgen_147((&res_3), T39_);
		res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		cgFormatValue__cgen_147((&res_3), lens);
		cgFormatValue__cgen_154((&res_3), ((NI64) (L)));
		res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA42_;
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA42_: ;
		T44_ = NIM_NIL;
		T44_ = rope__ropes_109(res_3);
		T45_ = NIM_NIL;
		T45_ = indentLine__cgen_286(p, T44_);
		add__ropes_159(T37_, T45_);
	}
	goto LA33_;
	LA35_: ;
	{
		NimStringDesc* res_4;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T47_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T48_;
		initLoc__cgen_66((&call), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 9), e, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 3));
		res_4 = rawNewString(((NI) 80));
		T47_ = NIM_NIL;
		T47_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_530));
		cgFormatValue__cgen_147((&res_4), T47_);
		res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T48_ = NIM_NIL;
		T48_ = rdLoc__cgen_435(dest);
		cgFormatValue__cgen_147((&res_4), T48_);
		res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		cgFormatValue__cgen_147((&res_4), lens);
		cgFormatValue__cgen_154((&res_4), ((NI64) (L)));
		res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		call.r = rope__ropes_109(res_4);
		genAssignment__cgen_10403(p, dest, call, 0);
		gcUsage__cgen_20553((*(*(*p).module).g).config, e);
	}
	LA33_: ;
	T49_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T49_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	add__ropes_159(T49_, appends);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, makePtrType__cgen_22084)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* baseType, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T1_;
	result = NIM_NIL;
	T1_ = nextTypeId__ast_3122(idgen);
	result = newType__ast_3884(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21), T1_, (*baseType).owner);
	addSonSkipIntLit__magicsys_136(result, baseType, idgen);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, makeAddr__cgen_22088)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64))) goto LA3_;
		result = n;
	}
	goto LA1_;
	LA3_: ;
	{
		tyArray__iegsN9bf6GqRiWprrJjTAoA T6_;
		nimZeroMem((void*)T6_, sizeof(tyArray__iegsN9bf6GqRiWprrJjTAoA));
		T6_[0] = n;
		result = newTree__ast_3356(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64), T6_, 1);
		asgnRef((void**) (&(*result).typ), makePtrType__cgen_22084((*n).typ, idgen));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genCall__cgen_13177)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	genAsgnCall__cgen_13147(p, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), e, d);
}
N_LIB_PRIVATE N_NIMCALL(void, getIntTemp__cgen_11104)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* result) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T2_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T3_;
	NimStringDesc* res;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T10_;
	(*p).labels += ((NI) 1);
	T1_ = NIM_NIL;
	T1_ = rope__ropes_115(((NI64) ((*p).labels)));
	T2_ = NIM_NIL;
	T2_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_157), T1_);
	unsureAsgnRef((void**) (&(*result).r), amp___ropes_140(T2_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3)));
	T3_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T3_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
	res = rawNewString(((NI) 80));
	res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_534));
	cgFormatValue__cgen_147((&res), (*result).r);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA6_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA6_: ;
	T8_ = NIM_NIL;
	T8_ = rope__ropes_109(res);
	T9_ = NIM_NIL;
	T9_ = indentLine__cgen_286(p, T8_);
	add__ropes_159(T3_, T9_);
	(*result).k = ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 1);
	(*result).storage = ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 2);
	T10_ = NIM_NIL;
	T10_ = getSysType__magicsys_60((*(*(*p).module).g).graph, unknownLineInfo__lineinfos_284, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31));
	unsureAsgnRef((void**) (&(*result).lode), lodeTyp__cgen_92(T10_));
	(*result).flags = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, genSeqElemAppend__cgen_20746)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw dest;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tmpL;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw call;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* seqType;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T16_;
	NimStringDesc* res_3;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
	NimStringDesc* res_4;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&dest), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&tmpL), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&call), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
	seqType = skipTypes__ast_3723((*(*e)._kind_6.sons->data[((NI) 1)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_531);
	initLoc__cgen_66((&call), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 9), e, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 3));
	{
		NIM_BOOL T3_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
		if (T3_) goto LA4_;
		T3_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
		LA4_: ;
		if (!!(T3_)) goto LA5_;
		res = rawNewString(((NI) 80));
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T7_ = NIM_NIL;
		T7_ = getTypeDesc__cgen_6662((*p).module, (*(*e)._kind_6.sons->data[((NI) 1)]).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		cgFormatValue__cgen_147((&res), T7_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_56));
		T8_ = NIM_NIL;
		T8_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_532));
		cgFormatValue__cgen_147((&res), T8_);
		res = resizeString(res, 16);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_533));
		T9_ = NIM_NIL;
		T9_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res), T9_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_410));
		T10_ = NIM_NIL;
		T10_ = genTypeInfoV1__cgen_6798((*p).module, seqType, (*e).info);
		cgFormatValue__cgen_147((&res), T10_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		call.r = rope__ropes_109(res);
	}
	goto LA1_;
	LA5_: ;
	{
		NimStringDesc* res_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T12_ = NIM_NIL;
		T12_ = getTypeDesc__cgen_6662((*p).module, (*(*e)._kind_6.sons->data[((NI) 1)]).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		cgFormatValue__cgen_147((&res_2), T12_);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_56));
		T13_ = NIM_NIL;
		T13_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_532));
		cgFormatValue__cgen_147((&res_2), T13_);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T14_ = NIM_NIL;
		T14_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res_2), T14_);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		T15_ = NIM_NIL;
		T15_ = genTypeInfoV1__cgen_6798((*p).module, seqType, (*e).info);
		cgFormatValue__cgen_147((&res_2), T15_);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		call.r = rope__ropes_109(res_2);
	}
	LA1_: ;
	genRefAssign__cgen_10581(p, a, call);
	initLoc__cgen_66((&dest), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 6), (*e)._kind_6.sons->data[((NI) 2)], ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 3));
	getIntTemp__cgen_11104(p, (&tmpL));
	T16_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T16_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	res_3 = rawNewString(((NI) 80));
	cgFormatValue__cgen_147((&res_3), tmpL.r);
	res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
	T17_ = NIM_NIL;
	T17_ = rdLoc__cgen_435(a);
	cgFormatValue__cgen_147((&res_3), T17_);
	res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_453));
	T18_ = NIM_NIL;
	T18_ = lenField__cgen_447(p);
	cgFormatValue__cgen_147((&res_3), T18_);
	res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_535));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA21_;
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA21_: ;
	T23_ = NIM_NIL;
	T23_ = rope__ropes_109(res_3);
	T24_ = NIM_NIL;
	T24_ = indentLine__cgen_286(p, T23_);
	add__ropes_159(T16_, T24_);
	res_4 = rawNewString(((NI) 80));
	T25_ = NIM_NIL;
	T25_ = rdLoc__cgen_435(a);
	cgFormatValue__cgen_147((&res_4), T25_);
	T26_ = NIM_NIL;
	T26_ = dataField__cgen_479(p);
	cgFormatValue__cgen_147((&res_4), T26_);
	res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_166));
	cgFormatValue__cgen_147((&res_4), tmpL.r);
	res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_167));
	dest.r = rope__ropes_109(res_4);
	genAssignment__cgen_10403(p, dest, b, 1);
	gcUsage__cgen_20553((*(*(*p).module).g).config, e);
}
N_LIB_PRIVATE N_NIMCALL(void, genStrEquals__cgen_23155)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw x;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b;
	nimZeroMem((void*)(&x), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	a = (*e)._kind_6.sons->data[((NI) 1)];
	b = (*e)._kind_6.sons->data[((NI) 2)];
	{
		NIM_BOOL T3_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*a).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) && (*a).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22));
		if (!(T3_)) goto LA4_;
		T3_ = (((*a)._kind_3.strVal ? (*a)._kind_3.strVal->Sup.len : 0) == 0);
		LA4_: ;
		if (!T3_) goto LA5_;
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&x));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T7_ = NIM_NIL;
		T7_ = lenExpr__cgen_458(p, x);
		cgFormatValue__cgen_147((&res), T7_);
		res = resizeString(res, 6);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_536));
		T8_ = NIM_NIL;
		T8_ = rope__ropes_109(res);
		putIntoDest__cgen_18794(p, d, e, T8_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T10_;
		NimStringDesc* res_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
		T10_ = (NIM_BOOL)0;
		T10_ = ((*b).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) && (*b).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22));
		if (!(T10_)) goto LA11_;
		T10_ = (((*b)._kind_3.strVal ? (*b)._kind_3.strVal->Sup.len : 0) == 0);
		LA11_: ;
		if (!T10_) goto LA12_;
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&x));
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T14_ = NIM_NIL;
		T14_ = lenExpr__cgen_458(p, x);
		cgFormatValue__cgen_147((&res_2), T14_);
		res_2 = resizeString(res_2, 6);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_536));
		T15_ = NIM_NIL;
		T15_ = rope__ropes_109(res_2);
		putIntoDest__cgen_18794(p, d, e, T15_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	goto LA1_;
	LA12_: ;
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym5225_;
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw bX60gensym5225_;
		NimStringDesc* res_3;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
		nimZeroMem((void*)(&aX60gensym5225_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		nimZeroMem((void*)(&bX60gensym5225_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5225_));
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym5225_));
		res_3 = rawNewString(((NI) 80));
		T17_ = NIM_NIL;
		T17_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_537));
		cgFormatValue__cgen_147((&res_3), T17_);
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T18_ = NIM_NIL;
		T18_ = rdLoc__cgen_435(aX60gensym5225_);
		cgFormatValue__cgen_147((&res_3), T18_);
		res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		T19_ = NIM_NIL;
		T19_ = rdLoc__cgen_435(bX60gensym5225_);
		cgFormatValue__cgen_147((&res_3), T19_);
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		T20_ = NIM_NIL;
		T20_ = rope__ropes_109(res_3);
		putIntoDest__cgen_18794(p, d, e, T20_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genIsNil__cgen_19358)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	t = skipTypes__ast_3723((*(*e)._kind_6.sons->data[((NI) 1)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_430);
	{
		NIM_BOOL T3_;
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym3837_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25));
		if (!(T3_)) goto LA4_;
		T3_ = ((*t).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
		LA4_: ;
		if (!T3_) goto LA5_;
		nimZeroMem((void*)(&aX60gensym3837_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym3837_));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T7_ = NIM_NIL;
		T7_ = rdLoc__cgen_435(aX60gensym3837_);
		cgFormatValue__cgen_147((&res), T7_);
		res = resizeString(res, 12);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_541));
		T8_ = NIM_NIL;
		T8_ = rope__ropes_109(res);
		putIntoDest__cgen_18794(p, d, e, T8_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	goto LA1_;
	LA5_: ;
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym3843_;
		NimStringDesc* res_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
		nimZeroMem((void*)(&aX60gensym3843_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym3843_));
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T10_ = NIM_NIL;
		T10_ = rdLoc__cgen_435(aX60gensym3843_);
		cgFormatValue__cgen_147((&res_2), T10_);
		res_2 = resizeString(res_2, 6);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_536));
		T11_ = NIM_NIL;
		T11_ = rope__ropes_109(res_2);
		putIntoDest__cgen_18794(p, d, e, T11_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genEnumToStr__cgen_23511)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* toStrProc;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
	t = skipTypes__ast_3723((*(*e)._kind_6.sons->data[((NI) 1)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_549);
	toStrProc = getToStringProc__modulegraphs_5686((*(*(*p).module).g).graph, t);
	n = copyTree__ast_4432(e);
	asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), newSymNode__ast_3704(toStrProc));
	expr__cgen_11525(p, n, d);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genOfHelper__cgen_21502)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* dest, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* a, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* ti;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* cache;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T6_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 41))&63U)))!=0)) goto LA3_;
		ti = genTypeInfo2Name__cgen_7835((*p).module, dest);
		(*(*p).module).labels += ((NI) 1);
		T5_ = NIM_NIL;
		T5_ = rope__ropes_115(((NI64) ((*(*p).module).labels)));
		cache = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_553), T5_);
		nimZeroMem((void*)T6_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T6_[0] = cache;
		T7_ = NIM_NIL;
		T7_ = percent___cgen_21518(T6_, 1);
		add__ropes_159(&(*(*p).module).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], T7_);
		res = rawNewString(((NI) 80));
		T8_ = NIM_NIL;
		T8_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_554));
		cgFormatValue__cgen_147((&res), T8_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		cgFormatValue__cgen_147((&res), a);
		res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_555));
		cgFormatValue__cgen_147((&res), ti);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		cgFormatValue__cgen_147((&res), cache);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		result = rope__ropes_109(res);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* ti_2;
		ti_2 = genTypeInfoV1__cgen_6798((*p).module, dest, info);
		{
			NIM_BOOL T12_;
			NIM_BOOL T14_;
			tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T18_;
			T12_ = (NIM_BOOL)0;
			T12_ = (((*dest).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 2))&63U)))!=0);
			if (T12_) goto LA13_;
			T14_ = (NIM_BOOL)0;
			T14_ = (((*(*p).module).flags &((NU8)1<<((NU)(((tyEnum_CodegenFlag__vPx29bHhk9a7V50u1UO0rM4w) 5))&7U)))!=0);
			if (!(T14_)) goto LA15_;
			T14_ = !((((*dest).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 5))&63U)))!=0));
			LA15_: ;
			T12_ = T14_;
			LA13_: ;
			if (!T12_) goto LA16_;
			nimZeroMem((void*)T18_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
			T18_[0] = a;
			T18_[1] = ti_2;
			result = percent___cgen_21545(T18_, 2);
		}
		goto LA10_;
		LA16_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* cache_2;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T21_;
			tyArray__ts9cf9blICas1QWmw89bglZ7w T22_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
			NimStringDesc* res_2;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
			T20_ = NIM_NIL;
			T20_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_142));
			(void)(T20_);
			(*(*p).module).labels += ((NI) 1);
			T21_ = NIM_NIL;
			T21_ = rope__ropes_115(((NI64) ((*(*p).module).labels)));
			cache_2 = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_553), T21_);
			nimZeroMem((void*)T22_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T22_[0] = cache_2;
			T23_ = NIM_NIL;
			T23_ = percent___cgen_21555(T22_, 1);
			add__ropes_159(&(*(*p).module).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], T23_);
			res_2 = rawNewString(((NI) 80));
			T24_ = NIM_NIL;
			T24_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_554));
			cgFormatValue__cgen_147((&res_2), T24_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			cgFormatValue__cgen_147((&res_2), a);
			res_2 = resizeString(res_2, 9);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_555));
			cgFormatValue__cgen_147((&res_2), ti_2);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			cgFormatValue__cgen_147((&res_2), cache_2);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
			result = rope__ropes_109(res_2);
		}
		LA10_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genOf__cgen_21569)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* dest;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* nilCheck;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, x, (&a));
	dest = skipTypes__ast_3723(typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_134);
	r = rdLoc__cgen_435(a);
	nilCheck = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
	T1_ = NIM_NIL;
	T1_ = t__cgen_85(a);
	t = skipTypes__ast_3723(T1_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_155);
	{
		while (1) {
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T16_;
			if (!((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22))) goto LA3;
			{
				if (!!(((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47)))) goto LA6_;
				nilCheck = r;
			}
			LA6_: ;
			{
				NIM_BOOL T10_;
				NIM_BOOL T12_;
				NimStringDesc* res;
				T10_ = (NIM_BOOL)0;
				T10_ = !(((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47)));
				if (T10_) goto LA11_;
				T12_ = (NIM_BOOL)0;
				T12_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
				if (T12_) goto LA13_;
				T12_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
				LA13_: ;
				T10_ = !(T12_);
				LA11_: ;
				if (!T10_) goto LA14_;
				res = rawNewString(((NI) 80));
				res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_109));
				cgFormatValue__cgen_147((&res), r);
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
				r = rope__ropes_109(res);
			}
			LA14_: ;
			T16_ = NIM_NIL;
			T16_ = lastSon__ast_3731(t);
			t = skipTypes__ast_3723(T16_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_67);
		} LA3: ;
	}
	T17_ = NIM_NIL;
	T17_ = getTypeDesc__cgen_6662((*p).module, t, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
	(void)(T17_);
	{
		NIM_BOOL T20_;
		T20_ = (NIM_BOOL)0;
		T20_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
		if (T20_) goto LA21_;
		T20_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
		LA21_: ;
		if (!!(T20_)) goto LA22_;
		{
			while (1) {
				NIM_BOOL T26_;
				tyArray__dAmhZbEWrTM5xES2bTVweg T28_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T29_;
				T26_ = (NIM_BOOL)0;
				T26_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17));
				if (!(T26_)) goto LA27_;
				T26_ = !(((*t).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
				LA27_: ;
				if (!T26_) goto LA25;
				nimZeroMem((void*)T28_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
				T29_ = NIM_NIL;
				T29_ = percent___cgen_21632(T28_, 0);
				add__ropes_159(&r, T29_);
				t = skipTypes__ast_3723((*t).sons->data[((NI) 0)], TM__9bddtAaa9cYLwzzzlT9aJ5CKw_130);
			} LA25: ;
		}
	}
	LA22_: ;
	{
		NIM_BOOL T32_;
		T32_ = (NIM_BOOL)0;
		T32_ = isObjLackingTypeField__cgen_1337(t);
		if (!T32_) goto LA33_;
		liMessage__msgs_1128((*(*(*p).module).g).config, (*x).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_550), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 2), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_551, NIM_FALSE);
	}
	LA33_: ;
	{
		NimStringDesc* res_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T39_;
		if (!!((nilCheck == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA37_;
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_29));
		cgFormatValue__cgen_147((&res_2), nilCheck);
		res_2 = resizeString(res_2, 6);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_552));
		T39_ = NIM_NIL;
		T39_ = genOfHelper__cgen_21502(p, dest, r, (*x).info);
		cgFormatValue__cgen_147((&res_2), T39_);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_41));
		r = rope__ropes_109(res_2);
	}
	goto LA35_;
	LA37_: ;
	{
		NimStringDesc* res_3;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T41_;
		res_3 = rawNewString(((NI) 80));
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T41_ = NIM_NIL;
		T41_ = genOfHelper__cgen_21502(p, dest, r, (*x).info);
		cgFormatValue__cgen_147((&res_3), T41_);
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		r = rope__ropes_109(res_3);
	}
	LA35_: ;
	putIntoDest__cgen_18794(p, d, x, r, a.storage);
}
N_LIB_PRIVATE N_NIMCALL(void, genOf__cgen_21660)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	genOf__cgen_21569(p, (*n)._kind_6.sons->data[((NI) 1)], (*(*n)._kind_6.sons->data[((NI) 2)]).typ, d);
}
N_LIB_PRIVATE N_NIMCALL(void, rawGenNew__cgen_20825)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* a, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* sizeExpr, NIM_BOOL needsInit) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* sizeExpr_2;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* refType;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* bt;
	sizeExpr_2 = sizeExpr;
	typ = t__cgen_85((*a));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLoc__cgen_66((&b), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 6), (*a).lode, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 3));
	refType = skipTypes__ast_3723(typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_155);
	bt = lastSon__ast_3731(refType);
	{
		tyArray__ts9cf9blICas1QWmw89bglZ7w T5_;
		if (!(sizeExpr_2 == 0)) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T5_[0] = getTypeDesc__cgen_6662((*p).module, bt, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		sizeExpr_2 = percent___cgen_20848(T5_, 1);
	}
	LA3_: ;
	{
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 41))&63U)))!=0)) goto LA8_;
		{
			NimStringDesc* res;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
			if (!needsInit) goto LA12_;
			res = rawNewString(((NI) 80));
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T14_ = NIM_NIL;
			T14_ = getTypeDesc__cgen_6662((*p).module, typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			cgFormatValue__cgen_147((&res), T14_);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_56));
			T15_ = NIM_NIL;
			T15_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_556));
			cgFormatValue__cgen_147((&res), T15_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			cgFormatValue__cgen_147((&res), sizeExpr_2);
			res = resizeString(res, 14);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_557));
			T16_ = NIM_NIL;
			T16_ = getTypeDesc__cgen_6662((*p).module, bt, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			cgFormatValue__cgen_147((&res), T16_);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_41));
			b.r = rope__ropes_109(res);
		}
		goto LA10_;
		LA12_: ;
		{
			NimStringDesc* res_2;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
			res_2 = rawNewString(((NI) 80));
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T18_ = NIM_NIL;
			T18_ = getTypeDesc__cgen_6662((*p).module, typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			cgFormatValue__cgen_147((&res_2), T18_);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_56));
			T19_ = NIM_NIL;
			T19_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_558));
			cgFormatValue__cgen_147((&res_2), T19_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			cgFormatValue__cgen_147((&res_2), sizeExpr_2);
			res_2 = resizeString(res_2, 14);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_557));
			T20_ = NIM_NIL;
			T20_ = getTypeDesc__cgen_6662((*p).module, bt, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			cgFormatValue__cgen_147((&res_2), T20_);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_41));
			b.r = rope__ropes_109(res_2);
		}
		LA10_: ;
		genAssignment__cgen_10403(p, (*a), b, 0);
	}
	goto LA6_;
	LA8_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* ti;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* op;
		ti = genTypeInfoV1__cgen_6798((*p).module, typ, (*(*a).lode).info);
		op = getAttachedOp__modulegraphs_4049((*(*(*p).module).g).graph, bt, ((tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ) 0));
		{
			NIM_BOOL T24_;
			NIM_BOOL T26_;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw f;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T35_;
			tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T36_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T37_;
			T24_ = (NIM_BOOL)0;
			T24_ = !((op == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
			if (!(T24_)) goto LA25_;
			T26_ = (NIM_BOOL)0;
			T26_ = isTrivialProc__cgen_7880((*(*(*p).module).g).graph, op);
			T24_ = !(T26_);
			LA25_: ;
			if (!T24_) goto LA27_;
			{
				NIM_BOOL T31_;
				T31_ = (NIM_BOOL)0;
				T31_ = ((*op).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
				if (T31_) goto LA32_;
				T31_ = !(((*(*op).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 0)));
				LA32_: ;
				if (!T31_) goto LA33_;
				liMessage__msgs_1128((*(*(*p).module).g).config, (*(*a).lode).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_559), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_560, NIM_FALSE);
			}
			LA33_: ;
			nimZeroMem((void*)(&f), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			T35_ = NIM_NIL;
			T35_ = newSymNode__ast_3704(op);
			initLocExpr__cgen_11548(p, T35_, (&f));
			nimZeroMem((void*)T36_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
			T36_[0] = ti;
			T36_[1] = rdLoc__cgen_435(f);
			T37_ = NIM_NIL;
			T37_ = percent___cgen_20890(T36_, 2);
			add__ropes_159(&(*(*p).module).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T37_);
		}
		LA27_: ;
		{
			NIM_BOOL T40_;
			T40_ = (NIM_BOOL)0;
			T40_ = ((*a).storage == ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 3));
			if (!(T40_)) goto LA41_;
			T40_ = usesWriteBarrier__options_4033((*(*(*p).module).g).config);
			LA41_: ;
			if (!T40_) goto LA42_;
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T46_;
				NIM_BOOL T47_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T50_;
				NimStringDesc* res_3;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T51_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T52_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T53_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T54_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T59_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T60_;
				T46_ = NIM_NIL;
				T46_ = t__cgen_85((*a));
				T47_ = (NIM_BOOL)0;
				T47_ = canFormAcycle__types_820((*(*(*p).module).g).graph, T46_);
				if (!T47_) goto LA48_;
				T50_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T50_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_3 = rawNewString(((NI) 80));
				res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
				T51_ = NIM_NIL;
				T51_ = rdLoc__cgen_435((*a));
				cgFormatValue__cgen_147((&res_3), T51_);
				res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_477));
				T52_ = NIM_NIL;
				T52_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_561));
				cgFormatValue__cgen_147((&res_3), T52_);
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
				T53_ = NIM_NIL;
				T53_ = rdLoc__cgen_435((*a));
				cgFormatValue__cgen_147((&res_3), T53_);
				res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_437));
				T54_ = NIM_NIL;
				T54_ = rdLoc__cgen_435((*a));
				cgFormatValue__cgen_147((&res_3), T54_);
				res_3 = resizeString(res_3, 13);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_562));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA57_;
					res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA57_: ;
				T59_ = NIM_NIL;
				T59_ = rope__ropes_109(res_3);
				T60_ = NIM_NIL;
				T60_ = indentLine__cgen_286(p, T59_);
				add__ropes_159(T50_, T60_);
			}
			goto LA44_;
			LA48_: ;
			{
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T62_;
				NimStringDesc* res_4;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T63_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T64_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T65_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T66_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T71_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T72_;
				T62_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T62_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_4 = rawNewString(((NI) 80));
				res_4 = resizeString(res_4, 4);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
				T63_ = NIM_NIL;
				T63_ = rdLoc__cgen_435((*a));
				cgFormatValue__cgen_147((&res_4), T63_);
				res_4 = resizeString(res_4, 4);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_477));
				T64_ = NIM_NIL;
				T64_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_261));
				cgFormatValue__cgen_147((&res_4), T64_);
				res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
				T65_ = NIM_NIL;
				T65_ = rdLoc__cgen_435((*a));
				cgFormatValue__cgen_147((&res_4), T65_);
				res_4 = resizeString(res_4, 3);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_437));
				T66_ = NIM_NIL;
				T66_ = rdLoc__cgen_435((*a));
				cgFormatValue__cgen_147((&res_4), T66_);
				res_4 = resizeString(res_4, 13);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_562));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA69_;
					res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA69_: ;
				T71_ = NIM_NIL;
				T71_ = rope__ropes_109(res_4);
				T72_ = NIM_NIL;
				T72_ = indentLine__cgen_286(p, T71_);
				add__ropes_159(T62_, T72_);
			}
			LA44_: ;
			{
				NimStringDesc* res_5;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T77_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T78_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T79_;
				NimStringDesc* res_6;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T80_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T81_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T82_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T87_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T88_;
				if (!((*(*(*(*p).module).g).config).selectedGC == ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 10))) goto LA75_;
				res_5 = rawNewString(((NI) 80));
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
				T77_ = NIM_NIL;
				T77_ = getTypeDesc__cgen_6662((*p).module, typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
				cgFormatValue__cgen_147((&res_5), T77_);
				res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_56));
				T78_ = NIM_NIL;
				T78_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_563));
				cgFormatValue__cgen_147((&res_5), T78_);
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
				cgFormatValue__cgen_147((&res_5), ti);
				res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
				cgFormatValue__cgen_147((&res_5), sizeExpr_2);
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
				b.r = rope__ropes_109(res_5);
				T79_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T79_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_6 = rawNewString(((NI) 80));
				T80_ = NIM_NIL;
				T80_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_123));
				cgFormatValue__cgen_147((&res_6), T80_);
				res_6 = resizeString(res_6, 10);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_121));
				T81_ = NIM_NIL;
				T81_ = addrLoc__cgen_10337((*(*(*p).module).g).config, (*a));
				cgFormatValue__cgen_147((&res_6), T81_);
				res_6 = resizeString(res_6, 2);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
				T82_ = NIM_NIL;
				T82_ = rdLoc__cgen_435(b);
				cgFormatValue__cgen_147((&res_6), T82_);
				res_6 = resizeString(res_6, 2);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA85_;
					res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA85_: ;
				T87_ = NIM_NIL;
				T87_ = rope__ropes_109(res_6);
				T88_ = NIM_NIL;
				T88_ = indentLine__cgen_286(p, T87_);
				add__ropes_159(T79_, T88_);
			}
			goto LA73_;
			LA75_: ;
			{
				NimStringDesc* res_7;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T90_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T91_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T92_;
				NimStringDesc* res_8;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T93_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T94_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T99_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T100_;
				res_7 = rawNewString(((NI) 80));
				res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
				T90_ = NIM_NIL;
				T90_ = getTypeDesc__cgen_6662((*p).module, typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
				cgFormatValue__cgen_147((&res_7), T90_);
				res_7 = resizeString(res_7, 2);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_56));
				T91_ = NIM_NIL;
				T91_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_564));
				cgFormatValue__cgen_147((&res_7), T91_);
				res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
				cgFormatValue__cgen_147((&res_7), ti);
				res_7 = resizeString(res_7, 2);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
				cgFormatValue__cgen_147((&res_7), sizeExpr_2);
				res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
				b.r = rope__ropes_109(res_7);
				T92_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T92_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_8 = rawNewString(((NI) 80));
				T93_ = NIM_NIL;
				T93_ = rdLoc__cgen_435((*a));
				cgFormatValue__cgen_147((&res_8), T93_);
				res_8 = resizeString(res_8, 3);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
				T94_ = NIM_NIL;
				T94_ = rdLoc__cgen_435(b);
				cgFormatValue__cgen_147((&res_8), T94_);
				res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA97_;
					res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA97_: ;
				T99_ = NIM_NIL;
				T99_ = rope__ropes_109(res_8);
				T100_ = NIM_NIL;
				T100_ = indentLine__cgen_286(p, T99_);
				add__ropes_159(T92_, T100_);
			}
			LA73_: ;
		}
		goto LA38_;
		LA42_: ;
		{
			NimStringDesc* res_9;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T102_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T103_;
			res_9 = rawNewString(((NI) 80));
			res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T102_ = NIM_NIL;
			T102_ = getTypeDesc__cgen_6662((*p).module, typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			cgFormatValue__cgen_147((&res_9), T102_);
			res_9 = resizeString(res_9, 2);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_56));
			T103_ = NIM_NIL;
			T103_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_563));
			cgFormatValue__cgen_147((&res_9), T103_);
			res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			cgFormatValue__cgen_147((&res_9), ti);
			res_9 = resizeString(res_9, 2);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			cgFormatValue__cgen_147((&res_9), sizeExpr_2);
			res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
			b.r = rope__ropes_109(res_9);
			genAssignment__cgen_10403(p, (*a), b, 0);
		}
		LA38_: ;
	}
	LA6_: ;
	genObjectInit__cgen_10414(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2), bt, a, ((tyEnum_ObjConstrMode__fUO6aSwLQdJNwZTWRxqbKg) 1));
}
N_LIB_PRIVATE N_NIMCALL(void, genNew__cgen_20982)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	{
		NI T3_;
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw se;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
		T3_ = (NI)0;
		T3_ = len__ast_3155(e);
		if (!(T3_ == ((NI) 3))) goto LA4_;
		nimZeroMem((void*)(&se), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&se));
		T6_ = NIM_NIL;
		T6_ = rdLoc__cgen_435(se);
		rawGenNew__cgen_20825(p, (&a), T6_, NIM_TRUE);
	}
	goto LA1_;
	LA4_: ;
	{
		rawGenNew__cgen_20825(p, (&a), ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL), NIM_TRUE);
	}
	LA1_: ;
	gcUsage__cgen_20553((*(*(*p).module).g).config, e);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genTypeInfo__cgen_10314)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	{
		if (!(((*config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 41))&63U)))!=0)) goto LA3_;
		result = genTypeInfoV2__cgen_7958(m, t, info);
	}
	goto LA1_;
	LA3_: ;
	{
		result = genTypeInfoV1__cgen_6798(m, t, info);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genNewFinalize__cgen_21471)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw f;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* refType;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* bt;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* ti;
	tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T2_;
	NimStringDesc* res;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T3_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T4_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T5_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T6_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T8_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&f), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	refType = NIM_NIL;
	bt = NIM_NIL;
	ti = NIM_NIL;
	refType = skipTypes__ast_3723((*(*e)._kind_6.sons->data[((NI) 1)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_183);
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&f));
	initLoc__cgen_66((&b), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 6), a.lode, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 3));
	ti = genTypeInfo__cgen_10314((*(*(*p).module).g).config, (*p).module, refType, (*e).info);
	nimZeroMem((void*)T1_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
	T1_[0] = ti;
	T1_[1] = rdLoc__cgen_435(f);
	T2_ = NIM_NIL;
	T2_ = percent___cgen_20890(T1_, 2);
	add__ropes_159(&(*(*p).module).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 16))- 0], T2_);
	res = rawNewString(((NI) 80));
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
	T3_ = NIM_NIL;
	T3_ = getTypeDesc__cgen_6662((*p).module, refType, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
	cgFormatValue__cgen_147((&res), T3_);
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_56));
	T4_ = NIM_NIL;
	T4_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_563));
	cgFormatValue__cgen_147((&res), T4_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
	cgFormatValue__cgen_147((&res), ti);
	res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_127));
	T5_ = NIM_NIL;
	T5_ = lastSon__ast_3731(refType);
	T6_ = NIM_NIL;
	T6_ = skipTypes__ast_3723(T5_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_430);
	T7_ = NIM_NIL;
	T7_ = getTypeDesc__cgen_6662((*p).module, T6_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
	cgFormatValue__cgen_147((&res), T7_);
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_41));
	b.r = rope__ropes_109(res);
	genAssignment__cgen_10403(p, a, b, 0);
	T8_ = NIM_NIL;
	T8_ = lastSon__ast_3731(refType);
	bt = skipTypes__ast_3723(T8_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_430);
	genObjectInit__cgen_10414(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2), bt, (&a), ((tyEnum_ObjConstrMode__fUO6aSwLQdJNwZTWRxqbKg) 1));
	gcUsage__cgen_20553((*(*(*p).module).g).config, e);
}
N_LIB_PRIVATE N_NIMCALL(void, genNewSeqAux__cgen_20992)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw dest, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* length, NIM_BOOL lenIsZero) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* seqtype;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1_;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw call;
	T1_ = NIM_NIL;
	T1_ = t__cgen_85(dest);
	seqtype = skipTypes__ast_3723(T1_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_183);
	nimZeroMem((void*)(&call), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLoc__cgen_66((&call), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 6), dest.lode, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 3));
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = (dest.storage == ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 3));
		if (!(T4_)) goto LA5_;
		T4_ = usesWriteBarrier__options_4033((*(*(*p).module).g).config);
		LA5_: ;
		if (!T4_) goto LA6_;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T10_;
			NIM_BOOL T11_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T14_;
			NimStringDesc* res;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
			T10_ = NIM_NIL;
			T10_ = t__cgen_85(dest);
			T11_ = (NIM_BOOL)0;
			T11_ = canFormAcycle__types_820((*(*(*p).module).g).graph, T10_);
			if (!T11_) goto LA12_;
			T14_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T14_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res = rawNewString(((NI) 80));
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
			T15_ = NIM_NIL;
			T15_ = rdLoc__cgen_435(dest);
			cgFormatValue__cgen_147((&res), T15_);
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_477));
			T16_ = NIM_NIL;
			T16_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_561));
			cgFormatValue__cgen_147((&res), T16_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T17_ = NIM_NIL;
			T17_ = rdLoc__cgen_435(dest);
			cgFormatValue__cgen_147((&res), T17_);
			res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_437));
			T18_ = NIM_NIL;
			T18_ = rdLoc__cgen_435(dest);
			cgFormatValue__cgen_147((&res), T18_);
			res = resizeString(res, 13);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_562));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA21_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA21_: ;
			T23_ = NIM_NIL;
			T23_ = rope__ropes_109(res);
			T24_ = NIM_NIL;
			T24_ = indentLine__cgen_286(p, T23_);
			add__ropes_159(T14_, T24_);
		}
		goto LA8_;
		LA12_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T26_;
			NimStringDesc* res_2;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T27_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T28_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T29_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T30_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T35_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T36_;
			T26_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T26_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_2 = rawNewString(((NI) 80));
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
			T27_ = NIM_NIL;
			T27_ = rdLoc__cgen_435(dest);
			cgFormatValue__cgen_147((&res_2), T27_);
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_477));
			T28_ = NIM_NIL;
			T28_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_261));
			cgFormatValue__cgen_147((&res_2), T28_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T29_ = NIM_NIL;
			T29_ = rdLoc__cgen_435(dest);
			cgFormatValue__cgen_147((&res_2), T29_);
			res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_437));
			T30_ = NIM_NIL;
			T30_ = rdLoc__cgen_435(dest);
			cgFormatValue__cgen_147((&res_2), T30_);
			res_2 = resizeString(res_2, 13);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_562));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA33_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA33_: ;
			T35_ = NIM_NIL;
			T35_ = rope__ropes_109(res_2);
			T36_ = NIM_NIL;
			T36_ = indentLine__cgen_286(p, T35_);
			add__ropes_159(T26_, T36_);
		}
		LA8_: ;
		{
			if (!!(lenIsZero)) goto LA39_;
			{
				NimStringDesc* res_3;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T45_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T46_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T47_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T48_;
				NimStringDesc* res_4;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T49_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T50_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T51_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T56_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T57_;
				if (!((*(*(*(*p).module).g).config).selectedGC == ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 10))) goto LA43_;
				res_3 = rawNewString(((NI) 80));
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
				T45_ = NIM_NIL;
				T45_ = getTypeDesc__cgen_6662((*p).module, seqtype, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
				cgFormatValue__cgen_147((&res_3), T45_);
				res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_56));
				T46_ = NIM_NIL;
				T46_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_569));
				cgFormatValue__cgen_147((&res_3), T46_);
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
				T47_ = NIM_NIL;
				T47_ = genTypeInfoV1__cgen_6798((*p).module, seqtype, (*dest.lode).info);
				cgFormatValue__cgen_147((&res_3), T47_);
				res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
				cgFormatValue__cgen_147((&res_3), length);
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
				call.r = rope__ropes_109(res_3);
				T48_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T48_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_4 = rawNewString(((NI) 80));
				T49_ = NIM_NIL;
				T49_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_123));
				cgFormatValue__cgen_147((&res_4), T49_);
				res_4 = resizeString(res_4, 10);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_121));
				T50_ = NIM_NIL;
				T50_ = addrLoc__cgen_10337((*(*(*p).module).g).config, dest);
				cgFormatValue__cgen_147((&res_4), T50_);
				res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
				T51_ = NIM_NIL;
				T51_ = rdLoc__cgen_435(call);
				cgFormatValue__cgen_147((&res_4), T51_);
				res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA54_;
					res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA54_: ;
				T56_ = NIM_NIL;
				T56_ = rope__ropes_109(res_4);
				T57_ = NIM_NIL;
				T57_ = indentLine__cgen_286(p, T56_);
				add__ropes_159(T48_, T57_);
			}
			goto LA41_;
			LA43_: ;
			{
				NimStringDesc* res_5;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T59_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T60_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T61_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T62_;
				NimStringDesc* res_6;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T63_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T64_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T69_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T70_;
				res_5 = rawNewString(((NI) 80));
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
				T59_ = NIM_NIL;
				T59_ = getTypeDesc__cgen_6662((*p).module, seqtype, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
				cgFormatValue__cgen_147((&res_5), T59_);
				res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_56));
				T60_ = NIM_NIL;
				T60_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_570));
				cgFormatValue__cgen_147((&res_5), T60_);
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
				T61_ = NIM_NIL;
				T61_ = genTypeInfoV1__cgen_6798((*p).module, seqtype, (*dest.lode).info);
				cgFormatValue__cgen_147((&res_5), T61_);
				res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
				cgFormatValue__cgen_147((&res_5), length);
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
				call.r = rope__ropes_109(res_5);
				T62_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T62_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_6 = rawNewString(((NI) 80));
				T63_ = NIM_NIL;
				T63_ = rdLoc__cgen_435(dest);
				cgFormatValue__cgen_147((&res_6), T63_);
				res_6 = resizeString(res_6, 3);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
				T64_ = NIM_NIL;
				T64_ = rdLoc__cgen_435(call);
				cgFormatValue__cgen_147((&res_6), T64_);
				res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA67_;
					res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA67_: ;
				T69_ = NIM_NIL;
				T69_ = rope__ropes_109(res_6);
				T70_ = NIM_NIL;
				T70_ = indentLine__cgen_286(p, T69_);
				add__ropes_159(T62_, T70_);
			}
			LA41_: ;
		}
		LA39_: ;
	}
	goto LA2_;
	LA6_: ;
	{
		{
			if (!lenIsZero) goto LA74_;
			call.r = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_242));
		}
		goto LA72_;
		LA74_: ;
		{
			NimStringDesc* res_7;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T77_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T78_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T79_;
			res_7 = rawNewString(((NI) 80));
			res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T77_ = NIM_NIL;
			T77_ = getTypeDesc__cgen_6662((*p).module, seqtype, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			cgFormatValue__cgen_147((&res_7), T77_);
			res_7 = resizeString(res_7, 2);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_56));
			T78_ = NIM_NIL;
			T78_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_569));
			cgFormatValue__cgen_147((&res_7), T78_);
			res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T79_ = NIM_NIL;
			T79_ = genTypeInfoV1__cgen_6798((*p).module, seqtype, (*dest.lode).info);
			cgFormatValue__cgen_147((&res_7), T79_);
			res_7 = resizeString(res_7, 2);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			cgFormatValue__cgen_147((&res_7), length);
			res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
			call.r = rope__ropes_109(res_7);
		}
		LA72_: ;
		genAssignment__cgen_10403(p, dest, call, 0);
	}
	LA2_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genNewSeq__cgen_21086)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* seqtype;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T5_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T12_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T14_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T21_;
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0)) goto LA3_;
		seqtype = skipTypes__ast_3723((*(*e)._kind_6.sons->data[((NI) 1)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_183);
		T5_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T5_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res = rawNewString(((NI) 80));
		T6_ = NIM_NIL;
		T6_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res), T6_);
		res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_565));
		T7_ = NIM_NIL;
		T7_ = rdLoc__cgen_435(b);
		cgFormatValue__cgen_147((&res), T7_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_164));
		T8_ = NIM_NIL;
		T8_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res), T8_);
		res = resizeString(res, 6);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_566));
		T9_ = NIM_NIL;
		T9_ = getSeqPayloadType__cgen_3476((*p).module, seqtype);
		cgFormatValue__cgen_147((&res), T9_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_389));
		T10_ = NIM_NIL;
		T10_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_567));
		cgFormatValue__cgen_147((&res), T10_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T11_ = NIM_NIL;
		T11_ = rdLoc__cgen_435(b);
		cgFormatValue__cgen_147((&res), T11_);
		res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_127));
		T12_ = NIM_NIL;
		T12_ = lastSon__ast_3731(seqtype);
		T13_ = NIM_NIL;
		T13_ = getTypeDesc__cgen_6662((*p).module, T12_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		cgFormatValue__cgen_147((&res), T13_);
		res = resizeString(res, 15);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_568));
		T14_ = NIM_NIL;
		T14_ = lastSon__ast_3731(seqtype);
		T15_ = NIM_NIL;
		T15_ = getTypeDesc__cgen_6662((*p).module, T14_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		cgFormatValue__cgen_147((&res), T15_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_128));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA18_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA18_: ;
		T20_ = NIM_NIL;
		T20_ = rope__ropes_109(res);
		T21_ = NIM_NIL;
		T21_ = indentLine__cgen_286(p, T20_);
		add__ropes_159(T5_, T21_);
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL lenIsZero;
		NIM_BOOL T23_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
		T23_ = (NIM_BOOL)0;
		T23_ = ((*(*e)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6));
		if (!(T23_)) goto LA24_;
		T23_ = ((*(*e)._kind_6.sons->data[((NI) 2)])._kind_1.intVal == IL64(0));
		LA24_: ;
		lenIsZero = T23_;
		T25_ = NIM_NIL;
		T25_ = rdLoc__cgen_435(b);
		genNewSeqAux__cgen_20992(p, a, T25_, lenIsZero);
		gcUsage__cgen_20553((*(*(*p).module).g).config, e);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genNewSeqOfCap__cgen_21125)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* seqtype;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	seqtype = skipTypes__ast_3723((*e).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_183);
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T9_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T15_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T17_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0)) goto LA3_;
		{
			if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA7_;
			getTemp__cgen_7373(p, (*e).typ, d, NIM_FALSE);
		}
		LA7_: ;
		T9_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T9_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res = rawNewString(((NI) 80));
		T10_ = NIM_NIL;
		T10_ = rdLoc__cgen_435((*d));
		cgFormatValue__cgen_147((&res), T10_);
		res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_116));
		T11_ = NIM_NIL;
		T11_ = rdLoc__cgen_435((*d));
		cgFormatValue__cgen_147((&res), T11_);
		res = resizeString(res, 6);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_566));
		T12_ = NIM_NIL;
		T12_ = getSeqPayloadType__cgen_3476((*p).module, seqtype);
		cgFormatValue__cgen_147((&res), T12_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_389));
		T13_ = NIM_NIL;
		T13_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_567));
		cgFormatValue__cgen_147((&res), T13_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T14_ = NIM_NIL;
		T14_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res), T14_);
		res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_127));
		T15_ = NIM_NIL;
		T15_ = lastSon__ast_3731(seqtype);
		T16_ = NIM_NIL;
		T16_ = getTypeDesc__cgen_6662((*p).module, T15_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		cgFormatValue__cgen_147((&res), T16_);
		res = resizeString(res, 15);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_568));
		T17_ = NIM_NIL;
		T17_ = lastSon__ast_3731(seqtype);
		T18_ = NIM_NIL;
		T18_ = getTypeDesc__cgen_6662((*p).module, T17_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		cgFormatValue__cgen_147((&res), T18_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_128));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA21_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA21_: ;
		T23_ = NIM_NIL;
		T23_ = rope__ropes_109(res);
		T24_ = NIM_NIL;
		T24_ = indentLine__cgen_286(p, T23_);
		add__ropes_159(T9_, T24_);
	}
	goto LA1_;
	LA3_: ;
	{
		NimStringDesc* res_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T27_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T28_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T29_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T30_;
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T26_ = NIM_NIL;
		T26_ = getTypeDesc__cgen_6662((*p).module, seqtype, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		cgFormatValue__cgen_147((&res_2), T26_);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		T27_ = NIM_NIL;
		T27_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_571));
		cgFormatValue__cgen_147((&res_2), T27_);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T28_ = NIM_NIL;
		T28_ = genTypeInfoV1__cgen_6798((*p).module, seqtype, (*e).info);
		cgFormatValue__cgen_147((&res_2), T28_);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		T29_ = NIM_NIL;
		T29_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res_2), T29_);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		T30_ = NIM_NIL;
		T30_ = rope__ropes_109(res_2);
		putIntoDest__cgen_18794(p, d, e, T30_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
		gcUsage__cgen_20553((*(*(*p).module).g).config, e);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSomeCast__cgen_22901)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* etyp;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* srcTyp;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	etyp = skipTypes__ast_3723((*e).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_549);
	srcTyp = skipTypes__ast_3723((*(*e)._kind_6.sons->data[((NI) 1)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_430);
	{
		NIM_BOOL T3_;
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T7_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*etyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18) || (*etyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17) || (*etyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16) || (*etyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27) || (*etyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48) || (*etyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 49));
		if (!(T3_)) goto LA4_;
		T3_ = !(((a.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 0))&15U)))!=0));
		LA4_: ;
		if (!T3_) goto LA5_;
		nimZeroMem((void*)T7_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T7_[0] = getTypeDesc__cgen_6662((*p).module, (*e).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		T7_[1] = addrLoc__cgen_10337((*(*(*p).module).g).config, a);
		T8_ = NIM_NIL;
		T8_ = percent___cgen_22923(T7_, 2);
		putIntoDest__cgen_18794(p, d, e, T8_, a.storage);
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T10_;
		NIM_BOOL T11_;
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T16_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
		T10_ = (NIM_BOOL)0;
		T11_ = (NIM_BOOL)0;
		T11_ = ((*etyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25));
		if (!(T11_)) goto LA12_;
		T11_ = ((*etyp).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
		LA12_: ;
		T10_ = T11_;
		if (!(T10_)) goto LA13_;
		T10_ = !(((*srcTyp).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9)));
		LA13_: ;
		if (!T10_) goto LA14_;
		nimZeroMem((void*)T16_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T16_[0] = getClosureType__cgen_6675((*p).module, etyp, ((tyEnum_TClosureTypeKind__9cCFzcVQ9cBXhFbAj307bqVg) 1));
		T16_[1] = rdCharLoc__cgen_10377(a);
		T17_ = NIM_NIL;
		T17_ = percent___cgen_22940(T16_, 2);
		putIntoDest__cgen_18794(p, d, e, T17_, a.storage);
	}
	goto LA1_;
	LA14_: ;
	{
		{
			NIM_BOOL T21_;
			tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T25_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
			T21_ = (NIM_BOOL)0;
			T21_ = ((*srcTyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21) || (*srcTyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 26));
			if (!(T21_)) goto LA22_;
			T21_ = ((*etyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1) || (*etyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2) || (*etyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14) || (*etyp).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) && (*etyp).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35) || (*etyp).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36) && (*etyp).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 39) || (*etyp).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40) && (*etyp).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44));
			LA22_: ;
			if (!T21_) goto LA23_;
			nimZeroMem((void*)T25_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
			T25_[0] = getTypeDesc__cgen_6662((*p).module, (*e).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			T25_[1] = rdCharLoc__cgen_10377(a);
			T26_ = NIM_NIL;
			T26_ = percent___cgen_22953(T25_, 2);
			putIntoDest__cgen_18794(p, d, e, T26_, a.storage);
		}
		goto LA19_;
		LA23_: ;
		{
			NIM_BOOL T28_;
			tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T32_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T33_;
			T28_ = (NIM_BOOL)0;
			T28_ = (((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0);
			if (!(T28_)) goto LA29_;
			T28_ = ((*etyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24) || (*etyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28));
			LA29_: ;
			if (!T28_) goto LA30_;
			nimZeroMem((void*)T32_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
			T32_[0] = getTypeDesc__cgen_6662((*p).module, (*e).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			T32_[1] = rdCharLoc__cgen_10377(a);
			T33_ = NIM_NIL;
			T33_ = percent___cgen_22966(T32_, 2);
			putIntoDest__cgen_18794(p, d, e, T33_, a.storage);
		}
		goto LA19_;
		LA30_: ;
		{
			NIM_BOOL T35_;
			tyArray__ts9cf9blICas1QWmw89bglZ7w T39_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T40_;
			T35_ = (NIM_BOOL)0;
			T35_ = ((*etyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1));
			if (!(T35_)) goto LA36_;
			T35_ = ((*srcTyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1) || (*srcTyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2) || (*srcTyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14) || (*srcTyp).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) && (*srcTyp).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35) || (*srcTyp).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36) && (*srcTyp).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 39) || (*srcTyp).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40) && (*srcTyp).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44));
			LA36_: ;
			if (!T35_) goto LA37_;
			nimZeroMem((void*)T39_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T39_[0] = rdCharLoc__cgen_10377(a);
			T40_ = NIM_NIL;
			T40_ = percent___cgen_22979(T39_, 1);
			putIntoDest__cgen_18794(p, d, e, T40_, a.storage);
		}
		goto LA19_;
		LA37_: ;
		{
			tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T51_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T52_;
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* internalType;
				if (!((*etyp).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21))) goto LA44_;
				internalType = skipTypes__ast_3723(etyp, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_576);
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T50_;
					if (!((*internalType).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17))) goto LA48_;
					T50_ = NIM_NIL;
					T50_ = getTypeDesc__cgen_6662((*p).module, internalType, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
					(void)(T50_);
				}
				LA48_: ;
			}
			LA44_: ;
			nimZeroMem((void*)T51_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
			T51_[0] = getTypeDesc__cgen_6662((*p).module, (*e).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			T51_[1] = rdCharLoc__cgen_10377(a);
			T52_ = NIM_NIL;
			T52_ = percent___cgen_22940(T51_, 2);
			putIntoDest__cgen_18794(p, d, e, T52_, a.storage);
		}
		LA19_: ;
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genOrd__cgen_22885)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym5136_;
	NimStringDesc* res;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T2_;
	nimZeroMem((void*)(&aX60gensym5136_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5136_));
	res = rawNewString(((NI) 80));
	T1_ = NIM_NIL;
	T1_ = rdCharLoc__cgen_10377(aX60gensym5136_);
	cgFormatValue__cgen_147((&res), T1_);
	T2_ = NIM_NIL;
	T2_ = rope__ropes_109(res);
	putIntoDest__cgen_18794(p, d, e, T2_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
}
N_LIB_PRIVATE N_NIMCALL(void, genArrayLen__cgen_21867)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag op) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
	a = (*e)._kind_6.sons->data[((NI) 1)];
	{
		if (!((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64))) goto LA3_;
		a = (*a)._kind_6.sons->data[((NI) 0)];
	}
	LA3_: ;
	typ = skipTypes__ast_3723((*a).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_577);
	switch ((*typ).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48):
	{
		{
			NIM_BOOL T8_;
			NIM_BOOL T9_;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw m;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw c;
			T8_ = (NIM_BOOL)0;
			T9_ = (NIM_BOOL)0;
			T9_ = ((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29) || (*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30) || (*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31) || (*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) || (*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28) || (*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32));
			if (!(T9_)) goto LA10_;
			T9_ = ((*(*a)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
			LA10_: ;
			T8_ = T9_;
			if (!(T8_)) goto LA11_;
			T8_ = ((*(*(*a)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 126));
			LA11_: ;
			if (!T8_) goto LA12_;
			nimZeroMem((void*)(&m), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			nimZeroMem((void*)(&c), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLocExpr__cgen_11548(p, (*a)._kind_6.sons->data[((NI) 1)], (&m));
			initLocExpr__cgen_11548(p, (*a)._kind_6.sons->data[((NI) 2)], (&b));
			initLocExpr__cgen_11548(p, (*a)._kind_6.sons->data[((NI) 3)], (&c));
			{
				if (!(((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 4))&31U)))!=0)) goto LA16_;
				genBoundsCheck__cgen_11820(p, m, b, c);
			}
			LA16_: ;
			{
				NimStringDesc* res;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
				if (!(op == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 9))) goto LA20_;
				res = rawNewString(((NI) 80));
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
				T22_ = NIM_NIL;
				T22_ = rdLoc__cgen_435(c);
				cgFormatValue__cgen_147((&res), T22_);
				res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_578));
				T23_ = NIM_NIL;
				T23_ = rdLoc__cgen_435(b);
				cgFormatValue__cgen_147((&res), T23_);
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
				T24_ = NIM_NIL;
				T24_ = rope__ropes_109(res);
				putIntoDest__cgen_18794(p, d, e, T24_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
			}
			goto LA18_;
			LA20_: ;
			{
				NimStringDesc* res_2;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T27_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T28_;
				res_2 = rawNewString(((NI) 80));
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
				T26_ = NIM_NIL;
				T26_ = rdLoc__cgen_435(c);
				cgFormatValue__cgen_147((&res_2), T26_);
				res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_578));
				T27_ = NIM_NIL;
				T27_ = rdLoc__cgen_435(b);
				cgFormatValue__cgen_147((&res_2), T27_);
				res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_579));
				T28_ = NIM_NIL;
				T28_ = rope__ropes_109(res_2);
				putIntoDest__cgen_18794(p, d, e, T28_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
			}
			LA18_: ;
		}
		goto LA6_;
		LA12_: ;
		{
			{
				NIM_BOOL T32_;
				T32_ = (NIM_BOOL)0;
				T32_ = reifiedOpenArray__cgen_11825(a);
				if (!!(T32_)) goto LA33_;
				{
					tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym4745_;
					NimStringDesc* res_3;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T39_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T40_;
					if (!(op == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 9))) goto LA37_;
					nimZeroMem((void*)(&aX60gensym4745_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
					initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4745_));
					res_3 = rawNewString(((NI) 80));
					res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
					T39_ = NIM_NIL;
					T39_ = rdLoc__cgen_435(aX60gensym4745_);
					cgFormatValue__cgen_147((&res_3), T39_);
					res_3 = resizeString(res_3, 8);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_580));
					T40_ = NIM_NIL;
					T40_ = rope__ropes_109(res_3);
					putIntoDest__cgen_18794(p, d, e, T40_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
				}
				goto LA35_;
				LA37_: ;
				{
					tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym4751_;
					NimStringDesc* res_4;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T42_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T43_;
					nimZeroMem((void*)(&aX60gensym4751_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
					initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4751_));
					res_4 = rawNewString(((NI) 80));
					T42_ = NIM_NIL;
					T42_ = rdLoc__cgen_435(aX60gensym4751_);
					cgFormatValue__cgen_147((&res_4), T42_);
					res_4 = resizeString(res_4, 5);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_581));
					T43_ = NIM_NIL;
					T43_ = rope__ropes_109(res_4);
					putIntoDest__cgen_18794(p, d, e, T43_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
				}
				LA35_: ;
			}
			goto LA30_;
			LA33_: ;
			{
				NIM_BOOL isDeref;
				isDeref = ((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65) || (*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 47));
				{
					if (!(op == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 9))) goto LA47_;
					{
						tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym4758_;
						NimStringDesc* res_5;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T53_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T54_;
						if (!isDeref) goto LA51_;
						nimZeroMem((void*)(&aX60gensym4758_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
						initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4758_));
						res_5 = rawNewString(((NI) 80));
						res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
						T53_ = NIM_NIL;
						T53_ = rdLoc__cgen_435(aX60gensym4758_);
						cgFormatValue__cgen_147((&res_5), T53_);
						res_5 = resizeString(res_5, 11);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_582));
						T54_ = NIM_NIL;
						T54_ = rope__ropes_109(res_5);
						putIntoDest__cgen_18794(p, d, e, T54_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
					}
					goto LA49_;
					LA51_: ;
					{
						tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym4764_;
						NimStringDesc* res_6;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T56_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T57_;
						nimZeroMem((void*)(&aX60gensym4764_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
						initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4764_));
						res_6 = rawNewString(((NI) 80));
						res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
						T56_ = NIM_NIL;
						T56_ = rdLoc__cgen_435(aX60gensym4764_);
						cgFormatValue__cgen_147((&res_6), T56_);
						res_6 = resizeString(res_6, 10);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_583));
						T57_ = NIM_NIL;
						T57_ = rope__ropes_109(res_6);
						putIntoDest__cgen_18794(p, d, e, T57_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
					}
					LA49_: ;
				}
				goto LA45_;
				LA47_: ;
				{
					{
						tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym4770_;
						NimStringDesc* res_7;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T63_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T64_;
						if (!isDeref) goto LA61_;
						nimZeroMem((void*)(&aX60gensym4770_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
						initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4770_));
						res_7 = rawNewString(((NI) 80));
						T63_ = NIM_NIL;
						T63_ = rdLoc__cgen_435(aX60gensym4770_);
						cgFormatValue__cgen_147((&res_7), T63_);
						res_7 = resizeString(res_7, 8);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_584));
						T64_ = NIM_NIL;
						T64_ = rope__ropes_109(res_7);
						putIntoDest__cgen_18794(p, d, e, T64_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
					}
					goto LA59_;
					LA61_: ;
					{
						tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym4776_;
						NimStringDesc* res_8;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T66_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T67_;
						nimZeroMem((void*)(&aX60gensym4776_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
						initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4776_));
						res_8 = rawNewString(((NI) 80));
						T66_ = NIM_NIL;
						T66_ = rdLoc__cgen_435(aX60gensym4776_);
						cgFormatValue__cgen_147((&res_8), T66_);
						res_8 = resizeString(res_8, 7);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_585));
						T67_ = NIM_NIL;
						T67_ = rope__ropes_109(res_8);
						putIntoDest__cgen_18794(p, d, e, T67_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
					}
					LA59_: ;
				}
				LA45_: ;
			}
			LA30_: ;
		}
		LA6_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29):
	{
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym4782_;
			NimStringDesc* res_9;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T73_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T74_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T75_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T76_;
			if (!(op == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 9))) goto LA71_;
			nimZeroMem((void*)(&aX60gensym4782_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4782_));
			res_9 = rawNewString(((NI) 80));
			res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T73_ = NIM_NIL;
			T73_ = rdLoc__cgen_435(aX60gensym4782_);
			cgFormatValue__cgen_147((&res_9), T73_);
			res_9 = resizeString(res_9, 4);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_586));
			T74_ = NIM_NIL;
			T74_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_587));
			cgFormatValue__cgen_147((&res_9), T74_);
			res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T75_ = NIM_NIL;
			T75_ = rdLoc__cgen_435(aX60gensym4782_);
			cgFormatValue__cgen_147((&res_9), T75_);
			res_9 = resizeString(res_9, 10);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_588));
			T76_ = NIM_NIL;
			T76_ = rope__ropes_109(res_9);
			putIntoDest__cgen_18794(p, d, e, T76_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
		}
		goto LA69_;
		LA71_: ;
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym4788_;
			NimStringDesc* res_10;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T78_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T79_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T80_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T81_;
			nimZeroMem((void*)(&aX60gensym4788_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4788_));
			res_10 = rawNewString(((NI) 80));
			res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T78_ = NIM_NIL;
			T78_ = rdLoc__cgen_435(aX60gensym4788_);
			cgFormatValue__cgen_147((&res_10), T78_);
			res_10 = resizeString(res_10, 3);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_589));
			T79_ = NIM_NIL;
			T79_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_587));
			cgFormatValue__cgen_147((&res_10), T79_);
			res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T80_ = NIM_NIL;
			T80_ = rdLoc__cgen_435(aX60gensym4788_);
			cgFormatValue__cgen_147((&res_10), T80_);
			res_10 = resizeString(res_10, 6);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_590));
			T81_ = NIM_NIL;
			T81_ = rope__ropes_109(res_10);
			putIntoDest__cgen_18794(p, d, e, T81_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
		}
		LA69_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* x;
		nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a_2));
		x = lenExpr__cgen_458(p, a_2);
		{
			tyArray__ts9cf9blICas1QWmw89bglZ7w T87_;
			if (!(op == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 9))) goto LA85_;
			nimZeroMem((void*)T87_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T87_[0] = x;
			x = percent___cgen_22050(T87_, 1);
		}
		LA85_: ;
		putIntoDest__cgen_18794(p, d, e, x, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a_3;
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tmp;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* x_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T94_;
		NimStringDesc* res_11;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T99_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T100_;
		nimZeroMem((void*)(&a_3), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a_3));
		getIntTemp__cgen_11104(p, (&tmp));
		x_2 = lenExpr__cgen_458(p, a_3);
		{
			tyArray__ts9cf9blICas1QWmw89bglZ7w T93_;
			if (!(op == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 9))) goto LA91_;
			nimZeroMem((void*)T93_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T93_[0] = x_2;
			x_2 = percent___cgen_22050(T93_, 1);
		}
		LA91_: ;
		T94_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T94_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_11 = rawNewString(((NI) 80));
		cgFormatValue__cgen_147((&res_11), tmp.r);
		res_11 = resizeString(res_11, 3);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
		cgFormatValue__cgen_147((&res_11), x_2);
		res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA97_;
			res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA97_: ;
		T99_ = NIM_NIL;
		T99_ = rope__ropes_109(res_11);
		T100_ = NIM_NIL;
		T100_ = indentLine__cgen_286(p, T99_);
		add__ropes_159(T94_, T100_);
		putIntoDest__cgen_18794(p, d, e, tmp.r, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
	{
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T106_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T107_;
			if (!(op == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 9))) goto LA104_;
			T106_ = lastOrd__types_1532((*(*(*p).module).g).config, typ);
			T107_ = NIM_NIL;
			T107_ = rope__cgen_6948(T106_);
			putIntoDest__cgen_18794(p, d, e, T107_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
		}
		goto LA102_;
		LA104_: ;
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T109_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T110_;
			T109_ = lengthOrd__types_1723((*(*(*p).module).g).config, typ);
			T110_ = NIM_NIL;
			T110_ = rope__cgen_6948(T109_);
			putIntoDest__cgen_18794(p, d, e, T110_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
		}
		LA102_: ;
	}
	break;
	default:
	{
		internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*e).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_591), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_592);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genSetLengthStr__cgen_22154)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	{
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0)) goto LA3_;
		binaryStmtAddr__cgen_18835(p, e, d, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_598));
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw call;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		nimZeroMem((void*)(&call), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		{
			if (!!(((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0)))) goto LA8_;
			internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*e).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_599), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_600);
		}
		LA8_: ;
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
		initLoc__cgen_66((&call), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 9), e, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 3));
		res = rawNewString(((NI) 80));
		T10_ = NIM_NIL;
		T10_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_601));
		cgFormatValue__cgen_147((&res), T10_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T11_ = NIM_NIL;
		T11_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res), T11_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		T12_ = NIM_NIL;
		T12_ = rdLoc__cgen_435(b);
		cgFormatValue__cgen_147((&res), T12_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		call.r = rope__ropes_109(res);
		genAssignment__cgen_10403(p, a, call, 0);
		gcUsage__cgen_20553((*(*(*p).module).g).config, e);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSetLengthSeq__cgen_22096)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw call;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
{	{
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0)) goto LA3_;
		asgnRef((void**) (&(*e)._kind_6.sons->data[((NI) 1)]), makeAddr__cgen_22088((*e)._kind_6.sons->data[((NI) 1)], (*(*p).module).Sup.idgen));
		genCall__cgen_13177(p, e, d);
		goto BeforeRet_;
	}
	LA3_: ;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&call), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	x = (*e)._kind_6.sons->data[((NI) 1)];
	{
		if (!((*x).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63) || (*x).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64))) goto LA7_;
		x = (*x)._kind_6.sons->data[((NI) 0)];
	}
	LA7_: ;
	initLocExpr__cgen_11548(p, x, (&a));
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
	t = skipTypes__ast_3723((*(*e)._kind_6.sons->data[((NI) 1)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_531);
	initLoc__cgen_66((&call), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 9), e, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 3));
	{
		NIM_BOOL T11_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T19_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T21_;
		T11_ = (NIM_BOOL)0;
		T11_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
		if (T11_) goto LA12_;
		T11_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
		LA12_: ;
		if (!!(T11_)) goto LA13_;
		res = rawNewString(((NI) 80));
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T15_ = NIM_NIL;
		T15_ = getTypeDesc__cgen_6662((*p).module, t, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		cgFormatValue__cgen_147((&res), T15_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_56));
		T16_ = NIM_NIL;
		T16_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_602));
		cgFormatValue__cgen_147((&res), T16_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_29));
		T17_ = NIM_NIL;
		T17_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res), T17_);
		res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_603));
		T18_ = NIM_NIL;
		T18_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res), T18_);
		res = resizeString(res, 16);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_604));
		T19_ = NIM_NIL;
		T19_ = skipTypes__ast_3723(t, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
		T20_ = NIM_NIL;
		T20_ = genTypeInfoV1__cgen_6798((*p).module, T19_, (*e).info);
		cgFormatValue__cgen_147((&res), T20_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		T21_ = NIM_NIL;
		T21_ = rdLoc__cgen_435(b);
		cgFormatValue__cgen_147((&res), T21_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		call.r = rope__ropes_109(res);
	}
	goto LA9_;
	LA13_: ;
	{
		NimStringDesc* res_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T26_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T27_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T28_;
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T23_ = NIM_NIL;
		T23_ = getTypeDesc__cgen_6662((*p).module, t, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		cgFormatValue__cgen_147((&res_2), T23_);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_56));
		T24_ = NIM_NIL;
		T24_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_602));
		cgFormatValue__cgen_147((&res_2), T24_);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T25_ = NIM_NIL;
		T25_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res_2), T25_);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		T26_ = NIM_NIL;
		T26_ = skipTypes__ast_3723(t, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
		T27_ = NIM_NIL;
		T27_ = genTypeInfoV1__cgen_6798((*p).module, T26_, (*e).info);
		cgFormatValue__cgen_147((&res_2), T27_);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		T28_ = NIM_NIL;
		T28_ = rdLoc__cgen_435(b);
		cgFormatValue__cgen_147((&res_2), T28_);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		call.r = rope__ropes_109(res_2);
	}
	LA9_: ;
	genAssignment__cgen_10403(p, a, call, 0);
	gcUsage__cgen_20553((*(*(*p).module).g).config, e);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, rdSetElemLoc__cgen_17717)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* setType;
	result = NIM_NIL;
	result = rdCharLoc__cgen_10377(a);
	setType = skipTypes__ast_3723(typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_201);
	{
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T3_;
		NIM_BOOL T4_;
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T7_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T8_;
		T3_ = firstOrd__types_1406(conf, setType);
		T4_ = (NIM_BOOL)0;
		T4_ = eqeq___int495056_952(T3_, IL64(0));
		if (!!(T4_)) goto LA5_;
		nimZeroMem((void*)T7_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T7_[0] = result;
		T8_ = firstOrd__types_1406(conf, setType);
		T7_[1] = rope__cgen_6948(T8_);
		result = percent___cgen_22205(T7_, 2);
	}
	LA5_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, fewCmps__cgen_22210)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* s) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		if (!!(((*s).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 39)))) goto LA3_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NIM_BOOL T7_;
		NI64 T8_;
		T7_ = (NIM_BOOL)0;
		T8_ = (NI64)0;
		T8_ = getSize__types_3388(conf, (*s).typ);
		T7_ = (T8_ <= ((NI64) ((*conf).target.intSize)));
		if (!(T7_)) goto LA9_;
		T7_ = (((*s).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg) 4))&31U)))!=0);
		LA9_: ;
		if (!T7_) goto LA10_;
		result = NIM_FALSE;
	}
	goto LA5_;
	LA10_: ;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T13_;
		T13_ = NIM_NIL;
		T13_ = elemType__types_263((*s).typ);
		if (!((*T13_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) || (*T13_).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 33) && (*T13_).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35))) goto LA14_;
		result = NIM_TRUE;
	}
	goto LA5_;
	LA14_: ;
	{
		NI T17_;
		T17_ = (NI)0;
		T17_ = len__ast_3155(s);
		result = (T17_ <= ((NI) 8));
	}
	LA5_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genInExprAux__cgen_19824)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* a, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* b, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1_;
	NI64 T2_;
	T1_ = NIM_NIL;
	T1_ = skipTypes__ast_3723((*(*e)._kind_6.sons->data[((NI) 1)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_266);
	T2_ = (NI64)0;
	T2_ = getSize__types_3388((*(*(*p).module).g).config, T1_);
	switch (((NI) (T2_))) {
	case ((NI) 1):
	{
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T4_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T5_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
		nimZeroMem((void*)T4_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T4_[0] = rdLoc__cgen_435((*a));
		T5_ = NIM_NIL;
		T5_ = t__cgen_85((*a));
		T4_[1] = rdSetElemLoc__cgen_17717((*(*(*p).module).g).config, (*b), T5_);
		T6_ = NIM_NIL;
		T6_ = percent___cgen_22243(T4_, 2);
		putIntoDest__cgen_18794(p, d, e, T6_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((NI) 2):
	{
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T8_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T9_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
		nimZeroMem((void*)T8_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T8_[0] = rdLoc__cgen_435((*a));
		T9_ = NIM_NIL;
		T9_ = t__cgen_85((*a));
		T8_[1] = rdSetElemLoc__cgen_17717((*(*(*p).module).g).config, (*b), T9_);
		T10_ = NIM_NIL;
		T10_ = percent___cgen_22248(T8_, 2);
		putIntoDest__cgen_18794(p, d, e, T10_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((NI) 4):
	{
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T12_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T13_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
		nimZeroMem((void*)T12_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T12_[0] = rdLoc__cgen_435((*a));
		T13_ = NIM_NIL;
		T13_ = t__cgen_85((*a));
		T12_[1] = rdSetElemLoc__cgen_17717((*(*(*p).module).g).config, (*b), T13_);
		T14_ = NIM_NIL;
		T14_ = percent___cgen_22253(T12_, 2);
		putIntoDest__cgen_18794(p, d, e, T14_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((NI) 8):
	{
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T16_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T17_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
		nimZeroMem((void*)T16_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T16_[0] = rdLoc__cgen_435((*a));
		T17_ = NIM_NIL;
		T17_ = t__cgen_85((*a));
		T16_[1] = rdSetElemLoc__cgen_17717((*(*(*p).module).g).config, (*b), T17_);
		T18_ = NIM_NIL;
		T18_ = percent___cgen_22258(T16_, 2);
		putIntoDest__cgen_18794(p, d, e, T18_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	default:
	{
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T20_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T21_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
		nimZeroMem((void*)T20_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T20_[0] = rdLoc__cgen_435((*a));
		T21_ = NIM_NIL;
		T21_ = t__cgen_85((*a));
		T20_[1] = rdSetElemLoc__cgen_17717((*(*(*p).module).g).config, (*b), T21_);
		T22_ = NIM_NIL;
		T22_ = percent___cgen_22263(T20_, 2);
		putIntoDest__cgen_18794(p, d, e, T22_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genInOp__cgen_22275)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw x;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw y;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&x), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&y), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	{
		NIM_BOOL T3_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ea;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*(*e)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 39));
		if (!(T3_)) goto LA4_;
		T3_ = fewCmps__cgen_22210((*(*(*p).module).g).config, (*e)._kind_6.sons->data[((NI) 1)]);
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			if (!((*(*e)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 70) || (*(*e)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 69))) goto LA9_;
			ea = (*(*e)._kind_6.sons->data[((NI) 2)])._kind_6.sons->data[((NI) 0)];
		}
		goto LA7_;
		LA9_: ;
		{
			ea = (*e)._kind_6.sons->data[((NI) 2)];
		}
		LA7_: ;
		initLocExpr__cgen_11548(p, ea, (&a));
		initLoc__cgen_66((&b), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 6), e, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
		{
			NI T14_;
			T14_ = (NI)0;
			T14_ = len__ast_3155((*e)._kind_6.sons->data[((NI) 1)]);
			if (!(((NI) 0) < T14_)) goto LA15_;
			b.r = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_3155((*e)._kind_6.sons->data[((NI) 1)]);
				i_2 = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
						if (!(i_2 < colontmp_)) goto LA19;
						i = i_2;
						it = (*(*e)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[i];
						{
							tyArray__FKvM4FDhljtt88k8FkGthA T24_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
							if (!((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 44))) goto LA22_;
							initLocExpr__cgen_11548(p, (*it)._kind_6.sons->data[((NI) 0)], (&x));
							initLocExpr__cgen_11548(p, (*it)._kind_6.sons->data[((NI) 1)], (&y));
							nimZeroMem((void*)T24_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
							T24_[0] = rdCharLoc__cgen_10377(a);
							T24_[1] = rdCharLoc__cgen_10377(x);
							T24_[2] = rdCharLoc__cgen_10377(y);
							T25_ = NIM_NIL;
							T25_ = percent___cgen_22320(T24_, 3);
							add__ropes_159(&b.r, T25_);
						}
						goto LA20_;
						LA22_: ;
						{
							tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T27_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T28_;
							initLocExpr__cgen_11548(p, it, (&x));
							nimZeroMem((void*)T27_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
							T27_[0] = rdCharLoc__cgen_10377(a);
							T27_[1] = rdCharLoc__cgen_10377(x);
							T28_ = NIM_NIL;
							T28_ = percent___cgen_22325(T27_, 2);
							add__ropes_159(&b.r, T28_);
						}
						LA20_: ;
						{
							NI T31_;
							T31_ = (NI)0;
							T31_ = len__ast_3155((*e)._kind_6.sons->data[((NI) 1)]);
							if (!(i < (NI)(T31_ - ((NI) 1)))) goto LA32_;
							add__ropes_162(&b.r, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_432));
						}
						LA32_: ;
						i_2 += ((NI) 1);
					} LA19: ;
				}
			}
			add__ropes_162(&b.r, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		}
		goto LA12_;
		LA15_: ;
		{
			b.r = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_153));
		}
		LA12_: ;
		putIntoDest__cgen_18794(p, d, e, b.r, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	goto LA1_;
	LA5_: ;
	{
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
		genInExprAux__cgen_19824(p, e, (&a), (&b), d);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSetOp__cgen_22352)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag op) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw i;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* setType;
	NI size;
	NI64 T1_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&i), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	setType = skipTypes__ast_3723((*(*e)._kind_6.sons->data[((NI) 1)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_266);
	T1_ = (NI64)0;
	T1_ = getSize__types_3388((*(*(*p).module).g).config, setType);
	size = ((NI) (T1_));
	switch (size) {
	case ((NI) 1):
	case ((NI) 2):
	case ((NI) 4):
	case ((NI) 8):
	{
		switch (op) {
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 40):
		{
			switch (size) {
			case ((NI) 1):
			{
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym4898_;
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw bX60gensym4898_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T5_;
				tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T6_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T7_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
				nimZeroMem((void*)(&aX60gensym4898_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				nimZeroMem((void*)(&bX60gensym4898_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4898_));
				initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym4898_));
				T5_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T5_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				nimZeroMem((void*)T6_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
				T6_[0] = rdLoc__cgen_435(aX60gensym4898_);
				T7_ = NIM_NIL;
				T7_ = t__cgen_85(aX60gensym4898_);
				T6_[1] = rdSetElemLoc__cgen_17717((*(*(*p).module).g).config, bX60gensym4898_, T7_);
				T8_ = NIM_NIL;
				T8_ = percent___cgen_22377(T6_, 2);
				T9_ = NIM_NIL;
				T9_ = indentLine__cgen_286(p, T8_);
				add__ropes_159(T5_, T9_);
			}
			break;
			case ((NI) 2):
			{
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym4905_;
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw bX60gensym4905_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T11_;
				tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T12_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T13_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
				nimZeroMem((void*)(&aX60gensym4905_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				nimZeroMem((void*)(&bX60gensym4905_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4905_));
				initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym4905_));
				T11_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T11_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				nimZeroMem((void*)T12_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
				T12_[0] = rdLoc__cgen_435(aX60gensym4905_);
				T13_ = NIM_NIL;
				T13_ = t__cgen_85(aX60gensym4905_);
				T12_[1] = rdSetElemLoc__cgen_17717((*(*(*p).module).g).config, bX60gensym4905_, T13_);
				T14_ = NIM_NIL;
				T14_ = percent___cgen_22395(T12_, 2);
				T15_ = NIM_NIL;
				T15_ = indentLine__cgen_286(p, T14_);
				add__ropes_159(T11_, T15_);
			}
			break;
			case ((NI) 4):
			{
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym4912_;
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw bX60gensym4912_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T17_;
				tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T18_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T19_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T21_;
				nimZeroMem((void*)(&aX60gensym4912_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				nimZeroMem((void*)(&bX60gensym4912_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4912_));
				initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym4912_));
				T17_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T17_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				nimZeroMem((void*)T18_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
				T18_[0] = rdLoc__cgen_435(aX60gensym4912_);
				T19_ = NIM_NIL;
				T19_ = t__cgen_85(aX60gensym4912_);
				T18_[1] = rdSetElemLoc__cgen_17717((*(*(*p).module).g).config, bX60gensym4912_, T19_);
				T20_ = NIM_NIL;
				T20_ = percent___cgen_22413(T18_, 2);
				T21_ = NIM_NIL;
				T21_ = indentLine__cgen_286(p, T20_);
				add__ropes_159(T17_, T21_);
			}
			break;
			case ((NI) 8):
			{
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym4919_;
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw bX60gensym4919_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T23_;
				tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T24_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T25_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T27_;
				nimZeroMem((void*)(&aX60gensym4919_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				nimZeroMem((void*)(&bX60gensym4919_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4919_));
				initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym4919_));
				T23_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T23_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				nimZeroMem((void*)T24_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
				T24_[0] = rdLoc__cgen_435(aX60gensym4919_);
				T25_ = NIM_NIL;
				T25_ = t__cgen_85(aX60gensym4919_);
				T24_[1] = rdSetElemLoc__cgen_17717((*(*(*p).module).g).config, bX60gensym4919_, T25_);
				T26_ = NIM_NIL;
				T26_ = percent___cgen_22431(T24_, 2);
				T27_ = NIM_NIL;
				T27_ = indentLine__cgen_286(p, T26_);
				add__ropes_159(T23_, T27_);
			}
			break;
			default:
			{
			}
			break;
			}
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 41):
		{
			switch (size) {
			case ((NI) 1):
			{
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym4928_;
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw bX60gensym4928_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T31_;
				tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T32_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T33_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T34_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T35_;
				nimZeroMem((void*)(&aX60gensym4928_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				nimZeroMem((void*)(&bX60gensym4928_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4928_));
				initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym4928_));
				T31_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T31_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				nimZeroMem((void*)T32_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
				T32_[0] = rdLoc__cgen_435(aX60gensym4928_);
				T33_ = NIM_NIL;
				T33_ = t__cgen_85(aX60gensym4928_);
				T32_[1] = rdSetElemLoc__cgen_17717((*(*(*p).module).g).config, bX60gensym4928_, T33_);
				T34_ = NIM_NIL;
				T34_ = percent___cgen_22452(T32_, 2);
				T35_ = NIM_NIL;
				T35_ = indentLine__cgen_286(p, T34_);
				add__ropes_159(T31_, T35_);
			}
			break;
			case ((NI) 2):
			{
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym4935_;
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw bX60gensym4935_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T37_;
				tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T38_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T39_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T40_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T41_;
				nimZeroMem((void*)(&aX60gensym4935_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				nimZeroMem((void*)(&bX60gensym4935_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4935_));
				initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym4935_));
				T37_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T37_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				nimZeroMem((void*)T38_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
				T38_[0] = rdLoc__cgen_435(aX60gensym4935_);
				T39_ = NIM_NIL;
				T39_ = t__cgen_85(aX60gensym4935_);
				T38_[1] = rdSetElemLoc__cgen_17717((*(*(*p).module).g).config, bX60gensym4935_, T39_);
				T40_ = NIM_NIL;
				T40_ = percent___cgen_22470(T38_, 2);
				T41_ = NIM_NIL;
				T41_ = indentLine__cgen_286(p, T40_);
				add__ropes_159(T37_, T41_);
			}
			break;
			case ((NI) 4):
			{
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym4942_;
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw bX60gensym4942_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T43_;
				tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T44_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T45_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T46_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T47_;
				nimZeroMem((void*)(&aX60gensym4942_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				nimZeroMem((void*)(&bX60gensym4942_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4942_));
				initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym4942_));
				T43_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T43_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				nimZeroMem((void*)T44_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
				T44_[0] = rdLoc__cgen_435(aX60gensym4942_);
				T45_ = NIM_NIL;
				T45_ = t__cgen_85(aX60gensym4942_);
				T44_[1] = rdSetElemLoc__cgen_17717((*(*(*p).module).g).config, bX60gensym4942_, T45_);
				T46_ = NIM_NIL;
				T46_ = percent___cgen_22488(T44_, 2);
				T47_ = NIM_NIL;
				T47_ = indentLine__cgen_286(p, T46_);
				add__ropes_159(T43_, T47_);
			}
			break;
			case ((NI) 8):
			{
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym4949_;
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw bX60gensym4949_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T49_;
				tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T50_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T51_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T52_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T53_;
				nimZeroMem((void*)(&aX60gensym4949_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				nimZeroMem((void*)(&bX60gensym4949_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4949_));
				initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym4949_));
				T49_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T49_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				nimZeroMem((void*)T50_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
				T50_[0] = rdLoc__cgen_435(aX60gensym4949_);
				T51_ = NIM_NIL;
				T51_ = t__cgen_85(aX60gensym4949_);
				T50_[1] = rdSetElemLoc__cgen_17717((*(*(*p).module).g).config, bX60gensym4949_, T51_);
				T52_ = NIM_NIL;
				T52_ = percent___cgen_22506(T50_, 2);
				T53_ = NIM_NIL;
				T53_ = indentLine__cgen_286(p, T52_);
				add__ropes_159(T49_, T53_);
			}
			break;
			default:
			{
			}
			break;
			}
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 42):
		{
			{
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym4958_;
				NimStringDesc* res;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T60_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T61_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T62_;
				if (!(size <= ((NI) 4))) goto LA58_;
				nimZeroMem((void*)(&aX60gensym4958_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4958_));
				res = rawNewString(((NI) 80));
				T60_ = NIM_NIL;
				T60_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_605));
				cgFormatValue__cgen_147((&res), T60_);
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
				T61_ = NIM_NIL;
				T61_ = rdCharLoc__cgen_10377(aX60gensym4958_);
				cgFormatValue__cgen_147((&res), T61_);
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
				T62_ = NIM_NIL;
				T62_ = rope__ropes_109(res);
				putIntoDest__cgen_18794(p, d, e, T62_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
			}
			goto LA56_;
			LA58_: ;
			{
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym4964_;
				NimStringDesc* res_2;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T64_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T65_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T66_;
				nimZeroMem((void*)(&aX60gensym4964_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4964_));
				res_2 = rawNewString(((NI) 80));
				T64_ = NIM_NIL;
				T64_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_606));
				cgFormatValue__cgen_147((&res_2), T64_);
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
				T65_ = NIM_NIL;
				T65_ = rdCharLoc__cgen_10377(aX60gensym4964_);
				cgFormatValue__cgen_147((&res_2), T65_);
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
				T66_ = NIM_NIL;
				T66_ = rope__ropes_109(res_2);
				putIntoDest__cgen_18794(p, d, e, T66_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
			}
			LA56_: ;
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 121):
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym4970_;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw bX60gensym4970_;
			NimStringDesc* res_3;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T68_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T69_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T70_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T71_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T72_;
			nimZeroMem((void*)(&aX60gensym4970_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			nimZeroMem((void*)(&bX60gensym4970_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4970_));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym4970_));
			res_3 = rawNewString(((NI) 80));
			res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_607));
			T68_ = NIM_NIL;
			T68_ = rdCharLoc__cgen_10377(aX60gensym4970_);
			cgFormatValue__cgen_147((&res_3), T68_);
			res_3 = resizeString(res_3, 5);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_608));
			T69_ = NIM_NIL;
			T69_ = rdCharLoc__cgen_10377(bX60gensym4970_);
			cgFormatValue__cgen_147((&res_3), T69_);
			res_3 = resizeString(res_3, 8);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_609));
			T70_ = NIM_NIL;
			T70_ = rdCharLoc__cgen_10377(aX60gensym4970_);
			cgFormatValue__cgen_147((&res_3), T70_);
			res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_473));
			T71_ = NIM_NIL;
			T71_ = rdCharLoc__cgen_10377(bX60gensym4970_);
			cgFormatValue__cgen_147((&res_3), T71_);
			res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_41));
			T72_ = NIM_NIL;
			T72_ = rope__ropes_109(res_3);
			putIntoDest__cgen_18794(p, d, e, T72_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 120):
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym4985_;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw bX60gensym4985_;
			NimStringDesc* res_4;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T74_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T75_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T76_;
			nimZeroMem((void*)(&aX60gensym4985_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			nimZeroMem((void*)(&bX60gensym4985_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4985_));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym4985_));
			res_4 = rawNewString(((NI) 80));
			res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_29));
			T74_ = NIM_NIL;
			T74_ = rdCharLoc__cgen_10377(aX60gensym4985_);
			cgFormatValue__cgen_147((&res_4), T74_);
			res_4 = resizeString(res_4, 5);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_608));
			T75_ = NIM_NIL;
			T75_ = rdCharLoc__cgen_10377(bX60gensym4985_);
			cgFormatValue__cgen_147((&res_4), T75_);
			res_4 = resizeString(res_4, 5);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_610));
			T76_ = NIM_NIL;
			T76_ = rope__ropes_109(res_4);
			putIntoDest__cgen_18794(p, d, e, T76_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 119):
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym5000_;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw bX60gensym5000_;
			NimStringDesc* res_5;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T78_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T79_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T80_;
			nimZeroMem((void*)(&aX60gensym5000_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			nimZeroMem((void*)(&bX60gensym5000_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5000_));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym5000_));
			res_5 = rawNewString(((NI) 80));
			res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T78_ = NIM_NIL;
			T78_ = rdLoc__cgen_435(aX60gensym5000_);
			cgFormatValue__cgen_147((&res_5), T78_);
			res_5 = resizeString(res_5, 4);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_467));
			T79_ = NIM_NIL;
			T79_ = rdLoc__cgen_435(bX60gensym5000_);
			cgFormatValue__cgen_147((&res_5), T79_);
			res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
			T80_ = NIM_NIL;
			T80_ = rope__ropes_109(res_5);
			putIntoDest__cgen_18794(p, d, e, T80_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 122):
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym5015_;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw bX60gensym5015_;
			NimStringDesc* res_6;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T82_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T83_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T84_;
			nimZeroMem((void*)(&aX60gensym5015_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			nimZeroMem((void*)(&bX60gensym5015_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5015_));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym5015_));
			res_6 = rawNewString(((NI) 80));
			res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T82_ = NIM_NIL;
			T82_ = rdLoc__cgen_435(aX60gensym5015_);
			cgFormatValue__cgen_147((&res_6), T82_);
			res_6 = resizeString(res_6, 3);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_611));
			T83_ = NIM_NIL;
			T83_ = rdLoc__cgen_435(bX60gensym5015_);
			cgFormatValue__cgen_147((&res_6), T83_);
			res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
			T84_ = NIM_NIL;
			T84_ = rope__ropes_109(res_6);
			putIntoDest__cgen_18794(p, d, e, T84_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 123):
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym5030_;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw bX60gensym5030_;
			NimStringDesc* res_7;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T86_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T87_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T88_;
			nimZeroMem((void*)(&aX60gensym5030_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			nimZeroMem((void*)(&bX60gensym5030_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5030_));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym5030_));
			res_7 = rawNewString(((NI) 80));
			res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T86_ = NIM_NIL;
			T86_ = rdLoc__cgen_435(aX60gensym5030_);
			cgFormatValue__cgen_147((&res_7), T86_);
			res_7 = resizeString(res_7, 3);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_612));
			T87_ = NIM_NIL;
			T87_ = rdLoc__cgen_435(bX60gensym5030_);
			cgFormatValue__cgen_147((&res_7), T87_);
			res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
			T88_ = NIM_NIL;
			T88_ = rope__ropes_109(res_7);
			putIntoDest__cgen_18794(p, d, e, T88_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 124):
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym5045_;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw bX60gensym5045_;
			NimStringDesc* res_8;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T90_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T91_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T92_;
			nimZeroMem((void*)(&aX60gensym5045_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			nimZeroMem((void*)(&bX60gensym5045_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5045_));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym5045_));
			res_8 = rawNewString(((NI) 80));
			res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T90_ = NIM_NIL;
			T90_ = rdLoc__cgen_435(aX60gensym5045_);
			cgFormatValue__cgen_147((&res_8), T90_);
			res_8 = resizeString(res_8, 5);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_608));
			T91_ = NIM_NIL;
			T91_ = rdLoc__cgen_435(bX60gensym5045_);
			cgFormatValue__cgen_147((&res_8), T91_);
			res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
			T92_ = NIM_NIL;
			T92_ = rope__ropes_109(res_8);
			putIntoDest__cgen_18794(p, d, e, T92_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 134):
		{
			genInOp__cgen_22275(p, e, d);
		}
		break;
		default:
		{
			internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*e).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_613), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_614);
		}
		break;
		}
	}
	break;
	default:
	{
		switch (op) {
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 40):
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym5063_;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw bX60gensym5063_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T97_;
			tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T98_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T99_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T100_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T101_;
			nimZeroMem((void*)(&aX60gensym5063_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			nimZeroMem((void*)(&bX60gensym5063_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5063_));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym5063_));
			T97_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T97_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			nimZeroMem((void*)T98_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
			T98_[0] = rdLoc__cgen_435(aX60gensym5063_);
			T99_ = NIM_NIL;
			T99_ = t__cgen_85(aX60gensym5063_);
			T98_[1] = rdSetElemLoc__cgen_17717((*(*(*p).module).g).config, bX60gensym5063_, T99_);
			T100_ = NIM_NIL;
			T100_ = percent___cgen_22737(T98_, 2);
			T101_ = NIM_NIL;
			T101_ = indentLine__cgen_286(p, T100_);
			add__ropes_159(T97_, T101_);
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 41):
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym5070_;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw bX60gensym5070_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T103_;
			tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T104_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T105_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T106_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T107_;
			nimZeroMem((void*)(&aX60gensym5070_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			nimZeroMem((void*)(&bX60gensym5070_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5070_));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym5070_));
			T103_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T103_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			nimZeroMem((void*)T104_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
			T104_[0] = rdLoc__cgen_435(aX60gensym5070_);
			T105_ = NIM_NIL;
			T105_ = t__cgen_85(aX60gensym5070_);
			T104_[1] = rdSetElemLoc__cgen_17717((*(*(*p).module).g).config, bX60gensym5070_, T105_);
			T106_ = NIM_NIL;
			T106_ = percent___cgen_22755(T104_, 2);
			T107_ = NIM_NIL;
			T107_ = indentLine__cgen_286(p, T106_);
			add__ropes_159(T103_, T107_);
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 42):
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a_2;
			NimStringDesc* res_9;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T109_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T110_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T111_;
			nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a_2));
			res_9 = rawNewString(((NI) 80));
			T109_ = NIM_NIL;
			T109_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_615));
			cgFormatValue__cgen_147((&res_9), T109_);
			res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T110_ = NIM_NIL;
			T110_ = addrLoc__cgen_10337((*(*(*p).module).g).config, a_2);
			cgFormatValue__cgen_147((&res_9), T110_);
			res_9 = resizeString(res_9, 2);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			cgFormatValue__cgen_154((&res_9), ((NI64) (size)));
			res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
			T111_ = NIM_NIL;
			T111_ = rope__ropes_109(res_9);
			putIntoDest__cgen_18794(p, d, e, T111_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 121):
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 120):
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T113_;
			T113_ = NIM_NIL;
			T113_ = getSysType__magicsys_60((*(*(*p).module).g).graph, unknownLineInfo__lineinfos_284, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31));
			getTemp__cgen_7373(p, T113_, (&i), NIM_FALSE);
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T118_;
				if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA116_;
				T118_ = NIM_NIL;
				T118_ = getSysType__magicsys_60((*(*(*p).module).g).graph, unknownLineInfo__lineinfos_284, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1));
				getTemp__cgen_7373(p, T118_, d, NIM_FALSE);
			}
			LA116_: ;
			{
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T123_;
				NimStringDesc* res_10;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T124_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T125_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T126_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T131_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T132_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T133_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T134_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T135_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T140_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T145_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T146_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T147_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T148_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T149_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T154_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T155_;
				if (!(op == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 121))) goto LA121_;
				T123_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T123_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_10 = rawNewString(((NI) 80));
				res_10 = resizeString(res_10, 5);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_161));
				T124_ = NIM_NIL;
				T124_ = rdLoc__cgen_435(i);
				cgFormatValue__cgen_147((&res_10), T124_);
				res_10 = resizeString(res_10, 6);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_162));
				T125_ = NIM_NIL;
				T125_ = rdLoc__cgen_435(i);
				cgFormatValue__cgen_147((&res_10), T125_);
				res_10 = resizeString(res_10, 3);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_163));
				cgFormatValue__cgen_154((&res_10), ((NI64) (size)));
				res_10 = resizeString(res_10, 2);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_164));
				T126_ = NIM_NIL;
				T126_ = rdLoc__cgen_435(i);
				cgFormatValue__cgen_147((&res_10), T126_);
				res_10 = resizeString(res_10, 6);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_616));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA129_;
					res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA129_: ;
				res_10 = resizeString(res_10, 2);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_233));
				T131_ = NIM_NIL;
				T131_ = rdLoc__cgen_435((*d));
				cgFormatValue__cgen_147((&res_10), T131_);
				res_10 = resizeString(res_10, 5);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_617));
				T132_ = NIM_NIL;
				T132_ = rdLoc__cgen_435(a);
				cgFormatValue__cgen_147((&res_10), T132_);
				res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_166));
				T133_ = NIM_NIL;
				T133_ = rdLoc__cgen_435(i);
				cgFormatValue__cgen_147((&res_10), T133_);
				res_10 = resizeString(res_10, 6);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_618));
				T134_ = NIM_NIL;
				T134_ = rdLoc__cgen_435(b);
				cgFormatValue__cgen_147((&res_10), T134_);
				res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_166));
				T135_ = NIM_NIL;
				T135_ = rdLoc__cgen_435(i);
				cgFormatValue__cgen_147((&res_10), T135_);
				res_10 = resizeString(res_10, 9);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_619));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA138_;
					res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA138_: ;
				res_10 = resizeString(res_10, 7);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_620));
				T140_ = NIM_NIL;
				T140_ = rdLoc__cgen_435((*d));
				cgFormatValue__cgen_147((&res_10), T140_);
				res_10 = resizeString(res_10, 9);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_621));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA143_;
					res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA143_: ;
				res_10 = resizeString(res_10, 4);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
				T145_ = NIM_NIL;
				T145_ = rdLoc__cgen_435((*d));
				cgFormatValue__cgen_147((&res_10), T145_);
				res_10 = resizeString(res_10, 2);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_56));
				T146_ = NIM_NIL;
				T146_ = rdLoc__cgen_435((*d));
				cgFormatValue__cgen_147((&res_10), T146_);
				res_10 = resizeString(res_10, 4);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_55));
				T147_ = NIM_NIL;
				T147_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_622));
				cgFormatValue__cgen_147((&res_10), T147_);
				res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
				T148_ = NIM_NIL;
				T148_ = rdLoc__cgen_435(a);
				cgFormatValue__cgen_147((&res_10), T148_);
				res_10 = resizeString(res_10, 2);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
				T149_ = NIM_NIL;
				T149_ = rdLoc__cgen_435(b);
				cgFormatValue__cgen_147((&res_10), T149_);
				res_10 = resizeString(res_10, 2);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
				cgFormatValue__cgen_154((&res_10), ((NI64) (size)));
				res_10 = resizeString(res_10, 8);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_623));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA152_;
					res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA152_: ;
				T154_ = NIM_NIL;
				T154_ = rope__ropes_109(res_10);
				T155_ = NIM_NIL;
				T155_ = indentLine__cgen_286(p, T154_);
				add__ropes_159(T123_, T155_);
			}
			goto LA119_;
			LA121_: ;
			{
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T157_;
				NimStringDesc* res_11;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T158_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T159_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T160_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T165_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T166_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T167_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T168_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T169_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T174_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T179_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T180_;
				T157_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T157_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_11 = rawNewString(((NI) 80));
				res_11 = resizeString(res_11, 5);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_161));
				T158_ = NIM_NIL;
				T158_ = rdLoc__cgen_435(i);
				cgFormatValue__cgen_147((&res_11), T158_);
				res_11 = resizeString(res_11, 6);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_162));
				T159_ = NIM_NIL;
				T159_ = rdLoc__cgen_435(i);
				cgFormatValue__cgen_147((&res_11), T159_);
				res_11 = resizeString(res_11, 3);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_163));
				cgFormatValue__cgen_154((&res_11), ((NI64) (size)));
				res_11 = resizeString(res_11, 2);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_164));
				T160_ = NIM_NIL;
				T160_ = rdLoc__cgen_435(i);
				cgFormatValue__cgen_147((&res_11), T160_);
				res_11 = resizeString(res_11, 6);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_616));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA163_;
					res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA163_: ;
				res_11 = resizeString(res_11, 2);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_233));
				T165_ = NIM_NIL;
				T165_ = rdLoc__cgen_435((*d));
				cgFormatValue__cgen_147((&res_11), T165_);
				res_11 = resizeString(res_11, 5);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_617));
				T166_ = NIM_NIL;
				T166_ = rdLoc__cgen_435(a);
				cgFormatValue__cgen_147((&res_11), T166_);
				res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_166));
				T167_ = NIM_NIL;
				T167_ = rdLoc__cgen_435(i);
				cgFormatValue__cgen_147((&res_11), T167_);
				res_11 = resizeString(res_11, 6);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_618));
				T168_ = NIM_NIL;
				T168_ = rdLoc__cgen_435(b);
				cgFormatValue__cgen_147((&res_11), T168_);
				res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_166));
				T169_ = NIM_NIL;
				T169_ = rdLoc__cgen_435(i);
				cgFormatValue__cgen_147((&res_11), T169_);
				res_11 = resizeString(res_11, 9);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_619));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA172_;
					res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA172_: ;
				res_11 = resizeString(res_11, 7);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_620));
				T174_ = NIM_NIL;
				T174_ = rdLoc__cgen_435((*d));
				cgFormatValue__cgen_147((&res_11), T174_);
				res_11 = resizeString(res_11, 9);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_621));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA177_;
					res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA177_: ;
				T179_ = NIM_NIL;
				T179_ = rope__ropes_109(res_11);
				T180_ = NIM_NIL;
				T180_ = indentLine__cgen_286(p, T179_);
				add__ropes_159(T157_, T180_);
			}
			LA119_: ;
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 119):
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a_3;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b_2;
			NimStringDesc* res_12;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T182_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T183_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T184_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T185_;
			nimZeroMem((void*)(&a_3), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			nimZeroMem((void*)(&b_2), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a_3));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&b_2));
			res_12 = rawNewString(((NI) 80));
			res_12 = resizeString(res_12, 1);
appendString(res_12, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T182_ = NIM_NIL;
			T182_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_622));
			cgFormatValue__cgen_147((&res_12), T182_);
			res_12 = resizeString(res_12, 1);
appendString(res_12, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T183_ = NIM_NIL;
			T183_ = rdCharLoc__cgen_10377(a_3);
			cgFormatValue__cgen_147((&res_12), T183_);
			res_12 = resizeString(res_12, 2);
appendString(res_12, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			T184_ = NIM_NIL;
			T184_ = rdCharLoc__cgen_10377(b_2);
			cgFormatValue__cgen_147((&res_12), T184_);
			res_12 = resizeString(res_12, 2);
appendString(res_12, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			cgFormatValue__cgen_154((&res_12), ((NI64) (size)));
			res_12 = resizeString(res_12, 5);
appendString(res_12, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_610));
			T185_ = NIM_NIL;
			T185_ = rope__ropes_109(res_12);
			putIntoDest__cgen_18794(p, d, e, T185_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 122):
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 123):
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 124):
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T187_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T192_;
			tyArray__SJIWFUvBTGjESW6tXwR6UA T193_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T194_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T195_;
			T187_ = NIM_NIL;
			T187_ = getSysType__magicsys_60((*(*(*p).module).g).graph, unknownLineInfo__lineinfos_284, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31));
			getTemp__cgen_7373(p, T187_, (&i), NIM_FALSE);
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
			{
				if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA190_;
				getTemp__cgen_7373(p, setType, d, NIM_FALSE);
			}
			LA190_: ;
			T192_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T192_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			nimZeroMem((void*)T193_, sizeof(tyArray__SJIWFUvBTGjESW6tXwR6UA));
			T193_[0] = rdLoc__cgen_435(i);
			T193_[1] = rope__ropes_115(((NI64) (size)));
			T193_[2] = rdLoc__cgen_435((*d));
			T193_[3] = rdLoc__cgen_435(a);
			T193_[4] = rdLoc__cgen_435(b);
			T193_[5] = rope__ropes_109(lookupOpr__cgen_22357[(op)- 120]);
			T194_ = NIM_NIL;
			T194_ = percent___cgen_22862(T193_, 6);
			T195_ = NIM_NIL;
			T195_ = indentLine__cgen_286(p, T194_);
			add__ropes_159(T192_, T195_);
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 134):
		{
			genInOp__cgen_22275(p, e, d);
		}
		break;
		default:
		{
			internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*e).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_627), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_628);
		}
		break;
		}
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genDefault__cgen_20817)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	{
		if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA3_;
		getTemp__cgen_7373(p, (*n).typ, d, NIM_TRUE);
	}
	goto LA1_;
	LA3_: ;
	{
		resetLoc__cgen_10897(p, d);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genReset__cgen_20812)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, (*n)._kind_6.sons->data[((NI) 1)], (&a));
	specializeReset__cgen_10894(p, a);
}
N_LIB_PRIVATE N_NIMCALL(void, genEcho__cgen_20455)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NimStringDesc* argX60gensym4228_;
		if (!!(((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41)))) goto LA3_;
		argX60gensym4228_ = toFileLineCol__msgs_625(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_629);
		internalErrorImpl__msgs_1441((*(*(*p).module).g).config, unknownLineInfo__lineinfos_284, argX60gensym4228_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_629);
	}
	LA3_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* args;
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T35_;
		NimStringDesc* res_3;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T40_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T41_;
		if (!((*(*(*(*p).module).g).config).target.targetOS == ((tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw) 26))) goto LA7_;
		args = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		{
			NI i;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
			tySequence__IeU9azYSNIK3V9b36Ir6NZcw* colontmp_;
			NI i_2;
			NI L;
			NI T10_;
			i = (NI)0;
			it = NIM_NIL;
			colontmp_ = NIM_NIL;
			colontmp_ = (*n)._kind_6.sons;
			i_2 = ((NI) 0);
			T10_ = (colontmp_ ? colontmp_->Sup.len : 0);
			L = T10_;
			{
				while (1) {
					if (!(i_2 < L)) goto LA12;
					i = i_2;
					it = colontmp_->data[i_2];
					{
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T15_;
						T15_ = NIM_NIL;
						T15_ = skipConv__types_3661(it);
						if (!((*T15_).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA16_;
						add__ropes_162(&args, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_630));
					}
					goto LA13_;
					LA16_: ;
					{
						NI T19_;
						NI T26_;
						T19_ = (NI)0;
						T19_ = len__ast_3155(n);
						if (!!((T19_ == ((NI) 0)))) goto LA20_;
						initLocExpr__cgen_11548(p, it, (&a));
						{
							if (!(((NI) 0) < i)) goto LA24_;
							add__ropes_162(&args, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
						}
						LA24_: ;
						T26_ = (NI)0;
						T26_ = detectStrVersion__cgen_490((*p).module);
						switch (T26_) {
						case ((NI) 2):
						{
							NimStringDesc* res;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T28_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T29_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T30_;
							res = rawNewString(((NI) 80));
							res = resizeString(res, 16);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_631));
							T28_ = NIM_NIL;
							T28_ = rdLoc__cgen_435(a);
							cgFormatValue__cgen_147((&res), T28_);
							res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_632));
							T29_ = NIM_NIL;
							T29_ = rdLoc__cgen_435(a);
							cgFormatValue__cgen_147((&res), T29_);
							res = resizeString(res, 5);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_633));
							T30_ = NIM_NIL;
							T30_ = rope__ropes_109(res);
							add__ropes_159(&args, T30_);
						}
						break;
						default:
						{
							NimStringDesc* res_2;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T32_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T33_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T34_;
							res_2 = rawNewString(((NI) 80));
							res_2 = resizeString(res_2, 16);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_631));
							T32_ = NIM_NIL;
							T32_ = rdLoc__cgen_435(a);
							cgFormatValue__cgen_147((&res_2), T32_);
							res_2 = resizeString(res_2, 8);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_634));
							T33_ = NIM_NIL;
							T33_ = rdLoc__cgen_435(a);
							cgFormatValue__cgen_147((&res_2), T33_);
							res_2 = resizeString(res_2, 6);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_635));
							T34_ = NIM_NIL;
							T34_ = rope__ropes_109(res_2);
							add__ropes_159(&args, T34_);
						}
						break;
						}
					}
					goto LA13_;
					LA20_: ;
					LA13_: ;
					i_2 += ((NI) 1);
				} LA12: ;
			}
		}
		includeHeader__cgendata_214((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_636));
		includeHeader__cgendata_214((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_637));
		T35_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T35_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_3 = rawNewString(((NI) 80));
		res_3 = resizeString(res_3, 12);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_638));
		cgFormatValue__cgen_147((&res_3), args);
		res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA38_;
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA38_: ;
		T40_ = NIM_NIL;
		T40_ = rope__ropes_109(res_3);
		T41_ = NIM_NIL;
		T41_ = indentLine__cgen_286(p, T40_);
		add__ropes_159(T35_, T41_);
	}
	goto LA5_;
	LA7_: ;
	{
		{
			NI T45_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T48_;
			NimStringDesc* res_4;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T49_;
			NI T50_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T55_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T56_;
			T45_ = (NI)0;
			T45_ = len__ast_3155(n);
			if (!(T45_ == ((NI) 0))) goto LA46_;
			T48_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T48_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_4 = rawNewString(((NI) 80));
			T49_ = NIM_NIL;
			T49_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_639));
			cgFormatValue__cgen_147((&res_4), T49_);
			res_4 = resizeString(res_4, 10);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_640));
			T50_ = (NI)0;
			T50_ = len__ast_3155(n);
			cgFormatValue__cgen_154((&res_4), ((NI64) (T50_)));
			res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA53_;
				res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA53_: ;
			T55_ = NIM_NIL;
			T55_ = rope__ropes_109(res_4);
			T56_ = NIM_NIL;
			T56_ = indentLine__cgen_286(p, T55_);
			add__ropes_159(T48_, T56_);
		}
		goto LA43_;
		LA46_: ;
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a_2;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T58_;
			NimStringDesc* res_5;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T59_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T60_;
			NI T61_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T66_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T67_;
			nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLocExpr__cgen_11548(p, n, (&a_2));
			T58_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T58_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_5 = rawNewString(((NI) 80));
			T59_ = NIM_NIL;
			T59_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_639));
			cgFormatValue__cgen_147((&res_5), T59_);
			res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T60_ = NIM_NIL;
			T60_ = rdLoc__cgen_435(a_2);
			cgFormatValue__cgen_147((&res_5), T60_);
			res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			T61_ = (NI)0;
			T61_ = len__ast_3155(n);
			cgFormatValue__cgen_154((&res_5), ((NI64) (T61_)));
			res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA64_;
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA64_: ;
			T66_ = NIM_NIL;
			T66_ = rope__ropes_109(res_5);
			T67_ = NIM_NIL;
			T67_ = indentLine__cgen_286(p, T66_);
			add__ropes_159(T58_, T67_);
		}
		LA43_: ;
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lhsDoesAlias__cgen_21281)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* y;
		y = NIM_NIL;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148(b);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					y = (*b)._kind_6.sons->data[i];
					{
						tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA T7_;
						T7_ = (tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA)0;
						T7_ = isPartOf__aliases_129(a, y);
						if (!!((T7_ == ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 0)))) goto LA8_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA8_: ;
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genSeqConstr__cgen_21290)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw arr;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tmp;
	NIM_BOOL doesAlias;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* dest;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* l;
	NI T13_;
	nimZeroMem((void*)(&arr), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	doesAlias = lhsDoesAlias__cgen_21281((*d).lode, n);
	{
		if (!doesAlias) goto LA3_;
		dest = (&tmp);
	}
	goto LA1_;
	LA3_: ;
	{
		dest = d;
	}
	LA1_: ;
	{
		if (!doesAlias) goto LA8_;
		getTemp__cgen_7373(p, (*n).typ, (&tmp), NIM_FALSE);
	}
	goto LA6_;
	LA8_: ;
	{
		if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA11_;
		getTemp__cgen_7373(p, (*n).typ, d, NIM_FALSE);
	}
	goto LA6_;
	LA11_: ;
	LA6_: ;
	T13_ = (NI)0;
	T13_ = len__ast_3155(n);
	l = intLiteral__cgen_11536(((NI64) (T13_)));
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* seqtype;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T18_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T21_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T23_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T25_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T31_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T32_;
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0)) goto LA16_;
		seqtype = (*n).typ;
		T18_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T18_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res = rawNewString(((NI) 80));
		T19_ = NIM_NIL;
		T19_ = rdLoc__cgen_435((*dest));
		cgFormatValue__cgen_147((&res), T19_);
		res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_565));
		cgFormatValue__cgen_147((&res), l);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_164));
		T20_ = NIM_NIL;
		T20_ = rdLoc__cgen_435((*dest));
		cgFormatValue__cgen_147((&res), T20_);
		res = resizeString(res, 6);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_566));
		T21_ = NIM_NIL;
		T21_ = getSeqPayloadType__cgen_3476((*p).module, seqtype);
		cgFormatValue__cgen_147((&res), T21_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_389));
		T22_ = NIM_NIL;
		T22_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_567));
		cgFormatValue__cgen_147((&res), T22_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		cgFormatValue__cgen_147((&res), l);
		res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_127));
		T23_ = NIM_NIL;
		T23_ = lastSon__ast_3731(seqtype);
		T24_ = NIM_NIL;
		T24_ = getTypeDesc__cgen_6662((*p).module, T23_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		cgFormatValue__cgen_147((&res), T24_);
		res = resizeString(res, 15);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_568));
		T25_ = NIM_NIL;
		T25_ = lastSon__ast_3731(seqtype);
		T26_ = NIM_NIL;
		T26_ = getTypeDesc__cgen_6662((*p).module, T25_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		cgFormatValue__cgen_147((&res), T26_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_128));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA29_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA29_: ;
		T31_ = NIM_NIL;
		T31_ = rope__ropes_109(res);
		T32_ = NIM_NIL;
		T32_ = indentLine__cgen_286(p, T31_);
		add__ropes_159(T18_, T32_);
	}
	goto LA14_;
	LA16_: ;
	{
		NI T34_;
		T34_ = (NI)0;
		T34_ = len__ast_3155(n);
		genNewSeqAux__cgen_20992(p, (*dest), l, (T34_ == ((NI) 0)));
	}
	LA14_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				NimStringDesc* res_2;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T39_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T40_;
				if (!(i_2 < colontmp_)) goto LA37;
				i = i_2;
				initLoc__cgen_66((&arr), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 6), (*n)._kind_6.sons->data[i], ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 3));
				res_2 = rawNewString(((NI) 80));
				T38_ = NIM_NIL;
				T38_ = rdLoc__cgen_435((*dest));
				cgFormatValue__cgen_147((&res_2), T38_);
				T39_ = NIM_NIL;
				T39_ = dataField__cgen_479(p);
				cgFormatValue__cgen_147((&res_2), T39_);
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_166));
				T40_ = NIM_NIL;
				T40_ = intLiteral__cgen_11536(((NI64) (i)));
				cgFormatValue__cgen_147((&res_2), T40_);
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_167));
				arr.r = rope__ropes_109(res_2);
				arr.storage = ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 3);
				expr__cgen_11525(p, (*n)._kind_6.sons->data[i], (&arr));
				i_2 += ((NI) 1);
			} LA37: ;
		}
	}
	gcUsage__cgen_20553((*(*(*p).module).g).config, n);
	{
		if (!doesAlias) goto LA43_;
		{
			if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA47_;
			genericAssign((void*)(&(*d)), (void*)(&tmp), (&NTItloc__CAJV4zTUpZwr0j6Wy8FiFw_));
		}
		goto LA45_;
		LA47_: ;
		{
			genAssignment__cgen_10403(p, (*d), tmp, 0);
		}
		LA45_: ;
	}
	LA43_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genArrToSeq__cgen_21365)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw elem;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw arr;
	NI L;
	tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T9_;
{	nimZeroMem((void*)(&elem), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&arr), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	{
		if (!((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41))) goto LA3_;
		asgnRef((void**) (&(*(*n)._kind_6.sons->data[((NI) 1)]).typ), (*n).typ);
		genSeqConstr__cgen_21290(p, (*n)._kind_6.sons->data[((NI) 1)], d);
		goto BeforeRet_;
	}
	LA3_: ;
	{
		if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA7_;
		getTemp__cgen_7373(p, (*n).typ, d, NIM_FALSE);
	}
	LA7_: ;
	initLocExpr__cgen_11548(p, (*n)._kind_6.sons->data[((NI) 1)], (&a));
	T9_ = lengthOrd__types_1723((*(*(*p).module).g).config, (*(*n)._kind_6.sons->data[((NI) 1)]).typ);
	L = toInt__int495056_273(T9_);
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* seqtype;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T14_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T19_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T21_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T27_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T28_;
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0)) goto LA12_;
		seqtype = (*n).typ;
		T14_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T14_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res = rawNewString(((NI) 80));
		T15_ = NIM_NIL;
		T15_ = rdLoc__cgen_435((*d));
		cgFormatValue__cgen_147((&res), T15_);
		res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_565));
		cgFormatValue__cgen_154((&res), ((NI64) (L)));
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_164));
		T16_ = NIM_NIL;
		T16_ = rdLoc__cgen_435((*d));
		cgFormatValue__cgen_147((&res), T16_);
		res = resizeString(res, 6);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_566));
		T17_ = NIM_NIL;
		T17_ = getSeqPayloadType__cgen_3476((*p).module, seqtype);
		cgFormatValue__cgen_147((&res), T17_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_389));
		T18_ = NIM_NIL;
		T18_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_567));
		cgFormatValue__cgen_147((&res), T18_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		cgFormatValue__cgen_154((&res), ((NI64) (L)));
		res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_127));
		T19_ = NIM_NIL;
		T19_ = lastSon__ast_3731(seqtype);
		T20_ = NIM_NIL;
		T20_ = getTypeDesc__cgen_6662((*p).module, T19_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		cgFormatValue__cgen_147((&res), T20_);
		res = resizeString(res, 15);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_568));
		T21_ = NIM_NIL;
		T21_ = lastSon__ast_3731(seqtype);
		T22_ = NIM_NIL;
		T22_ = getTypeDesc__cgen_6662((*p).module, T21_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		cgFormatValue__cgen_147((&res), T22_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_128));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA25_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA25_: ;
		T27_ = NIM_NIL;
		T27_ = rope__ropes_109(res);
		T28_ = NIM_NIL;
		T28_ = indentLine__cgen_286(p, T27_);
		add__ropes_159(T14_, T28_);
	}
	goto LA10_;
	LA12_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T30_;
		T30_ = NIM_NIL;
		T30_ = intLiteral__cgen_11536(((NI64) (L)));
		genNewSeqAux__cgen_20992(p, (*d), T30_, (L == ((NI) 0)));
	}
	LA10_: ;
	{
		if (!(L < ((NI) 10))) goto LA33_;
		{
			NI i;
			NI i_2;
			i = (NI)0;
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T38_;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T39_;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T40_;
					NimStringDesc* res_2;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T41_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T42_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T43_;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T44_;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T45_;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T46_;
					NimStringDesc* res_3;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T47_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T48_;
					if (!(i_2 < L)) goto LA37;
					i = i_2;
					T38_ = NIM_NIL;
					T38_ = skipTypes__ast_3723((*n).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
					T39_ = NIM_NIL;
					T39_ = elemType__types_263(T38_);
					T40_ = NIM_NIL;
					T40_ = lodeTyp__cgen_92(T39_);
					initLoc__cgen_66((&elem), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 6), T40_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 3));
					res_2 = rawNewString(((NI) 80));
					T41_ = NIM_NIL;
					T41_ = rdLoc__cgen_435((*d));
					cgFormatValue__cgen_147((&res_2), T41_);
					T42_ = NIM_NIL;
					T42_ = dataField__cgen_479(p);
					cgFormatValue__cgen_147((&res_2), T42_);
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_166));
					T43_ = NIM_NIL;
					T43_ = intLiteral__cgen_11536(((NI64) (i)));
					cgFormatValue__cgen_147((&res_2), T43_);
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_167));
					elem.r = rope__ropes_109(res_2);
					elem.storage = ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 3);
					T44_ = NIM_NIL;
					T44_ = skipTypes__ast_3723((*(*n)._kind_6.sons->data[((NI) 1)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
					T45_ = NIM_NIL;
					T45_ = elemType__types_263(T44_);
					T46_ = NIM_NIL;
					T46_ = lodeTyp__cgen_92(T45_);
					initLoc__cgen_66((&arr), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 6), T46_, a.storage);
					res_3 = rawNewString(((NI) 80));
					T47_ = NIM_NIL;
					T47_ = rdLoc__cgen_435(a);
					cgFormatValue__cgen_147((&res_3), T47_);
					res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_166));
					T48_ = NIM_NIL;
					T48_ = intLiteral__cgen_11536(((NI64) (i)));
					cgFormatValue__cgen_147((&res_3), T48_);
					res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_167));
					arr.r = rope__ropes_109(res_3);
					genAssignment__cgen_10403(p, elem, arr, 1);
					i_2 += ((NI) 1);
				} LA37: ;
			}
		}
	}
	goto LA31_;
	LA33_: ;
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw i_3;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T50_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T51_;
		NimStringDesc* res_4;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T56_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T57_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T58_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T59_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T60_;
		NimStringDesc* res_5;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T61_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T62_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T63_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T64_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T65_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T66_;
		NimStringDesc* res_6;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T67_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T68_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T69_;
		tyArray__dAmhZbEWrTM5xES2bTVweg T70_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T71_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T72_;
		nimZeroMem((void*)(&i_3), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		T50_ = NIM_NIL;
		T50_ = getSysType__magicsys_60((*(*(*p).module).g).graph, unknownLineInfo__lineinfos_284, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31));
		getTemp__cgen_7373(p, T50_, (&i_3), NIM_FALSE);
		T51_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T51_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_4 = rawNewString(((NI) 80));
		res_4 = resizeString(res_4, 5);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_161));
		cgFormatValue__cgen_147((&res_4), i_3.r);
		res_4 = resizeString(res_4, 6);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_162));
		cgFormatValue__cgen_147((&res_4), i_3.r);
		res_4 = resizeString(res_4, 3);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_163));
		cgFormatValue__cgen_154((&res_4), ((NI64) (L)));
		res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_164));
		cgFormatValue__cgen_147((&res_4), i_3.r);
		res_4 = resizeString(res_4, 5);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_165));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA54_;
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA54_: ;
		T56_ = NIM_NIL;
		T56_ = rope__ropes_109(res_4);
		T57_ = NIM_NIL;
		T57_ = indentLine__cgen_286(p, T56_);
		add__ropes_159(T51_, T57_);
		T58_ = NIM_NIL;
		T58_ = skipTypes__ast_3723((*n).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
		T59_ = NIM_NIL;
		T59_ = elemType__types_263(T58_);
		T60_ = NIM_NIL;
		T60_ = lodeTyp__cgen_92(T59_);
		initLoc__cgen_66((&elem), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 6), T60_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 3));
		res_5 = rawNewString(((NI) 80));
		T61_ = NIM_NIL;
		T61_ = rdLoc__cgen_435((*d));
		cgFormatValue__cgen_147((&res_5), T61_);
		T62_ = NIM_NIL;
		T62_ = dataField__cgen_479(p);
		cgFormatValue__cgen_147((&res_5), T62_);
		res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_166));
		T63_ = NIM_NIL;
		T63_ = rdLoc__cgen_435(i_3);
		cgFormatValue__cgen_147((&res_5), T63_);
		res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_167));
		elem.r = rope__ropes_109(res_5);
		elem.storage = ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 3);
		T64_ = NIM_NIL;
		T64_ = skipTypes__ast_3723((*(*n)._kind_6.sons->data[((NI) 1)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
		T65_ = NIM_NIL;
		T65_ = elemType__types_263(T64_);
		T66_ = NIM_NIL;
		T66_ = lodeTyp__cgen_92(T65_);
		initLoc__cgen_66((&arr), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 6), T66_, a.storage);
		res_6 = rawNewString(((NI) 80));
		T67_ = NIM_NIL;
		T67_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res_6), T67_);
		res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_166));
		T68_ = NIM_NIL;
		T68_ = rdLoc__cgen_435(i_3);
		cgFormatValue__cgen_147((&res_6), T68_);
		res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_167));
		arr.r = rope__ropes_109(res_6);
		genAssignment__cgen_10403(p, elem, arr, 1);
		T69_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T69_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		nimZeroMem((void*)T70_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		T71_ = NIM_NIL;
		T71_ = percent___cgen_7535(T70_, 0);
		T72_ = NIM_NIL;
		T72_ = indentLine__cgen_286(p, T71_);
		add__ropes_159(T69_, T72_);
	}
	LA31_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genDeepCopy__cgen_18636)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw dest, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw src) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ty;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1_;
	T1_ = NIM_NIL;
	T1_ = t__cgen_85(dest);
	ty = skipTypes__ast_3723(T1_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_645);
	switch ((*ty).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T3_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T4_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T13_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
		T3_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T3_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res = rawNewString(((NI) 80));
		T4_ = NIM_NIL;
		T4_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_646));
		cgFormatValue__cgen_147((&res), T4_);
		res = resizeString(res, 8);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_126));
		T5_ = NIM_NIL;
		T5_ = addrLoc__cgen_10337((*(*(*p).module).g).config, dest);
		cgFormatValue__cgen_147((&res), T5_);
		res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_255));
		T6_ = NIM_NIL;
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tmpX60gensym3594_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T11_;
			if (!(src.k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 6))) goto LA9_;
			nimZeroMem((void*)(&tmpX60gensym3594_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			T11_ = NIM_NIL;
			T11_ = t__cgen_85(src);
			getTemp__cgen_7373(p, T11_, (&tmpX60gensym3594_), NIM_FALSE);
			genAssignment__cgen_10403(p, tmpX60gensym3594_, src, 0);
			T6_ = addrLoc__cgen_10337((*(*(*p).module).g).config, tmpX60gensym3594_);
		}
		goto LA7_;
		LA9_: ;
		{
			T6_ = addrLoc__cgen_10337((*(*(*p).module).g).config, src);
		}
		LA7_: ;
		cgFormatValue__cgen_147((&res), T6_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		T13_ = NIM_NIL;
		T13_ = t__cgen_85(dest);
		T14_ = NIM_NIL;
		T14_ = genTypeInfoV1__cgen_6798((*p).module, T13_, (*dest.lode).info);
		cgFormatValue__cgen_147((&res), T14_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA17_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA17_: ;
		T19_ = NIM_NIL;
		T19_ = rope__ropes_109(res);
		T20_ = NIM_NIL;
		T20_ = indentLine__cgen_286(p, T19_);
		add__ropes_159(T3_, T20_);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
	{
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T26_;
			NimStringDesc* res_2;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T27_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T28_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T29_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T36_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T37_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T42_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T43_;
			if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 41))&63U)))!=0)) goto LA24_;
			T26_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T26_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_2 = rawNewString(((NI) 80));
			T27_ = NIM_NIL;
			T27_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_646));
			cgFormatValue__cgen_147((&res_2), T27_);
			res_2 = resizeString(res_2, 8);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_126));
			T28_ = NIM_NIL;
			T28_ = addrLoc__cgen_10337((*(*(*p).module).g).config, dest);
			cgFormatValue__cgen_147((&res_2), T28_);
			res_2 = resizeString(res_2, 9);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_255));
			T29_ = NIM_NIL;
			{
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tmpX60gensym3608_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T34_;
				if (!(src.k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 6))) goto LA32_;
				nimZeroMem((void*)(&tmpX60gensym3608_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				T34_ = NIM_NIL;
				T34_ = t__cgen_85(src);
				getTemp__cgen_7373(p, T34_, (&tmpX60gensym3608_), NIM_FALSE);
				genAssignment__cgen_10403(p, tmpX60gensym3608_, src, 0);
				T29_ = addrLoc__cgen_10337((*(*(*p).module).g).config, tmpX60gensym3608_);
			}
			goto LA30_;
			LA32_: ;
			{
				T29_ = addrLoc__cgen_10337((*(*(*p).module).g).config, src);
			}
			LA30_: ;
			cgFormatValue__cgen_147((&res_2), T29_);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			T36_ = NIM_NIL;
			T36_ = t__cgen_85(dest);
			T37_ = NIM_NIL;
			T37_ = genTypeInfoV1__cgen_6798((*p).module, T36_, (*dest.lode).info);
			cgFormatValue__cgen_147((&res_2), T37_);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA40_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA40_: ;
			T42_ = NIM_NIL;
			T42_ = rope__ropes_109(res_2);
			T43_ = NIM_NIL;
			T43_ = indentLine__cgen_286(p, T42_);
			add__ropes_159(T26_, T43_);
		}
		goto LA22_;
		LA24_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T45_;
			NimStringDesc* res_3;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T46_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T47_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T48_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T49_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T50_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T55_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T56_;
			T45_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T45_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_3 = rawNewString(((NI) 80));
			T46_ = NIM_NIL;
			T46_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_647));
			cgFormatValue__cgen_147((&res_3), T46_);
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T47_ = NIM_NIL;
			T47_ = addrLoc__cgen_10337((*(*(*p).module).g).config, dest);
			cgFormatValue__cgen_147((&res_3), T47_);
			res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			T48_ = NIM_NIL;
			T48_ = rdLoc__cgen_435(src);
			cgFormatValue__cgen_147((&res_3), T48_);
			res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			T49_ = NIM_NIL;
			T49_ = t__cgen_85(dest);
			T50_ = NIM_NIL;
			T50_ = genTypeInfoV1__cgen_6798((*p).module, T49_, (*dest.lode).info);
			cgFormatValue__cgen_147((&res_3), T50_);
			res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA53_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA53_: ;
			T55_ = NIM_NIL;
			T55_ = rope__ropes_109(res_3);
			T56_ = NIM_NIL;
			T56_ = indentLine__cgen_286(p, T55_);
			add__ropes_159(T45_, T56_);
		}
		LA22_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48):
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T58_;
		NimStringDesc* res_4;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T59_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T60_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T61_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T68_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T69_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T70_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T75_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T76_;
		T58_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T58_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_4 = rawNewString(((NI) 80));
		T59_ = NIM_NIL;
		T59_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_648));
		cgFormatValue__cgen_147((&res_4), T59_);
		res_4 = resizeString(res_4, 8);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_126));
		T60_ = NIM_NIL;
		T60_ = addrLoc__cgen_10337((*(*(*p).module).g).config, dest);
		cgFormatValue__cgen_147((&res_4), T60_);
		res_4 = resizeString(res_4, 9);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_255));
		T61_ = NIM_NIL;
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tmpX60gensym3629_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T66_;
			if (!(src.k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 6))) goto LA64_;
			nimZeroMem((void*)(&tmpX60gensym3629_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			T66_ = NIM_NIL;
			T66_ = t__cgen_85(src);
			getTemp__cgen_7373(p, T66_, (&tmpX60gensym3629_), NIM_FALSE);
			genAssignment__cgen_10403(p, tmpX60gensym3629_, src, 0);
			T61_ = addrLoc__cgen_10337((*(*(*p).module).g).config, tmpX60gensym3629_);
		}
		goto LA62_;
		LA64_: ;
		{
			T61_ = addrLoc__cgen_10337((*(*(*p).module).g).config, src);
		}
		LA62_: ;
		cgFormatValue__cgen_147((&res_4), T61_);
		res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		T68_ = NIM_NIL;
		T68_ = addrLoc__cgen_10337((*(*(*p).module).g).config, dest);
		cgFormatValue__cgen_147((&res_4), T68_);
		res_4 = resizeString(res_4, 7);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_280));
		T69_ = NIM_NIL;
		T69_ = t__cgen_85(dest);
		T70_ = NIM_NIL;
		T70_ = genTypeInfoV1__cgen_6798((*p).module, T69_, (*dest.lode).info);
		cgFormatValue__cgen_147((&res_4), T70_);
		res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA73_;
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA73_: ;
		T75_ = NIM_NIL;
		T75_ = rope__ropes_109(res_4);
		T76_ = NIM_NIL;
		T76_ = indentLine__cgen_286(p, T75_);
		add__ropes_159(T58_, T76_);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 19):
	{
		{
			tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ T80_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T83_;
			NimStringDesc* res_5;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T84_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T85_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T86_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T87_;
			NI64 T88_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T93_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T94_;
			T80_ = (tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ)0;
			T80_ = mapSetType__cgen_1223((*(*(*p).module).g).config, ty);
			if (!(T80_ == ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 17))) goto LA81_;
			T83_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T83_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_5 = rawNewString(((NI) 80));
			T84_ = NIM_NIL;
			T84_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_250));
			cgFormatValue__cgen_147((&res_5), T84_);
			res_5 = resizeString(res_5, 8);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_126));
			T85_ = NIM_NIL;
			T85_ = rdLoc__cgen_435(dest);
			cgFormatValue__cgen_147((&res_5), T85_);
			res_5 = resizeString(res_5, 19);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_253));
			T86_ = NIM_NIL;
			T86_ = rdLoc__cgen_435(src);
			cgFormatValue__cgen_147((&res_5), T86_);
			res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			T87_ = NIM_NIL;
			T87_ = t__cgen_85(dest);
			T88_ = (NI64)0;
			T88_ = getSize__types_3388((*(*(*p).module).g).config, T87_);
			cgFormatValue__cgen_154((&res_5), T88_);
			res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA91_;
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA91_: ;
			T93_ = NIM_NIL;
			T93_ = rope__ropes_109(res_5);
			T94_ = NIM_NIL;
			T94_ = indentLine__cgen_286(p, T93_);
			add__ropes_159(T83_, T94_);
		}
		goto LA78_;
		LA81_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T96_;
			NimStringDesc* res_6;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T97_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T98_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T103_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T104_;
			T96_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T96_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_6 = rawNewString(((NI) 80));
			T97_ = NIM_NIL;
			T97_ = rdLoc__cgen_435(dest);
			cgFormatValue__cgen_147((&res_6), T97_);
			res_6 = resizeString(res_6, 3);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
			T98_ = NIM_NIL;
			T98_ = rdLoc__cgen_435(src);
			cgFormatValue__cgen_147((&res_6), T98_);
			res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA101_;
				res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA101_: ;
			T103_ = NIM_NIL;
			T103_ = rope__ropes_109(res_6);
			T104_ = NIM_NIL;
			T104_ = indentLine__cgen_286(p, T103_);
			add__ropes_159(T96_, T104_);
		}
		LA78_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 26):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 20):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47):
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T106_;
		NimStringDesc* res_7;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T107_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T108_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T113_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T114_;
		T106_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T106_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_7 = rawNewString(((NI) 80));
		T107_ = NIM_NIL;
		T107_ = rdLoc__cgen_435(dest);
		cgFormatValue__cgen_147((&res_7), T107_);
		res_7 = resizeString(res_7, 3);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
		T108_ = NIM_NIL;
		T108_ = rdLoc__cgen_435(src);
		cgFormatValue__cgen_147((&res_7), T108_);
		res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA111_;
			res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA111_: ;
		T113_ = NIM_NIL;
		T113_ = rope__ropes_109(res_7);
		T114_ = NIM_NIL;
		T114_ = indentLine__cgen_286(p, T113_);
		add__ropes_159(T106_, T114_);
	}
	break;
	default:
	{
		NimStringDesc* T116_;
		T116_ = NIM_NIL;
		T116_ = rawNewString((reprEnum((NI)(*ty).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)) ? reprEnum((NI)(*ty).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_))->Sup.len : 0) + 13);
appendString(T116_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_649));
appendString(T116_, reprEnum((NI)(*ty).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)));
		internalErrorImpl__msgs_1441((*(*(*p).module).g).config, unknownLineInfo__lineinfos_284, T116_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_650);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, skipAddr__cgen_23320)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64))) goto LA3_;
		result = (*n)._kind_6.sons->data[((NI) 0)];
	}
	goto LA1_;
	LA3_: ;
	{
		result = n;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genWasMoved__cgen_23328)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n1;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	n1 = skipAddr__cgen_23320((*n)._kind_6.sons->data[((NI) 1)]);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((NI) 0) < (*p).withinBlockLeaveActions);
		if (!(T3_)) goto LA4_;
		T3_ = notYetAlive__cgen_13121(n1);
		LA4_: ;
		if (!T3_) goto LA5_;
	}
	goto LA1_;
	LA5_: ;
	{
		initLocExpr__cgen_11548(p, n1, (&a));
		resetLoc__cgen_10897(p, (&a));
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genMove__cgen_23334)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T1_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	T1_ = NIM_NIL;
	T1_ = skipAddr__cgen_23320((*n)._kind_6.sons->data[((NI) 1)]);
	initLocExpr__cgen_11548(p, T1_, (&a));
	{
		NI T4_;
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw src;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T7_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T12_;
		NimStringDesc* res_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
		T4_ = (NI)0;
		T4_ = len__ast_3155(n);
		if (!(T4_ == ((NI) 4))) goto LA5_;
		nimZeroMem((void*)(&src), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548(p, (*n)._kind_6.sons->data[((NI) 2)], (&src));
		T7_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T7_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
		T8_ = NIM_NIL;
		T8_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res), T8_);
		res = resizeString(res, 6);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_651));
		T9_ = NIM_NIL;
		T9_ = rdLoc__cgen_435(src);
		cgFormatValue__cgen_147((&res), T9_);
		res = resizeString(res, 5);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_652));
		T10_ = NIM_NIL;
		T10_ = rope__ropes_109(res);
		T11_ = NIM_NIL;
		T11_ = indentLine__cgen_286(p, T10_);
		add__ropes_159(T7_, T11_);
		genStmts__cgen_11522(p, (*n)._kind_6.sons->data[((NI) 3)]);
		T12_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T12_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA15_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA15_: ;
		T17_ = NIM_NIL;
		T17_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res_2), T17_);
		res_2 = resizeString(res_2, 7);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_565));
		T18_ = NIM_NIL;
		T18_ = rdLoc__cgen_435(src);
		cgFormatValue__cgen_147((&res_2), T18_);
		res_2 = resizeString(res_2, 6);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_653));
		T19_ = NIM_NIL;
		T19_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res_2), T19_);
		res_2 = resizeString(res_2, 5);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_654));
		T20_ = NIM_NIL;
		T20_ = rdLoc__cgen_435(src);
		cgFormatValue__cgen_147((&res_2), T20_);
		res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_655));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA23_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA23_: ;
		T25_ = NIM_NIL;
		T25_ = rope__ropes_109(res_2);
		T26_ = NIM_NIL;
		T26_ = indentLine__cgen_286(p, T25_);
		add__ropes_159(T12_, T26_);
	}
	goto LA2_;
	LA5_: ;
	{
		{
			if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA30_;
			getTemp__cgen_7373(p, (*n).typ, d, NIM_FALSE);
		}
		LA30_: ;
		genAssignment__cgen_10403(p, (*d), a, 0);
		resetLoc__cgen_10897(p, (&a));
	}
	LA2_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genDestroy__cgen_23376)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0)) goto LA3_;
		arg = skipAddr__cgen_23320((*n)._kind_6.sons->data[((NI) 1)]);
		t = skipTypes__ast_3723((*arg).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
		switch ((*t).kind) {
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
			nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLocExpr__cgen_11548(p, arg, (&a));
			{
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T10_;
				NimStringDesc* res;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T27_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T28_;
				if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 23))&63U)))!=0)) goto LA8_;
				T10_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T10_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res = rawNewString(((NI) 80));
				res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
				T11_ = NIM_NIL;
				T11_ = rdLoc__cgen_435(a);
				cgFormatValue__cgen_147((&res), T11_);
				res = resizeString(res, 8);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_656));
				T12_ = NIM_NIL;
				T12_ = rdLoc__cgen_435(a);
				cgFormatValue__cgen_147((&res), T12_);
				res = resizeString(res, 29);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_657));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA15_;
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA15_: ;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_13));
				T17_ = NIM_NIL;
				T17_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_658));
				cgFormatValue__cgen_147((&res), T17_);
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
				T18_ = NIM_NIL;
				T18_ = rdLoc__cgen_435(a);
				cgFormatValue__cgen_147((&res), T18_);
				res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_659));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA21_;
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA21_: ;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA25_;
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA25_: ;
				T27_ = NIM_NIL;
				T27_ = rope__ropes_109(res);
				T28_ = NIM_NIL;
				T28_ = indentLine__cgen_286(p, T27_);
				add__ropes_159(T10_, T28_);
			}
			goto LA6_;
			LA8_: ;
			{
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T30_;
				NimStringDesc* res_2;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T31_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T32_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T37_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T47_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T48_;
				T30_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T30_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_2 = rawNewString(((NI) 80));
				res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
				T31_ = NIM_NIL;
				T31_ = rdLoc__cgen_435(a);
				cgFormatValue__cgen_147((&res_2), T31_);
				res_2 = resizeString(res_2, 8);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_656));
				T32_ = NIM_NIL;
				T32_ = rdLoc__cgen_435(a);
				cgFormatValue__cgen_147((&res_2), T32_);
				res_2 = resizeString(res_2, 29);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_657));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA35_;
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA35_: ;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_13));
				T37_ = NIM_NIL;
				T37_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_660));
				cgFormatValue__cgen_147((&res_2), T37_);
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
				T38_ = NIM_NIL;
				T38_ = rdLoc__cgen_435(a);
				cgFormatValue__cgen_147((&res_2), T38_);
				res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_659));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA41_;
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA41_: ;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA45_;
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA45_: ;
				T47_ = NIM_NIL;
				T47_ = rope__ropes_109(res_2);
				T48_ = NIM_NIL;
				T48_ = indentLine__cgen_286(p, T47_);
				add__ropes_159(T30_, T48_);
			}
			LA6_: ;
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a_2;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T50_;
			NimStringDesc* res_3;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T51_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T52_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T57_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T58_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T59_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T60_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T69_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T70_;
			nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLocExpr__cgen_11548(p, arg, (&a_2));
			T50_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T50_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_3 = rawNewString(((NI) 80));
			res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
			T51_ = NIM_NIL;
			T51_ = rdLoc__cgen_435(a_2);
			cgFormatValue__cgen_147((&res_3), T51_);
			res_3 = resizeString(res_3, 8);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_656));
			T52_ = NIM_NIL;
			T52_ = rdLoc__cgen_435(a_2);
			cgFormatValue__cgen_147((&res_3), T52_);
			res_3 = resizeString(res_3, 29);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_657));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA55_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA55_: ;
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_13));
			T57_ = NIM_NIL;
			T57_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_661));
			cgFormatValue__cgen_147((&res_3), T57_);
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T58_ = NIM_NIL;
			T58_ = rdLoc__cgen_435(a_2);
			cgFormatValue__cgen_147((&res_3), T58_);
			res_3 = resizeString(res_3, 16);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_662));
			T59_ = NIM_NIL;
			T59_ = lastSon__ast_3731(t);
			T60_ = NIM_NIL;
			T60_ = getTypeDesc__cgen_6662((*p).module, T59_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			cgFormatValue__cgen_147((&res_3), T60_);
			res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_128));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA63_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA63_: ;
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA67_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA67_: ;
			T69_ = NIM_NIL;
			T69_ = rope__ropes_109(res_3);
			T70_ = NIM_NIL;
			T70_ = indentLine__cgen_286(p, T69_);
			add__ropes_159(T50_, T70_);
		}
		break;
		default:
		{
		}
		break;
		}
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t_2;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* op;
		t_2 = skipTypes__ast_3723((*(*n)._kind_6.sons->data[((NI) 1)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_266);
		op = getAttachedOp__modulegraphs_4049((*(*(*p).module).g).graph, t_2, ((tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ) 0));
		{
			NIM_BOOL T75_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T77_;
			NI T78_;
			T75_ = (NIM_BOOL)0;
			T75_ = !((op == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
			if (!(T75_)) goto LA76_;
			T77_ = NIM_NIL;
			T77_ = getBody__modulegraphs_13094((*(*(*p).module).g).graph, op);
			T78_ = (NI)0;
			T78_ = len__ast_3155(T77_);
			T75_ = !((T78_ == ((NI) 0)));
			LA76_: ;
			if (!T75_) goto LA79_;
			internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_663), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_664);
		}
		LA79_: ;
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genAccessTypeField__cgen_21854)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* nilCheck;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	nilCheck = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
	T1_ = NIM_NIL;
	T1_ = rdMType__cgen_21782(p, a, &nilCheck, NIM_FALSE);
	putIntoDest__cgen_18794(p, d, e, T1_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
}
N_LIB_PRIVATE N_NIMCALL(void, genSlice__cgen_23471)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1_;
	NIM_BOOL T2_;
	NIM_BOOL T3_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T5_;
	tyTuple__xIPPgKI3s9a9c79aFyHPbe0cg T7_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* x;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* y;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T12_;
	NimStringDesc* res;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
	T1_ = NIM_NIL;
	T1_ = lastSon__ast_3731((*e).typ);
	T2_ = (NIM_BOOL)0;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*(*e)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65));
	if (!(T3_)) goto LA4_;
	T5_ = NIM_NIL;
	T5_ = skipTypes__ast_3723((*(*e)._kind_6.sons->data[((NI) 1)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
	T3_ = ((*T5_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28));
	LA4_: ;
	T2_ = T3_;
	if (!(T2_)) goto LA6_;
	T2_ = ((48 &((NU16)1<<((NU)((*(*(*(*p).module).g).config).selectedGC)&15U)))!=0);
	LA6_: ;
	nimZeroMem((void*)(&T7_), sizeof(tyTuple__xIPPgKI3s9a9c79aFyHPbe0cg));
	genOpenArraySlice__cgen_11842(p, e, (*e).typ, T1_, T2_, (&T7_));
	x = NIM_NIL;
	x = T7_.Field0;
	y = NIM_NIL;
	y = T7_.Field1;
	{
		if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA10_;
		getTemp__cgen_7373(p, (*e).typ, d, NIM_FALSE);
	}
	LA10_: ;
	T12_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T12_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	res = rawNewString(((NI) 80));
	T13_ = NIM_NIL;
	T13_ = rdLoc__cgen_435((*d));
	cgFormatValue__cgen_147((&res), T13_);
	res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_267));
	cgFormatValue__cgen_147((&res), x);
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_164));
	T14_ = NIM_NIL;
	T14_ = rdLoc__cgen_435((*d));
	cgFormatValue__cgen_147((&res), T14_);
	res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_269));
	cgFormatValue__cgen_147((&res), y);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA17_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA17_: ;
	T19_ = NIM_NIL;
	T19_ = rope__ropes_109(res);
	T20_ = NIM_NIL;
	T20_ = indentLine__cgen_286(p, T19_);
	add__ropes_159(T12_, T20_);
}
N_LIB_PRIVATE N_NIMCALL(void, genMagicExpr__cgen_23524)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag op) {
	switch (op) {
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 110):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 109):
	{
		genAndOr__cgen_20420(p, e, d, op);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 96) ... ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 100):
	{
		unaryArith__cgen_19396(p, e, d, op);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 93) ... ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 95):
	{
		unaryArithOverflow__cgen_19054(p, e, d, op);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 53) ... ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 56):
	{
		binaryFloatArith__cgen_23223(p, e, d, op);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 57) ... ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 90):
	{
		binaryArith__cgen_19108(p, e, d, op);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 92):
	{
		genEqProc__cgen_19321(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 46) ... ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 52):
	{
		binaryArithOverflow__cgen_18902(p, e, d, op);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 135):
	{
		genRepr__cgen_21666(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 262):
	{
		genGetTypeInfo__cgen_21838(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 263):
	{
		genGetTypeInfoV2__cgen_21844(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 142):
	{
		genSwap__cgen_22180(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 29):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 30):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* underlying;
		underlying = skipTypes__ast_3723((*(*e)._kind_6.sons->data[((NI) 1)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_515);
		{
			NIM_BOOL T15_;
			T15_ = (NIM_BOOL)0;
			T15_ = !((((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 5))&31U)))!=0));
			if (T15_) goto LA16_;
			T15_ = ((*underlying).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40) && (*underlying).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44));
			LA16_: ;
			if (!T15_) goto LA17_;
			binaryStmt__cgen_18809(p, e, d, opr__cgen_23529[(op)- 29]);
		}
		goto LA13_;
		LA17_: ;
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ranged;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* res;
			NI64 sizeX60gensym5379_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* storageX60gensym5379_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* resultX60gensym5379_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T25_;
			NimStringDesc* res_2;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T30_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T31_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T32_;
			NimStringDesc* res_3;
			NimStringDesc* T33_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T39_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T40_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T41_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T42_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T43_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T48_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T49_;
			tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T69_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T70_;
			nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
			ranged = skipTypes__ast_3723((*(*e)._kind_6.sons->data[((NI) 1)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_520);
			sizeX60gensym5379_ = getSize__types_3388((*(*(*p).module).g).config, ranged);
			{
				if (!(sizeX60gensym5379_ < ((NI64) ((*(*(*(*p).module).g).config).target.intSize)))) goto LA22_;
				storageX60gensym5379_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_340));
			}
			goto LA20_;
			LA22_: ;
			{
				storageX60gensym5379_ = getTypeDesc__cgen_6662((*p).module, ranged, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			}
			LA20_: ;
			resultX60gensym5379_ = getTempName__cgen_428((*p).module);
			T25_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T25_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
			res_2 = rawNewString(((NI) 80));
			cgFormatValue__cgen_147((&res_2), storageX60gensym5379_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_13));
			cgFormatValue__cgen_147((&res_2), resultX60gensym5379_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA28_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA28_: ;
			T30_ = NIM_NIL;
			T30_ = rope__ropes_109(res_2);
			T31_ = NIM_NIL;
			T31_ = indentLine__cgen_286(p, T30_);
			add__ropes_159(T25_, T31_);
			T32_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T32_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_3 = rawNewString(((NI) 80));
			res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
			T33_ = NIM_NIL;
			{
				if (!((*underlying).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35))) goto LA36_;
				T33_ = copyString(fun64__cgen_23530[(op)- 29]);
			}
			goto LA34_;
			LA36_: ;
			{
				T33_ = copyString(fun__cgen_23531[(op)- 29]);
			}
			LA34_: ;
			T39_ = NIM_NIL;
			T39_ = cgsym__cgen_126((*p).module, T33_);
			cgFormatValue__cgen_147((&res_3), T39_);
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T40_ = NIM_NIL;
			T40_ = rdCharLoc__cgen_10377(a);
			cgFormatValue__cgen_147((&res_3), T40_);
			res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			T41_ = NIM_NIL;
			T41_ = rdCharLoc__cgen_10377(b);
			cgFormatValue__cgen_147((&res_3), T41_);
			res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_492));
			cgFormatValue__cgen_147((&res_3), resultX60gensym5379_);
			res_3 = resizeString(res_3, 5);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_493));
			T42_ = NIM_NIL;
			T42_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_469));
			cgFormatValue__cgen_147((&res_3), T42_);
			res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_436));
			T43_ = NIM_NIL;
			T43_ = raiseInstr__cgen_424(p);
			cgFormatValue__cgen_147((&res_3), T43_);
			res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_230));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA46_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA46_: ;
			T48_ = NIM_NIL;
			T48_ = rope__ropes_109(res_3);
			T49_ = NIM_NIL;
			T49_ = indentLine__cgen_286(p, T48_);
			add__ropes_159(T32_, T49_);
			{
				NIM_BOOL T52_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T56_;
				NimStringDesc* res_4;
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T57_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T58_;
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T59_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T60_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T61_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T62_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T67_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T68_;
				T52_ = (NIM_BOOL)0;
				T52_ = (sizeX60gensym5379_ < ((NI64) ((*(*(*(*p).module).g).config).target.intSize)));
				if (T52_) goto LA53_;
				T52_ = ((*ranged).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 20) || (*ranged).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14));
				LA53_: ;
				if (!T52_) goto LA54_;
				T56_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T56_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_4 = rawNewString(((NI) 80));
				res_4 = resizeString(res_4, 4);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
				cgFormatValue__cgen_147((&res_4), resultX60gensym5379_);
				res_4 = resizeString(res_4, 3);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_163));
				T57_ = firstOrd__types_1406((*(*(*p).module).g).config, ranged);
				T58_ = NIM_NIL;
				T58_ = intLiteral__cgen_17773(T57_);
				cgFormatValue__cgen_147((&res_4), T58_);
				res_4 = resizeString(res_4, 4);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_432));
				cgFormatValue__cgen_147((&res_4), resultX60gensym5379_);
				res_4 = resizeString(res_4, 3);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_433));
				T59_ = lastOrd__types_1532((*(*(*p).module).g).config, ranged);
				T60_ = NIM_NIL;
				T60_ = intLiteral__cgen_17773(T59_);
				cgFormatValue__cgen_147((&res_4), T60_);
				res_4 = resizeString(res_4, 3);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_468));
				T61_ = NIM_NIL;
				T61_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_469));
				cgFormatValue__cgen_147((&res_4), T61_);
				res_4 = resizeString(res_4, 4);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_436));
				T62_ = NIM_NIL;
				T62_ = raiseInstr__cgen_424(p);
				cgFormatValue__cgen_147((&res_4), T62_);
				res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA65_;
					res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA65_: ;
				T67_ = NIM_NIL;
				T67_ = rope__ropes_109(res_4);
				T68_ = NIM_NIL;
				T68_ = indentLine__cgen_286(p, T67_);
				add__ropes_159(T56_, T68_);
			}
			LA54_: ;
			res = resultX60gensym5379_;
			nimZeroMem((void*)T69_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
			T69_[0] = getTypeDesc__cgen_6662((*p).module, ranged, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			T69_[1] = res;
			T70_ = NIM_NIL;
			T70_ = percent___cgen_19026(T69_, 2);
			putIntoDest__cgen_18794(p, (&a), (*e)._kind_6.sons->data[((NI) 1)], T70_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
		}
		LA13_: ;
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 125):
	{
		genStrConcat__cgen_20568(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 131):
	{
		{
			if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0)) goto LA75_;
			binaryStmtAddr__cgen_18835(p, e, d, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_527));
		}
		goto LA73_;
		LA75_: ;
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw dest;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b_2;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw call;
			NimStringDesc* res_5;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T78_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T79_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T80_;
			nimZeroMem((void*)(&dest), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			nimZeroMem((void*)(&b_2), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			nimZeroMem((void*)(&call), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLoc__cgen_66((&call), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 9), e, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 3));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&dest));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&b_2));
			res_5 = rawNewString(((NI) 80));
			T78_ = NIM_NIL;
			T78_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_528));
			cgFormatValue__cgen_147((&res_5), T78_);
			res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T79_ = NIM_NIL;
			T79_ = rdLoc__cgen_435(dest);
			cgFormatValue__cgen_147((&res_5), T79_);
			res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			T80_ = NIM_NIL;
			T80_ = rdLoc__cgen_435(b_2);
			cgFormatValue__cgen_147((&res_5), T80_);
			res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
			call.r = rope__ropes_109(res_5);
			genAssignment__cgen_10403(p, dest, call, 0);
		}
		LA73_: ;
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 132):
	{
		genStrAppend__cgen_20648(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 133):
	{
		{
			if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0)) goto LA85_;
			asgnRef((void**) (&(*e)._kind_6.sons->data[((NI) 1)]), makeAddr__cgen_22088((*e)._kind_6.sons->data[((NI) 1)], (*(*p).module).Sup.idgen));
			genCall__cgen_13177(p, e, d);
		}
		goto LA83_;
		LA85_: ;
		{
			genSeqElemAppend__cgen_20746(p, e, d);
		}
		LA83_: ;
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 116):
	{
		genStrEquals__cgen_23155(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 117):
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym5423_;
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw bX60gensym5423_;
		NimStringDesc* res_6;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T90_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T91_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T92_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T93_;
		nimZeroMem((void*)(&aX60gensym5423_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		nimZeroMem((void*)(&bX60gensym5423_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5423_));
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym5423_));
		res_6 = rawNewString(((NI) 80));
		res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T90_ = NIM_NIL;
		T90_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_538));
		cgFormatValue__cgen_147((&res_6), T90_);
		res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T91_ = NIM_NIL;
		T91_ = rdLoc__cgen_435(aX60gensym5423_);
		cgFormatValue__cgen_147((&res_6), T91_);
		res_6 = resizeString(res_6, 2);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		T92_ = NIM_NIL;
		T92_ = rdLoc__cgen_435(bX60gensym5423_);
		cgFormatValue__cgen_147((&res_6), T92_);
		res_6 = resizeString(res_6, 7);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_539));
		T93_ = NIM_NIL;
		T93_ = rope__ropes_109(res_6);
		putIntoDest__cgen_18794(p, d, e, T93_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 118):
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym5438_;
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw bX60gensym5438_;
		NimStringDesc* res_7;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T95_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T96_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T97_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T98_;
		nimZeroMem((void*)(&aX60gensym5438_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		nimZeroMem((void*)(&bX60gensym5438_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5438_));
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym5438_));
		res_7 = rawNewString(((NI) 80));
		res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T95_ = NIM_NIL;
		T95_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_538));
		cgFormatValue__cgen_147((&res_7), T95_);
		res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T96_ = NIM_NIL;
		T96_ = rdLoc__cgen_435(aX60gensym5438_);
		cgFormatValue__cgen_147((&res_7), T96_);
		res_7 = resizeString(res_7, 2);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
		T97_ = NIM_NIL;
		T97_ = rdLoc__cgen_435(bX60gensym5438_);
		cgFormatValue__cgen_147((&res_7), T97_);
		res_7 = resizeString(res_7, 6);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_540));
		T98_ = NIM_NIL;
		T98_ = rope__ropes_109(res_7);
		putIntoDest__cgen_18794(p, d, e, T98_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 143):
	{
		genIsNil__cgen_19358(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 103):
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym5453_;
		NimStringDesc* res_8;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T101_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T102_;
		nimZeroMem((void*)(&aX60gensym5453_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5453_));
		res_8 = rawNewString(((NI) 80));
		T101_ = NIM_NIL;
		T101_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_542));
		cgFormatValue__cgen_147((&res_8), T101_);
		res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T102_ = NIM_NIL;
		T102_ = rdLoc__cgen_435(aX60gensym5453_);
		cgFormatValue__cgen_147((&res_8), T102_);
		res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		aX60gensym5453_.r = rope__ropes_109(res_8);
		aX60gensym5453_.flags &= ~(((NU16)1) << ((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 0)) & 15));
		{
			if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA105_;
			getTemp__cgen_7373(p, (*e).typ, d, NIM_FALSE);
		}
		LA105_: ;
		genAssignment__cgen_10403(p, (*d), aX60gensym5453_, 0);
		gcUsage__cgen_20553((*(*(*p).module).g).config, e);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 104):
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym5460_;
		NimStringDesc* res_9;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T108_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T109_;
		nimZeroMem((void*)(&aX60gensym5460_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5460_));
		res_9 = rawNewString(((NI) 80));
		T108_ = NIM_NIL;
		T108_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_543));
		cgFormatValue__cgen_147((&res_9), T108_);
		res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T109_ = NIM_NIL;
		T109_ = rdLoc__cgen_435(aX60gensym5460_);
		cgFormatValue__cgen_147((&res_9), T109_);
		res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		aX60gensym5460_.r = rope__ropes_109(res_9);
		aX60gensym5460_.flags &= ~(((NU16)1) << ((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 0)) & 15));
		{
			if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA112_;
			getTemp__cgen_7373(p, (*e).typ, d, NIM_FALSE);
		}
		LA112_: ;
		genAssignment__cgen_10403(p, (*d), aX60gensym5460_, 0);
		gcUsage__cgen_20553((*(*(*p).module).g).config, e);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 102):
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym5467_;
		NimStringDesc* res_10;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T115_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T116_;
		nimZeroMem((void*)(&aX60gensym5467_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5467_));
		res_10 = rawNewString(((NI) 80));
		T115_ = NIM_NIL;
		T115_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_544));
		cgFormatValue__cgen_147((&res_10), T115_);
		res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T116_ = NIM_NIL;
		T116_ = rdLoc__cgen_435(aX60gensym5467_);
		cgFormatValue__cgen_147((&res_10), T116_);
		res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		aX60gensym5467_.r = rope__ropes_109(res_10);
		aX60gensym5467_.flags &= ~(((NU16)1) << ((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 0)) & 15));
		{
			if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA119_;
			getTemp__cgen_7373(p, (*e).typ, d, NIM_FALSE);
		}
		LA119_: ;
		genAssignment__cgen_10403(p, (*d), aX60gensym5467_, 0);
		gcUsage__cgen_20553((*(*(*p).module).g).config, e);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 101):
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym5474_;
		NimStringDesc* res_11;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T122_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T123_;
		nimZeroMem((void*)(&aX60gensym5474_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5474_));
		res_11 = rawNewString(((NI) 80));
		T122_ = NIM_NIL;
		T122_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_545));
		cgFormatValue__cgen_147((&res_11), T122_);
		res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T123_ = NIM_NIL;
		T123_ = rdLoc__cgen_435(aX60gensym5474_);
		cgFormatValue__cgen_147((&res_11), T123_);
		res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		aX60gensym5474_.r = rope__ropes_109(res_11);
		aX60gensym5474_.flags &= ~(((NU16)1) << ((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 0)) & 15));
		{
			if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA126_;
			getTemp__cgen_7373(p, (*e).typ, d, NIM_FALSE);
		}
		LA126_: ;
		genAssignment__cgen_10403(p, (*d), aX60gensym5474_, 0);
		gcUsage__cgen_20553((*(*(*p).module).g).config, e);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 105):
	{
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T131_;
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym5482_;
			NimStringDesc* res_12;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T134_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T135_;
			T131_ = NIM_NIL;
			T131_ = skipTypes__ast_3723((*(*e)._kind_6.sons->data[((NI) 1)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
			if (!((*T131_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 37))) goto LA132_;
			nimZeroMem((void*)(&aX60gensym5482_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5482_));
			res_12 = rawNewString(((NI) 80));
			T134_ = NIM_NIL;
			T134_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_546));
			cgFormatValue__cgen_147((&res_12), T134_);
			res_12 = resizeString(res_12, 1);
appendString(res_12, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T135_ = NIM_NIL;
			T135_ = rdLoc__cgen_435(aX60gensym5482_);
			cgFormatValue__cgen_147((&res_12), T135_);
			res_12 = resizeString(res_12, 1);
appendString(res_12, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
			aX60gensym5482_.r = rope__ropes_109(res_12);
			aX60gensym5482_.flags &= ~(((NU16)1) << ((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 0)) & 15));
			{
				if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA138_;
				getTemp__cgen_7373(p, (*e).typ, d, NIM_FALSE);
			}
			LA138_: ;
			genAssignment__cgen_10403(p, (*d), aX60gensym5482_, 0);
			gcUsage__cgen_20553((*(*(*p).module).g).config, e);
		}
		goto LA129_;
		LA132_: ;
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym5489_;
			NimStringDesc* res_13;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T141_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T142_;
			nimZeroMem((void*)(&aX60gensym5489_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5489_));
			res_13 = rawNewString(((NI) 80));
			T141_ = NIM_NIL;
			T141_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_547));
			cgFormatValue__cgen_147((&res_13), T141_);
			res_13 = resizeString(res_13, 1);
appendString(res_13, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T142_ = NIM_NIL;
			T142_ = rdLoc__cgen_435(aX60gensym5489_);
			cgFormatValue__cgen_147((&res_13), T142_);
			res_13 = resizeString(res_13, 1);
appendString(res_13, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
			aX60gensym5489_.r = rope__ropes_109(res_13);
			aX60gensym5489_.flags &= ~(((NU16)1) << ((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 0)) & 15));
			{
				if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA145_;
				getTemp__cgen_7373(p, (*e).typ, d, NIM_FALSE);
			}
			LA145_: ;
			genAssignment__cgen_10403(p, (*d), aX60gensym5489_, 0);
			gcUsage__cgen_20553((*(*(*p).module).g).config, e);
		}
		LA129_: ;
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 106):
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym5496_;
		NimStringDesc* res_14;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T148_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T149_;
		nimZeroMem((void*)(&aX60gensym5496_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5496_));
		res_14 = rawNewString(((NI) 80));
		T148_ = NIM_NIL;
		T148_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_548));
		cgFormatValue__cgen_147((&res_14), T148_);
		res_14 = resizeString(res_14, 1);
appendString(res_14, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T149_ = NIM_NIL;
		T149_ = rdLoc__cgen_435(aX60gensym5496_);
		cgFormatValue__cgen_147((&res_14), T149_);
		res_14 = resizeString(res_14, 1);
appendString(res_14, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		aX60gensym5496_.r = rope__ropes_109(res_14);
		aX60gensym5496_.flags &= ~(((NU16)1) << ((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 0)) & 15));
		{
			if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA152_;
			getTemp__cgen_7373(p, (*e).typ, d, NIM_FALSE);
		}
		LA152_: ;
		genAssignment__cgen_10403(p, (*d), aX60gensym5496_, 0);
		gcUsage__cgen_20553((*(*(*p).module).g).config, e);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 107):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 154):
	{
		expr__cgen_11525(p, (*e)._kind_6.sons->data[((NI) 1)], d);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 0):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 145):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 155) ... ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 156):
	{
		genCall__cgen_13177(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 108):
	{
		{
			if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 41))&63U)))!=0)) goto LA159_;
			genEnumToStr__cgen_23511(p, e, d);
		}
		goto LA157_;
		LA159_: ;
		{
			genRepr__cgen_21666(p, e, d);
		}
		LA157_: ;
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 15):
	{
		genOf__cgen_21660(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 32):
	{
		genNew__cgen_20982(p, e);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 33):
	{
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a_2;
			if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 41))&63U)))!=0)) goto LA167_;
			nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&a_2));
			rawGenNew__cgen_20825(p, (&a_2), ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL), NIM_TRUE);
			gcUsage__cgen_20553((*(*(*p).module).g).config, e);
		}
		goto LA165_;
		LA167_: ;
		{
			genNewFinalize__cgen_21471(p, e);
		}
		LA165_: ;
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 34):
	{
		{
			if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0)) goto LA173_;
			asgnRef((void**) (&(*e)._kind_6.sons->data[((NI) 1)]), makeAddr__cgen_22088((*e)._kind_6.sons->data[((NI) 1)], (*(*p).module).Sup.idgen));
			genCall__cgen_13177(p, e, d);
		}
		goto LA171_;
		LA173_: ;
		{
			genNewSeq__cgen_21086(p, e);
		}
		LA171_: ;
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 35):
	{
		genNewSeqOfCap__cgen_21125(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 10):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T178_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T179_;
		t = skipTypes__ast_3723((*(*e)._kind_6.sons->data[((NI) 1)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_572);
		nimZeroMem((void*)T178_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T178_[0] = getTypeDesc__cgen_6662((*p).module, t, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
		T179_ = NIM_NIL;
		T179_ = percent___cgen_23873(T178_, 1);
		putIntoDest__cgen_18794(p, d, e, T179_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 11):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t_2;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T181_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T182_;
		t_2 = skipTypes__ast_3723((*(*e)._kind_6.sons->data[((NI) 1)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_572);
		nimZeroMem((void*)T181_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T181_[0] = getTypeDesc__cgen_6662((*p).module, t_2, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
		T182_ = NIM_NIL;
		T182_ = percent___cgen_23880(T181_, 1);
		putIntoDest__cgen_18794(p, d, e, T182_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 12):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* dotExpr;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t_3;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tname;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* member;
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T198_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T199_;
		dotExpr = NIM_NIL;
		{
			if (!((*(*e)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45))) goto LA186_;
			dotExpr = (*e)._kind_6.sons->data[((NI) 1)];
		}
		goto LA184_;
		LA186_: ;
		{
			if (!((*(*e)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 46))) goto LA189_;
			dotExpr = (*(*e)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 0)];
		}
		goto LA184_;
		LA189_: ;
		{
			internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*e).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_573), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_574);
		}
		LA184_: ;
		t_3 = skipTypes__ast_3723((*(*dotExpr)._kind_6.sons->data[((NI) 0)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_572);
		tname = getTypeDesc__cgen_6662((*p).module, t_3, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T196_;
			if (!((*t_3).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18))) goto LA194_;
			T196_ = NIM_NIL;
			T196_ = rope__ropes_115(((NI64) ((*(*(*dotExpr)._kind_6.sons->data[((NI) 1)])._kind_4.sym).position)));
			member = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_575), T196_);
		}
		goto LA192_;
		LA194_: ;
		{
			member = (*(*(*dotExpr)._kind_6.sons->data[((NI) 1)])._kind_4.sym).loc.r;
		}
		LA192_: ;
		nimZeroMem((void*)T198_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T198_[0] = tname;
		T198_[1] = member;
		T199_ = NIM_NIL;
		T199_ = percent___cgen_23909(T198_, 2);
		putIntoDest__cgen_18794(p, d, e, T199_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 43):
	{
		genSomeCast__cgen_22901(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 31):
	{
		genOrd__cgen_22885(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 38):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 9):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 37):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 39):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 36):
	{
		genArrayLen__cgen_21867(p, e, d, op);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 44):
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym5527_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T208_;
		NimStringDesc* res_15;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T209_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T210_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T211_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T216_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T217_;
		nimZeroMem((void*)(&aX60gensym5527_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		{
			if (!!(((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0)))) goto LA206_;
			internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*e).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_593), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_594);
		}
		LA206_: ;
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5527_));
		T208_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T208_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_15 = rawNewString(((NI) 80));
		res_15 = resizeString(res_15, 4);
appendString(res_15, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
		T209_ = NIM_NIL;
		T209_ = rdLoc__cgen_435(aX60gensym5527_);
		cgFormatValue__cgen_147((&res_15), T209_);
		res_15 = resizeString(res_15, 4);
appendString(res_15, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_477));
		T210_ = NIM_NIL;
		T210_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_595));
		cgFormatValue__cgen_147((&res_15), T210_);
		res_15 = resizeString(res_15, 1);
appendString(res_15, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T211_ = NIM_NIL;
		T211_ = rdLoc__cgen_435(aX60gensym5527_);
		cgFormatValue__cgen_147((&res_15), T211_);
		res_15 = resizeString(res_15, 4);
appendString(res_15, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_596));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA214_;
			res_15 = resizeString(res_15, 1);
appendString(res_15, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA214_: ;
		T216_ = NIM_NIL;
		T216_ = rope__ropes_109(res_15);
		T217_ = NIM_NIL;
		T217_ = indentLine__cgen_286(p, T216_);
		add__ropes_159(T208_, T217_);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 45):
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym5541_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T223_;
		NimStringDesc* res_16;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T224_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T225_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T226_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T231_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T232_;
		nimZeroMem((void*)(&aX60gensym5541_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		{
			if (!!(((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0)))) goto LA221_;
			internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*e).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_593), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_594);
		}
		LA221_: ;
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5541_));
		T223_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T223_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_16 = rawNewString(((NI) 80));
		res_16 = resizeString(res_16, 4);
appendString(res_16, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
		T224_ = NIM_NIL;
		T224_ = rdLoc__cgen_435(aX60gensym5541_);
		cgFormatValue__cgen_147((&res_16), T224_);
		res_16 = resizeString(res_16, 4);
appendString(res_16, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_477));
		T225_ = NIM_NIL;
		T225_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_597));
		cgFormatValue__cgen_147((&res_16), T225_);
		res_16 = resizeString(res_16, 1);
appendString(res_16, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T226_ = NIM_NIL;
		T226_ = rdLoc__cgen_435(aX60gensym5541_);
		cgFormatValue__cgen_147((&res_16), T226_);
		res_16 = resizeString(res_16, 4);
appendString(res_16, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_596));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA229_;
			res_16 = resizeString(res_16, 1);
appendString(res_16, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA229_: ;
		T231_ = NIM_NIL;
		T231_ = rope__ropes_109(res_16);
		T232_ = NIM_NIL;
		T232_ = indentLine__cgen_286(p, T231_);
		add__ropes_159(T223_, T232_);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 137):
	{
		genSetLengthStr__cgen_22154(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 138):
	{
		genSetLengthSeq__cgen_22096(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 40):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 41):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 42):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 121):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 120):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 119):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 122):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 123):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 124):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 134):
	{
		genSetOp__cgen_22352(p, e, d, op);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 146):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 147):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 136):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 148):
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opr;
		opr = (*(*e)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc;
			NimStringDesc* T241_;
			NIM_BOOL wasDeclared;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym5560_;
			NimStringDesc* T242_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T243_;
			if (!!((((*opr).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 3))&15U)))!=0))) goto LA239_;
			T241_ = NIM_NIL;
			T241_ = dollar___ropes_250((*opr).loc.r);
			prc = getCompilerProc__magicsys_145((*(*(*p).module).g).graph, T241_);
			xX60gensym5560_ = prc;
			wasDeclared = containsOrIncl__astalgo_402((&(*(*p).module).declaredProtos), (NI)((NI)((NU64)(((NI) ((*xX60gensym5560_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym5560_).Sup.itemId.item))));
			T242_ = NIM_NIL;
			T242_ = dollar___ropes_250((*opr).loc.r);
			T243_ = NIM_NIL;
			T243_ = cgsym__cgen_126((*p).module, T242_);
			(void)(T243_);
			{
				NIM_BOOL T246_;
				tyArray__FKvM4FDhljtt88k8FkGthA T250_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T251_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T252_;
				T246_ = (NIM_BOOL)0;
				T246_ = !(wasDeclared);
				if (!(T246_)) goto LA247_;
				T246_ = hcrOn__cgen_46(p);
				LA247_: ;
				if (!T246_) goto LA248_;
				nimZeroMem((void*)T250_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
				T250_[0] = mangleDynLibProc__cgen_3812(prc);
				T251_ = NIM_NIL;
				T251_ = t__cgen_85((*prc).loc);
				T250_[1] = getTypeDesc__cgen_6662((*p).module, T251_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
				T250_[2] = getModuleDllPath__cgen_142((*p).module, prc);
				T252_ = NIM_NIL;
				T252_ = percent___cgen_23990(T250_, 3);
				add__ropes_159(&(*(*p).module).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 18))- 0], T252_);
			}
			LA248_: ;
		}
		LA239_: ;
		genCall__cgen_13177(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 153):
	{
		genDefault__cgen_20817(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 159):
	{
		genReset__cgen_20812(p, e);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 20):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T256_;
		T256_ = NIM_NIL;
		T256_ = skipConv__types_3661((*e)._kind_6.sons->data[((NI) 1)]);
		genEcho__cgen_20455(p, T256_);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 144):
	{
		genArrToSeq__cgen_21365(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 213) ... ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 260):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 22) ... ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 28):
	{
		NimStringDesc* T259_;
		T259_ = NIM_NIL;
		T259_ = nsuFormatSingleElem(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_641), (*(*(*(*e)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).s);
		liMessage__msgs_1128((*(*(*p).module).g).config, (*e).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T259_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_642, NIM_FALSE);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 199):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
		n = wrapProcForSpawn__spawn_510((*(*(*p).module).g).graph, (*(*p).module).Sup.idgen, (*(*p).module).module, e, (*e).typ, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
		expr__cgen_11525(p, n, d);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 141):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n_2;
		n_2 = liftParallel__semparallel_855((*(*(*p).module).g).graph, (*(*p).module).Sup.idgen, (*(*p).module).module, e);
		expr__cgen_11525(p, n_2, d);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 200):
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a_3;
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b_3;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x;
		{
			NIM_BOOL T265_;
			T265_ = (NIM_BOOL)0;
			T265_ = ((48 &((NU16)1<<((NU)((*(*(*(*p).module).g).config).selectedGC)&15U)))!=0);
			if (!(T265_)) goto LA266_;
			T265_ = !((((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 51))&63U)))!=0));
			LA266_: ;
			if (!T265_) goto LA267_;
			liMessage__msgs_1128((*(*(*p).module).g).config, (*e).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_643), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_644, NIM_FALSE);
		}
		LA267_: ;
		nimZeroMem((void*)(&a_3), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		nimZeroMem((void*)(&b_3), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		{
			if (!((*(*e)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63) || (*(*e)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64))) goto LA271_;
			x = (*(*e)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 0)];
		}
		goto LA269_;
		LA271_: ;
		{
			x = (*e)._kind_6.sons->data[((NI) 1)];
		}
		LA269_: ;
		initLocExpr__cgen_11548(p, x, (&a_3));
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 2)], (&b_3));
		genDeepCopy__cgen_18636(p, a_3, b_3);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 127):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 91):
	{
		genCall__cgen_13177(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 150):
	{
		genWasMoved__cgen_23328(p, e);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 149):
	{
		genMove__cgen_23334(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 151):
	{
		genDestroy__cgen_23376(p, e);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 157):
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym5580_;
		NimStringDesc* res_17;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T279_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T280_;
		nimZeroMem((void*)(&aX60gensym5580_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5580_));
		res_17 = rawNewString(((NI) 80));
		T279_ = NIM_NIL;
		T279_ = rdLoc__cgen_435(aX60gensym5580_);
		cgFormatValue__cgen_147((&res_17), T279_);
		res_17 = resizeString(res_17, 6);
appendString(res_17, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_194));
		T280_ = NIM_NIL;
		T280_ = rope__ropes_109(res_17);
		putIntoDest__cgen_18794(p, d, e, T280_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 158):
	{
		genAccessTypeField__cgen_21854(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 126):
	{
		genSlice__cgen_23471(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 152):
	{
	}
	break;
	default:
	{
		NimStringDesc* T285_;
		T285_ = NIM_NIL;
		T285_ = rawNewString((reprEnum((NI)op, (&NTItmagic__3qAy6bDUDlF8Fc2RR6pF9ag_)) ? reprEnum((NI)op, (&NTItmagic__3qAy6bDUDlF8Fc2RR6pF9ag_))->Sup.len : 0) + 14);
appendString(T285_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_665));
appendString(T285_, reprEnum((NI)op, (&NTItmagic__3qAy6bDUDlF8Fc2RR6pF9ag_)));
		internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*e).info, T285_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_666);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genSetNode__cgen_17906)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	NI size;
	NI64 T1_;
	tySequence__6H5Oh5UUvVCLiakt9aTwtUQ* cs;
	result = NIM_NIL;
	T1_ = (NI64)0;
	T1_ = getSize__types_3388((*(*(*p).module).g).config, (*n).typ);
	size = ((NI) (T1_));
	cs = toBitSet__nimsets_103((*(*(*p).module).g).config, n);
	{
		NI id;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
		if (!(((NI) 8) < size)) goto LA4_;
		id = nodeTableTestOrSet__treetab_198((&(*(*p).module).dataCache), n, ((NI) ((*(*p).module).labels)));
		T6_ = NIM_NIL;
		T6_ = rope__ropes_115(((NI64) (id)));
		result = amp___ropes_128((*(*p).module).tmpBase, T6_);
		{
			tyArray__FKvM4FDhljtt88k8FkGthA T11_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
			if (!(id == ((NI) ((*(*p).module).labels)))) goto LA9_;
			(*(*p).module).labels += ((NI) 1);
			nimZeroMem((void*)T11_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
			T11_[0] = getTypeDesc__cgen_6662((*p).module, (*n).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			T11_[1] = result;
			T11_[2] = genRawSetData__cgen_17896(cs, size);
			T12_ = NIM_NIL;
			T12_ = percent___cgen_17917(T11_, 3);
			add__ropes_159(&(*(*p).module).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 9))- 0], T12_);
		}
		LA9_: ;
	}
	goto LA2_;
	LA4_: ;
	{
		result = genRawSetData__cgen_17896(cs, size);
	}
	LA2_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genSetConstr__cgen_24052)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw idx;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&idx), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
		if (!(((*e).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg) 4))&31U)))!=0)) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = genSetNode__cgen_17906(p, e);
		putIntoDest__cgen_18794(p, d, e, T5_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	goto LA1_;
	LA3_: ;
	{
		{
			if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA9_;
			getTemp__cgen_7373(p, (*e).typ, d, NIM_FALSE);
		}
		LA9_: ;
		{
			NI64 T13_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T16_;
			NimStringDesc* res;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
			T13_ = (NI64)0;
			T13_ = getSize__types_3388((*(*(*p).module).g).config, (*e).typ);
			if (!(IL64(8) < T13_)) goto LA14_;
			T16_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T16_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res = rawNewString(((NI) 80));
			T17_ = NIM_NIL;
			T17_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_125));
			cgFormatValue__cgen_147((&res), T17_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T18_ = NIM_NIL;
			T18_ = rdLoc__cgen_435((*d));
			cgFormatValue__cgen_147((&res), T18_);
			res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_127));
			T19_ = NIM_NIL;
			T19_ = getTypeDesc__cgen_6662((*p).module, (*e).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			cgFormatValue__cgen_147((&res), T19_);
			res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_128));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA22_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA22_: ;
			T24_ = NIM_NIL;
			T24_ = rope__ropes_109(res);
			T25_ = NIM_NIL;
			T25_ = indentLine__cgen_286(p, T24_);
			add__ropes_159(T16_, T25_);
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** it;
				tySequence__IeU9azYSNIK3V9b36Ir6NZcw* colontmp_;
				NI i;
				NI L;
				NI T27_;
				it = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
				colontmp_ = NIM_NIL;
				colontmp_ = (*e)._kind_6.sons;
				i = ((NI) 0);
				T27_ = (colontmp_ ? colontmp_->Sup.len : 0);
				L = T27_;
				{
					while (1) {
						if (!(i < L)) goto LA29;
						it = &colontmp_->data[i];
						{
							tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T34_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T35_;
							tyArray__InO6xIOhXMnkCXPnEYWwWg T36_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T37_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
							if (!((*(*it)).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 44))) goto LA32_;
							T34_ = NIM_NIL;
							T34_ = getSysType__magicsys_60((*(*(*p).module).g).graph, unknownLineInfo__lineinfos_284, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31));
							getTemp__cgen_7373(p, T34_, (&idx), NIM_FALSE);
							initLocExpr__cgen_11548(p, (*(*it))._kind_6.sons->data[((NI) 0)], (&a));
							initLocExpr__cgen_11548(p, (*(*it))._kind_6.sons->data[((NI) 1)], (&b));
							T35_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
							T35_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
							nimZeroMem((void*)T36_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
							T36_[0] = rdLoc__cgen_435(idx);
							T36_[1] = rdLoc__cgen_435((*d));
							T36_[2] = rdSetElemLoc__cgen_17717((*(*(*p).module).g).config, a, (*e).typ);
							T36_[3] = rdSetElemLoc__cgen_17717((*(*(*p).module).g).config, b, (*e).typ);
							T37_ = NIM_NIL;
							T37_ = percent___cgen_24090(T36_, 4);
							T38_ = NIM_NIL;
							T38_ = indentLine__cgen_286(p, T37_);
							add__ropes_159(T35_, T38_);
						}
						goto LA30_;
						LA32_: ;
						{
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T40_;
							tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T41_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T42_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T43_;
							initLocExpr__cgen_11548(p, (*it), (&a));
							T40_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
							T40_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
							nimZeroMem((void*)T41_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
							T41_[0] = rdLoc__cgen_435((*d));
							T41_[1] = rdSetElemLoc__cgen_17717((*(*(*p).module).g).config, a, (*e).typ);
							T42_ = NIM_NIL;
							T42_ = percent___cgen_24095(T41_, 2);
							T43_ = NIM_NIL;
							T43_ = indentLine__cgen_286(p, T42_);
							add__ropes_159(T40_, T43_);
						}
						LA30_: ;
						i += ((NI) 1);
					} LA29: ;
				}
			}
		}
		goto LA11_;
		LA14_: ;
		{
			NimStringDesc* ts;
			NimStringDesc* T45_;
			NI64 T46_;
			NimStringDesc* T47_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T48_;
			tyArray__ts9cf9blICas1QWmw89bglZ7w T49_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T50_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T51_;
			T45_ = NIM_NIL;
			T46_ = (NI64)0;
			T46_ = getSize__types_3388((*(*(*p).module).g).config, (*e).typ);
			T47_ = NIM_NIL;
			T47_ = dollar___systemZdollars_6((NI64)(T46_ * IL64(8)));
			T45_ = rawNewString((T47_ ? T47_->Sup.len : 0) + 2);
appendString(T45_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_349));
appendString(T45_, T47_);
			ts = T45_;
			T48_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T48_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			nimZeroMem((void*)T49_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T49_[0] = rdLoc__cgen_435((*d));
			T50_ = NIM_NIL;
			T50_ = percent___cgen_24101(T49_, 1);
			T51_ = NIM_NIL;
			T51_ = indentLine__cgen_286(p, T50_);
			add__ropes_159(T48_, T51_);
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** it_2;
				tySequence__IeU9azYSNIK3V9b36Ir6NZcw* colontmp__2;
				NI i_2;
				NI L_2;
				NI T53_;
				it_2 = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
				colontmp__2 = NIM_NIL;
				colontmp__2 = (*e)._kind_6.sons;
				i_2 = ((NI) 0);
				T53_ = (colontmp__2 ? colontmp__2->Sup.len : 0);
				L_2 = T53_;
				{
					while (1) {
						if (!(i_2 < L_2)) goto LA55;
						it_2 = &colontmp__2->data[i_2];
						{
							tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T60_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T61_;
							tyArray__XSZGJHCjWme3CUmFzckT3g T62_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T63_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T64_;
							if (!((*(*it_2)).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 44))) goto LA58_;
							T60_ = NIM_NIL;
							T60_ = getSysType__magicsys_60((*(*(*p).module).g).graph, unknownLineInfo__lineinfos_284, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31));
							getTemp__cgen_7373(p, T60_, (&idx), NIM_FALSE);
							initLocExpr__cgen_11548(p, (*(*it_2))._kind_6.sons->data[((NI) 0)], (&a));
							initLocExpr__cgen_11548(p, (*(*it_2))._kind_6.sons->data[((NI) 1)], (&b));
							T61_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
							T61_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
							nimZeroMem((void*)T62_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
							T62_[0] = rdLoc__cgen_435(idx);
							T62_[1] = rdLoc__cgen_435((*d));
							T62_[2] = rdSetElemLoc__cgen_17717((*(*(*p).module).g).config, a, (*e).typ);
							T62_[3] = rdSetElemLoc__cgen_17717((*(*(*p).module).g).config, b, (*e).typ);
							T62_[4] = rope__ropes_109(ts);
							T63_ = NIM_NIL;
							T63_ = percent___cgen_24116(T62_, 5);
							T64_ = NIM_NIL;
							T64_ = indentLine__cgen_286(p, T63_);
							add__ropes_159(T61_, T64_);
						}
						goto LA56_;
						LA58_: ;
						{
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T66_;
							tyArray__FKvM4FDhljtt88k8FkGthA T67_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T68_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T69_;
							initLocExpr__cgen_11548(p, (*it_2), (&a));
							T66_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
							T66_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
							nimZeroMem((void*)T67_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
							T67_[0] = rdLoc__cgen_435((*d));
							T67_[1] = rdSetElemLoc__cgen_17717((*(*(*p).module).g).config, a, (*e).typ);
							T67_[2] = rope__ropes_109(ts);
							T68_ = NIM_NIL;
							T68_ = percent___cgen_24121(T67_, 3);
							T69_ = NIM_NIL;
							T69_ = indentLine__cgen_286(p, T68_);
							add__ropes_159(T66_, T69_);
						}
						LA56_: ;
						i_2 += ((NI) 1);
					} LA55: ;
				}
			}
		}
		LA11_: ;
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, exprComplexConst__cgen_24475)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	NI id;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tmp;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T2_;
	t = (*n).typ;
	T1_ = NIM_NIL;
	T1_ = getTypeDesc__cgen_6662((*p).module, t, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
	(void)(T1_);
	id = nodeTableTestOrSet__treetab_198((&(*(*p).module).dataCache), n, ((NI) ((*(*p).module).labels)));
	T2_ = NIM_NIL;
	T2_ = rope__ropes_115(((NI64) (id)));
	tmp = amp___ropes_128((*(*p).module).tmpBase, T2_);
	{
		tyArray__FKvM4FDhljtt88k8FkGthA T7_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
		if (!(id == ((NI) ((*(*p).module).labels)))) goto LA5_;
		(*(*p).module).labels += ((NI) 1);
		nimZeroMem((void*)T7_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
		T7_[0] = getTypeDesc__cgen_6662((*p).module, t, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 10));
		T7_[1] = tmp;
		T7_[2] = genBracedInit__cgen_13891(p, n, NIM_TRUE, t);
		T8_ = NIM_NIL;
		T8_ = percent___cgen_17917(T7_, 3);
		add__ropes_159(&(*(*p).module).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 9))- 0], T8_);
	}
	LA5_: ;
	{
		if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA11_;
		fillLoc__cgen_71(d, ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 8), n, tmp, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 1));
	}
	goto LA9_;
	LA11_: ;
	{
		putDataIntoDest__cgen_18780(p, d, n, tmp);
		{
			if (!!(((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28)))) goto LA16_;
			(*d).storage = ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 1);
		}
		LA16_: ;
	}
	LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, handleConstExpr__cgen_21182)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T6_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0));
		if (!(T4_)) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__ast_3155(n);
		T4_ = (((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 38)) < T6_);
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA7_;
		T3_ = isDeepConstExpr__trees_171(n, NIM_FALSE);
		LA7_: ;
		if (!T3_) goto LA8_;
		rawConstExpr__cgen_10399(p, n, d);
		result = NIM_TRUE;
	}
	goto LA1_;
	LA8_: ;
	{
		result = NIM_FALSE;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genArrayConstr__cgen_24216)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw arr;
	nimZeroMem((void*)(&arr), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = handleConstExpr__cgen_21182(p, n, d);
		if (!!(T3_)) goto LA4_;
		{
			if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA8_;
			getTemp__cgen_7373(p, (*n).typ, d, NIM_FALSE);
		}
		LA8_: ;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T13_;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T14_;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T15_;
					tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T16_;
					if (!(i_2 < colontmp_)) goto LA12;
					i = i_2;
					T13_ = NIM_NIL;
					T13_ = skipTypes__ast_3723((*n).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
					T14_ = NIM_NIL;
					T14_ = elemType__types_263(T13_);
					T15_ = NIM_NIL;
					T15_ = lodeTyp__cgen_92(T14_);
					initLoc__cgen_66((&arr), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 6), T15_, (*d).storage);
					nimZeroMem((void*)T16_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
					T16_[0] = rdLoc__cgen_435((*d));
					T16_[1] = intLiteral__cgen_11536(((NI64) (i)));
					arr.r = percent___cgen_6805(T16_, 2);
					expr__cgen_11525(p, (*n)._kind_6.sons->data[i], (&arr));
					i_2 += ((NI) 1);
				} LA12: ;
			}
		}
	}
	LA4_: ;
}
static N_INLINE(NIM_BOOL, isRoutine__ast_4677)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((520192 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
	return result;
}
static N_INLINE(NIM_BOOL, isConstClosure__cgen_24159)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
	if (!(T2_)) goto LA3_;
	T2_ = isRoutine__ast_4677((*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23));
	LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genClosure__cgen_24173)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	{
		NIM_BOOL T3_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tmp;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
		tyArray__FKvM4FDhljtt88k8FkGthA T7_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = isConstClosure__cgen_24159(n);
		if (!T3_) goto LA4_;
		(*(*p).module).labels += ((NI) 1);
		T6_ = NIM_NIL;
		T6_ = rope__ropes_115(((NI64) ((*(*p).module).labels)));
		tmp = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_667), T6_);
		nimZeroMem((void*)T7_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
		T7_[0] = getTypeDesc__cgen_6662((*p).module, (*n).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		T7_[1] = tmp;
		T7_[2] = genBracedInit__cgen_13891(p, n, NIM_TRUE, (*n).typ);
		T8_ = NIM_NIL;
		T8_ = percent___cgen_17917(T7_, 3);
		add__ropes_159(&(*(*p).module).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 9))- 0], T8_);
		putIntoDest__cgen_18794(p, d, n, tmp, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 1));
	}
	goto LA1_;
	LA4_: ;
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tmp_2;
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T15_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
		nimZeroMem((void*)(&tmp_2), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548(p, (*n)._kind_6.sons->data[((NI) 0)], (&a));
		initLocExpr__cgen_11548(p, (*n)._kind_6.sons->data[((NI) 1)], (&b));
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T12_;
			T12_ = NIM_NIL;
			T12_ = skipConv__types_3661((*n)._kind_6.sons->data[((NI) 0)]);
			if (!((*T12_).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 155))) goto LA13_;
			internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_668), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_669);
		}
		LA13_: ;
		getTemp__cgen_7373(p, (*n).typ, (&tmp_2), NIM_FALSE);
		T15_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T15_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res = rawNewString(((NI) 80));
		T16_ = NIM_NIL;
		T16_ = rdLoc__cgen_435(tmp_2);
		cgFormatValue__cgen_147((&res), T16_);
		res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_263));
		T17_ = NIM_NIL;
		T17_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res), T17_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_164));
		T18_ = NIM_NIL;
		T18_ = rdLoc__cgen_435(tmp_2);
		cgFormatValue__cgen_147((&res), T18_);
		res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_670));
		T19_ = NIM_NIL;
		T19_ = rdLoc__cgen_435(b);
		cgFormatValue__cgen_147((&res), T19_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA22_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA22_: ;
		T24_ = NIM_NIL;
		T24_ = rope__ropes_109(res);
		T25_ = NIM_NIL;
		T25_ = indentLine__cgen_286(p, T24_);
		add__ropes_159(T15_, T25_);
		putLocIntoDest__cgen_11532(p, d, tmp_2);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genTupleConstr__cgen_24126)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw rec;
	nimZeroMem((void*)(&rec), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	{
		NIM_BOOL T3_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
		T3_ = (NIM_BOOL)0;
		T3_ = handleConstExpr__cgen_21182(p, n, d);
		if (!!(T3_)) goto LA4_;
		t = (*n).typ;
		T6_ = NIM_NIL;
		T6_ = getTypeDesc__cgen_6662((*p).module, t, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		(void)(T6_);
		{
			if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA9_;
			getTemp__cgen_7373(p, t, d, NIM_FALSE);
		}
		LA9_: ;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
					tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T18_;
					if (!(i_2 < colontmp_)) goto LA13;
					i = i_2;
					it = (*n)._kind_6.sons->data[i];
					{
						if (!((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34))) goto LA16_;
						it = (*it)._kind_6.sons->data[((NI) 1)];
					}
					LA16_: ;
					initLoc__cgen_66((&rec), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 6), it, (*d).storage);
					nimZeroMem((void*)T18_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
					T18_[0] = rdLoc__cgen_435((*d));
					T18_[1] = rope__ropes_115(((NI64) (i)));
					rec.r = percent___cgen_13428(T18_, 2);
					rec.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 9)) & 15);
					expr__cgen_11525(p, it, (&rec));
					i_2 += ((NI) 1);
				} LA13: ;
			}
		}
	}
	LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, lookupFieldAgain__cgen_19728)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ty, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** r, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA** resTyp) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ty_2;
	result = NIM_NIL;
	ty_2 = ty;
	{
		while (1) {
			if (!!((ty_2 == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA2;
			ty_2 = skipTypes__ast_3723(ty_2, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_130);
			result = lookupInRecord__astalgo_84((*ty_2).n, (*field).name);
			{
				if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA5_;
				{
					if (!!((resTyp == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA**) NIM_NIL)))) goto LA9_;
					unsureAsgnRef((void**) (&(*resTyp)), ty_2);
				}
				LA9_: ;
				goto LA1;
			}
			LA5_: ;
			{
				NIM_BOOL T13_;
				T13_ = (NIM_BOOL)0;
				T13_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
				if (T13_) goto LA14_;
				T13_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
				LA14_: ;
				if (!!(T13_)) goto LA15_;
				add__ropes_162(r, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_129));
			}
			LA15_: ;
			ty_2 = (*ty_2).sons->data[((NI) 0)];
		} LA2: ;
	} LA1: ;
	{
		if (!(result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA19_;
		internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*field).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_671), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_672);
	}
	LA19_: ;
	return result;
}
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_629)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = toMsgFilename__msgs_612(conf, info.fileIndex);
	result = resizeString(result, (T1_ ? T1_->Sup.len : 0) + 0);
appendString(result, T1_);
	{
		if (!(((NI) 0) < ((NI) (info.line)))) goto LA4_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		addInt__stdZprivateZdigitsutils_189((&result), ((NI) (info.line)));
		{
			if (!(((NI) 0) < (NI)(((NI) (info.col)) + ((NI) 1)))) goto LA8_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			addInt__stdZprivateZdigitsutils_189((&result), (NI)(((NI) (info.col)) + ((NI) 1)));
		}
		LA8_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genFieldCheck__cgen_19830)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* obj, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw test;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw u;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw v;
	nimZeroMem((void*)(&test), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&u), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&v), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(e);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* op;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* disc;
				NimStringDesc* msg;
				NimStringDesc* T14_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* strLit;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T15_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* discIndex;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T29_;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				it = (*e)._kind_6.sons->data[i];
				op = (*(*it)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
				{
					if (!((*op).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 96))) goto LA6_;
					it = (*it)._kind_6.sons->data[((NI) 1)];
				}
				LA6_: ;
				disc = skipConv__types_3661((*it)._kind_6.sons->data[((NI) 2)]);
				initLoc__cgen_66((&test), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0), it, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 2));
				initLocExpr__cgen_11548(p, (*it)._kind_6.sons->data[((NI) 1)], (&u));
				initLoc__cgen_66((&v), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 6), disc, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
				v.r = obj;
				add__ropes_162(&v.r, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_138));
				add__ropes_159(&v.r, (*(*disc)._kind_4.sym).loc.r);
				genInExprAux__cgen_19824(p, it, (&u), (&v), (&test));
				msg = ((NimStringDesc*) NIM_NIL);
				{
					NimStringDesc* T12_;
					NimStringDesc* T13_;
					if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 36))&63U)))!=0)) goto LA10_;
					T12_ = NIM_NIL;
					T13_ = NIM_NIL;
					T13_ = toFileLineCol__msgs_629((*(*(*p).module).g).config, (*e).info);
					T12_ = rawNewString((T13_ ? T13_->Sup.len : 0) + 1);
appendString(T12_, T13_);
appendString(T12_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_13));
					msg = resizeString(msg, (T12_ ? T12_->Sup.len : 0) + 0);
appendString(msg, T12_);
				}
				LA10_: ;
				T14_ = NIM_NIL;
				T14_ = genFieldDefect__astmsgs_61((*(*(*p).module).g).config, (*(*field).name).s, (*disc)._kind_4.sym);
				msg = resizeString(msg, (T14_ ? T14_->Sup.len : 0) + 0);
appendString(msg, T14_);
				T15_ = NIM_NIL;
				T15_ = newStrNode__ast_3801(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20), msg);
				strLit = genStringLiteral__cgen_626((*p).module, T15_);
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T20_;
					NimStringDesc* res;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T21_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
					if (!((*op).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 96))) goto LA18_;
					T20_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T20_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					res = rawNewString(((NI) 80));
					res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
					T21_ = NIM_NIL;
					T21_ = rdLoc__cgen_435(test);
					cgFormatValue__cgen_147((&res), T21_);
					res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_56));
					T22_ = NIM_NIL;
					T22_ = rope__ropes_109(res);
					T23_ = NIM_NIL;
					T23_ = indentLine__cgen_286(p, T22_);
					add__ropes_159(T20_, T23_);
				}
				goto LA16_;
				LA18_: ;
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T25_;
					NimStringDesc* res_2;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T27_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T28_;
					T25_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T25_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					res_2 = rawNewString(((NI) 80));
					res_2 = resizeString(res_2, 6);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_42));
					T26_ = NIM_NIL;
					T26_ = rdLoc__cgen_435(test);
					cgFormatValue__cgen_147((&res_2), T26_);
					res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_43));
					T27_ = NIM_NIL;
					T27_ = rope__ropes_109(res_2);
					T28_ = NIM_NIL;
					T28_ = indentLine__cgen_286(p, T27_);
					add__ropes_159(T25_, T28_);
				}
				LA16_: ;
				T29_ = NIM_NIL;
				T29_ = t__cgen_85(u);
				discIndex = rdSetElemLoc__cgen_17717((*(*(*p).module).g).config, v, T29_);
				{
					if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 41))&63U)))!=0)) goto LA32_;
					{
						tyTuple__47w2DboNEPf69aPgubZdd7Q T36_;
						NIM_BOOL T37_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T40_;
						NimStringDesc* res_3;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T41_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T42_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T47_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T48_;
						T36_ = getStdlibVersion__options_3920((*(*(*p).module).g).config);
						T37_ = (NIM_BOOL)0;
						T37_ = lt___cgen_19915(T36_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_675);
						if (!T37_) goto LA38_;
						T40_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
						T40_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
						res_3 = rawNewString(((NI) 80));
						res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_676));
						T41_ = NIM_NIL;
						T41_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_677));
						cgFormatValue__cgen_147((&res_3), T41_);
						res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
						cgFormatValue__cgen_147((&res_3), strLit);
						res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_437));
						T42_ = NIM_NIL;
						T42_ = raiseInstr__cgen_424(p);
						cgFormatValue__cgen_147((&res_3), T42_);
						res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_227));
						{
							if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA45_;
							res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
						}
						LA45_: ;
						T47_ = NIM_NIL;
						T47_ = rope__ropes_109(res_3);
						T48_ = NIM_NIL;
						T48_ = indentLine__cgen_286(p, T47_);
						add__ropes_159(T40_, T48_);
					}
					goto LA34_;
					LA38_: ;
					{
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T50_;
						NimStringDesc* res_4;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T51_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T52_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T57_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T58_;
						T50_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
						T50_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
						res_4 = rawNewString(((NI) 80));
						res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_676));
						T51_ = NIM_NIL;
						T51_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_678));
						cgFormatValue__cgen_147((&res_4), T51_);
						res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
						cgFormatValue__cgen_147((&res_4), strLit);
						res_4 = resizeString(res_4, 6);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_679));
						cgFormatValue__cgen_147((&res_4), discIndex);
						res_4 = resizeString(res_4, 3);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_437));
						T52_ = NIM_NIL;
						T52_ = raiseInstr__cgen_424(p);
						cgFormatValue__cgen_147((&res_4), T52_);
						res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_227));
						{
							if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA55_;
							res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
						}
						LA55_: ;
						T57_ = NIM_NIL;
						T57_ = rope__ropes_109(res_4);
						T58_ = NIM_NIL;
						T58_ = indentLine__cgen_286(p, T57_);
						add__ropes_159(T50_, T58_);
					}
					LA34_: ;
				}
				goto LA30_;
				LA32_: ;
				{
					tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ first;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* firstLit;
					union { tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ source; NI dest; } LOC60;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* discName;
					first = firstOrd__types_1406((*(*(*p).module).g).config, (*(*disc)._kind_4.sym).typ);
					LOC60.source = first;
					firstLit = int64Literal__cgen_17721(((NI64) (LOC60.dest)));
					discName = genTypeInfo__cgen_10314((*(*(*p).module).g).config, (*p).module, (*(*disc)._kind_4.sym).typ, (*e).info);
					{
						tyTuple__47w2DboNEPf69aPgubZdd7Q T63_;
						NIM_BOOL T64_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T67_;
						NimStringDesc* res_5;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T68_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T69_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T74_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T75_;
						T63_ = getStdlibVersion__options_3920((*(*(*p).module).g).config);
						T64_ = (NIM_BOOL)0;
						T64_ = lt___cgen_19915(T63_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_675);
						if (!T64_) goto LA65_;
						T67_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
						T67_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
						res_5 = rawNewString(((NI) 80));
						res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_676));
						T68_ = NIM_NIL;
						T68_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_677));
						cgFormatValue__cgen_147((&res_5), T68_);
						res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
						cgFormatValue__cgen_147((&res_5), strLit);
						res_5 = resizeString(res_5, 3);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_437));
						T69_ = NIM_NIL;
						T69_ = raiseInstr__cgen_424(p);
						cgFormatValue__cgen_147((&res_5), T69_);
						res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_227));
						{
							if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA72_;
							res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
						}
						LA72_: ;
						T74_ = NIM_NIL;
						T74_ = rope__ropes_109(res_5);
						T75_ = NIM_NIL;
						T75_ = indentLine__cgen_286(p, T74_);
						add__ropes_159(T67_, T75_);
					}
					goto LA61_;
					LA65_: ;
					{
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T77_;
						NimStringDesc* res_6;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T78_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T79_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T80_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T85_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T86_;
						T77_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
						T77_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
						res_6 = rawNewString(((NI) 80));
						res_6 = resizeString(res_6, 2);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_676));
						T78_ = NIM_NIL;
						T78_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_678));
						cgFormatValue__cgen_147((&res_6), T78_);
						res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
						cgFormatValue__cgen_147((&res_6), strLit);
						res_6 = resizeString(res_6, 2);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
						T79_ = NIM_NIL;
						T79_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_680));
						cgFormatValue__cgen_147((&res_6), T79_);
						res_6 = resizeString(res_6, 6);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_681));
						cgFormatValue__cgen_147((&res_6), discIndex);
						res_6 = resizeString(res_6, 8);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_682));
						cgFormatValue__cgen_147((&res_6), firstLit);
						res_6 = resizeString(res_6, 2);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
						cgFormatValue__cgen_147((&res_6), discName);
						res_6 = resizeString(res_6, 4);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_683));
						T80_ = NIM_NIL;
						T80_ = raiseInstr__cgen_424(p);
						cgFormatValue__cgen_147((&res_6), T80_);
						res_6 = resizeString(res_6, 2);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_227));
						{
							if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA83_;
							res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
						}
						LA83_: ;
						T85_ = NIM_NIL;
						T85_ = rope__ropes_109(res_6);
						T86_ = NIM_NIL;
						T86_ = indentLine__cgen_286(p, T85_);
						add__ropes_159(T77_, T86_);
					}
					LA61_: ;
				}
				LA30_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genObjConstr__cgen_10395)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	NIM_BOOL isRef;
	NIM_BOOL useTemp;
	NIM_BOOL T14_;
	NIM_BOOL T15_;
	tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA T18_;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tmp;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T31_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ty;
{	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
		if (T4_) goto LA5_;
		T4_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
		LA5_: ;
		T3_ = !(T4_);
		if (!(T3_)) goto LA6_;
		T3_ = !((((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0));
		LA6_: ;
		if (!T3_) goto LA7_;
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = handleConstExpr__cgen_21182(p, e, d);
			if (!T11_) goto LA12_;
			goto BeforeRet_;
		}
		LA12_: ;
	}
	LA7_: ;
	t = skipTypes__ast_3723((*e).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_155);
	isRef = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22));
	T14_ = (NIM_BOOL)0;
	T15_ = (NIM_BOOL)0;
	T15_ = isRef;
	if (T15_) goto LA16_;
	T15_ = !(((62 &((NU16)1<<((NU)((*d).k)&15U)))!=0));
	LA16_: ;
	T14_ = T15_;
	if (T14_) goto LA17_;
	T18_ = (tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA)0;
	T18_ = isPartOf__aliases_129((*d).lode, e);
	T14_ = !((T18_ == ((tyEnum_TAnalysisResult__e4ifdKCCVVqwIObVZzYzMA) 0)));
	LA17_: ;
	useTemp = T14_;
	nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	r = NIM_NIL;
	{
		if (!useTemp) goto LA21_;
		getTemp__cgen_7373(p, t, (&tmp), NIM_FALSE);
		r = rdLoc__cgen_435(tmp);
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T27_;
			tyArray__ts9cf9blICas1QWmw89bglZ7w T28_;
			if (!isRef) goto LA25_;
			rawGenNew__cgen_20825(p, (&tmp), ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL), !((((*e).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg) 1))&31U)))!=0)));
			T27_ = NIM_NIL;
			T27_ = lastSon__ast_3731(t);
			t = skipTypes__ast_3723(T27_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_155);
			nimZeroMem((void*)T28_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T28_[0] = r;
			r = percent___cgen_442(T28_, 1);
			gcUsage__cgen_20553((*(*(*p).module).g).config, e);
		}
		goto LA23_;
		LA25_: ;
		{
			constructLoc__cgen_10987(p, (&tmp), NIM_FALSE);
		}
		LA23_: ;
	}
	goto LA19_;
	LA21_: ;
	{
		resetLoc__cgen_10897(p, d);
		r = rdLoc__cgen_435((*d));
	}
	LA19_: ;
	T31_ = NIM_NIL;
	T31_ = getTypeDesc__cgen_6662((*p).module, t, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
	(void)(T31_);
	ty = t;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(e);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tmp2;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field;
				if (!(i_2 < colontmp_)) goto LA34;
				i = i_2;
				it = (*e)._kind_6.sons->data[i];
				nimZeroMem((void*)(&tmp2), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				tmp2.r = r;
				field = lookupFieldAgain__cgen_19728(p, ty, (*(*it)._kind_6.sons->data[((NI) 0)])._kind_4.sym, &tmp2.r, ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA**) NIM_NIL));
				{
					if (!((*field).loc.r == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA37_;
					fillObjectFields__cgen_3808((*p).module, ty);
				}
				LA37_: ;
				{
					if (!((*field).loc.r == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA41_;
					internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*e).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_673), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_674);
				}
				LA41_: ;
				{
					NIM_BOOL T45_;
					NI T46_;
					T45_ = (NIM_BOOL)0;
					T46_ = (NI)0;
					T46_ = len__ast_3155(it);
					T45_ = (T46_ == ((NI) 3));
					if (!(T45_)) goto LA47_;
					T45_ = (((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 2))&31U)))!=0);
					LA47_: ;
					if (!T45_) goto LA48_;
					genFieldCheck__cgen_19830(p, (*it)._kind_6.sons->data[((NI) 2)], r, field);
				}
				LA48_: ;
				add__ropes_162(&tmp2.r, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_138));
				add__ropes_159(&tmp2.r, (*field).loc.r);
				{
					if (!useTemp) goto LA52_;
					tmp2.k = ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 1);
					{
						if (!isRef) goto LA56_;
						tmp2.storage = ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 3);
					}
					goto LA54_;
					LA56_: ;
					{
						tmp2.storage = ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 2);
					}
					LA54_: ;
				}
				goto LA50_;
				LA52_: ;
				{
					tmp2.k = (*d).k;
					{
						if (!isRef) goto LA62_;
						tmp2.storage = ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 3);
					}
					goto LA60_;
					LA62_: ;
					{
						tmp2.storage = (*d).storage;
					}
					LA60_: ;
				}
				LA50_: ;
				tmp2.lode = (*it)._kind_6.sons->data[((NI) 1)];
				expr__cgen_11525(p, (*it)._kind_6.sons->data[((NI) 1)], (&tmp2));
				i_2 += ((NI) 1);
			} LA34: ;
		}
	}
	{
		if (!useTemp) goto LA67_;
		{
			if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA71_;
			genericAssign((void*)(&(*d)), (void*)(&tmp), (&NTItloc__CAJV4zTUpZwr0j6Wy8FiFw_));
		}
		goto LA69_;
		LA71_: ;
		{
			genAssignment__cgen_10403(p, (*d), tmp, 0);
		}
		LA69_: ;
	}
	LA67_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCast__cgen_22997)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* destt;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* srct;
	destt = skipTypes__ast_3723((*e).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_430);
	srct = skipTypes__ast_3723((*(*e)._kind_6.sons->data[((NI) 1)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_430);
	{
		NIM_BOOL T3_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* lbl;
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tmp;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T7_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T8_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T17_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*destt).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36) && (*destt).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 39) || (*destt).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18) || (*destt).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17) || (*destt).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16));
		if (T3_) goto LA4_;
		T3_ = ((*srct).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36) && (*srct).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 39) || (*srct).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18) || (*srct).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17) || (*srct).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16));
		LA4_: ;
		if (!T3_) goto LA5_;
		(*p).labels += ((NI) 1);
		lbl = rope__ropes_115(((NI64) ((*p).labels)));
		nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		nimZeroMem((void*)T7_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T7_[0] = lbl;
		tmp.r = percent___cgen_23019(T7_, 1);
		T8_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T8_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 8);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_684));
		T9_ = NIM_NIL;
		T9_ = getTypeDesc__cgen_6662((*p).module, (*(*e)._kind_6.sons->data[((NI) 1)]).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		cgFormatValue__cgen_147((&res), T9_);
		res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_685));
		T10_ = NIM_NIL;
		T10_ = getTypeDesc__cgen_6662((*p).module, (*e).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		cgFormatValue__cgen_147((&res), T10_);
		res = resizeString(res, 12);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_686));
		cgFormatValue__cgen_147((&res), lbl);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA13_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA13_: ;
		T15_ = NIM_NIL;
		T15_ = rope__ropes_109(res);
		T16_ = NIM_NIL;
		T16_ = indentLine__cgen_286(p, T15_);
		add__ropes_159(T8_, T16_);
		tmp.k = ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 6);
		tmp.lode = lodeTyp__cgen_92(srct);
		tmp.storage = ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 2);
		tmp.flags = 0;
		expr__cgen_11525(p, (*e)._kind_6.sons->data[((NI) 1)], (&tmp));
		nimZeroMem((void*)T17_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T17_[0] = lbl;
		T18_ = NIM_NIL;
		T18_ = percent___cgen_23039(T17_, 1);
		putIntoDest__cgen_18794(p, d, e, T18_, tmp.storage);
	}
	goto LA1_;
	LA5_: ;
	{
		genSomeCast__cgen_22901(p, e, d);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genConv__cgen_23118)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* destType;
	destType = skipTypes__ast_3723((*e).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_687);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = sameBackendType__types_689(destType, (*(*e)._kind_6.sons->data[((NI) 1)]).typ);
		if (!T3_) goto LA4_;
		expr__cgen_11525(p, (*e)._kind_6.sons->data[((NI) 1)], d);
	}
	goto LA1_;
	LA4_: ;
	{
		genSomeCast__cgen_22901(p, e, d);
	}
	LA1_: ;
}
static N_INLINE(NIM_BOOL, isCppRef__cgen_19443)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NIM_BOOL T3_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T6_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T8_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
	if (T3_) goto LA4_;
	T3_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
	LA4_: ;
	T2_ = T3_;
	if (!(T2_)) goto LA5_;
	T6_ = NIM_NIL;
	T6_ = skipTypes__ast_3723(typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_155);
	T2_ = ((*T6_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23));
	LA5_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA7_;
	T8_ = NIM_NIL;
	T8_ = skipTypes__ast_3723(typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_155);
	T1_ = !((((*T8_).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 20))&63U)))!=0));
	LA7_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genAddr__cgen_19655)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T3_;
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
		T3_ = NIM_NIL;
		T3_ = skipTypes__ast_3723((*(*e)._kind_6.sons->data[((NI) 0)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_155);
		if (!((*T3_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22) || (*T3_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21))) goto LA4_;
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 0)], (&a));
		T6_ = NIM_NIL;
		T6_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_358), a.r);
		putIntoDest__cgen_18794(p, d, e, T6_, a.storage);
	}
	goto LA1_;
	LA4_: ;
	{
		NIM_BOOL T8_;
		tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw T9_;
		tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ T15_;
		T8_ = (NIM_BOOL)0;
		T9_ = (tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw)0;
		{
			if (!((*(*e)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA12_;
			T9_ = (*(*(*e)._kind_6.sons->data[((NI) 0)])._kind_4.sym).kind;
		}
		goto LA10_;
		LA12_: ;
		{
			T9_ = ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8);
		}
		LA10_: ;
		T15_ = (tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ)0;
		T15_ = mapType__cgen_1227((*(*(*p).module).g).config, (*(*e)._kind_6.sons->data[((NI) 0)]).typ, T9_);
		T8_ = (T15_ == ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 17));
		if (T8_) goto LA16_;
		T8_ = isCppRef__cgen_19443(p, (*e).typ);
		LA16_: ;
		if (!T8_) goto LA17_;
		expr__cgen_11525(p, (*e)._kind_6.sons->data[((NI) 0)], d);
	}
	goto LA1_;
	LA17_: ;
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
		nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 0)], (&a_2));
		T20_ = NIM_NIL;
		T20_ = addrLoc__cgen_10337((*(*(*p).module).g).config, a_2);
		putIntoDest__cgen_18794(p, d, e, T20_, a_2.storage);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genUncheckedArrayElem__cgen_20050)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* y, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
	NimStringDesc* res;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, x, (&a));
	initLocExpr__cgen_11548(p, y, (&b));
	{
		if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA3_;
		(*d).storage = a.storage;
	}
	LA3_: ;
	res = rawNewString(((NI) 80));
	T5_ = NIM_NIL;
	T5_ = rdLoc__cgen_435(a);
	cgFormatValue__cgen_147((&res), T5_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_166));
	T6_ = NIM_NIL;
	T6_ = rdCharLoc__cgen_10377(b);
	cgFormatValue__cgen_147((&res), T6_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_167));
	T7_ = NIM_NIL;
	T7_ = rope__ropes_109(res);
	putIntoDest__cgen_18794(p, d, n, T7_, a.storage);
}
N_LIB_PRIVATE N_NIMCALL(void, genArrayElem__cgen_20071)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* y, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ty;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* first;
	tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T2_;
	NimStringDesc* res_3;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T94_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T95_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T96_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, x, (&a));
	initLocExpr__cgen_11548(p, y, (&b));
	T1_ = NIM_NIL;
	T1_ = t__cgen_85(a);
	ty = skipTypes__ast_3723(T1_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_689);
	T2_ = firstOrd__types_1406((*(*(*p).module).g).config, ty);
	first = intLiteral__cgen_17773(T2_);
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = (((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 4))&31U)))!=0);
		if (!(T5_)) goto LA6_;
		T5_ = !(((*ty).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 49)));
		LA6_: ;
		if (!T5_) goto LA7_;
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = isConstExpr__trees_146(y);
			if (!!(T11_)) goto LA12_;
			{
				NIM_BOOL T16_;
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T17_;
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T19_;
				T16_ = (NIM_BOOL)0;
				T17_ = firstOrd__types_1406((*(*(*p).module).g).config, ty);
				T16_ = eqeq___int495056_952(T17_, IL64(0));
				if (!(T16_)) goto LA18_;
				T19_ = lastOrd__types_1532((*(*(*p).module).g).config, ty);
				T16_ = lteq___int495056_945(IL64(0), T19_);
				LA18_: ;
				if (!T16_) goto LA20_;
				{
					NIM_BOOL T24_;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T25_;
					tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T26_;
					tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T27_;
					tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T29_;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T30_;
					tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T31_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T34_;
					NimStringDesc* res;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T35_;
					tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T36_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T37_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T39_;
					tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T40_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T41_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T42_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T47_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T48_;
					T24_ = (NIM_BOOL)0;
					T25_ = NIM_NIL;
					T25_ = t__cgen_85(b);
					T26_ = firstOrd__types_1406((*(*(*p).module).g).config, T25_);
					T27_ = firstOrd__types_1406((*(*(*p).module).g).config, ty);
					T24_ = lt___int495056_417(T26_, T27_);
					if (T24_) goto LA28_;
					T29_ = lastOrd__types_1532((*(*(*p).module).g).config, ty);
					T30_ = NIM_NIL;
					T30_ = t__cgen_85(b);
					T31_ = lastOrd__types_1532((*(*(*p).module).g).config, T30_);
					T24_ = lt___int495056_417(T29_, T31_);
					LA28_: ;
					if (!T24_) goto LA32_;
					T34_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T34_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					res = rawNewString(((NI) 80));
					res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_690));
					T35_ = NIM_NIL;
					T35_ = rdCharLoc__cgen_10377(b);
					cgFormatValue__cgen_147((&res), T35_);
					res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_691));
					T36_ = lastOrd__types_1532((*(*(*p).module).g).config, ty);
					T37_ = NIM_NIL;
					T37_ = intLiteral__cgen_17773(T36_);
					cgFormatValue__cgen_147((&res), T37_);
					res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_434));
					T38_ = NIM_NIL;
					T38_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_692));
					cgFormatValue__cgen_147((&res), T38_);
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
					T39_ = NIM_NIL;
					T39_ = rdCharLoc__cgen_10377(b);
					cgFormatValue__cgen_147((&res), T39_);
					res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
					T40_ = lastOrd__types_1532((*(*(*p).module).g).config, ty);
					T41_ = NIM_NIL;
					T41_ = intLiteral__cgen_17773(T40_);
					cgFormatValue__cgen_147((&res), T41_);
					res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_437));
					T42_ = NIM_NIL;
					T42_ = raiseInstr__cgen_424(p);
					cgFormatValue__cgen_147((&res), T42_);
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA45_;
						res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
					}
					LA45_: ;
					T47_ = NIM_NIL;
					T47_ = rope__ropes_109(res);
					T48_ = NIM_NIL;
					T48_ = indentLine__cgen_286(p, T47_);
					add__ropes_159(T34_, T48_);
				}
				LA32_: ;
			}
			goto LA14_;
			LA20_: ;
			{
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T50_;
				NimStringDesc* res_2;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T51_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T52_;
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T53_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T54_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T55_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T56_;
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T57_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T58_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T59_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T64_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T65_;
				T50_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T50_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_2 = rawNewString(((NI) 80));
				res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
				T51_ = NIM_NIL;
				T51_ = rdCharLoc__cgen_10377(b);
				cgFormatValue__cgen_147((&res_2), T51_);
				res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_163));
				cgFormatValue__cgen_147((&res_2), first);
				res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_432));
				T52_ = NIM_NIL;
				T52_ = rdCharLoc__cgen_10377(b);
				cgFormatValue__cgen_147((&res_2), T52_);
				res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_433));
				T53_ = lastOrd__types_1532((*(*(*p).module).g).config, ty);
				T54_ = NIM_NIL;
				T54_ = intLiteral__cgen_17773(T53_);
				cgFormatValue__cgen_147((&res_2), T54_);
				res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_468));
				T55_ = NIM_NIL;
				T55_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_693));
				cgFormatValue__cgen_147((&res_2), T55_);
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
				T56_ = NIM_NIL;
				T56_ = rdCharLoc__cgen_10377(b);
				cgFormatValue__cgen_147((&res_2), T56_);
				res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
				cgFormatValue__cgen_147((&res_2), first);
				res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
				T57_ = lastOrd__types_1532((*(*(*p).module).g).config, ty);
				T58_ = NIM_NIL;
				T58_ = intLiteral__cgen_17773(T57_);
				cgFormatValue__cgen_147((&res_2), T58_);
				res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_437));
				T59_ = NIM_NIL;
				T59_ = raiseInstr__cgen_424(p);
				cgFormatValue__cgen_147((&res_2), T59_);
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA62_;
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA62_: ;
				T64_ = NIM_NIL;
				T64_ = rope__ropes_109(res_2);
				T65_ = NIM_NIL;
				T65_ = indentLine__cgen_286(p, T64_);
				add__ropes_159(T50_, T65_);
			}
			LA14_: ;
		}
		goto LA9_;
		LA12_: ;
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ idx;
			idx = getOrdValue__types_161(y, Max__int495056_27);
			{
				NIM_BOOL T69_;
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T70_;
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T72_;
				NimStringDesc* T75_;
				T69_ = (NIM_BOOL)0;
				T70_ = firstOrd__types_1406((*(*(*p).module).g).config, ty);
				T69_ = lt___int495056_417(idx, T70_);
				if (T69_) goto LA71_;
				T72_ = lastOrd__types_1532((*(*(*p).module).g).config, ty);
				T69_ = lt___int495056_417(T72_, idx);
				LA71_: ;
				if (!T69_) goto LA73_;
				T75_ = NIM_NIL;
				{
					tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T78_;
					tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T79_;
					NIM_BOOL T80_;
					T78_ = lastOrd__types_1532((*(*(*p).module).g).config, ty);
					T79_ = firstOrd__types_1406((*(*(*p).module).g).config, ty);
					T80_ = (NIM_BOOL)0;
					T80_ = lt___int495056_417(T78_, T79_);
					if (!T80_) goto LA81_;
					T75_ = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_694));
				}
				goto LA76_;
				LA81_: ;
				{
					NimStringDesc* T84_;
					NimStringDesc* T85_;
					tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T86_;
					NimStringDesc* T87_;
					tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T88_;
					NimStringDesc* T89_;
					T84_ = NIM_NIL;
					T85_ = NIM_NIL;
					T85_ = dollar___int495056_53(idx);
					T86_ = firstOrd__types_1406((*(*(*p).module).g).config, ty);
					T87_ = NIM_NIL;
					T87_ = dollar___int495056_53(T86_);
					T88_ = lastOrd__types_1532((*(*(*p).module).g).config, ty);
					T89_ = NIM_NIL;
					T89_ = dollar___int495056_53(T88_);
					T84_ = rawNewString((T85_ ? T85_->Sup.len : 0) + (T87_ ? T87_->Sup.len : 0) + (T89_ ? T89_->Sup.len : 0) + 18);
appendString(T84_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_695));
appendString(T84_, T85_);
appendString(T84_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_696));
appendString(T84_, T87_);
appendString(T84_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_697));
appendString(T84_, T89_);
					T75_ = T84_;
				}
				LA76_: ;
				liMessage__msgs_1128((*(*(*p).module).g).config, (*x).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T75_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_698, NIM_FALSE);
			}
			LA73_: ;
		}
		LA9_: ;
	}
	LA7_: ;
	{
		if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA92_;
		(*d).storage = a.storage;
	}
	LA92_: ;
	res_3 = rawNewString(((NI) 80));
	T94_ = NIM_NIL;
	T94_ = rdLoc__cgen_435(a);
	cgFormatValue__cgen_147((&res_3), T94_);
	res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_699));
	T95_ = NIM_NIL;
	T95_ = rdCharLoc__cgen_10377(b);
	cgFormatValue__cgen_147((&res_3), T95_);
	res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_700));
	cgFormatValue__cgen_147((&res_3), first);
	res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_167));
	T96_ = NIM_NIL;
	T96_ = rope__ropes_109(res_3);
	putIntoDest__cgen_18794(p, d, n, T96_, a.storage);
}
N_LIB_PRIVATE N_NIMCALL(void, genOpenArrayElem__cgen_20218)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* y, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, x, (&a));
	initLocExpr__cgen_11548(p, y, (&b));
	{
		NIM_BOOL T3_;
		NimStringDesc* res_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T28_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T29_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T30_;
		T3_ = (NIM_BOOL)0;
		T3_ = reifiedOpenArray__cgen_11825(x);
		if (!!(T3_)) goto LA4_;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T10_;
			NimStringDesc* res;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
			if (!(((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 4))&31U)))!=0)) goto LA8_;
			T10_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T10_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res = rawNewString(((NI) 80));
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
			T11_ = NIM_NIL;
			T11_ = rdCharLoc__cgen_10377(b);
			cgFormatValue__cgen_147((&res), T11_);
			res = resizeString(res, 8);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_418));
			T12_ = NIM_NIL;
			T12_ = rdCharLoc__cgen_10377(b);
			cgFormatValue__cgen_147((&res), T12_);
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_419));
			T13_ = NIM_NIL;
			T13_ = rdLoc__cgen_435(a);
			cgFormatValue__cgen_147((&res), T13_);
			res = resizeString(res, 8);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_701));
			T14_ = NIM_NIL;
			T14_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_692));
			cgFormatValue__cgen_147((&res), T14_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T15_ = NIM_NIL;
			T15_ = rdCharLoc__cgen_10377(b);
			cgFormatValue__cgen_147((&res), T15_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_702));
			T16_ = NIM_NIL;
			T16_ = rdLoc__cgen_435(a);
			cgFormatValue__cgen_147((&res), T16_);
			res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_703));
			T17_ = NIM_NIL;
			T17_ = raiseInstr__cgen_424(p);
			cgFormatValue__cgen_147((&res), T17_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA20_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA20_: ;
			T22_ = NIM_NIL;
			T22_ = rope__ropes_109(res);
			T23_ = NIM_NIL;
			T23_ = indentLine__cgen_286(p, T22_);
			add__ropes_159(T10_, T23_);
		}
		LA8_: ;
		{
			if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA26_;
			(*d).storage = a.storage;
		}
		LA26_: ;
		res_2 = rawNewString(((NI) 80));
		T28_ = NIM_NIL;
		T28_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res_2), T28_);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_166));
		T29_ = NIM_NIL;
		T29_ = rdCharLoc__cgen_10377(b);
		cgFormatValue__cgen_147((&res_2), T29_);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_167));
		T30_ = NIM_NIL;
		T30_ = rope__ropes_109(res_2);
		putIntoDest__cgen_18794(p, d, n, T30_, a.storage);
	}
	goto LA1_;
	LA4_: ;
	{
		NimStringDesc* res_4;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T54_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T55_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T56_;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T36_;
			NimStringDesc* res_3;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T37_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T39_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T40_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T41_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T42_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T43_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T48_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T49_;
			if (!(((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 4))&31U)))!=0)) goto LA34_;
			T36_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T36_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_3 = rawNewString(((NI) 80));
			res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
			T37_ = NIM_NIL;
			T37_ = rdCharLoc__cgen_10377(b);
			cgFormatValue__cgen_147((&res_3), T37_);
			res_3 = resizeString(res_3, 8);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_418));
			T38_ = NIM_NIL;
			T38_ = rdCharLoc__cgen_10377(b);
			cgFormatValue__cgen_147((&res_3), T38_);
			res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_419));
			T39_ = NIM_NIL;
			T39_ = rdLoc__cgen_435(a);
			cgFormatValue__cgen_147((&res_3), T39_);
			res_3 = resizeString(res_3, 10);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_704));
			T40_ = NIM_NIL;
			T40_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_692));
			cgFormatValue__cgen_147((&res_3), T40_);
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T41_ = NIM_NIL;
			T41_ = rdCharLoc__cgen_10377(b);
			cgFormatValue__cgen_147((&res_3), T41_);
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_702));
			T42_ = NIM_NIL;
			T42_ = rdLoc__cgen_435(a);
			cgFormatValue__cgen_147((&res_3), T42_);
			res_3 = resizeString(res_3, 12);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_705));
			T43_ = NIM_NIL;
			T43_ = raiseInstr__cgen_424(p);
			cgFormatValue__cgen_147((&res_3), T43_);
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA46_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA46_: ;
			T48_ = NIM_NIL;
			T48_ = rope__ropes_109(res_3);
			T49_ = NIM_NIL;
			T49_ = indentLine__cgen_286(p, T48_);
			add__ropes_159(T36_, T49_);
		}
		LA34_: ;
		{
			if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA52_;
			(*d).storage = a.storage;
		}
		LA52_: ;
		res_4 = rawNewString(((NI) 80));
		T54_ = NIM_NIL;
		T54_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res_4), T54_);
		res_4 = resizeString(res_4, 8);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_706));
		T55_ = NIM_NIL;
		T55_ = rdCharLoc__cgen_10377(b);
		cgFormatValue__cgen_147((&res_4), T55_);
		res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_167));
		T56_ = NIM_NIL;
		T56_ = rope__ropes_109(res_4);
		putIntoDest__cgen_18794(p, d, n, T56_, a.storage);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSeqElem__cgen_20286)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* y, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ty;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1_;
	NimStringDesc* res_4;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T52_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T53_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T54_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T55_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, x, (&a));
	initLocExpr__cgen_11548(p, y, (&b));
	T1_ = NIM_NIL;
	T1_ = t__cgen_85(a);
	ty = skipTypes__ast_3723(T1_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_183);
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T6_;
		if (!((*ty).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22) || (*ty).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21))) goto LA4_;
		T6_ = NIM_NIL;
		T6_ = lastSon__ast_3731(ty);
		ty = skipTypes__ast_3723(T6_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_183);
	}
	LA4_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T11_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
		if (!(((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 4))&31U)))!=0)) goto LA9_;
		T11_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T11_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
		T12_ = NIM_NIL;
		T12_ = rdCharLoc__cgen_10377(b);
		cgFormatValue__cgen_147((&res), T12_);
		res = resizeString(res, 8);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_418));
		T13_ = NIM_NIL;
		T13_ = rdCharLoc__cgen_10377(b);
		cgFormatValue__cgen_147((&res), T13_);
		res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_419));
		T14_ = NIM_NIL;
		T14_ = lenExpr__cgen_458(p, a);
		cgFormatValue__cgen_147((&res), T14_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_468));
		T15_ = NIM_NIL;
		T15_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_692));
		cgFormatValue__cgen_147((&res), T15_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T16_ = NIM_NIL;
		T16_ = rdCharLoc__cgen_10377(b);
		cgFormatValue__cgen_147((&res), T16_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_702));
		T17_ = NIM_NIL;
		T17_ = lenExpr__cgen_458(p, a);
		cgFormatValue__cgen_147((&res), T17_);
		res = resizeString(res, 5);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_707));
		T18_ = NIM_NIL;
		T18_ = raiseInstr__cgen_424(p);
		cgFormatValue__cgen_147((&res), T18_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA21_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA21_: ;
		T23_ = NIM_NIL;
		T23_ = rope__ropes_109(res);
		T24_ = NIM_NIL;
		T24_ = indentLine__cgen_286(p, T23_);
		add__ropes_159(T11_, T24_);
	}
	LA9_: ;
	{
		if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA27_;
		(*d).storage = ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 3);
	}
	LA27_: ;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T31_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T32_;
		NimStringDesc* res_2;
		T31_ = NIM_NIL;
		T31_ = t__cgen_85(a);
		T32_ = NIM_NIL;
		T32_ = skipTypes__ast_3723(T31_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_266);
		if (!((*T32_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22) || (*T32_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21))) goto LA33_;
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_109));
		cgFormatValue__cgen_147((&res_2), a.r);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		a.r = rope__ropes_109(res_2);
	}
	LA33_: ;
	{
		NIM_BOOL T37_;
		NIM_BOOL T38_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T43_;
		NimStringDesc* res_3;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T44_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T45_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T50_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T51_;
		T37_ = (NIM_BOOL)0;
		T38_ = (NIM_BOOL)0;
		T38_ = (((*d).flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 10))&15U)))!=0);
		if (!(T38_)) goto LA39_;
		T38_ = ((*ty).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28));
		LA39_: ;
		T37_ = T38_;
		if (!(T37_)) goto LA40_;
		T37_ = (((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0);
		LA40_: ;
		if (!T37_) goto LA41_;
		T43_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T43_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_3 = rawNewString(((NI) 80));
		T44_ = NIM_NIL;
		T44_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_276));
		cgFormatValue__cgen_147((&res_3), T44_);
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T45_ = NIM_NIL;
		T45_ = byRefLoc__cgen_10353(p, a);
		cgFormatValue__cgen_147((&res_3), T45_);
		res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA48_;
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA48_: ;
		T50_ = NIM_NIL;
		T50_ = rope__ropes_109(res_3);
		T51_ = NIM_NIL;
		T51_ = indentLine__cgen_286(p, T50_);
		add__ropes_159(T43_, T51_);
	}
	LA41_: ;
	res_4 = rawNewString(((NI) 80));
	T52_ = NIM_NIL;
	T52_ = rdLoc__cgen_435(a);
	cgFormatValue__cgen_147((&res_4), T52_);
	T53_ = NIM_NIL;
	T53_ = dataField__cgen_479(p);
	cgFormatValue__cgen_147((&res_4), T53_);
	res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_166));
	T54_ = NIM_NIL;
	T54_ = rdCharLoc__cgen_10377(b);
	cgFormatValue__cgen_147((&res_4), T54_);
	res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_167));
	T55_ = NIM_NIL;
	T55_ = rope__ropes_109(res_4);
	putIntoDest__cgen_18794(p, d, n, T55_, a.storage);
}
N_LIB_PRIVATE N_NIMCALL(void, genCStringElem__cgen_20138)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* y, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw b;
	NimStringDesc* res;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, x, (&a));
	initLocExpr__cgen_11548(p, y, (&b));
	{
		if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA3_;
		(*d).storage = a.storage;
	}
	LA3_: ;
	res = rawNewString(((NI) 80));
	T5_ = NIM_NIL;
	T5_ = rdLoc__cgen_435(a);
	cgFormatValue__cgen_147((&res), T5_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_166));
	T6_ = NIM_NIL;
	T6_ = rdCharLoc__cgen_10377(b);
	cgFormatValue__cgen_147((&res), T6_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_167));
	T7_ = NIM_NIL;
	T7_ = rope__ropes_109(res);
	putIntoDest__cgen_18794(p, d, n, T7_, a.storage);
}
N_LIB_PRIVATE N_NIMCALL(void, genTupleElem__cgen_19697)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	NI i;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tupType;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T6_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
	tyArray__ts9cf9blICas1QWmw89bglZ7w T10_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	i = (NI)0;
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 0)], (&a));
	T1_ = NIM_NIL;
	T1_ = t__cgen_85(a);
	tupType = skipTypes__ast_3723(T1_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_708);
	{
		if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA4_;
		(*d).storage = a.storage;
	}
	LA4_: ;
	T6_ = NIM_NIL;
	T6_ = t__cgen_85(a);
	T7_ = NIM_NIL;
	T7_ = getTypeDesc__cgen_6662((*p).module, T6_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
	(void)(T7_);
	r = rdLoc__cgen_435(a);
	switch ((*(*e)._kind_6.sons->data[((NI) 1)]).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 15):
	{
		i = ((NI) ((*(*e)._kind_6.sons->data[((NI) 1)])._kind_1.intVal));
	}
	break;
	default:
	{
		internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*e).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_709), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_710);
	}
	break;
	}
	nimZeroMem((void*)T10_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
	T10_[0] = rope__ropes_115(((NI64) (i)));
	T11_ = NIM_NIL;
	T11_ = percent___cgen_19723(T10_, 1);
	add__ropes_159(&r, T11_);
	putIntoDest__cgen_18794(p, d, e, r, a.storage);
}
N_LIB_PRIVATE N_NIMCALL(void, genBracketExpr__cgen_20370)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ty;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
	ty = skipTypes__ast_3723((*(*n)._kind_6.sons->data[((NI) 0)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_688);
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T5_;
		if (!((*ty).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22) || (*ty).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = lastSon__ast_3731(ty);
		ty = skipTypes__ast_3723(T5_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_183);
	}
	LA3_: ;
	switch ((*ty).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 49):
	{
		genUncheckedArrayElem__cgen_20050(p, n, (*n)._kind_6.sons->data[((NI) 0)], (*n)._kind_6.sons->data[((NI) 1)], d);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
	{
		genArrayElem__cgen_20071(p, n, (*n)._kind_6.sons->data[((NI) 0)], (*n)._kind_6.sons->data[((NI) 1)], d);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48):
	{
		genOpenArrayElem__cgen_20218(p, n, (*n)._kind_6.sons->data[((NI) 0)], (*n)._kind_6.sons->data[((NI) 1)], d);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
	{
		genSeqElem__cgen_20286(p, n, (*n)._kind_6.sons->data[((NI) 0)], (*n)._kind_6.sons->data[((NI) 1)], d);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29):
	{
		genCStringElem__cgen_20138(p, n, (*n)._kind_6.sons->data[((NI) 0)], (*n)._kind_6.sons->data[((NI) 1)], d);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18):
	{
		genTupleElem__cgen_19697(p, n, d);
	}
	break;
	default:
	{
		NimStringDesc* T13_;
		T13_ = NIM_NIL;
		T13_ = rawNewString((reprEnum((NI)(*ty).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)) ? reprEnum((NI)(*ty).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_))->Sup.len : 0) + 21);
appendString(T13_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_711));
appendString(T13_, reprEnum((NI)(*ty).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)));
appendChar(T13_, 41);
		internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*n).info, T13_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_712);
	}
	break;
	}
	T14_ = NIM_NIL;
	T14_ = getTypeDesc__cgen_6662((*p).module, (*n).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
	(void)(T14_);
}
N_LIB_PRIVATE N_NIMCALL(void, derefBlock__cgen_19463)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e0;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
	NI T5_;
	tyArray__iegsN9bf6GqRiWprrJjTAoA T6_;
	NI T7_;
	e0 = (*e)._kind_6.sons->data[((NI) 0)];
	n = shallowCopy__ast_4414(e0);
	asgnRef((void**) (&(*n).typ), (*e).typ);
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (NI)0;
		T2_ = len__ast_3155(e0);
		colontmp_ = (NI)(T2_ - ((NI) 1));
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				asgnRef((void**) (&(*n)._kind_6.sons->data[i]), (*e0)._kind_6.sons->data[i]);
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	T5_ = (NI)0;
	T5_ = len__ast_3155(e0);
	nimZeroMem((void*)T6_, sizeof(tyArray__iegsN9bf6GqRiWprrJjTAoA));
	T7_ = (NI)0;
	T7_ = len__ast_3155(e0);
	T6_[0] = (*e0)._kind_6.sons->data[(NI)(T7_ - ((NI) 1))];
	asgnRef((void**) (&(*n)._kind_6.sons->data[(NI)(T5_ - ((NI) 1))]), newTreeIT__ast_3395(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65), (*e).info, (*e).typ, T6_, 1));
	expr__cgen_11525(p, n, d);
}
N_LIB_PRIVATE N_NIMCALL(void, genDeref__cgen_19488)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ mt;
	tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw T7_;
{	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*e).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*e)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 127) || (*(*e)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 112));
		LA4_: ;
		if (!T3_) goto LA5_;
		derefBlock__cgen_19463(p, e, d);
		goto BeforeRet_;
	}
	LA5_: ;
	T7_ = (tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw)0;
	{
		if (!((*(*e)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA10_;
		T7_ = (*(*(*e)._kind_6.sons->data[((NI) 0)])._kind_4.sym).kind;
	}
	goto LA8_;
	LA10_: ;
	{
		T7_ = ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8);
	}
	LA8_: ;
	mt = mapType__cgen_1227((*(*(*p).module).g).config, (*(*e)._kind_6.sons->data[((NI) 0)]).typ, T7_);
	{
		NIM_BOOL T15_;
		T15_ = (NIM_BOOL)0;
		T15_ = ((393216 &((NU32)1<<((NU)(mt)&31U)))!=0);
		if (!(T15_)) goto LA16_;
		T15_ = !((((*d).flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 9))&15U)))!=0));
		LA16_: ;
		if (!T15_) goto LA17_;
		expr__cgen_11525(p, (*e)._kind_6.sons->data[((NI) 0)], d);
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T21_;
			T21_ = NIM_NIL;
			T21_ = skipTypes__ast_3723((*(*e)._kind_6.sons->data[((NI) 0)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_155);
			if (!((*T21_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22))) goto LA22_;
			(*d).storage = ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 3);
		}
		LA22_: ;
	}
	goto LA13_;
	LA17_: ;
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		typ = (*(*e)._kind_6.sons->data[((NI) 0)]).typ;
		{
			NIM_BOOL T27_;
			T27_ = (NIM_BOOL)0;
			T27_ = ((*typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 52) || (*typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 53));
			if (!(T27_)) goto LA28_;
			T27_ = (((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 10))&63U)))!=0);
			LA28_: ;
			if (!T27_) goto LA29_;
			typ = lastSon__ast_3731(typ);
		}
		LA29_: ;
		typ = skipTypes__ast_3723(typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_155);
		{
			NIM_BOOL T33_;
			NIM_BOOL T34_;
			NIM_BOOL T35_;
			NIM_BOOL T38_;
			T33_ = (NIM_BOOL)0;
			T34_ = (NIM_BOOL)0;
			T35_ = (NIM_BOOL)0;
			T35_ = ((*typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23));
			if (!(T35_)) goto LA36_;
			T35_ = !((((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 20))&63U)))!=0));
			LA36_: ;
			T34_ = T35_;
			if (!(T34_)) goto LA37_;
			T38_ = (NIM_BOOL)0;
			T38_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
			if (T38_) goto LA39_;
			T38_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
			LA39_: ;
			T34_ = T38_;
			LA37_: ;
			T33_ = T34_;
			if (!(T33_)) goto LA40_;
			T33_ = ((*(*e)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64));
			LA40_: ;
			if (!T33_) goto LA41_;
			initLocExprSingleUse__cgen_11552(p, (*(*e)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)], d);
			goto BeforeRet_;
		}
		goto LA31_;
		LA41_: ;
		{
			initLocExprSingleUse__cgen_11552(p, (*e)._kind_6.sons->data[((NI) 0)], (&a));
		}
		LA31_: ;
		{
			if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA46_;
			switch ((*typ).kind) {
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22):
			{
				(*d).storage = ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 3);
			}
			break;
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47):
			{
				(*d).storage = ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0);
				{
					NIM_BOOL T52_;
					NIM_BOOL T53_;
					NIM_BOOL T55_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T60_;
					T52_ = (NIM_BOOL)0;
					T53_ = (NIM_BOOL)0;
					T53_ = !((((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 20))&63U)))!=0));
					if (!(T53_)) goto LA54_;
					T55_ = (NIM_BOOL)0;
					T55_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
					if (T55_) goto LA56_;
					T55_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
					LA56_: ;
					T53_ = T55_;
					LA54_: ;
					T52_ = T53_;
					if (!(T52_)) goto LA57_;
					T52_ = ((*e).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65));
					LA57_: ;
					if (!T52_) goto LA58_;
					T60_ = NIM_NIL;
					T60_ = rdLoc__cgen_435(a);
					putIntoDest__cgen_18794(p, d, e, T60_, a.storage);
					goto BeforeRet_;
				}
				LA58_: ;
			}
			break;
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21):
			{
				(*d).storage = ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0);
			}
			break;
			default:
			{
				NimStringDesc* T63_;
				T63_ = NIM_NIL;
				T63_ = rawNewString((reprEnum((NI)(*typ).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)) ? reprEnum((NI)(*typ).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_))->Sup.len : 0) + 9);
appendString(T63_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_713));
appendString(T63_, reprEnum((NI)(*typ).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)));
				internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*e).info, T63_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_714);
			}
			break;
			}
		}
		goto LA44_;
		LA46_: ;
		{
			NIM_BOOL T65_;
			T65_ = (NIM_BOOL)0;
			T65_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
			if (T65_) goto LA66_;
			T65_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
			LA66_: ;
			if (!T65_) goto LA67_;
			{
				NIM_BOOL T71_;
				NIM_BOOL T72_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T77_;
				T71_ = (NIM_BOOL)0;
				T72_ = (NIM_BOOL)0;
				T72_ = ((*typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23));
				if (!(T72_)) goto LA73_;
				T72_ = !((((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 20))&63U)))!=0));
				LA73_: ;
				T71_ = T72_;
				if (!(T71_)) goto LA74_;
				T71_ = ((*e).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65));
				LA74_: ;
				if (!T71_) goto LA75_;
				T77_ = NIM_NIL;
				T77_ = rdLoc__cgen_435(a);
				putIntoDest__cgen_18794(p, d, e, T77_, a.storage);
				goto BeforeRet_;
			}
			LA75_: ;
		}
		goto LA44_;
		LA67_: ;
		LA44_: ;
		{
			NIM_BOOL T80_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T84_;
			T80_ = (NIM_BOOL)0;
			T80_ = (mt == ((tyEnum_TCTypeKind__EkIfaZePDU9bvUIbh26nizQ) 18));
			if (!(T80_)) goto LA81_;
			T80_ = (((*d).flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 9))&15U)))!=0);
			LA81_: ;
			if (!T80_) goto LA82_;
			T84_ = NIM_NIL;
			T84_ = rdLoc__cgen_435(a);
			putIntoDest__cgen_18794(p, d, e, T84_, a.storage);
		}
		goto LA78_;
		LA82_: ;
		{
			tyArray__ts9cf9blICas1QWmw89bglZ7w T86_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T87_;
			nimZeroMem((void*)T86_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T86_[0] = rdLoc__cgen_435(a);
			T87_ = NIM_NIL;
			T87_ = percent___cgen_442(T86_, 1);
			putIntoDest__cgen_18794(p, d, e, T87_, a.storage);
		}
		LA78_: ;
	}
	LA13_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genRecordFieldAux__cgen_19682)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* a) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T9_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 0)], a);
	{
		if (!!(((*(*e)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)))) goto LA3_;
		internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*e).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_715), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_716);
	}
	LA3_: ;
	{
		if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA7_;
		(*d).storage = (*a).storage;
	}
	LA7_: ;
	T9_ = NIM_NIL;
	T9_ = t__cgen_85((*a));
	T10_ = NIM_NIL;
	T10_ = getTypeDesc__cgen_6662((*p).module, T9_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
	(void)(T10_);
}
N_LIB_PRIVATE N_NIMCALL(void, genRecordField__cgen_19775)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* f;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ty;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	genRecordFieldAux__cgen_19682(p, e, d, (&a));
	r = rdLoc__cgen_435(a);
	f = (*(*e)._kind_6.sons->data[((NI) 1)])._kind_4.sym;
	T1_ = NIM_NIL;
	T1_ = t__cgen_85(a);
	ty = skipTypes__ast_3723(T1_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_118);
	{
		tyArray__ts9cf9blICas1QWmw89bglZ7w T6_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
		if (!((*ty).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18))) goto LA4_;
		nimZeroMem((void*)T6_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T6_[0] = rope__ropes_115(((NI64) ((*f).position)));
		T7_ = NIM_NIL;
		T7_ = percent___cgen_19723(T6_, 1);
		add__ropes_159(&r, T7_);
		putIntoDest__cgen_18794(p, d, e, r, a.storage);
	}
	goto LA2_;
	LA4_: ;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* rtyp;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T21_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
		rtyp = NIM_NIL;
		field = lookupFieldAgain__cgen_19728(p, ty, f, &r, &rtyp);
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = ((*field).loc.r == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL));
			if (!(T11_)) goto LA12_;
			T11_ = !((rtyp == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
			LA12_: ;
			if (!T11_) goto LA13_;
			fillObjectFields__cgen_3808((*p).module, rtyp);
		}
		LA13_: ;
		{
			NimStringDesc* T19_;
			NimStringDesc* T20_;
			if (!((*field).loc.r == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA17_;
			T19_ = NIM_NIL;
			T20_ = NIM_NIL;
			T20_ = typeToString__types_50(ty, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
			T19_ = rawNewString((T20_ ? T20_->Sup.len : 0) + 17);
appendString(T19_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_717));
appendString(T19_, T20_);
			internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*e).info, T19_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_718);
		}
		LA17_: ;
		nimZeroMem((void*)T21_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T21_[0] = (*field).loc.r;
		T22_ = NIM_NIL;
		T22_ = percent___cgen_19810(T21_, 1);
		add__ropes_159(&r, T22_);
		putIntoDest__cgen_18794(p, d, e, r, a.storage);
	}
	LA2_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCheckedRecordField__cgen_20003)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ty;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T5_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* f;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
		if (!(((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 2))&31U)))!=0)) goto LA3_;
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		genRecordFieldAux__cgen_19682(p, (*e)._kind_6.sons->data[((NI) 0)], d, (&a));
		T5_ = NIM_NIL;
		T5_ = t__cgen_85(a);
		ty = skipTypes__ast_3723(T5_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_118);
		r = rdLoc__cgen_435(a);
		f = (*(*(*e)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)])._kind_4.sym;
		field = lookupFieldAgain__cgen_19728(p, ty, f, &r, ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA**) NIM_NIL));
		{
			if (!((*field).loc.r == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA8_;
			fillObjectFields__cgen_3808((*p).module, ty);
		}
		LA8_: ;
		{
			if (!((*field).loc.r == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA12_;
			internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*e).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_671), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_719);
		}
		LA12_: ;
		genFieldCheck__cgen_19830(p, e, r, field);
		res = rawNewString(((NI) 80));
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_138));
		cgFormatValue__cgen_147((&res), (*field).loc.r);
		T14_ = NIM_NIL;
		T14_ = rope__ropes_109(res);
		add__ropes_159(&r, T14_);
		putIntoDest__cgen_18794(p, d, (*e)._kind_6.sons->data[((NI) 0)], r, a.storage);
	}
	goto LA1_;
	LA3_: ;
	{
		genRecordField__cgen_19775(p, (*e)._kind_6.sons->data[((NI) 0)], d);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genBlock__cgen_14665)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	NI oldBreakIdxX60gensym2019_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T10_;
	NimStringDesc* res;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isEmptyType__ast_4780((*n).typ);
		if (!!(T3_)) goto LA4_;
		{
			if (!((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0))) goto LA8_;
			getTemp__cgen_7373(p, (*n).typ, d, NIM_FALSE);
		}
		LA8_: ;
		(*d).flags |= ((NU16)1)<<((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 9)) & 15);
	}
	LA4_: ;
	oldBreakIdxX60gensym2019_ = (*p).breakIdx;
	T10_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T10_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	res = rawNewString(((NI) 80));
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA13_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA13_: ;
	T15_ = NIM_NIL;
	T15_ = rope__ropes_109(res);
	T16_ = NIM_NIL;
	T16_ = indentLine__cgen_286(p, T15_);
	add__ropes_159(T10_, T16_);
	(*p).breakIdx = startBlockInternal__cgen_13308(p);
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
		if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)))) goto LA19_;
		sym = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		(*sym).loc.k = ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 10);
		(*sym).position = (NI)((*p).breakIdx + ((NI) 1));
	}
	LA19_: ;
	expr__cgen_11525(p, (*n)._kind_6.sons->data[((NI) 1)], d);
	endBlock__cgen_13329(p);
	(*p).breakIdx = oldBreakIdxX60gensym2019_;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, initFrameNoDebug__cgen_17649)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* frame, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* procname, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* filename, NI line) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	tyArray__ts9cf9blICas1QWmw89bglZ7w T2_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T3_;
	NimStringDesc* res;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_319));
	(void)(T1_);
	nimZeroMem((void*)T2_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
	T2_[0] = frame;
	T3_ = NIM_NIL;
	T3_ = percent___cgen_17656(T2_, 1);
	add__ropes_159(&(*p).blocks->data[((NI) 0)].sections[(((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0))- 0], T3_);
	res = rawNewString(((NI) 80));
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_6));
	cgFormatValue__cgen_147((&res), frame);
	res = resizeString(res, 12);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_721));
	cgFormatValue__cgen_147((&res), procname);
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_164));
	cgFormatValue__cgen_147((&res), frame);
	res = resizeString(res, 12);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_722));
	cgFormatValue__cgen_147((&res), filename);
	res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_723));
	cgFormatValue__cgen_147((&res), frame);
	res = resizeString(res, 8);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_724));
	cgFormatValue__cgen_154((&res), ((NI64) (line)));
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_164));
	cgFormatValue__cgen_147((&res), frame);
	res = resizeString(res, 21);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_725));
	cgFormatValue__cgen_147((&res), frame);
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA6_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA6_: ;
	result = rope__ropes_109(res);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, deinitFrameNoDebug__cgen_17674)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* frame) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	NimStringDesc* res;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	result = NIM_NIL;
	res = rawNewString(((NI) 80));
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_6));
	T1_ = NIM_NIL;
	T1_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_726));
	cgFormatValue__cgen_147((&res), T1_);
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_122));
	cgFormatValue__cgen_147((&res), frame);
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA4_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA4_: ;
	result = rope__ropes_109(res);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genStmtListExpr__cgen_24255)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	NIM_BOOL hasNimFrame;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* frameName;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = !(((*p).prc == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
	if (!(T2_)) goto LA3_;
	T2_ = !((((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 15))&63U)))!=0));
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = (((*(*p).prc).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 17))&31U)))!=0);
	LA4_: ;
	hasNimFrame = T1_;
	frameName = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
	{
		NI i;
		NI colontmp_;
		NI T6_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T6_ = (NI)0;
		T6_ = len__ast_3155(n);
		colontmp_ = (NI)(T6_ - ((NI) 1));
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
				if (!(i_2 < colontmp_)) goto LA8;
				i = i_2;
				it = (*n)._kind_6.sons->data[i];
				{
					if (!((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 24))) goto LA11_;
					{
						NIM_BOOL T15_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* theMacro;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T21_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
						T15_ = (NIM_BOOL)0;
						T15_ = hasNimFrame;
						if (!(T15_)) goto LA16_;
						T15_ = (frameName == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL));
						LA16_: ;
						if (!T15_) goto LA17_;
						(*p).labels += ((NI) 1);
						T19_ = NIM_NIL;
						T19_ = rope__ropes_115(((NI64) ((*p).labels)));
						T20_ = NIM_NIL;
						T20_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_720), T19_);
						frameName = amp___ropes_140(T20_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3));
						theMacro = (*(*it)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
						T21_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
						T21_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
						T22_ = NIM_NIL;
						T22_ = makeCString__msgs_50((*(*theMacro).name).s);
						T23_ = NIM_NIL;
						T23_ = quotedFilename__msgs_1473((*(*(*p).module).g).config, (*theMacro).info);
						T24_ = NIM_NIL;
						T24_ = initFrameNoDebug__cgen_17649(p, frameName, T22_, T23_, ((NI) ((*it).info.line)));
						add__ropes_159(T21_, T24_);
					}
					LA17_: ;
				}
				goto LA9_;
				LA11_: ;
				{
					genStmts__cgen_11522(p, it);
				}
				LA9_: ;
				i_2 += ((NI) 1);
			} LA8: ;
		}
	}
	{
		NI T28_;
		NI T31_;
		T28_ = (NI)0;
		T28_ = len__ast_3155(n);
		if (!(((NI) 0) < T28_)) goto LA29_;
		T31_ = (NI)0;
		T31_ = len__ast_3155(n);
		expr__cgen_11525(p, (*n)._kind_6.sons->data[(NI)(T31_ - ((NI) 1))], d);
	}
	LA29_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T36_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T37_;
		if (!!((frameName == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA34_;
		T36_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T36_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		T37_ = NIM_NIL;
		T37_ = deinitFrameNoDebug__cgen_17674(p, frameName);
		add__ropes_159(T36_, T37_);
	}
	LA34_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genStmtList__cgen_24309)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL hasNimFrame;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* frameName;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = !(((*p).prc == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
	if (!(T2_)) goto LA3_;
	T2_ = !((((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 15))&63U)))!=0));
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = (((*(*p).prc).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 17))&31U)))!=0);
	LA4_: ;
	hasNimFrame = T1_;
	frameName = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
	{
		NI i;
		NI colontmp_;
		NI T6_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T6_ = (NI)0;
		T6_ = len__ast_3155(n);
		colontmp_ = (NI)(T6_ - ((NI) 1));
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
				if (!(i_2 < colontmp_)) goto LA8;
				i = i_2;
				it = (*n)._kind_6.sons->data[i];
				{
					if (!((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 24))) goto LA11_;
					{
						NIM_BOOL T15_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* theMacro;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T21_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
						T15_ = (NIM_BOOL)0;
						T15_ = hasNimFrame;
						if (!(T15_)) goto LA16_;
						T15_ = (frameName == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL));
						LA16_: ;
						if (!T15_) goto LA17_;
						(*p).labels += ((NI) 1);
						T19_ = NIM_NIL;
						T19_ = rope__ropes_115(((NI64) ((*p).labels)));
						T20_ = NIM_NIL;
						T20_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_720), T19_);
						frameName = amp___ropes_140(T20_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3));
						theMacro = (*(*it)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
						T21_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
						T21_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
						T22_ = NIM_NIL;
						T22_ = makeCString__msgs_50((*(*theMacro).name).s);
						T23_ = NIM_NIL;
						T23_ = quotedFilename__msgs_1473((*(*(*p).module).g).config, (*theMacro).info);
						T24_ = NIM_NIL;
						T24_ = initFrameNoDebug__cgen_17649(p, frameName, T22_, T23_, ((NI) ((*it).info.line)));
						add__ropes_159(T21_, T24_);
					}
					LA17_: ;
				}
				goto LA9_;
				LA11_: ;
				{
					genStmts__cgen_11522(p, it);
				}
				LA9_: ;
				i_2 += ((NI) 1);
			} LA8: ;
		}
	}
	{
		NI T28_;
		NI T31_;
		T28_ = (NI)0;
		T28_ = len__ast_3155(n);
		if (!(((NI) 0) < T28_)) goto LA29_;
		T31_ = (NI)0;
		T31_ = len__ast_3155(n);
		genStmts__cgen_11522(p, (*n)._kind_6.sons->data[(NI)(T31_ - ((NI) 1))]);
	}
	LA29_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T36_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T37_;
		if (!!((frameName == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA34_;
		T36_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T36_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		T37_ = NIM_NIL;
		T37_ = deinitFrameNoDebug__cgen_17674(p, frameName);
		add__ropes_159(T36_, T37_);
	}
	LA34_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genIf__cgen_14186)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* lelse;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* lend;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	lelse = NIM_NIL;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = isEmptyType__ast_4780((*n).typ);
		T3_ = !(T4_);
		if (!(T3_)) goto LA5_;
		T3_ = ((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0));
		LA5_: ;
		if (!T3_) goto LA6_;
		getTemp__cgen_7373(p, (*n).typ, d, NIM_FALSE);
	}
	LA6_: ;
	genLineDir__cgen_369(p, n);
	lend = getLabel__cgen_11501(p);
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** it;
		tySequence__IeU9azYSNIK3V9b36Ir6NZcw* colontmp_;
		NI i;
		NI L;
		NI T9_;
		it = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
		colontmp_ = NIM_NIL;
		colontmp_ = (*n)._kind_6.sons;
		i = ((NI) 0);
		T9_ = (colontmp_ ? colontmp_->Sup.len : 0);
		L = T9_;
		{
			while (1) {
				if (!(i < L)) goto LA11;
				it = &colontmp_->data[i];
				{
					NIM_BOOL T14_;
					T14_ = (NIM_BOOL)0;
					T14_ = ((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 1));
					if (!(T14_)) goto LA15_;
					T14_ = isEmptyType__ast_4780((*n).typ);
					LA15_: ;
					if (!T14_) goto LA16_;
					(*d).k = ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0);
				}
				LA16_: ;
				{
					NI T20_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T23_;
					NimStringDesc* res;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T28_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T29_;
					NI T30_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T31_;
					tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T32_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T33_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T34_;
					T20_ = (NI)0;
					T20_ = len__ast_3155((*it));
					if (!(T20_ == ((NI) 2))) goto LA21_;
					T23_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T23_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					res = rawNewString(((NI) 80));
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA26_;
						res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
					}
					LA26_: ;
					T28_ = NIM_NIL;
					T28_ = rope__ropes_109(res);
					T29_ = NIM_NIL;
					T29_ = indentLine__cgen_286(p, T28_);
					add__ropes_159(T23_, T29_);
					T30_ = (NI)0;
					T30_ = startBlockInternal__cgen_13308(p);
					initLocExprSingleUse__cgen_11552(p, (*(*it))._kind_6.sons->data[((NI) 0)], (&a));
					lelse = getLabel__cgen_11501(p);
					(*p).labels += ((NI) 1);
					T31_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T31_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					nimZeroMem((void*)T32_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
					T32_[0] = rdLoc__cgen_435(a);
					T32_[1] = lelse;
					T33_ = NIM_NIL;
					T33_ = percent___cgen_14226(T32_, 2);
					T34_ = NIM_NIL;
					T34_ = indentLine__cgen_286(p, T33_);
					add__ropes_159(T31_, T34_);
					{
						NIM_BOOL T37_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T41_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T42_;
						T37_ = (NIM_BOOL)0;
						T37_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
						if (T37_) goto LA38_;
						T37_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
						LA38_: ;
						if (!T37_) goto LA39_;
						T41_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
						T41_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
						add__ropes_162(T41_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8));
						expr__cgen_11525(p, (*(*it))._kind_6.sons->data[((NI) 1)], d);
						T42_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
						T42_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
						add__ropes_162(T42_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
					}
					goto LA35_;
					LA39_: ;
					{
						expr__cgen_11525(p, (*(*it))._kind_6.sons->data[((NI) 1)], d);
					}
					LA35_: ;
					endBlock__cgen_13329(p);
					{
						NI T46_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T49_;
						tyArray__ts9cf9blICas1QWmw89bglZ7w T50_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T51_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T52_;
						T46_ = (NI)0;
						T46_ = len__ast_3155(n);
						if (!(((NI) 1) < T46_)) goto LA47_;
						T49_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
						T49_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
						nimZeroMem((void*)T50_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
						T50_[0] = lend;
						T51_ = NIM_NIL;
						T51_ = percent___cgen_14244(T50_, 1);
						T52_ = NIM_NIL;
						T52_ = indentLine__cgen_286(p, T51_);
						add__ropes_159(T49_, T52_);
					}
					LA47_: ;
					fixLabel__cgen_11508(p, lelse);
				}
				goto LA18_;
				LA21_: ;
				{
					NI T54_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T57_;
					NimStringDesc* res_2;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T62_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T63_;
					NI T64_;
					T54_ = (NI)0;
					T54_ = len__ast_3155((*it));
					if (!(T54_ == ((NI) 1))) goto LA55_;
					T57_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T57_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					res_2 = rawNewString(((NI) 80));
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA60_;
						res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
					}
					LA60_: ;
					T62_ = NIM_NIL;
					T62_ = rope__ropes_109(res_2);
					T63_ = NIM_NIL;
					T63_ = indentLine__cgen_286(p, T62_);
					add__ropes_159(T57_, T63_);
					T64_ = (NI)0;
					T64_ = startBlockInternal__cgen_13308(p);
					expr__cgen_11525(p, (*(*it))._kind_6.sons->data[((NI) 0)], d);
					endBlock__cgen_13329(p);
				}
				goto LA18_;
				LA55_: ;
				{
					internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_727), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_728);
				}
				LA18_: ;
				i += ((NI) 1);
			} LA11: ;
		}
	}
	{
		NI T68_;
		T68_ = (NI)0;
		T68_ = len__ast_3155(n);
		if (!(((NI) 1) < T68_)) goto LA69_;
		fixLabel__cgen_11508(p, lend);
	}
	LA69_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, downConv__cgen_24429)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* dest;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* src;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T3_;
	NIM_BOOL isRef;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T4_;
	arg = (*n)._kind_6.sons->data[((NI) 0)];
	{
		while (1) {
			if (!((*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 66))) goto LA2;
			arg = (*arg)._kind_6.sons->data[((NI) 0)];
		} LA2: ;
	}
	dest = skipTypes__ast_3723((*n).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_201);
	src = skipTypes__ast_3723((*arg).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_201);
	T3_ = NIM_NIL;
	T3_ = getTypeDesc__cgen_6662((*p).module, src, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
	(void)(T3_);
	T4_ = NIM_NIL;
	T4_ = skipTypes__ast_3723((*arg).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_155);
	isRef = ((*T4_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22) || (*T4_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21) || (*T4_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*T4_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47));
	{
		NIM_BOOL T7_;
		NIM_BOOL T8_;
		NIM_BOOL T9_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T12_;
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T16_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
		T7_ = (NIM_BOOL)0;
		T8_ = (NIM_BOOL)0;
		T9_ = (NIM_BOOL)0;
		T9_ = isRef;
		if (!(T9_)) goto LA10_;
		T9_ = ((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0));
		LA10_: ;
		T8_ = T9_;
		if (!(T8_)) goto LA11_;
		T12_ = NIM_NIL;
		T12_ = skipTypes__ast_3723((*n).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_155);
		T8_ = ((*T12_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22) || (*T12_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21));
		LA11_: ;
		T7_ = T8_;
		if (!(T7_)) goto LA13_;
		T7_ = isLValue__parampatterns_497(n);
		LA13_: ;
		if (!T7_) goto LA14_;
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548(p, arg, (&a));
		nimZeroMem((void*)T16_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T16_[0] = getTypeDesc__cgen_6662((*p).module, (*n).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		T16_[1] = rdLoc__cgen_435(a);
		T17_ = NIM_NIL;
		T17_ = percent___cgen_24416(T16_, 2);
		putIntoDest__cgen_18794(p, d, n, T17_, a.storage);
	}
	goto LA5_;
	LA14_: ;
	{
		NIM_BOOL T19_;
		T19_ = (NIM_BOOL)0;
		T19_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
		if (T19_) goto LA20_;
		T19_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
		LA20_: ;
		if (!T19_) goto LA21_;
		expr__cgen_11525(p, arg, d);
	}
	goto LA5_;
	LA21_: ;
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
		NimStringDesc* T25_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T35_;
		nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548(p, arg, (&a_2));
		T24_ = NIM_NIL;
		T24_ = rdLoc__cgen_435(a_2);
		T25_ = NIM_NIL;
		{
			if (!isRef) goto LA28_;
			T25_ = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_729));
		}
		goto LA26_;
		LA28_: ;
		{
			T25_ = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_129));
		}
		LA26_: ;
		r = amp___ropes_140(T24_, T25_);
		{
			NI i;
			NI colontmp_;
			NI T32_;
			NI res;
			i = (NI)0;
			colontmp_ = (NI)0;
			T32_ = (NI)0;
			T32_ = inheritanceDiff__types_2737(dest, src);
			colontmp_ = (T32_ > 0? (T32_) : -(T32_));
			res = ((NI) 2);
			{
				while (1) {
					if (!(res <= colontmp_)) goto LA34;
					i = res;
					add__ropes_162(&r, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_129));
					res += ((NI) 1);
				} LA34: ;
			}
		}
		T35_ = NIM_NIL;
		{
			if (!isRef) goto LA38_;
			T35_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_358), r);
		}
		goto LA36_;
		LA38_: ;
		{
			T35_ = r;
		}
		LA36_: ;
		putIntoDest__cgen_18794(p, d, n, T35_, a_2.storage);
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, upConv__cgen_24363)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* dest;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, (*n)._kind_6.sons->data[((NI) 0)], (&a));
	dest = skipTypes__ast_3723((*n).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_201);
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* nilCheck;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* checkFor;
		T3_ = (NIM_BOOL)0;
		T3_ = (((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 1))&31U)))!=0);
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = isObjLackingTypeField__cgen_1337(dest);
		T3_ = !(T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		nilCheck = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
		r = rdMType__cgen_21782(p, a, &nilCheck, NIM_FALSE);
		{
			if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 41))&63U)))!=0)) goto LA10_;
			checkFor = genTypeInfo2Name__cgen_7835((*p).module, dest);
		}
		goto LA8_;
		LA10_: ;
		{
			checkFor = genTypeInfoV1__cgen_6798((*p).module, dest, (*n).info);
		}
		LA8_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T17_;
			NimStringDesc* res;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
			if (!!((nilCheck == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA15_;
			T17_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T17_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res = rawNewString(((NI) 80));
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
			cgFormatValue__cgen_147((&res), nilCheck);
			res = resizeString(res, 5);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_730));
			T18_ = NIM_NIL;
			T18_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_731));
			cgFormatValue__cgen_147((&res), T18_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			cgFormatValue__cgen_147((&res), r);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			cgFormatValue__cgen_147((&res), checkFor);
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_434));
			T19_ = NIM_NIL;
			T19_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_732));
			cgFormatValue__cgen_147((&res), T19_);
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_436));
			T20_ = NIM_NIL;
			T20_ = raiseInstr__cgen_424(p);
			cgFormatValue__cgen_147((&res), T20_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA23_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA23_: ;
			T25_ = NIM_NIL;
			T25_ = rope__ropes_109(res);
			T26_ = NIM_NIL;
			T26_ = indentLine__cgen_286(p, T25_);
			add__ropes_159(T17_, T26_);
		}
		goto LA13_;
		LA15_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T28_;
			NimStringDesc* res_2;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T29_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T30_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T31_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T36_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T37_;
			T28_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T28_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_2 = rawNewString(((NI) 80));
			res_2 = resizeString(res_2, 5);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_733));
			T29_ = NIM_NIL;
			T29_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_731));
			cgFormatValue__cgen_147((&res_2), T29_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			cgFormatValue__cgen_147((&res_2), r);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			cgFormatValue__cgen_147((&res_2), checkFor);
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_434));
			T30_ = NIM_NIL;
			T30_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_732));
			cgFormatValue__cgen_147((&res_2), T30_);
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_436));
			T31_ = NIM_NIL;
			T31_ = raiseInstr__cgen_424(p);
			cgFormatValue__cgen_147((&res_2), T31_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA34_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA34_: ;
			T36_ = NIM_NIL;
			T36_ = rope__ropes_109(res_2);
			T37_ = NIM_NIL;
			T37_ = indentLine__cgen_286(p, T36_);
			add__ropes_159(T28_, T37_);
		}
		LA13_: ;
	}
	LA6_: ;
	{
		if (!!(((*(*(*n)._kind_6.sons->data[((NI) 0)]).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17)))) goto LA40_;
		{
			NIM_BOOL T44_;
			tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T47_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T48_;
			T44_ = (NIM_BOOL)0;
			T44_ = isLValue__parampatterns_497(n);
			if (!T44_) goto LA45_;
			nimZeroMem((void*)T47_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
			T47_[0] = getTypeDesc__cgen_6662((*p).module, (*n).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			T47_[1] = rdLoc__cgen_435(a);
			T48_ = NIM_NIL;
			T48_ = percent___cgen_24416(T47_, 2);
			putIntoDest__cgen_18794(p, d, n, T48_, a.storage);
		}
		goto LA42_;
		LA45_: ;
		{
			tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T50_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T51_;
			nimZeroMem((void*)T50_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
			T50_[0] = getTypeDesc__cgen_6662((*p).module, (*n).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			T50_[1] = rdLoc__cgen_435(a);
			T51_ = NIM_NIL;
			T51_ = percent___cgen_22940(T50_, 2);
			putIntoDest__cgen_18794(p, d, n, T51_, a.storage);
		}
		LA42_: ;
	}
	goto LA38_;
	LA40_: ;
	{
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T53_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T54_;
		nimZeroMem((void*)T53_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T53_[0] = getTypeDesc__cgen_6662((*p).module, dest, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		T53_[1] = addrLoc__cgen_10337((*(*(*p).module).g).config, a);
		T54_ = NIM_NIL;
		T54_ = percent___cgen_22923(T53_, 2);
		putIntoDest__cgen_18794(p, d, n, T54_, a.storage);
	}
	LA38_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genRangeChck__cgen_23044)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* dest;
	tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T59_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T60_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	dest = skipTypes__ast_3723((*n).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_266);
	initLocExpr__cgen_11548(p, (*n)._kind_6.sons->data[((NI) 0)], (&a));
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !((((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 3))&31U)))!=0));
		if (T3_) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = ((*dest).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40) && (*dest).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44));
		if (!(T5_)) goto LA6_;
		T5_ = !((((*(*(*(*p).module).g).config).legacyFeatures &((NU8)1<<((NU)(((tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g) 1))&7U)))!=0));
		LA6_: ;
		T3_ = T5_;
		LA4_: ;
		if (!T3_) goto LA7_;
	}
	goto LA1_;
	LA7_: ;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n0t;
		n0t = (*(*n)._kind_6.sons->data[((NI) 0)]).typ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T14_;
			NimStringDesc* res;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
			if (!((*n0t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40) || (*n0t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44))) goto LA12_;
			T14_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T14_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res = rawNewString(((NI) 80));
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
			T15_ = NIM_NIL;
			T15_ = rdCharLoc__cgen_10377(a);
			cgFormatValue__cgen_147((&res), T15_);
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_734));
			T16_ = NIM_NIL;
			T16_ = getTypeDesc__cgen_6662((*p).module, n0t, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			cgFormatValue__cgen_147((&res), T16_);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_470));
			T17_ = NIM_NIL;
			T17_ = genLiteral__cgen_17776(p, (*n)._kind_6.sons->data[((NI) 2)], dest);
			cgFormatValue__cgen_147((&res), T17_);
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_434));
			T18_ = NIM_NIL;
			T18_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_735));
			cgFormatValue__cgen_147((&res), T18_);
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_436));
			T19_ = NIM_NIL;
			T19_ = raiseInstr__cgen_424(p);
			cgFormatValue__cgen_147((&res), T19_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA22_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA22_: ;
			T24_ = NIM_NIL;
			T24_ = rope__ropes_109(res);
			T25_ = NIM_NIL;
			T25_ = indentLine__cgen_286(p, T24_);
			add__ropes_159(T14_, T25_);
		}
		goto LA10_;
		LA12_: ;
		{
			NimStringDesc* raiser;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T27_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T31_;
			NimStringDesc* boundaryCast;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T44_;
			NimStringDesc* res_2;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T45_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T46_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T47_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T48_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T49_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T50_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T51_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T52_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T57_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T58_;
			T27_ = NIM_NIL;
			T27_ = skipTypes__ast_3723((*n).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_183);
			switch ((*T27_).kind) {
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2):
			{
				raiser = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_736));
			}
			break;
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 39):
			{
				raiser = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_737));
			}
			break;
			default:
			{
				raiser = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_738));
			}
			break;
			}
			T31_ = NIM_NIL;
			T31_ = cgsym__cgen_126((*p).module, raiser);
			(void)(T31_);
			{
				NIM_BOOL T34_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T35_;
				NIM_BOOL T37_;
				NIM_BOOL T38_;
				T34_ = (NIM_BOOL)0;
				T35_ = NIM_NIL;
				T35_ = skipTypes__ast_3723(n0t, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_183);
				T34_ = ((*T35_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40) || (*T35_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 43) || (*T35_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44));
				if (T34_) goto LA36_;
				T37_ = (NIM_BOOL)0;
				T38_ = (NIM_BOOL)0;
				T38_ = !(((*n0t).sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
				if (!(T38_)) goto LA39_;
				T38_ = (((*(*(*n0t).sym).owner).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 15))&63U)))!=0);
				LA39_: ;
				T37_ = T38_;
				if (!(T37_)) goto LA40_;
				T37_ = eqStrings((*(*(*n0t).sym).name).s, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_739));
				LA40_: ;
				T34_ = T37_;
				LA36_: ;
				if (!T34_) goto LA41_;
				boundaryCast = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_740));
			}
			goto LA32_;
			LA41_: ;
			{
				boundaryCast = ((NimStringDesc*) NIM_NIL);
			}
			LA32_: ;
			T44_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T44_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_2 = rawNewString(((NI) 80));
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
			cgFormatValue__cgen_151((&res_2), boundaryCast);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T45_ = NIM_NIL;
			T45_ = rdCharLoc__cgen_10377(a);
			cgFormatValue__cgen_147((&res_2), T45_);
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_741));
			T46_ = NIM_NIL;
			T46_ = genLiteral__cgen_17776(p, (*n)._kind_6.sons->data[((NI) 1)], dest);
			cgFormatValue__cgen_147((&res_2), T46_);
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_432));
			cgFormatValue__cgen_151((&res_2), boundaryCast);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T47_ = NIM_NIL;
			T47_ = rdCharLoc__cgen_10377(a);
			cgFormatValue__cgen_147((&res_2), T47_);
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_742));
			T48_ = NIM_NIL;
			T48_ = genLiteral__cgen_17776(p, (*n)._kind_6.sons->data[((NI) 2)], dest);
			cgFormatValue__cgen_147((&res_2), T48_);
			res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_468));
			cgFormatValue__cgen_151((&res_2), raiser);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
			T49_ = NIM_NIL;
			T49_ = rdCharLoc__cgen_10377(a);
			cgFormatValue__cgen_147((&res_2), T49_);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			T50_ = NIM_NIL;
			T50_ = genLiteral__cgen_17776(p, (*n)._kind_6.sons->data[((NI) 1)], dest);
			cgFormatValue__cgen_147((&res_2), T50_);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			T51_ = NIM_NIL;
			T51_ = genLiteral__cgen_17776(p, (*n)._kind_6.sons->data[((NI) 2)], dest);
			cgFormatValue__cgen_147((&res_2), T51_);
			res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_437));
			T52_ = NIM_NIL;
			T52_ = raiseInstr__cgen_424(p);
			cgFormatValue__cgen_147((&res_2), T52_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA55_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA55_: ;
			T57_ = NIM_NIL;
			T57_ = rope__ropes_109(res_2);
			T58_ = NIM_NIL;
			T58_ = indentLine__cgen_286(p, T57_);
			add__ropes_159(T44_, T58_);
		}
		LA10_: ;
	}
	LA1_: ;
	nimZeroMem((void*)T59_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
	T59_[0] = getTypeDesc__cgen_6662((*p).module, dest, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
	T59_[1] = rdCharLoc__cgen_10377(a);
	T60_ = NIM_NIL;
	T60_ = percent___cgen_22940(T59_, 2);
	putIntoDest__cgen_18794(p, d, n, T60_, a.storage);
}
N_LIB_PRIVATE N_NIMCALL(void, convStrToCStr__cgen_23125)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	NimStringDesc* res;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T2_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T3_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, (*n)._kind_6.sons->data[((NI) 0)], (&a));
	res = rawNewString(((NI) 80));
	T1_ = NIM_NIL;
	T1_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_403));
	cgFormatValue__cgen_147((&res), T1_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
	T2_ = NIM_NIL;
	T2_ = rdLoc__cgen_435(a);
	cgFormatValue__cgen_147((&res), T2_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
	T3_ = NIM_NIL;
	T3_ = rope__ropes_109(res);
	putIntoDest__cgen_18794(p, d, n, T3_, a.storage);
}
N_LIB_PRIVATE N_NIMCALL(void, convCStrToStr__cgen_23140)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	NimStringDesc* res;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T2_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T3_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, (*n)._kind_6.sons->data[((NI) 0)], (&a));
	res = rawNewString(((NI) 80));
	T1_ = NIM_NIL;
	T1_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_548));
	cgFormatValue__cgen_147((&res), T1_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
	T2_ = NIM_NIL;
	T2_ = rdLoc__cgen_435(a);
	cgFormatValue__cgen_147((&res), T2_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
	T3_ = NIM_NIL;
	T3_ = rope__ropes_109(res);
	putIntoDest__cgen_18794(p, d, n, T3_, a.storage);
	gcUsage__cgen_20553((*(*(*p).module).g).config, n);
}
N_LIB_PRIVATE N_NIMCALL(void, genComputedGoto__cgen_14416)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n_2;
	NI casePos;
	NI arraySize;
	NI id;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tmp;
	tyArray__ts9cf9blICas1QWmw89bglZ7w T33_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* gotoArray;
	tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T34_;
	tyArray__ts9cf9blICas1QWmw89bglZ7w T40_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T41_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T42_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T43_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* caseStmt;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T47_;
	tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T48_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T49_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T50_;
{	n_2 = flattenStmts__trees_355(n);
	casePos = ((NI) -1);
	arraySize = (NI)0;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(n_2);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				it = (*n_2)._kind_6.sons->data[i];
				{
					tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ aSize;
					if (!((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 97))) goto LA6_;
					{
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T10_;
						T10_ = NIM_NIL;
						T10_ = lastSon__ast_4833(it);
						if (!!(((*T10_).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 85)))) goto LA11_;
						liMessage__msgs_1128((*(*(*p).module).g).config, (*it).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_744), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_745, NIM_FALSE);
						goto BeforeRet_;
					}
					LA11_: ;
					casePos = i;
					{
						NIM_BOOL T15_;
						T15_ = (NIM_BOOL)0;
						T15_ = enumHasHoles__types_287((*(*it)._kind_6.sons->data[((NI) 0)]).typ);
						if (!T15_) goto LA16_;
						liMessage__msgs_1128((*(*(*p).module).g).config, (*it).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_746), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_747, NIM_FALSE);
						goto BeforeRet_;
					}
					LA16_: ;
					aSize = lengthOrd__types_1723((*(*(*p).module).g).config, (*(*it)._kind_6.sons->data[((NI) 0)]).typ);
					{
						NIM_BOOL T20_;
						T20_ = (NIM_BOOL)0;
						T20_ = lt___int495056_931(IL64(10000), aSize);
						if (!T20_) goto LA21_;
						liMessage__msgs_1128((*(*(*p).module).g).config, (*it).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_748), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_749, NIM_FALSE);
						goto BeforeRet_;
					}
					LA21_: ;
					arraySize = toInt__int495056_273(aSize);
					{
						tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T25_;
						NIM_BOOL T26_;
						T25_ = firstOrd__types_1406((*(*(*p).module).g).config, (*(*it)._kind_6.sons->data[((NI) 0)]).typ);
						T26_ = (NIM_BOOL)0;
						T26_ = eqeq___int495056_952(T25_, IL64(0));
						if (!!(T26_)) goto LA27_;
						liMessage__msgs_1128((*(*(*p).module).g).config, (*it).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_750), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_751, NIM_FALSE);
						goto BeforeRet_;
					}
					LA27_: ;
				}
				LA6_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	{
		if (!(casePos < ((NI) 0))) goto LA31_;
		liMessage__msgs_1128((*(*(*p).module).g).config, (*n_2).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_752), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_753, NIM_FALSE);
		goto BeforeRet_;
	}
	LA31_: ;
	id = (NI)(((NI) ((*p).labels)) + ((NI) 1));
	(*p).labels += (NI)(arraySize + ((NI) 1));
	nimZeroMem((void*)T33_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
	T33_[0] = rope__ropes_115(((NI64) (id)));
	tmp = percent___cgen_14452(T33_, 1);
	nimZeroMem((void*)T34_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
	T34_[0] = tmp;
	T34_[1] = rope__ropes_115(((NI64) (arraySize)));
	gotoArray = percent___cgen_14458(T34_, 2);
	{
		NI i_3;
		NI colontmp__2;
		NI res;
		i_3 = (NI)0;
		colontmp__2 = (NI)0;
		colontmp__2 = (NI)(arraySize - ((NI) 1));
		res = ((NI) 1);
		{
			while (1) {
				tyArray__ts9cf9blICas1QWmw89bglZ7w T38_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T39_;
				if (!(res <= colontmp__2)) goto LA37;
				i_3 = res;
				nimZeroMem((void*)T38_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
				T38_[0] = rope__ropes_115(((NI64) ((NI)(id + i_3))));
				T39_ = NIM_NIL;
				T39_ = percent___cgen_14469(T38_, 1);
				add__ropes_159(&gotoArray, T39_);
				res += ((NI) 1);
			} LA37: ;
		}
	}
	nimZeroMem((void*)T40_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
	T40_[0] = rope__ropes_115(((NI64) ((NI)(id + arraySize))));
	T41_ = NIM_NIL;
	T41_ = percent___cgen_14474(T40_, 1);
	add__ropes_159(&gotoArray, T41_);
	T42_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T42_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
	T43_ = NIM_NIL;
	T43_ = indentLine__cgen_286(p, gotoArray);
	add__ropes_159(T42_, T43_);
	{
		NI j;
		NI i_4;
		j = (NI)0;
		i_4 = ((NI) 0);
		{
			while (1) {
				if (!(i_4 < casePos)) goto LA46;
				j = i_4;
				genStmts__cgen_11522(p, (*n_2)._kind_6.sons->data[j]);
				i_4 += ((NI) 1);
			} LA46: ;
		}
	}
	caseStmt = (*n_2)._kind_6.sons->data[casePos];
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, (*caseStmt)._kind_6.sons->data[((NI) 0)], (&a));
	T47_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T47_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	nimZeroMem((void*)T48_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
	T48_[0] = tmp;
	T48_[1] = rdLoc__cgen_435(a);
	T49_ = NIM_NIL;
	T49_ = percent___cgen_14489(T48_, 2);
	T50_ = NIM_NIL;
	T50_ = indentLine__cgen_286(p, T49_);
	add__ropes_159(T47_, T50_);
	{
		NI i_5;
		NI colontmp__3;
		NI i_6;
		i_5 = (NI)0;
		colontmp__3 = (NI)0;
		colontmp__3 = len__ast_3155(caseStmt);
		i_6 = ((NI) 1);
		{
			while (1) {
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T54_;
				NimStringDesc* res_2;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T59_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T60_;
				NI T61_;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it_2;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T75_;
				tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a_2;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T105_;
				tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T106_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T107_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T108_;
				if (!(i_6 < colontmp__3)) goto LA53;
				i_5 = i_6;
				T54_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T54_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_2 = rawNewString(((NI) 80));
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA57_;
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA57_: ;
				T59_ = NIM_NIL;
				T59_ = rope__ropes_109(res_2);
				T60_ = NIM_NIL;
				T60_ = indentLine__cgen_286(p, T59_);
				add__ropes_159(T54_, T60_);
				T61_ = (NI)0;
				T61_ = startBlockInternal__cgen_13308(p);
				it_2 = (*caseStmt)._kind_6.sons->data[i_5];
				{
					NI j_2;
					NI colontmp__4;
					NI T63_;
					NI i_7;
					j_2 = (NI)0;
					colontmp__4 = (NI)0;
					T63_ = (NI)0;
					T63_ = len__ast_3155(it_2);
					colontmp__4 = (NI)(T63_ - ((NI) 1));
					i_7 = ((NI) 0);
					{
						while (1) {
							tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ val;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T70_;
							tyArray__ts9cf9blICas1QWmw89bglZ7w T71_;
							NI64 T72_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T73_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T74_;
							if (!(i_7 < colontmp__4)) goto LA65;
							j_2 = i_7;
							{
								if (!((*(*it_2)._kind_6.sons->data[j_2]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 44))) goto LA68_;
								liMessage__msgs_1128((*(*(*p).module).g).config, (*it_2).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_754), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_755, NIM_FALSE);
								goto BeforeRet_;
							}
							LA68_: ;
							val = getOrdValue__types_161((*it_2)._kind_6.sons->data[j_2], Max__int495056_27);
							T70_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
							T70_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
							nimZeroMem((void*)T71_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
							T72_ = (NI64)0;
							T72_ = toInt64__int495056_88(val);
							T71_[0] = intLiteral__cgen_11536((NI64)((NI64)(T72_ + ((NI64) (id))) + IL64(1)));
							T73_ = NIM_NIL;
							T73_ = percent___cgen_14532(T71_, 1);
							T74_ = NIM_NIL;
							T74_ = indentLine__cgen_286(p, T73_);
							add__ropes_159(T70_, T74_);
							i_7 += ((NI) 1);
						} LA65: ;
					}
				}
				T75_ = NIM_NIL;
				T75_ = lastSon__ast_4833(it_2);
				genStmts__cgen_11522(p, T75_);
				{
					NI j_3;
					NI colontmp__5;
					NI colontmp__6;
					NI i_8;
					j_3 = (NI)0;
					colontmp__5 = (NI)0;
					colontmp__6 = (NI)0;
					colontmp__5 = (NI)(casePos + ((NI) 1));
					colontmp__6 = len__ast_3155(n_2);
					i_8 = colontmp__5;
					{
						while (1) {
							if (!(i_8 < colontmp__6)) goto LA78;
							j_3 = i_8;
							genStmts__cgen_11522(p, (*n_2)._kind_6.sons->data[j_3]);
							i_8 += ((NI) 1);
						} LA78: ;
					}
				}
				{
					NI j_4;
					NI i_9;
					j_4 = (NI)0;
					i_9 = ((NI) 0);
					{
						while (1) {
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it_3;
							if (!(i_9 < casePos)) goto LA81;
							j_4 = i_9;
							it_3 = (*n_2)._kind_6.sons->data[j_4];
							{
								tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* asgn;
								if (!((*it_3).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 100) || (*it_3).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 99))) goto LA84_;
								asgn = copyNode__ast_4324(it_3);
								transitionSonsKind__ast_4347(asgn, ((tyEnum_TNodeKind__jsmc0lvQl44MLrOvpRmgJQ) 73));
								asgnRef((void**) (&(*asgn)._kind_6.sons), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) setLengthSeqV2(((*asgn)._kind_6.sons)?&((*asgn)._kind_6.sons)->Sup:NIM_NIL, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) 2)));
								{
									tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* sym;
									tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* value;
									sym = NIM_NIL;
									value = NIM_NIL;
									{
										tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* identDefs;
										identDefs = NIM_NIL;
										{
											NI i_10;
											NI colontmp__7;
											NI i_11;
											i_10 = (NI)0;
											colontmp__7 = (NI)0;
											colontmp__7 = safeLen__ast_3148(it_3);
											i_11 = ((NI) 0);
											{
												while (1) {
													if (!(i_11 < colontmp__7)) goto LA90;
													i_10 = i_11;
													identDefs = (*it_3)._kind_6.sons->data[i_10];
													{
														tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* valueSym;
														NI T95_;
														if (!((*identDefs).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 35))) goto LA93_;
														T95_ = (NI)0;
														T95_ = len__ast_3155(identDefs);
														valueSym = (*identDefs)._kind_6.sons->data[(NI)(T95_ - ((NI) 1))];
														{
															NI i_12;
															NI colontmp__8;
															NI T97_;
															NI i_13;
															i_12 = (NI)0;
															colontmp__8 = (NI)0;
															T97_ = (NI)0;
															T97_ = len__ast_3155(identDefs);
															colontmp__8 = (NI)(T97_ - ((NI) 2));
															i_13 = ((NI) 0);
															{
																while (1) {
																	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* memberSym;
																	if (!(i_13 < colontmp__8)) goto LA99;
																	i_12 = i_13;
																	memberSym = (*identDefs)._kind_6.sons->data[i_12];
																	sym = memberSym;
																	value = valueSym;
																	{
																		if (!!(((*value).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)))) goto LA102_;
																		asgnRef((void**) (&(*asgn)._kind_6.sons->data[((NI) 0)]), sym);
																		asgnRef((void**) (&(*asgn)._kind_6.sons->data[((NI) 1)]), value);
																		genStmts__cgen_11522(p, asgn);
																	}
																	LA102_: ;
																	i_13 += ((NI) 1);
																} LA99: ;
															}
														}
													}
													LA93_: ;
													i_11 += ((NI) 1);
												} LA90: ;
											}
										}
									}
								}
							}
							goto LA82_;
							LA84_: ;
							{
								genStmts__cgen_11522(p, it_3);
							}
							LA82_: ;
							i_9 += ((NI) 1);
						} LA81: ;
					}
				}
				nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
				initLocExpr__cgen_11548(p, (*caseStmt)._kind_6.sons->data[((NI) 0)], (&a_2));
				T105_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T105_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				nimZeroMem((void*)T106_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
				T106_[0] = tmp;
				T106_[1] = rdLoc__cgen_435(a_2);
				T107_ = NIM_NIL;
				T107_ = percent___cgen_14489(T106_, 2);
				T108_ = NIM_NIL;
				T108_ = indentLine__cgen_286(p, T107_);
				add__ropes_159(T105_, T108_);
				endBlock__cgen_13329(p);
				i_6 += ((NI) 1);
			} LA53: ;
		}
	}
	{
		NI j_5;
		NI colontmp__9;
		NI colontmp__10;
		NI i_14;
		j_5 = (NI)0;
		colontmp__9 = (NI)0;
		colontmp__10 = (NI)0;
		colontmp__9 = (NI)(casePos + ((NI) 1));
		colontmp__10 = len__ast_3155(n_2);
		i_14 = colontmp__9;
		{
			while (1) {
				if (!(i_14 < colontmp__10)) goto LA111;
				j_5 = i_14;
				genStmts__cgen_11522(p, (*n_2)._kind_6.sons->data[j_5]);
				i_14 += ((NI) 1);
			} LA111: ;
		}
	}
	}BeforeRet_: ;
}
static N_INLINE(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, assignLabel__cgen_13551)(tyObject_TBlock__FHXN9cI0ri9bj2d9cKw8iPHZg* b) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = rope__ropes_115(((NI64) ((*b).id)));
	unsureAsgnRef((void**) (&(*b).label), amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_466), T1_));
	result = (*b).label;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genWhileStmt__cgen_14588)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	NI oldBreakIdxX60gensym1990_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* loopBody;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	(*p).withinLoop += ((NI) 1);
	genLineDir__cgen_369(p, t);
	oldBreakIdxX60gensym1990_ = (*p).breakIdx;
	loopBody = (*t)._kind_6.sons->data[((NI) 1)];
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = stmtsContainPragma__ccgutils_42(loopBody, ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 206));
		if (!(T3_)) goto LA4_;
		T3_ = ((CC__extccomp_510[((*(*(*(*p).module).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__9biNtFPzjM9c2i62RuZ9c19biA) 1))&7U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			NIM_BOOL T9_;
			NI T10_;
			T9_ = (NIM_BOOL)0;
			T10_ = (NI)0;
			T10_ = len__ast_3155(loopBody);
			T9_ = (T10_ == ((NI) 2));
			if (!(T9_)) goto LA11_;
			T9_ = ((*(*loopBody)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1));
			LA11_: ;
			if (!T9_) goto LA12_;
			loopBody = (*loopBody)._kind_6.sons->data[((NI) 1)];
		}
		LA12_: ;
		genComputedGoto__cgen_14416(p, loopBody);
	}
	goto LA1_;
	LA5_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T15_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T21_;
		T15_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T15_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 11);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_756));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA18_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA18_: ;
		T20_ = NIM_NIL;
		T20_ = rope__ropes_109(res);
		T21_ = NIM_NIL;
		T21_ = indentLine__cgen_286(p, T20_);
		add__ropes_159(T15_, T21_);
		(*p).breakIdx = startBlockInternal__cgen_13308(p);
		(*p).blocks->data[(*p).breakIdx].isLoop = NIM_TRUE;
		initLocExpr__cgen_11548(p, (*t)._kind_6.sons->data[((NI) 0)], (&a));
		{
			NIM_BOOL T24_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* label;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T28_;
			tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T29_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T30_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T31_;
			T24_ = (NIM_BOOL)0;
			T24_ = !(((*(*t)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6)));
			if (T24_) goto LA25_;
			T24_ = ((*(*t)._kind_6.sons->data[((NI) 0)])._kind_1.intVal == IL64(0));
			LA25_: ;
			if (!T24_) goto LA26_;
			label = assignLabel__cgen_13551((&(*p).blocks->data[(*p).breakIdx]));
			T28_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T28_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			nimZeroMem((void*)T29_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
			T29_[0] = rdLoc__cgen_435(a);
			T29_[1] = label;
			T30_ = NIM_NIL;
			T30_ = percent___cgen_14226(T29_, 2);
			T31_ = NIM_NIL;
			T31_ = indentLine__cgen_286(p, T30_);
			add__ropes_159(T28_, T31_);
		}
		LA26_: ;
		genStmts__cgen_11522(p, loopBody);
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T36_;
			NimStringDesc* res_2;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T37_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T42_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T43_;
			if (!(((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 21))&31U)))!=0)) goto LA34_;
			T36_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T36_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_2 = rawNewString(((NI) 80));
			T37_ = NIM_NIL;
			T37_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_325));
			cgFormatValue__cgen_147((&res_2), T37_);
			res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_312));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA40_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA40_: ;
			T42_ = NIM_NIL;
			T42_ = rope__ropes_109(res_2);
			T43_ = NIM_NIL;
			T43_ = indentLine__cgen_286(p, T42_);
			add__ropes_159(T36_, T43_);
		}
		LA34_: ;
		endBlock__cgen_13329(p);
	}
	LA1_: ;
	(*p).breakIdx = oldBreakIdxX60gensym1990_;
	(*p).withinLoop -= ((NI) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, genSingleVar__cgen_14124)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* v;
{	v = (*(*a)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
	{
		if (!(((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 28))&63U)))!=0)) goto LA3_;
		{
			NIM_BOOL T7_;
			NIM_BOOL T8_;
			T7_ = (NIM_BOOL)0;
			T8_ = (NIM_BOOL)0;
			T8_ = (((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 3))&63U)))!=0);
			if (!(T8_)) goto LA9_;
			T8_ = !(((*p).prc == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
			LA9_: ;
			T7_ = T8_;
			if (!(T7_)) goto LA10_;
			T7_ = ((*(*p).prc).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 12));
			LA10_: ;
			if (!T7_) goto LA11_;
		}
		goto LA5_;
		LA11_: ;
		{
			goto BeforeRet_;
		}
		LA5_: ;
	}
	LA3_: ;
	genSingleVar__cgen_13925(p, v, (*a)._kind_6.sons->data[((NI) 0)], (*a)._kind_6.sons->data[((NI) 2)]);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genClosureVar__cgen_14147)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a) {
	NIM_BOOL immediateAsgn;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw v;
	immediateAsgn = !(((*(*a)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)));
	nimZeroMem((void*)(&v), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, (*a)._kind_6.sons->data[((NI) 0)], (&v));
	genLineDir__cgen_369(p, a);
	{
		if (!immediateAsgn) goto LA3_;
		loadInto__cgen_13528(p, (*a)._kind_6.sons->data[((NI) 0)], (*a)._kind_6.sons->data[((NI) 2)], (&v));
	}
	goto LA1_;
	LA3_: ;
	{
		if (!!((((*(*(*(*a)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 14))&63U)))!=0))) goto LA6_;
		constructLoc__cgen_10987(p, (&v), NIM_FALSE);
	}
	goto LA1_;
	LA6_: ;
	LA1_: ;
}
static N_NIMCALL(void, Marker_tySequence__Vz8km29c8JcWq5WOBlnn2aQ)(void* p, NI op) {
	tySequence__Vz8km29c8JcWq5WOBlnn2aQ* a;
	NI T1_;
	a = (tySequence__Vz8km29c8JcWq5WOBlnn2aQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field0.lode, op);
	nimGCvisit((void*)a->data[T1_].Field0.r, op);
	nimGCvisit((void*)a->data[T1_].Field1, op);
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genVarTuple__cgen_13331)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tup;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw field;
	NIM_BOOL forHcr;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* hcrCond;
	tySequence__Vz8km29c8JcWq5WOBlnn2aQ* hcrGlobals;
	NIM_BOOL isGlobalInBlock;
	NIM_BOOL T19_;
	NI T21_;
	NIM_BOOL T22_;
	NI T43_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T44_;
{	nimZeroMem((void*)(&tup), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&field), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	{
		if (!!(((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 36)))) goto LA3_;
		internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_757), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_758);
	}
	LA3_: ;
	{
		NI i;
		NI colontmp_;
		NI T6_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T6_ = (NI)0;
		T6_ = len__ast_3155(n);
		colontmp_ = (NI)(T6_ - ((NI) 2));
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA8;
				i = i_2;
				{
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T13_;
					if (!!(((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)))) goto LA11_;
					T13_ = NIM_NIL;
					T13_ = lowerTupleUnpacking__lowerings_116((*(*(*p).module).g).graph, n, (*(*p).module).Sup.idgen, (*p).prc);
					genStmts__cgen_11522(p, T13_);
					goto BeforeRet_;
				}
				LA11_: ;
				i_2 += ((NI) 1);
			} LA8: ;
		}
	}
	forHcr = treatGlobalDifferentlyForHCR__cgen_11316((*p).module, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
	{
		if (!forHcr) goto LA16_;
		hcrCond = getTempName__cgen_428((*p).module);
	}
	goto LA14_;
	LA16_: ;
	{
		hcrCond = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
	}
	LA14_: ;
	hcrGlobals = NIM_NIL;
	T19_ = (NIM_BOOL)0;
	T19_ = forHcr;
	if (!(T19_)) goto LA20_;
	T21_ = ((*p).blocks ? (*p).blocks->Sup.len : 0);
	T19_ = (((NI) 2) < T21_);
	LA20_: ;
	isGlobalInBlock = T19_;
	T22_ = (NIM_BOOL)0;
	T22_ = forHcr;
	if (!(T22_)) goto LA23_;
	T22_ = !(isGlobalInBlock);
	LA23_: ;
	forHcr = T22_;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T28_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T33_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T34_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T35_;
		NimStringDesc* res_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T40_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T41_;
		NI T42_;
		if (!forHcr) goto LA26_;
		T28_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T28_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
		cgFormatValue__cgen_147((&res), hcrCond);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA31_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA31_: ;
		T33_ = NIM_NIL;
		T33_ = rope__ropes_109(res);
		T34_ = NIM_NIL;
		T34_ = indentLine__cgen_286(p, T33_);
		add__ropes_159(T28_, T34_);
		T35_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T35_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA38_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA38_: ;
		T40_ = NIM_NIL;
		T40_ = rope__ropes_109(res_2);
		T41_ = NIM_NIL;
		T41_ = indentLine__cgen_286(p, T40_);
		add__ropes_159(T35_, T41_);
		T42_ = (NI)0;
		T42_ = startBlockInternal__cgen_13308(p);
	}
	LA26_: ;
	genLineDir__cgen_369(p, n);
	T43_ = (NI)0;
	T43_ = len__ast_3155(n);
	initLocExpr__cgen_11548(p, (*n)._kind_6.sons->data[(NI)(T43_ - ((NI) 1))], (&tup));
	T44_ = NIM_NIL;
	T44_ = t__cgen_85(tup);
	t = skipTypes__ast_3723(T44_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
	{
		NI i_3;
		NI colontmp__2;
		NI T46_;
		NI i_4;
		i_3 = (NI)0;
		colontmp__2 = (NI)0;
		T46_ = (NI)0;
		T46_ = len__ast_3155(n);
		colontmp__2 = (NI)(T46_ - ((NI) 2));
		i_4 = ((NI) 0);
		{
			while (1) {
				if (!(i_4 < colontmp__2)) goto LA48;
				i_3 = i_4;
				{
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* vn;
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* v;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* traverseProc;
					vn = (*n)._kind_6.sons->data[i_3];
					v = (*vn)._kind_4.sym;
					{
						if (!(((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 28))&63U)))!=0)) goto LA52_;
						goto LA49;
					}
					LA52_: ;
					traverseProc = NIM_NIL;
					{
						if (!(((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 3))&63U)))!=0)) goto LA56_;
						assignGlobalVar__cgen_11336(p, vn, ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL));
						genObjectInit__cgen_10414(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 1), (*v).typ, (&(*v).loc), ((tyEnum_ObjConstrMode__fUO6aSwLQdJNwZTWRxqbKg) 0));
						traverseProc = getTraverseProc__cgen_13183(p, v);
						{
							NIM_BOOL T60_;
							NIM_BOOL T62_;
							T60_ = (NIM_BOOL)0;
							T60_ = !((traverseProc == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)));
							if (!(T60_)) goto LA61_;
							T62_ = (NIM_BOOL)0;
							T62_ = hcrOn__cgen_46(p);
							T60_ = !(T62_);
							LA61_: ;
							if (!T60_) goto LA63_;
							registerTraverseProc__cgen_13195(p, v, traverseProc);
						}
						LA63_: ;
					}
					goto LA54_;
					LA56_: ;
					{
						NI T66_;
						NIM_BOOL T67_;
						assignLocalVar__cgen_11164(p, vn);
						T66_ = (NI)0;
						T66_ = len__ast_3155(n);
						T67_ = (NIM_BOOL)0;
						T67_ = isAssignedImmediately__cgen_13245((*(*(*p).module).g).config, (*n)._kind_6.sons->data[(NI)(T66_ - ((NI) 1))]);
						initLocalVar__cgen_11052(p, v, T67_);
					}
					LA54_: ;
					initLoc__cgen_66((&field), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 6), vn, tup.storage);
					{
						tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T72_;
						if (!((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18))) goto LA70_;
						nimZeroMem((void*)T72_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
						T72_[0] = rdLoc__cgen_435(tup);
						T72_[1] = rope__ropes_115(((NI64) (i_3)));
						field.r = percent___cgen_13428(T72_, 2);
					}
					goto LA68_;
					LA70_: ;
					{
						tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T78_;
						{
							if (!!(((*(*(*t).n)._kind_6.sons->data[i_3]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)))) goto LA76_;
							internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_757), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_759);
						}
						LA76_: ;
						nimZeroMem((void*)T78_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
						T78_[0] = rdLoc__cgen_435(tup);
						T78_[1] = mangleRecFieldName__cgen_3649((*p).module, (*(*(*t).n)._kind_6.sons->data[i_3])._kind_4.sym);
						field.r = percent___cgen_7469(T78_, 2);
					}
					LA68_: ;
					putLocIntoDest__cgen_11532(p, (&(*v).loc), field);
					{
						NIM_BOOL T81_;
						tyTuple__PCL3pTh9cmlWmhmXAE5IOKQ T85_;
						NI T92_;
						T81_ = (NIM_BOOL)0;
						T81_ = forHcr;
						if (T81_) goto LA82_;
						T81_ = isGlobalInBlock;
						LA82_: ;
						if (!T81_) goto LA83_;
						nimZeroMem((void*)(&T85_), sizeof(tyTuple__PCL3pTh9cmlWmhmXAE5IOKQ));
						genericAssign((void*)(&T85_.Field0), (void*)(&(*v).loc), (&NTItloc__CAJV4zTUpZwr0j6Wy8FiFw_));
						{
							tyArray__dAmhZbEWrTM5xES2bTVweg T90_;
							if (!(traverseProc == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA88_;
							nimZeroMem((void*)T90_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
							T85_.Field1 = percent___cgen_13448(T90_, 0);
						}
						goto LA86_;
						LA88_: ;
						{
							T85_.Field1 = traverseProc;
						}
						LA86_: ;
						hcrGlobals = (tySequence__Vz8km29c8JcWq5WOBlnn2aQ*) incrSeqV3((TGenericSeq*)(hcrGlobals), (&NTIseqLtupleLloc58tloc_tp58ropeTT__Vz8km29c8JcWq5WOBlnn2aQ_));
						T92_ = hcrGlobals->Sup.len++;
						genericAssign((void*)(&hcrGlobals->data[T92_].Field0), (void*)(&T85_.Field0), (&NTItloc__CAJV4zTUpZwr0j6Wy8FiFw_));
						asgnRef((void**) (&hcrGlobals->data[T92_].Field1), T85_.Field1);
					}
					LA83_: ;
				} LA49: ;
				i_4 += ((NI) 1);
			} LA48: ;
		}
	}
	{
		if (!forHcr) goto LA95_;
		endBlock__cgen_13329(p);
	}
	LA95_: ;
	{
		NIM_BOOL T99_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T103_;
		NimStringDesc* res_3;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T108_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T109_;
		T99_ = (NIM_BOOL)0;
		T99_ = forHcr;
		if (T99_) goto LA100_;
		T99_ = isGlobalInBlock;
		LA100_: ;
		if (!T99_) goto LA101_;
		T103_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T103_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
		res_3 = rawNewString(((NI) 80));
		res_3 = resizeString(res_3, 9);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_761));
		cgFormatValue__cgen_147((&res_3), hcrCond);
		res_3 = resizeString(res_3, 13);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_762));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA106_;
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA106_: ;
		T108_ = NIM_NIL;
		T108_ = rope__ropes_109(res_3);
		T109_ = NIM_NIL;
		T109_ = indentLine__cgen_286(p, T108_);
		add__ropes_159(T103_, T109_);
		{
			tyTuple__PCL3pTh9cmlWmhmXAE5IOKQ* curr;
			NI i_5;
			NI L;
			NI T111_;
			curr = (tyTuple__PCL3pTh9cmlWmhmXAE5IOKQ*)0;
			i_5 = ((NI) 0);
			T111_ = (hcrGlobals ? hcrGlobals->Sup.len : 0);
			L = T111_;
			{
				while (1) {
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T114_;
					NimStringDesc* res_4;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T115_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T116_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T117_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T118_;
					if (!(i_5 < L)) goto LA113;
					curr = (&hcrGlobals->data[i_5]);
					T114_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T114_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
					res_4 = rawNewString(((NI) 80));
					cgFormatValue__cgen_147((&res_4), hcrCond);
					res_4 = resizeString(res_4, 22);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_763));
					T115_ = NIM_NIL;
					T115_ = getModuleDllPath__cgen_142((*p).module, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
					cgFormatValue__cgen_147((&res_4), T115_);
					res_4 = resizeString(res_4, 3);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_408));
					cgFormatValue__cgen_147((&res_4), (*curr).Field0.r);
					res_4 = resizeString(res_4, 10);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_409));
					T116_ = NIM_NIL;
					T116_ = rdLoc__cgen_435((*curr).Field0);
					cgFormatValue__cgen_147((&res_4), T116_);
					res_4 = resizeString(res_4, 3);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_410));
					cgFormatValue__cgen_147((&res_4), (*curr).Field1);
					res_4 = resizeString(res_4, 11);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_411));
					cgFormatValue__cgen_147((&res_4), (*curr).Field0.r);
					res_4 = resizeString(res_4, 3);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_764));
					T117_ = NIM_NIL;
					T117_ = rope__ropes_109(res_4);
					T118_ = NIM_NIL;
					T118_ = indentLine__cgen_286(p, T117_);
					add__ropes_159(T114_, T118_);
					i_5 += ((NI) 1);
				} LA113: ;
			}
		}
	}
	LA101_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genVarStmt__cgen_14166)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** it;
		tySequence__IeU9azYSNIK3V9b36Ir6NZcw* colontmp_;
		NI i;
		NI L;
		NI T2_;
		it = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
		colontmp_ = NIM_NIL;
		colontmp_ = (*n)._kind_6.sons;
		i = ((NI) 0);
		T2_ = (colontmp_ ? colontmp_->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				it = &colontmp_->data[i];
				{
					{
						if (!((*(*it)).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 125))) goto LA8_;
						goto LA5;
					}
					LA8_: ;
					{
						if (!((*(*it)).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 35))) goto LA12_;
						{
							if (!((*(*(*it))._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA16_;
							genSingleVar__cgen_14124(p, (*it));
						}
						goto LA14_;
						LA16_: ;
						{
							genClosureVar__cgen_14147(p, (*it));
						}
						LA14_: ;
					}
					goto LA10_;
					LA12_: ;
					{
						genVarTuple__cgen_13331(p, (*it));
					}
					LA10_: ;
				} LA5: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genConstStmt__cgen_24590)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m;
	m = (*p).module;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
		it = NIM_NIL;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					it = (*n)._kind_6.sons->data[i];
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
						if (!((*(*it)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA7_;
						sym = (*(*it)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
						{
							NIM_BOOL T11_;
							NIM_BOOL T12_;
							NIM_BOOL T13_;
							T11_ = (NIM_BOOL)0;
							T12_ = (NIM_BOOL)0;
							T13_ = (NIM_BOOL)0;
							T13_ = isSimpleConst__cgen_95((*sym).typ);
							T12_ = !(T13_);
							if (!(T12_)) goto LA14_;
							T12_ = contains__astalgo_3489((&(*m).alive), ((NI) ((*sym).Sup.itemId.item)));
							LA14_: ;
							T11_ = T12_;
							if (!(T11_)) goto LA15_;
							T11_ = genConstSetup__cgen_24498(p, sym);
							LA15_: ;
							if (!T11_) goto LA16_;
							genConstDefinition__cgen_24558(m, p, sym);
						}
						LA16_: ;
					}
					LA7_: ;
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genCaseStringBranch__cgen_15118)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw e, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* labl, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** branches, NI branchesLen_0) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw x;
	nimZeroMem((void*)(&x), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (NI)0;
		T2_ = len__ast_3155(b);
		colontmp_ = (NI)(T2_ - ((NI) 1));
		i_2 = ((NI) 0);
		{
			while (1) {
				NI j;
				NI64 T5_;
				NimStringDesc* res;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				initLocExpr__cgen_11548(p, (*b)._kind_6.sons->data[i], (&x));
				T5_ = (NI64)0;
				T5_ = hashString__ccgutils_50((*(*(*p).module).g).config, (*(*b)._kind_6.sons->data[i])._kind_3.strVal);
				j = ((NI) ((NI64)(T5_ & ((NI64) ((branchesLen_0-1))))));
				res = rawNewString(((NI) 80));
				res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
				T6_ = NIM_NIL;
				T6_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_537));
				cgFormatValue__cgen_147((&res), T6_);
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
				T7_ = NIM_NIL;
				T7_ = rdLoc__cgen_435(e);
				cgFormatValue__cgen_147((&res), T7_);
				res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
				T8_ = NIM_NIL;
				T8_ = rdLoc__cgen_435(x);
				cgFormatValue__cgen_147((&res), T8_);
				res = resizeString(res, 8);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_767));
				cgFormatValue__cgen_147((&res), labl);
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA11_;
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA11_: ;
				T13_ = NIM_NIL;
				T13_ = rope__ropes_109(res);
				add__ropes_159(&branches[j], T13_);
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, exprBlock__cgen_13615)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T1_;
	NimStringDesc* res;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
	NI T8_;
	T1_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T1_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	res = rawNewString(((NI) 80));
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA4_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA4_: ;
	T6_ = NIM_NIL;
	T6_ = rope__ropes_109(res);
	T7_ = NIM_NIL;
	T7_ = indentLine__cgen_286(p, T6_);
	add__ropes_159(T1_, T7_);
	T8_ = (NI)0;
	T8_ = startBlockInternal__cgen_13308(p);
	expr__cgen_11525(p, n, d);
	endBlock__cgen_13329(p);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genCaseSecondPass__cgen_15059)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d, NI labId, NI until) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* lend;
	result = NIM_NIL;
	lend = getLabel__cgen_11501(p);
	{
		NI i;
		NI res;
		i = (NI)0;
		res = ((NI) 1);
		{
			while (1) {
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T10_;
				tyArray__ts9cf9blICas1QWmw89bglZ7w T11_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
				if (!(res <= until)) goto LA3;
				i = res;
				{
					NIM_BOOL T6_;
					T6_ = (NIM_BOOL)0;
					T6_ = ((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 1));
					if (!(T6_)) goto LA7_;
					T6_ = isEmptyType__ast_4780((*t).typ);
					LA7_: ;
					if (!T6_) goto LA8_;
					(*d).k = ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0);
				}
				LA8_: ;
				T10_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T10_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				nimZeroMem((void*)T11_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
				T11_[0] = rope__ropes_115(((NI64) ((NI)(labId + i))));
				T12_ = NIM_NIL;
				T12_ = percent___cgen_15076(T11_, 1);
				T13_ = NIM_NIL;
				T13_ = indentLine__cgen_286(p, T12_);
				add__ropes_159(T10_, T13_);
				{
					NI T18_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T19_;
					tyArray__ts9cf9blICas1QWmw89bglZ7w T20_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T21_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
					if (!((*(*t)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 85))) goto LA16_;
					T18_ = (NI)0;
					T18_ = len__ast_3155((*t)._kind_6.sons->data[i]);
					exprBlock__cgen_13615(p, (*(*t)._kind_6.sons->data[i])._kind_6.sons->data[(NI)(T18_ - ((NI) 1))], d);
					T19_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T19_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					nimZeroMem((void*)T20_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
					T20_[0] = lend;
					T21_ = NIM_NIL;
					T21_ = percent___cgen_14244(T20_, 1);
					T22_ = NIM_NIL;
					T22_ = indentLine__cgen_286(p, T21_);
					add__ropes_159(T19_, T22_);
				}
				goto LA14_;
				LA16_: ;
				{
					exprBlock__cgen_13615(p, (*(*t)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)], d);
				}
				LA14_: ;
				res += ((NI) 1);
			} LA3: ;
		}
	}
	result = lend;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genStringCase__cgen_15168)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	NI strings;
	strings = ((NI) 0);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(t);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					NI T8_;
					if (!((*(*t)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 85))) goto LA6_;
					T8_ = (NI)0;
					T8_ = len__ast_3155((*t)._kind_6.sons->data[i]);
					strings += (NI)(T8_ - ((NI) 1));
				}
				LA6_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	{
		NI bitMask;
		NI T13_;
		tySequence__UQWyowqEA29c6NZ9csQYyjXQ* branches;
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
		NI labId;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T25_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T27_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T32_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T33_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T46_;
		tyArray__dAmhZbEWrTM5xES2bTVweg T47_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T48_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T49_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* lend;
		NI T59_;
		if (!(((NI) 8) < strings)) goto LA11_;
		T13_ = (NI)0;
		T13_ = nextPowerOfTwo__pureZmath_177(strings);
		bitMask = (NI)(T13_ - ((NI) 1));
		branches = NIM_NIL;
		branches = (tySequence__UQWyowqEA29c6NZ9csQYyjXQ*) newSeq((&NTIseqLropeT__UQWyowqEA29c6NZ9csQYyjXQ_), ((NI) ((NI)(bitMask + ((NI) 1)))));
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548(p, (*t)._kind_6.sons->data[((NI) 0)], (&a));
		labId = (*p).labels;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3155(t);
			i_4 = ((NI) 1);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA16;
					i_3 = i_4;
					(*p).labels += ((NI) 1);
					{
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T21_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
						if (!((*(*t)._kind_6.sons->data[i_3]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 85))) goto LA19_;
						T21_ = NIM_NIL;
						T21_ = rope__ropes_115(((NI64) ((*p).labels)));
						T22_ = NIM_NIL;
						T22_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_466), T21_);
						T23_ = NIM_NIL;
						T23_ = amp___ropes_140(T22_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3));
						genCaseStringBranch__cgen_15118(p, (*t)._kind_6.sons->data[i_3], a, T23_, (branches) ? (branches->data) : NIM_NIL, (branches ? branches->Sup.len : 0));
					}
					goto LA17_;
					LA19_: ;
					{
					}
					LA17_: ;
					i_4 += ((NI) 1);
				} LA16: ;
			}
		}
		T25_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T25_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 8);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_768));
		T26_ = NIM_NIL;
		T26_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_769));
		cgFormatValue__cgen_147((&res), T26_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
		T27_ = NIM_NIL;
		T27_ = rdLoc__cgen_435(a);
		cgFormatValue__cgen_147((&res), T27_);
		res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_770));
		cgFormatValue__cgen_154((&res), ((NI64) (bitMask)));
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_771));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA30_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA30_: ;
		T32_ = NIM_NIL;
		T32_ = rope__ropes_109(res);
		T33_ = NIM_NIL;
		T33_ = indentLine__cgen_286(p, T32_);
		add__ropes_159(T25_, T33_);
		{
			NI j;
			NI colontmp__3;
			NI T35_;
			NI res_2;
			j = (NI)0;
			colontmp__3 = (NI)0;
			T35_ = ((branches ? branches->Sup.len : 0)-1);
			colontmp__3 = T35_;
			res_2 = ((NI) 0);
			{
				while (1) {
					if (!(res_2 <= colontmp__3)) goto LA37;
					j = res_2;
					{
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T42_;
						tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T43_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T44_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T45_;
						if (!!((branches->data[j] == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA40_;
						T42_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
						T42_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
						nimZeroMem((void*)T43_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
						T43_[0] = intLiteral__cgen_11536(((NI64) (j)));
						T43_[1] = branches->data[j];
						T44_ = NIM_NIL;
						T44_ = percent___cgen_15246(T43_, 2);
						T45_ = NIM_NIL;
						T45_ = indentLine__cgen_286(p, T44_);
						add__ropes_159(T42_, T45_);
					}
					LA40_: ;
					res_2 += ((NI) 1);
				} LA37: ;
			}
		}
		T46_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T46_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		nimZeroMem((void*)T47_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		T48_ = NIM_NIL;
		T48_ = percent___cgen_7535(T47_, 0);
		T49_ = NIM_NIL;
		T49_ = indentLine__cgen_286(p, T48_);
		add__ropes_159(T46_, T49_);
		{
			NI T52_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T55_;
			tyArray__ts9cf9blICas1QWmw89bglZ7w T56_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T57_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T58_;
			T52_ = (NI)0;
			T52_ = len__ast_3155(t);
			if (!!(((*(*t)._kind_6.sons->data[(NI)(T52_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 85)))) goto LA53_;
			T55_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T55_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			nimZeroMem((void*)T56_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T56_[0] = rope__ropes_115(((NI64) ((*p).labels)));
			T57_ = NIM_NIL;
			T57_ = percent___cgen_15264(T56_, 1);
			T58_ = NIM_NIL;
			T58_ = indentLine__cgen_286(p, T57_);
			add__ropes_159(T55_, T58_);
		}
		LA53_: ;
		T59_ = (NI)0;
		T59_ = len__ast_3155(t);
		lend = genCaseSecondPass__cgen_15059(p, t, d, ((NI) (labId)), (NI)(T59_ - ((NI) 1)));
		fixLabel__cgen_11508(p, lend);
	}
	goto LA9_;
	LA11_: ;
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym2212_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* lendX60gensym2212_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* resX60gensym2214_;
		NI labIdX60gensym2214_;
		nimZeroMem((void*)(&aX60gensym2212_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548(p, (*t)._kind_6.sons->data[((NI) 0)], (&aX60gensym2212_));
		resX60gensym2214_ = NIM_NIL;
		labIdX60gensym2214_ = (*p).labels;
		{
			NI iX60gensym2214_;
			NI colontmp__4;
			NI T62_;
			NI res_3;
			iX60gensym2214_ = (NI)0;
			colontmp__4 = (NI)0;
			T62_ = (NI)0;
			T62_ = len__ast_3155(t);
			colontmp__4 = (NI)(T62_ - ((NI) 1));
			res_3 = ((NI) 1);
			{
				while (1) {
					if (!(res_3 <= colontmp__4)) goto LA64;
					iX60gensym2214_ = res_3;
					(*p).labels += ((NI) 1);
					{
						tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw xX60gensym2217_;
						tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw yX60gensym2217_;
						if (!((*(*t)._kind_6.sons->data[iX60gensym2214_]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 85))) goto LA67_;
						nimZeroMem((void*)(&xX60gensym2217_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
						nimZeroMem((void*)(&yX60gensym2217_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
						{
							NI iX60gensym2217_;
							NI colontmp__5;
							NI T70_;
							NI i_5;
							iX60gensym2217_ = (NI)0;
							colontmp__5 = (NI)0;
							T70_ = (NI)0;
							T70_ = len__ast_3155((*t)._kind_6.sons->data[iX60gensym2214_]);
							colontmp__5 = (NI)(T70_ - ((NI) 1));
							i_5 = ((NI) 0);
							{
								while (1) {
									if (!(i_5 < colontmp__5)) goto LA72;
									iX60gensym2217_ = i_5;
									{
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T77_;
										NimStringDesc* res_4;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T78_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T79_;
										if (!((*(*(*t)._kind_6.sons->data[iX60gensym2214_])._kind_6.sons->data[iX60gensym2217_]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 44))) goto LA75_;
										initLocExpr__cgen_11548(p, (*(*(*t)._kind_6.sons->data[iX60gensym2214_])._kind_6.sons->data[iX60gensym2217_])._kind_6.sons->data[((NI) 0)], (&xX60gensym2217_));
										initLocExpr__cgen_11548(p, (*(*(*t)._kind_6.sons->data[iX60gensym2214_])._kind_6.sons->data[iX60gensym2217_])._kind_6.sons->data[((NI) 1)], (&yX60gensym2217_));
										T77_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
										T77_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
										res_4 = rawNewString(((NI) 80));
										T78_ = NIM_NIL;
										T78_ = rope__ropes_109(res_4);
										T79_ = NIM_NIL;
										T79_ = indentLine__cgen_286(p, T78_);
										add__ropes_159(T77_, T79_);
									}
									goto LA73_;
									LA75_: ;
									{
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T81_;
										NimStringDesc* res_5;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T82_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T83_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T84_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T85_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T86_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T87_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T92_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T93_;
										initLocExpr__cgen_11548(p, (*(*t)._kind_6.sons->data[iX60gensym2214_])._kind_6.sons->data[iX60gensym2217_], (&xX60gensym2217_));
										T81_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
										T81_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
										res_5 = rawNewString(((NI) 80));
										res_5 = resizeString(res_5, 4);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
										T82_ = NIM_NIL;
										T82_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_537));
										cgFormatValue__cgen_147((&res_5), T82_);
										res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
										T83_ = NIM_NIL;
										T83_ = rdCharLoc__cgen_10377(aX60gensym2212_);
										cgFormatValue__cgen_147((&res_5), T83_);
										res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
										T84_ = NIM_NIL;
										T84_ = rdCharLoc__cgen_10377(xX60gensym2217_);
										cgFormatValue__cgen_147((&res_5), T84_);
										res_5 = resizeString(res_5, 8);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_767));
										T85_ = NIM_NIL;
										T85_ = rope__ropes_115(((NI64) ((*p).labels)));
										T86_ = NIM_NIL;
										T86_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_466), T85_);
										T87_ = NIM_NIL;
										T87_ = amp___ropes_140(T86_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3));
										cgFormatValue__cgen_147((&res_5), T87_);
										res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
										{
											if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA90_;
											res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
										}
										LA90_: ;
										T92_ = NIM_NIL;
										T92_ = rope__ropes_109(res_5);
										T93_ = NIM_NIL;
										T93_ = indentLine__cgen_286(p, T92_);
										add__ropes_159(T81_, T93_);
									}
									LA73_: ;
									i_5 += ((NI) 1);
								} LA72: ;
							}
						}
					}
					goto LA65_;
					LA67_: ;
					{
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T95_;
						tyArray__ts9cf9blICas1QWmw89bglZ7w T96_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T97_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T98_;
						T95_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
						T95_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
						nimZeroMem((void*)T96_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
						T96_[0] = rope__ropes_115(((NI64) ((*p).labels)));
						T97_ = NIM_NIL;
						T97_ = percent___cgen_15264(T96_, 1);
						T98_ = NIM_NIL;
						T98_ = indentLine__cgen_286(p, T97_);
						add__ropes_159(T95_, T98_);
					}
					LA65_: ;
					res_3 += ((NI) 1);
				} LA64: ;
			}
		}
		{
			NI T101_;
			NI T102_;
			NI gotoTargetX60gensym2214_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T105_;
			tyArray__ts9cf9blICas1QWmw89bglZ7w T106_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T107_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T108_;
			NI T109_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T110_;
			tyArray__ts9cf9blICas1QWmw89bglZ7w T111_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T112_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T113_;
			T101_ = (NI)0;
			T101_ = len__ast_3155(t);
			T102_ = (NI)0;
			T102_ = len__ast_3155(t);
			if (!((NI)(T101_ - ((NI) 1)) < (NI)(T102_ - ((NI) 1)))) goto LA103_;
			(*p).labels += ((NI) 1);
			gotoTargetX60gensym2214_ = (*p).labels;
			T105_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T105_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			nimZeroMem((void*)T106_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T106_[0] = rope__ropes_115(((NI64) (gotoTargetX60gensym2214_)));
			T107_ = NIM_NIL;
			T107_ = percent___cgen_15264(T106_, 1);
			T108_ = NIM_NIL;
			T108_ = indentLine__cgen_286(p, T107_);
			add__ropes_159(T105_, T108_);
			T109_ = (NI)0;
			T109_ = len__ast_3155(t);
			resX60gensym2214_ = genCaseSecondPass__cgen_15059(p, t, d, ((NI) (labIdX60gensym2214_)), (NI)(T109_ - ((NI) 1)));
			T110_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T110_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			nimZeroMem((void*)T111_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T111_[0] = rope__ropes_115(((NI64) (gotoTargetX60gensym2214_)));
			T112_ = NIM_NIL;
			T112_ = percent___cgen_15076(T111_, 1);
			T113_ = NIM_NIL;
			T113_ = indentLine__cgen_286(p, T112_);
			add__ropes_159(T110_, T113_);
		}
		goto LA99_;
		LA103_: ;
		{
			NI T115_;
			T115_ = (NI)0;
			T115_ = len__ast_3155(t);
			resX60gensym2214_ = genCaseSecondPass__cgen_15059(p, t, d, ((NI) (labIdX60gensym2214_)), (NI)(T115_ - ((NI) 1)));
		}
		LA99_: ;
		lendX60gensym2212_ = resX60gensym2214_;
		fixLabel__cgen_11508(p, lendX60gensym2212_);
	}
	LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genGotoForCase__cgen_14333)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* caseStmt) {
{	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(caseStmt);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T4_;
				NimStringDesc* res;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
				NI T11_;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T24_;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				T4_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T4_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res = rawNewString(((NI) 80));
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA7_;
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA7_: ;
				T9_ = NIM_NIL;
				T9_ = rope__ropes_109(res);
				T10_ = NIM_NIL;
				T10_ = indentLine__cgen_286(p, T9_);
				add__ropes_159(T4_, T10_);
				T11_ = (NI)0;
				T11_ = startBlockInternal__cgen_13308(p);
				it = (*caseStmt)._kind_6.sons->data[i];
				{
					NI j;
					NI colontmp__2;
					NI T13_;
					NI i_3;
					j = (NI)0;
					colontmp__2 = (NI)0;
					T13_ = (NI)0;
					T13_ = len__ast_3155(it);
					colontmp__2 = (NI)(T13_ - ((NI) 1));
					i_3 = ((NI) 0);
					{
						while (1) {
							tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ val;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T20_;
							tyArray__ts9cf9blICas1QWmw89bglZ7w T21_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
							if (!(i_3 < colontmp__2)) goto LA15;
							j = i_3;
							{
								if (!((*(*it)._kind_6.sons->data[j]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 44))) goto LA18_;
								liMessage__msgs_1128((*(*(*p).module).g).config, (*it).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_754), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_775, NIM_FALSE);
								goto BeforeRet_;
							}
							LA18_: ;
							val = getOrdValue__types_161((*it)._kind_6.sons->data[j], Max__int495056_27);
							T20_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
							T20_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
							nimZeroMem((void*)T21_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
							T21_[0] = rope__cgen_6948(val);
							T22_ = NIM_NIL;
							T22_ = percent___cgen_14374(T21_, 1);
							T23_ = NIM_NIL;
							T23_ = indentLine__cgen_286(p, T22_);
							add__ropes_159(T20_, T23_);
							i_3 += ((NI) 1);
						} LA15: ;
					}
				}
				T24_ = NIM_NIL;
				T24_ = lastSon__ast_4833(it);
				genStmts__cgen_11522(p, T24_);
				endBlock__cgen_13329(p);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, branchHasTooBigRange__cgen_15367)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
		it = NIM_NIL;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148(b);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					it = (*b)._kind_6.sons->data[i];
					{
						NIM_BOOL T7_;
						T7_ = (NIM_BOOL)0;
						T7_ = ((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 44));
						if (!(T7_)) goto LA8_;
						T7_ = (IL64(256) < (NI64)((*(*it)._kind_6.sons->data[((NI) 1)])._kind_1.intVal - (*(*it)._kind_6.sons->data[((NI) 0)])._kind_1.intVal));
						LA8_: ;
						if (!T7_) goto LA9_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA9_: ;
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, ifSwitchSplitPoint__cgen_15377)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* branch;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* stmtBlock;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				branch = (*n)._kind_6.sons->data[i];
				stmtBlock = lastSon__ast_4833(branch);
				{
					NIM_BOOL T6_;
					T6_ = (NIM_BOOL)0;
					T6_ = stmtsContainPragma__ccgutils_42(stmtBlock, ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 205));
					if (!T6_) goto LA7_;
					result = i;
				}
				goto LA4_;
				LA7_: ;
				{
					if (!!(((CC__extccomp_510[((*(*(*(*p).module).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__9biNtFPzjM9c2i62RuZ9c19biA) 0))&7U)))!=0))) goto LA10_;
					{
						NIM_BOOL T14_;
						T14_ = (NIM_BOOL)0;
						T14_ = ((*branch).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 85));
						if (!(T14_)) goto LA15_;
						T14_ = branchHasTooBigRange__cgen_15367(branch);
						LA15_: ;
						if (!T14_) goto LA16_;
						result = i;
					}
					LA16_: ;
				}
				goto LA4_;
				LA10_: ;
				LA4_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genOrdinalCase__cgen_15451)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	NI splitPoint;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* lend;
	splitPoint = ifSwitchSplitPoint__cgen_15377(p, n);
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, (*n)._kind_6.sons->data[((NI) 0)], (&a));
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* resX60gensym2263_;
		NI labIdX60gensym2263_;
		if (!(((NI) 0) < splitPoint)) goto LA3_;
		resX60gensym2263_ = NIM_NIL;
		labIdX60gensym2263_ = (*p).labels;
		{
			NI iX60gensym2263_;
			NI res;
			iX60gensym2263_ = (NI)0;
			res = ((NI) 1);
			{
				while (1) {
					if (!(res <= splitPoint)) goto LA7;
					iX60gensym2263_ = res;
					(*p).labels += ((NI) 1);
					{
						tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw xX60gensym2266_;
						tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw yX60gensym2266_;
						if (!((*(*n)._kind_6.sons->data[iX60gensym2263_]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 85))) goto LA10_;
						nimZeroMem((void*)(&xX60gensym2266_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
						nimZeroMem((void*)(&yX60gensym2266_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
						{
							NI iX60gensym2266_;
							NI colontmp_;
							NI T13_;
							NI i;
							iX60gensym2266_ = (NI)0;
							colontmp_ = (NI)0;
							T13_ = (NI)0;
							T13_ = len__ast_3155((*n)._kind_6.sons->data[iX60gensym2263_]);
							colontmp_ = (NI)(T13_ - ((NI) 1));
							i = ((NI) 0);
							{
								while (1) {
									if (!(i < colontmp_)) goto LA15;
									iX60gensym2266_ = i;
									{
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T20_;
										NimStringDesc* res_2;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T21_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T27_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T32_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T33_;
										if (!((*(*(*n)._kind_6.sons->data[iX60gensym2263_])._kind_6.sons->data[iX60gensym2266_]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 44))) goto LA18_;
										initLocExpr__cgen_11548(p, (*(*(*n)._kind_6.sons->data[iX60gensym2263_])._kind_6.sons->data[iX60gensym2266_])._kind_6.sons->data[((NI) 0)], (&xX60gensym2266_));
										initLocExpr__cgen_11548(p, (*(*(*n)._kind_6.sons->data[iX60gensym2263_])._kind_6.sons->data[iX60gensym2266_])._kind_6.sons->data[((NI) 1)], (&yX60gensym2266_));
										T20_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
										T20_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
										res_2 = rawNewString(((NI) 80));
										res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
										T21_ = NIM_NIL;
										T21_ = rdCharLoc__cgen_10377(a);
										cgFormatValue__cgen_147((&res_2), T21_);
										res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_419));
										T22_ = NIM_NIL;
										T22_ = rdCharLoc__cgen_10377(xX60gensym2266_);
										cgFormatValue__cgen_147((&res_2), T22_);
										res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_772));
										T23_ = NIM_NIL;
										T23_ = rdCharLoc__cgen_10377(a);
										cgFormatValue__cgen_147((&res_2), T23_);
										res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_773));
										T24_ = NIM_NIL;
										T24_ = rdCharLoc__cgen_10377(yX60gensym2266_);
										cgFormatValue__cgen_147((&res_2), T24_);
										res_2 = resizeString(res_2, 7);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_774));
										T25_ = NIM_NIL;
										T25_ = rope__ropes_115(((NI64) ((*p).labels)));
										T26_ = NIM_NIL;
										T26_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_466), T25_);
										T27_ = NIM_NIL;
										T27_ = amp___ropes_140(T26_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3));
										cgFormatValue__cgen_147((&res_2), T27_);
										res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
										{
											if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA30_;
											res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
										}
										LA30_: ;
										T32_ = NIM_NIL;
										T32_ = rope__ropes_109(res_2);
										T33_ = NIM_NIL;
										T33_ = indentLine__cgen_286(p, T32_);
										add__ropes_159(T20_, T33_);
									}
									goto LA16_;
									LA18_: ;
									{
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T35_;
										NimStringDesc* res_3;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T36_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T37_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T39_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T40_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T45_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T46_;
										initLocExpr__cgen_11548(p, (*(*n)._kind_6.sons->data[iX60gensym2263_])._kind_6.sons->data[iX60gensym2266_], (&xX60gensym2266_));
										T35_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
										T35_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
										res_3 = rawNewString(((NI) 80));
										res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
										T36_ = NIM_NIL;
										T36_ = rdCharLoc__cgen_10377(a);
										cgFormatValue__cgen_147((&res_3), T36_);
										res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_467));
										T37_ = NIM_NIL;
										T37_ = rdCharLoc__cgen_10377(xX60gensym2266_);
										cgFormatValue__cgen_147((&res_3), T37_);
										res_3 = resizeString(res_3, 7);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_774));
										T38_ = NIM_NIL;
										T38_ = rope__ropes_115(((NI64) ((*p).labels)));
										T39_ = NIM_NIL;
										T39_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_466), T38_);
										T40_ = NIM_NIL;
										T40_ = amp___ropes_140(T39_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3));
										cgFormatValue__cgen_147((&res_3), T40_);
										res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
										{
											if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA43_;
											res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
										}
										LA43_: ;
										T45_ = NIM_NIL;
										T45_ = rope__ropes_109(res_3);
										T46_ = NIM_NIL;
										T46_ = indentLine__cgen_286(p, T45_);
										add__ropes_159(T35_, T46_);
									}
									LA16_: ;
									i += ((NI) 1);
								} LA15: ;
							}
						}
					}
					goto LA8_;
					LA10_: ;
					{
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T48_;
						tyArray__ts9cf9blICas1QWmw89bglZ7w T49_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T50_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T51_;
						T48_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
						T48_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
						nimZeroMem((void*)T49_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
						T49_[0] = rope__ropes_115(((NI64) ((*p).labels)));
						T50_ = NIM_NIL;
						T50_ = percent___cgen_15264(T49_, 1);
						T51_ = NIM_NIL;
						T51_ = indentLine__cgen_286(p, T50_);
						add__ropes_159(T48_, T51_);
					}
					LA8_: ;
					res += ((NI) 1);
				} LA7: ;
			}
		}
		{
			NI T54_;
			NI gotoTargetX60gensym2263_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T57_;
			tyArray__ts9cf9blICas1QWmw89bglZ7w T58_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T59_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T60_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T61_;
			tyArray__ts9cf9blICas1QWmw89bglZ7w T62_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T63_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T64_;
			T54_ = (NI)0;
			T54_ = len__ast_3155(n);
			if (!(splitPoint < (NI)(T54_ - ((NI) 1)))) goto LA55_;
			(*p).labels += ((NI) 1);
			gotoTargetX60gensym2263_ = (*p).labels;
			T57_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T57_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			nimZeroMem((void*)T58_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T58_[0] = rope__ropes_115(((NI64) (gotoTargetX60gensym2263_)));
			T59_ = NIM_NIL;
			T59_ = percent___cgen_15264(T58_, 1);
			T60_ = NIM_NIL;
			T60_ = indentLine__cgen_286(p, T59_);
			add__ropes_159(T57_, T60_);
			resX60gensym2263_ = genCaseSecondPass__cgen_15059(p, n, d, ((NI) (labIdX60gensym2263_)), splitPoint);
			T61_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T61_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			nimZeroMem((void*)T62_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T62_[0] = rope__ropes_115(((NI64) (gotoTargetX60gensym2263_)));
			T63_ = NIM_NIL;
			T63_ = percent___cgen_15076(T62_, 1);
			T64_ = NIM_NIL;
			T64_ = indentLine__cgen_286(p, T63_);
			add__ropes_159(T61_, T64_);
		}
		goto LA52_;
		LA55_: ;
		{
			resX60gensym2263_ = genCaseSecondPass__cgen_15059(p, n, d, ((NI) (labIdX60gensym2263_)), splitPoint);
		}
		LA52_: ;
		lend = resX60gensym2263_;
	}
	goto LA1_;
	LA3_: ;
	{
		lend = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
	}
	LA1_: ;
	{
		NI T69_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T72_;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T73_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T74_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T75_;
		NIM_BOOL hasDefault;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T109_;
		tyArray__dAmhZbEWrTM5xES2bTVweg T110_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T111_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T112_;
		T69_ = (NI)0;
		T69_ = len__ast_3155(n);
		if (!((NI)(splitPoint + ((NI) 1)) < T69_)) goto LA70_;
		T72_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T72_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		nimZeroMem((void*)T73_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T73_[0] = rdCharLoc__cgen_10377(a);
		T74_ = NIM_NIL;
		T74_ = percent___cgen_13803(T73_, 1);
		T75_ = NIM_NIL;
		T75_ = indentLine__cgen_286(p, T74_);
		add__ropes_159(T72_, T75_);
		hasDefault = NIM_FALSE;
		{
			NI i_2;
			NI colontmp__2;
			NI colontmp__3;
			NI i_3;
			i_2 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__3 = (NI)0;
			colontmp__2 = (NI)(splitPoint + ((NI) 1));
			colontmp__3 = len__ast_3155(n);
			i_3 = colontmp__2;
			{
				while (1) {
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* branch;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T94_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T95_;
					tyArray__dAmhZbEWrTM5xES2bTVweg T96_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T97_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T98_;
					if (!(i_3 < colontmp__3)) goto LA78;
					i_2 = i_3;
					{
						NIM_BOOL T81_;
						T81_ = (NIM_BOOL)0;
						T81_ = ((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 1));
						if (!(T81_)) goto LA82_;
						T81_ = isEmptyType__ast_4780((*n).typ);
						LA82_: ;
						if (!T81_) goto LA83_;
						(*d).k = ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0);
					}
					LA83_: ;
					branch = (*n)._kind_6.sons->data[i_2];
					{
						if (!((*branch).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 85))) goto LA87_;
						genCaseRange__cgen_7370(p, branch);
					}
					goto LA85_;
					LA87_: ;
					{
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T90_;
						tyArray__dAmhZbEWrTM5xES2bTVweg T91_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T92_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T93_;
						T90_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
						T90_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
						nimZeroMem((void*)T91_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
						T92_ = NIM_NIL;
						T92_ = percent___cgen_7438(T91_, 0);
						T93_ = NIM_NIL;
						T93_ = indentLine__cgen_286(p, T92_);
						add__ropes_159(T90_, T93_);
						hasDefault = NIM_TRUE;
					}
					LA85_: ;
					T94_ = NIM_NIL;
					T94_ = lastSon__ast_4833(branch);
					exprBlock__cgen_13615(p, T94_, d);
					T95_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T95_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					nimZeroMem((void*)T96_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
					T97_ = NIM_NIL;
					T97_ = percent___cgen_7446(T96_, 0);
					T98_ = NIM_NIL;
					T98_ = indentLine__cgen_286(p, T97_);
					add__ropes_159(T95_, T98_);
					i_3 += ((NI) 1);
				} LA78: ;
			}
		}
		{
			NIM_BOOL T101_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T105_;
			tyArray__dAmhZbEWrTM5xES2bTVweg T106_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T107_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T108_;
			T101_ = (NIM_BOOL)0;
			T101_ = ((CC__extccomp_510[((*(*(*(*p).module).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__9biNtFPzjM9c2i62RuZ9c19biA) 3))&7U)))!=0);
			if (!(T101_)) goto LA102_;
			T101_ = !(hasDefault);
			LA102_: ;
			if (!T101_) goto LA103_;
			T105_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T105_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			nimZeroMem((void*)T106_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
			T107_ = NIM_NIL;
			T107_ = percent___cgen_15590(T106_, 0);
			T108_ = NIM_NIL;
			T108_ = indentLine__cgen_286(p, T107_);
			add__ropes_159(T105_, T108_);
		}
		LA103_: ;
		T109_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T109_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		nimZeroMem((void*)T110_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		T111_ = NIM_NIL;
		T111_ = percent___cgen_7535(T110_, 0);
		T112_ = NIM_NIL;
		T112_ = indentLine__cgen_286(p, T111_);
		add__ropes_159(T109_, T112_);
	}
	LA70_: ;
	{
		if (!!((lend == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA115_;
		fixLabel__cgen_11508(p, lend);
	}
	LA115_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCase__cgen_15603)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T8_;
	genLineDir__cgen_369(p, t);
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = isEmptyType__ast_4780((*t).typ);
		T3_ = !(T4_);
		if (!(T3_)) goto LA5_;
		T3_ = ((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0));
		LA5_: ;
		if (!T3_) goto LA6_;
		getTemp__cgen_7373(p, (*t).typ, d, NIM_FALSE);
	}
	LA6_: ;
	T8_ = NIM_NIL;
	T8_ = skipTypes__ast_3723((*(*t)._kind_6.sons->data[((NI) 0)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_183);
	switch ((*T8_).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
	{
		genStringCase__cgen_15168(p, t, d);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 39):
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw aX60gensym2302_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* lendX60gensym2302_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* resX60gensym2304_;
		NI labIdX60gensym2304_;
		nimZeroMem((void*)(&aX60gensym2302_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548(p, (*t)._kind_6.sons->data[((NI) 0)], (&aX60gensym2302_));
		resX60gensym2304_ = NIM_NIL;
		labIdX60gensym2304_ = (*p).labels;
		{
			NI iX60gensym2304_;
			NI colontmp_;
			NI T12_;
			NI res;
			iX60gensym2304_ = (NI)0;
			colontmp_ = (NI)0;
			T12_ = (NI)0;
			T12_ = len__ast_3155(t);
			colontmp_ = (NI)(T12_ - ((NI) 1));
			res = ((NI) 1);
			{
				while (1) {
					if (!(res <= colontmp_)) goto LA14;
					iX60gensym2304_ = res;
					(*p).labels += ((NI) 1);
					{
						tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw xX60gensym2307_;
						tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw yX60gensym2307_;
						if (!((*(*t)._kind_6.sons->data[iX60gensym2304_]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 85))) goto LA17_;
						nimZeroMem((void*)(&xX60gensym2307_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
						nimZeroMem((void*)(&yX60gensym2307_), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
						{
							NI iX60gensym2307_;
							NI colontmp__2;
							NI T20_;
							NI i;
							iX60gensym2307_ = (NI)0;
							colontmp__2 = (NI)0;
							T20_ = (NI)0;
							T20_ = len__ast_3155((*t)._kind_6.sons->data[iX60gensym2304_]);
							colontmp__2 = (NI)(T20_ - ((NI) 1));
							i = ((NI) 0);
							{
								while (1) {
									if (!(i < colontmp__2)) goto LA22;
									iX60gensym2307_ = i;
									{
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T27_;
										NimStringDesc* res_2;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T28_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T29_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T30_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T31_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T32_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T33_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T34_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T39_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T40_;
										if (!((*(*(*t)._kind_6.sons->data[iX60gensym2304_])._kind_6.sons->data[iX60gensym2307_]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 44))) goto LA25_;
										initLocExpr__cgen_11548(p, (*(*(*t)._kind_6.sons->data[iX60gensym2304_])._kind_6.sons->data[iX60gensym2307_])._kind_6.sons->data[((NI) 0)], (&xX60gensym2307_));
										initLocExpr__cgen_11548(p, (*(*(*t)._kind_6.sons->data[iX60gensym2304_])._kind_6.sons->data[iX60gensym2307_])._kind_6.sons->data[((NI) 1)], (&yX60gensym2307_));
										T27_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
										T27_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
										res_2 = rawNewString(((NI) 80));
										res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
										T28_ = NIM_NIL;
										T28_ = rdCharLoc__cgen_10377(aX60gensym2302_);
										cgFormatValue__cgen_147((&res_2), T28_);
										res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_419));
										T29_ = NIM_NIL;
										T29_ = rdCharLoc__cgen_10377(xX60gensym2307_);
										cgFormatValue__cgen_147((&res_2), T29_);
										res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_772));
										T30_ = NIM_NIL;
										T30_ = rdCharLoc__cgen_10377(aX60gensym2302_);
										cgFormatValue__cgen_147((&res_2), T30_);
										res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_773));
										T31_ = NIM_NIL;
										T31_ = rdCharLoc__cgen_10377(yX60gensym2307_);
										cgFormatValue__cgen_147((&res_2), T31_);
										res_2 = resizeString(res_2, 7);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_774));
										T32_ = NIM_NIL;
										T32_ = rope__ropes_115(((NI64) ((*p).labels)));
										T33_ = NIM_NIL;
										T33_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_466), T32_);
										T34_ = NIM_NIL;
										T34_ = amp___ropes_140(T33_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3));
										cgFormatValue__cgen_147((&res_2), T34_);
										res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
										{
											if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA37_;
											res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
										}
										LA37_: ;
										T39_ = NIM_NIL;
										T39_ = rope__ropes_109(res_2);
										T40_ = NIM_NIL;
										T40_ = indentLine__cgen_286(p, T39_);
										add__ropes_159(T27_, T40_);
									}
									goto LA23_;
									LA25_: ;
									{
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T42_;
										NimStringDesc* res_3;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T43_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T44_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T45_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T46_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T47_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T52_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T53_;
										initLocExpr__cgen_11548(p, (*(*t)._kind_6.sons->data[iX60gensym2304_])._kind_6.sons->data[iX60gensym2307_], (&xX60gensym2307_));
										T42_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
										T42_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
										res_3 = rawNewString(((NI) 80));
										res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
										T43_ = NIM_NIL;
										T43_ = rdCharLoc__cgen_10377(aX60gensym2302_);
										cgFormatValue__cgen_147((&res_3), T43_);
										res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_467));
										T44_ = NIM_NIL;
										T44_ = rdCharLoc__cgen_10377(xX60gensym2307_);
										cgFormatValue__cgen_147((&res_3), T44_);
										res_3 = resizeString(res_3, 7);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_774));
										T45_ = NIM_NIL;
										T45_ = rope__ropes_115(((NI64) ((*p).labels)));
										T46_ = NIM_NIL;
										T46_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_466), T45_);
										T47_ = NIM_NIL;
										T47_ = amp___ropes_140(T46_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3));
										cgFormatValue__cgen_147((&res_3), T47_);
										res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
										{
											if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA50_;
											res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
										}
										LA50_: ;
										T52_ = NIM_NIL;
										T52_ = rope__ropes_109(res_3);
										T53_ = NIM_NIL;
										T53_ = indentLine__cgen_286(p, T52_);
										add__ropes_159(T42_, T53_);
									}
									LA23_: ;
									i += ((NI) 1);
								} LA22: ;
							}
						}
					}
					goto LA15_;
					LA17_: ;
					{
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T55_;
						tyArray__ts9cf9blICas1QWmw89bglZ7w T56_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T57_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T58_;
						T55_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
						T55_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
						nimZeroMem((void*)T56_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
						T56_[0] = rope__ropes_115(((NI64) ((*p).labels)));
						T57_ = NIM_NIL;
						T57_ = percent___cgen_15264(T56_, 1);
						T58_ = NIM_NIL;
						T58_ = indentLine__cgen_286(p, T57_);
						add__ropes_159(T55_, T58_);
					}
					LA15_: ;
					res += ((NI) 1);
				} LA14: ;
			}
		}
		{
			NI T61_;
			NI T62_;
			NI gotoTargetX60gensym2304_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T65_;
			tyArray__ts9cf9blICas1QWmw89bglZ7w T66_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T67_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T68_;
			NI T69_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T70_;
			tyArray__ts9cf9blICas1QWmw89bglZ7w T71_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T72_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T73_;
			T61_ = (NI)0;
			T61_ = len__ast_3155(t);
			T62_ = (NI)0;
			T62_ = len__ast_3155(t);
			if (!((NI)(T61_ - ((NI) 1)) < (NI)(T62_ - ((NI) 1)))) goto LA63_;
			(*p).labels += ((NI) 1);
			gotoTargetX60gensym2304_ = (*p).labels;
			T65_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T65_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			nimZeroMem((void*)T66_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T66_[0] = rope__ropes_115(((NI64) (gotoTargetX60gensym2304_)));
			T67_ = NIM_NIL;
			T67_ = percent___cgen_15264(T66_, 1);
			T68_ = NIM_NIL;
			T68_ = indentLine__cgen_286(p, T67_);
			add__ropes_159(T65_, T68_);
			T69_ = (NI)0;
			T69_ = len__ast_3155(t);
			resX60gensym2304_ = genCaseSecondPass__cgen_15059(p, t, d, ((NI) (labIdX60gensym2304_)), (NI)(T69_ - ((NI) 1)));
			T70_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T70_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			nimZeroMem((void*)T71_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T71_[0] = rope__ropes_115(((NI64) (gotoTargetX60gensym2304_)));
			T72_ = NIM_NIL;
			T72_ = percent___cgen_15076(T71_, 1);
			T73_ = NIM_NIL;
			T73_ = indentLine__cgen_286(p, T72_);
			add__ropes_159(T70_, T73_);
		}
		goto LA59_;
		LA63_: ;
		{
			NI T75_;
			T75_ = (NI)0;
			T75_ = len__ast_3155(t);
			resX60gensym2304_ = genCaseSecondPass__cgen_15059(p, t, d, ((NI) (labIdX60gensym2304_)), (NI)(T75_ - ((NI) 1)));
		}
		LA59_: ;
		lendX60gensym2302_ = resX60gensym2304_;
		fixLabel__cgen_11508(p, lendX60gensym2302_);
	}
	break;
	default:
	{
		{
			NIM_BOOL T79_;
			T79_ = (NIM_BOOL)0;
			T79_ = ((*(*t)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
			if (!(T79_)) goto LA80_;
			T79_ = (((*(*(*t)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 35))&63U)))!=0);
			LA80_: ;
			if (!T79_) goto LA81_;
			genGotoForCase__cgen_14333(p, t);
		}
		goto LA77_;
		LA81_: ;
		{
			genOrdinalCase__cgen_15451(p, t, d);
		}
		LA77_: ;
	}
	break;
	}
}
static N_INLINE(void, pop__cgen_13721)(tySequence__IjAwukZ9aSEsol9c48He4FYQ** s, tyTuple__T1RBf8m9axj9bvJRlYejkpkQ* Result) {
	NI L;
	NI T1_;
	T1_ = ((*s) ? (*s)->Sup.len : 0);
	L = (NI)(T1_ - ((NI) 1));
	unsureAsgnRef((void**) (&(*Result).Field0), (*s)->data[L].Field0);
	(*Result).Field1 = (*s)->data[L].Field1;
	(*Result).Field2 = (*s)->data[L].Field2;
	unsureAsgnRef((void**) (&(*s)), (tySequence__IjAwukZ9aSEsol9c48He4FYQ*) setLengthSeqV2(((*s))?&((*s))->Sup:NIM_NIL, (&NTIseqLtupleLfin58pnode_inexcept58bool_label58naturalTT__IjAwukZ9aSEsol9c48He4FYQ_), ((NI) (L))));
}
N_LIB_PRIVATE N_NIMCALL(void, blockLeaveActions__cgen_13683)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, NI howManyTrys, NI howManyExcepts) {
	tySequence__IjAwukZ9aSEsol9c48He4FYQ* stack;
	stack = newSeq__cgen_13694(((NI) 0));
	(*p).withinBlockLeaveActions += ((NI) 1);
	{
		NI i;
		NI res;
		i = (NI)0;
		res = ((NI) 1);
		{
			while (1) {
				tyTuple__T1RBf8m9axj9bvJRlYejkpkQ tryStmt;
				NI T20_;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* finallyStmt;
				if (!(res <= howManyTrys)) goto LA3;
				i = res;
				nimZeroMem((void*)(&tryStmt), sizeof(tyTuple__T1RBf8m9axj9bvJRlYejkpkQ));
				pop__cgen_13721((&(*p).nestedTryStmts), (&tryStmt));
				{
					if (!((*(*(*(*p).module).g).config).exc == ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 1))) goto LA6_;
					{
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T12_;
						NimStringDesc* res_2;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
						if (!!(tryStmt.Field1)) goto LA10_;
						T12_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
						T12_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
						res_2 = rawNewString(((NI) 80));
						T13_ = NIM_NIL;
						T13_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_776));
						cgFormatValue__cgen_147((&res_2), T13_);
						res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_312));
						{
							if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA16_;
							res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
						}
						LA16_: ;
						T18_ = NIM_NIL;
						T18_ = rope__ropes_109(res_2);
						T19_ = NIM_NIL;
						T19_ = indentLine__cgen_286(p, T18_);
						add__ropes_159(T12_, T19_);
					}
					LA10_: ;
				}
				LA6_: ;
				stack = (tySequence__IjAwukZ9aSEsol9c48He4FYQ*) incrSeqV3((TGenericSeq*)(stack), (&NTIseqLtupleLfin58pnode_inexcept58bool_label58naturalTT__IjAwukZ9aSEsol9c48He4FYQ_));
				T20_ = stack->Sup.len++;
				asgnRef((void**) (&stack->data[T20_].Field0), tryStmt.Field0);
				stack->data[T20_].Field1 = tryStmt.Field1;
				stack->data[T20_].Field2 = tryStmt.Field2;
				finallyStmt = tryStmt.Field0;
				{
					if (!!((finallyStmt == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA23_;
					genStmts__cgen_11522(p, (*finallyStmt)._kind_6.sons->data[((NI) 0)]);
				}
				LA23_: ;
				res += ((NI) 1);
			} LA3: ;
		}
	}
	(*p).withinBlockLeaveActions -= ((NI) 1);
	{
		NI i_2;
		NI colontmp_;
		NI res_3;
		i_2 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (NI)(howManyTrys - ((NI) 1));
		res_3 = colontmp_;
		{
			while (1) {
				NI T28_;
				if (!(((NI) 0) <= res_3)) goto LA27;
				i_2 = res_3;
				asgnRef((void**) (&(*p).nestedTryStmts), (tySequence__IjAwukZ9aSEsol9c48He4FYQ*) incrSeqV3((TGenericSeq*)((*p).nestedTryStmts), (&NTIseqLtupleLfin58pnode_inexcept58bool_label58naturalTT__IjAwukZ9aSEsol9c48He4FYQ_)));
				T28_ = (*p).nestedTryStmts->Sup.len++;
				asgnRef((void**) (&(*p).nestedTryStmts->data[T28_].Field0), stack->data[i_2].Field0);
				(*p).nestedTryStmts->data[T28_].Field1 = stack->data[i_2].Field1;
				(*p).nestedTryStmts->data[T28_].Field2 = stack->data[i_2].Field2;
				res_3 -= ((NI) 1);
			} LA27: ;
		}
	}
	{
		if (!!((((*p).flags &((NU8)1<<((NU)(((tyEnum_TCProcFlag__Iv1wQAvkoMCW3v9cTnZWvJw) 3))&7U)))!=0))) goto LA31_;
		{
			NI i_3;
			NI colontmp__2;
			NI res_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = (NI)(howManyExcepts - ((NI) 1));
			res_4 = colontmp__2;
			{
				while (1) {
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T36_;
					NimStringDesc* res_5;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T37_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T42_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T43_;
					if (!(((NI) 0) <= res_4)) goto LA35;
					i_3 = res_4;
					T36_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T36_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					res_5 = rawNewString(((NI) 80));
					T37_ = NIM_NIL;
					T37_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_777));
					cgFormatValue__cgen_147((&res_5), T37_);
					res_5 = resizeString(res_5, 3);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_312));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA40_;
						res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
					}
					LA40_: ;
					T42_ = NIM_NIL;
					T42_ = rope__ropes_109(res_5);
					T43_ = NIM_NIL;
					T43_ = indentLine__cgen_286(p, T42_);
					add__ropes_159(T36_, T43_);
					res_4 -= ((NI) 1);
				} LA35: ;
			}
		}
	}
	LA31_: ;
}
static N_INLINE(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**, X5BX5D___cgen_14296)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** s, NI sLen_0, NI i) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** result;
	result = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	result = &s[(NI)(sLen_0 - i)];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genReturnStmt__cgen_14269)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t) {
	NI T9_;
	NI T10_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T27_;
	tyArray__dAmhZbEWrTM5xES2bTVweg T28_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T29_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T30_;
{	{
		if (!(((*t).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg) 15))&31U)))!=0)) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	(*p).flags |= ((NU8)1)<<((((tyEnum_TCProcFlag__Iv1wQAvkoMCW3v9cTnZWvJw) 0)) & 7);
	genLineDir__cgen_369(p, t);
	{
		if (!!(((*(*t)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)))) goto LA7_;
		genStmts__cgen_11522(p, (*t)._kind_6.sons->data[((NI) 0)]);
	}
	LA7_: ;
	T9_ = ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0);
	T10_ = (NI)0;
	T10_ = inExceptBlockLen__cgen_13273(p);
	blockLeaveActions__cgen_13683(p, T9_, T10_);
	{
		NIM_BOOL T13_;
		NI T14_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* safePoint;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T18_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T19_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
		T13_ = (NIM_BOOL)0;
		T14_ = ((*p).finallySafePoints ? (*p).finallySafePoints->Sup.len : 0);
		T13_ = (((NI) 0) < T14_);
		if (!(T13_)) goto LA15_;
		T13_ = !((((*p).flags &((NU8)1<<((NU)(((tyEnum_TCProcFlag__Iv1wQAvkoMCW3v9cTnZWvJw) 3))&7U)))!=0));
		LA15_: ;
		if (!T13_) goto LA16_;
		T18_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T18_ = X5BX5D___cgen_14296(((*p).finallySafePoints) ? ((*p).finallySafePoints->data) : NIM_NIL, ((*p).finallySafePoints ? (*p).finallySafePoints->Sup.len : 0), ((NI) 1));
		safePoint = (*T18_);
		T19_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T19_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
		cgFormatValue__cgen_147((&res), safePoint);
		res = resizeString(res, 14);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_778));
		T20_ = NIM_NIL;
		T20_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_777));
		cgFormatValue__cgen_147((&res), T20_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_312));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA23_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA23_: ;
		T25_ = NIM_NIL;
		T25_ = rope__ropes_109(res);
		T26_ = NIM_NIL;
		T26_ = indentLine__cgen_286(p, T25_);
		add__ropes_159(T19_, T26_);
	}
	LA16_: ;
	T27_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T27_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	nimZeroMem((void*)T28_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
	T29_ = NIM_NIL;
	T29_ = percent___cgen_14319(T28_, 0);
	T30_ = NIM_NIL;
	T30_ = indentLine__cgen_286(p, T29_);
	add__ropes_159(T27_, T30_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genBreakStmt__cgen_14784)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t) {
	NI idx;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* label;
	NI T20_;
	NI T21_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T22_;
	tyArray__ts9cf9blICas1QWmw89bglZ7w T23_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
	idx = (*p).breakIdx;
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
		if (!!(((*(*t)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)))) goto LA3_;
		sym = (*(*t)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		{
			if (!!(((*sym).loc.k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 10)))) goto LA7_;
			failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_779));
		}
		LA7_: ;
		idx = (NI)((*sym).position - ((NI) 1));
	}
	goto LA1_;
	LA3_: ;
	{
		{
			while (1) {
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (((NI) 0) <= idx);
				if (!(T12_)) goto LA13_;
				T12_ = !((*p).blocks->data[idx].isLoop);
				LA13_: ;
				if (!T12_) goto LA11;
				idx -= ((NI) 1);
			} LA11: ;
		}
		{
			NIM_BOOL T16_;
			T16_ = (NIM_BOOL)0;
			T16_ = (idx < ((NI) 0));
			if (T16_) goto LA17_;
			T16_ = !((*p).blocks->data[idx].isLoop);
			LA17_: ;
			if (!T16_) goto LA18_;
			internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*t).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_780), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_781);
		}
		LA18_: ;
	}
	LA1_: ;
	label = assignLabel__cgen_13551((&(*p).blocks->data[idx]));
	T20_ = ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0);
	T21_ = (NI)0;
	T21_ = inExceptBlockLen__cgen_13273(p);
	blockLeaveActions__cgen_13683(p, (NI)(T20_ - ((NI) ((*p).blocks->data[idx].nestedTryStmts))), (NI)(T21_ - ((NI) ((*p).blocks->data[idx].nestedExceptStmts))));
	genLineDir__cgen_369(p, t);
	T22_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T22_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	nimZeroMem((void*)T23_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
	T23_[0] = label;
	T24_ = NIM_NIL;
	T24_ = percent___cgen_14244(T23_, 1);
	T25_ = NIM_NIL;
	T25_ = indentLine__cgen_286(p, T24_);
	add__ropes_159(T22_, T25_);
}
static N_INLINE(void, cow__cgen_19647)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64))) goto LA3_;
		cowBracket__cgen_19616(p, (*n)._kind_6.sons->data[((NI) 0)]);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, discriminatorTableDecl__cgen_6951)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* objtype, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* d) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tmp;
	tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T2_;
	tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T3_;
	tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T4_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_143));
	(void)(T1_);
	tmp = discriminatorTableName__cgen_6928(m, objtype, d);
	nimZeroMem((void*)T2_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
	T2_[0] = tmp;
	T3_ = lengthOrd__types_1723((*(*m).g).config, (*d).typ);
	T4_ = plus___int495056_987(T3_, IL64(1));
	T2_[1] = rope__cgen_6948(T4_);
	result = percent___cgen_6957(T2_, 2);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genDiscriminantCheck__cgen_17425)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tmp, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* objtype, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T9_;
	NimStringDesc* res_2;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
	tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T14_;
	NI64 T15_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T21_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
	t = skipTypes__ast_3723(objtype, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_266);
	T1_ = NIM_NIL;
	T1_ = genTypeInfoV1__cgen_6798((*p).module, t, (*a.lode).info);
	(void)(T1_);
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym3160_;
		NIM_BOOL T4_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
		xX60gensym3160_ = field;
		T4_ = (NIM_BOOL)0;
		T4_ = containsOrIncl__astalgo_402((&(*(*p).module).declaredThings), (NI)((NI)((NU64)(((NI) ((*xX60gensym3160_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym3160_).Sup.itemId.item))));
		if (!!(T4_)) goto LA5_;
		res = rawNewString(((NI) 80));
		res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_327));
		T7_ = NIM_NIL;
		T7_ = discriminatorTableDecl__cgen_6951((*p).module, t, field);
		cgFormatValue__cgen_147((&res), T7_);
		T8_ = NIM_NIL;
		T8_ = rope__ropes_109(res);
		add__ropes_159(&(*(*p).module).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], T8_);
	}
	LA5_: ;
	T9_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T9_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	res_2 = rawNewString(((NI) 80));
	T10_ = NIM_NIL;
	T10_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_782));
	cgFormatValue__cgen_147((&res_2), T10_);
	res_2 = resizeString(res_2, 10);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_783));
	T11_ = NIM_NIL;
	T11_ = rdLoc__cgen_435(a);
	cgFormatValue__cgen_147((&res_2), T11_);
	res_2 = resizeString(res_2, 12);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_784));
	T12_ = NIM_NIL;
	T12_ = rdLoc__cgen_435(tmp);
	cgFormatValue__cgen_147((&res_2), T12_);
	res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_410));
	T13_ = NIM_NIL;
	T13_ = discriminatorTableName__cgen_6928((*p).module, t, field);
	cgFormatValue__cgen_147((&res_2), T13_);
	res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
	T14_ = lengthOrd__types_1723((*(*(*p).module).g).config, (*field).typ);
	T15_ = (NI64)0;
	T15_ = toInt64__int495056_88(T14_);
	T16_ = NIM_NIL;
	T16_ = intLiteral__cgen_11536((NI64)(T15_ + IL64(1)));
	cgFormatValue__cgen_147((&res_2), T16_);
	res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA19_;
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA19_: ;
	T21_ = NIM_NIL;
	T21_ = rope__ropes_109(res_2);
	T22_ = NIM_NIL;
	T22_ = indentLine__cgen_286(p, T21_);
	add__ropes_159(T9_, T22_);
}
N_LIB_PRIVATE N_NIMCALL(void, asgnFieldDiscriminant__cgen_17539)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tmp;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* dotExpr;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T5_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	dotExpr = (*e)._kind_6.sons->data[((NI) 0)];
	{
		if (!((*dotExpr).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 46))) goto LA3_;
		dotExpr = (*dotExpr)._kind_6.sons->data[((NI) 0)];
	}
	LA3_: ;
	initLocExpr__cgen_11548(p, (*e)._kind_6.sons->data[((NI) 0)], (&a));
	T5_ = NIM_NIL;
	T5_ = t__cgen_85(a);
	getTemp__cgen_7373(p, T5_, (&tmp), NIM_FALSE);
	expr__cgen_11525(p, (*e)._kind_6.sons->data[((NI) 1)], (&tmp));
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field;
		if (!!((((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 41))&63U)))!=0))) goto LA8_;
		field = (*(*dotExpr)._kind_6.sons->data[((NI) 1)])._kind_4.sym;
		genDiscriminantCheck__cgen_17425(p, a, tmp, (*(*dotExpr)._kind_6.sons->data[((NI) 0)]).typ, field);
		liMessage__msgs_1128((*(*(*p).module).g).config, (*e).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 56), ((NimStringDesc*) NIM_NIL), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_785, NIM_FALSE);
	}
	LA8_: ;
	genAssignment__cgen_10403(p, a, tmp, 0);
}
N_LIB_PRIVATE N_NIMCALL(void, genAsgn__cgen_17560)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, NIM_BOOL fastAsgn) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*(*e)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		if (!(T3_)) goto LA4_;
		T3_ = (((*(*(*e)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 35))&63U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		genLineDir__cgen_369(p, e);
		genGotoVar__cgen_13879(p, (*e)._kind_6.sons->data[((NI) 1)]);
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = (((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 2))&31U)))!=0);
		if (!(T8_)) goto LA9_;
		T8_ = isDiscriminantField__astalgo_4328((*e)._kind_6.sons->data[((NI) 0)]);
		LA9_: ;
		if (!T8_) goto LA10_;
		genLineDir__cgen_369(p, e);
		asgnFieldDiscriminant__cgen_17539(p, e);
	}
	goto LA1_;
	LA10_: ;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* le;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri;
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T13_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
		le = (*e)._kind_6.sons->data[((NI) 0)];
		ri = (*e)._kind_6.sons->data[((NI) 1)];
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		T13_ = NIM_NIL;
		T13_ = skipTypes__ast_3723((*le).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_130);
		T14_ = NIM_NIL;
		T14_ = getTypeDesc__cgen_6662((*p).module, T13_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
		(void)(T14_);
		initLoc__cgen_66((&a), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0), le, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
		a.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 9)) & 15);
		a.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 10)) & 15);
		genLineDir__cgen_369(p, le);
		expr__cgen_11525(p, le, (&a));
		a.flags &= ~(((NU16)1) << ((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 10)) & 15));
		{
			if (!fastAsgn) goto LA17_;
			a.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 2)) & 15);
		}
		LA17_: ;
		genLineDir__cgen_369(p, ri);
		loadInto__cgen_13528(p, le, ri, (&a));
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genAsmOrEmitStmt__cgen_17326)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t, NIM_BOOL isAsmStmt) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	NimStringDesc* res;
	result = NIM_NIL;
	res = ((NimStringDesc*) NIM_NIL);
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** it;
		tySequence__IeU9azYSNIK3V9b36Ir6NZcw* colontmp_;
		NI i;
		NI L;
		NI T2_;
		it = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
		colontmp_ = NIM_NIL;
		colontmp_ = (*t)._kind_6.sons;
		i = ((NI) 0);
		T2_ = (colontmp_ ? colontmp_->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				it = &colontmp_->data[i];
				switch ((*(*it)).kind) {
				case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22):
				{
					res = resizeString(res, ((*(*it))._kind_3.strVal ? (*(*it))._kind_3.strVal->Sup.len : 0) + 0);
appendString(res, (*(*it))._kind_3.strVal);
				}
				break;
				case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
				{
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
					sym = (*(*it))._kind_4.sym;
					{
						tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
						NimStringDesc* T12_;
						if (!((61440 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0)) goto LA9_;
						nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
						initLocExpr__cgen_11548(p, (*it), (&a));
						T11_ = NIM_NIL;
						T11_ = rdLoc__cgen_435(a);
						T12_ = NIM_NIL;
						T12_ = dollar___ropes_250(T11_);
						res = resizeString(res, (T12_ ? T12_->Sup.len : 0) + 0);
appendString(res, T12_);
					}
					goto LA7_;
					LA9_: ;
					{
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
						NimStringDesc* T17_;
						if (!((*sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 7))) goto LA14_;
						T16_ = NIM_NIL;
						T16_ = getTypeDesc__cgen_6662((*p).module, (*sym).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
						T17_ = NIM_NIL;
						T17_ = dollar___ropes_250(T16_);
						res = resizeString(res, (T17_ ? T17_->Sup.len : 0) + 0);
appendString(res, T17_);
					}
					goto LA7_;
					LA14_: ;
					{
						tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T19_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
						NimStringDesc* T25_;
						T19_ = NIM_NIL;
						T19_ = skipTypes__ast_3723((*sym).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_201);
						T20_ = NIM_NIL;
						T20_ = getTypeDesc__cgen_6662((*p).module, T19_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
						(void)(T20_);
						r = (*sym).loc.r;
						{
							if (!(r == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA23_;
							r = mangleName__cgen_646((*p).module, sym);
							asgnRef((void**) (&(*sym).loc.r), r);
						}
						LA23_: ;
						T25_ = NIM_NIL;
						T25_ = dollar___ropes_250(r);
						res = resizeString(res, (T25_ ? T25_->Sup.len : 0) + 0);
appendString(res, T25_);
					}
					LA7_: ;
				}
				break;
				case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 132):
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T27_;
					NimStringDesc* T28_;
					T27_ = NIM_NIL;
					T27_ = getTypeDesc__cgen_6662((*p).module, (*(*it)).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
					T28_ = NIM_NIL;
					T28_ = dollar___ropes_250(T27_);
					res = resizeString(res, (T28_ ? T28_->Sup.len : 0) + 0);
appendString(res, T28_);
				}
				break;
				default:
				{
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T30_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T31_;
					tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a_2;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T32_;
					NimStringDesc* T33_;
					T30_ = NIM_NIL;
					T30_ = skipTypes__ast_3723((*(*it)).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_201);
					T31_ = NIM_NIL;
					T31_ = getTypeDesc__cgen_6662((*p).module, T30_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
					(void)(T31_);
					nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
					initLocExpr__cgen_11548(p, (*it), (&a_2));
					T32_ = NIM_NIL;
					T32_ = rdLoc__cgen_435(a_2);
					T33_ = NIM_NIL;
					T33_ = dollar___ropes_250(T32_);
					res = resizeString(res, (T33_ ? T33_->Sup.len : 0) + 0);
appendString(res, T33_);
				}
				break;
				}
				i += ((NI) 1);
			} LA4: ;
		}
	}
	{
		NIM_BOOL T36_;
		T36_ = (NIM_BOOL)0;
		T36_ = isAsmStmt;
		if (!(T36_)) goto LA37_;
		T36_ = ((CC__extccomp_510[((*(*(*(*p).module).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__9biNtFPzjM9c2i62RuZ9c19biA) 5))&7U)))!=0);
		LA37_: ;
		if (!T36_) goto LA38_;
		{
			NimStringDesc* x;
			NI first;
			NI last;
			NI eolpos;
			x = NIM_NIL;
			first = ((NI) 0);
			last = ((NI) 0);
			eolpos = ((NI) 0);
			{
				while (1) {
					NI T64_;
					NI j;
					{
						while (1) {
							NIM_BOOL T45_;
							T45_ = (NIM_BOOL)0;
							T45_ = (last < (res ? res->Sup.len : 0));
							if (!(T45_)) goto LA46_;
							T45_ = !((((NU8)(res->data[last])) == ((NU8)(13)) || ((NU8)(res->data[last])) == ((NU8)(10))));
							LA46_: ;
							if (!T45_) goto LA44;
							last += ((NI) 1);
						} LA44: ;
					}
					eolpos = last;
					{
						if (!(last < (res ? res->Sup.len : 0))) goto LA49_;
						{
							if (!((NU8)(res->data[last]) == (NU8)(10))) goto LA53_;
							last += ((NI) 1);
						}
						goto LA51_;
						LA53_: ;
						{
							if (!((NU8)(res->data[last]) == (NU8)(13))) goto LA56_;
							last += ((NI) 1);
							{
								NIM_BOOL T60_;
								T60_ = (NIM_BOOL)0;
								T60_ = (last < (res ? res->Sup.len : 0));
								if (!(T60_)) goto LA61_;
								T60_ = ((NU8)(res->data[last]) == (NU8)(10));
								LA61_: ;
								if (!T60_) goto LA62_;
								last += ((NI) 1);
							}
							LA62_: ;
						}
						goto LA51_;
						LA56_: ;
						LA51_: ;
					}
					LA49_: ;
					T64_ = (NI)0;
					{
						if (!NIM_FALSE) goto LA67_;
						T64_ = (NI)(last - ((NI) 1));
					}
					goto LA65_;
					LA67_: ;
					{
						T64_ = (NI)(eolpos - ((NI) 1));
					}
					LA65_: ;
					x = substr__system_7755(res, first, T64_);
					j = ((NI) 0);
					{
						while (1) {
							NIM_BOOL T72_;
							T72_ = (NIM_BOOL)0;
							T72_ = (j < (x ? x->Sup.len : 0));
							if (!(T72_)) goto LA73_;
							T72_ = (((NU8)(x->data[j])) == ((NU8)(32)) || ((NU8)(x->data[j])) == ((NU8)(9)));
							LA73_: ;
							if (!T72_) goto LA71;
							j += ((NI) 1);
						} LA71: ;
					}
					{
						if (!(j < (x ? x->Sup.len : 0))) goto LA76_;
						{
							if (!(((NU8)(x->data[j])) == ((NU8)(34)) || ((NU8)(x->data[j])) == ((NU8)(58)))) goto LA80_;
							add__ropes_162(&result, x);
							add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
						}
						goto LA78_;
						LA80_: ;
						{
							NimStringDesc* T83_;
							add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_787));
							T83_ = NIM_NIL;
							T83_ = nsuReplaceStr(x, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_787), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_788));
							add__ropes_162(&result, T83_);
							add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_789));
						}
						LA78_: ;
					}
					LA76_: ;
					{
						if (!(eolpos == last)) goto LA86_;
						goto LA41;
					}
					LA86_: ;
					first = last;
				}
			} LA41: ;
		}
	}
	goto LA34_;
	LA38_: ;
	{
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		result = rope__ropes_109(res);
	}
	LA34_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genAsmStmt__cgen_17370)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* s;
	genLineDir__cgen_369(p, t);
	s = genAsmOrEmitStmt__cgen_17326(p, t, NIM_TRUE);
	{
		tyArray__ts9cf9blICas1QWmw89bglZ7w T5_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
		if (!((*p).prc == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T5_[0] = s;
		T6_ = NIM_NIL;
		T6_ = runtimeFormat__ropes_271(CC__extccomp_510[((*(*(*(*p).module).g).config).cCompiler)- 1].Field17, T5_, 1);
		add__ropes_159(&(*(*p).module).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 8))- 0], T6_);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T8_;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T9_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
		T8_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T8_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		nimZeroMem((void*)T9_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T9_[0] = s;
		T10_ = NIM_NIL;
		T10_ = runtimeFormat__ropes_271(CC__extccomp_510[((*(*(*(*p).module).g).config).cCompiler)- 1].Field17, T9_, 1);
		T11_ = NIM_NIL;
		T11_ = indentLine__cgen_286(p, T10_);
		add__ropes_159(T8_, T11_);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, bodyCanRaise__cgen_16470)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
	{
		result = canRaiseDisp__cgen_11588(p, (*n)._kind_6.sons->data[((NI) 0)]);
		{
			if (!!(result)) goto LA4_;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_3155(n);
				i_2 = ((NI) 1);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA8;
						i = i_2;
						{
							NIM_BOOL T11_;
							T11_ = (NIM_BOOL)0;
							T11_ = bodyCanRaise__cgen_16470(p, (*n)._kind_6.sons->data[i]);
							if (!T11_) goto LA12_;
							result = NIM_TRUE;
							goto BeforeRet_;
						}
						LA12_: ;
						i_2 += ((NI) 1);
					} LA8: ;
				}
			}
		}
		LA4_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 108):
	{
		result = NIM_TRUE;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 98):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 81):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 80):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 82):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 83):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 51):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 52):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159):
	{
		result = NIM_FALSE;
	}
	break;
	default:
	{
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = safeLen__ast_3148(n);
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA19;
					i_3 = i_4;
					{
						NIM_BOOL T22_;
						T22_ = (NIM_BOOL)0;
						T22_ = bodyCanRaise__cgen_16470(p, (*n)._kind_6.sons->data[i_3]);
						if (!T22_) goto LA23_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA23_: ;
					i_4 += ((NI) 1);
				} LA19: ;
			}
		}
		result = NIM_FALSE;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genTryGoto__cgen_16490)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* fin;
	NI lab;
	NIM_BOOL hasExcept;
	tyTuple__T1RBf8m9axj9bvJRlYejkpkQ T12_;
	NI T13_;
	NI T21_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T44_;
	NimStringDesc* res_3;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T49_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T50_;
	tyTuple__T1RBf8m9axj9bvJRlYejkpkQ* T51_;
	NI i;
	tyTuple__T1RBf8m9axj9bvJRlYejkpkQ T154_;
	{
		NI T3_;
		NI T6_;
		T3_ = (NI)0;
		T3_ = len__ast_3155(t);
		if (!((*(*t)._kind_6.sons->data[(NI)(T3_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 107))) goto LA4_;
		T6_ = (NI)0;
		T6_ = len__ast_3155(t);
		fin = (*t)._kind_6.sons->data[(NI)(T6_ - ((NI) 1))];
	}
	goto LA1_;
	LA4_: ;
	{
		fin = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
	}
	LA1_: ;
	(*p).labels += ((NI) 1);
	lab = (*p).labels;
	hasExcept = ((*(*t)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 87));
	{
		if (!hasExcept) goto LA10_;
		(*p).withinTryWithExcept += ((NI) 1);
	}
	LA10_: ;
	nimZeroMem((void*)(&T12_), sizeof(tyTuple__T1RBf8m9axj9bvJRlYejkpkQ));
	T12_.Field0 = fin;
	T12_.Field1 = NIM_FALSE;
	T12_.Field2 = lab;
	asgnRef((void**) (&(*p).nestedTryStmts), (tySequence__IjAwukZ9aSEsol9c48He4FYQ*) incrSeqV3((TGenericSeq*)((*p).nestedTryStmts), (&NTIseqLtupleLfin58pnode_inexcept58bool_label58naturalTT__IjAwukZ9aSEsol9c48He4FYQ_)));
	T13_ = (*p).nestedTryStmts->Sup.len++;
	asgnRef((void**) (&(*p).nestedTryStmts->data[T13_].Field0), T12_.Field0);
	(*p).nestedTryStmts->data[T13_].Field1 = T12_.Field1;
	(*p).nestedTryStmts->data[T13_].Field2 = T12_.Field2;
	(*p).flags |= ((NU8)1)<<((((tyEnum_TCProcFlag__Iv1wQAvkoMCW3v9cTnZWvJw) 4)) & 7);
	{
		NIM_BOOL T16_;
		NIM_BOOL T17_;
		T16_ = (NIM_BOOL)0;
		T17_ = (NIM_BOOL)0;
		T17_ = isEmptyType__ast_4780((*t).typ);
		T16_ = !(T17_);
		if (!(T16_)) goto LA18_;
		T16_ = ((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0));
		LA18_: ;
		if (!T16_) goto LA19_;
		getTemp__cgen_7373(p, (*t).typ, d, NIM_FALSE);
	}
	LA19_: ;
	expr__cgen_11525(p, (*t)._kind_6.sons->data[((NI) 0)], d);
	T21_ = (NI)0;
	{
		NIM_BOOL T24_;
		NI T25_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T29_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T34_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T35_;
		T24_ = (NIM_BOOL)0;
		T25_ = (NI)0;
		T25_ = len__ast_3155(t);
		T24_ = (((NI) 1) < T25_);
		if (!(T24_)) goto LA26_;
		T24_ = ((*(*t)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 87));
		LA26_: ;
		if (!T24_) goto LA27_;
		T29_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T29_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 29);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_790));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA32_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA32_: ;
		T34_ = NIM_NIL;
		T34_ = rope__ropes_109(res);
		T35_ = NIM_NIL;
		T35_ = indentLine__cgen_286(p, T34_);
		add__ropes_159(T29_, T35_);
		T21_ = startBlockInternal__cgen_13308(p);
	}
	goto LA22_;
	LA27_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T37_;
		NimStringDesc* res_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T42_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T43_;
		T37_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T37_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA40_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA40_: ;
		T42_ = NIM_NIL;
		T42_ = rope__ropes_109(res_2);
		T43_ = NIM_NIL;
		T43_ = indentLine__cgen_286(p, T42_);
		add__ropes_159(T37_, T43_);
		T21_ = startBlockInternal__cgen_13308(p);
	}
	LA22_: ;
	T44_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T44_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	res_3 = rawNewString(((NI) 80));
	res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_466));
	cgFormatValue__cgen_154((&res_3), ((NI64) (lab)));
	res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_791));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA47_;
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA47_: ;
	T49_ = NIM_NIL;
	T49_ = rope__ropes_109(res_3);
	T50_ = NIM_NIL;
	T50_ = indentLine__cgen_286(p, T49_);
	add__ropes_159(T44_, T50_);
	T51_ = (tyTuple__T1RBf8m9axj9bvJRlYejkpkQ*)0;
	T51_ = X5BX5D___cgen_14870(((*p).nestedTryStmts) ? ((*p).nestedTryStmts->data) : NIM_NIL, ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0), ((NI) 1));
	(*T51_).Field1 = NIM_TRUE;
	i = ((NI) 1);
	{
		while (1) {
			NIM_BOOL T54_;
			NI T55_;
			NI nextExcept;
			tyTuple__T1RBf8m9axj9bvJRlYejkpkQ* T57_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T139_;
			NimStringDesc* res_9;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T140_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T145_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T146_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T147_;
			NimStringDesc* res_10;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T152_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T153_;
			T54_ = (NIM_BOOL)0;
			T55_ = (NI)0;
			T55_ = len__ast_3155(t);
			T54_ = (i < T55_);
			if (!(T54_)) goto LA56_;
			T54_ = ((*(*t)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 87));
			LA56_: ;
			if (!T54_) goto LA53;
			(*p).labels += ((NI) 1);
			nextExcept = (*p).labels;
			T57_ = (tyTuple__T1RBf8m9axj9bvJRlYejkpkQ*)0;
			T57_ = X5BX5D___cgen_14870(((*p).nestedTryStmts) ? ((*p).nestedTryStmts->data) : NIM_NIL, ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0), ((NI) 1));
			(*T57_).Field2 = nextExcept;
			{
				NIM_BOOL T60_;
				T60_ = (NIM_BOOL)0;
				T60_ = ((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 1));
				if (!(T60_)) goto LA61_;
				T60_ = isEmptyType__ast_4780((*t).typ);
				LA61_: ;
				if (!T60_) goto LA62_;
				(*d).k = ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0);
			}
			LA62_: ;
			{
				NI T66_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T77_;
				NimStringDesc* res_4;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T82_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T83_;
				NI T84_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T85_;
				NimStringDesc* res_5;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T90_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T91_;
				T66_ = (NI)0;
				T66_ = len__ast_3155((*t)._kind_6.sons->data[i]);
				if (!(T66_ == ((NI) 1))) goto LA67_;
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T73_;
					tyArray__dAmhZbEWrTM5xES2bTVweg T74_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T75_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T76_;
					if (!(((NI) 1) < i)) goto LA71_;
					T73_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T73_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					nimZeroMem((void*)T74_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
					T75_ = NIM_NIL;
					T75_ = percent___cgen_16614(T74_, 0);
					T76_ = NIM_NIL;
					T76_ = indentLine__cgen_286(p, T75_);
					add__ropes_159(T73_, T76_);
				}
				LA71_: ;
				T77_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T77_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_4 = rawNewString(((NI) 80));
				res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA80_;
					res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA80_: ;
				T82_ = NIM_NIL;
				T82_ = rope__ropes_109(res_4);
				T83_ = NIM_NIL;
				T83_ = indentLine__cgen_286(p, T82_);
				add__ropes_159(T77_, T83_);
				T84_ = (NI)0;
				T84_ = startBlockInternal__cgen_13308(p);
				T85_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T85_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_5 = rawNewString(((NI) 80));
				res_5 = resizeString(res_5, 21);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_792));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA88_;
					res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA88_: ;
				T90_ = NIM_NIL;
				T90_ = rope__ropes_109(res_5);
				T91_ = NIM_NIL;
				T91_ = indentLine__cgen_286(p, T90_);
				add__ropes_159(T85_, T91_);
				expr__cgen_11525(p, (*(*t)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)], d);
			}
			goto LA64_;
			LA67_: ;
			{
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* orExpr;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T123_;
				NimStringDesc* res_7;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T128_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T129_;
				NI T130_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T131_;
				NimStringDesc* res_8;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T136_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T137_;
				NI T138_;
				orExpr = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
				{
					NI j;
					NI colontmp_;
					NI T94_;
					NI i_2;
					j = (NI)0;
					colontmp_ = (NI)0;
					T94_ = (NI)0;
					T94_ = len__ast_3155((*t)._kind_6.sons->data[i]);
					colontmp_ = (NI)(T94_ - ((NI) 1));
					i_2 = ((NI) 0);
					{
						while (1) {
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* checkFor;
							NimStringDesc* memberName;
							NimStringDesc* res_6;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T113_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T114_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T115_;
							if (!(i_2 < colontmp_)) goto LA96;
							j = i_2;
							{
								if (!!((orExpr == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA99_;
								add__ropes_162(&orExpr, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_25));
							}
							LA99_: ;
							{
								if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 41))&63U)))!=0)) goto LA103_;
								checkFor = genTypeInfo2Name__cgen_7835((*p).module, (*(*(*t)._kind_6.sons->data[i])._kind_6.sons->data[j]).typ);
							}
							goto LA101_;
							LA103_: ;
							{
								checkFor = genTypeInfoV1__cgen_6798((*p).module, (*(*(*t)._kind_6.sons->data[i])._kind_6.sons->data[j]).typ, (*(*(*t)._kind_6.sons->data[i])._kind_6.sons->data[j]).info);
							}
							LA101_: ;
							{
								NIM_BOOL T108_;
								T108_ = (NIM_BOOL)0;
								T108_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
								if (T108_) goto LA109_;
								T108_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
								LA109_: ;
								if (!T108_) goto LA110_;
								memberName = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_793));
							}
							goto LA106_;
							LA110_: ;
							{
								memberName = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_794));
							}
							LA106_: ;
							res_6 = rawNewString(((NI) 80));
							T113_ = NIM_NIL;
							T113_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_731));
							cgFormatValue__cgen_147((&res_6), T113_);
							res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
							T114_ = NIM_NIL;
							T114_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_795));
							cgFormatValue__cgen_147((&res_6), T114_);
							res_6 = resizeString(res_6, 4);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_796));
							cgFormatValue__cgen_151((&res_6), memberName);
							res_6 = resizeString(res_6, 2);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
							cgFormatValue__cgen_147((&res_6), checkFor);
							res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
							T115_ = NIM_NIL;
							T115_ = rope__ropes_109(res_6);
							add__ropes_159(&orExpr, T115_);
							i_2 += ((NI) 1);
						} LA96: ;
					}
				}
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T120_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T121_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T122_;
					if (!(((NI) 1) < i)) goto LA118_;
					T120_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T120_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					T121_ = NIM_NIL;
					T121_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_797));
					T122_ = NIM_NIL;
					T122_ = indentLine__cgen_286(p, T121_);
					add__ropes_159(T120_, T122_);
				}
				LA118_: ;
				T123_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T123_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_7 = rawNewString(((NI) 80));
				res_7 = resizeString(res_7, 4);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
				cgFormatValue__cgen_147((&res_7), orExpr);
				res_7 = resizeString(res_7, 3);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_771));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA126_;
					res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA126_: ;
				T128_ = NIM_NIL;
				T128_ = rope__ropes_109(res_7);
				T129_ = NIM_NIL;
				T129_ = indentLine__cgen_286(p, T128_);
				add__ropes_159(T123_, T129_);
				T130_ = (NI)0;
				T130_ = startBlockInternal__cgen_13308(p);
				T131_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T131_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_8 = rawNewString(((NI) 80));
				res_8 = resizeString(res_8, 21);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_792));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA134_;
					res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA134_: ;
				T136_ = NIM_NIL;
				T136_ = rope__ropes_109(res_8);
				T137_ = NIM_NIL;
				T137_ = indentLine__cgen_286(p, T136_);
				add__ropes_159(T131_, T137_);
				T138_ = (NI)0;
				T138_ = len__ast_3155((*t)._kind_6.sons->data[i]);
				expr__cgen_11525(p, (*(*t)._kind_6.sons->data[i])._kind_6.sons->data[(NI)(T138_ - ((NI) 1))], d);
			}
			LA64_: ;
			T139_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T139_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_9 = rawNewString(((NI) 80));
			T140_ = NIM_NIL;
			T140_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_777));
			cgFormatValue__cgen_147((&res_9), T140_);
			res_9 = resizeString(res_9, 3);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_312));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA143_;
				res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA143_: ;
			T145_ = NIM_NIL;
			T145_ = rope__ropes_109(res_9);
			T146_ = NIM_NIL;
			T146_ = indentLine__cgen_286(p, T145_);
			add__ropes_159(T139_, T146_);
			T147_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T147_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_10 = rawNewString(((NI) 80));
			res_10 = resizeString(res_10, 2);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_466));
			cgFormatValue__cgen_154((&res_10), ((NI64) (nextExcept)));
			res_10 = resizeString(res_10, 3);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_791));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA150_;
				res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA150_: ;
			T152_ = NIM_NIL;
			T152_ = rope__ropes_109(res_10);
			T153_ = NIM_NIL;
			T153_ = indentLine__cgen_286(p, T152_);
			add__ropes_159(T147_, T153_);
			endBlock__cgen_13329(p);
			i += ((NI) 1);
		} LA53: ;
	}
	nimZeroMem((void*)(&T154_), sizeof(tyTuple__T1RBf8m9axj9bvJRlYejkpkQ));
	pop__cgen_13721((&(*p).nestedTryStmts), (&T154_));
	(void)(T154_);
	endBlock__cgen_13329(p);
	{
		NIM_BOOL T157_;
		NI T158_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T162_;
		NimStringDesc* res_11;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T167_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T168_;
		NI T169_;
		T157_ = (NIM_BOOL)0;
		T158_ = (NI)0;
		T158_ = len__ast_3155(t);
		T157_ = (i < T158_);
		if (!(T157_)) goto LA159_;
		T157_ = ((*(*t)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 107));
		LA159_: ;
		if (!T157_) goto LA160_;
		T162_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T162_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_11 = rawNewString(((NI) 80));
		res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA165_;
			res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA165_: ;
		T167_ = NIM_NIL;
		T167_ = rope__ropes_109(res_11);
		T168_ = NIM_NIL;
		T168_ = indentLine__cgen_286(p, T167_);
		add__ropes_159(T162_, T168_);
		T169_ = (NI)0;
		T169_ = startBlockInternal__cgen_13308(p);
		{
			NIM_BOOL T172_;
			T172_ = (NIM_BOOL)0;
			T172_ = bodyCanRaise__cgen_16470(p, (*(*t)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)]);
			if (!!(T172_)) goto LA173_;
			genStmts__cgen_11522(p, (*(*t)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)]);
		}
		goto LA170_;
		LA173_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T176_;
			NimStringDesc* res_12;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T181_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T182_;
			NimStringDesc* res_13;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T187_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T188_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T189_;
			NimStringDesc* res_14;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T194_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T195_;
			T176_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T176_ = procSec__cgendata_274(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
			res_12 = rawNewString(((NI) 80));
			res_12 = resizeString(res_12, 21);
appendString(res_12, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_798));
			cgFormatValue__cgen_154((&res_12), ((NI64) (lab)));
			res_12 = resizeString(res_12, 2);
appendString(res_12, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_426));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA179_;
				res_12 = resizeString(res_12, 1);
appendString(res_12, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA179_: ;
			T181_ = NIM_NIL;
			T181_ = rope__ropes_109(res_12);
			add__ropes_159(T176_, T181_);
			T182_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T182_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_13 = rawNewString(((NI) 80));
			res_13 = resizeString(res_13, 12);
appendString(res_13, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_799));
			cgFormatValue__cgen_154((&res_13), ((NI64) (lab)));
			res_13 = resizeString(res_13, 35);
appendString(res_13, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_800));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA185_;
				res_13 = resizeString(res_13, 1);
appendString(res_13, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA185_: ;
			T187_ = NIM_NIL;
			T187_ = rope__ropes_109(res_13);
			T188_ = NIM_NIL;
			T188_ = indentLine__cgen_286(p, T187_);
			add__ropes_159(T182_, T188_);
			genStmts__cgen_11522(p, (*(*t)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)]);
			T189_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T189_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_14 = rawNewString(((NI) 80));
			res_14 = resizeString(res_14, 23);
appendString(res_14, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_801));
			cgFormatValue__cgen_154((&res_14), ((NI64) (lab)));
			res_14 = resizeString(res_14, 2);
appendString(res_14, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_426));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA192_;
				res_14 = resizeString(res_14, 1);
appendString(res_14, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA192_: ;
			T194_ = NIM_NIL;
			T194_ = rope__ropes_109(res_14);
			T195_ = NIM_NIL;
			T195_ = indentLine__cgen_286(p, T194_);
			add__ropes_159(T189_, T195_);
		}
		LA170_: ;
		endBlock__cgen_13329(p);
	}
	LA160_: ;
	raiseExit__cgen_11546(p);
	{
		if (!hasExcept) goto LA198_;
		(*p).withinTryWithExcept += ((NI) 1);
	}
	LA198_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genRestoreFrameAfterException__cgen_15720)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p) {
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T22_;
		NimStringDesc* res_3;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T28_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T29_;
		if (!(((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 17))&31U)))!=0)) goto LA3_;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T9_;
			NimStringDesc* res;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T15_;
			NimStringDesc* res_2;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T21_;
			if (!!((((*p).flags &((NU8)1<<((NU)(((tyEnum_TCProcFlag__Iv1wQAvkoMCW3v9cTnZWvJw) 2))&7U)))!=0))) goto LA7_;
			(*p).flags |= ((NU8)1)<<((((tyEnum_TCProcFlag__Iv1wQAvkoMCW3v9cTnZWvJw) 2)) & 7);
			T9_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T9_ = procSec__cgendata_274(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
			res = rawNewString(((NI) 80));
			res = resizeString(res, 22);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_810));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA12_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA12_: ;
			T14_ = NIM_NIL;
			T14_ = rope__ropes_109(res);
			add__ropes_159(T9_, T14_);
			T15_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T15_ = procSec__cgendata_274(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 1));
			res_2 = rawNewString(((NI) 80));
			res_2 = resizeString(res_2, 16);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_811));
			T16_ = NIM_NIL;
			T16_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_812));
			cgFormatValue__cgen_147((&res_2), T16_);
			res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_312));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA19_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA19_: ;
			T21_ = NIM_NIL;
			T21_ = rope__ropes_109(res_2);
			add__ropes_159(T15_, T21_);
		}
		LA7_: ;
		T22_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T22_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_3 = rawNewString(((NI) 80));
		T23_ = NIM_NIL;
		T23_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_813));
		cgFormatValue__cgen_147((&res_3), T23_);
		res_3 = resizeString(res_3, 15);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_814));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA26_;
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA26_: ;
		T28_ = NIM_NIL;
		T28_ = rope__ropes_109(res_3);
		T29_ = NIM_NIL;
		T29_ = indentLine__cgen_286(p, T28_);
		add__ropes_159(T22_, T29_);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genTryCpp__cgen_15773)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	NI etmp;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T8_;
	NimStringDesc* res;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* fin;
	tyTuple__T1RBf8m9axj9bvJRlYejkpkQ T17_;
	NI T18_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T46_;
	NimStringDesc* res_5;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T47_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T52_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T53_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T54_;
	NimStringDesc* res_6;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T59_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T60_;
	tyTuple__T1RBf8m9axj9bvJRlYejkpkQ* T61_;
	NIM_BOOL hasImportedCppExceptions;
	NI i;
	NIM_BOOL hasIf;
	NIM_BOOL hasElse;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T213_;
	NimStringDesc* res_17;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T218_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T219_;
	NIM_BOOL catchAllPresent;
	tyTuple__T1RBf8m9axj9bvJRlYejkpkQ T287_;
	includeHeader__cgendata_214((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_802));
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = isEmptyType__ast_4780((*t).typ);
		T3_ = !(T4_);
		if (!(T3_)) goto LA5_;
		T3_ = ((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0));
		LA5_: ;
		if (!T3_) goto LA6_;
		getTemp__cgen_7373(p, (*t).typ, d, NIM_FALSE);
	}
	LA6_: ;
	genLineDir__cgen_369(p, t);
	(*p).labels += ((NI) 2);
	etmp = (*p).labels;
	T8_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T8_ = procSec__cgendata_274(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 1));
	res = rawNewString(((NI) 80));
	res = resizeString(res, 21);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_803));
	cgFormatValue__cgen_154((&res), ((NI64) (etmp)));
	res = resizeString(res, 12);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_804));
	T9_ = NIM_NIL;
	T9_ = rope__ropes_109(res);
	add__ropes_159(T8_, T9_);
	{
		NI T12_;
		NI T15_;
		T12_ = (NI)0;
		T12_ = len__ast_3155(t);
		if (!((*(*t)._kind_6.sons->data[(NI)(T12_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 107))) goto LA13_;
		T15_ = (NI)0;
		T15_ = len__ast_3155(t);
		fin = (*t)._kind_6.sons->data[(NI)(T15_ - ((NI) 1))];
	}
	goto LA10_;
	LA13_: ;
	{
		fin = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
	}
	LA10_: ;
	nimZeroMem((void*)(&T17_), sizeof(tyTuple__T1RBf8m9axj9bvJRlYejkpkQ));
	T17_.Field0 = fin;
	T17_.Field1 = NIM_FALSE;
	T17_.Field2 = ((NI) 0);
	asgnRef((void**) (&(*p).nestedTryStmts), (tySequence__IjAwukZ9aSEsol9c48He4FYQ*) incrSeqV3((TGenericSeq*)((*p).nestedTryStmts), (&NTIseqLtupleLfin58pnode_inexcept58bool_label58naturalTT__IjAwukZ9aSEsol9c48He4FYQ_)));
	T18_ = (*p).nestedTryStmts->Sup.len++;
	asgnRef((void**) (&(*p).nestedTryStmts->data[T18_].Field0), T17_.Field0);
	(*p).nestedTryStmts->data[T18_].Field1 = T17_.Field1;
	(*p).nestedTryStmts->data[T18_].Field2 = T17_.Field2;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T23_;
		NimStringDesc* res_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T28_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T29_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T30_;
		NimStringDesc* res_3;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T35_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T36_;
		if (!((*t).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 154))) goto LA21_;
		T23_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T23_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 5);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_805));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA26_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA26_: ;
		T28_ = NIM_NIL;
		T28_ = rope__ropes_109(res_2);
		T29_ = NIM_NIL;
		T29_ = indentLine__cgen_286(p, T28_);
		add__ropes_159(T23_, T29_);
		expr__cgen_11525(p, (*t)._kind_6.sons->data[((NI) 0)], d);
		T30_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T30_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_3 = rawNewString(((NI) 80));
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA33_;
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA33_: ;
		T35_ = NIM_NIL;
		T35_ = rope__ropes_109(res_3);
		T36_ = NIM_NIL;
		T36_ = indentLine__cgen_286(p, T35_);
		add__ropes_159(T30_, T36_);
	}
	goto LA19_;
	LA21_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T38_;
		NimStringDesc* res_4;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T43_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T44_;
		NI T45_;
		T38_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T38_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_4 = rawNewString(((NI) 80));
		res_4 = resizeString(res_4, 5);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_805));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA41_;
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA41_: ;
		T43_ = NIM_NIL;
		T43_ = rope__ropes_109(res_4);
		T44_ = NIM_NIL;
		T44_ = indentLine__cgen_286(p, T43_);
		add__ropes_159(T38_, T44_);
		T45_ = (NI)0;
		T45_ = startBlockInternal__cgen_13308(p);
		expr__cgen_11525(p, (*t)._kind_6.sons->data[((NI) 0)], d);
		endBlock__cgen_13329(p);
	}
	LA19_: ;
	T46_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T46_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	res_5 = rawNewString(((NI) 80));
	res_5 = resizeString(res_5, 7);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_806));
	T47_ = NIM_NIL;
	T47_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_807));
	cgFormatValue__cgen_147((&res_5), T47_);
	res_5 = resizeString(res_5, 3);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_808));
	cgFormatValue__cgen_154((&res_5), ((NI64) ((NI)(((NI) (etmp)) + ((NI) 1)))));
	res_5 = resizeString(res_5, 4);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_809));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA50_;
		res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA50_: ;
	T52_ = NIM_NIL;
	T52_ = rope__ropes_109(res_5);
	T53_ = NIM_NIL;
	T53_ = indentLine__cgen_286(p, T52_);
	add__ropes_159(T46_, T53_);
	genRestoreFrameAfterException__cgen_15720(p);
	T54_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T54_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	res_6 = rawNewString(((NI) 80));
	res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_157));
	cgFormatValue__cgen_154((&res_6), ((NI64) (etmp)));
	res_6 = resizeString(res_6, 29);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_815));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA57_;
		res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA57_: ;
	T59_ = NIM_NIL;
	T59_ = rope__ropes_109(res_6);
	T60_ = NIM_NIL;
	T60_ = indentLine__cgen_286(p, T59_);
	add__ropes_159(T54_, T60_);
	T61_ = (tyTuple__T1RBf8m9axj9bvJRlYejkpkQ*)0;
	T61_ = X5BX5D___cgen_14870(((*p).nestedTryStmts) ? ((*p).nestedTryStmts->data) : NIM_NIL, ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0), ((NI) 1));
	(*T61_).Field1 = NIM_TRUE;
	hasImportedCppExceptions = NIM_FALSE;
	i = ((NI) 1);
	hasIf = NIM_FALSE;
	hasElse = NIM_FALSE;
	{
		while (1) {
			NIM_BOOL T64_;
			NI T65_;
			T64_ = (NIM_BOOL)0;
			T65_ = (NI)0;
			T65_ = len__ast_3155(t);
			T64_ = (i < T65_);
			if (!(T64_)) goto LA66_;
			T64_ = ((*(*t)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 87));
			LA66_: ;
			if (!T64_) goto LA63;
			{
				NIM_BOOL T69_;
				T69_ = (NIM_BOOL)0;
				T69_ = ((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 1));
				if (!(T69_)) goto LA70_;
				T69_ = isEmptyType__ast_4780((*t).typ);
				LA70_: ;
				if (!T69_) goto LA71_;
				(*d).k = ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0);
			}
			LA71_: ;
			{
				NI T75_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T86_;
				NimStringDesc* res_7;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T91_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T92_;
				NI T93_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T94_;
				NimStringDesc* res_8;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T99_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T100_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T101_;
				NimStringDesc* res_9;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T102_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T107_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T108_;
				T75_ = (NI)0;
				T75_ = len__ast_3155((*t)._kind_6.sons->data[i]);
				if (!(T75_ == ((NI) 1))) goto LA76_;
				hasImportedCppExceptions = NIM_TRUE;
				hasElse = NIM_TRUE;
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T82_;
					tyArray__dAmhZbEWrTM5xES2bTVweg T83_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T84_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T85_;
					if (!hasIf) goto LA80_;
					T82_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T82_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					nimZeroMem((void*)T83_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
					T84_ = NIM_NIL;
					T84_ = percent___cgen_15909(T83_, 0);
					T85_ = NIM_NIL;
					T85_ = indentLine__cgen_286(p, T84_);
					add__ropes_159(T82_, T85_);
				}
				LA80_: ;
				T86_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T86_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_7 = rawNewString(((NI) 80));
				res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA89_;
					res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA89_: ;
				T91_ = NIM_NIL;
				T91_ = rope__ropes_109(res_7);
				T92_ = NIM_NIL;
				T92_ = indentLine__cgen_286(p, T91_);
				add__ropes_159(T86_, T92_);
				T93_ = (NI)0;
				T93_ = startBlockInternal__cgen_13308(p);
				T94_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T94_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_8 = rawNewString(((NI) 80));
				res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_157));
				cgFormatValue__cgen_154((&res_8), ((NI64) (etmp)));
				res_8 = resizeString(res_8, 12);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_804));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA97_;
					res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA97_: ;
				T99_ = NIM_NIL;
				T99_ = rope__ropes_109(res_8);
				T100_ = NIM_NIL;
				T100_ = indentLine__cgen_286(p, T99_);
				add__ropes_159(T94_, T100_);
				expr__cgen_11525(p, (*(*t)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)], d);
				T101_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T101_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_9 = rawNewString(((NI) 80));
				T102_ = NIM_NIL;
				T102_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_777));
				cgFormatValue__cgen_147((&res_9), T102_);
				res_9 = resizeString(res_9, 3);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_312));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA105_;
					res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA105_: ;
				T107_ = NIM_NIL;
				T107_ = rope__ropes_109(res_9);
				T108_ = NIM_NIL;
				T108_ = indentLine__cgen_286(p, T107_);
				add__ropes_159(T101_, T108_);
				endBlock__cgen_13329(p);
			}
			goto LA73_;
			LA76_: ;
			{
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* orExpr;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* exvar;
				orExpr = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
				exvar = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
				{
					NI j;
					NI colontmp_;
					NI T111_;
					NI i_2;
					j = (NI)0;
					colontmp_ = (NI)0;
					T111_ = (NI)0;
					T111_ = len__ast_3155((*t)._kind_6.sons->data[i]);
					colontmp_ = (NI)(T111_ - ((NI) 1));
					i_2 = ((NI) 0);
					{
						while (1) {
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* typeNode;
							if (!(i_2 < colontmp_)) goto LA113;
							j = i_2;
							typeNode = (*(*t)._kind_6.sons->data[i])._kind_6.sons->data[j];
							{
								NIM_BOOL T116_;
								T116_ = (NIM_BOOL)0;
								T116_ = isInfixAs__ast_4936((*(*t)._kind_6.sons->data[i])._kind_6.sons->data[j]);
								if (!T116_) goto LA117_;
								typeNode = (*(*(*t)._kind_6.sons->data[i])._kind_6.sons->data[j])._kind_6.sons->data[((NI) 1)];
								exvar = (*(*(*t)._kind_6.sons->data[i])._kind_6.sons->data[j])._kind_6.sons->data[((NI) 2)];
							}
							LA117_: ;
							{
								NIM_BOOL T121_;
								T121_ = (NIM_BOOL)0;
								T121_ = isImportedException__ast_4905((*typeNode).typ, (*(*(*p).module).g).config);
								if (!T121_) goto LA122_;
								hasImportedCppExceptions = NIM_TRUE;
							}
							goto LA119_;
							LA122_: ;
							{
								tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* checkFor;
								NimStringDesc* memberName;
								NimStringDesc* res_10;
								tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T141_;
								tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T142_;
								tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T143_;
								{
									if (!!((orExpr == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA127_;
									add__ropes_162(&orExpr, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_25));
								}
								LA127_: ;
								{
									if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 41))&63U)))!=0)) goto LA131_;
									checkFor = genTypeInfo2Name__cgen_7835((*p).module, (*typeNode).typ);
								}
								goto LA129_;
								LA131_: ;
								{
									checkFor = genTypeInfoV1__cgen_6798((*p).module, (*typeNode).typ, (*typeNode).info);
								}
								LA129_: ;
								{
									NIM_BOOL T136_;
									T136_ = (NIM_BOOL)0;
									T136_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
									if (T136_) goto LA137_;
									T136_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
									LA137_: ;
									if (!T136_) goto LA138_;
									memberName = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_793));
								}
								goto LA134_;
								LA138_: ;
								{
									memberName = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_794));
								}
								LA134_: ;
								res_10 = rawNewString(((NI) 80));
								T141_ = NIM_NIL;
								T141_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_731));
								cgFormatValue__cgen_147((&res_10), T141_);
								res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
								T142_ = NIM_NIL;
								T142_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_795));
								cgFormatValue__cgen_147((&res_10), T142_);
								res_10 = resizeString(res_10, 4);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_796));
								cgFormatValue__cgen_151((&res_10), memberName);
								res_10 = resizeString(res_10, 2);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
								cgFormatValue__cgen_147((&res_10), checkFor);
								res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
								T143_ = NIM_NIL;
								T143_ = rope__ropes_109(res_10);
								add__ropes_159(&orExpr, T143_);
							}
							LA119_: ;
							i_2 += ((NI) 1);
						} LA113: ;
					}
				}
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T184_;
					NimStringDesc* res_14;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T189_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T190_;
					NI T191_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T192_;
					NimStringDesc* res_15;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T193_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T198_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T199_;
					if (!!((orExpr == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA146_;
					{
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T152_;
						NimStringDesc* res_11;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T157_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T158_;
						NI T159_;
						if (!hasIf) goto LA150_;
						T152_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
						T152_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
						res_11 = rawNewString(((NI) 80));
						res_11 = resizeString(res_11, 9);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_816));
						cgFormatValue__cgen_147((&res_11), orExpr);
						res_11 = resizeString(res_11, 3);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_771));
						{
							if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA155_;
							res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
						}
						LA155_: ;
						T157_ = NIM_NIL;
						T157_ = rope__ropes_109(res_11);
						T158_ = NIM_NIL;
						T158_ = indentLine__cgen_286(p, T157_);
						add__ropes_159(T152_, T158_);
						T159_ = (NI)0;
						T159_ = startBlockInternal__cgen_13308(p);
					}
					goto LA148_;
					LA150_: ;
					{
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T161_;
						NimStringDesc* res_12;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T166_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T167_;
						NI T168_;
						T161_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
						T161_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
						res_12 = rawNewString(((NI) 80));
						res_12 = resizeString(res_12, 4);
appendString(res_12, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
						cgFormatValue__cgen_147((&res_12), orExpr);
						res_12 = resizeString(res_12, 3);
appendString(res_12, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_771));
						{
							if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA164_;
							res_12 = resizeString(res_12, 1);
appendString(res_12, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
						}
						LA164_: ;
						T166_ = NIM_NIL;
						T166_ = rope__ropes_109(res_12);
						T167_ = NIM_NIL;
						T167_ = indentLine__cgen_286(p, T166_);
						add__ropes_159(T161_, T167_);
						T168_ = (NI)0;
						T168_ = startBlockInternal__cgen_13308(p);
						hasIf = NIM_TRUE;
					}
					LA148_: ;
					{
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T173_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T174_;
						NimStringDesc* res_13;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T175_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T176_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T177_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T182_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T183_;
						if (!!((exvar == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA171_;
						T173_ = NIM_NIL;
						T173_ = mangleLocalName__cgen_744(p, (*exvar)._kind_4.sym);
						fillLoc__cgen_71((&(*(*exvar)._kind_4.sym).loc), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 1), exvar, T173_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 2));
						T174_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
						T174_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
						res_13 = rawNewString(((NI) 80));
						T175_ = NIM_NIL;
						T175_ = getTypeDesc__cgen_6662((*p).module, (*(*exvar)._kind_4.sym).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
						cgFormatValue__cgen_147((&res_13), T175_);
						res_13 = resizeString(res_13, 1);
appendString(res_13, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_13));
						T176_ = NIM_NIL;
						T176_ = rdLoc__cgen_435((*(*exvar)._kind_4.sym).loc);
						cgFormatValue__cgen_147((&res_13), T176_);
						res_13 = resizeString(res_13, 4);
appendString(res_13, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_817));
						T177_ = NIM_NIL;
						T177_ = rope__ropes_115(((NI64) ((NI)(((NI) (etmp)) + ((NI) 1)))));
						cgFormatValue__cgen_147((&res_13), T177_);
						res_13 = resizeString(res_13, 2);
appendString(res_13, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_426));
						{
							if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA180_;
							res_13 = resizeString(res_13, 1);
appendString(res_13, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
						}
						LA180_: ;
						T182_ = NIM_NIL;
						T182_ = rope__ropes_109(res_13);
						T183_ = NIM_NIL;
						T183_ = indentLine__cgen_286(p, T182_);
						add__ropes_159(T174_, T183_);
					}
					LA171_: ;
					T184_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T184_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					res_14 = rawNewString(((NI) 80));
					res_14 = resizeString(res_14, 1);
appendString(res_14, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_157));
					cgFormatValue__cgen_154((&res_14), ((NI64) (etmp)));
					res_14 = resizeString(res_14, 12);
appendString(res_14, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_804));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA187_;
						res_14 = resizeString(res_14, 1);
appendString(res_14, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
					}
					LA187_: ;
					T189_ = NIM_NIL;
					T189_ = rope__ropes_109(res_14);
					T190_ = NIM_NIL;
					T190_ = indentLine__cgen_286(p, T189_);
					add__ropes_159(T184_, T190_);
					T191_ = (NI)0;
					T191_ = len__ast_3155((*t)._kind_6.sons->data[i]);
					expr__cgen_11525(p, (*(*t)._kind_6.sons->data[i])._kind_6.sons->data[(NI)(T191_ - ((NI) 1))], d);
					T192_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T192_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					res_15 = rawNewString(((NI) 80));
					T193_ = NIM_NIL;
					T193_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_777));
					cgFormatValue__cgen_147((&res_15), T193_);
					res_15 = resizeString(res_15, 3);
appendString(res_15, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_312));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA196_;
						res_15 = resizeString(res_15, 1);
appendString(res_15, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
					}
					LA196_: ;
					T198_ = NIM_NIL;
					T198_ = rope__ropes_109(res_15);
					T199_ = NIM_NIL;
					T199_ = indentLine__cgen_286(p, T198_);
					add__ropes_159(T192_, T199_);
					endBlock__cgen_13329(p);
				}
				LA146_: ;
			}
			LA73_: ;
			i += ((NI) 1);
		} LA63: ;
	}
	{
		NIM_BOOL T202_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T206_;
		NimStringDesc* res_16;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T211_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T212_;
		T202_ = (NIM_BOOL)0;
		T202_ = hasIf;
		if (!(T202_)) goto LA203_;
		T202_ = !(hasElse);
		LA203_: ;
		if (!T202_) goto LA204_;
		T206_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T206_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_16 = rawNewString(((NI) 80));
		res_16 = resizeString(res_16, 11);
appendString(res_16, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_818));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA209_;
			res_16 = resizeString(res_16, 1);
appendString(res_16, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA209_: ;
		T211_ = NIM_NIL;
		T211_ = rope__ropes_109(res_16);
		T212_ = NIM_NIL;
		T212_ = indentLine__cgen_286(p, T211_);
		add__ropes_159(T206_, T212_);
	}
	LA204_: ;
	T213_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T213_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	res_17 = rawNewString(((NI) 80));
	res_17 = resizeString(res_17, 1);
appendString(res_17, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA216_;
		res_17 = resizeString(res_17, 1);
appendString(res_17, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA216_: ;
	T218_ = NIM_NIL;
	T218_ = rope__ropes_109(res_17);
	T219_ = NIM_NIL;
	T219_ = indentLine__cgen_286(p, T218_);
	add__ropes_159(T213_, T219_);
	catchAllPresent = NIM_FALSE;
	(*p).flags |= ((NU8)1)<<((((tyEnum_TCProcFlag__Iv1wQAvkoMCW3v9cTnZWvJw) 3)) & 7);
	{
		if (!hasImportedCppExceptions) goto LA222_;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3155(t);
			i_4 = ((NI) 1);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA226;
					i_3 = i_4;
					{
						if (!!(((*(*t)._kind_6.sons->data[i_3]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 87)))) goto LA229_;
						goto LA224;
					}
					LA229_: ;
					{
						NIM_BOOL T233_;
						T233_ = (NIM_BOOL)0;
						T233_ = ((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 1));
						if (!(T233_)) goto LA234_;
						T233_ = isEmptyType__ast_4780((*t).typ);
						LA234_: ;
						if (!T233_) goto LA235_;
						(*d).k = ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0);
					}
					LA235_: ;
					{
						NI T239_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T242_;
						NimStringDesc* res_18;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T243_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T244_;
						NI T245_;
						T239_ = (NI)0;
						T239_ = len__ast_3155((*t)._kind_6.sons->data[i_3]);
						if (!(T239_ == ((NI) 1))) goto LA240_;
						T242_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
						T242_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
						res_18 = rawNewString(((NI) 80));
						res_18 = resizeString(res_18, 13);
appendString(res_18, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_819));
						T243_ = NIM_NIL;
						T243_ = rope__ropes_109(res_18);
						T244_ = NIM_NIL;
						T244_ = indentLine__cgen_286(p, T243_);
						add__ropes_159(T242_, T244_);
						T245_ = (NI)0;
						T245_ = startBlockInternal__cgen_13308(p);
						genRestoreFrameAfterException__cgen_15720(p);
						expr__cgen_11525(p, (*(*t)._kind_6.sons->data[i_3])._kind_6.sons->data[((NI) 0)], d);
						endBlock__cgen_13329(p);
						catchAllPresent = NIM_TRUE;
					}
					goto LA237_;
					LA240_: ;
					{
						{
							NI j_2;
							NI colontmp__3;
							NI T248_;
							NI i_5;
							j_2 = (NI)0;
							colontmp__3 = (NI)0;
							T248_ = (NI)0;
							T248_ = len__ast_3155((*t)._kind_6.sons->data[i_3]);
							colontmp__3 = (NI)(T248_ - ((NI) 1));
							i_5 = ((NI) 0);
							{
								while (1) {
									tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* typeNode_2;
									if (!(i_5 < colontmp__3)) goto LA250;
									j_2 = i_5;
									typeNode_2 = (*(*t)._kind_6.sons->data[i_3])._kind_6.sons->data[j_2];
									{
										NIM_BOOL T253_;
										T253_ = (NIM_BOOL)0;
										T253_ = isInfixAs__ast_4936((*(*t)._kind_6.sons->data[i_3])._kind_6.sons->data[j_2]);
										if (!T253_) goto LA254_;
										typeNode_2 = (*(*(*t)._kind_6.sons->data[i_3])._kind_6.sons->data[j_2])._kind_6.sons->data[((NI) 1)];
										{
											NIM_BOOL T258_;
											tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* exvar_2;
											tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T261_;
											tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T262_;
											NimStringDesc* res_19;
											tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T263_;
											tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T264_;
											tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T269_;
											tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T270_;
											NI T271_;
											NI T272_;
											T258_ = (NIM_BOOL)0;
											T258_ = isImportedException__ast_4905((*typeNode_2).typ, (*(*(*p).module).g).config);
											if (!T258_) goto LA259_;
											exvar_2 = (*(*(*t)._kind_6.sons->data[i_3])._kind_6.sons->data[j_2])._kind_6.sons->data[((NI) 2)];
											T261_ = NIM_NIL;
											T261_ = mangleLocalName__cgen_744(p, (*exvar_2)._kind_4.sym);
											fillLoc__cgen_71((&(*(*exvar_2)._kind_4.sym).loc), ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 1), exvar_2, T261_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 2));
											T262_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
											T262_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
											res_19 = rawNewString(((NI) 80));
											res_19 = resizeString(res_19, 7);
appendString(res_19, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_806));
											T263_ = NIM_NIL;
											T263_ = getTypeDesc__cgen_6662((*p).module, (*typeNode_2).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
											cgFormatValue__cgen_147((&res_19), T263_);
											res_19 = resizeString(res_19, 2);
appendString(res_19, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_820));
											T264_ = NIM_NIL;
											T264_ = rdLoc__cgen_435((*(*exvar_2)._kind_4.sym).loc);
											cgFormatValue__cgen_147((&res_19), T264_);
											res_19 = resizeString(res_19, 3);
appendString(res_19, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_771));
											{
												if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA267_;
												res_19 = resizeString(res_19, 1);
appendString(res_19, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
											}
											LA267_: ;
											T269_ = NIM_NIL;
											T269_ = rope__ropes_109(res_19);
											T270_ = NIM_NIL;
											T270_ = indentLine__cgen_286(p, T269_);
											add__ropes_159(T262_, T270_);
											T271_ = (NI)0;
											T271_ = startBlockInternal__cgen_13308(p);
											genRestoreFrameAfterException__cgen_15720(p);
											T272_ = (NI)0;
											T272_ = len__ast_3155((*t)._kind_6.sons->data[i_3]);
											expr__cgen_11525(p, (*(*t)._kind_6.sons->data[i_3])._kind_6.sons->data[(NI)(T272_ - ((NI) 1))], d);
											endBlock__cgen_13329(p);
										}
										LA259_: ;
									}
									goto LA251_;
									LA254_: ;
									{
										NIM_BOOL T274_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T277_;
										NimStringDesc* res_20;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T278_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T283_;
										tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T284_;
										NI T285_;
										NI T286_;
										T274_ = (NIM_BOOL)0;
										T274_ = isImportedException__ast_4905((*typeNode_2).typ, (*(*(*p).module).g).config);
										if (!T274_) goto LA275_;
										T277_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
										T277_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
										res_20 = rawNewString(((NI) 80));
										res_20 = resizeString(res_20, 7);
appendString(res_20, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_806));
										T278_ = NIM_NIL;
										T278_ = getTypeDesc__cgen_6662((*p).module, (*(*(*t)._kind_6.sons->data[i_3])._kind_6.sons->data[j_2]).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
										cgFormatValue__cgen_147((&res_20), T278_);
										res_20 = resizeString(res_20, 4);
appendString(res_20, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_821));
										{
											if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA281_;
											res_20 = resizeString(res_20, 1);
appendString(res_20, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
										}
										LA281_: ;
										T283_ = NIM_NIL;
										T283_ = rope__ropes_109(res_20);
										T284_ = NIM_NIL;
										T284_ = indentLine__cgen_286(p, T283_);
										add__ropes_159(T277_, T284_);
										T285_ = (NI)0;
										T285_ = startBlockInternal__cgen_13308(p);
										genRestoreFrameAfterException__cgen_15720(p);
										T286_ = (NI)0;
										T286_ = len__ast_3155((*t)._kind_6.sons->data[i_3]);
										expr__cgen_11525(p, (*(*t)._kind_6.sons->data[i_3])._kind_6.sons->data[(NI)(T286_ - ((NI) 1))], d);
										endBlock__cgen_13329(p);
									}
									goto LA251_;
									LA275_: ;
									LA251_: ;
									i_5 += ((NI) 1);
								} LA250: ;
							}
						}
					}
					LA237_: ;
					i_4 += ((NI) 1);
				} LA226: ;
			}
		} LA224: ;
	}
	LA222_: ;
	(*p).flags &= ~(((NU8)1) << ((((tyEnum_TCProcFlag__Iv1wQAvkoMCW3v9cTnZWvJw) 3)) & 7));
	nimZeroMem((void*)(&T287_), sizeof(tyTuple__T1RBf8m9axj9bvJRlYejkpkQ));
	pop__cgen_13721((&(*p).nestedTryStmts), (&T287_));
	(void)(T287_);
	{
		NIM_BOOL T290_;
		NI T291_;
		NI T293_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T311_;
		NimStringDesc* res_23;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T316_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T317_;
		NI T318_;
		NI T319_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T320_;
		NimStringDesc* res_24;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T325_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T326_;
		T290_ = (NIM_BOOL)0;
		T291_ = (NI)0;
		T291_ = len__ast_3155(t);
		T290_ = (((NI) 0) < T291_);
		if (!(T290_)) goto LA292_;
		T293_ = (NI)0;
		T293_ = len__ast_3155(t);
		T290_ = ((*(*t)._kind_6.sons->data[(NI)(T293_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 107));
		LA292_: ;
		if (!T290_) goto LA294_;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T300_;
			NimStringDesc* res_21;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T301_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T302_;
			NI T303_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T304_;
			NimStringDesc* res_22;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T309_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T310_;
			if (!!(catchAllPresent)) goto LA298_;
			T300_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T300_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_21 = rawNewString(((NI) 80));
			res_21 = resizeString(res_21, 13);
appendString(res_21, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_819));
			T301_ = NIM_NIL;
			T301_ = rope__ropes_109(res_21);
			T302_ = NIM_NIL;
			T302_ = indentLine__cgen_286(p, T301_);
			add__ropes_159(T300_, T302_);
			T303_ = (NI)0;
			T303_ = startBlockInternal__cgen_13308(p);
			genRestoreFrameAfterException__cgen_15720(p);
			T304_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T304_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_22 = rawNewString(((NI) 80));
			res_22 = resizeString(res_22, 1);
appendString(res_22, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_157));
			cgFormatValue__cgen_154((&res_22), ((NI64) (etmp)));
			res_22 = resizeString(res_22, 29);
appendString(res_22, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_815));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA307_;
				res_22 = resizeString(res_22, 1);
appendString(res_22, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA307_: ;
			T309_ = NIM_NIL;
			T309_ = rope__ropes_109(res_22);
			T310_ = NIM_NIL;
			T310_ = indentLine__cgen_286(p, T309_);
			add__ropes_159(T304_, T310_);
			endBlock__cgen_13329(p);
		}
		LA298_: ;
		T311_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T311_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_23 = rawNewString(((NI) 80));
		res_23 = resizeString(res_23, 1);
appendString(res_23, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA314_;
			res_23 = resizeString(res_23, 1);
appendString(res_23, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA314_: ;
		T316_ = NIM_NIL;
		T316_ = rope__ropes_109(res_23);
		T317_ = NIM_NIL;
		T317_ = indentLine__cgen_286(p, T316_);
		add__ropes_159(T311_, T317_);
		T318_ = (NI)0;
		T318_ = startBlockInternal__cgen_13308(p);
		T319_ = (NI)0;
		T319_ = len__ast_3155(t);
		genStmts__cgen_11522(p, (*(*t)._kind_6.sons->data[(NI)(T319_ - ((NI) 1))])._kind_6.sons->data[((NI) 0)]);
		T320_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T320_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_24 = rawNewString(((NI) 80));
		res_24 = resizeString(res_24, 5);
appendString(res_24, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_822));
		cgFormatValue__cgen_154((&res_24), ((NI64) (etmp)));
		res_24 = resizeString(res_24, 27);
appendString(res_24, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_823));
		cgFormatValue__cgen_154((&res_24), ((NI64) (etmp)));
		res_24 = resizeString(res_24, 3);
appendString(res_24, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_824));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA323_;
			res_24 = resizeString(res_24, 1);
appendString(res_24, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA323_: ;
		T325_ = NIM_NIL;
		T325_ = rope__ropes_109(res_24);
		T326_ = NIM_NIL;
		T326_ = indentLine__cgen_286(p, T325_);
		add__ropes_159(T320_, T326_);
		endBlock__cgen_13329(p);
	}
	LA294_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genTrySetjmp__cgen_16834)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	NIM_BOOL quirkyExceptions;
	NIM_BOOL T8_;
	NIM_BOOL T10_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T17_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* safePoint;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* fin;
	tyTuple__T1RBf8m9axj9bvJRlYejkpkQ T132_;
	NI T133_;
	tyTuple__T1RBf8m9axj9bvJRlYejkpkQ* T193_;
	NI i;
	tyTuple__T1RBf8m9axj9bvJRlYejkpkQ T304_;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = isEmptyType__ast_4780((*t).typ);
		T3_ = !(T4_);
		if (!(T3_)) goto LA5_;
		T3_ = ((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0));
		LA5_: ;
		if (!T3_) goto LA6_;
		getTemp__cgen_7373(p, (*t).typ, d, NIM_FALSE);
	}
	LA6_: ;
	T8_ = (NIM_BOOL)0;
	T8_ = ((*(*(*(*p).module).g).config).exc == ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 4));
	if (T8_) goto LA9_;
	T10_ = (NIM_BOOL)0;
	T10_ = ((*t).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 154));
	if (!(T10_)) goto LA11_;
	T10_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 15))&63U)))!=0);
	LA11_: ;
	T8_ = T10_;
	LA9_: ;
	quirkyExceptions = T8_;
	{
		if (!!(quirkyExceptions)) goto LA14_;
		includeHeader__cgendata_214((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_825));
	}
	goto LA12_;
	LA14_: ;
	{
		(*p).flags |= ((NU8)1)<<((((tyEnum_TCProcFlag__Iv1wQAvkoMCW3v9cTnZWvJw) 3)) & 7);
	}
	LA12_: ;
	genLineDir__cgen_369(p, t);
	T17_ = NIM_NIL;
	T17_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_807));
	(void)(T17_);
	safePoint = NIM_NIL;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T22_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T28_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T29_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T30_;
		NimStringDesc* res_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T31_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T36_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T37_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T118_;
		NimStringDesc* res_10;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T123_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T124_;
		if (!!(quirkyExceptions)) goto LA20_;
		safePoint = getTempName__cgen_428((*p).module);
		T22_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T22_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
		res = rawNewString(((NI) 80));
		T23_ = NIM_NIL;
		T23_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_826));
		cgFormatValue__cgen_147((&res), T23_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_13));
		cgFormatValue__cgen_147((&res), safePoint);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_46));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA26_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA26_: ;
		T28_ = NIM_NIL;
		T28_ = rope__ropes_109(res);
		T29_ = NIM_NIL;
		T29_ = indentLine__cgen_286(p, T28_);
		add__ropes_159(T22_, T29_);
		T30_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T30_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_2 = rawNewString(((NI) 80));
		T31_ = NIM_NIL;
		T31_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_827));
		cgFormatValue__cgen_147((&res_2), T31_);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_122));
		cgFormatValue__cgen_147((&res_2), safePoint);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA34_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA34_: ;
		T36_ = NIM_NIL;
		T36_ = rope__ropes_109(res_2);
		T37_ = NIM_NIL;
		T37_ = indentLine__cgen_286(p, T36_);
		add__ropes_159(T30_, T37_);
		{
			NIM_BOOL T40_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T43_;
			NimStringDesc* res_3;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T48_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T49_;
			T40_ = (NIM_BOOL)0;
			T40_ = isDefined__options_2292((*(*(*p).module).g).config, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_828));
			if (!T40_) goto LA41_;
			T43_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T43_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_3 = rawNewString(((NI) 80));
			cgFormatValue__cgen_147((&res_3), safePoint);
			res_3 = resizeString(res_3, 17);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_829));
			cgFormatValue__cgen_147((&res_3), safePoint);
			res_3 = resizeString(res_3, 10);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_830));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA46_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA46_: ;
			T48_ = NIM_NIL;
			T48_ = rope__ropes_109(res_3);
			T49_ = NIM_NIL;
			T49_ = indentLine__cgen_286(p, T48_);
			add__ropes_159(T43_, T49_);
		}
		goto LA38_;
		LA41_: ;
		{
			NIM_BOOL T51_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T54_;
			NimStringDesc* res_4;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T59_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T60_;
			T51_ = (NIM_BOOL)0;
			T51_ = isDefined__options_2292((*(*(*p).module).g).config, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_831));
			if (!T51_) goto LA52_;
			T54_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T54_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_4 = rawNewString(((NI) 80));
			cgFormatValue__cgen_147((&res_4), safePoint);
			res_4 = resizeString(res_4, 20);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_832));
			cgFormatValue__cgen_147((&res_4), safePoint);
			res_4 = resizeString(res_4, 13);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_833));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA57_;
				res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA57_: ;
			T59_ = NIM_NIL;
			T59_ = rope__ropes_109(res_4);
			T60_ = NIM_NIL;
			T60_ = indentLine__cgen_286(p, T59_);
			add__ropes_159(T54_, T60_);
		}
		goto LA38_;
		LA52_: ;
		{
			NIM_BOOL T62_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T65_;
			NimStringDesc* res_5;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T70_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T71_;
			T62_ = (NIM_BOOL)0;
			T62_ = isDefined__options_2292((*(*(*p).module).g).config, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_834));
			if (!T62_) goto LA63_;
			T65_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T65_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_5 = rawNewString(((NI) 80));
			cgFormatValue__cgen_147((&res_5), safePoint);
			res_5 = resizeString(res_5, 27);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_835));
			cgFormatValue__cgen_147((&res_5), safePoint);
			res_5 = resizeString(res_5, 10);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_830));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA68_;
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA68_: ;
			T70_ = NIM_NIL;
			T70_ = rope__ropes_109(res_5);
			T71_ = NIM_NIL;
			T71_ = indentLine__cgen_286(p, T70_);
			add__ropes_159(T65_, T71_);
		}
		goto LA38_;
		LA63_: ;
		{
			NIM_BOOL T73_;
			T73_ = (NIM_BOOL)0;
			T73_ = isDefined__options_2292((*(*(*p).module).g).config, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_836));
			if (!T73_) goto LA74_;
			{
				NIM_BOOL T78_;
				T78_ = (NIM_BOOL)0;
				T78_ = isDefined__options_2292((*(*(*p).module).g).config, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_837));
				if (!T78_) goto LA79_;
				{
					NIM_BOOL T83_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T87_;
					NimStringDesc* res_6;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T92_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T93_;
					T83_ = (NIM_BOOL)0;
					T83_ = isDefined__options_2292((*(*(*p).module).g).config, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_838));
					if (T83_) goto LA84_;
					T83_ = isDefined__options_2292((*(*(*p).module).g).config, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_839));
					LA84_: ;
					if (!T83_) goto LA85_;
					T87_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T87_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					res_6 = rawNewString(((NI) 80));
					cgFormatValue__cgen_147((&res_6), safePoint);
					res_6 = resizeString(res_6, 17);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_829));
					cgFormatValue__cgen_147((&res_6), safePoint);
					res_6 = resizeString(res_6, 10);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_830));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA90_;
						res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
					}
					LA90_: ;
					T92_ = NIM_NIL;
					T92_ = rope__ropes_109(res_6);
					T93_ = NIM_NIL;
					T93_ = indentLine__cgen_286(p, T92_);
					add__ropes_159(T87_, T93_);
				}
				goto LA81_;
				LA85_: ;
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T95_;
					NimStringDesc* res_7;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T100_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T101_;
					T95_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T95_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					res_7 = rawNewString(((NI) 80));
					cgFormatValue__cgen_147((&res_7), safePoint);
					res_7 = resizeString(res_7, 18);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_840));
					cgFormatValue__cgen_147((&res_7), safePoint);
					res_7 = resizeString(res_7, 13);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_833));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA98_;
						res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
					}
					LA98_: ;
					T100_ = NIM_NIL;
					T100_ = rope__ropes_109(res_7);
					T101_ = NIM_NIL;
					T101_ = indentLine__cgen_286(p, T100_);
					add__ropes_159(T95_, T101_);
				}
				LA81_: ;
			}
			goto LA76_;
			LA79_: ;
			{
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T103_;
				NimStringDesc* res_8;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T108_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T109_;
				T103_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T103_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_8 = rawNewString(((NI) 80));
				cgFormatValue__cgen_147((&res_8), safePoint);
				res_8 = resizeString(res_8, 18);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_840));
				cgFormatValue__cgen_147((&res_8), safePoint);
				res_8 = resizeString(res_8, 10);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_830));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA106_;
					res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA106_: ;
				T108_ = NIM_NIL;
				T108_ = rope__ropes_109(res_8);
				T109_ = NIM_NIL;
				T109_ = indentLine__cgen_286(p, T108_);
				add__ropes_159(T103_, T109_);
			}
			LA76_: ;
		}
		goto LA38_;
		LA74_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T111_;
			NimStringDesc* res_9;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T116_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T117_;
			T111_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T111_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_9 = rawNewString(((NI) 80));
			cgFormatValue__cgen_147((&res_9), safePoint);
			res_9 = resizeString(res_9, 17);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_829));
			cgFormatValue__cgen_147((&res_9), safePoint);
			res_9 = resizeString(res_9, 10);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_830));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA114_;
				res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA114_: ;
			T116_ = NIM_NIL;
			T116_ = rope__ropes_109(res_9);
			T117_ = NIM_NIL;
			T117_ = indentLine__cgen_286(p, T116_);
			add__ropes_159(T111_, T117_);
		}
		LA38_: ;
		T118_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T118_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_10 = rawNewString(((NI) 80));
		res_10 = resizeString(res_10, 4);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
		cgFormatValue__cgen_147((&res_10), safePoint);
		res_10 = resizeString(res_10, 15);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_841));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA121_;
			res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA121_: ;
		T123_ = NIM_NIL;
		T123_ = rope__ropes_109(res_10);
		T124_ = NIM_NIL;
		T124_ = indentLine__cgen_286(p, T123_);
		add__ropes_159(T118_, T124_);
	}
	LA20_: ;
	{
		NI T127_;
		NI T130_;
		T127_ = (NI)0;
		T127_ = len__ast_3155(t);
		if (!((*(*t)._kind_6.sons->data[(NI)(T127_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 107))) goto LA128_;
		T130_ = (NI)0;
		T130_ = len__ast_3155(t);
		fin = (*t)._kind_6.sons->data[(NI)(T130_ - ((NI) 1))];
	}
	goto LA125_;
	LA128_: ;
	{
		fin = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
	}
	LA125_: ;
	nimZeroMem((void*)(&T132_), sizeof(tyTuple__T1RBf8m9axj9bvJRlYejkpkQ));
	T132_.Field0 = fin;
	T132_.Field1 = quirkyExceptions;
	T132_.Field2 = ((NI) 0);
	asgnRef((void**) (&(*p).nestedTryStmts), (tySequence__IjAwukZ9aSEsol9c48He4FYQ*) incrSeqV3((TGenericSeq*)((*p).nestedTryStmts), (&NTIseqLtupleLfin58pnode_inexcept58bool_label58naturalTT__IjAwukZ9aSEsol9c48He4FYQ_)));
	T133_ = (*p).nestedTryStmts->Sup.len++;
	asgnRef((void**) (&(*p).nestedTryStmts->data[T133_].Field0), T132_.Field0);
	(*p).nestedTryStmts->data[T133_].Field1 = T132_.Field1;
	(*p).nestedTryStmts->data[T133_].Field2 = T132_.Field2;
	expr__cgen_11525(p, (*t)._kind_6.sons->data[((NI) 0)], d);
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T138_;
		NimStringDesc* res_11;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T139_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T144_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T145_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T146_;
		NimStringDesc* res_12;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T151_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T152_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T153_;
		NimStringDesc* res_13;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T158_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T159_;
		NI T160_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T161_;
		NimStringDesc* res_14;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T162_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T167_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T168_;
		if (!!(quirkyExceptions)) goto LA136_;
		T138_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T138_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_11 = rawNewString(((NI) 80));
		T139_ = NIM_NIL;
		T139_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_776));
		cgFormatValue__cgen_147((&res_11), T139_);
		res_11 = resizeString(res_11, 3);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_312));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA142_;
			res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA142_: ;
		T144_ = NIM_NIL;
		T144_ = rope__ropes_109(res_11);
		T145_ = NIM_NIL;
		T145_ = indentLine__cgen_286(p, T144_);
		add__ropes_159(T138_, T145_);
		T146_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T146_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_12 = rawNewString(((NI) 80));
		res_12 = resizeString(res_12, 1);
appendString(res_12, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_222));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA149_;
			res_12 = resizeString(res_12, 1);
appendString(res_12, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA149_: ;
		T151_ = NIM_NIL;
		T151_ = rope__ropes_109(res_12);
		T152_ = NIM_NIL;
		T152_ = indentLine__cgen_286(p, T151_);
		add__ropes_159(T146_, T152_);
		T153_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T153_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_13 = rawNewString(((NI) 80));
		res_13 = resizeString(res_13, 6);
appendString(res_13, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_842));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA156_;
			res_13 = resizeString(res_13, 1);
appendString(res_13, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA156_: ;
		T158_ = NIM_NIL;
		T158_ = rope__ropes_109(res_13);
		T159_ = NIM_NIL;
		T159_ = indentLine__cgen_286(p, T158_);
		add__ropes_159(T153_, T159_);
		T160_ = (NI)0;
		T160_ = startBlockInternal__cgen_13308(p);
		T161_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T161_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_14 = rawNewString(((NI) 80));
		T162_ = NIM_NIL;
		T162_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_776));
		cgFormatValue__cgen_147((&res_14), T162_);
		res_14 = resizeString(res_14, 3);
appendString(res_14, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_312));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA165_;
			res_14 = resizeString(res_14, 1);
appendString(res_14, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA165_: ;
		T167_ = NIM_NIL;
		T167_ = rope__ropes_109(res_14);
		T168_ = NIM_NIL;
		T168_ = indentLine__cgen_286(p, T167_);
		add__ropes_159(T161_, T168_);
		genRestoreFrameAfterException__cgen_15720(p);
	}
	goto LA134_;
	LA136_: ;
	{
		NIM_BOOL T170_;
		NI T171_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T175_;
		NimStringDesc* res_15;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T176_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T181_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T182_;
		NI T183_;
		T170_ = (NIM_BOOL)0;
		T171_ = (NI)0;
		T171_ = len__ast_3155(t);
		T170_ = (((NI) 1) < T171_);
		if (!(T170_)) goto LA172_;
		T170_ = ((*(*t)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 87));
		LA172_: ;
		if (!T170_) goto LA173_;
		T175_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T175_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_15 = rawNewString(((NI) 80));
		res_15 = resizeString(res_15, 4);
appendString(res_15, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
		T176_ = NIM_NIL;
		T176_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_795));
		cgFormatValue__cgen_147((&res_15), T176_);
		res_15 = resizeString(res_15, 5);
appendString(res_15, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_843));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA179_;
			res_15 = resizeString(res_15, 1);
appendString(res_15, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA179_: ;
		T181_ = NIM_NIL;
		T181_ = rope__ropes_109(res_15);
		T182_ = NIM_NIL;
		T182_ = indentLine__cgen_286(p, T181_);
		add__ropes_159(T175_, T182_);
		T183_ = (NI)0;
		T183_ = startBlockInternal__cgen_13308(p);
	}
	goto LA134_;
	LA173_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T185_;
		NimStringDesc* res_16;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T190_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T191_;
		NI T192_;
		T185_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T185_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_16 = rawNewString(((NI) 80));
		res_16 = resizeString(res_16, 1);
appendString(res_16, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA188_;
			res_16 = resizeString(res_16, 1);
appendString(res_16, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA188_: ;
		T190_ = NIM_NIL;
		T190_ = rope__ropes_109(res_16);
		T191_ = NIM_NIL;
		T191_ = indentLine__cgen_286(p, T190_);
		add__ropes_159(T185_, T191_);
		T192_ = (NI)0;
		T192_ = startBlockInternal__cgen_13308(p);
	}
	LA134_: ;
	T193_ = (tyTuple__T1RBf8m9axj9bvJRlYejkpkQ*)0;
	T193_ = X5BX5D___cgen_14870(((*p).nestedTryStmts) ? ((*p).nestedTryStmts->data) : NIM_NIL, ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0), ((NI) 1));
	(*T193_).Field1 = NIM_TRUE;
	i = ((NI) 1);
	{
		while (1) {
			NIM_BOOL T196_;
			NI T197_;
			T196_ = (NIM_BOOL)0;
			T197_ = (NI)0;
			T197_ = len__ast_3155(t);
			T196_ = (i < T197_);
			if (!(T196_)) goto LA198_;
			T196_ = ((*(*t)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 87));
			LA198_: ;
			if (!T196_) goto LA195;
			{
				NIM_BOOL T201_;
				T201_ = (NIM_BOOL)0;
				T201_ = ((*d).k == ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 1));
				if (!(T201_)) goto LA202_;
				T201_ = isEmptyType__ast_4780((*t).typ);
				LA202_: ;
				if (!T201_) goto LA203_;
				(*d).k = ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 0);
			}
			LA203_: ;
			{
				NI T207_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T218_;
				NimStringDesc* res_17;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T223_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T224_;
				NI T225_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T237_;
				NimStringDesc* res_19;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T238_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T243_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T244_;
				T207_ = (NI)0;
				T207_ = len__ast_3155((*t)._kind_6.sons->data[i]);
				if (!(T207_ == ((NI) 1))) goto LA208_;
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T214_;
					tyArray__dAmhZbEWrTM5xES2bTVweg T215_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T216_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T217_;
					if (!(((NI) 1) < i)) goto LA212_;
					T214_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T214_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					nimZeroMem((void*)T215_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
					T216_ = NIM_NIL;
					T216_ = percent___cgen_16614(T215_, 0);
					T217_ = NIM_NIL;
					T217_ = indentLine__cgen_286(p, T216_);
					add__ropes_159(T214_, T217_);
				}
				LA212_: ;
				T218_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T218_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_17 = rawNewString(((NI) 80));
				res_17 = resizeString(res_17, 1);
appendString(res_17, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA221_;
					res_17 = resizeString(res_17, 1);
appendString(res_17, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA221_: ;
				T223_ = NIM_NIL;
				T223_ = rope__ropes_109(res_17);
				T224_ = NIM_NIL;
				T224_ = indentLine__cgen_286(p, T223_);
				add__ropes_159(T218_, T224_);
				T225_ = (NI)0;
				T225_ = startBlockInternal__cgen_13308(p);
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T230_;
					NimStringDesc* res_18;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T235_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T236_;
					if (!!(quirkyExceptions)) goto LA228_;
					T230_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T230_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					res_18 = rawNewString(((NI) 80));
					cgFormatValue__cgen_147((&res_18), safePoint);
					res_18 = resizeString(res_18, 12);
appendString(res_18, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_844));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA233_;
						res_18 = resizeString(res_18, 1);
appendString(res_18, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
					}
					LA233_: ;
					T235_ = NIM_NIL;
					T235_ = rope__ropes_109(res_18);
					T236_ = NIM_NIL;
					T236_ = indentLine__cgen_286(p, T235_);
					add__ropes_159(T230_, T236_);
				}
				LA228_: ;
				expr__cgen_11525(p, (*(*t)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)], d);
				T237_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T237_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_19 = rawNewString(((NI) 80));
				T238_ = NIM_NIL;
				T238_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_777));
				cgFormatValue__cgen_147((&res_19), T238_);
				res_19 = resizeString(res_19, 3);
appendString(res_19, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_312));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA241_;
					res_19 = resizeString(res_19, 1);
appendString(res_19, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA241_: ;
				T243_ = NIM_NIL;
				T243_ = rope__ropes_109(res_19);
				T244_ = NIM_NIL;
				T244_ = indentLine__cgen_286(p, T243_);
				add__ropes_159(T237_, T244_);
				endBlock__cgen_13329(p);
			}
			goto LA205_;
			LA208_: ;
			{
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* orExpr;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T276_;
				NimStringDesc* res_21;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T281_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T282_;
				NI T283_;
				NI T295_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T296_;
				NimStringDesc* res_23;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T297_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T302_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T303_;
				orExpr = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
				{
					NI j;
					NI colontmp_;
					NI T247_;
					NI i_2;
					j = (NI)0;
					colontmp_ = (NI)0;
					T247_ = (NI)0;
					T247_ = len__ast_3155((*t)._kind_6.sons->data[i]);
					colontmp_ = (NI)(T247_ - ((NI) 1));
					i_2 = ((NI) 0);
					{
						while (1) {
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* checkFor;
							NimStringDesc* memberName;
							NimStringDesc* res_20;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T266_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T267_;
							tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T268_;
							if (!(i_2 < colontmp_)) goto LA249;
							j = i_2;
							{
								if (!!((orExpr == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA252_;
								add__ropes_162(&orExpr, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_25));
							}
							LA252_: ;
							{
								if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 41))&63U)))!=0)) goto LA256_;
								checkFor = genTypeInfo2Name__cgen_7835((*p).module, (*(*(*t)._kind_6.sons->data[i])._kind_6.sons->data[j]).typ);
							}
							goto LA254_;
							LA256_: ;
							{
								checkFor = genTypeInfoV1__cgen_6798((*p).module, (*(*(*t)._kind_6.sons->data[i])._kind_6.sons->data[j]).typ, (*(*(*t)._kind_6.sons->data[i])._kind_6.sons->data[j]).info);
							}
							LA254_: ;
							{
								NIM_BOOL T261_;
								T261_ = (NIM_BOOL)0;
								T261_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
								if (T261_) goto LA262_;
								T261_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
								LA262_: ;
								if (!T261_) goto LA263_;
								memberName = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_793));
							}
							goto LA259_;
							LA263_: ;
							{
								memberName = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_794));
							}
							LA259_: ;
							res_20 = rawNewString(((NI) 80));
							T266_ = NIM_NIL;
							T266_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_731));
							cgFormatValue__cgen_147((&res_20), T266_);
							res_20 = resizeString(res_20, 1);
appendString(res_20, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
							T267_ = NIM_NIL;
							T267_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_795));
							cgFormatValue__cgen_147((&res_20), T267_);
							res_20 = resizeString(res_20, 4);
appendString(res_20, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_796));
							cgFormatValue__cgen_151((&res_20), memberName);
							res_20 = resizeString(res_20, 2);
appendString(res_20, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
							cgFormatValue__cgen_147((&res_20), checkFor);
							res_20 = resizeString(res_20, 1);
appendString(res_20, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_34));
							T268_ = NIM_NIL;
							T268_ = rope__ropes_109(res_20);
							add__ropes_159(&orExpr, T268_);
							i_2 += ((NI) 1);
						} LA249: ;
					}
				}
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T273_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T274_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T275_;
					if (!(((NI) 1) < i)) goto LA271_;
					T273_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T273_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					T274_ = NIM_NIL;
					T274_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_797));
					T275_ = NIM_NIL;
					T275_ = indentLine__cgen_286(p, T274_);
					add__ropes_159(T273_, T275_);
				}
				LA271_: ;
				T276_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T276_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_21 = rawNewString(((NI) 80));
				res_21 = resizeString(res_21, 4);
appendString(res_21, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
				cgFormatValue__cgen_147((&res_21), orExpr);
				res_21 = resizeString(res_21, 3);
appendString(res_21, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_771));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA279_;
					res_21 = resizeString(res_21, 1);
appendString(res_21, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA279_: ;
				T281_ = NIM_NIL;
				T281_ = rope__ropes_109(res_21);
				T282_ = NIM_NIL;
				T282_ = indentLine__cgen_286(p, T281_);
				add__ropes_159(T276_, T282_);
				T283_ = (NI)0;
				T283_ = startBlockInternal__cgen_13308(p);
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T288_;
					NimStringDesc* res_22;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T293_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T294_;
					if (!!(quirkyExceptions)) goto LA286_;
					T288_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
					T288_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
					res_22 = rawNewString(((NI) 80));
					cgFormatValue__cgen_147((&res_22), safePoint);
					res_22 = resizeString(res_22, 12);
appendString(res_22, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_844));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA291_;
						res_22 = resizeString(res_22, 1);
appendString(res_22, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
					}
					LA291_: ;
					T293_ = NIM_NIL;
					T293_ = rope__ropes_109(res_22);
					T294_ = NIM_NIL;
					T294_ = indentLine__cgen_286(p, T293_);
					add__ropes_159(T288_, T294_);
				}
				LA286_: ;
				T295_ = (NI)0;
				T295_ = len__ast_3155((*t)._kind_6.sons->data[i]);
				expr__cgen_11525(p, (*(*t)._kind_6.sons->data[i])._kind_6.sons->data[(NI)(T295_ - ((NI) 1))], d);
				T296_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T296_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_23 = rawNewString(((NI) 80));
				T297_ = NIM_NIL;
				T297_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_777));
				cgFormatValue__cgen_147((&res_23), T297_);
				res_23 = resizeString(res_23, 3);
appendString(res_23, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_312));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA300_;
					res_23 = resizeString(res_23, 1);
appendString(res_23, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA300_: ;
				T302_ = NIM_NIL;
				T302_ = rope__ropes_109(res_23);
				T303_ = NIM_NIL;
				T303_ = indentLine__cgen_286(p, T302_);
				add__ropes_159(T296_, T303_);
				endBlock__cgen_13329(p);
			}
			LA205_: ;
			i += ((NI) 1);
		} LA195: ;
	}
	nimZeroMem((void*)(&T304_), sizeof(tyTuple__T1RBf8m9axj9bvJRlYejkpkQ));
	pop__cgen_13721((&(*p).nestedTryStmts), (&T304_));
	(void)(T304_);
	endBlock__cgen_13329(p);
	{
		NIM_BOOL T307_;
		NI T308_;
		NI T312_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T313_;
		NimStringDesc* res_24;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T318_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T319_;
		NI T320_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T336_;
		T307_ = (NIM_BOOL)0;
		T308_ = (NI)0;
		T308_ = len__ast_3155(t);
		T307_ = (i < T308_);
		if (!(T307_)) goto LA309_;
		T307_ = ((*(*t)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 107));
		LA309_: ;
		if (!T307_) goto LA310_;
		asgnRef((void**) (&(*p).finallySafePoints), (tySequence__UQWyowqEA29c6NZ9csQYyjXQ*) incrSeqV3((TGenericSeq*)((*p).finallySafePoints), (&NTIseqLropeT__UQWyowqEA29c6NZ9csQYyjXQ_)));
		T312_ = (*p).finallySafePoints->Sup.len++;
		asgnRef((void**) (&(*p).finallySafePoints->data[T312_]), safePoint);
		T313_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T313_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_24 = rawNewString(((NI) 80));
		res_24 = resizeString(res_24, 1);
appendString(res_24, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA316_;
			res_24 = resizeString(res_24, 1);
appendString(res_24, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA316_: ;
		T318_ = NIM_NIL;
		T318_ = rope__ropes_109(res_24);
		T319_ = NIM_NIL;
		T319_ = indentLine__cgen_286(p, T318_);
		add__ropes_159(T313_, T319_);
		T320_ = (NI)0;
		T320_ = startBlockInternal__cgen_13308(p);
		genStmts__cgen_11522(p, (*(*t)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)]);
		{
			NIM_BOOL T323_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T325_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T328_;
			NimStringDesc* res_25;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T329_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T334_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T335_;
			T323_ = (NIM_BOOL)0;
			T323_ = !(quirkyExceptions);
			if (!(T323_)) goto LA324_;
			T325_ = NIM_NIL;
			T325_ = getCompilerProc__magicsys_145((*(*(*p).module).g).graph, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_845));
			T323_ = !((T325_ == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
			LA324_: ;
			if (!T323_) goto LA326_;
			T328_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T328_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_25 = rawNewString(((NI) 80));
			res_25 = resizeString(res_25, 4);
appendString(res_25, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
			cgFormatValue__cgen_147((&res_25), safePoint);
			res_25 = resizeString(res_25, 14);
appendString(res_25, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_778));
			T329_ = NIM_NIL;
			T329_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_845));
			cgFormatValue__cgen_147((&res_25), T329_);
			res_25 = resizeString(res_25, 3);
appendString(res_25, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_312));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA332_;
				res_25 = resizeString(res_25, 1);
appendString(res_25, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA332_: ;
			T334_ = NIM_NIL;
			T334_ = rope__ropes_109(res_25);
			T335_ = NIM_NIL;
			T335_ = indentLine__cgen_286(p, T334_);
			add__ropes_159(T328_, T335_);
		}
		LA326_: ;
		endBlock__cgen_13329(p);
		T336_ = NIM_NIL;
		T336_ = pop__ropes_180((&(*p).finallySafePoints));
		(void)(T336_);
	}
	LA310_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T341_;
		NimStringDesc* res_26;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T342_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T347_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T348_;
		if (!!(quirkyExceptions)) goto LA339_;
		T341_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T341_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_26 = rawNewString(((NI) 80));
		res_26 = resizeString(res_26, 4);
appendString(res_26, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_260));
		cgFormatValue__cgen_147((&res_26), safePoint);
		res_26 = resizeString(res_26, 14);
appendString(res_26, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_778));
		T342_ = NIM_NIL;
		T342_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_846));
		cgFormatValue__cgen_147((&res_26), T342_);
		res_26 = resizeString(res_26, 3);
appendString(res_26, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_312));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA345_;
			res_26 = resizeString(res_26, 1);
appendString(res_26, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA345_: ;
		T347_ = NIM_NIL;
		T347_ = rope__ropes_109(res_26);
		T348_ = NIM_NIL;
		T348_ = indentLine__cgen_286(p, T347_);
		add__ropes_159(T341_, T348_);
	}
	LA339_: ;
}
static N_INLINE(void, genSimpleBlock__cgen_13599)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* stmts) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T1_;
	NimStringDesc* res;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
	NI T8_;
	T1_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T1_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	res = rawNewString(((NI) 80));
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA4_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA4_: ;
	T6_ = NIM_NIL;
	T6_ = rope__ropes_109(res);
	T7_ = NIM_NIL;
	T7_ = indentLine__cgen_286(p, T6_);
	add__ropes_159(T1_, T7_);
	T8_ = (NI)0;
	T8_ = startBlockInternal__cgen_13308(p);
	genStmts__cgen_11522(p, stmts);
	endBlock__cgen_13329(p);
}
N_LIB_PRIVATE N_NIMCALL(void, finallyActions__cgen_14901)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T6_;
		tyTuple__T1RBf8m9axj9bvJRlYejkpkQ* T8_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* finallyBlock;
		tyTuple__T1RBf8m9axj9bvJRlYejkpkQ* T11_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = !(((*(*(*(*p).module).g).config).exc == ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 3)));
		if (!(T4_)) goto LA5_;
		T6_ = ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0);
		T4_ = (((NI) 0) < T6_);
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA7_;
		T8_ = (tyTuple__T1RBf8m9axj9bvJRlYejkpkQ*)0;
		T8_ = X5BX5D___cgen_14870(((*p).nestedTryStmts) ? ((*p).nestedTryStmts->data) : NIM_NIL, ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0), ((NI) 1));
		T3_ = (*T8_).Field1;
		LA7_: ;
		if (!T3_) goto LA9_;
		T11_ = (tyTuple__T1RBf8m9axj9bvJRlYejkpkQ*)0;
		T11_ = X5BX5D___cgen_14870(((*p).nestedTryStmts) ? ((*p).nestedTryStmts->data) : NIM_NIL, ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0), ((NI) 1));
		finallyBlock = (*T11_).Field0;
		{
			if (!!((finallyBlock == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA14_;
			genSimpleBlock__cgen_13599(p, (*finallyBlock)._kind_6.sons->data[((NI) 0)]);
		}
		LA14_: ;
	}
	LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genRaiseStmt__cgen_14965)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* gotoInstr;
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* e;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
		if (!!(((*(*t)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)))) goto LA3_;
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExprSingleUse__cgen_11552(p, (*t)._kind_6.sons->data[((NI) 0)], (&a));
		finallyActions__cgen_14901(p);
		e = rdLoc__cgen_435(a);
		T5_ = NIM_NIL;
		T5_ = getTypeDesc__cgen_6662((*p).module, (*(*t)._kind_6.sons->data[((NI) 0)]).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		(void)(T5_);
		typ = skipTypes__ast_3723((*(*t)._kind_6.sons->data[((NI) 0)]).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_201);
		{
			NI T10_;
			if (!((*(*(*(*p).module).g).config).exc == ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 2))) goto LA8_;
			T10_ = (NI)0;
			T10_ = inExceptBlockLen__cgen_13273(p);
			blockLeaveActions__cgen_13683(p, ((NI) 0), T10_);
		}
		LA8_: ;
		genLineDir__cgen_369(p, t);
		{
			NIM_BOOL T13_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T16_;
			tyArray__ts9cf9blICas1QWmw89bglZ7w T17_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
			T13_ = (NIM_BOOL)0;
			T13_ = isImportedException__ast_4905(typ, (*(*(*p).module).g).config);
			if (!T13_) goto LA14_;
			T16_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T16_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			nimZeroMem((void*)T17_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T17_[0] = e;
			T18_ = NIM_NIL;
			T18_ = percent___cgen_14983(T17_, 1);
			T19_ = NIM_NIL;
			T19_ = indentLine__cgen_286(p, T18_);
			add__ropes_159(T16_, T19_);
		}
		goto LA11_;
		LA14_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T21_;
			NimStringDesc* res;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
			NimStringDesc* T25_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T31_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T32_;
			NI T33_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T39_;
			T21_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T21_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res = rawNewString(((NI) 80));
			T22_ = NIM_NIL;
			T22_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_847));
			cgFormatValue__cgen_147((&res), T22_);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_29));
			T23_ = NIM_NIL;
			T23_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_807));
			cgFormatValue__cgen_147((&res), T23_);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_848));
			cgFormatValue__cgen_147((&res), e);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			T24_ = NIM_NIL;
			T24_ = makeCString__msgs_50((*(*(*typ).sym).name).s);
			cgFormatValue__cgen_147((&res), T24_);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			T25_ = NIM_NIL;
			{
				if (!!(((*p).prc == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA28_;
				T25_ = copyString((*(*(*p).prc).name).s);
			}
			goto LA26_;
			LA28_: ;
			{
				T25_ = copyString((*(*(*(*p).module).module).name).s);
			}
			LA26_: ;
			T31_ = NIM_NIL;
			T31_ = makeCString__msgs_50(T25_);
			cgFormatValue__cgen_147((&res), T31_);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			T32_ = NIM_NIL;
			T32_ = quotedFilename__msgs_1473((*(*(*p).module).g).config, (*t).info);
			cgFormatValue__cgen_147((&res), T32_);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_51));
			T33_ = (NI)0;
			T33_ = toLinenumber__msgs_619((*t).info);
			cgFormatValue__cgen_154((&res), ((NI64) (T33_)));
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_45));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA36_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA36_: ;
			T38_ = NIM_NIL;
			T38_ = rope__ropes_109(res);
			T39_ = NIM_NIL;
			T39_ = indentLine__cgen_286(p, T38_);
			add__ropes_159(T21_, T39_);
			{
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T44_;
				NimStringDesc* res_2;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T49_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T50_;
				if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 42))&63U)))!=0)) goto LA42_;
				T44_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T44_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res_2 = rawNewString(((NI) 80));
				cgFormatValue__cgen_147((&res_2), e);
				res_2 = resizeString(res_2, 11);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_302));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA47_;
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA47_: ;
				T49_ = NIM_NIL;
				T49_ = rope__ropes_109(res_2);
				T50_ = NIM_NIL;
				T50_ = indentLine__cgen_286(p, T49_);
				add__ropes_159(T44_, T50_);
			}
			LA42_: ;
		}
		LA11_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		finallyActions__cgen_14901(p);
		genLineDir__cgen_369(p, t);
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T56_;
			tyArray__dAmhZbEWrTM5xES2bTVweg T57_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T58_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T59_;
			if (!((*(*(*(*p).module).g).config).exc == ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 2))) goto LA54_;
			T56_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T56_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			nimZeroMem((void*)T57_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
			T58_ = NIM_NIL;
			T58_ = percent___cgen_15026(T57_, 0);
			T59_ = NIM_NIL;
			T59_ = indentLine__cgen_286(p, T58_);
			add__ropes_159(T56_, T59_);
		}
		goto LA52_;
		LA54_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T61_;
			NimStringDesc* res_3;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T62_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T67_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T68_;
			T61_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T61_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			res_3 = rawNewString(((NI) 80));
			T62_ = NIM_NIL;
			T62_ = cgsym__cgen_126((*p).module, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_846));
			cgFormatValue__cgen_147((&res_3), T62_);
			res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_312));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA65_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA65_: ;
			T67_ = NIM_NIL;
			T67_ = rope__ropes_109(res_3);
			T68_ = NIM_NIL;
			T68_ = indentLine__cgen_286(p, T67_);
			add__ropes_159(T61_, T68_);
		}
		LA52_: ;
	}
	LA1_: ;
	gotoInstr = raiseInstr__cgen_424(p);
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T73_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T74_;
		if (!!((gotoInstr == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA71_;
		T73_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T73_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		T74_ = NIM_NIL;
		T74_ = indentLine__cgen_286(p, gotoInstr);
		add__ropes_159(T73_, T74_);
	}
	LA71_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genTypeSection__cgen_10311)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw, determineSection__cgen_17385)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw result;
	result = (tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw)0;
	result = ((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 8);
	{
		NIM_BOOL T3_;
		NI T4_;
		NimStringDesc* sec;
		T3_ = (NIM_BOOL)0;
		T4_ = (NI)0;
		T4_ = len__ast_3155(n);
		T3_ = (((NI) 1) <= T4_);
		if (!(T3_)) goto LA5_;
		T3_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) && (*(*n)._kind_6.sons->data[((NI) 0)]).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22));
		LA5_: ;
		if (!T3_) goto LA6_;
		sec = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_3.strVal;
		{
			NIM_BOOL T10_;
			T10_ = (NIM_BOOL)0;
			T10_ = nsuStartsWith(sec, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_849));
			if (!T10_) goto LA11_;
			result = ((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 4);
		}
		goto LA8_;
		LA11_: ;
		{
			NIM_BOOL T14_;
			T14_ = (NIM_BOOL)0;
			T14_ = nsuStartsWith(sec, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_850));
			if (!T14_) goto LA15_;
			result = ((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10);
		}
		goto LA8_;
		LA15_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = nsuStartsWith(sec, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_851));
			if (!T18_) goto LA19_;
			result = ((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 1);
		}
		goto LA8_;
		LA19_: ;
		LA8_: ;
	}
	LA6_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genEmit__cgen_17407)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* s;
	s = genAsmOrEmitStmt__cgen_17326(p, (*t)._kind_6.sons->data[((NI) 1)], NIM_FALSE);
	{
		tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw section;
		if (!((*p).prc == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA3_;
		section = determineSection__cgen_17385((*t)._kind_6.sons->data[((NI) 1)]);
		genCLineDir__cgen_357(&(*(*p).module).s[(section)- 0], (*t).info, (*(*(*p).module).g).config);
		add__ropes_159(&(*(*p).module).s[(section)- 0], s);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T6_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
		genLineDir__cgen_369(p, t);
		T6_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T6_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		T7_ = NIM_NIL;
		T7_ = indentLine__cgen_286(p, s);
		add__ropes_159(T6_, T7_);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genPragma__cgen_17418)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** it;
		tySequence__IeU9azYSNIK3V9b36Ir6NZcw* colontmp_;
		NI i;
		NI L;
		NI T2_;
		it = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
		colontmp_ = NIM_NIL;
		colontmp_ = (*n)._kind_6.sons;
		i = ((NI) 0);
		T2_ = (colontmp_ ? colontmp_->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw T5_;
				if (!(i < L)) goto LA4;
				it = &colontmp_->data[i];
				T5_ = (tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw)0;
				T5_ = whichPragma__trees_244((*it));
				switch (T5_) {
				case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 215):
				{
					genEmit__cgen_17407(p, (*it));
				}
				break;
				default:
				{
				}
				break;
				}
				i += ((NI) 1);
			} LA4: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genParForStmt__cgen_14708)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t) {
	NI oldBreakIdxX60gensym2038_;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* forLoopVar;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw rangeA;
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw rangeB;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* call;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T27_;
	NimStringDesc* res;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T32_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T33_;
	(*p).withinLoop += ((NI) 1);
	genLineDir__cgen_369(p, t);
	oldBreakIdxX60gensym2038_ = (*p).breakIdx;
	forLoopVar = (*(*t)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
	nimZeroMem((void*)(&rangeA), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	nimZeroMem((void*)(&rangeB), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	assignLocalVar__cgen_11164(p, (*t)._kind_6.sons->data[((NI) 0)]);
	call = (*t)._kind_6.sons->data[((NI) 1)];
	initLocExpr__cgen_11548(p, (*call)._kind_6.sons->data[((NI) 1)], (&rangeA));
	initLocExpr__cgen_11548(p, (*call)._kind_6.sons->data[((NI) 2)], (&rangeB));
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__ast_3155(call);
		if (!(T3_ == ((NI) 4))) goto LA4_;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T10_;
			tyArray__InO6xIOhXMnkCXPnEYWwWg T11_;
			NimStringDesc* T12_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
			if (!eqStrings((*(*(*(*call)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).s, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_25))) goto LA8_;
			T10_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T10_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			nimZeroMem((void*)T11_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
			T11_[0] = rdLoc__cgen_435((*forLoopVar).loc);
			T11_[1] = rdLoc__cgen_435(rangeA);
			T11_[2] = rdLoc__cgen_435(rangeB);
			T12_ = NIM_NIL;
			T12_ = getStr__ast_4611((*call)._kind_6.sons->data[((NI) 3)]);
			T11_[3] = rope__ropes_109(T12_);
			T13_ = NIM_NIL;
			T13_ = percent___cgen_14747(T11_, 4);
			T14_ = NIM_NIL;
			T14_ = indentLine__cgen_286(p, T13_);
			add__ropes_159(T10_, T14_);
		}
		goto LA6_;
		LA8_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T16_;
			tyArray__InO6xIOhXMnkCXPnEYWwWg T17_;
			NimStringDesc* T18_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
			T16_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T16_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			nimZeroMem((void*)T17_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
			T17_[0] = rdLoc__cgen_435((*forLoopVar).loc);
			T17_[1] = rdLoc__cgen_435(rangeA);
			T17_[2] = rdLoc__cgen_435(rangeB);
			T18_ = NIM_NIL;
			T18_ = getStr__ast_4611((*call)._kind_6.sons->data[((NI) 3)]);
			T17_[3] = rope__ropes_109(T18_);
			T19_ = NIM_NIL;
			T19_ = percent___cgen_14753(T17_, 4);
			T20_ = NIM_NIL;
			T20_ = indentLine__cgen_286(p, T19_);
			add__ropes_159(T16_, T20_);
		}
		LA6_: ;
	}
	goto LA1_;
	LA4_: ;
	{
		tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw step;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T22_;
		tyArray__XSZGJHCjWme3CUmFzckT3g T23_;
		NimStringDesc* T24_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
		nimZeroMem((void*)(&step), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
		initLocExpr__cgen_11548(p, (*call)._kind_6.sons->data[((NI) 3)], (&step));
		T22_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T22_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		nimZeroMem((void*)T23_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
		T23_[0] = rdLoc__cgen_435((*forLoopVar).loc);
		T23_[1] = rdLoc__cgen_435(rangeA);
		T23_[2] = rdLoc__cgen_435(rangeB);
		T23_[3] = rdLoc__cgen_435(step);
		T24_ = NIM_NIL;
		T24_ = getStr__ast_4611((*call)._kind_6.sons->data[((NI) 4)]);
		T23_[4] = rope__ropes_109(T24_);
		T25_ = NIM_NIL;
		T25_ = percent___cgen_14761(T23_, 5);
		T26_ = NIM_NIL;
		T26_ = indentLine__cgen_286(p, T25_);
		add__ropes_159(T22_, T26_);
	}
	LA1_: ;
	T27_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T27_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	res = rawNewString(((NI) 80));
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA30_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA30_: ;
	T32_ = NIM_NIL;
	T32_ = rope__ropes_109(res);
	T33_ = NIM_NIL;
	T33_ = indentLine__cgen_286(p, T32_);
	add__ropes_159(T27_, T33_);
	(*p).breakIdx = startBlockInternal__cgen_13308(p);
	(*p).blocks->data[(*p).breakIdx].isLoop = NIM_TRUE;
	genStmts__cgen_11522(p, (*t)._kind_6.sons->data[((NI) 2)]);
	endBlock__cgen_13329(p);
	(*p).breakIdx = oldBreakIdxX60gensym2038_;
	(*p).withinLoop -= ((NI) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, genState__cgen_13635)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n0;
	{
		NI T3_;
		NimStringDesc* argX60gensym1725_;
		T3_ = (NI)0;
		T3_ = len__ast_3155(n);
		if (!!((T3_ == ((NI) 1)))) goto LA4_;
		argX60gensym1725_ = toFileLineCol__msgs_625(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_852);
		internalErrorImpl__msgs_1441((*(*(*p).module).g).config, unknownLineInfo__lineinfos_284, argX60gensym1725_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_852);
	}
	LA4_: ;
	n0 = (*n)._kind_6.sons->data[((NI) 0)];
	{
		NI64 idx;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T10_;
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
		if (!((*n0).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6))) goto LA8_;
		idx = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_1.intVal;
		T10_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T10_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 5);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_853));
		cgFormatValue__cgen_154((&res), idx);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_854));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA13_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA13_: ;
		T15_ = NIM_NIL;
		T15_ = rope__ropes_109(res);
		T16_ = NIM_NIL;
		T16_ = indentLine__cgen_286(p, T15_);
		add__ropes_159(T10_, T16_);
	}
	goto LA6_;
	LA8_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T20_;
		NimStringDesc* res_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
		if (!((*n0).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20))) goto LA18_;
		T20_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T20_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		res_2 = rawNewString(((NI) 80));
		cgFormatValue__cgen_151((&res_2), (*n0)._kind_3.strVal);
		res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_854));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA23_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA23_: ;
		T25_ = NIM_NIL;
		T25_ = rope__ropes_109(res_2);
		T26_ = NIM_NIL;
		T26_ = indentLine__cgen_286(p, T25_);
		add__ropes_159(T20_, T26_);
	}
	goto LA6_;
	LA18_: ;
	LA6_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genGotoState__cgen_13798)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T1_;
	tyArray__ts9cf9blICas1QWmw89bglZ7w T2_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T3_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T4_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T5_;
	tyArray__dAmhZbEWrTM5xES2bTVweg T6_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
	NI T9_;
	NI T10_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T11_;
	tyArray__dAmhZbEWrTM5xES2bTVweg T12_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
	tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ statesCounter;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* prefix;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T37_;
	tyArray__dAmhZbEWrTM5xES2bTVweg T38_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T39_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T40_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLocExpr__cgen_11548(p, (*n)._kind_6.sons->data[((NI) 0)], (&a));
	T1_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T1_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	nimZeroMem((void*)T2_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
	T2_[0] = rdLoc__cgen_435(a);
	T3_ = NIM_NIL;
	T3_ = percent___cgen_13803(T2_, 1);
	T4_ = NIM_NIL;
	T4_ = indentLine__cgen_286(p, T3_);
	add__ropes_159(T1_, T4_);
	(*p).flags |= ((NU8)1)<<((((tyEnum_TCProcFlag__Iv1wQAvkoMCW3v9cTnZWvJw) 0)) & 7);
	T5_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T5_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	nimZeroMem((void*)T6_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
	T7_ = NIM_NIL;
	T7_ = percent___cgen_13812(T6_, 0);
	T8_ = NIM_NIL;
	T8_ = indentLine__cgen_286(p, T7_);
	add__ropes_159(T5_, T8_);
	T9_ = ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0);
	T10_ = (NI)0;
	T10_ = inExceptBlockLen__cgen_13273(p);
	blockLeaveActions__cgen_13683(p, T9_, T10_);
	T11_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T11_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	nimZeroMem((void*)T12_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
	T13_ = NIM_NIL;
	T13_ = percent___cgen_13820(T12_, 0);
	T14_ = NIM_NIL;
	T14_ = indentLine__cgen_286(p, T13_);
	add__ropes_159(T11_, T14_);
	statesCounter = lastOrd__types_1532((*(*(*p).module).g).config, (*(*n)._kind_6.sons->data[((NI) 0)]).typ);
	{
		NIM_BOOL T17_;
		NI T18_;
		T17_ = (NIM_BOOL)0;
		T18_ = (NI)0;
		T18_ = len__ast_3155(n);
		T17_ = (((NI) 2) <= T18_);
		if (!(T17_)) goto LA19_;
		T17_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6));
		LA19_: ;
		if (!T17_) goto LA20_;
		statesCounter = getInt__ast_4593((*n)._kind_6.sons->data[((NI) 1)]);
	}
	LA20_: ;
	{
		NIM_BOOL T24_;
		NI T25_;
		T24_ = (NIM_BOOL)0;
		T25_ = (NI)0;
		T25_ = len__ast_3155(n);
		T24_ = (T25_ == ((NI) 3));
		if (!(T24_)) goto LA26_;
		T24_ = ((*(*n)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20));
		LA26_: ;
		if (!T24_) goto LA27_;
		prefix = rope__ropes_109((*(*n)._kind_6.sons->data[((NI) 2)])._kind_3.strVal);
	}
	goto LA22_;
	LA27_: ;
	{
		prefix = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_855));
	}
	LA22_: ;
	{
		NI64 i;
		NI64 colontmp_;
		NI64 res;
		i = (NI64)0;
		colontmp_ = (NI64)0;
		colontmp_ = toInt64__int495056_88(statesCounter);
		res = IL64(0);
		{
			while (1) {
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T33_;
				tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T34_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T35_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T36_;
				if (!(res <= colontmp_)) goto LA32;
				i = res;
				T33_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T33_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				nimZeroMem((void*)T34_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
				T34_[0] = prefix;
				T34_[1] = rope__ropes_115(i);
				T35_ = NIM_NIL;
				T35_ = percent___cgen_13847(T34_, 2);
				T36_ = NIM_NIL;
				T36_ = indentLine__cgen_286(p, T35_);
				add__ropes_159(T33_, T36_);
				res += ((NI) 1);
			} LA32: ;
		}
	}
	T37_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
	T37_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
	nimZeroMem((void*)T38_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
	T39_ = NIM_NIL;
	T39_ = percent___cgen_7535(T38_, 0);
	T40_ = NIM_NIL;
	T40_ = indentLine__cgen_286(p, T39_);
	add__ropes_159(T37_, T40_);
}
N_LIB_PRIVATE N_NIMCALL(void, genBreakState__cgen_13856)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	initLoc__cgen_66(d, ((tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw) 6), n, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	{
		tyArray__ts9cf9blICas1QWmw89bglZ7w T5_;
		if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 155))) goto LA3_;
		initLocExpr__cgen_11548(p, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)], (&a));
		nimZeroMem((void*)T5_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T5_[0] = rdLoc__cgen_435(a);
		unsureAsgnRef((void**) (&(*d).r), percent___cgen_13868(T5_, 1));
	}
	goto LA1_;
	LA3_: ;
	{
		tyArray__ts9cf9blICas1QWmw89bglZ7w T7_;
		initLocExpr__cgen_11548(p, (*n)._kind_6.sons->data[((NI) 0)], (&a));
		nimZeroMem((void*)T7_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T7_[0] = rdLoc__cgen_435(a);
		unsureAsgnRef((void**) (&(*d).r), percent___cgen_13874(T7_, 1));
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, expr__cgen_11525)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw* d) {
	(*p).currLineInfo = (*n).info;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
		sym = (*n)._kind_4.sym;
		switch ((*sym).kind) {
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 14):
		{
			{
				NIM_BOOL T5_;
				T5_ = (NIM_BOOL)0;
				T5_ = (((*(*p).module).flags &((NU8)1<<((NU)(((tyEnum_CodegenFlag__vPx29bHhk9a7V50u1UO0rM4w) 6))&7U)))!=0);
				if (T5_) goto LA6_;
				T5_ = !(((1073741840 & (*sym).flags) == 0));
				LA6_: ;
				if (!T5_) goto LA7_;
				fillProcLoc__cgen_11493((*p).module, n);
				genProcPrototype__cgen_11529((*p).module, sym);
			}
			goto LA3_;
			LA7_: ;
			{
				genProc__cgen_421((*p).module, sym);
			}
			LA3_: ;
			putLocIntoDest__cgen_11532(p, d, (*sym).loc);
		}
		break;
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 12):
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 16):
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 15):
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 13):
		{
			{
				NimStringDesc* T15_;
				if (!(((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 28))&63U)))!=0)) goto LA13_;
				T15_ = NIM_NIL;
				T15_ = rawNewString(((*(*sym).name).s ? (*(*sym).name).s->Sup.len : 0) + 48);
appendString(T15_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_381));
appendString(T15_, (*(*sym).name).s);
				liMessage__msgs_1128((*(*(*p).module).g).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T15_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_382, NIM_FALSE);
			}
			LA13_: ;
			{
				NIM_BOOL T18_;
				T18_ = (NIM_BOOL)0;
				T18_ = (((*(*p).module).flags &((NU8)1<<((NU)(((tyEnum_CodegenFlag__vPx29bHhk9a7V50u1UO0rM4w) 6))&7U)))!=0);
				if (!(T18_)) goto LA19_;
				T18_ = !(((*(*sym).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 5)));
				LA19_: ;
				if (!T18_) goto LA20_;
				fillProcLoc__cgen_11493((*p).module, n);
				genProcPrototype__cgen_11529((*p).module, sym);
			}
			goto LA16_;
			LA20_: ;
			{
				genProc__cgen_421((*p).module, sym);
			}
			LA16_: ;
			{
				NIM_BOOL T25_;
				NimStringDesc* T29_;
				T25_ = (NIM_BOOL)0;
				T25_ = ((*sym).loc.r == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL));
				if (T25_) goto LA26_;
				T25_ = ((*sym).loc.lode == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
				LA26_: ;
				if (!T25_) goto LA27_;
				T29_ = NIM_NIL;
				T29_ = rawNewString(((*(*sym).name).s ? (*(*sym).name).s->Sup.len : 0) + 20);
appendString(T29_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_383));
appendString(T29_, (*(*sym).name).s);
				internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*n).info, T29_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_384);
			}
			LA27_: ;
			putLocIntoDest__cgen_11532(p, d, (*sym).loc);
		}
		break;
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 10):
		{
			{
				NIM_BOOL T33_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T36_;
				T33_ = (NIM_BOOL)0;
				T33_ = isSimpleConst__cgen_95((*sym).typ);
				if (!T33_) goto LA34_;
				T36_ = NIM_NIL;
				T36_ = genLiteral__cgen_17776(p, (*sym).ast, (*sym).typ);
				putIntoDest__cgen_18794(p, d, n, T36_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 1));
			}
			goto LA31_;
			LA34_: ;
			{
				if (!(((*(*p).module).flags &((NU8)1<<((NU)(((tyEnum_CodegenFlag__vPx29bHhk9a7V50u1UO0rM4w) 6))&7U)))!=0)) goto LA38_;
				genConstHeader__cgen_24515((*p).module, (*p).module, p, sym);
				putLocIntoDest__cgen_11532(p, d, (*sym).loc);
			}
			goto LA31_;
			LA38_: ;
			{
				genComplexConst__cgen_24238(p, sym, d);
			}
			LA31_: ;
		}
		break;
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 20):
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T42_;
			T42_ = NIM_NIL;
			T42_ = rope__ropes_115(((NI64) ((*sym).position)));
			putIntoDest__cgen_18794(p, d, n, T42_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
		}
		break;
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8):
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 21):
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 11):
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 9):
		{
			{
				if (!!(((67108872 & (*sym).flags) == 0))) goto LA46_;
				genVarPrototype__cgen_11516((*p).module, n);
				{
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T52_;
					if (!(((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 28))&63U)))!=0)) goto LA50_;
					T52_ = NIM_NIL;
					T52_ = astdef__ast_3462(sym);
					genSingleVar__cgen_13925(p, sym, n, T52_);
				}
				LA50_: ;
			}
			LA46_: ;
			{
				NIM_BOOL T55_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T57_;
				NimStringDesc* T60_;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym5744_;
				NimStringDesc* T61_;
				T55_ = (NIM_BOOL)0;
				T55_ = ((*sym).loc.r == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL));
				if (T55_) goto LA56_;
				T57_ = NIM_NIL;
				T57_ = t__cgen_85((*sym).loc);
				T55_ = (T57_ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
				LA56_: ;
				if (!T55_) goto LA58_;
				T60_ = NIM_NIL;
				xX60gensym5744_ = sym;
				T61_ = NIM_NIL;
				T61_ = dollar___systemZdollars_3((NI)((NI)((NU64)(((NI) ((*xX60gensym5744_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym5744_).Sup.itemId.item))));
				T60_ = rawNewString(((*(*sym).name).s ? (*(*sym).name).s->Sup.len : 0) + (T61_ ? T61_->Sup.len : 0) + 20);
appendString(T60_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_457));
appendString(T60_, (*(*sym).name).s);
appendString(T60_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3));
appendString(T60_, T61_);
				internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*n).info, T60_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_458);
			}
			LA58_: ;
			{
				if (!(((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 26))&63U)))!=0)) goto LA64_;
				accessThreadLocalVar__cgen_416(p, sym);
				{
					NIM_BOOL T68_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T71_;
					T68_ = (NIM_BOOL)0;
					T68_ = emulatedThreadVars__cgen_419((*(*(*p).module).g).config);
					if (!T68_) goto LA69_;
					T71_ = NIM_NIL;
					T71_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_399), (*sym).loc.r);
					putIntoDest__cgen_18794(p, d, (*sym).loc.lode, T71_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
				}
				goto LA66_;
				LA69_: ;
				{
					putLocIntoDest__cgen_11532(p, d, (*sym).loc);
				}
				LA66_: ;
			}
			goto LA62_;
			LA64_: ;
			{
				putLocIntoDest__cgen_11532(p, d, (*sym).loc);
			}
			LA62_: ;
		}
		break;
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 5):
		{
			{
				NIM_BOOL T77_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T79_;
				NimStringDesc* T82_;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym5750_;
				NimStringDesc* T83_;
				T77_ = (NIM_BOOL)0;
				T77_ = ((*sym).loc.r == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL));
				if (T77_) goto LA78_;
				T79_ = NIM_NIL;
				T79_ = t__cgen_85((*sym).loc);
				T77_ = (T79_ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
				LA78_: ;
				if (!T77_) goto LA80_;
				T82_ = NIM_NIL;
				xX60gensym5750_ = sym;
				T83_ = NIM_NIL;
				T83_ = dollar___systemZdollars_3((NI)((NI)((NU64)(((NI) ((*xX60gensym5750_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym5750_).Sup.itemId.item))));
				T82_ = rawNewString(((*(*sym).name).s ? (*(*sym).name).s->Sup.len : 0) + (T83_ ? T83_->Sup.len : 0) + 21);
appendString(T82_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_459));
appendString(T82_, (*(*sym).name).s);
appendString(T82_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3));
appendString(T82_, T83_);
				internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*n).info, T82_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_460);
			}
			LA80_: ;
			putLocIntoDest__cgen_11532(p, d, (*sym).loc);
		}
		break;
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3):
		{
			{
				NIM_BOOL T87_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T89_;
				NimStringDesc* T92_;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym5754_;
				NimStringDesc* T93_;
				T87_ = (NIM_BOOL)0;
				T87_ = ((*sym).loc.r == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL));
				if (T87_) goto LA88_;
				T89_ = NIM_NIL;
				T89_ = t__cgen_85((*sym).loc);
				T87_ = (T89_ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
				LA88_: ;
				if (!T87_) goto LA90_;
				T92_ = NIM_NIL;
				xX60gensym5754_ = sym;
				T93_ = NIM_NIL;
				T93_ = dollar___systemZdollars_3((NI)((NI)((NU64)(((NI) ((*xX60gensym5754_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym5754_).Sup.itemId.item))));
				T92_ = rawNewString(((*(*sym).name).s ? (*(*sym).name).s->Sup.len : 0) + (T93_ ? T93_->Sup.len : 0) + 22);
appendString(T92_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_461));
appendString(T92_, (*(*sym).name).s);
appendString(T92_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3));
appendString(T92_, T93_);
				internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*n).info, T92_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_462);
			}
			LA90_: ;
			putLocIntoDest__cgen_11532(p, d, (*sym).loc);
		}
		break;
		default:
		{
			NimStringDesc* T95_;
			T95_ = NIM_NIL;
			T95_ = rawNewString((reprEnum((NI)(*sym).kind, (&NTItsymkind__sjiB9b9aO1FRPetW6gPYZbfw_)) ? reprEnum((NI)(*sym).kind, (&NTItsymkind__sjiB9b9aO1FRPetW6gPYZbfw_))->Sup.len : 0) + 22);
appendString(T95_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_463));
appendString(T95_, reprEnum((NI)(*sym).kind, (&NTItsymkind__sjiB9b9aO1FRPetW6gPYZbfw_)));
appendString(T95_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_464));
			internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*n).info, T95_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_465);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
	{
		{
			NIM_BOOL T99_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T102_;
			T99_ = (NIM_BOOL)0;
			T99_ = isEmptyType__ast_4780((*n).typ);
			if (!!(T99_)) goto LA100_;
			T102_ = NIM_NIL;
			T102_ = genLiteral__cgen_11538(p, n);
			putIntoDest__cgen_18794(p, d, n, T102_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
		}
		LA100_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22):
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T104_;
		T104_ = NIM_NIL;
		T104_ = genLiteral__cgen_11538(p, n);
		putDataIntoDest__cgen_18780(p, d, n, T104_);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 15):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 16) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 19):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5):
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T106_;
		T106_ = NIM_NIL;
		T106_ = genLiteral__cgen_11538(p, n);
		putIntoDest__cgen_18794(p, d, n, T106_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* op;
		genLineDir__cgen_369(p, n);
		op = (*n)._kind_6.sons->data[((NI) 0)];
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
			if (!((*n).typ == 0)) goto LA110_;
			nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			{
				NIM_BOOL T114_;
				T114_ = (NIM_BOOL)0;
				T114_ = ((*op).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
				if (!(T114_)) goto LA115_;
				T114_ = !(((*(*op)._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 0)));
				LA115_: ;
				if (!T114_) goto LA116_;
				genMagicExpr__cgen_23524(p, n, (&a), (*(*op)._kind_4.sym).magic);
			}
			goto LA112_;
			LA116_: ;
			{
				genCall__cgen_13177(p, n, (&a));
			}
			LA112_: ;
		}
		goto LA108_;
		LA110_: ;
		{
			{
				NIM_BOOL T122_;
				T122_ = (NIM_BOOL)0;
				T122_ = ((*op).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
				if (!(T122_)) goto LA123_;
				T122_ = !(((*(*op)._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 0)));
				LA123_: ;
				if (!T122_) goto LA124_;
				genMagicExpr__cgen_23524(p, n, d, (*(*op)._kind_4.sym).magic);
			}
			goto LA120_;
			LA124_: ;
			{
				genCall__cgen_13177(p, n, d);
			}
			LA120_: ;
		}
		LA108_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 39):
	{
		{
			NIM_BOOL T130_;
			NI T132_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T135_;
			T130_ = (NIM_BOOL)0;
			T130_ = isDeepConstExpr__trees_171(n, NIM_FALSE);
			if (!(T130_)) goto LA131_;
			T132_ = (NI)0;
			T132_ = len__ast_3155(n);
			T130_ = !((T132_ == ((NI) 0)));
			LA131_: ;
			if (!T130_) goto LA133_;
			T135_ = NIM_NIL;
			T135_ = genSetNode__cgen_17906(p, n);
			putIntoDest__cgen_18794(p, d, n, T135_, ((tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ) 0));
		}
		goto LA128_;
		LA133_: ;
		{
			genSetConstr__cgen_24052(p, n, d);
		}
		LA128_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41):
	{
		{
			NIM_BOOL T140_;
			NI T142_;
			T140_ = (NIM_BOOL)0;
			T140_ = isDeepConstExpr__trees_171(n, NIM_FALSE);
			if (!(T140_)) goto LA141_;
			T142_ = (NI)0;
			T142_ = len__ast_3155(n);
			T140_ = !((T142_ == ((NI) 0)));
			LA141_: ;
			if (!T140_) goto LA143_;
			exprComplexConst__cgen_24475(p, n, d);
		}
		goto LA138_;
		LA143_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T146_;
			T146_ = NIM_NIL;
			T146_ = skipTypes__ast_3723((*n).typ, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_183);
			if (!((*T146_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24))) goto LA147_;
			genSeqConstr__cgen_21290(p, n, d);
		}
		goto LA138_;
		LA147_: ;
		{
			genArrayConstr__cgen_24216(p, n, d);
		}
		LA138_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 37):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 160):
	{
		{
			NIM_BOOL T153_;
			NIM_BOOL T154_;
			NI T157_;
			T153_ = (NIM_BOOL)0;
			T154_ = (NIM_BOOL)0;
			T154_ = !(((*n).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
			if (!(T154_)) goto LA155_;
			T154_ = ((*(*n).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25));
			LA155_: ;
			T153_ = T154_;
			if (!(T153_)) goto LA156_;
			T157_ = (NI)0;
			T157_ = len__ast_3155(n);
			T153_ = (T157_ == ((NI) 2));
			LA156_: ;
			if (!T153_) goto LA158_;
			genClosure__cgen_24173(p, n, d);
		}
		goto LA151_;
		LA158_: ;
		{
			NIM_BOOL T161_;
			NI T163_;
			T161_ = (NIM_BOOL)0;
			T161_ = isDeepConstExpr__trees_171(n, NIM_FALSE);
			if (!(T161_)) goto LA162_;
			T163_ = (NI)0;
			T163_ = len__ast_3155(n);
			T161_ = !((T163_ == ((NI) 0)));
			LA162_: ;
			if (!T161_) goto LA164_;
			exprComplexConst__cgen_24475(p, n, d);
		}
		goto LA151_;
		LA164_: ;
		{
			genTupleConstr__cgen_24126(p, n, d);
		}
		LA151_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 38):
	{
		genObjConstr__cgen_10395(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 61):
	{
		genCast__cgen_22997(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 60):
	{
		genConv__cgen_23118(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63):
	{
		genAddr__cgen_19655(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42):
	{
		genBracketExpr__cgen_20370(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 47):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65):
	{
		genDeref__cgen_19488(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45):
	{
		genRecordField__cgen_19775(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 46):
	{
		genCheckedRecordField__cgen_20003(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 127):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 112):
	{
		genBlock__cgen_14665(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126):
	{
		genStmtListExpr__cgen_24255(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115):
	{
		genStmtList__cgen_24309(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 48):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 92):
	{
		genIf__cgen_14186(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 93):
	{
		expr__cgen_11525(p, (*(*n)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 0)], d);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 66):
	{
		downConv__cgen_24429(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 67):
	{
		upConv__cgen_24363(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 68):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 69):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 70):
	{
		genRangeChck__cgen_23044(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 71):
	{
		convStrToCStr__cgen_23125(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 72):
	{
		convCStrToStr__cgen_23140(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 51) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 52):
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym_2;
		sym_2 = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		genProc__cgen_421((*p).module, sym_2);
		{
			NIM_BOOL T188_;
			NimStringDesc* T192_;
			T188_ = (NIM_BOOL)0;
			T188_ = ((*sym_2).loc.r == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL));
			if (T188_) goto LA189_;
			T188_ = ((*sym_2).loc.lode == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
			LA189_: ;
			if (!T188_) goto LA190_;
			T192_ = NIM_NIL;
			T192_ = rawNewString(((*(*sym_2).name).s ? (*(*sym_2).name).s->Sup.len : 0) + 20);
appendString(T192_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_383));
appendString(T192_, (*(*sym_2).name).s);
			internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*n).info, T192_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_743);
		}
		LA190_: ;
		putLocIntoDest__cgen_11532(p, d, (*sym_2).loc);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 155):
	{
		genClosure__cgen_24173(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1):
	{
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 96):
	{
		genWhileStmt__cgen_14588(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 99):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 100):
	{
		genVarStmt__cgen_14166(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 101):
	{
		{
			if (!(((*(*p).module).flags &((NU8)1<<((NU)(((tyEnum_CodegenFlag__vPx29bHhk9a7V50u1UO0rM4w) 6))&7U)))!=0)) goto LA200_;
			genConstStmt__cgen_24590(p, n);
		}
		LA200_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 94):
	{
		internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_765), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_766);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 97):
	{
		genCase__cgen_15603(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 109):
	{
		genReturnStmt__cgen_14269(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 110):
	{
		genBreakStmt__cgen_14784(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 73):
	{
		cow__cgen_19647(p, (*n)._kind_6.sons->data[((NI) 1)]);
		{
			if (!!((((*n).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg) 15))&31U)))!=0))) goto LA209_;
			genAsgn__cgen_17560(p, n, NIM_FALSE);
		}
		LA209_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 74):
	{
		cow__cgen_19647(p, (*n)._kind_6.sons->data[((NI) 1)]);
		{
			if (!!((((*n).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg) 15))&31U)))!=0))) goto LA214_;
			genAsgn__cgen_17560(p, n, !(((*p).prc == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))));
		}
		LA214_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 114):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ex;
		ex = (*n)._kind_6.sons->data[((NI) 0)];
		{
			tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a_2;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T221_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T222_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T223_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T224_;
			if (!!(((*ex).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)))) goto LA219_;
			genLineDir__cgen_369(p, n);
			nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
			initLocExprSingleUse__cgen_11552(p, ex, (&a_2));
			T221_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T221_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			T222_ = NIM_NIL;
			T222_ = amp___ropes_144(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_786), a_2.r);
			T223_ = NIM_NIL;
			T223_ = amp___ropes_140(T222_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_764));
			T224_ = NIM_NIL;
			T224_ = indentLine__cgen_286(p, T223_);
			add__ropes_159(T221_, T224_);
		}
		LA219_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 89):
	{
		genAsmStmt__cgen_17370(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 106):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 154):
	{
		switch ((*(*(*(*p).module).g).config).exc) {
		case ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 3):
		{
			genTryGoto__cgen_16490(p, n, d);
		}
		break;
		case ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 2):
		{
			genTryCpp__cgen_15773(p, n, d);
		}
		break;
		default:
		{
			genTrySetjmp__cgen_16834(p, n, d);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 108):
	{
		genRaiseStmt__cgen_14965(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 98):
	{
		genTypeSection__cgen_10311((*p).module, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 125):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 121):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 116):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 117):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 118):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 119):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 120):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 83):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 82):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 113):
	{
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 90):
	{
		genPragma__cgen_17418(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 91):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T235_;
		T235_ = NIM_NIL;
		T235_ = lastSon__ast_4833(n);
		expr__cgen_11525(p, T235_, d);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 80):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 81):
	{
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc;
			if (!((*(*n)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1))) goto LA239_;
			prc = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
			{
				if (!(((*(*p).module).flags &((NU8)1<<((NU)(((tyEnum_CodegenFlag__vPx29bHhk9a7V50u1UO0rM4w) 6))&7U)))!=0)) goto LA243_;
				{
					NIM_BOOL T247_;
					T247_ = (NIM_BOOL)0;
					T247_ = contains__astalgo_3489((&(*(*p).module).alive), ((NI) ((*prc).Sup.itemId.item)));
					if (!(T247_)) goto LA248_;
					T247_ = ((*prc).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 0) || (*prc).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 156) || (*prc).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 155) || (*prc).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 145));
					LA248_: ;
					if (!T247_) goto LA249_;
					genProc__cgen_421((*p).module, prc);
				}
				LA249_: ;
			}
			goto LA241_;
			LA243_: ;
			{
				NIM_BOOL T252_;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T253_;
				T252_ = (NIM_BOOL)0;
				T253_ = NIM_NIL;
				T253_ = skipGenericOwner__ast_4659(prc);
				T252_ = ((*T253_).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6));
				if (!(T252_)) goto LA254_;
				T252_ = !((((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 28))&63U)))!=0));
				LA254_: ;
				if (!T252_) goto LA255_;
				{
					NIM_BOOL T259_;
					NIM_BOOL T260_;
					NIM_BOOL T262_;
					T259_ = (NIM_BOOL)0;
					T260_ = (NIM_BOOL)0;
					T260_ = ((262272 & (*prc).flags) == 128);
					if (T260_) goto LA261_;
					T262_ = (NIM_BOOL)0;
					T262_ = (((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 7))&63U)))!=0);
					if (!(T262_)) goto LA263_;
					T262_ = (((*prc).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 5))&15U)))!=0);
					LA263_: ;
					T260_ = T262_;
					LA261_: ;
					T259_ = T260_;
					if (T259_) goto LA264_;
					T259_ = ((*prc).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 14));
					LA264_: ;
					if (!T259_) goto LA265_;
					genProc__cgen_421((*p).module, prc);
				}
				LA265_: ;
			}
			goto LA241_;
			LA255_: ;
			LA241_: ;
		}
		LA239_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 95):
	{
		genParForStmt__cgen_14708(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 157):
	{
		genState__cgen_13635(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 156):
	{
		(*p).splitDecls += ((NI) 1);
		genGotoState__cgen_13798(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 158):
	{
		genBreakState__cgen_13856(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 123):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 122):
	{
	}
	break;
	default:
	{
		NimStringDesc* T273_;
		T273_ = NIM_NIL;
		T273_ = rawNewString((reprEnum((NI)(*n).kind, (&NTItnodekind__clSgDh22o9au33BrVH9bDQZw_)) ? reprEnum((NI)(*n).kind, (&NTItnodekind__clSgDh22o9au33BrVH9bDQZw_))->Sup.len : 0) + 25);
appendString(T273_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_463));
appendString(T273_, reprEnum((NI)(*n).kind, (&NTItnodekind__clSgDh22o9au33BrVH9bDQZw_)));
appendString(T273_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_856));
		internalErrorImpl__msgs_1441((*(*(*p).module).g).config, (*n).info, T273_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_857);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genStmts__cgen_11522)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t) {
	tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw a;
	NIM_BOOL isPush;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw));
	isPush = hasHint__options_530((*(*(*p).module).g).config, ((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 104));
	{
		if (!isPush) goto LA3_;
		pushInfoContext__msgs_500((*(*(*p).module).g).config, (*t).info, ((NimStringDesc*) NIM_NIL));
	}
	LA3_: ;
	expr__cgen_11525(p, t, (&a));
	{
		if (!isPush) goto LA7_;
		popInfoContext__msgs_517((*(*(*p).module).g).config);
	}
	LA7_: ;
	{
		NimStringDesc* argX60gensym3202_;
		if (!!(((71 &((NU16)1<<((NU)(a.k)&15U)))!=0))) goto LA11_;
		argX60gensym3202_ = toFileLineCol__msgs_625(TM__9bddtAaa9cYLwzzzlT9aJ5CKw_858);
		internalErrorImpl__msgs_1441((*(*(*p).module).g).config, unknownLineInfo__lineinfos_284, argX60gensym3202_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_858);
	}
	LA11_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addHcrInitGuards__cgen_28671)(tyObject_TCProc__MBi6xLytmtkj9c39aVVi9aJ8w* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL* inInitGuard) {
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115))) goto LA3_;
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child;
			child = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA8;
						i = i_2;
						child = (*n)._kind_6.sons->data[i];
						addHcrInitGuards__cgen_28671(p, child, inInitGuard);
						i_2 += ((NI) 1);
					} LA8: ;
				}
			}
		}
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL stmtShouldExecute;
		NIM_BOOL T10_;
		T10_ = (NIM_BOOL)0;
		T10_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 99) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 100));
		if (T10_) goto LA11_;
		T10_ = (((*n).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg) 20))&31U)))!=0);
		LA11_: ;
		stmtShouldExecute = T10_;
		{
			if (!(*inInitGuard)) goto LA14_;
			{
				if (!stmtShouldExecute) goto LA18_;
				endBlock__cgen_13329(p);
				(*inInitGuard) = NIM_FALSE;
			}
			LA18_: ;
		}
		goto LA12_;
		LA14_: ;
		{
			{
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T25_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T27_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T28_;
				NimStringDesc* res;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T33_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T34_;
				NI T35_;
				if (!!(stmtShouldExecute)) goto LA23_;
				T25_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T25_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				T26_ = NIM_NIL;
				T26_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_7));
				T27_ = NIM_NIL;
				T27_ = indentLine__cgen_286(p, T26_);
				add__ropes_159(T25_, T27_);
				T28_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
				T28_ = s__cgendata_225(p, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
				res = rawNewString(((NI) 80));
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_8));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA31_;
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA31_: ;
				T33_ = NIM_NIL;
				T33_ = rope__ropes_109(res);
				T34_ = NIM_NIL;
				T34_ = indentLine__cgen_286(p, T33_);
				add__ropes_159(T28_, T34_);
				T35_ = (NI)0;
				T35_ = startBlockInternal__cgen_13308(p);
				(*inInitGuard) = NIM_TRUE;
			}
			LA23_: ;
		}
		LA12_: ;
		genStmts__cgen_11522(p, n);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genTopLevelStmt__cgen_28702)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedN;
{	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = skipCodegen__passes_51((*(*m).g).config, n);
		if (!T3_) goto LA4_;
		goto BeforeRet_;
	}
	LA4_: ;
	(*(*m).initProc).options = initProcOptions__cgen_28467(m);
	transformedN = transformStmt__transf_1888((*(*m).g).graph, (*m).Sup.idgen, (*m).module, n);
	{
		if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 42))&63U)))!=0)) goto LA8_;
		transformedN = injectDestructorCalls__injectdestructors_10132((*(*m).g).graph, (*m).Sup.idgen, (*m).module, transformedN);
	}
	LA8_: ;
	{
		NIM_BOOL T12_;
		T12_ = (NIM_BOOL)0;
		T12_ = hcrOn__cgen_43(m);
		if (!T12_) goto LA13_;
		addHcrInitGuards__cgen_28671((*m).initProc, transformedN, (&(*m).inHcrInitGuard));
	}
	goto LA10_;
	LA13_: ;
	{
		genProcBody__cgen_26219((*m).initProc, transformedN);
	}
	LA10_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, myProcess__cgen_28710)(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* b, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = n;
	{
		tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m;
		if (!!((b == ((tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*) NIM_NIL)))) goto LA3_;
		m = ((tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA*) (b));
		genTopLevelStmt__cgen_28702(m, n);
	}
	LA3_: ;
	return result;
}
static N_INLINE(NIM_BOOL, moduleHasChanged__passes_209)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = NIM_TRUE;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, finalCodegenActions__cgen_28755)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* mm;
	NI T82_;
{	{
		if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 14))&63U)))!=0)) goto LA3_;
		{
			NIM_BOOL T7_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T9_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
			T7_ = (NIM_BOOL)0;
			T7_ = ((*(*(*m).g).config).exc == ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 3));
			if (!(T7_)) goto LA8_;
			T9_ = NIM_NIL;
			T9_ = getCompilerProc__magicsys_145(graph, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_859));
			T7_ = !((T9_ == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
			LA8_: ;
			if (!T7_) goto LA10_;
			T12_ = NIM_NIL;
			T12_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_859));
			(void)(T12_);
		}
		LA10_: ;
		{
			if (!((2097536 & (*(*(*m).g).config).globalOptions) == 0)) goto LA15_;
			{
				NI i;
				NI colontmp_;
				NI T18_;
				NI res;
				i = (NI)0;
				colontmp_ = (NI)0;
				T18_ = (((*graph).globalDestructors ? (*graph).globalDestructors->Sup.len : 0)-1);
				colontmp_ = T18_;
				res = colontmp_;
				{
					while (1) {
						if (!(((NI) 0) <= res)) goto LA20;
						i = res;
						add__ast_4798(n, (*graph).globalDestructors->data[i]);
						res -= ((NI) 1);
					} LA20: ;
				}
			}
		}
		LA15_: ;
	}
	LA3_: ;
	{
		NIM_BOOL T23_;
		T23_ = (NIM_BOOL)0;
		T23_ = skipCodegen__passes_51((*(*m).g).config, n);
		if (!T23_) goto LA24_;
		goto BeforeRet_;
	}
	LA24_: ;
	{
		NIM_BOOL T28_;
		T28_ = (NIM_BOOL)0;
		T28_ = moduleHasChanged__passes_209(graph, (*m).module);
		if (!T28_) goto LA29_;
		{
			if (!!((n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA33_;
			(*(*m).initProc).options = initProcOptions__cgen_28467(m);
			genProcBody__cgen_26219((*m).initProc, n);
		}
		LA33_: ;
		{
			NIM_BOOL T37_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T40_;
			T37_ = (NIM_BOOL)0;
			T37_ = hcrOn__cgen_43(m);
			if (!T37_) goto LA38_;
			T40_ = NIM_NIL;
			T40_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_860));
			(void)(T40_);
			{
				if (!(*m).inHcrInitGuard) goto LA43_;
				endBlock__cgen_13329((*m).initProc);
			}
			LA43_: ;
		}
		LA38_: ;
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* disp;
			if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 14))&63U)))!=0)) goto LA47_;
			{
				NIM_BOOL T51_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T54_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T55_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T56_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T57_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T58_;
				T51_ = (NIM_BOOL)0;
				T51_ = hcrOn__cgen_43(m);
				if (!T51_) goto LA52_;
				T54_ = NIM_NIL;
				T54_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_28));
				(void)(T54_);
				T55_ = NIM_NIL;
				T55_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_44));
				(void)(T55_);
				T56_ = NIM_NIL;
				T56_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_57));
				(void)(T56_);
				T57_ = NIM_NIL;
				T57_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_861));
				(void)(T57_);
				T58_ = NIM_NIL;
				T58_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_862));
				(void)(T58_);
			}
			LA52_: ;
			{
				NIM_BOOL T61_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T65_;
				T61_ = (NIM_BOOL)0;
				T61_ = !(((*(*(*m).g).config).target.targetOS == ((tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw) 29)));
				if (!(T61_)) goto LA62_;
				T61_ = !(((50 &((NU16)1<<((NU)((*(*(*m).g).config).selectedGC)&15U)))!=0));
				LA62_: ;
				if (!T61_) goto LA63_;
				T65_ = NIM_NIL;
				T65_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_863));
				(void)(T65_);
			}
			LA63_: ;
			{
				NIM_BOOL T68_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T72_;
				T68_ = (NIM_BOOL)0;
				T68_ = emulatedThreadVars__cgen_419((*(*m).g).config);
				if (!(T68_)) goto LA69_;
				T68_ = !(((*(*(*m).g).config).target.targetOS == ((tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw) 29)));
				LA69_: ;
				if (!T68_) goto LA70_;
				T72_ = NIM_NIL;
				T72_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_864));
				(void)(T72_);
			}
			LA70_: ;
			{
				NI T75_;
				T75_ = ((*(*m).g).forwardedProcs ? (*(*m).g).forwardedProcs->Sup.len : 0);
				if (!(T75_ == ((NI) 0))) goto LA76_;
				(*m).flags |= ((NU8)1)<<((((tyEnum_CodegenFlag__vPx29bHhk9a7V50u1UO0rM4w) 5)) & 7);
			}
			LA76_: ;
			disp = generateMethodDispatchers__cgmeth_547(graph);
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x;
				x = NIM_NIL;
				{
					NI i_2;
					NI colontmp__2;
					NI i_3;
					i_2 = (NI)0;
					colontmp__2 = (NI)0;
					colontmp__2 = safeLen__ast_3148(disp);
					i_3 = ((NI) 0);
					{
						while (1) {
							if (!(i_3 < colontmp__2)) goto LA81;
							i_2 = i_3;
							x = (*disp)._kind_6.sons->data[i_2];
							genProcAux__cgen_26283(m, (*x)._kind_4.sym);
							i_3 += ((NI) 1);
						} LA81: ;
					}
				}
			}
		}
		LA47_: ;
	}
	LA29_: ;
	mm = m;
	asgnRef((void**) (&(*(*m).g).modulesClosed), (tySequence__ukLNp6qJ4FndCViFTz0FGg*) incrSeqV3((TGenericSeq*)((*(*m).g).modulesClosed), (&NTIseqLbmoduleT__ukLNp6qJ4FndCViFTz0FGg_)));
	T82_ = (*(*m).g).modulesClosed->Sup.len++;
	asgnRef((void**) (&(*(*m).g).modulesClosed->data[T82_]), mm);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, myClose__cgen_28826)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* b, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
{	result = NIM_NIL;
	result = n;
	{
		if (!(b == ((tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	finalCodegenActions__cgen_28755(graph, ((tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA*) (b)), n);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, pop__icZic_2462)(tySequence__ed0C0uAUZPhvw3RAc5hfYg** s) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	NI L;
	NI T1_;
	result = NIM_NIL;
	T1_ = ((*s) ? (*s)->Sup.len : 0);
	L = (NI)(T1_ - ((NI) 1));
	result = (*s)->data[L];
	unsureAsgnRef((void**) (&(*s)), (tySequence__ed0C0uAUZPhvw3RAc5hfYg*) setLengthSeqV2(((*s))?&((*s))->Sup:NIM_NIL, (&NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_), ((NI) (L))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genForwardedProcs__cgen_28835)(tyObject_BModuleListcolonObjectType___9c4b0IbdzIJRabh100GyFtA* g) {
	{
		while (1) {
			NI T3_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc;
			tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m;
			T3_ = ((*g).forwardedProcs ? (*g).forwardedProcs->Sup.len : 0);
			if (!(((NI) 0) < T3_)) goto LA2;
			prc = pop__icZic_2462((&(*g).forwardedProcs));
			m = (*g).modules->data[(*prc).Sup.itemId.module];
			{
				NimStringDesc* T8_;
				if (!(((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 4))&63U)))!=0)) goto LA6_;
				T8_ = NIM_NIL;
				T8_ = rawNewString(((*(*prc).name).s ? (*(*prc).name).s->Sup.len : 0) + 17);
appendString(T8_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_865));
appendString(T8_, (*(*prc).name).s);
				internalErrorImpl__msgs_1441((*(*m).g).config, (*prc).info, T8_, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_866);
			}
			LA6_: ;
			genProcNoForward__cgen_26633(m, prc);
		} LA2: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getSomeNameForModule__cgen_27153)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = mangleModuleName__modulepaths_32((*(*m).g).config, (*m).filename);
	T2_ = NIM_NIL;
	T2_ = mangle__ccgutils_112(T1_);
	add__ropes_162(&result, T2_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getSomeInitName__cgen_27170)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, NimStringDesc* suffix) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = hcrOn__cgen_43(m);
		if (!!(T3_)) goto LA4_;
		result = getSomeNameForModule__cgen_27153(m);
	}
	LA4_: ;
	add__ropes_162(&result, suffix);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getInitName__cgen_27174)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
		if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 14))&63U)))!=0)) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = rope__ropes_109((*(*(*m).g).config).nimMainPrefix);
		T6_ = NIM_NIL;
		T6_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_867));
		result = amp___ropes_128(T5_, T6_);
	}
	goto LA1_;
	LA3_: ;
	{
		result = getSomeInitName__cgen_27170(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_868));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getHcrInitName__cgen_27184)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	result = getSomeInitName__cgen_27170(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_882));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, hcrGetProcLoadCode__cgen_27187)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, NimStringDesc* sym, NimStringDesc* prefix, NimStringDesc* handle, NimStringDesc* getProcFunc) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc;
	NimStringDesc* extname;
	NimStringDesc* T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tmp;
	tyArray__XSZGJHCjWme3CUmFzckT3g T10_;
	NimStringDesc* T11_;
	result = NIM_NIL;
	prc = getCompilerProc__magicsys_145((*(*m).g).graph, sym);
	fillProcLoc__cgen_11493(m, (*(*prc).ast)._kind_6.sons->data[((NI) 0)]);
	T1_ = NIM_NIL;
	T1_ = rawNewString((prefix ? prefix->Sup.len : 0) + (sym ? sym->Sup.len : 0) + 0);
appendString(T1_, prefix);
appendString(T1_, sym);
	extname = T1_;
	tmp = mangleDynLibProc__cgen_3812(prc);
	asgnRef((void**) (&(*prc).loc.r), tmp);
	asgnRef((void**) (&(*(*prc).typ).sym), ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym6503_;
		NIM_BOOL T4_;
		tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T7_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T8_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
		xX60gensym6503_ = prc;
		T4_ = (NIM_BOOL)0;
		T4_ = containsOrIncl__astalgo_402((&(*m).declaredThings), (NI)((NI)((NU64)(((NI) ((*xX60gensym6503_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym6503_).Sup.itemId.item))));
		if (!!(T4_)) goto LA5_;
		nimZeroMem((void*)T7_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
		T7_[0] = (*prc).loc.r;
		T8_ = NIM_NIL;
		T8_ = t__cgen_85((*prc).loc);
		T7_[1] = getTypeDesc__cgen_6662(m, T8_, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
		T9_ = NIM_NIL;
		T9_ = percent___cgen_28137(T7_, 2);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 10))- 0], T9_);
	}
	LA5_: ;
	nimZeroMem((void*)T10_, sizeof(tyArray__XSZGJHCjWme3CUmFzckT3g));
	T10_[0] = tmp;
	T10_[1] = getTypeDesc__cgen_6662(m, (*prc).typ, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
	T10_[2] = rope__ropes_109(getProcFunc);
	T10_[3] = rope__ropes_109(handle);
	T11_ = NIM_NIL;
	T11_ = rawNewString((prefix ? prefix->Sup.len : 0) + (sym ? sym->Sup.len : 0) + 0);
appendString(T11_, prefix);
appendString(T11_, sym);
	T10_[4] = makeCString__msgs_50(T11_);
	result = percent___cgen_28142(T10_, 5);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getDatInitName__cgen_27181)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	result = getSomeInitName__cgen_27170(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_887));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genDatInitCode__cgen_28079)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m) {
	NIM_BOOL moduleDatInitRequired;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* prc;
	tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T1_;
	NimStringDesc* T2_;
	tyArray__dAmhZbEWrTM5xES2bTVweg T17_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
	moduleDatInitRequired = hcrOn__cgen_43(m);
	nimZeroMem((void*)T1_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
	T2_ = NIM_NIL;
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = hcrOn__cgen_43(m);
		if (!T5_) goto LA6_;
		T2_ = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_869));
	}
	goto LA3_;
	LA6_: ;
	{
		T2_ = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_870));
	}
	LA3_: ;
	T1_[0] = rope__ropes_109(T2_);
	T1_[1] = getDatInitName__cgen_27181(m);
	prc = percent___cgen_28082(T1_, 2);
	genCLineDir__cgen_340(&prc, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_871), ((NI) 999999), (*(*m).g).config);
	{
		tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw i;
		NI res;
		i = (tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw)0;
		res = ((NI) 14);
		{
			while (1) {
				if (!(res <= ((NI) 18))) goto LA11;
				i = ((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) (res));
				{
					NI T14_;
					T14_ = (NI)0;
					T14_ = len__ropes_10((*m).s[(i)- 0]);
					if (!!((T14_ == ((NI) 0)))) goto LA15_;
					moduleDatInitRequired = NIM_TRUE;
					add__ropes_159(&prc, (*m).s[(i)- 0]);
				}
				LA15_: ;
				res += ((NI) 1);
			} LA11: ;
		}
	}
	nimZeroMem((void*)T17_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
	T18_ = NIM_NIL;
	T18_ = percent___cgen_28093(T17_, 0);
	add__ropes_159(&prc, T18_);
	{
		if (!moduleDatInitRequired) goto LA21_;
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 13))- 0], prc);
	}
	LA21_: ;
}
static N_INLINE(NU64, hiXorLo__pureZhashes_79)(NU64 a, NU64 b) {
	NU64 result;
	result = (NU64)0;
	__uint128_t r = a; r *= b; result = (r >> 64) ^ r;
	return result;
}
static N_INLINE(NI, hashWangYi1__pureZhashes_136)(NU64 x) {
	NI result;
	NU64 T1_;
	NU64 T2_;
	result = (NI)0;
	T1_ = (NU64)0;
	T1_ = hiXorLo__pureZhashes_79(11562461410679940143ULL, (NU64)(x ^ 16646288086500911323ULL));
	T2_ = (NU64)0;
	T2_ = hiXorLo__pureZhashes_79(T1_, 16952864883938283885ULL);
	result = ((NI) (T2_));
	return result;
}
static N_INLINE(NI, hash__ast_784)(NI32 x) {
	NI result;
	result = (NI)0;
	result = hashWangYi1__pureZhashes_136(((NU64) (x)));
	return result;
}
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_31)(NI hcode) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = !((hcode == ((NI) 0)));
	return result;
}
static N_INLINE(NI, nextTry__pureZcollectionsZtables_34)(NI h, NI maxHash) {
	NI result;
	result = (NI)0;
	result = (NI)((NI)(h + ((NI) 1)) & maxHash);
	return result;
}
static N_INLINE(NI, rawGet__cgen_27608)(tyObject_Table__imojfg883tkWsWJwyshGqQ t, NI32 key, NI* hc) {
	NI result;
	NI h;
	NI T10_;
{	result = (NI)0;
	(*hc) = hash__ast_784(key);
	{
		if (!((*hc) == ((NI) 0))) goto LA3_;
		(*hc) = ((NI) 314159265);
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (t.data ? t.data->Sup.len : 0);
		if (!(T7_ == ((NI) 0))) goto LA8_;
		result = ((NI) -1);
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)((*hc) & T10_);
	{
		while (1) {
			NIM_BOOL T13_;
			NI T20_;
			T13_ = (NIM_BOOL)0;
			T13_ = isFilled__pureZcollectionsZtables_31(t.data->data[h].Field0);
			if (!T13_) goto LA12;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = (t.data->data[h].Field0 == (*hc));
				if (!(T16_)) goto LA17_;
				T16_ = (t.data->data[h].Field1 == key);
				LA17_: ;
				if (!T16_) goto LA18_;
				result = h;
				goto BeforeRet_;
			}
			LA18_: ;
			T20_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__pureZcollectionsZtables_34(h, T20_);
		} LA12: ;
	}
	result = (NI)(((NI) -1) - h);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, registerModuleToMain__cgen_27580)(tyObject_BModuleListcolonObjectType___9c4b0IbdzIJRabh100GyFtA* g, tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* init;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* datInit;
{	init = getInitName__cgen_27174(m);
	datInit = getDatInitName__cgen_27181(m);
	{
		NIM_BOOL T3_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* hcrModuleMeta;
		tyArray__dAmhZbEWrTM5xES2bTVweg T6_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* systemModulePath;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* mainModulePath;
		NI hcX60gensym6450_;
		NI indexX60gensym6450_;
		NIM_BOOL hasKeyX60gensym6450_;
		tyArray__dAmhZbEWrTM5xES2bTVweg T23_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T24_;
		tyArray__dAmhZbEWrTM5xES2bTVweg T25_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T26_;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T27_;
		tyArray__qtqsWM5aXmcpMIVmvq3kAA T28_;
		NimStringDesc* T29_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T30_;
		T3_ = (NIM_BOOL)0;
		T3_ = hcrOn__cgen_43(m);
		if (!T3_) goto LA4_;
		nimZeroMem((void*)T6_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		hcrModuleMeta = percent___cgen_27585(T6_, 0);
		systemModulePath = getModuleDllPath__cgen_142(m, (*(*g).modules->data[(*(*(*g).graph).config).m.systemFileIdx]).module);
		mainModulePath = getModuleDllPath__cgen_142(m, (*m).module);
		{
			tyArray__ts9cf9blICas1QWmw89bglZ7w T11_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
			if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 14))&63U)))!=0)) goto LA9_;
			nimZeroMem((void*)T11_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T11_[0] = systemModulePath;
			T12_ = NIM_NIL;
			T12_ = percent___cgen_27597(T11_, 1);
			add__ropes_159(&hcrModuleMeta, T12_);
		}
		LA9_: ;
		hcX60gensym6450_ = (NI)0;
		indexX60gensym6450_ = rawGet__cgen_27608((*(*g).graph).importDeps, ((NI32) ((*(*m).module).position)), (&hcX60gensym6450_));
		hasKeyX60gensym6450_ = (((NI) 0) <= indexX60gensym6450_);
		{
			tySequence__48JTohSgTy339bRxHzUD8KA** deps;
			if (!hasKeyX60gensym6450_) goto LA15_;
			deps = (&(*(*g).graph).importDeps.data->data[indexX60gensym6450_].Field2);
			{
				NI32* curr;
				NI i;
				NI L;
				NI T18_;
				curr = (NI32*)0;
				i = ((NI) 0);
				T18_ = ((*deps) ? (*deps)->Sup.len : 0);
				L = T18_;
				{
					while (1) {
						tyArray__ts9cf9blICas1QWmw89bglZ7w T21_;
						tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T22_;
						if (!(i < L)) goto LA20;
						curr = (&(*deps)->data[i]);
						nimZeroMem((void*)T21_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
						T21_[0] = getModuleDllPath__cgen_142(m, (*(*g).modules->data[(*curr)]).module);
						T22_ = NIM_NIL;
						T22_ = percent___cgen_27597(T21_, 1);
						add__ropes_159(&hcrModuleMeta, T22_);
						i += ((NI) 1);
					} LA20: ;
				}
			}
		}
		LA15_: ;
		nimZeroMem((void*)T23_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		T24_ = NIM_NIL;
		T24_ = percent___cgen_27929(T23_, 0);
		add__ropes_159(&hcrModuleMeta, T24_);
		nimZeroMem((void*)T25_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		T26_ = NIM_NIL;
		T26_ = percent___cgen_27934(T25_, 0);
		add__ropes_159(&hcrModuleMeta, T26_);
		nimZeroMem((void*)T27_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		nimZeroMem((void*)T28_, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
		sigHash__sighashes_535((*m).module, (*(*m).g).config, T28_);
		T29_ = NIM_NIL;
		T29_ = dollar___modulegraphs_8985(T28_);
		T27_[0] = rope__ropes_109(T29_);
		T30_ = NIM_NIL;
		T30_ = percent___cgen_27939(T27_, 1);
		add__ropes_159(&hcrModuleMeta, T30_);
		{
			tyArray__dAmhZbEWrTM5xES2bTVweg T35_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T36_;
			tyArray__ts9cf9blICas1QWmw89bglZ7w T37_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
			tyArray__ts9cf9blICas1QWmw89bglZ7w T39_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T40_;
			tyArray__ts9cf9blICas1QWmw89bglZ7w T41_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T42_;
			tyArray__dAmhZbEWrTM5xES2bTVweg T43_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T44_;
			tyArray__ts9cf9blICas1QWmw89bglZ7w T45_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T46_;
			tyArray__FKvM4FDhljtt88k8FkGthA T47_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T48_;
			tyArray__ts9cf9blICas1QWmw89bglZ7w T49_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T50_;
			tyArray__ts9cf9blICas1QWmw89bglZ7w T51_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T52_;
			tyArray__dAmhZbEWrTM5xES2bTVweg T53_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T54_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* osModulePath;
			NimStringDesc* T55_;
			NimStringDesc* T56_;
			tyArray__ts9cf9blICas1QWmw89bglZ7w T57_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T58_;
			tyArray__ts9cf9blICas1QWmw89bglZ7w T59_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T60_;
			tyArray__ts9cf9blICas1QWmw89bglZ7w T61_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T62_;
			if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 14))&63U)))!=0)) goto LA33_;
			add__ropes_159(&(*g).mainModProcs, hcrModuleMeta);
			nimZeroMem((void*)T35_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
			T36_ = NIM_NIL;
			T36_ = percent___cgen_27948(T35_, 0);
			add__ropes_159(&(*g).mainModProcs, T36_);
			nimZeroMem((void*)T37_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T37_[0] = init;
			T38_ = NIM_NIL;
			T38_ = percent___cgen_27953(T37_, 1);
			add__ropes_159(&(*g).mainModProcs, T38_);
			nimZeroMem((void*)T39_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T39_[0] = datInit;
			T40_ = NIM_NIL;
			T40_ = percent___cgen_27953(T39_, 1);
			add__ropes_159(&(*g).mainModProcs, T40_);
			nimZeroMem((void*)T41_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T41_[0] = getHcrInitName__cgen_27184(m);
			T42_ = NIM_NIL;
			T42_ = percent___cgen_27962(T41_, 1);
			add__ropes_159(&(*g).mainModProcs, T42_);
			nimZeroMem((void*)T43_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
			T44_ = NIM_NIL;
			T44_ = percent___cgen_27967(T43_, 0);
			add__ropes_159(&(*g).mainModProcs, T44_);
			nimZeroMem((void*)T45_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T45_[0] = init;
			T46_ = NIM_NIL;
			T46_ = percent___cgen_27522(T45_, 1);
			add__ropes_159(&(*g).mainModInit, T46_);
			nimZeroMem((void*)T47_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
			T47_[0] = mainModulePath;
			T47_[1] = systemModulePath;
			T47_[2] = datInit;
			T48_ = NIM_NIL;
			T48_ = percent___cgen_27976(T47_, 3);
			add__ropes_159(&(*g).otherModsInit, T48_);
			nimZeroMem((void*)T49_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T49_[0] = getHcrInitName__cgen_27184(m);
			T50_ = NIM_NIL;
			T50_ = percent___cgen_27981(T49_, 1);
			add__ropes_159(&(*g).mainDatInit, T50_);
			nimZeroMem((void*)T51_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T51_[0] = mainModulePath;
			T52_ = NIM_NIL;
			T52_ = percent___cgen_27986(T51_, 1);
			add__ropes_159(&(*g).mainDatInit, T52_);
			nimZeroMem((void*)T53_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
			T54_ = NIM_NIL;
			T54_ = percent___cgen_27991(T53_, 0);
			add__ropes_159(&(*g).mainDatInit, T54_);
			T55_ = NIM_NIL;
			T55_ = dollar___ropes_250(systemModulePath);
			T56_ = NIM_NIL;
			T56_ = nsuReplaceStr(T55_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_888), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_889));
			osModulePath = rope__ropes_109(T56_);
			nimZeroMem((void*)T57_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T57_[0] = osModulePath;
			T58_ = NIM_NIL;
			T58_ = percent___cgen_27986(T57_, 1);
			add__ropes_159(&(*g).mainDatInit, T58_);
			add__ropes_162(&(*g).mainDatInit, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_890));
			add__ropes_162(&(*g).mainDatInit, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_891));
			nimZeroMem((void*)T59_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T59_[0] = osModulePath;
			T60_ = NIM_NIL;
			T60_ = percent___cgen_28001(T59_, 1);
			add__ropes_159(&(*g).mainDatInit, T60_);
			nimZeroMem((void*)T61_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
			T61_[0] = osModulePath;
			T62_ = NIM_NIL;
			T62_ = percent___cgen_28006(T61_, 1);
			add__ropes_159(&(*g).mainDatInit, T62_);
			add__ropes_162(&(*g).mainDatInit, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_892));
			add__ropes_162(&(*g).mainDatInit, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_893));
		}
		goto LA31_;
		LA33_: ;
		{
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 12))- 0], hcrModuleMeta);
		}
		LA31_: ;
		goto BeforeRet_;
	}
	LA4_: ;
	{
		NI T66_;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T69_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T70_;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T71_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T72_;
		T66_ = (NI)0;
		T66_ = len__ropes_10((*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 13))- 0]);
		if (!(((NI) 0) < T66_)) goto LA67_;
		nimZeroMem((void*)T69_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T69_[0] = datInit;
		T70_ = NIM_NIL;
		T70_ = percent___cgen_27517(T69_, 1);
		add__ropes_159(&(*g).mainModProcs, T70_);
		nimZeroMem((void*)T71_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T71_[0] = datInit;
		T72_ = NIM_NIL;
		T72_ = percent___cgen_27522(T71_, 1);
		add__ropes_159(&(*g).mainDatInit, T72_);
	}
	LA67_: ;
	{
		if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 15))&63U)))!=0)) goto LA75_;
		{
			NIM_BOOL T79_;
			NimStringDesc* res;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T83_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T84_;
			T79_ = (NIM_BOOL)0;
			T79_ = emulatedThreadVars__cgen_419((*(*m).g).config);
			if (!(T79_)) goto LA80_;
			T79_ = !(((*(*(*m).g).config).target.targetOS == ((tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw) 29)));
			LA80_: ;
			if (!T79_) goto LA81_;
			res = rawNewString(((NI) 80));
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_6));
			T83_ = NIM_NIL;
			T83_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_864));
			cgFormatValue__cgen_147((&res), T83_);
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_894));
			T84_ = NIM_NIL;
			T84_ = rope__ropes_109(res);
			add__ropes_159(&(*g).mainDatInit, T84_);
		}
		LA81_: ;
		{
			NIM_BOOL T87_;
			NimStringDesc* res_2;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T91_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T92_;
			T87_ = (NIM_BOOL)0;
			T87_ = !(((*(*(*m).g).config).target.targetOS == ((tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw) 29)));
			if (!(T87_)) goto LA88_;
			T87_ = !(((50 &((NU16)1<<((NU)((*(*(*m).g).config).selectedGC)&15U)))!=0));
			LA88_: ;
			if (!T87_) goto LA89_;
			res_2 = rawNewString(((NI) 80));
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_6));
			T91_ = NIM_NIL;
			T91_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_863));
			cgFormatValue__cgen_147((&res_2), T91_);
			res_2 = resizeString(res_2, 18);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_895));
			T92_ = NIM_NIL;
			T92_ = rope__ropes_109(res_2);
			add__ropes_159(&(*g).mainDatInit, T92_);
		}
		LA89_: ;
	}
	LA75_: ;
	{
		NI T95_;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T98_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T99_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* initCall;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T100_;
		T95_ = (NI)0;
		T95_ = len__ropes_10((*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 12))- 0]);
		if (!(((NI) 0) < T95_)) goto LA96_;
		nimZeroMem((void*)T98_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T98_[0] = init;
		T99_ = NIM_NIL;
		T99_ = percent___cgen_27517(T98_, 1);
		add__ropes_159(&(*g).mainModProcs, T99_);
		nimZeroMem((void*)T100_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T100_[0] = init;
		initCall = percent___cgen_27522(T100_, 1);
		{
			if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 14))&63U)))!=0)) goto LA103_;
			add__ropes_159(&(*g).mainModInit, initCall);
		}
		goto LA101_;
		LA103_: ;
		{
			if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 15))&63U)))!=0)) goto LA106_;
			add__ropes_159(&(*g).mainDatInit, initCall);
		}
		goto LA101_;
		LA106_: ;
		{
			add__ropes_159(&(*g).otherModsInit, initCall);
		}
		LA101_: ;
	}
	LA96_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genInitCode__cgen_28147)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m) {
	NIM_BOOL moduleInitRequired;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* initname;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* prc;
	tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T1_;
	NimStringDesc* T2_;
	tyArray__dAmhZbEWrTM5xES2bTVweg T109_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T110_;
	tyArray__dAmhZbEWrTM5xES2bTVweg T213_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T214_;
	tyArray__dAmhZbEWrTM5xES2bTVweg T215_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T216_;
	moduleInitRequired = hcrOn__cgen_43(m);
	initname = getInitName__cgen_27174(m);
	nimZeroMem((void*)T1_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
	T2_ = NIM_NIL;
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = hcrOn__cgen_43(m);
		if (!T5_) goto LA6_;
		T2_ = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_869));
	}
	goto LA3_;
	LA6_: ;
	{
		T2_ = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_870));
	}
	LA3_: ;
	T1_[0] = rope__ropes_109(T2_);
	T1_[1] = initname;
	prc = percent___cgen_28082(T1_, 2);
	genCLineDir__cgen_340(&prc, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_871), ((NI) 999999), (*(*m).g).config);
	{
		if (!(((NI) 0) < (*m).typeNodes)) goto LA11_;
		{
			NIM_BOOL T15_;
			NimStringDesc* res;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
			NimStringDesc* res_2;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T21_;
			T15_ = (NIM_BOOL)0;
			T15_ = hcrOn__cgen_43(m);
			if (!T15_) goto LA16_;
			res = rawNewString(((NI) 80));
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_6));
			T18_ = NIM_NIL;
			T18_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_143));
			cgFormatValue__cgen_147((&res), T18_);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_872));
			cgFormatValue__cgen_147((&res), (*m).typeNodesName);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_380));
			T19_ = NIM_NIL;
			T19_ = rope__ropes_109(res);
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 14))- 0], T19_);
			res_2 = rawNewString(((NI) 80));
			res_2 = resizeString(res_2, 19);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_873));
			T20_ = NIM_NIL;
			T20_ = getModuleDllPath__cgen_142(m, (*m).module);
			cgFormatValue__cgen_147((&res_2), T20_);
			res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_408));
			cgFormatValue__cgen_147((&res_2), (*m).typeNodesName);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_3));
			cgFormatValue__cgen_154((&res_2), ((NI64) ((*m).typeNodes)));
			res_2 = resizeString(res_2, 22);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_874));
			cgFormatValue__cgen_154((&res_2), ((NI64) ((*m).typeNodes)));
			res_2 = resizeString(res_2, 17);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_875));
			cgFormatValue__cgen_147((&res_2), (*m).typeNodesName);
			res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_764));
			T21_ = NIM_NIL;
			T21_ = rope__ropes_109(res_2);
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 14))- 0], T21_);
		}
		goto LA13_;
		LA16_: ;
		{
			NimStringDesc* res_3;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T23_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T28_;
			res_3 = rawNewString(((NI) 80));
			res_3 = resizeString(res_3, 7);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_64));
			T23_ = NIM_NIL;
			T23_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_143));
			cgFormatValue__cgen_147((&res_3), T23_);
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_13));
			cgFormatValue__cgen_147((&res_3), (*m).typeNodesName);
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_166));
			cgFormatValue__cgen_154((&res_3), ((NI64) ((*m).typeNodes)));
			res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_226));
			{
				if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA26_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
			}
			LA26_: ;
			T28_ = NIM_NIL;
			T28_ = rope__ropes_109(res_3);
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 14))- 0], T28_);
		}
		LA13_: ;
	}
	LA11_: ;
	{
		NimStringDesc* res_4;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T33_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T38_;
		if (!(((NI) 0) < (*m).nimTypes)) goto LA31_;
		res_4 = rawNewString(((NI) 80));
		res_4 = resizeString(res_4, 7);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_64));
		T33_ = NIM_NIL;
		T33_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_142));
		cgFormatValue__cgen_147((&res_4), T33_);
		res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_13));
		cgFormatValue__cgen_147((&res_4), (*m).nimTypesName);
		res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_166));
		cgFormatValue__cgen_154((&res_4), ((NI64) ((*m).nimTypes)));
		res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_226));
		{
			if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA36_;
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
		}
		LA36_: ;
		T38_ = NIM_NIL;
		T38_ = rope__ropes_109(res_4);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 14))- 0], T38_);
	}
	LA31_: ;
	{
		NIM_BOOL T41_;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T44_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T45_;
		T41_ = (NIM_BOOL)0;
		T41_ = hcrOn__cgen_43(m);
		if (!T41_) goto LA42_;
		nimZeroMem((void*)T44_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T44_[0] = getModuleDllPath__cgen_142(m, (*m).module);
		T45_ = NIM_NIL;
		T45_ = percent___cgen_28200(T44_, 1);
		add__ropes_159(&prc, T45_);
	}
	LA42_: ;
	{
		NIM_BOOL T48_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T49_;
		NI T50_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T52_;
		NI T53_;
		tyArray__dAmhZbEWrTM5xES2bTVweg T56_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T57_;
		tyArray__dAmhZbEWrTM5xES2bTVweg T58_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T59_;
		tyArray__dAmhZbEWrTM5xES2bTVweg T107_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T108_;
		T48_ = (NIM_BOOL)0;
		T49_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T49_ = s__cgendata_225((*m).preInitProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 1));
		T50_ = (NI)0;
		T50_ = len__ropes_10((*T49_));
		T48_ = (((NI) 0) < T50_);
		if (T48_) goto LA51_;
		T52_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T52_ = s__cgendata_225((*m).preInitProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		T53_ = (NI)0;
		T53_ = len__ropes_10((*T52_));
		T48_ = (((NI) 0) < T53_);
		LA51_: ;
		if (!T48_) goto LA54_;
		nimZeroMem((void*)T56_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		T57_ = NIM_NIL;
		T57_ = percent___cgen_28209(T56_, 0);
		add__ropes_159(&prc, T57_);
		nimZeroMem((void*)T58_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		T59_ = NIM_NIL;
		T59_ = percent___cgen_28214(T58_, 0);
		add__ropes_159(&prc, T59_);
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T62_;
			NI T63_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T70_;
			T62_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T62_ = s__cgendata_225((*m).preInitProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
			T63_ = (NI)0;
			T63_ = len__ropes_10((*T62_));
			if (!(((NI) 0) < T63_)) goto LA64_;
			moduleInitRequired = NIM_TRUE;
			{
				if (!NIM_FALSE) goto LA68_;
				add__ropes_162(&prc, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_876));
			}
			LA68_: ;
			T70_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T70_ = s__cgendata_225((*m).preInitProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
			add__ropes_159(&prc, (*T70_));
			{
				if (!NIM_FALSE) goto LA73_;
				add__ropes_162(&prc, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_877));
			}
			LA73_: ;
		}
		LA64_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T77_;
			NI T78_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T86_;
			T77_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T77_ = s__cgendata_225((*m).preInitProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 1));
			T78_ = (NI)0;
			T78_ = len__ropes_10((*T77_));
			if (!(((NI) 0) < T78_)) goto LA79_;
			moduleInitRequired = NIM_TRUE;
			{
				NIM_BOOL T83_;
				T83_ = (NIM_BOOL)0;
				T83_ = hcrOn__cgen_43(m);
				if (!T83_) goto LA84_;
				add__ropes_162(&prc, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_876));
			}
			LA84_: ;
			T86_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T86_ = s__cgendata_225((*m).preInitProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 1));
			add__ropes_159(&prc, (*T86_));
			{
				NIM_BOOL T89_;
				T89_ = (NIM_BOOL)0;
				T89_ = hcrOn__cgen_43(m);
				if (!T89_) goto LA90_;
				add__ropes_162(&prc, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_877));
			}
			LA90_: ;
		}
		LA79_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T94_;
			NI T95_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T102_;
			T94_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T94_ = s__cgendata_225((*m).preInitProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			T95_ = (NI)0;
			T95_ = len__ropes_10((*T94_));
			if (!(((NI) 0) < T95_)) goto LA96_;
			moduleInitRequired = NIM_TRUE;
			{
				if (!NIM_FALSE) goto LA100_;
				add__ropes_162(&prc, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_876));
			}
			LA100_: ;
			T102_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T102_ = s__cgendata_225((*m).preInitProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			add__ropes_159(&prc, (*T102_));
			{
				if (!NIM_FALSE) goto LA105_;
				add__ropes_162(&prc, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_877));
			}
			LA105_: ;
		}
		LA96_: ;
		nimZeroMem((void*)T107_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		T108_ = NIM_NIL;
		T108_ = percent___cgen_28219(T107_, 0);
		add__ropes_159(&prc, T108_);
	}
	LA54_: ;
	nimZeroMem((void*)T109_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
	T110_ = NIM_NIL;
	T110_ = percent___cgen_28209(T109_, 0);
	add__ropes_159(&prc, T110_);
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T113_;
		NI T114_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T121_;
		T113_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T113_ = s__cgendata_225((*m).initProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
		T114_ = (NI)0;
		T114_ = len__ropes_10((*T113_));
		if (!(((NI) 0) < T114_)) goto LA115_;
		moduleInitRequired = NIM_TRUE;
		{
			if (!NIM_FALSE) goto LA119_;
			add__ropes_162(&prc, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_876));
		}
		LA119_: ;
		T121_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T121_ = s__cgendata_225((*m).initProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 0));
		add__ropes_159(&prc, (*T121_));
		{
			if (!NIM_FALSE) goto LA124_;
			add__ropes_162(&prc, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_877));
		}
		LA124_: ;
	}
	LA115_: ;
	{
		NIM_BOOL T128_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T129_;
		NI T130_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T132_;
		NI T133_;
		T128_ = (NIM_BOOL)0;
		T129_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T129_ = s__cgendata_225((*m).initProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 1));
		T130_ = (NI)0;
		T130_ = len__ropes_10((*T129_));
		T128_ = (((NI) 0) < T130_);
		if (T128_) goto LA131_;
		T132_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T132_ = s__cgendata_225((*m).initProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		T133_ = (NI)0;
		T133_ = len__ropes_10((*T132_));
		T128_ = (((NI) 0) < T133_);
		LA131_: ;
		if (!T128_) goto LA134_;
		moduleInitRequired = NIM_TRUE;
		{
			NIM_BOOL T138_;
			T138_ = (NIM_BOOL)0;
			T138_ = (((*(*m).initProc).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 17))&31U)))!=0);
			if (!(T138_)) goto LA139_;
			T138_ = !((((*m).flags &((NU8)1<<((NU)(((tyEnum_CodegenFlag__vPx29bHhk9a7V50u1UO0rM4w) 2))&7U)))!=0));
			LA139_: ;
			if (!T138_) goto LA140_;
			(*m).flags |= ((NU8)1)<<((((tyEnum_CodegenFlag__vPx29bHhk9a7V50u1UO0rM4w) 2)) & 7);
			{
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* procname;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T146_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T147_;
				if (!!((((*m).flags &((NU8)1<<((NU)(((tyEnum_CodegenFlag__vPx29bHhk9a7V50u1UO0rM4w) 0))&7U)))!=0))) goto LA144_;
				procname = makeCString__msgs_50((*(*(*m).module).name).s);
				T146_ = NIM_NIL;
				T146_ = quotedFilename__msgs_1473((*(*m).g).config, (*(*m).module).info);
				T147_ = NIM_NIL;
				T147_ = initFrame__cgen_17621((*m).initProc, procname, T146_);
				add__ropes_159(&prc, T147_);
			}
			goto LA142_;
			LA144_: ;
			{
				tyArray__dAmhZbEWrTM5xES2bTVweg T149_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T150_;
				nimZeroMem((void*)T149_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
				T150_ = NIM_NIL;
				T150_ = percent___cgen_28214(T149_, 0);
				add__ropes_159(&prc, T150_);
			}
			LA142_: ;
		}
		LA140_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T153_;
			NI T154_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T162_;
			T153_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T153_ = s__cgendata_225((*m).initProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 1));
			T154_ = (NI)0;
			T154_ = len__ropes_10((*T153_));
			if (!(((NI) 0) < T154_)) goto LA155_;
			moduleInitRequired = NIM_TRUE;
			{
				NIM_BOOL T159_;
				T159_ = (NIM_BOOL)0;
				T159_ = hcrOn__cgen_43(m);
				if (!T159_) goto LA160_;
				add__ropes_162(&prc, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_876));
			}
			LA160_: ;
			T162_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T162_ = s__cgendata_225((*m).initProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 1));
			add__ropes_159(&prc, (*T162_));
			{
				NIM_BOOL T165_;
				T165_ = (NIM_BOOL)0;
				T165_ = hcrOn__cgen_43(m);
				if (!T165_) goto LA166_;
				add__ropes_162(&prc, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_877));
			}
			LA166_: ;
		}
		LA155_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T170_;
			NI T171_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T178_;
			T170_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T170_ = s__cgendata_225((*m).initProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			T171_ = (NI)0;
			T171_ = len__ropes_10((*T170_));
			if (!(((NI) 0) < T171_)) goto LA172_;
			moduleInitRequired = NIM_TRUE;
			{
				if (!NIM_FALSE) goto LA176_;
				add__ropes_162(&prc, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_876));
			}
			LA176_: ;
			T178_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
			T178_ = s__cgendata_225((*m).initProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
			add__ropes_159(&prc, (*T178_));
			{
				if (!NIM_FALSE) goto LA181_;
				add__ropes_162(&prc, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_877));
			}
			LA181_: ;
		}
		LA172_: ;
		{
			tyArray__dAmhZbEWrTM5xES2bTVweg T187_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T188_;
			if (!(((*(*m).initProc).flags &((NU8)1<<((NU)(((tyEnum_TCProcFlag__Iv1wQAvkoMCW3v9cTnZWvJw) 0))&7U)))!=0)) goto LA185_;
			nimZeroMem((void*)T187_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
			T188_ = NIM_NIL;
			T188_ = percent___cgen_28253(T187_, 0);
			add__ropes_159(&prc, T188_);
		}
		LA185_: ;
		{
			NIM_BOOL T191_;
			T191_ = (NIM_BOOL)0;
			T191_ = (((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 14))&63U)))!=0);
			if (!(T191_)) goto LA192_;
			T191_ = ((*(*(*m).g).config).exc == ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 3));
			LA192_: ;
			if (!T191_) goto LA193_;
			{
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T197_;
				NimStringDesc* res_5;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T200_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T205_;
				T197_ = NIM_NIL;
				T197_ = getCompilerProc__magicsys_145((*(*m).g).graph, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_859));
				if (!!((T197_ == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA198_;
				res_5 = rawNewString(((NI) 80));
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_6));
				T200_ = NIM_NIL;
				T200_ = cgsym__cgen_126(m, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_859));
				cgFormatValue__cgen_147((&res_5), T200_);
				res_5 = resizeString(res_5, 3);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_312));
				{
					if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0))) goto LA203_;
					res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
				}
				LA203_: ;
				T205_ = NIM_NIL;
				T205_ = rope__ropes_109(res_5);
				add__ropes_159(&prc, T205_);
			}
			LA198_: ;
		}
		LA193_: ;
		{
			NIM_BOOL T208_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T212_;
			T208_ = (NIM_BOOL)0;
			T208_ = (((*(*m).initProc).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 17))&31U)))!=0);
			if (!(T208_)) goto LA209_;
			T208_ = !((((*m).flags &((NU8)1<<((NU)(((tyEnum_CodegenFlag__vPx29bHhk9a7V50u1UO0rM4w) 0))&7U)))!=0));
			LA209_: ;
			if (!T208_) goto LA210_;
			T212_ = NIM_NIL;
			T212_ = deinitFrame__cgen_17691((*m).initProc);
			add__ropes_159(&prc, T212_);
		}
		LA210_: ;
	}
	LA134_: ;
	nimZeroMem((void*)T213_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
	T214_ = NIM_NIL;
	T214_ = percent___cgen_26482(T213_, 0);
	add__ropes_159(&prc, T214_);
	nimZeroMem((void*)T215_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
	T216_ = NIM_NIL;
	T216_ = percent___cgen_28093(T215_, 0);
	add__ropes_159(&prc, T216_);
	{
		NIM_BOOL T219_;
		tySequence__sM4lkSb7zS6F7OVMvW9cffQ* procsToLoad;
		NimStringDesc* T222_;
		NimStringDesc* T223_;
		NimStringDesc* T224_;
		NimStringDesc* T225_;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T226_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T227_;
		tyArray__dAmhZbEWrTM5xES2bTVweg T241_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T242_;
		T219_ = (NIM_BOOL)0;
		T219_ = hcrOn__cgen_43(m);
		if (!T219_) goto LA220_;
		procsToLoad = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) newSeq((&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_), 4);
		T222_ = NIM_NIL;
		T222_ = procsToLoad->data[0]; procsToLoad->data[0] = copyStringRC1(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_878));
		if (T222_) nimGCunrefNoCycle(T222_);
		T223_ = NIM_NIL;
		T223_ = procsToLoad->data[1]; procsToLoad->data[1] = copyStringRC1(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_879));
		if (T223_) nimGCunrefNoCycle(T223_);
		T224_ = NIM_NIL;
		T224_ = procsToLoad->data[2]; procsToLoad->data[2] = copyStringRC1(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_880));
		if (T224_) nimGCunrefNoCycle(T224_);
		T225_ = NIM_NIL;
		T225_ = procsToLoad->data[3]; procsToLoad->data[3] = copyStringRC1(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_881));
		if (T225_) nimGCunrefNoCycle(T225_);
		nimZeroMem((void*)T226_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T226_[0] = getHcrInitName__cgen_27184(m);
		T227_ = NIM_NIL;
		T227_ = percent___cgen_28304(T226_, 1);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 12))- 0], T227_);
		{
			NI T232_;
			NimStringDesc* T233_;
			NI T234_;
			NimStringDesc* T235_;
			if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 14))&63U)))!=0)) goto LA230_;
			procsToLoad = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)(procsToLoad), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_));
			T232_ = procsToLoad->Sup.len++;
			T233_ = NIM_NIL;
			T233_ = procsToLoad->data[T232_]; procsToLoad->data[T232_] = copyStringRC1(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_883));
			if (T233_) nimGCunrefNoCycle(T233_);
			procsToLoad = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)(procsToLoad), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_));
			T234_ = procsToLoad->Sup.len++;
			T235_ = NIM_NIL;
			T235_ = procsToLoad->data[T234_]; procsToLoad->data[T234_] = copyStringRC1(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_884));
			if (T235_) nimGCunrefNoCycle(T235_);
		}
		LA230_: ;
		{
			NimStringDesc** curr;
			NI i;
			NI L;
			NI T237_;
			curr = (NimStringDesc**)0;
			i = ((NI) 0);
			T237_ = (procsToLoad ? procsToLoad->Sup.len : 0);
			L = T237_;
			{
				while (1) {
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T240_;
					if (!(i < L)) goto LA239;
					curr = (&procsToLoad->data[i]);
					T240_ = NIM_NIL;
					T240_ = hcrGetProcLoadCode__cgen_27187(m, (*curr), ((NimStringDesc*) NIM_NIL), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_885), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_886));
					add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 12))- 0], T240_);
					i += ((NI) 1);
				} LA239: ;
			}
		}
		nimZeroMem((void*)T241_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		T242_ = NIM_NIL;
		T242_ = percent___cgen_28093(T241_, 0);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 12))- 0], T242_);
	}
	LA220_: ;
	{
		NIM_CHAR i_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* el;
		NIM_CHAR i_3;
		i_2 = (NIM_CHAR)0;
		el = NIM_NIL;
		i_3 = 48;
		{
			while (1) {
				i_2 = i_3;
				el = (*m).extensionLoaders[(((NU8)(i_3)))- 48];
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* ex;
					tyArray__o0h2w7RqUVr9aUhiJaoJjoQ T250_;
					if (!!((el == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA248_;
					nimZeroMem((void*)T250_, sizeof(tyArray__o0h2w7RqUVr9aUhiJaoJjoQ));
					T250_[0] = rope__ropes_115(((NI64) ((NI)(((NU8)(i_2)) - ((NI) 48)))));
					T250_[1] = el;
					ex = percent___cgen_28429(T250_, 2);
					moduleInitRequired = NIM_TRUE;
					add__ropes_159(&prc, ex);
				}
				LA248_: ;
				{
					if (!((NU8)(57) <= (NU8)(((NIM_CHAR) (((NU8)(i_3))))))) goto LA253_;
					goto LA244;
				}
				LA253_: ;
				i_3 += ((NI) 1);
			}
		} LA244: ;
	}
	{
		NIM_BOOL T257_;
		T257_ = (NIM_BOOL)0;
		T257_ = moduleInitRequired;
		if (T257_) goto LA258_;
		T257_ = (((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 14))&63U)))!=0);
		LA258_: ;
		if (!T257_) goto LA259_;
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 12))- 0], prc);
	}
	LA259_: ;
	genDatInitCode__cgen_28079(m);
	{
		NIM_BOOL T263_;
		tyArray__dAmhZbEWrTM5xES2bTVweg T266_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T267_;
		tyArray__dAmhZbEWrTM5xES2bTVweg T268_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T269_;
		T263_ = (NIM_BOOL)0;
		T263_ = hcrOn__cgen_43(m);
		if (!T263_) goto LA264_;
		nimZeroMem((void*)T266_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		T267_ = NIM_NIL;
		T267_ = percent___cgen_28439(T266_, 0);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 12))- 0], T267_);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 12))- 0], (*m).hcrCreateTypeInfosProc);
		nimZeroMem((void*)T268_, sizeof(tyArray__dAmhZbEWrTM5xES2bTVweg));
		T269_ = NIM_NIL;
		T269_ = percent___cgen_28093(T268_, 0);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 12))- 0], T269_);
	}
	LA264_: ;
	registerModuleToMain__cgen_27580((*m).g, m);
}
N_LIB_PRIVATE N_NIMCALL(void, seqV2ContentType__cgen_3481)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* check) {
	tyArray__qtqsWM5aXmcpMIVmvq3kAA sig;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	nimZeroMem((void*)sig, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
	hashType__sighashes_473(t, (*(*m).g).config, 2, sig);
	result = cacheGetType__cgen_1380((*m).typeCache, sig);
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
		if (!(result == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = getTypeDescAux__cgen_1332(m, t, check, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
		(void)(T5_);
	}
	goto LA1_;
	LA3_: ;
	{
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T9_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
		res = rawNewString(((NI) 80));
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_896));
		T7_ = NIM_NIL;
		T7_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_897));
		cgFormatValue__cgen_147((&res), T7_);
		res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_898));
		cgFormatValue__cgen_147((&res), result);
		res = resizeString(res, 12);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_899));
		T8_ = NIM_NIL;
		T8_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_897));
		cgFormatValue__cgen_147((&res), T8_);
		res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_900));
		cgFormatValue__cgen_147((&res), result);
		res = resizeString(res, 19);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_901));
		cgFormatValue__cgen_147((&res), result);
		res = resizeString(res, 19);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_902));
		T9_ = NIM_NIL;
		T9_ = skipTypes__ast_3723(t, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
		T10_ = NIM_NIL;
		T10_ = getTypeDescAux__cgen_1332(m, (*T9_).sons->data[((NI) 0)], check, ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
		cgFormatValue__cgen_147((&res), T10_);
		res = resizeString(res, 24);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_903));
		T11_ = NIM_NIL;
		T11_ = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_897));
		cgFormatValue__cgen_147((&res), T11_);
		res = resizeString(res, 13);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_904));
		T12_ = NIM_NIL;
		T12_ = rope__ropes_109(res);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 4))- 0], T12_);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, finishTypeDescriptions__cgen_6711)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m) {
	NI i;
	tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw check;
	i = ((NI) 0);
	nimZeroMem((void*)(&check), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
	initIntSet__pureZcollectionsZintsets_238((&check));
	{
		while (1) {
			NI T3_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
			T3_ = ((*m).typeStack ? (*m).typeStack->Sup.len : 0);
			if (!(i < T3_)) goto LA2;
			t = (*m).typeStack->data[i];
			{
				NIM_BOOL T6_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T8_;
				T6_ = (NIM_BOOL)0;
				T6_ = (((*(*(*m).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0);
				if (!(T6_)) goto LA7_;
				T8_ = NIM_NIL;
				T8_ = skipTypes__ast_3723(t, TM__9bddtAaa9cYLwzzzlT9aJ5CKw_74);
				T6_ = ((*T8_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24));
				LA7_: ;
				if (!T6_) goto LA9_;
				seqV2ContentType__cgen_3481(m, t, (&check));
			}
			goto LA4_;
			LA9_: ;
			{
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T12_;
				T12_ = NIM_NIL;
				T12_ = getTypeDescAux__cgen_1332(m, t, (&check), ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
				(void)(T12_);
			}
			LA4_: ;
			i += ((NI) 1);
		} LA2: ;
	}
	asgnRef((void**) (&(*m).typeStack), (tySequence__vKogasEnJSPhbQmA8r4Y9aA*) setLengthSeqV2(((*m).typeStack)?&((*m).typeStack)->Sup:NIM_NIL, (&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_), ((NI) 0)));
}
static N_NIMCALL(void, Marker_tyRef__9bbPrOZAgwWihvYGa8yXUow)(void* p, NI op) {
	tyObject_Env_cgendotnim_genMainProc___MH1VwSLIbfCI9coJDTeX9c2Q* a;
	a = (tyObject_Env_cgendotnim_genMainProc___MH1VwSLIbfCI9coJDTeX9c2Q*)p;
	nimGCvisit((void*)(*a).m1, op);
}
N_LIB_PRIVATE N_CLOSURE(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, loadLib__cgen_27196)(NimStringDesc* handle, NimStringDesc* name, void* ClE_0) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_Env_cgendotnim_genMainProc___MH1VwSLIbfCI9coJDTeX9c2Q* colonenvP_;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
	NimStringDesc* res;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T2_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T3_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T4_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
	result = NIM_NIL;
	colonenvP_ = (tyObject_Env_cgendotnim_genMainProc___MH1VwSLIbfCI9coJDTeX9c2Q*) ClE_0;
	prc = getCompilerProc__magicsys_145((*(*(*colonenvP_).m1).g).graph, name);
	n = newStrNode__ast_3801(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20), (*(*(*prc).annex).path)._kind_3.strVal);
	(*n).info = (*(*(*prc).annex).path).info;
	res = rawNewString(((NI) 80));
	res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_906));
	cgFormatValue__cgen_151((&res), handle);
	res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_27));
	T1_ = NIM_NIL;
	T1_ = cgsym__cgen_126((*colonenvP_).m1, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_28));
	cgFormatValue__cgen_147((&res), T1_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
	T2_ = NIM_NIL;
	T2_ = genStringLiteral__cgen_626((*colonenvP_).m1, n);
	cgFormatValue__cgen_147((&res), T2_);
	res = resizeString(res, 6);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_907));
	T3_ = NIM_NIL;
	T3_ = cgsym__cgen_126((*colonenvP_).m1, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_44));
	cgFormatValue__cgen_147((&res), T3_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_26));
	T4_ = NIM_NIL;
	T4_ = genStringLiteral__cgen_626((*colonenvP_).m1, n);
	cgFormatValue__cgen_147((&res), T4_);
	res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_764));
	T5_ = NIM_NIL;
	T5_ = rope__ropes_109(res);
	add__ropes_159(&result, T5_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, closeNamespaceNim__cgen_25933)(void) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_220));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, openNamespaceNim__cgen_25930)(NimStringDesc* namespace_0) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_954));
	add__ropes_162(&result, namespace_0);
	add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_955));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genMainProc__cgen_27193)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m) {
	tyObject_Env_cgendotnim_genMainProc___MH1VwSLIbfCI9coJDTeX9c2Q* colonenv_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* preMainCode;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* posixCmdLine;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* initStackBottomCall;
	colonenv_ = NIM_NIL;
	colonenv_ = (tyObject_Env_cgendotnim_genMainProc___MH1VwSLIbfCI9coJDTeX9c2Q*) newObj((&NTIrefobject__9bbPrOZAgwWihvYGa8yXUow_), sizeof(tyObject_Env_cgendotnim_genMainProc___MH1VwSLIbfCI9coJDTeX9c2Q));
	(*colonenv_).Sup.m_type = (&NTIobject__MH1VwSLIbfCI9coJDTeX9c2Q_);
	asgnRef((void**) (&(*colonenv_).m1), m);
	preMainCode = NIM_NIL;
	{
		NIM_BOOL T3_;
		tyProc__XXidWMaHeMLVIvwr9a5WT9ag T6_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
		tyProc__XXidWMaHeMLVIvwr9a5WT9ag T8_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T9_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
		T3_ = (NIM_BOOL)0;
		T3_ = hcrOn__cgen_43((*colonenv_).m1);
		if (!T3_) goto LA4_;
		nimZeroMem((void*)(&T6_), sizeof(tyProc__XXidWMaHeMLVIvwr9a5WT9ag));
		T6_.ClP_0 = loadLib__cgen_27196; T6_.ClE_0 = colonenv_;
		T7_ = NIM_NIL;
		T7_ = T6_.ClE_0? T6_.ClP_0(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_908), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_879), T6_.ClE_0):((TM__9bddtAaa9cYLwzzzlT9aJ5CKw_909)(T6_.ClP_0))(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_908), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_879));
		add__ropes_159(&preMainCode, T7_);
		add__ropes_162(&preMainCode, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_910));
		nimZeroMem((void*)(&T8_), sizeof(tyProc__XXidWMaHeMLVIvwr9a5WT9ag));
		T8_.ClP_0 = loadLib__cgen_27196; T8_.ClE_0 = colonenv_;
		T9_ = NIM_NIL;
		T9_ = T8_.ClE_0? T8_.ClP_0(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_911), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_912), T8_.ClE_0):((TM__9bddtAaa9cYLwzzzlT9aJ5CKw_913)(T8_.ClP_0))(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_911), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_912));
		add__ropes_159(&preMainCode, T9_);
		T10_ = NIM_NIL;
		T10_ = hcrGetProcLoadCode__cgen_27187((*colonenv_).m1, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_912), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_914), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_911), ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_57));
		add__ropes_159(&preMainCode, T10_);
		add__ropes_162(&preMainCode, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_915));
		add__ropes_162(&preMainCode, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_916));
		add__ropes_162(&preMainCode, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_917));
	}
	goto LA1_;
	LA4_: ;
	{
		tyArray__ts9cf9blICas1QWmw89bglZ7w T12_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
		nimZeroMem((void*)T12_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T12_[0] = rope__ropes_109((*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
		T13_ = NIM_NIL;
		T13_ = percent___cgen_27218(T12_, 1);
		add__ropes_159(&preMainCode, T13_);
	}
	LA1_: ;
	posixCmdLine = NIM_NIL;
	{
		if (!!((((*(*(*(*colonenv_).m1).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 21))&63U)))!=0))) goto LA16_;
		add__ropes_162(&posixCmdLine, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_918));
		add__ropes_162(&posixCmdLine, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_919));
		add__ropes_162(&posixCmdLine, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_920));
	}
	LA16_: ;
	{
		NIM_BOOL T20_;
		T20_ = (NIM_BOOL)0;
		T20_ = ((*(*(*(*colonenv_).m1).g).config).target.targetOS == ((tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw) 2));
		if (!(T20_)) goto LA21_;
		T20_ = !((((*(*(*(*colonenv_).m1).g).config).globalOptions & 640) == 0));
		LA21_: ;
		if (!T20_) goto LA22_;
		includeHeader__cgendata_214((*colonenv_).m1, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_921));
	}
	goto LA18_;
	LA22_: ;
	{
		if (!((*(*(*(*colonenv_).m1).g).config).target.targetOS == ((tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw) 26))) goto LA25_;
		includeHeader__cgendata_214((*colonenv_).m1, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_922));
	}
	goto LA18_;
	LA25_: ;
	LA18_: ;
	{
		NIM_BOOL T29_;
		T29_ = (NIM_BOOL)0;
		T29_ = ((*(*(*(*colonenv_).m1).g).config).target.targetOS == ((tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw) 29));
		if (T29_) goto LA30_;
		T29_ = ((50 &((NU16)1<<((NU)((*(*(*(*colonenv_).m1).g).config).selectedGC)&15U)))!=0);
		LA30_: ;
		if (!T29_) goto LA31_;
		initStackBottomCall = rope__ropes_109(((NimStringDesc*) NIM_NIL));
	}
	goto LA27_;
	LA31_: ;
	{
		NimStringDesc* res;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T34_;
		res = rawNewString(((NI) 80));
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_6));
		T34_ = NIM_NIL;
		T34_ = cgsym__cgen_126((*colonenv_).m1, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_863));
		cgFormatValue__cgen_147((&res), T34_);
		res = resizeString(res, 18);
appendString(res, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_895));
		initStackBottomCall = rope__ropes_109(res);
	}
	LA27_: ;
	(*(*colonenv_).m1).labels += ((NI) 1);
	{
		NimStringDesc* res_2;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T39_;
		if (!!(((50 &((NU16)1<<((NU)((*(*(*(*colonenv_).m1).g).config).selectedGC)&15U)))!=0))) goto LA37_;
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 20);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_923));
		cgFormatValue__cgen_151((&res_2), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
		res_2 = resizeString(res_2, 21);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_924));
		cgFormatValue__cgen_147((&res_2), (*(*(*colonenv_).m1).g).otherModsInit);
		res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_316));
		cgFormatValue__cgen_147((&res_2), posixCmdLine);
		res_2 = resizeString(res_2, 19);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_925));
		cgFormatValue__cgen_151((&res_2), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
		res_2 = resizeString(res_2, 56);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_926));
		cgFormatValue__cgen_151((&res_2), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
		res_2 = resizeString(res_2, 14);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_927));
		cgFormatValue__cgen_147((&res_2), (*(*(*colonenv_).m1).g).mainDatInit);
		res_2 = resizeString(res_2, 16);
appendString(res_2, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_928));
		T39_ = NIM_NIL;
		T39_ = rope__ropes_109(res_2);
		add__ropes_159(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 11))- 0], T39_);
	}
	goto LA35_;
	LA37_: ;
	{
		NimStringDesc* res_3;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T41_;
		res_3 = rawNewString(((NI) 80));
		res_3 = resizeString(res_3, 20);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_923));
		cgFormatValue__cgen_151((&res_3), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
		res_3 = resizeString(res_3, 21);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_924));
		cgFormatValue__cgen_147((&res_3), (*(*(*colonenv_).m1).g).otherModsInit);
		res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_316));
		cgFormatValue__cgen_147((&res_3), posixCmdLine);
		res_3 = resizeString(res_3, 19);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_925));
		cgFormatValue__cgen_151((&res_3), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
		res_3 = resizeString(res_3, 16);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_929));
		cgFormatValue__cgen_147((&res_3), (*(*(*colonenv_).m1).g).mainDatInit);
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_6));
		cgFormatValue__cgen_151((&res_3), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
		res_3 = resizeString(res_3, 19);
appendString(res_3, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_930));
		T41_ = NIM_NIL;
		T41_ = rope__ropes_109(res_3);
		add__ropes_159(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 11))- 0], T41_);
	}
	LA35_: ;
	{
		NIM_BOOL T44_;
		T44_ = (NIM_BOOL)0;
		T44_ = ((*(*(*(*colonenv_).m1).g).config).target.targetOS == ((tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw) 2));
		if (!(T44_)) goto LA45_;
		T44_ = !((((*(*(*(*colonenv_).m1).g).config).globalOptions & 640) == 0));
		LA45_: ;
		if (!T44_) goto LA46_;
		{
			NimStringDesc* res_4;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T52_;
			if (!(((*(*(*(*colonenv_).m1).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 9))&63U)))!=0)) goto LA50_;
			res_4 = rawNewString(((NI) 80));
			res_4 = resizeString(res_4, 28);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_931));
			cgFormatValue__cgen_151((&res_4), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
			res_4 = resizeString(res_4, 22);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_932));
			cgFormatValue__cgen_147((&res_4), (*(*(*colonenv_).m1).g).mainModInit);
			res_4 = resizeString(res_4, 17);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_933));
			cgFormatValue__cgen_151((&res_4), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
			res_4 = resizeString(res_4, 48);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_934));
			cgFormatValue__cgen_147((&res_4), preMainCode);
			res_4 = resizeString(res_4, 9);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_935));
			cgFormatValue__cgen_151((&res_4), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
			res_4 = resizeString(res_4, 14);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_936));
			cgFormatValue__cgen_147((&res_4), initStackBottomCall);
			res_4 = resizeString(res_4, 16);
appendString(res_4, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_928));
			T52_ = NIM_NIL;
			T52_ = rope__ropes_109(res_4);
			add__ropes_159(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 11))- 0], T52_);
		}
		goto LA48_;
		LA50_: ;
		{
			NimStringDesc* res_5;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T54_;
			res_5 = rawNewString(((NI) 80));
			res_5 = resizeString(res_5, 28);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_931));
			cgFormatValue__cgen_151((&res_5), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
			res_5 = resizeString(res_5, 22);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_932));
			cgFormatValue__cgen_147((&res_5), (*(*(*colonenv_).m1).g).mainModInit);
			res_5 = resizeString(res_5, 30);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_937));
			cgFormatValue__cgen_151((&res_5), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
			res_5 = resizeString(res_5, 48);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_934));
			cgFormatValue__cgen_147((&res_5), preMainCode);
			res_5 = resizeString(res_5, 9);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_935));
			cgFormatValue__cgen_151((&res_5), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
			res_5 = resizeString(res_5, 14);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_936));
			cgFormatValue__cgen_147((&res_5), initStackBottomCall);
			res_5 = resizeString(res_5, 16);
appendString(res_5, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_928));
			T54_ = NIM_NIL;
			T54_ = rope__ropes_109(res_5);
			add__ropes_159(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 11))- 0], T54_);
		}
		LA48_: ;
	}
	goto LA42_;
	LA46_: ;
	{
		NimStringDesc* res_6;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T58_;
		if (!((*(*(*(*colonenv_).m1).g).config).target.targetOS == ((tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw) 26))) goto LA56_;
		res_6 = rawNewString(((NI) 80));
		res_6 = resizeString(res_6, 121);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_938));
		cgFormatValue__cgen_151((&res_6), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
		res_6 = resizeString(res_6, 22);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_932));
		cgFormatValue__cgen_147((&res_6), (*(*(*colonenv_).m1).g).mainModInit);
		res_6 = resizeString(res_6, 17);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_933));
		cgFormatValue__cgen_151((&res_6), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
		res_6 = resizeString(res_6, 48);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_934));
		cgFormatValue__cgen_147((&res_6), preMainCode);
		res_6 = resizeString(res_6, 9);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_935));
		cgFormatValue__cgen_151((&res_6), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
		res_6 = resizeString(res_6, 14);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_936));
		cgFormatValue__cgen_147((&res_6), initStackBottomCall);
		res_6 = resizeString(res_6, 16);
appendString(res_6, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_928));
		T58_ = NIM_NIL;
		T58_ = rope__ropes_109(res_6);
		add__ropes_159(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 11))- 0], T58_);
	}
	goto LA42_;
	LA56_: ;
	{
		NimStringDesc* res_7;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T62_;
		if (!(((*(*(*(*colonenv_).m1).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 7))&63U)))!=0)) goto LA60_;
		res_7 = rawNewString(((NI) 80));
		res_7 = resizeString(res_7, 28);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_931));
		cgFormatValue__cgen_151((&res_7), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
		res_7 = resizeString(res_7, 22);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_932));
		cgFormatValue__cgen_147((&res_7), (*(*(*colonenv_).m1).g).mainModInit);
		res_7 = resizeString(res_7, 30);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_937));
		cgFormatValue__cgen_151((&res_7), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
		res_7 = resizeString(res_7, 48);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_934));
		cgFormatValue__cgen_147((&res_7), preMainCode);
		res_7 = resizeString(res_7, 9);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_935));
		cgFormatValue__cgen_151((&res_7), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
		res_7 = resizeString(res_7, 14);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_936));
		cgFormatValue__cgen_147((&res_7), initStackBottomCall);
		res_7 = resizeString(res_7, 16);
appendString(res_7, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_928));
		T62_ = NIM_NIL;
		T62_ = rope__ropes_109(res_7);
		add__ropes_159(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 11))- 0], T62_);
	}
	goto LA42_;
	LA60_: ;
	{
		NimStringDesc* res_8;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T66_;
		if (!((*(*(*(*colonenv_).m1).g).config).target.targetOS == ((tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw) 29))) goto LA64_;
		res_8 = rawNewString(((NI) 80));
		res_8 = resizeString(res_8, 28);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_931));
		cgFormatValue__cgen_151((&res_8), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
		res_8 = resizeString(res_8, 22);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_932));
		cgFormatValue__cgen_147((&res_8), (*(*(*colonenv_).m1).g).mainModInit);
		res_8 = resizeString(res_8, 17);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_933));
		cgFormatValue__cgen_151((&res_8), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
		res_8 = resizeString(res_8, 48);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_934));
		cgFormatValue__cgen_147((&res_8), preMainCode);
		res_8 = resizeString(res_8, 9);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_935));
		cgFormatValue__cgen_151((&res_8), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
		res_8 = resizeString(res_8, 14);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_936));
		cgFormatValue__cgen_147((&res_8), initStackBottomCall);
		res_8 = resizeString(res_8, 16);
appendString(res_8, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_928));
		T66_ = NIM_NIL;
		T66_ = rope__ropes_109(res_8);
		add__ropes_159(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 11))- 0], T66_);
	}
	goto LA42_;
	LA64_: ;
	{
		{
			NimStringDesc* res_9;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T72_;
			if (!!(((50 &((NU16)1<<((NU)((*(*(*(*colonenv_).m1).g).config).selectedGC)&15U)))!=0))) goto LA70_;
			res_9 = rawNewString(((NI) 80));
			res_9 = resizeString(res_9, 28);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_931));
			cgFormatValue__cgen_151((&res_9), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
			res_9 = resizeString(res_9, 22);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_932));
			cgFormatValue__cgen_147((&res_9), (*(*(*colonenv_).m1).g).mainModInit);
			res_9 = resizeString(res_9, 17);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_933));
			cgFormatValue__cgen_151((&res_9), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
			res_9 = resizeString(res_9, 48);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_934));
			cgFormatValue__cgen_147((&res_9), preMainCode);
			res_9 = resizeString(res_9, 9);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_935));
			cgFormatValue__cgen_151((&res_9), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
			res_9 = resizeString(res_9, 14);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_936));
			cgFormatValue__cgen_147((&res_9), initStackBottomCall);
			res_9 = resizeString(res_9, 16);
appendString(res_9, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_928));
			T72_ = NIM_NIL;
			T72_ = rope__ropes_109(res_9);
			add__ropes_159(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 11))- 0], T72_);
		}
		goto LA68_;
		LA70_: ;
		{
			NimStringDesc* res_10;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T74_;
			res_10 = rawNewString(((NI) 80));
			res_10 = resizeString(res_10, 28);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_931));
			cgFormatValue__cgen_151((&res_10), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
			res_10 = resizeString(res_10, 22);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_932));
			cgFormatValue__cgen_147((&res_10), (*(*(*colonenv_).m1).g).mainModInit);
			res_10 = resizeString(res_10, 17);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_933));
			cgFormatValue__cgen_151((&res_10), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
			res_10 = resizeString(res_10, 17);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_939));
			cgFormatValue__cgen_147((&res_10), preMainCode);
			cgFormatValue__cgen_147((&res_10), initStackBottomCall);
			res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_6));
			cgFormatValue__cgen_151((&res_10), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
			res_10 = resizeString(res_10, 19);
appendString(res_10, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_940));
			T74_ = NIM_NIL;
			T74_ = rope__ropes_109(res_10);
			add__ropes_159(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 11))- 0], T74_);
		}
		LA68_: ;
	}
	LA42_: ;
	{
		if (!!((((*(*(*(*colonenv_).m1).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 21))&63U)))!=0))) goto LA77_;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T83_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T84_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T85_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T86_;
			if (!(((NI) 0) < ((*(*(*(*colonenv_).m1).g).config).cppCustomNamespace ? (*(*(*(*colonenv_).m1).g).config).cppCustomNamespace->Sup.len : 0))) goto LA81_;
			T83_ = NIM_NIL;
			T83_ = closeNamespaceNim__cgen_25933();
			T84_ = NIM_NIL;
			T84_ = amp___ropes_140(T83_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_941));
			T85_ = NIM_NIL;
			T85_ = amp___ropes_140(T84_, (*(*(*(*colonenv_).m1).g).config).cppCustomNamespace);
			T86_ = NIM_NIL;
			T86_ = amp___ropes_140(T85_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_380));
			add__ropes_159(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 11))- 0], T86_);
		}
		LA81_: ;
		{
			NIM_BOOL T89_;
			T89_ = (NIM_BOOL)0;
			T89_ = ((*(*(*(*colonenv_).m1).g).config).target.targetOS == ((tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw) 2));
			if (!(T89_)) goto LA90_;
			T89_ = !((((*(*(*(*colonenv_).m1).g).config).globalOptions & 640) == 0));
			LA90_: ;
			if (!T89_) goto LA91_;
			{
				NimStringDesc* res_11;
				NimStringDesc* T97_;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T104_;
				if (!(((*(*(*(*colonenv_).m1).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 9))&63U)))!=0)) goto LA95_;
				res_11 = rawNewString(((NI) 80));
				res_11 = resizeString(res_11, 157);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_942));
				cgFormatValue__cgen_151((&res_11), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
				res_11 = resizeString(res_11, 19);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_943));
				T97_ = NIM_NIL;
				{
					NIM_BOOL T100_;
					T100_ = (NIM_BOOL)0;
					T100_ = hcrOn__cgen_43((*colonenv_).m1);
					if (!T100_) goto LA101_;
					T97_ = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_90));
				}
				goto LA98_;
				LA101_: ;
				{
					T97_ = ((NimStringDesc*) NIM_NIL);
				}
				LA98_: ;
				cgFormatValue__cgen_151((&res_11), T97_);
				res_11 = resizeString(res_11, 23);
appendString(res_11, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_944));
				T104_ = NIM_NIL;
				T104_ = rope__ropes_109(res_11);
				add__ropes_159(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 11))- 0], T104_);
			}
			goto LA93_;
			LA95_: ;
			{
				NimStringDesc* res_12;
				tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T106_;
				res_12 = rawNewString(((NI) 80));
				res_12 = resizeString(res_12, 140);
appendString(res_12, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_945));
				cgFormatValue__cgen_151((&res_12), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
				res_12 = resizeString(res_12, 27);
appendString(res_12, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_946));
				T106_ = NIM_NIL;
				T106_ = rope__ropes_109(res_12);
				add__ropes_159(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 11))- 0], T106_);
			}
			LA93_: ;
		}
		goto LA87_;
		LA91_: ;
		{
			NimStringDesc* res_13;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T110_;
			if (!((*(*(*(*colonenv_).m1).g).config).target.targetOS == ((tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw) 26))) goto LA108_;
			res_13 = rawNewString(((NI) 80));
			res_13 = resizeString(res_13, 185);
appendString(res_13, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_947));
			cgFormatValue__cgen_151((&res_13), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
			res_13 = resizeString(res_13, 83);
appendString(res_13, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_948));
			T110_ = NIM_NIL;
			T110_ = rope__ropes_109(res_13);
			add__ropes_159(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 11))- 0], T110_);
		}
		goto LA87_;
		LA108_: ;
		{
			NimStringDesc* res_14;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T114_;
			if (!(((*(*(*(*colonenv_).m1).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 7))&63U)))!=0)) goto LA112_;
			res_14 = rawNewString(((NI) 80));
			res_14 = resizeString(res_14, 55);
appendString(res_14, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_949));
			cgFormatValue__cgen_151((&res_14), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
			res_14 = resizeString(res_14, 14);
appendString(res_14, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_950));
			T114_ = NIM_NIL;
			T114_ = rope__ropes_109(res_14);
			add__ropes_159(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 11))- 0], T114_);
		}
		goto LA87_;
		LA112_: ;
		{
			NimStringDesc* res_15;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T118_;
			if (!((*(*(*(*colonenv_).m1).g).config).target.targetOS == ((tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw) 29))) goto LA116_;
			res_15 = rawNewString(((NI) 80));
			res_15 = resizeString(res_15, 18);
appendString(res_15, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_951));
			cgFormatValue__cgen_151((&res_15), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
			res_15 = resizeString(res_15, 25);
appendString(res_15, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_952));
			T118_ = NIM_NIL;
			T118_ = rope__ropes_109(res_15);
			add__ropes_159(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 11))- 0], T118_);
		}
		goto LA87_;
		LA116_: ;
		{
			NimStringDesc* res_16;
			NimStringDesc* T120_;
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T127_;
			res_16 = rawNewString(((NI) 80));
			res_16 = resizeString(res_16, 95);
appendString(res_16, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_953));
			cgFormatValue__cgen_151((&res_16), (*(*(*(*colonenv_).m1).g).config).nimMainPrefix);
			res_16 = resizeString(res_16, 19);
appendString(res_16, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_943));
			T120_ = NIM_NIL;
			{
				NIM_BOOL T123_;
				T123_ = (NIM_BOOL)0;
				T123_ = hcrOn__cgen_43((*colonenv_).m1);
				if (!T123_) goto LA124_;
				T120_ = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_90));
			}
			goto LA121_;
			LA124_: ;
			{
				T120_ = ((NimStringDesc*) NIM_NIL);
			}
			LA121_: ;
			cgFormatValue__cgen_151((&res_16), T120_);
			res_16 = resizeString(res_16, 23);
appendString(res_16, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_944));
			T127_ = NIM_NIL;
			T127_ = rope__ropes_109(res_16);
			add__ropes_159(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 11))- 0], T127_);
		}
		LA87_: ;
		{
			tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T132_;
			if (!(((NI) 0) < ((*(*(*(*colonenv_).m1).g).config).cppCustomNamespace ? (*(*(*(*colonenv_).m1).g).config).cppCustomNamespace->Sup.len : 0))) goto LA130_;
			T132_ = NIM_NIL;
			T132_ = openNamespaceNim__cgen_25930((*(*(*(*colonenv_).m1).g).config).cppCustomNamespace);
			add__ropes_159(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 11))- 0], T132_);
		}
		LA130_: ;
	}
	LA77_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, generateThreadVarsSize__cgen_11293)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m) {
	{
		NimStringDesc* externc;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T12_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
		if (!!(((*(*m).g).nimtv == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)))) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = ((*(*(*m).g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2));
			if (T7_) goto LA8_;
			T7_ = (((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32))&63U)))!=0);
			LA8_: ;
			if (!T7_) goto LA9_;
			externc = copyString(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_377));
		}
		goto LA5_;
		LA9_: ;
		{
			externc = ((NimStringDesc*) NIM_NIL);
		}
		LA5_: ;
		nimZeroMem((void*)T12_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T12_[0] = rope__ropes_109(externc);
		T13_ = NIM_NIL;
		T13_ = percent___cgen_11308(T12_, 1);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 11))- 0], T13_);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, headerTop__cgen_27125)(void) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyArray__ts9cf9blICas1QWmw89bglZ7w T1_;
	result = NIM_NIL;
	nimZeroMem((void*)T1_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
	T1_[0] = rope__ropes_109(((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_956));
	result = percent___cgen_27127(T1_, 1);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getCopyright__cgen_27132)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw* cfile) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	result = headerTop__cgen_27125();
	{
		tyArray__InO6xIOhXMnkCXPnEYWwWg T5_;
		NimStringDesc* T6_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T7_;
		if (!!((((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 4))&63U)))!=0))) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__InO6xIOhXMnkCXPnEYWwWg));
		T5_[0] = rope__ropes_109(OS__platform_518[((*conf).target.targetOS)- 1].Field0);
		T5_[1] = rope__ropes_109(CPU__platform_705[((*conf).target.targetCPU)- 1].Field0);
		T5_[2] = rope__ropes_109(CC__extccomp_510[((*conf).cCompiler)- 1].Field0);
		T6_ = NIM_NIL;
		T6_ = getCompileCFileCmd__extccomp_997(conf, cfile, NIM_FALSE, NIM_FALSE);
		T5_[3] = rope__ropes_109(T6_);
		T7_ = NIM_NIL;
		T7_ = percent___cgen_27140(T5_, 4);
		add__ropes_159(&result, T7_);
	}
	LA3_: ;
	return result;
}
static N_INLINE(void, addNimDefines__cgen_27117)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** result, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	tyArray__ts9cf9blICas1QWmw89bglZ7w T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T2_;
	nimZeroMem((void*)T1_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
	T1_[0] = rope__ropes_115(((NI64) (CPU__platform_705[((*conf).target.targetCPU)- 1].Field1)));
	T2_ = NIM_NIL;
	T2_ = percent___cgen_27120(T1_, 1);
	add__ropes_159(result, T2_);
	{
		if (!(((NI) 0) < ((*conf).cppCustomNamespace ? (*conf).cppCustomNamespace->Sup.len : 0))) goto LA5_;
		add__ropes_162(result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_958));
		add__ropes_162(result, (*conf).cppCustomNamespace);
		add__ropes_162(result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
	}
	LA5_: ;
	{
		NIM_BOOL T9_;
		T9_ = (NIM_BOOL)0;
		T9_ = isDefined__options_2292(conf, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_959));
		if (!T9_) goto LA10_;
		add__ropes_162(result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_960));
	}
	LA10_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getFileHeader__cgen_27145)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw* cfile) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	result = getCopyright__cgen_27132(conf, cfile);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = hcrOn__options_582(conf);
		if (!T3_) goto LA4_;
		add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_957));
	}
	LA4_: ;
	addNimDefines__cgen_27117(&result, conf);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, generateThreadLocalStorage__cgen_11270)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T14_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T15_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*(*m).g).nimtv == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = (((*m).flags &((NU8)1<<((NU)(((tyEnum_CodegenFlag__vPx29bHhk9a7V50u1UO0rM4w) 1))&7U)))!=0);
		if (T5_) goto LA6_;
		T5_ = (((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 14))&63U)))!=0);
		LA6_: ;
		T3_ = T5_;
		LA4_: ;
		if (!T3_) goto LA7_;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA** t;
			NI i;
			NI L;
			NI T10_;
			t = (tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA**)0;
			i = ((NI) 0);
			T10_ = ((*(*m).g).nimtvDeps ? (*(*m).g).nimtvDeps->Sup.len : 0);
			L = T10_;
			{
				while (1) {
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T13_;
					if (!(i < L)) goto LA12;
					t = &(*(*m).g).nimtvDeps->data[i];
					T13_ = NIM_NIL;
					T13_ = getTypeDesc__cgen_6662(m, (*t), ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
					(void)(T13_);
					i += ((NI) 1);
				} LA12: ;
			}
		}
		finishTypeDescriptions__cgen_6711(m);
		nimZeroMem((void*)T14_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T14_[0] = (*(*m).g).nimtv;
		T15_ = NIM_NIL;
		T15_ = percent___cgen_11288(T14_, 1);
		add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 5))- 0], T15_);
	}
	LA7_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, generateHeaders__cgen_25910)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m) {
	add__ropes_162(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 1))- 0], ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_961));
	{
		NimStringDesc** it;
		NI i;
		NI L;
		NI T2_;
		it = (NimStringDesc**)0;
		i = ((NI) 0);
		T2_ = ((*m).headerFiles ? (*m).headerFiles->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				it = (&(*m).headerFiles->data[i]);
				{
					NimStringDesc* T9_;
					NimStringDesc* T10_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T11_;
					if (!((NU8)((*it)->data[((NI) 0)]) == (NU8)(35))) goto LA7_;
					T9_ = NIM_NIL;
					T10_ = NIM_NIL;
					T10_ = nsuReplaceChar((*it), 96, 34);
					T9_ = rawNewString((T10_ ? T10_->Sup.len : 0) + 1);
appendString(T9_, T10_);
appendString(T9_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_9));
					T11_ = NIM_NIL;
					T11_ = rope__ropes_109(T9_);
					add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 1))- 0], T11_);
				}
				goto LA5_;
				LA7_: ;
				{
					tyArray__ts9cf9blICas1QWmw89bglZ7w T15_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
					if (!!((((NU8)((*it)->data[((NI) 0)])) == ((NU8)(34)) || ((NU8)((*it)->data[((NI) 0)])) == ((NU8)(60))))) goto LA13_;
					nimZeroMem((void*)T15_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
					T15_[0] = rope__ropes_109((*it));
					T16_ = NIM_NIL;
					T16_ = percent___cgen_25920(T15_, 1);
					add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 1))- 0], T16_);
				}
				goto LA5_;
				LA13_: ;
				{
					tyArray__ts9cf9blICas1QWmw89bglZ7w T18_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T19_;
					nimZeroMem((void*)T18_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
					T18_[0] = rope__ropes_109((*it));
					T19_ = NIM_NIL;
					T19_ = percent___cgen_25925(T18_, 1);
					add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 1))- 0], T19_);
				}
				LA5_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
	add__ropes_162(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 1))- 0], ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_962));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, genModule__cgen_28457)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw* cfile) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	NIM_BOOL moduleIsEmpty;
	result = NIM_NIL;
	moduleIsEmpty = NIM_TRUE;
	result = getFileHeader__cgen_27145((*(*m).g).config, cfile);
	generateThreadLocalStorage__cgen_11270(m);
	generateHeaders__cgen_25910(m);
	add__ropes_159(&result, (*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 1))- 0]);
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
		if (!(((NI) 0) < ((*(*(*m).g).config).cppCustomNamespace ? (*(*(*m).g).config).cppCustomNamespace->Sup.len : 0))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = openNamespaceNim__cgen_25930((*(*(*m).g).config).cppCustomNamespace);
		add__ropes_159(&result, T5_);
	}
	LA3_: ;
	{
		NI T8_;
		T8_ = (NI)0;
		T8_ = len__ropes_10((*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 2))- 0]);
		if (!(((NI) 0) < T8_)) goto LA9_;
		add__ropes_159(&result, (*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 2))- 0]);
	}
	goto LA6_;
	LA9_: ;
	{
		add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_963));
	}
	LA6_: ;
	{
		tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw i;
		NI res;
		i = (tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw)0;
		res = ((NI) 3);
		{
			while (1) {
				if (!(res <= ((NI) 11))) goto LA14;
				i = ((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) (res));
				{
					NI T17_;
					T17_ = (NI)0;
					T17_ = len__ropes_10((*m).s[(i)- 0]);
					if (!(((NI) 0) < T17_)) goto LA18_;
					moduleIsEmpty = NIM_FALSE;
					add__ropes_159(&result, (*m).s[(i)- 0]);
				}
				LA18_: ;
				res += ((NI) 1);
			} LA14: ;
		}
	}
	{
		NI T22_;
		T22_ = (NI)0;
		T22_ = len__ropes_10((*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 12))- 0]);
		if (!(((NI) 0) < T22_)) goto LA23_;
		moduleIsEmpty = NIM_FALSE;
		add__ropes_159(&result, (*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 12))- 0]);
	}
	LA23_: ;
	{
		NIM_BOOL T27_;
		NI T28_;
		T27_ = (NIM_BOOL)0;
		T28_ = (NI)0;
		T28_ = len__ropes_10((*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 13))- 0]);
		T27_ = (((NI) 0) < T28_);
		if (T27_) goto LA29_;
		T27_ = hcrOn__cgen_43(m);
		LA29_: ;
		if (!T27_) goto LA30_;
		moduleIsEmpty = NIM_FALSE;
		add__ropes_159(&result, (*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 13))- 0]);
	}
	LA30_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T36_;
		if (!(((NI) 0) < ((*(*(*m).g).config).cppCustomNamespace ? (*(*(*m).g).config).cppCustomNamespace->Sup.len : 0))) goto LA34_;
		T36_ = NIM_NIL;
		T36_ = closeNamespaceNim__cgen_25933();
		add__ropes_159(&result, T36_);
	}
	LA34_: ;
	{
		if (!moduleIsEmpty) goto LA39_;
		result = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
	}
	LA39_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, shouldRecompile__cgen_28719)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* code, tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw* cfile) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		if (!!((((*(*(*m).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 1))&63U)))!=0))) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = moduleHasChanged__passes_209((*(*m).g).graph, (*m).module);
			if (!!(T7_)) goto LA8_;
			result = NIM_FALSE;
		}
		goto LA5_;
		LA8_: ;
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = equalsFile__ropes_453(code, (*cfile).cname);
			if (!!(T11_)) goto LA12_;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = writeRope__ropes_241(code, (*cfile).cname);
				if (!!(T16_)) goto LA17_;
				liMessage__msgs_1128((*(*m).g).config, unknownLineInfo__lineinfos_284, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 4), (*cfile).cname, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_964, NIM_FALSE);
			}
			LA17_: ;
			result = NIM_TRUE;
		}
		goto LA5_;
		LA12_: ;
		{
			NIM_BOOL T20_;
			T20_ = (NIM_BOOL)0;
			T20_ = nosfileExists((*cfile).obj);
			if (!(T20_)) goto LA21_;
			T20_ = nosfileNewer((*cfile).obj, (*cfile).cname);
			LA21_: ;
			if (!T20_) goto LA22_;
			result = NIM_FALSE;
		}
		goto LA5_;
		LA22_: ;
		{
			result = NIM_TRUE;
		}
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		{
			NIM_BOOL T28_;
			T28_ = (NIM_BOOL)0;
			T28_ = writeRope__ropes_241(code, (*cfile).cname);
			if (!!(T28_)) goto LA29_;
			liMessage__msgs_1128((*(*m).g).config, unknownLineInfo__lineinfos_284, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 4), (*cfile).cname, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_965, NIM_FALSE);
		}
		LA29_: ;
		result = NIM_TRUE;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, writeModule__cgen_28728)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m, NIM_BOOL pending) {
	NimStringDesc* cfile;
	tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw cf;
	NimStringDesc* T10_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* code;
	cfile = getCFile__cgen_129(m);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = moduleHasChanged__passes_209((*(*m).g).graph, (*m).module);
		if (!T3_) goto LA4_;
		genInitCode__cgen_28147(m);
		finishTypeDescriptions__cgen_6711(m);
		{
			if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 14))&63U)))!=0)) goto LA8_;
			genMainProc__cgen_27193(m);
			add__ropes_159(&(*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 8))- 0], (*(*m).g).mainModProcs);
			generateThreadVarsSize__cgen_11293(m);
		}
		LA8_: ;
	}
	LA4_: ;
	nimZeroMem((void*)(&cf), sizeof(tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw));
	nimZeroMem((void*)(&cf), sizeof(tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw));
	cf.nimname = copyString((*(*(*m).module).name).s);
	cf.cname = copyString(cfile);
	T10_ = NIM_NIL;
	T10_ = toObjFile__extccomp_720((*(*m).g).config, cfile);
	cf.obj = completeCfilePath__extccomp_715((*(*m).g).config, T10_, NIM_TRUE);
	cf.flags = 0;
	code = genModule__cgen_28457(m, (&cf));
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = !((code == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL)));
		if (T13_) goto LA14_;
		T13_ = !(((*(*(*m).g).config).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0)));
		LA14_: ;
		if (!T13_) goto LA15_;
		{
			NIM_BOOL T19_;
			T19_ = (NIM_BOOL)0;
			T19_ = shouldRecompile__cgen_28719(m, code, (&cf));
			if (!!(T19_)) goto LA20_;
			cf.flags = 1;
		}
		LA20_: ;
		addFileToCompile__extccomp_724((*(*m).g).config, (&cf));
	}
	LA15_: ;
	close__ndi_31((&(*m).ndi), (*(*m).g).config);
}
N_LIB_PRIVATE N_NIMCALL(void, writeHeader__cgen_28613)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* guard;
	tyArray__ts9cf9blICas1QWmw89bglZ7w T1_;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T2_;
	tyArray__ts9cf9blICas1QWmw89bglZ7w T3_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T4_;
	tyArray__ts9cf9blICas1QWmw89bglZ7w T19_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T20_;
	tyArray__ts9cf9blICas1QWmw89bglZ7w T26_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T27_;
	result = headerTop__cgen_27125();
	nimZeroMem((void*)T1_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
	nimZeroMem((void*)(&T2_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	splitFile__pathutils_27((*m).filename, (&T2_));
	T1_[0] = rope__ropes_109(T2_.Field1);
	guard = percent___cgen_28616(T1_, 1);
	nimZeroMem((void*)T3_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
	T3_[0] = guard;
	T4_ = NIM_NIL;
	T4_ = percent___cgen_28622(T3_, 1);
	add__ropes_159(&result, T4_);
	addNimDefines__cgen_27117(&result, (*(*m).g).config);
	generateHeaders__cgen_25910(m);
	generateThreadLocalStorage__cgen_11270(m);
	{
		tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw i;
		NI res;
		i = (tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw)0;
		res = ((NI) 1);
		{
			while (1) {
				if (!(res <= ((NI) 11))) goto LA7;
				i = ((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) (res));
				add__ropes_159(&result, (*m).s[(i)- 0]);
				{
					NIM_BOOL T10_;
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T14_;
					T10_ = (NIM_BOOL)0;
					T10_ = (((NI) 0) < ((*(*(*m).g).config).cppCustomNamespace ? (*(*(*m).g).config).cppCustomNamespace->Sup.len : 0));
					if (!(T10_)) goto LA11_;
					T10_ = (i == ((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 1));
					LA11_: ;
					if (!T10_) goto LA12_;
					T14_ = NIM_NIL;
					T14_ = openNamespaceNim__cgen_25930((*(*(*m).g).config).cppCustomNamespace);
					add__ropes_159(&result, T14_);
				}
				LA12_: ;
				res += ((NI) 1);
			} LA7: ;
		}
	}
	add__ropes_159(&result, (*m).s[(((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) 12))- 0]);
	{
		if (!(((*(*(*m).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 7))&63U)))!=0)) goto LA17_;
		add__ropes_162(&result, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_62));
	}
	LA17_: ;
	nimZeroMem((void*)T19_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
	T19_[0] = rope__ropes_109((*(*(*m).g).config).nimMainPrefix);
	T20_ = NIM_NIL;
	T20_ = percent___cgen_28641(T19_, 1);
	add__ropes_159(&result, T20_);
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T25_;
		if (!(((NI) 0) < ((*(*(*m).g).config).cppCustomNamespace ? (*(*(*m).g).config).cppCustomNamespace->Sup.len : 0))) goto LA23_;
		T25_ = NIM_NIL;
		T25_ = closeNamespaceNim__cgen_25933();
		add__ropes_159(&result, T25_);
	}
	LA23_: ;
	nimZeroMem((void*)T26_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
	T26_[0] = guard;
	T27_ = NIM_NIL;
	T27_ = percent___cgen_28646(T26_, 1);
	add__ropes_159(&result, T27_);
	{
		NIM_BOOL T30_;
		T30_ = (NIM_BOOL)0;
		T30_ = writeRope__ropes_241(result, (*m).filename);
		if (!!(T30_)) goto LA31_;
		liMessage__msgs_1128((*(*m).g).config, unknownLineInfo__lineinfos_284, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 4), (*m).filename, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), TM__9bddtAaa9cYLwzzzlT9aJ5CKw_966, NIM_FALSE);
	}
	LA31_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, cgenWriteModules__cgen_28849)(RootObj* backend, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config) {
	tyObject_BModuleListcolonObjectType___9c4b0IbdzIJRabh100GyFtA* g;
	g = ((tyObject_BModuleListcolonObjectType___9c4b0IbdzIJRabh100GyFtA*) (backend));
	asgnRef((void**) (&(*g).config), config);
	genForwardedProcs__cgen_28835(g);
	{
		tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m;
		m = NIM_NIL;
		{
			tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA** m_2;
			NI i;
			NI L;
			NI T3_;
			m_2 = (tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA**)0;
			i = ((NI) 0);
			T3_ = ((*g).modulesClosed ? (*g).modulesClosed->Sup.len : 0);
			L = T3_;
			{
				while (1) {
					if (!(i < L)) goto LA5;
					m_2 = &(*g).modulesClosed->data[i];
					m = (*m_2);
					writeModule__cgen_28728(m, NIM_TRUE);
					i += ((NI) 1);
				} LA5: ;
			}
		}
	}
	writeMapping__extccomp_2663(config, (*g).mapping);
	{
		if (!!(((*g).generatedHeader == ((tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA*) NIM_NIL)))) goto LA8_;
		writeHeader__cgen_28613((*g).generatedHeader);
	}
	LA8_: ;
}
N_LIB_PRIVATE N_NIMCALL(tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ, whichInitProcs__cgen_27549)(tyObject_TCGen__LLLbwetkArja9aBhGlHYtvA* m) {
	tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ result;
	nimZeroMem((void*)(&result), sizeof(tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ));
	result = 0;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T6_;
		NI T7_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** T9_;
		NI T10_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = hcrOn__cgen_43(m);
		if (T4_) goto LA5_;
		T6_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T6_ = s__cgendata_225((*m).preInitProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 1));
		T7_ = (NI)0;
		T7_ = len__ropes_10((*T6_));
		T4_ = (((NI) 0) < T7_);
		LA5_: ;
		T3_ = T4_;
		if (T3_) goto LA8_;
		T9_ = (tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ**)0;
		T9_ = s__cgendata_225((*m).preInitProc, ((tyEnum_TCProcSection__w9a0SccmJ1gyaGT0MphVZSw) 2));
		T10_ = (NI)0;
		T10_ = len__ropes_10((*T9_));
		T3_ = (((NI) 0) < T10_);
		LA8_: ;
		if (!T3_) goto LA11_;
		result |= ((NU8)1)<<((((tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ) 1)) & 7);
	}
	LA11_: ;
	{
		tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw i;
		NI res;
		i = (tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw)0;
		res = ((NI) 14);
		{
			while (1) {
				if (!(res <= ((NI) 18))) goto LA15;
				i = ((tyEnum_TCFileSection__N9cfZ9a1wl1RNB5AmLY5atkw) (res));
				{
					NI T18_;
					T18_ = (NI)0;
					T18_ = len__ropes_10((*m).s[(i)- 0]);
					if (!!((T18_ == ((NI) 0)))) goto LA19_;
					result |= ((NU8)1)<<((((tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ) 0)) & 7);
					goto LA13;
				}
				LA19_: ;
				res += ((NI) 1);
			} LA15: ;
		}
	} LA13: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, getSomeNameForModule__cgen_27149)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = mangleModuleName__modulepaths_32(conf, filename);
	T2_ = NIM_NIL;
	T2_ = mangle__ccgutils_112(T1_);
	add__ropes_162(&result, T2_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, registerInitProcs__cgen_27507)(tyObject_BModuleListcolonObjectType___9c4b0IbdzIJRabh100GyFtA* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ flags) {
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* datInit;
		NimStringDesc* T5_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T6_;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T7_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T9_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
		if (!((flags &((NU8)1<<((NU)(((tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ) 0))&7U)))!=0)) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = toFullPath__msgs_548((*g).config, (*m).info.fileIndex);
		T6_ = NIM_NIL;
		T6_ = getSomeNameForModule__cgen_27149((*g).config, T5_);
		datInit = amp___ropes_140(T6_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_887));
		nimZeroMem((void*)T7_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T7_[0] = datInit;
		T8_ = NIM_NIL;
		T8_ = percent___cgen_27517(T7_, 1);
		add__ropes_159(&(*g).mainModProcs, T8_);
		nimZeroMem((void*)T9_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T9_[0] = datInit;
		T10_ = NIM_NIL;
		T10_ = percent___cgen_27522(T9_, 1);
		add__ropes_159(&(*g).mainDatInit, T10_);
	}
	LA3_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* init;
		NimStringDesc* T15_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T16_;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T17_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T18_;
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* initCall;
		tyArray__ts9cf9blICas1QWmw89bglZ7w T19_;
		if (!((flags &((NU8)1<<((NU)(((tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ) 1))&7U)))!=0)) goto LA13_;
		T15_ = NIM_NIL;
		T15_ = toFullPath__msgs_548((*g).config, (*m).info.fileIndex);
		T16_ = NIM_NIL;
		T16_ = getSomeNameForModule__cgen_27149((*g).config, T15_);
		init = amp___ropes_140(T16_, ((NimStringDesc*) &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_868));
		nimZeroMem((void*)T17_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T17_[0] = init;
		T18_ = NIM_NIL;
		T18_ = percent___cgen_27517(T17_, 1);
		add__ropes_159(&(*g).mainModProcs, T18_);
		nimZeroMem((void*)T19_, sizeof(tyArray__ts9cf9blICas1QWmw89bglZ7w));
		T19_[0] = init;
		initCall = percent___cgen_27522(T19_, 1);
		{
			if (!(((*m).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 14))&63U)))!=0)) goto LA22_;
			add__ropes_159(&(*g).mainModInit, initCall);
		}
		goto LA20_;
		LA22_: ;
		{
			if (!(((*m).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 15))&63U)))!=0)) goto LA25_;
			add__ropes_159(&(*g).mainDatInit, initCall);
		}
		goto LA20_;
		LA25_: ;
		{
			add__ropes_159(&(*g).otherModsInit, initCall);
		}
		LA20_: ;
	}
	LA13_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, atmcgendotnim_DatInit000)(void) {
static TNimNode* TM__9bddtAaa9cYLwzzzlT9aJ5CKw_760_2[2];
static TNimNode* TM__9bddtAaa9cYLwzzzlT9aJ5CKw_905_2[2];
static TNimNode TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[6];
NTItupleLloc58tloc_tp58ropeT__PCL3pTh9cmlWmhmXAE5IOKQ_.size = sizeof(tyTuple__PCL3pTh9cmlWmhmXAE5IOKQ);
NTItupleLloc58tloc_tp58ropeT__PCL3pTh9cmlWmhmXAE5IOKQ_.align = NIM_ALIGNOF(tyTuple__PCL3pTh9cmlWmhmXAE5IOKQ);
NTItupleLloc58tloc_tp58ropeT__PCL3pTh9cmlWmhmXAE5IOKQ_.kind = 18;
NTItupleLloc58tloc_tp58ropeT__PCL3pTh9cmlWmhmXAE5IOKQ_.base = 0;
NTItupleLloc58tloc_tp58ropeT__PCL3pTh9cmlWmhmXAE5IOKQ_.flags = 2;
TM__9bddtAaa9cYLwzzzlT9aJ5CKw_760_2[0] = &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[1];
TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[1].kind = 1;
TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[1].offset = offsetof(tyTuple__PCL3pTh9cmlWmhmXAE5IOKQ, Field0);
TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[1].typ = (&NTItloc__CAJV4zTUpZwr0j6Wy8FiFw_);
TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[1].name = "Field0";
TM__9bddtAaa9cYLwzzzlT9aJ5CKw_760_2[1] = &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[2];
TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[2].kind = 1;
TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[2].offset = offsetof(tyTuple__PCL3pTh9cmlWmhmXAE5IOKQ, Field1);
TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[2].typ = (&NTIrope__Ylz2qJFHq2oxQcAA5BJOQg_);
TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[2].name = "Field1";
TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[0].len = 2; TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[0].kind = 2; TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[0].sons = &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_760_2[0];
NTItupleLloc58tloc_tp58ropeT__PCL3pTh9cmlWmhmXAE5IOKQ_.node = &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[0];
NTIseqLtupleLloc58tloc_tp58ropeTT__Vz8km29c8JcWq5WOBlnn2aQ_.size = sizeof(tySequence__Vz8km29c8JcWq5WOBlnn2aQ*);
NTIseqLtupleLloc58tloc_tp58ropeTT__Vz8km29c8JcWq5WOBlnn2aQ_.align = NIM_ALIGNOF(tySequence__Vz8km29c8JcWq5WOBlnn2aQ*);
NTIseqLtupleLloc58tloc_tp58ropeTT__Vz8km29c8JcWq5WOBlnn2aQ_.kind = 24;
NTIseqLtupleLloc58tloc_tp58ropeTT__Vz8km29c8JcWq5WOBlnn2aQ_.base = (&NTItupleLloc58tloc_tp58ropeT__PCL3pTh9cmlWmhmXAE5IOKQ_);
NTIseqLtupleLloc58tloc_tp58ropeTT__Vz8km29c8JcWq5WOBlnn2aQ_.flags = 2;
NTIseqLtupleLloc58tloc_tp58ropeTT__Vz8km29c8JcWq5WOBlnn2aQ_.marker = Marker_tySequence__Vz8km29c8JcWq5WOBlnn2aQ;
NTIobject__MH1VwSLIbfCI9coJDTeX9c2Q_.size = sizeof(tyObject_Env_cgendotnim_genMainProc___MH1VwSLIbfCI9coJDTeX9c2Q);
NTIobject__MH1VwSLIbfCI9coJDTeX9c2Q_.align = NIM_ALIGNOF(tyObject_Env_cgendotnim_genMainProc___MH1VwSLIbfCI9coJDTeX9c2Q);
NTIobject__MH1VwSLIbfCI9coJDTeX9c2Q_.kind = 17;
NTIobject__MH1VwSLIbfCI9coJDTeX9c2Q_.base = (&NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_);
TM__9bddtAaa9cYLwzzzlT9aJ5CKw_905_2[0] = &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[4];
TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[4].kind = 1;
TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[4].offset = offsetof(tyObject_Env_cgendotnim_genMainProc___MH1VwSLIbfCI9coJDTeX9c2Q, colonstate_);
TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[4].typ = (&NTIint__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[4].name = ":state";
TM__9bddtAaa9cYLwzzzlT9aJ5CKw_905_2[1] = &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[5];
TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[5].kind = 1;
TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[5].offset = offsetof(tyObject_Env_cgendotnim_genMainProc___MH1VwSLIbfCI9coJDTeX9c2Q, m1);
TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[5].typ = (&NTIbmodule__AeJVysvbewqqb9ao16aCkYA_);
TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[5].name = "m1";
TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[3].len = 2; TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[3].kind = 2; TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[3].sons = &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_905_2[0];
NTIobject__MH1VwSLIbfCI9coJDTeX9c2Q_.node = &TM__9bddtAaa9cYLwzzzlT9aJ5CKw_0[3];
NTIrefobject__9bbPrOZAgwWihvYGa8yXUow_.size = sizeof(tyObject_Env_cgendotnim_genMainProc___MH1VwSLIbfCI9coJDTeX9c2Q*);
NTIrefobject__9bbPrOZAgwWihvYGa8yXUow_.align = NIM_ALIGNOF(tyObject_Env_cgendotnim_genMainProc___MH1VwSLIbfCI9coJDTeX9c2Q*);
NTIrefobject__9bbPrOZAgwWihvYGa8yXUow_.kind = 22;
NTIrefobject__9bbPrOZAgwWihvYGa8yXUow_.base = (&NTIobject__MH1VwSLIbfCI9coJDTeX9c2Q_);
NTIrefobject__9bbPrOZAgwWihvYGa8yXUow_.marker = Marker_tyRef__9bbPrOZAgwWihvYGa8yXUow;
}

