/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 32
#define NIM_EmulateOverflowChecks

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow;
typedef struct tyObject_Table__rDTSDzC8VietpxpD1ELe1g tyObject_Table__rDTSDzC8VietpxpD1ELe1g;
typedef struct tySequence__dAjyAaabi52TN36Jp0fAXQ tySequence__dAjyAaabi52TN36Jp0fAXQ;
typedef struct tySequence__wbHXzzfwTCmsKuzoRrgI3g tySequence__wbHXzzfwTCmsKuzoRrgI3g;
typedef struct tyObject_HashSet__zVZZy9cn25qKcaABhU9aN2vw tyObject_HashSet__zVZZy9cn25qKcaABhU9aN2vw;
typedef struct tySequence__nueg5spSfGVW7EdegG2fTw tySequence__nueg5spSfGVW7EdegG2fTw;
typedef struct tyTuple__X9bWVAqRSgByRpQwn6owzEA tyTuple__X9bWVAqRSgByRpQwn6owzEA;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tyTuple__QJASEmMHDLGFAvbisAV7AA tyTuple__QJASEmMHDLGFAvbisAV7AA;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyTuple__cyDO9czMbIL47POKM3sIQng tyTuple__cyDO9czMbIL47POKM3sIQng;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A;
typedef struct tySequence__kGCKZrVGM65uzo2SGY9bxMQ tySequence__kGCKZrVGM65uzo2SGY9bxMQ;
typedef struct tySequence__TXTtz79abNCf5jWrlvNZpOw tySequence__TXTtz79abNCf5jWrlvNZpOw;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
typedef struct tyObject_History__nemqwCae5qEp6Zk6QXd7RA tyObject_History__nemqwCae5qEp6Zk6QXd7RA;
typedef struct tySequence__ShKVNN7kN9a0hT6rhE7ADzg tySequence__ShKVNN7kN9a0hT6rhE7ADzg;
typedef struct tyObject_Check__7OzxEL6sl2sLK509ac4JShA tyObject_Check__7OzxEL6sl2sLK509ac4JShA;
typedef struct tySequence__AHhlrIyws6DwjcjqnuoVWQ tySequence__AHhlrIyws6DwjcjqnuoVWQ;
typedef struct tyTuple__3w8Q5T9cOF5FQ54JItYYe3Q tyTuple__3w8Q5T9cOF5FQ54JItYYe3Q;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_HSlice__7TOOBlADhY009aGwq7hyBaw tyObject_HSlice__7TOOBlADhY009aGwq7hyBaw;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyObject_Table__rDTSDzC8VietpxpD1ELe1g {
tySequence__dAjyAaabi52TN36Jp0fAXQ* data;
NI counter;
};
struct tyObject_HashSet__zVZZy9cn25qKcaABhU9aN2vw {
tySequence__nueg5spSfGVW7EdegG2fTw* data;
NI counter;
};
struct tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow {
tyObject_Table__rDTSDzC8VietpxpD1ELe1g symbolIndices;
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* expressions;
tySequence__wbHXzzfwTCmsKuzoRrgI3g* dependants;
tyObject_HashSet__zVZZy9cn25qKcaABhU9aN2vw warningLocations;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
};
struct tyTuple__X9bWVAqRSgByRpQwn6owzEA {
NI Field0;
NI Field1;
NI16 Field2;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyTuple__QJASEmMHDLGFAvbisAV7AA {
NI Field0;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field1;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
struct tyTuple__cyDO9czMbIL47POKM3sIQng {
NI Field0;
NI16 Field1;
};
typedef tyTuple__cyDO9czMbIL47POKM3sIQng tyArray__brqof9bq2QWioDkbae3wZsw[1];
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInst;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg uniqueId;
};
typedef NU8 tySet_tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw[21];
typedef NU8 tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
typedef NU8 tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA;
struct tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A {
tySequence__kGCKZrVGM65uzo2SGY9bxMQ* expressions;
tySequence__TXTtz79abNCf5jWrlvNZpOw* history;
tySequence__qwqHTkRvwhrRyENtudHQ7g* setIndices;
tySequence__wbHXzzfwTCmsKuzoRrgI3g* sets;
tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* parent;
};
typedef NU8 tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA;
struct tyObject_History__nemqwCae5qEp6Zk6QXd7RA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA nilability;
tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA kind;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* node;
};
typedef NU tyArray__cC4ce9cdvDKtIpar5g9cDejA[16];
struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg {
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* next;
NI key;
tyArray__cC4ce9cdvDKtIpar5g9cDejA bits;
};
struct tyObject_Check__7OzxEL6sl2sLK509ac4JShA {
tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA nilability;
tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map;
tySequence__AHhlrIyws6DwjcjqnuoVWQ* elements;
};
struct tyTuple__3w8Q5T9cOF5FQ54JItYYe3Q {
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field0;
tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA Field1;
};
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* tyArray__Nfk9cOEzg2bRz9c1V8fGzONg[2];
typedef tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* tyArray__iegsN9bf6GqRiWprrJjTAoA[1];
struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg {
NI32 module;
NI32 symId;
NI32 typeId_0;
NIM_BOOL sealed;
};
typedef tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* tyArray__id9c0PBojP5C2oM2bRQSViA[3];
struct tyObject_HSlice__7TOOBlADhY009aGwq7hyBaw {
NI16 a;
NI16 b;
};
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
struct tySequence__dAjyAaabi52TN36Jp0fAXQ {
  TGenericSeq Sup;
  tyTuple__X9bWVAqRSgByRpQwn6owzEA data[SEQ_DECL_SIZE];
};
struct tySequence__wbHXzzfwTCmsKuzoRrgI3g {
  TGenericSeq Sup;
  tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw data[SEQ_DECL_SIZE];
};
struct tySequence__nueg5spSfGVW7EdegG2fTw {
  TGenericSeq Sup;
  tyTuple__QJASEmMHDLGFAvbisAV7AA data[SEQ_DECL_SIZE];
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__kGCKZrVGM65uzo2SGY9bxMQ {
  TGenericSeq Sup;
  tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA data[SEQ_DECL_SIZE];
};
struct tySequence__ShKVNN7kN9a0hT6rhE7ADzg {
  TGenericSeq Sup;
  tyObject_History__nemqwCae5qEp6Zk6QXd7RA data[SEQ_DECL_SIZE];
};
struct tySequence__TXTtz79abNCf5jWrlvNZpOw {
  TGenericSeq Sup;
  tySequence__ShKVNN7kN9a0hT6rhE7ADzg* data[SEQ_DECL_SIZE];
};
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  TGenericSeq Sup;
  NI data[SEQ_DECL_SIZE];
};
struct tySequence__AHhlrIyws6DwjcjqnuoVWQ {
  TGenericSeq Sup;
  tyTuple__3w8Q5T9cOF5FQ54JItYYe3Q data[SEQ_DECL_SIZE];
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
static N_NIMCALL(void, Marker_tySequence__dAjyAaabi52TN36Jp0fAXQ)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__wbHXzzfwTCmsKuzoRrgI3g)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__nueg5spSfGVW7EdegG2fTw)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__9bnT9cUqmgQIJCayD7fHaOUw)(void* p, NI op);
N_LIB_PRIVATE N_NOINLINE(void*, newObj)(TNimType* typ, NI size);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5331)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5293)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5338)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5336)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5287)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(void, preVisit__nilcheck_8813)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, toTable__nilcheck_8818)(tyTuple__cyDO9czMbIL47POKM3sIQng* pairs, NI pairsLen_0, tyObject_Table__rDTSDzC8VietpxpD1ELe1g* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ*, newIdentCache__idents_161)(void);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqRC1)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newIdentNode__ast_3700)(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*, getIdent__idents_152)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* ic, NimStringDesc* identifier);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void, genericAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(NI, symbol__nilcheck_1219)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NI, hashTree__treetab_5)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__nilcheck_1994)(tyObject_Table__rDTSDzC8VietpxpD1ELe1g t, NI key);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___nilcheck_7191)(tyObject_Table__rDTSDzC8VietpxpD1ELe1g* t, NI key, NI16 val);
N_LIB_PRIVATE N_NIMCALL(NI16, len__nilcheck_5932)(tySequence__IeU9azYSNIK3V9b36Ir6NZcw* a);
N_LIB_PRIVATE N_NIMCALL(void, add__nilcheck_8378)(tySequence__IeU9azYSNIK3V9b36Ir6NZcw** a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* value);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(void, preVisitNode__nilcheck_7029)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* node, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(NI16*, X5BX5D___nilcheck_2331)(tyObject_Table__rDTSDzC8VietpxpD1ELe1g* t, NI key);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___systemZdollars_3)(NI x);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lteq___nilcheck_176)(NI16 a, NI16 b);
N_LIB_PRIVATE N_NIMCALL(NI16, len__nilcheck_8709)(tySequence__wbHXzzfwTCmsKuzoRrgI3g* a);
N_LIB_PRIVATE N_NIMCALL(void, setLen__nilcheck_8717)(tySequence__wbHXzzfwTCmsKuzoRrgI3g** a, NI16 length);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(NI16, plus___nilcheck_195)(NI16 a, NI16 b);
N_LIB_PRIVATE N_NIMCALL(void, incl__pureZcollectionsZintsets_55)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw*, X5BX5D___nilcheck_3555)(tySequence__wbHXzzfwTCmsKuzoRrgI3g** a, NI16 index);
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___nilcheck_163)(NI16 a, NI16 b);
N_LIB_PRIVATE N_NIMCALL(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A*, newNilMap__nilcheck_237)(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* parent, NI count);
N_LIB_PRIVATE N_NIMCALL(NI16, len__nilcheck_300)(tySequence__kGCKZrVGM65uzo2SGY9bxMQ* a);
static N_NIMCALL(void, Marker_tySequence__kGCKZrVGM65uzo2SGY9bxMQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__ShKVNN7kN9a0hT6rhE7ADzg)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__TXTtz79abNCf5jWrlvNZpOw)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__4xhug3qIp2asVjvZ3bVlPQ)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(tySequence__kGCKZrVGM65uzo2SGY9bxMQ*, newSeqOfDistinct__nilcheck_362)(NI length);
N_LIB_PRIVATE N_NIMCALL(tySequence__kGCKZrVGM65uzo2SGY9bxMQ*, newSeq__nilcheck_345)(NI len);
N_LIB_PRIVATE N_NIMCALL(tySequence__TXTtz79abNCf5jWrlvNZpOw*, newSeqOfDistinct__nilcheck_427)(NI length);
N_LIB_PRIVATE N_NIMCALL(tySequence__TXTtz79abNCf5jWrlvNZpOw*, newSeq__nilcheck_383)(NI len);
N_LIB_PRIVATE N_NIMCALL(tySequence__qwqHTkRvwhrRyENtudHQ7g*, newSeqOfDistinct__nilcheck_483)(NI length);
N_LIB_PRIVATE N_NIMCALL(tySequence__qwqHTkRvwhrRyENtudHQ7g*, newSeq__nilcheck_448)(NI len);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___nilcheck_584)(tySequence__qwqHTkRvwhrRyENtudHQ7g** a, NI16 index, NI value);
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(void, initPackedSet__pureZcollectionsZintsets_16)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(void, add__nilcheck_640)(tySequence__wbHXzzfwTCmsKuzoRrgI3g** a, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* value);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NI, len__nilcheck_9426)(tyObject_Table__rDTSDzC8VietpxpD1ELe1g t);
N_LIB_PRIVATE N_NIMCALL(void, store__nilcheck_2683)(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, NI16 index, tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA value, tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* node);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___nilcheck_188)(NI16 a, NI16 b);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___nilcheck_2731)(tySequence__kGCKZrVGM65uzo2SGY9bxMQ** a, NI16 index, tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA value);
N_LIB_PRIVATE N_NIMCALL(tySequence__ShKVNN7kN9a0hT6rhE7ADzg**, X5BX5D___nilcheck_1191)(tySequence__TXTtz79abNCf5jWrlvNZpOw** a, NI16 index);
N_LIB_PRIVATE N_NIMCALL(void, aliasSet__nilcheck_2554)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, NI16 index, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw*, X5BX5D___nilcheck_1513)(tySequence__wbHXzzfwTCmsKuzoRrgI3g** a, NI index);
N_LIB_PRIVATE N_NIMCALL(NI*, X5BX5D___nilcheck_2477)(tySequence__qwqHTkRvwhrRyENtudHQ7g** a, NI16 index);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___nilcheck_2902)(tySequence__TXTtz79abNCf5jWrlvNZpOw** a, NI16 index, tySequence__ShKVNN7kN9a0hT6rhE7ADzg* value);
N_LIB_PRIVATE N_NIMCALL(void, genericSeqAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(NI16, index__nilcheck_1949)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA, typeNilability__nilcheck_4066)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(void, check__nilcheck_227)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result);
N_LIB_PRIVATE N_NIMCALL(tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA, X5BX5D___nilcheck_865)(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, NI16 index);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, gteq___nilcheck_184)(NI16 a, NI16 b);
N_LIB_PRIVATE N_NIMCALL(tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA*, X5BX5D___nilcheck_989)(tySequence__kGCKZrVGM65uzo2SGY9bxMQ** a, NI16 index);
N_LIB_PRIVATE N_NIMCALL(void, checkInfix__nilcheck_6297)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A*, checkCondition__nilcheck_231)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, NIM_BOOL reverse, NIM_BOOL base);
N_LIB_PRIVATE N_NIMCALL(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A*, union__nilcheck_5865)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* l, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A*, findCommonParent__nilcheck_5850)(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* l, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* r);
N_LIB_PRIVATE N_NIMCALL(tySequence__ShKVNN7kN9a0hT6rhE7ADzg*, history__nilcheck_1071)(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, NI16 index);
static N_INLINE(void, X5BX5D___nilcheck_5946)(tyObject_History__nemqwCae5qEp6Zk6QXd7RA* s, NI sLen_0, NI i, tyObject_History__nemqwCae5qEp6Zk6QXd7RA* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___renderer_2116)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(void, checkIsNil__nilcheck_6340)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, NIM_BOOL isElse, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result);
N_LIB_PRIVATE N_NIMCALL(void, checkCall__nilcheck_4068)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result);
N_LIB_PRIVATE N_NIMCALL(void, moveOut__nilcheck_2992)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* target);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___nilcheck_215)(NI a, NI b);
static N_INLINE(NI, len__nilcheck_1789)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s);
N_LIB_PRIVATE N_NIMCALL(void, excl__reorder_273)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(NI, minus___nilcheck_223)(NI a, NI b);
N_LIB_PRIVATE N_NIMCALL(NI, len__nilcheck_3439)(tySequence__wbHXzzfwTCmsKuzoRrgI3g* a);
N_LIB_PRIVATE N_NIMCALL(void, moveOutDependants__nilcheck_3493)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* node);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**, X5BX5D___nilcheck_1405)(tySequence__IeU9azYSNIK3V9b36Ir6NZcw** a, NI16 index);
N_LIB_PRIVATE N_NIMCALL(void, storeDependants__nilcheck_3627)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* node, tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA value);
static N_NIMCALL(void, Marker_tySequence__AHhlrIyws6DwjcjqnuoVWQ)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, checkDotExpr__nilcheck_5830)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result);
N_LIB_PRIVATE N_NIMCALL(void, checkRefExpr__nilcheck_5799)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_Check__7OzxEL6sl2sLK509ac4JShA check, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result);
N_LIB_PRIVATE N_NIMCALL(void, checkDeref__nilcheck_5792)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result);
N_LIB_PRIVATE N_NIMCALL(void, handleNilability__nilcheck_5787)(tyObject_Check__7OzxEL6sl2sLK509ac4JShA check, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map);
N_LIB_PRIVATE N_NIMCALL(void, derefWarning__nilcheck_4274)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA kind);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__nilcheck_4332)(tyObject_HashSet__zVZZy9cn25qKcaABhU9aN2vw s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw key);
N_LIB_PRIVATE N_NIMCALL(void, incl__nilcheck_4627)(tyObject_HashSet__zVZZy9cn25qKcaABhU9aN2vw* s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw key);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___systemZdollars_9)(NU64 x);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(void, checkIf__nilcheck_6230)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A*, reverseDirect__nilcheck_1223)(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map);
N_LIB_PRIVATE N_NIMCALL(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A*, copyMap__nilcheck_4056)(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map);
N_LIB_PRIVATE N_NIMCALL(tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA, reverse__nilcheck_6447)(tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA value);
static N_INLINE(tyObject_History__nemqwCae5qEp6Zk6QXd7RA*, X5BX5D___nilcheck_6635)(tyObject_History__nemqwCae5qEp6Zk6QXd7RA* s, NI sLen_0, NI i);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA, reverse__nilcheck_6450)(tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A*, add__nilcheck_5969)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* l, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* r);
N_LIB_PRIVATE N_NIMCALL(void, checkBranch__nilcheck_1225)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasUnstructuredControlFlowJump__nilcheck_1229)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, checkAsgn__nilcheck_6079)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* target, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* assigned, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result);
N_LIB_PRIVATE N_NIMCALL(void, move__nilcheck_3699)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* target, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* assigned);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newTree__ast_3356)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** children, NI childrenLen_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__nilcheck_6185)(tyObject_Table__rDTSDzC8VietpxpD1ELe1g t, NI key);
N_LIB_PRIVATE N_NIMCALL(void, checkFor__nilcheck_6269)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result);
N_LIB_PRIVATE N_NIMCALL(void, checkCase__nilcheck_6383)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, infixEq__nilcheck_6373)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* l, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, infix__nilcheck_6349)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* l, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* r, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, newSym__ast_3409)(tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw symKind, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg id, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options);
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextSymId__ast_3103)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newSymNode__ast_3707)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, newType__ast_3884)(tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg id, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner);
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextTypeId__ast_3122)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, infixOr__nilcheck_6378)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* l, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, prefixNot__nilcheck_6367)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* node);
N_LIB_PRIVATE N_NIMCALL(void, checkReturn__nilcheck_6224)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result);
N_LIB_PRIVATE N_NIMCALL(void, checkBracketExpr__nilcheck_5836)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result);
N_LIB_PRIVATE N_NIMCALL(void, checkTry__nilcheck_6420)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canRaise__ast_5100)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* fn);
N_LIB_PRIVATE N_NIMCALL(void, checkWhile__nilcheck_6286)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result);
static N_INLINE(NIM_BOOL, contains__nilcheck_9550)(tyObject_HSlice__7TOOBlADhY009aGwq7hyBaw s, NI16 value);
static N_INLINE(tyObject_HSlice__7TOOBlADhY009aGwq7hyBaw, dotdot___nilcheck_9478)(NI16 a, NI16 b);
N_LIB_PRIVATE N_NIMCALL(NI16, low__nilcheck_9453)(tySequence__TXTtz79abNCf5jWrlvNZpOw* a);
N_LIB_PRIVATE N_NIMCALL(NI16, high__nilcheck_9461)(tySequence__TXTtz79abNCf5jWrlvNZpOw* a);
N_LIB_PRIVATE N_NIMCALL(void, checkResult__nilcheck_6944)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map);
N_LIB_PRIVATE TNimType NTInilcheckercontext58objecttype__r0vZFiu6Xw1EWAX9crgVyow_;
N_LIB_PRIVATE TNimType NTItable__rDTSDzC8VietpxpD1ELe1g_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__X9bWVAqRSgByRpQwn6owzEA_;
extern TNimType NTIint__rR5Bzr1D5krxoo1NcNyeMA_;
extern TNimType NTIint4954__kDPg4wXyR8DDyA0MeEjIsw_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__dAjyAaabi52TN36Jp0fAXQ_;
extern TNimType NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_;
extern TNimType NTIpackedset__THXDbzJSs2hcC9a33en2pdw_;
N_LIB_PRIVATE TNimType NTIseqLintsetT__wbHXzzfwTCmsKuzoRrgI3g_;
N_LIB_PRIVATE TNimType NTIhashset__zVZZy9cn25qKcaABhU9aN2vw_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__QJASEmMHDLGFAvbisAV7AA_;
extern TNimType NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__nueg5spSfGVW7EdegG2fTw_;
extern TNimType NTIidgenerator__M4gwBCp6eTol0yFD6lAxTQ_;
extern TNimType NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_;
N_LIB_PRIVATE TNimType NTInilcheckercontext__9bnT9cUqmgQIJCayD7fHaOUw_;
static NIM_CONST tyArray__brqof9bq2QWioDkbae3wZsw TM__9a75rVZu7sg4HRrHPMS3VUw_7 = {{((NI) -1),
((NI16) 0)}
}
;
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_8, "result", 6);
extern NIM_CONST tySet_tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw nkLiterals__ast_3033;
N_LIB_PRIVATE TNimType NTInilmap58objecttype__2Zw1RuVpNwptw8NipVHY8A_;
N_LIB_PRIVATE TNimType NTInilability__XDKthSvkddpY2lzfr6uPgA_;
N_LIB_PRIVATE TNimType NTIseqLnilabilityT__kGCKZrVGM65uzo2SGY9bxMQ_;
N_LIB_PRIVATE TNimType NTIhistory__nemqwCae5qEp6Zk6QXd7RA_;
N_LIB_PRIVATE TNimType NTItransitionkind__MTYoDYWJEv6ZS8OvFNF5IA_;
extern TNimType NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_;
N_LIB_PRIVATE TNimType NTIseqLhistoryT__ShKVNN7kN9a0hT6rhE7ADzg_;
N_LIB_PRIVATE TNimType NTIseqLseqLhistoryTT__TXTtz79abNCf5jWrlvNZpOw_;
extern TNimType NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_;
N_LIB_PRIVATE TNimType NTInilmap__4xhug3qIp2asVjvZ3bVlPQ_;
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_17, "true", 4);
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_18, "false", 5);
N_LIB_PRIVATE TNimType NTILpnode_nilabilityT__3w8Q5T9cOF5FQ54JItYYe3Q_;
N_LIB_PRIVATE TNimType NTIseqLLpnode_nilabilityTT__AHhlrIyws6DwjcjqnuoVWQ_;
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_20, "it is nil", 9);
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_21, "it might be nil", 15);
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_22, "it is unreachable", 17);
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_23, "can\'t deref ", 12);
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_24, ", ", 2);
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_25, "\012", 1);
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_26, "  ", 2);
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_27, "param with nilable type", 23);
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_28, "it returns true for isNil", 25);
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_29, "assigns a value which might be nil", 34);
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_30, "passes it as a var arg which might change to nil", 48);
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_31, "it is nil by default", 20);
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_32, "it has ref type", 15);
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_33, "it is safe here as it returns false for isNil", 45);
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_34, "it might be changed directly or through an alias", 48);
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_35, "it might be changed because its base might be changed", 53);
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_36, " on line ", 9);
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_37, ":", 1);
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_39, "/home/runner/work/nightlies/nightlies/nim/compiler/nilcheck.nim", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9a75rVZu7sg4HRrHPMS3VUw_38 = {((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_39),
((NI) 575),
((NI) 9)}
;
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_40, "==", 2);
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_41, "and", 3);
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_42, "or", 2);
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_43, "not", 3);
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_44, "return value is nil", 19);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9a75rVZu7sg4HRrHPMS3VUw_45 = {((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_39),
((NI) 1178),
((NI) 11)}
;
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_46, "return value might be nil", 25);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9a75rVZu7sg4HRrHPMS3VUw_47 = {((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_39),
((NI) 1180),
((NI) 11)}
;
STRING_LITERAL(TM__9a75rVZu7sg4HRrHPMS3VUw_48, "return value is unreachable", 27);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9a75rVZu7sg4HRrHPMS3VUw_49 = {((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_39),
((NI) 1182),
((NI) 11)}
;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5240;
static N_NIMCALL(void, Marker_tySequence__dAjyAaabi52TN36Jp0fAXQ)(void* p, NI op) {
	tySequence__dAjyAaabi52TN36Jp0fAXQ* a;
	NI T1_;
	a = (tySequence__dAjyAaabi52TN36Jp0fAXQ*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__wbHXzzfwTCmsKuzoRrgI3g)(void* p, NI op) {
	tySequence__wbHXzzfwTCmsKuzoRrgI3g* a;
	NI T1_;
	NI T2_;
	a = (tySequence__wbHXzzfwTCmsKuzoRrgI3g*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].head, op);
	nimGCvisit((void*)a->data[T1_].data, op);
	T2_ = (NI)0;
	}
}
static N_NIMCALL(void, Marker_tySequence__nueg5spSfGVW7EdegG2fTw)(void* p, NI op) {
	tySequence__nueg5spSfGVW7EdegG2fTw* a;
	NI T1_;
	a = (tySequence__nueg5spSfGVW7EdegG2fTw*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tyRef__9bnT9cUqmgQIJCayD7fHaOUw)(void* p, NI op) {
	tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* a;
	a = (tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow*)p;
	nimGCvisit((void*)(*a).symbolIndices.data, op);
	nimGCvisit((void*)(*a).expressions, op);
	nimGCvisit((void*)(*a).dependants, op);
	nimGCvisit((void*)(*a).warningLocations.data, op);
	nimGCvisit((void*)(*a).idgen, op);
	nimGCvisit((void*)(*a).config, op);
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5331)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5293)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5336)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5287((&gch__system_5240.zct), c);
}
static N_INLINE(void, decRef__system_5338)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5336(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5293(src);
		incRef__system_5331(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5293((*dest));
		decRef__system_5338(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___nilcheck_1940)(NI a, NI b) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = (a == b);
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5293(p);
	decRef__system_5338(T1_);
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
N_LIB_PRIVATE N_NIMCALL(NI, symbol__nilcheck_1219)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	{
		result = ((NI) -2);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		{
			if (!((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 11))) goto LA5_;
			result = ((NI) -1);
		}
		goto LA3_;
		LA5_: ;
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym10_;
			xX60gensym10_ = (*n)._kind_4.sym;
			result = (NI)((NI)((NU32)(((NI) ((*xX60gensym10_).Sup.itemId.module))) << (NU32)(((NI) 20))) + ((NI) ((*xX60gensym10_).Sup.itemId.item)));
		}
		LA3_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63):
	{
		result = symbol__nilcheck_1219((*n)._kind_6.sons->data[((NI) 0)]);
	}
	break;
	default:
	{
		result = hashTree__treetab_5(n);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI16, len__nilcheck_5932)(tySequence__IeU9azYSNIK3V9b36Ir6NZcw* a) {
	NI16 result;
	NI T1_;
	result = (NI16)0;
	T1_ = (a ? a->Sup.len : 0);
	result = ((NI16) (T1_));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__nilcheck_8378)(tySequence__IeU9azYSNIK3V9b36Ir6NZcw** a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* value) {
	NI T1_;
	unsureAsgnRef((void**) (&(*a)), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) incrSeqV3((TGenericSeq*)((*a)), (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_)));
	T1_ = (*a)->Sup.len++;
	asgnRef((void**) (&(*a)->data[T1_]), value);
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___nilcheck_1944)(NI a) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = dollar___systemZdollars_3(a);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lteq___nilcheck_176)(NI16 a, NI16 b) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = (a <= b);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI16, len__nilcheck_8709)(tySequence__wbHXzzfwTCmsKuzoRrgI3g* a) {
	NI16 result;
	NI T1_;
	result = (NI16)0;
	T1_ = (a ? a->Sup.len : 0);
	result = ((NI16) (T1_));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__nilcheck_8717)(tySequence__wbHXzzfwTCmsKuzoRrgI3g** a, NI16 length) {
	unsureAsgnRef((void**) (&(*a)), (tySequence__wbHXzzfwTCmsKuzoRrgI3g*) setLengthSeqV2(((*a))?&((*a))->Sup:NIM_NIL, (&NTIseqLintsetT__wbHXzzfwTCmsKuzoRrgI3g_), ((NI) (length))));
}
N_LIB_PRIVATE N_NIMCALL(NI16, plus___nilcheck_195)(NI16 a, NI16 b) {
	NI16 result;
	result = (NI16)0;
	result = (NI16)(a + b);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw*, X5BX5D___nilcheck_3555)(tySequence__wbHXzzfwTCmsKuzoRrgI3g** a, NI16 index) {
	tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* result;
	result = (tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw*)0;
	result = (&(*a)->data[index]);
	return result;
}
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__ast_3155(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, preVisitNode__nilcheck_7029)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* node, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		NI nodeSymbol;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*node).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3) || (*node).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45));
		if (T3_) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = ((*node).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42));
		if (!(T5_)) goto LA6_;
		T5_ = ((nkLiterals__ast_3033[(NU)((*(*node)._kind_6.sons->data[((NI) 1)]).kind)>>3] &(1U<<((NU)((*(*node)._kind_6.sons->data[((NI) 1)]).kind)&7U)))!=0);
		LA6_: ;
		T3_ = T5_;
		LA4_: ;
		if (!T3_) goto LA7_;
		nodeSymbol = symbol__nilcheck_1219(node);
		{
			NIM_BOOL T11_;
			NI16 T14_;
			T11_ = (NIM_BOOL)0;
			T11_ = hasKey__nilcheck_1994((*ctx).symbolIndices, nodeSymbol);
			if (!!(T11_)) goto LA12_;
			T14_ = (NI16)0;
			T14_ = len__nilcheck_5932((*ctx).expressions);
			X5BX5Deq___nilcheck_7191((&(*ctx).symbolIndices), nodeSymbol, T14_);
			add__nilcheck_8378((&(*ctx).expressions), node);
		}
		LA12_: ;
		{
			if (!((*node).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45) || (*node).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42))) goto LA17_;
			{
				NIM_BOOL T21_;
				NIM_BOOL T22_;
				NIM_BOOL T24_;
				NIM_BOOL T25_;
				NI16 index;
				NI16* T31_;
				NI16 baseIndex;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* base;
				T21_ = (NIM_BOOL)0;
				T22_ = (NIM_BOOL)0;
				T22_ = ((*node).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45));
				if (!(T22_)) goto LA23_;
				T24_ = (NIM_BOOL)0;
				T25_ = (NIM_BOOL)0;
				T25_ = !(((*node).typ == 0));
				if (!(T25_)) goto LA26_;
				T25_ = ((*(*node).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22));
				LA26_: ;
				T24_ = T25_;
				if (!(T24_)) goto LA27_;
				T24_ = !((((*(*node).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 17))&63U)))!=0));
				LA27_: ;
				T22_ = T24_;
				LA23_: ;
				T21_ = T22_;
				if (T21_) goto LA28_;
				T21_ = ((*node).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42));
				LA28_: ;
				if (!T21_) goto LA29_;
				T31_ = (NI16*)0;
				T31_ = X5BX5D___nilcheck_2331((&(*ctx).symbolIndices), nodeSymbol);
				index = (*T31_);
				baseIndex = ((NI16) -1);
				{
					if (!!(((*(*node)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3) || (*(*node)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2)))) goto LA34_;
					base = (*(*node)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)];
				}
				goto LA32_;
				LA34_: ;
				{
					base = (*node)._kind_6.sons->data[((NI) 0)];
				}
				LA32_: ;
				{
					NI baseSymbol;
					tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* T55_;
					if (!!(((*base).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2)))) goto LA39_;
					baseSymbol = symbol__nilcheck_1219(base);
					{
						NIM_BOOL T43_;
						T43_ = (NIM_BOOL)0;
						T43_ = hasKey__nilcheck_1994((*ctx).symbolIndices, baseSymbol);
						if (!!(T43_)) goto LA44_;
						baseIndex = len__nilcheck_5932((*ctx).expressions);
					}
					goto LA41_;
					LA44_: ;
					{
						NI16* T47_;
						T47_ = (NI16*)0;
						T47_ = X5BX5D___nilcheck_2331((&(*ctx).symbolIndices), baseSymbol);
						baseIndex = (*T47_);
					}
					LA41_: ;
					{
						NI16 T50_;
						NIM_BOOL T51_;
						NI16 T54_;
						T50_ = (NI16)0;
						T50_ = len__nilcheck_8709((*ctx).dependants);
						T51_ = (NIM_BOOL)0;
						T51_ = lteq___nilcheck_176(T50_, baseIndex);
						if (!T51_) goto LA52_;
						T54_ = (NI16)0;
						T54_ = plus___nilcheck_195(baseIndex, ((NI16) 1));
						setLen__nilcheck_8717((&(*ctx).dependants), T54_);
					}
					LA52_: ;
					T55_ = (tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw*)0;
					T55_ = X5BX5D___nilcheck_3555((&(*ctx).dependants), baseIndex);
					incl__pureZcollectionsZintsets_55(T55_, ((NI) (index)));
				}
				LA39_: ;
			}
			LA29_: ;
		}
		LA17_: ;
	}
	LA7_: ;
	switch ((*node).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 4):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 15):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 16) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 18):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22):
	{
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45):
	{
		preVisitNode__nilcheck_7029(ctx, (*node)._kind_6.sons->data[((NI) 0)], conf);
	}
	break;
	default:
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* element;
			element = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(node);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA62;
						i = i_2;
						element = (*node)._kind_6.sons->data[i];
						preVisitNode__nilcheck_7029(ctx, element, conf);
						i_2 += ((NI) 1);
					} LA62: ;
				}
			}
		}
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___nilcheck_163)(NI16 a, NI16 b) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = (a < b);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, preVisit__nilcheck_8813)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T1_;
	tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw emptySet;
	toTable__nilcheck_8818(TM__9a75rVZu7sg4HRrHPMS3VUw_7, 1, (&(*ctx).symbolIndices));
	cache = newIdentCache__idents_161();
	if ((*ctx).expressions) { nimGCunrefNoCycle((*ctx).expressions); (*ctx).expressions = NIM_NIL; }
	(*ctx).expressions = (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) newSeqRC1((&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), 1);
	T1_ = NIM_NIL;
	T1_ = getIdent__idents_152(cache, ((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_8));
	asgnRef((void**) (&(*ctx).expressions->data[0]), newIdentNode__ast_3700(T1_, (*(*s).ast).info));
	nimZeroMem((void*)(&emptySet), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
	if ((*ctx).dependants) { nimGCunrefNoCycle((*ctx).dependants); (*ctx).dependants = NIM_NIL; }
	(*ctx).dependants = (tySequence__wbHXzzfwTCmsKuzoRrgI3g*) newSeqRC1((&NTIseqLintsetT__wbHXzzfwTCmsKuzoRrgI3g_), 1);
	genericAssign((void*)(&(*ctx).dependants->data[0]), (void*)(&emptySet), (&NTIpackedset__THXDbzJSs2hcC9a33en2pdw_));
	{
		NI i;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg;
		tySequence__IeU9azYSNIK3V9b36Ir6NZcw* colontmp_;
		NI i_2;
		NI L;
		NI T3_;
		i = (NI)0;
		arg = NIM_NIL;
		colontmp_ = NIM_NIL;
		colontmp_ = (*(*(*s).typ).n)._kind_6.sons;
		i_2 = ((NI) 0);
		T3_ = (colontmp_ ? colontmp_->Sup.len : 0);
		L = T3_;
		{
			while (1) {
				if (!(i_2 < L)) goto LA5;
				i = i_2;
				arg = colontmp_->data[i_2];
				{
					{
						NI argSymbol;
						if (!(((NI) 0) < i)) goto LA9_;
						{
							if (!!(((*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)))) goto LA13_;
							goto LA6;
						}
						LA13_: ;
						argSymbol = symbol__nilcheck_1219(arg);
						{
							NIM_BOOL T17_;
							NI16 T20_;
							T17_ = (NIM_BOOL)0;
							T17_ = hasKey__nilcheck_1994((*ctx).symbolIndices, argSymbol);
							if (!!(T17_)) goto LA18_;
							T20_ = (NI16)0;
							T20_ = len__nilcheck_5932((*ctx).expressions);
							X5BX5Deq___nilcheck_7191((&(*ctx).symbolIndices), argSymbol, T20_);
							add__nilcheck_8378((&(*ctx).expressions), arg);
						}
						LA18_: ;
					}
					LA9_: ;
				} LA6: ;
				i_2 += ((NI) 1);
			} LA5: ;
		}
	}
	preVisitNode__nilcheck_7029(ctx, body, conf);
	{
		NI16 T23_;
		NI16 T24_;
		NIM_BOOL T25_;
		NI16 T28_;
		T23_ = (NI16)0;
		T23_ = len__nilcheck_8709((*ctx).dependants);
		T24_ = (NI16)0;
		T24_ = len__nilcheck_5932((*ctx).expressions);
		T25_ = (NIM_BOOL)0;
		T25_ = lt___nilcheck_163(T23_, T24_);
		if (!T25_) goto LA26_;
		T28_ = (NI16)0;
		T28_ = len__nilcheck_5932((*ctx).expressions);
		setLen__nilcheck_8717((&(*ctx).dependants), T28_);
	}
	LA26_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI16, len__nilcheck_300)(tySequence__kGCKZrVGM65uzo2SGY9bxMQ* a) {
	NI16 result;
	NI T1_;
	result = (NI16)0;
	T1_ = (a ? a->Sup.len : 0);
	result = ((NI16) (T1_));
	return result;
}
static N_NIMCALL(void, Marker_tySequence__kGCKZrVGM65uzo2SGY9bxMQ)(void* p, NI op) {
	tySequence__kGCKZrVGM65uzo2SGY9bxMQ* a;
	NI T1_;
	a = (tySequence__kGCKZrVGM65uzo2SGY9bxMQ*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__ShKVNN7kN9a0hT6rhE7ADzg)(void* p, NI op) {
	tySequence__ShKVNN7kN9a0hT6rhE7ADzg* a;
	NI T1_;
	a = (tySequence__ShKVNN7kN9a0hT6rhE7ADzg*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].node, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__TXTtz79abNCf5jWrlvNZpOw)(void* p, NI op) {
	tySequence__TXTtz79abNCf5jWrlvNZpOw* a;
	NI T1_;
	a = (tySequence__TXTtz79abNCf5jWrlvNZpOw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_], op);
	}
}
static N_NIMCALL(void, Marker_tyRef__4xhug3qIp2asVjvZ3bVlPQ)(void* p, NI op) {
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* a;
	a = (tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A*)p;
	nimGCvisit((void*)(*a).expressions, op);
	nimGCvisit((void*)(*a).history, op);
	nimGCvisit((void*)(*a).setIndices, op);
	nimGCvisit((void*)(*a).sets, op);
	nimGCvisit((void*)(*a).parent, op);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__kGCKZrVGM65uzo2SGY9bxMQ*, newSeqOfDistinct__nilcheck_362)(NI length) {
	tySequence__kGCKZrVGM65uzo2SGY9bxMQ* result;
	result = NIM_NIL;
	result = newSeq__nilcheck_345(((NI) (length)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__TXTtz79abNCf5jWrlvNZpOw*, newSeqOfDistinct__nilcheck_427)(NI length) {
	tySequence__TXTtz79abNCf5jWrlvNZpOw* result;
	result = NIM_NIL;
	result = newSeq__nilcheck_383(((NI) (length)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__qwqHTkRvwhrRyENtudHQ7g*, newSeqOfDistinct__nilcheck_483)(NI length) {
	tySequence__qwqHTkRvwhrRyENtudHQ7g* result;
	result = NIM_NIL;
	result = newSeq__nilcheck_448(((NI) (length)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___nilcheck_584)(tySequence__qwqHTkRvwhrRyENtudHQ7g** a, NI16 index, NI value) {
	(*a)->data[index] = value;
}
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result) {
	initPackedSet__pureZcollectionsZintsets_16(Result);
}
N_LIB_PRIVATE N_NIMCALL(void, add__nilcheck_640)(tySequence__wbHXzzfwTCmsKuzoRrgI3g** a, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* value) {
	NI T1_;
	unsureAsgnRef((void**) (&(*a)), (tySequence__wbHXzzfwTCmsKuzoRrgI3g*) incrSeqV3((TGenericSeq*)((*a)), (&NTIseqLintsetT__wbHXzzfwTCmsKuzoRrgI3g_)));
	T1_ = (*a)->Sup.len++;
	genericAssign((void*)(&(*a)->data[T1_]), (void*)value, (&NTIpackedset__THXDbzJSs2hcC9a33en2pdw_));
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A*, newNilMap__nilcheck_237)(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* parent, NI count) {
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* result;
	NI expressionsCount;
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* T9_;
	result = NIM_NIL;
	expressionsCount = ((NI) 0);
	{
		if (!!((count == ((NI) -1)))) goto LA3_;
		expressionsCount = count;
	}
	goto LA1_;
	LA3_: ;
	{
		NI16 T8_;
		if (!!((parent == 0))) goto LA6_;
		T8_ = (NI16)0;
		T8_ = len__nilcheck_300((*parent).expressions);
		expressionsCount = ((NI) (T8_));
	}
	goto LA1_;
	LA6_: ;
	LA1_: ;
	T9_ = NIM_NIL;
	T9_ = (tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A*) newObj((&NTInilmap__4xhug3qIp2asVjvZ3bVlPQ_), sizeof(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A));
	asgnRef((void**) (&(*T9_).expressions), newSeqOfDistinct__nilcheck_362(expressionsCount));
	asgnRef((void**) (&(*T9_).history), newSeqOfDistinct__nilcheck_427(expressionsCount));
	asgnRef((void**) (&(*T9_).setIndices), newSeqOfDistinct__nilcheck_483(expressionsCount));
	asgnRef((void**) (&(*T9_).parent), parent);
	result = T9_;
	{
		if (!(parent == 0)) goto LA12_;
		{
			NI16 i;
			tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA expr;
			i = (NI16)0;
			expr = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA)0;
			{
				NI i_2;
				tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA element;
				tySequence__kGCKZrVGM65uzo2SGY9bxMQ* colontmp_;
				NI i_3;
				NI L;
				NI T16_;
				i_2 = (NI)0;
				element = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA)0;
				colontmp_ = NIM_NIL;
				colontmp_ = (*result).expressions;
				i_3 = ((NI) 0);
				T16_ = (colontmp_ ? colontmp_->Sup.len : 0);
				L = T16_;
				{
					while (1) {
						tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw newSet;
						if (!(i_3 < L)) goto LA18;
						i_2 = i_3;
						element = colontmp_->data[i_3];
						i = ((NI16) (i_2));
						expr = element;
						X5BX5Deq___nilcheck_584((&(*result).setIndices), i, ((NI) (i)));
						nimZeroMem((void*)(&newSet), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
						initIntSet__pureZcollectionsZintsets_238((&newSet));
						incl__pureZcollectionsZintsets_55((&newSet), ((NI) (i)));
						add__nilcheck_640((&(*result).sets), (&newSet));
						i_3 += ((NI) 1);
					} LA18: ;
				}
			}
		}
	}
	goto LA10_;
	LA12_: ;
	{
		{
			NI i_4;
			tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw exprs;
			i_4 = (NI)0;
			nimZeroMem((void*)(&exprs), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
			{
				NI i_5;
				tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw element_2;
				tySequence__wbHXzzfwTCmsKuzoRrgI3g* colontmp__2;
				NI i_6;
				NI L_2;
				NI T22_;
				i_5 = (NI)0;
				nimZeroMem((void*)(&element_2), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
				colontmp__2 = NIM_NIL;
				colontmp__2 = (*parent).sets;
				i_6 = ((NI) 0);
				T22_ = (colontmp__2 ? colontmp__2->Sup.len : 0);
				L_2 = T22_;
				{
					while (1) {
						if (!(i_6 < L_2)) goto LA24;
						i_5 = i_6;
						nimCopyMem((void*)(&element_2), (NIM_CONST void*)(&colontmp__2->data[i_6]), sizeof(element_2));
						i_4 = i_5;
						nimCopyMem((void*)(&exprs), (NIM_CONST void*)(&element_2), sizeof(exprs));
						add__nilcheck_640((&(*result).sets), (&exprs));
						i_6 += ((NI) 1);
					} LA24: ;
				}
			}
		}
		{
			NI16 i_7;
			NI index;
			i_7 = (NI16)0;
			index = (NI)0;
			{
				NI i_8;
				NI element_3;
				tySequence__qwqHTkRvwhrRyENtudHQ7g* colontmp__3;
				NI i_9;
				NI L_3;
				NI T27_;
				i_8 = (NI)0;
				element_3 = (NI)0;
				colontmp__3 = NIM_NIL;
				colontmp__3 = (*parent).setIndices;
				i_9 = ((NI) 0);
				T27_ = (colontmp__3 ? colontmp__3->Sup.len : 0);
				L_3 = T27_;
				{
					while (1) {
						if (!(i_9 < L_3)) goto LA29;
						i_8 = i_9;
						element_3 = colontmp__3->data[i_9];
						i_7 = ((NI16) (i_8));
						index = element_3;
						X5BX5Deq___nilcheck_584((&(*result).setIndices), i_7, index);
						i_9 += ((NI) 1);
					} LA29: ;
				}
			}
		}
	}
	LA10_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___nilcheck_188)(NI16 a, NI16 b) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = (a == b);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___nilcheck_2731)(tySequence__kGCKZrVGM65uzo2SGY9bxMQ** a, NI16 index, tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA value) {
	(*a)->data[index] = value;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__ShKVNN7kN9a0hT6rhE7ADzg**, X5BX5D___nilcheck_1191)(tySequence__TXTtz79abNCf5jWrlvNZpOw** a, NI16 index) {
	tySequence__ShKVNN7kN9a0hT6rhE7ADzg** result;
	result = (tySequence__ShKVNN7kN9a0hT6rhE7ADzg**)0;
	result = (&(*a)->data[index]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw*, X5BX5D___nilcheck_1513)(tySequence__wbHXzzfwTCmsKuzoRrgI3g** a, NI index) {
	tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* result;
	result = (tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw*)0;
	result = (&(*a)->data[index]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI*, X5BX5D___nilcheck_2477)(tySequence__qwqHTkRvwhrRyENtudHQ7g** a, NI16 index) {
	NI* result;
	result = (NI*)0;
	result = (&(*a)->data[index]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, aliasSet__nilcheck_2554)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, NI16 index, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result) {
	NI* T1_;
	tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* T2_;
	T1_ = (NI*)0;
	T1_ = X5BX5D___nilcheck_2477((&(*map).setIndices), index);
	T2_ = (tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw*)0;
	T2_ = X5BX5D___nilcheck_1513((&(*map).sets), (*T1_));
	genericAssign((void*)Result, (void*)(&(*T2_)), (&NTIpackedset__THXDbzJSs2hcC9a33en2pdw_));
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___nilcheck_2902)(tySequence__TXTtz79abNCf5jWrlvNZpOw** a, NI16 index, tySequence__ShKVNN7kN9a0hT6rhE7ADzg* value) {
	genericSeqAssign((&(*a)->data[index]), value, (&NTIseqLhistoryT__ShKVNN7kN9a0hT6rhE7ADzg_));
}
N_LIB_PRIVATE N_NIMCALL(void, store__nilcheck_2683)(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, NI16 index, tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA value, tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* node) {
	tySequence__ShKVNN7kN9a0hT6rhE7ADzg** T6_;
	tyObject_History__nemqwCae5qEp6Zk6QXd7RA T7_;
	NI T8_;
	tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw exprAliases;
{	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = eqeq___nilcheck_188(index, ((NI16) -1));
		if (!T3_) goto LA4_;
		goto BeforeRet_;
	}
	LA4_: ;
	X5BX5Deq___nilcheck_2731((&(*map).expressions), index, value);
	T6_ = (tySequence__ShKVNN7kN9a0hT6rhE7ADzg**)0;
	T6_ = X5BX5D___nilcheck_1191((&(*map).history), index);
	nimZeroMem((void*)(&T7_), sizeof(tyObject_History__nemqwCae5qEp6Zk6QXd7RA));
	nimZeroMem((void*)(&T7_), sizeof(tyObject_History__nemqwCae5qEp6Zk6QXd7RA));
	T7_.info = info;
	T7_.kind = kind;
	T7_.node = node;
	T7_.nilability = value;
	unsureAsgnRef((void**) (&(*T6_)), (tySequence__ShKVNN7kN9a0hT6rhE7ADzg*) incrSeqV3((TGenericSeq*)((*T6_)), (&NTIseqLhistoryT__ShKVNN7kN9a0hT6rhE7ADzg_)));
	T8_ = (*T6_)->Sup.len++;
	(*T6_)->data[T8_].info = T7_.info;
	(*T6_)->data[T8_].nilability = T7_.nilability;
	(*T6_)->data[T8_].kind = T7_.kind;
	asgnRef((void**) (&(*T6_)->data[T8_].node), T7_.node);
	nimZeroMem((void*)(&exprAliases), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
	aliasSet__nilcheck_2554(ctx, map, index, (&exprAliases));
	{
		NI a;
		a = (NI)0;
		{
			if (!(exprAliases.elems <= ((NI) 34))) goto LA12_;
			{
				NI i;
				NI i_2;
				i = (NI)0;
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < exprAliases.elems)) goto LA16;
						i = i_2;
						a = exprAliases.a[(i)- 0];
						{
							NIM_BOOL T19_;
							T19_ = (NIM_BOOL)0;
							T19_ = eqeq___nilcheck_188(((NI16) (a)), index);
							if (!!(T19_)) goto LA20_;
							X5BX5Deq___nilcheck_2731((&(*map).expressions), ((NI16) (a)), value);
							{
								tySequence__ShKVNN7kN9a0hT6rhE7ADzg* T26_;
								if (!(value == ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1))) goto LA24_;
								T26_ = NIM_NIL;
								T26_ = NIM_NIL;
								X5BX5Deq___nilcheck_2902((&(*map).history), ((NI16) (a)), T26_);
							}
							goto LA22_;
							LA24_: ;
							{
								tySequence__ShKVNN7kN9a0hT6rhE7ADzg** T28_;
								tyObject_History__nemqwCae5qEp6Zk6QXd7RA T29_;
								NI T30_;
								T28_ = (tySequence__ShKVNN7kN9a0hT6rhE7ADzg**)0;
								T28_ = X5BX5D___nilcheck_1191((&(*map).history), ((NI16) (a)));
								nimZeroMem((void*)(&T29_), sizeof(tyObject_History__nemqwCae5qEp6Zk6QXd7RA));
								nimZeroMem((void*)(&T29_), sizeof(tyObject_History__nemqwCae5qEp6Zk6QXd7RA));
								T29_.info = info;
								T29_.kind = ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 7);
								T29_.node = node;
								T29_.nilability = value;
								unsureAsgnRef((void**) (&(*T28_)), (tySequence__ShKVNN7kN9a0hT6rhE7ADzg*) incrSeqV3((TGenericSeq*)((*T28_)), (&NTIseqLhistoryT__ShKVNN7kN9a0hT6rhE7ADzg_)));
								T30_ = (*T28_)->Sup.len++;
								(*T28_)->data[T30_].info = T29_.info;
								(*T28_)->data[T30_].nilability = T29_.nilability;
								(*T28_)->data[T30_].kind = T29_.kind;
								asgnRef((void**) (&(*T28_)->data[T30_].node), T29_.node);
							}
							LA22_: ;
						}
						LA20_: ;
						i_2 += ((NI) 1);
					} LA16: ;
				}
			}
		}
		goto LA10_;
		LA12_: ;
		{
			tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* r;
			r = exprAliases.head;
			{
				while (1) {
					NI i_3;
					if (!!((r == ((tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) NIM_NIL)))) goto LA33;
					i_3 = ((NI) 0);
					{
						while (1) {
							NU w;
							NI j;
							if (!(i_3 <= ((NI) 15))) goto LA35;
							w = (*r).bits[(i_3)- 0];
							j = ((NI) 0);
							{
								while (1) {
									if (!!((w == ((NU) 0)))) goto LA37;
									{
										NI T42_;
										if (!!(((NU)(w & ((NU) 1)) == ((NU) 0)))) goto LA40_;
										T42_ = (NI)0;
										T42_ = pluspercent___system_696((NI)((NU32)(i_3) << (NU32)(((NI) 5))), j);
										a = (NI)((NI)((NU32)((*r).key) << (NU32)(((NI) 9))) | T42_);
										{
											NIM_BOOL T45_;
											T45_ = (NIM_BOOL)0;
											T45_ = eqeq___nilcheck_188(((NI16) (a)), index);
											if (!!(T45_)) goto LA46_;
											X5BX5Deq___nilcheck_2731((&(*map).expressions), ((NI16) (a)), value);
											{
												tySequence__ShKVNN7kN9a0hT6rhE7ADzg* T52_;
												if (!(value == ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1))) goto LA50_;
												T52_ = NIM_NIL;
												T52_ = NIM_NIL;
												X5BX5Deq___nilcheck_2902((&(*map).history), ((NI16) (a)), T52_);
											}
											goto LA48_;
											LA50_: ;
											{
												tySequence__ShKVNN7kN9a0hT6rhE7ADzg** T54_;
												tyObject_History__nemqwCae5qEp6Zk6QXd7RA T55_;
												NI T56_;
												T54_ = (tySequence__ShKVNN7kN9a0hT6rhE7ADzg**)0;
												T54_ = X5BX5D___nilcheck_1191((&(*map).history), ((NI16) (a)));
												nimZeroMem((void*)(&T55_), sizeof(tyObject_History__nemqwCae5qEp6Zk6QXd7RA));
												nimZeroMem((void*)(&T55_), sizeof(tyObject_History__nemqwCae5qEp6Zk6QXd7RA));
												T55_.info = info;
												T55_.kind = ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 7);
												T55_.node = node;
												T55_.nilability = value;
												unsureAsgnRef((void**) (&(*T54_)), (tySequence__ShKVNN7kN9a0hT6rhE7ADzg*) incrSeqV3((TGenericSeq*)((*T54_)), (&NTIseqLhistoryT__ShKVNN7kN9a0hT6rhE7ADzg_)));
												T56_ = (*T54_)->Sup.len++;
												(*T54_)->data[T56_].info = T55_.info;
												(*T54_)->data[T56_].nilability = T55_.nilability;
												(*T54_)->data[T56_].kind = T55_.kind;
												asgnRef((void**) (&(*T54_)->data[T56_].node), T55_.node);
											}
											LA48_: ;
										}
										LA46_: ;
									}
									LA40_: ;
									j += ((NI) 1);
									w = (NU)((NU32)(w) >> (NU32)(((NI) 1)));
								} LA37: ;
							}
							i_3 += ((NI) 1);
						} LA35: ;
					}
					r = (*r).next;
				} LA33: ;
			}
		}
		LA10_: ;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI16, index__nilcheck_1949)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI16 result;
	NI a;
{	result = (NI16)0;
	a = symbol__nilcheck_1219(n);
	{
		NIM_BOOL T3_;
		NI16* T6_;
		T3_ = (NIM_BOOL)0;
		T3_ = hasKey__nilcheck_1994((*ctx).symbolIndices, a);
		if (!T3_) goto LA4_;
		T6_ = (NI16*)0;
		T6_ = X5BX5D___nilcheck_2331((&(*ctx).symbolIndices), a);
		result = (*T6_);
		goto BeforeRet_;
	}
	goto LA1_;
	LA4_: ;
	{
		result = ((NI16) -1);
		goto BeforeRet_;
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA, typeNilability__nilcheck_4066)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ) {
	tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA result;
	result = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA)0;
	{
		if (!(((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 17))&63U)))!=0)) goto LA3_;
		result = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1);
	}
	goto LA1_;
	LA3_: ;
	{
		if (!((*typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22) || (*typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29) || (*typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21) || (*typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 26))) goto LA6_;
		result = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 2);
	}
	goto LA1_;
	LA6_: ;
	{
		result = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, gteq___nilcheck_184)(NI16 a, NI16 b) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = (b <= a);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA*, X5BX5D___nilcheck_989)(tySequence__kGCKZrVGM65uzo2SGY9bxMQ** a, NI16 index) {
	tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA* result;
	result = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA*)0;
	result = (&(*a)->data[index]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA, X5BX5D___nilcheck_865)(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, NI16 index) {
	tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA result;
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* now;
{	result = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA)0;
	{
		NIM_BOOL T3_;
		NI16 T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = lt___nilcheck_163(index, ((NI16) 0));
		if (T3_) goto LA4_;
		T5_ = (NI16)0;
		T5_ = len__nilcheck_300((*map).expressions);
		T3_ = gteq___nilcheck_184(index, T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		result = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 2);
		goto BeforeRet_;
	}
	LA6_: ;
	now = map;
	{
		while (1) {
			if (!!((now == 0))) goto LA9;
			{
				tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA* T12_;
				tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA* T15_;
				T12_ = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA*)0;
				T12_ = X5BX5D___nilcheck_989((&(*now).expressions), index);
				if (!!(((*T12_) == ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 0)))) goto LA13_;
				T15_ = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA*)0;
				T15_ = X5BX5D___nilcheck_989((&(*now).expressions), index);
				result = (*T15_);
				goto BeforeRet_;
			}
			LA13_: ;
			now = (*now).parent;
		} LA9: ;
	}
	result = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 2);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A*, checkCondition__nilcheck_231)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, NIM_BOOL reverse, NIM_BOOL base) {
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* result;
	result = NIM_NIL;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27))) goto LA3_;
		result = newNilMap__nilcheck_237(map, ((NI) -1));
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* element;
			element = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA8;
						i = i_2;
						element = (*n)._kind_6.sons->data[i];
						{
							NIM_BOOL T11_;
							NIM_BOOL T12_;
							tyObject_Check__7OzxEL6sl2sLK509ac4JShA T17_;
							T11_ = (NIM_BOOL)0;
							T12_ = (NIM_BOOL)0;
							T12_ = ((*element).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65));
							if (!(T12_)) goto LA13_;
							T12_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
							LA13_: ;
							T11_ = T12_;
							if (!(T11_)) goto LA14_;
							T11_ = ((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 143));
							LA14_: ;
							if (!T11_) goto LA15_;
							nimZeroMem((void*)(&T17_), sizeof(tyObject_Check__7OzxEL6sl2sLK509ac4JShA));
							check__nilcheck_227((*element)._kind_6.sons->data[((NI) 0)], ctx, result, (&T17_));
							result = T17_.map;
						}
						goto LA9_;
						LA15_: ;
						{
							tyObject_Check__7OzxEL6sl2sLK509ac4JShA T19_;
							nimZeroMem((void*)(&T19_), sizeof(tyObject_Check__7OzxEL6sl2sLK509ac4JShA));
							check__nilcheck_227(element, ctx, result, (&T19_));
							result = T19_.map;
						}
						LA9_: ;
						i_2 += ((NI) 1);
					} LA8: ;
				}
			}
		}
		{
			NIM_BOOL T22_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg;
			T22_ = (NIM_BOOL)0;
			T22_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
			if (!(T22_)) goto LA23_;
			T22_ = ((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 143));
			LA23_: ;
			if (!T22_) goto LA24_;
			arg = (*n)._kind_6.sons->data[((NI) 1)];
			{
				while (1) {
					if (!((*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65))) goto LA27;
					arg = (*arg)._kind_6.sons->data[((NI) 0)];
				} LA27: ;
			}
			{
				NIM_BOOL T30_;
				NIM_BOOL T32_;
				NI16 a;
				tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA T36_;
				tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA T42_;
				T30_ = (NIM_BOOL)0;
				T30_ = ((*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3) || (*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45));
				if (T30_) goto LA31_;
				T32_ = (NIM_BOOL)0;
				T32_ = ((*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42));
				if (!(T32_)) goto LA33_;
				T32_ = ((nkLiterals__ast_3033[(NU)((*(*arg)._kind_6.sons->data[((NI) 1)]).kind)>>3] &(1U<<((NU)((*(*arg)._kind_6.sons->data[((NI) 1)]).kind)&7U)))!=0);
				LA33_: ;
				T30_ = T32_;
				LA31_: ;
				if (!T30_) goto LA34_;
				a = index__nilcheck_1949(ctx, arg);
				T36_ = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA)0;
				{
					if (!!(reverse)) goto LA39_;
					T36_ = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 3);
				}
				goto LA37_;
				LA39_: ;
				{
					T36_ = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1);
				}
				LA37_: ;
				T42_ = (tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA)0;
				{
					if (!!(reverse)) goto LA45_;
					T42_ = ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 3);
				}
				goto LA43_;
				LA45_: ;
				{
					T42_ = ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 6);
				}
				LA43_: ;
				store__nilcheck_2683(result, ctx, a, T36_, T42_, (*n).info, arg);
			}
			goto LA28_;
			LA34_: ;
			{
			}
			LA28_: ;
		}
		goto LA20_;
		LA24_: ;
		{
		}
		LA20_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T51_;
		NIM_BOOL T52_;
		T51_ = (NIM_BOOL)0;
		T52_ = (NIM_BOOL)0;
		T52_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30));
		if (!(T52_)) goto LA53_;
		T52_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		LA53_: ;
		T51_ = T52_;
		if (!(T51_)) goto LA54_;
		T51_ = ((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 96));
		LA54_: ;
		if (!T51_) goto LA55_;
		result = checkCondition__nilcheck_231((*n)._kind_6.sons->data[((NI) 1)], ctx, map, !(reverse), NIM_FALSE);
	}
	goto LA1_;
	LA55_: ;
	{
		tyObject_Check__7OzxEL6sl2sLK509ac4JShA T60_;
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29))) goto LA58_;
		result = newNilMap__nilcheck_237(map, ((NI) -1));
		nimZeroMem((void*)(&T60_), sizeof(tyObject_Check__7OzxEL6sl2sLK509ac4JShA));
		checkInfix__nilcheck_6297(n, ctx, result, (&T60_));
		result = T60_.map;
	}
	goto LA1_;
	LA58_: ;
	{
		tyObject_Check__7OzxEL6sl2sLK509ac4JShA T62_;
		nimZeroMem((void*)(&T62_), sizeof(tyObject_Check__7OzxEL6sl2sLK509ac4JShA));
		check__nilcheck_227(n, ctx, map, (&T62_));
		result = T62_.map;
		result = newNilMap__nilcheck_237(map, ((NI) -1));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A*, findCommonParent__nilcheck_5850)(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* l, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* r) {
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* result;
{	result = NIM_NIL;
	result = (*l).parent;
	{
		while (1) {
			tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* rparent;
			if (!!((result == 0))) goto LA2;
			rparent = (*r).parent;
			{
				while (1) {
					if (!!((rparent == 0))) goto LA4;
					{
						if (!(result == rparent)) goto LA7_;
						goto BeforeRet_;
					}
					LA7_: ;
					rparent = (*rparent).parent;
				} LA4: ;
			}
			result = (*result).parent;
		} LA2: ;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__ShKVNN7kN9a0hT6rhE7ADzg*, history__nilcheck_1071)(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, NI16 index) {
	tySequence__ShKVNN7kN9a0hT6rhE7ADzg* result;
	result = NIM_NIL;
	{
		NI16 T3_;
		NIM_BOOL T4_;
		tySequence__ShKVNN7kN9a0hT6rhE7ADzg** T7_;
		T3_ = (NI16)0;
		T3_ = len__nilcheck_300((*map).expressions);
		T4_ = (NIM_BOOL)0;
		T4_ = lt___nilcheck_163(index, T3_);
		if (!T4_) goto LA5_;
		T7_ = (tySequence__ShKVNN7kN9a0hT6rhE7ADzg**)0;
		T7_ = X5BX5D___nilcheck_1191((&(*map).history), index);
		genericSeqAssign((&result), (*T7_), (&NTIseqLhistoryT__ShKVNN7kN9a0hT6rhE7ADzg_));
	}
	goto LA1_;
	LA5_: ;
	{
		result = NIM_NIL;
	}
	LA1_: ;
	return result;
}
static N_INLINE(void, X5BX5D___nilcheck_5946)(tyObject_History__nemqwCae5qEp6Zk6QXd7RA* s, NI sLen_0, NI i, tyObject_History__nemqwCae5qEp6Zk6QXd7RA* Result) {
	(*Result).info = s[(NI)(sLen_0 - i)].info;
	(*Result).nilability = s[(NI)(sLen_0 - i)].nilability;
	(*Result).kind = s[(NI)(sLen_0 - i)].kind;
	unsureAsgnRef((void**) (&(*Result).node), s[(NI)(sLen_0 - i)].node);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A*, union__nilcheck_5865)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* l, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* r) {
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* result;
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* common;
	NI16 T8_;
{	result = NIM_NIL;
	{
		if (!(l == 0)) goto LA3_;
		result = r;
		goto BeforeRet_;
	}
	goto LA1_;
	LA3_: ;
	{
		if (!(r == 0)) goto LA6_;
		result = l;
		goto BeforeRet_;
	}
	goto LA1_;
	LA6_: ;
	LA1_: ;
	common = findCommonParent__nilcheck_5850(l, r);
	T8_ = (NI16)0;
	T8_ = len__nilcheck_5932((*ctx).expressions);
	result = newNilMap__nilcheck_237(common, ((NI) (T8_)));
	{
		NI16 index;
		tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA value;
		index = (NI16)0;
		value = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA)0;
		{
			NI16 index_2;
			tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA value_2;
			index_2 = (NI16)0;
			value_2 = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA)0;
			{
				NI i;
				tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA element;
				tySequence__kGCKZrVGM65uzo2SGY9bxMQ* colontmp_;
				NI i_2;
				NI L;
				NI T12_;
				i = (NI)0;
				element = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA)0;
				colontmp_ = NIM_NIL;
				colontmp_ = (*l).expressions;
				i_2 = ((NI) 0);
				T12_ = (colontmp_ ? colontmp_->Sup.len : 0);
				L = T12_;
				{
					while (1) {
						tySequence__ShKVNN7kN9a0hT6rhE7ADzg* h;
						tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
						tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA T22_;
						if (!(i_2 < L)) goto LA14;
						i = i_2;
						element = colontmp_->data[i_2];
						index_2 = ((NI16) (i));
						value_2 = element;
						index = index_2;
						value = X5BX5D___nilcheck_865(l, index_2);
						h = history__nilcheck_1071(r, index);
						{
							NI T17_;
							tyObject_History__nemqwCae5qEp6Zk6QXd7RA T20_;
							T17_ = (h ? h->Sup.len : 0);
							if (!(((NI) 0) < T17_)) goto LA18_;
							nimZeroMem((void*)(&T20_), sizeof(tyObject_History__nemqwCae5qEp6Zk6QXd7RA));
							X5BX5D___nilcheck_5946((h) ? (h->data) : NIM_NIL, (h ? h->Sup.len : 0), ((NI) 1), (&T20_));
							info = T20_.info;
						}
						goto LA15_;
						LA18_: ;
						{
							nimZeroMem((void*)(&info), sizeof(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw));
							info.line = ((NU16) 0);
						}
						LA15_: ;
						T22_ = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA)0;
						{
							tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA T25_;
							T25_ = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA)0;
							T25_ = X5BX5D___nilcheck_865(r, index);
							if (!(value == T25_)) goto LA26_;
							T22_ = value;
						}
						goto LA23_;
						LA26_: ;
						{
							T22_ = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 2);
						}
						LA23_: ;
						store__nilcheck_2683(result, ctx, index, T22_, ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 1), info, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
						i_2 += ((NI) 1);
					} LA14: ;
				}
			}
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkInfix__nilcheck_6297)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result) {
	(*Result).nilability = 0;
	unsureAsgnRef((void**)&(*Result).map, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).elements, NIM_NIL);
	{
		tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* mapL;
		tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* mapR;
		if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA3_;
		mapL = NIM_NIL;
		mapR = NIM_NIL;
		{
			if (!!(((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 109) || (*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 87)))) goto LA7_;
			mapL = checkCondition__nilcheck_231((*n)._kind_6.sons->data[((NI) 1)], ctx, map, NIM_FALSE, NIM_FALSE);
			mapR = checkCondition__nilcheck_231((*n)._kind_6.sons->data[((NI) 2)], ctx, map, NIM_FALSE, NIM_FALSE);
		}
		LA7_: ;
		switch ((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic) {
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 110):
		{
			unsureAsgnRef((void**) (&(*Result).map), union__nilcheck_5865(ctx, mapL, mapR));
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 109):
		{
			unsureAsgnRef((void**) (&(*Result).map), checkCondition__nilcheck_231((*n)._kind_6.sons->data[((NI) 1)], ctx, map, NIM_FALSE, NIM_FALSE));
			unsureAsgnRef((void**) (&(*Result).map), checkCondition__nilcheck_231((*n)._kind_6.sons->data[((NI) 2)], ctx, (*Result).map, NIM_FALSE, NIM_FALSE));
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 87):
		{
			{
				if (!((*(*n)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6))) goto LA14_;
				{
					NimStringDesc* T18_;
					T18_ = NIM_NIL;
					T18_ = dollar___renderer_2116((*n)._kind_6.sons->data[((NI) 2)]);
					if (!eqStrings(T18_, ((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_17))) goto LA19_;
					unsureAsgnRef((void**) (&(*Result).map), checkCondition__nilcheck_231((*n)._kind_6.sons->data[((NI) 1)], ctx, map, NIM_FALSE, NIM_FALSE));
				}
				goto LA16_;
				LA19_: ;
				{
					NimStringDesc* T22_;
					T22_ = NIM_NIL;
					T22_ = dollar___renderer_2116((*n)._kind_6.sons->data[((NI) 2)]);
					if (!eqStrings(T22_, ((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_18))) goto LA23_;
					unsureAsgnRef((void**) (&(*Result).map), checkCondition__nilcheck_231((*n)._kind_6.sons->data[((NI) 1)], ctx, map, NIM_TRUE, NIM_FALSE));
				}
				goto LA16_;
				LA23_: ;
				LA16_: ;
			}
			goto LA12_;
			LA14_: ;
			{
				if (!((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6))) goto LA26_;
				{
					NimStringDesc* T30_;
					T30_ = NIM_NIL;
					T30_ = dollar___renderer_2116((*n)._kind_6.sons->data[((NI) 1)]);
					if (!eqStrings(T30_, ((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_17))) goto LA31_;
					unsureAsgnRef((void**) (&(*Result).map), checkCondition__nilcheck_231((*n)._kind_6.sons->data[((NI) 2)], ctx, map, NIM_FALSE, NIM_FALSE));
				}
				goto LA28_;
				LA31_: ;
				{
					NimStringDesc* T34_;
					T34_ = NIM_NIL;
					T34_ = dollar___renderer_2116((*n)._kind_6.sons->data[((NI) 1)]);
					if (!eqStrings(T34_, ((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_18))) goto LA35_;
					unsureAsgnRef((void**) (&(*Result).map), checkCondition__nilcheck_231((*n)._kind_6.sons->data[((NI) 2)], ctx, map, NIM_TRUE, NIM_FALSE));
				}
				goto LA28_;
				LA35_: ;
				LA28_: ;
			}
			goto LA12_;
			LA26_: ;
			LA12_: ;
			{
				if (!((*Result).map == 0)) goto LA39_;
				unsureAsgnRef((void**) (&(*Result).map), map);
			}
			LA39_: ;
		}
		break;
		default:
		{
			unsureAsgnRef((void**) (&(*Result).map), map);
		}
		break;
		}
	}
	goto LA1_;
	LA3_: ;
	{
		unsureAsgnRef((void**) (&(*Result).map), map);
	}
	LA1_: ;
	(*Result).nilability = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, checkIsNil__nilcheck_6340)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, NIM_BOOL isElse, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* value;
	NI16 T1_;
	tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA T2_;
	(*Result).nilability = 0;
	unsureAsgnRef((void**)&(*Result).map, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).elements, NIM_NIL);
	unsureAsgnRef((void**) (&(*Result).map), newNilMap__nilcheck_237(map, ((NI) -1)));
	value = (*n)._kind_6.sons->data[((NI) 1)];
	T1_ = (NI16)0;
	T1_ = index__nilcheck_1949(ctx, (*n)._kind_6.sons->data[((NI) 1)]);
	T2_ = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA)0;
	{
		if (!!(isElse)) goto LA5_;
		T2_ = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 3);
	}
	goto LA3_;
	LA5_: ;
	{
		T2_ = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1);
	}
	LA3_: ;
	store__nilcheck_2683((*Result).map, ctx, T1_, T2_, ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 0), (*n).info, n);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___nilcheck_215)(NI a, NI b) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = (a == b);
	return result;
}
static N_INLINE(NI, len__nilcheck_1789)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s) {
	NI result;
	result = (NI)0;
	{
		if (!((*s).elems < ((NI) 34))) goto LA3_;
		result = (*s).elems;
	}
	goto LA1_;
	LA3_: ;
	{
		result = ((NI) 0);
		{
			NI _;
			_ = (NI)0;
			{
				if (!((*s).elems <= ((NI) 34))) goto LA9_;
				{
					NI i;
					NI i_2;
					i = (NI)0;
					i_2 = ((NI) 0);
					{
						while (1) {
							if (!(i_2 < (*s).elems)) goto LA13;
							i = i_2;
							_ = (*s).a[(i)- 0];
							result += ((NI) 1);
							i_2 += ((NI) 1);
						} LA13: ;
					}
				}
			}
			goto LA7_;
			LA9_: ;
			{
				tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* r;
				r = (*s).head;
				{
					while (1) {
						NI i_3;
						if (!!((r == ((tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) NIM_NIL)))) goto LA16;
						i_3 = ((NI) 0);
						{
							while (1) {
								NU w;
								NI j;
								if (!(i_3 <= ((NI) 15))) goto LA18;
								w = (*r).bits[(i_3)- 0];
								j = ((NI) 0);
								{
									while (1) {
										if (!!((w == ((NU) 0)))) goto LA20;
										{
											NI T25_;
											if (!!(((NU)(w & ((NU) 1)) == ((NU) 0)))) goto LA23_;
											T25_ = (NI)0;
											T25_ = pluspercent___system_696((NI)((NU32)(i_3) << (NU32)(((NI) 5))), j);
											_ = (NI)((NI)((NU32)((*r).key) << (NU32)(((NI) 9))) | T25_);
											result += ((NI) 1);
										}
										LA23_: ;
										j += ((NI) 1);
										w = (NU)((NU32)(w) >> (NU32)(((NI) 1)));
									} LA20: ;
								}
								i_3 += ((NI) 1);
							} LA18: ;
						}
						r = (*r).next;
					} LA16: ;
				}
			}
			LA7_: ;
		}
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, minus___nilcheck_223)(NI a, NI b) {
	NI result;
	result = (NI)0;
	result = (NI)(a - b);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, len__nilcheck_3439)(tySequence__wbHXzzfwTCmsKuzoRrgI3g* a) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = (a ? a->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, moveOut__nilcheck_2992)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* target) {
	NI16 targetIndex;
	NI targetSetIndex;
	NI* T1_;
	targetIndex = index__nilcheck_1949(ctx, target);
	T1_ = (NI*)0;
	T1_ = X5BX5D___nilcheck_2477((&(*map).setIndices), targetIndex);
	targetSetIndex = (*T1_);
	{
		NIM_BOOL T4_;
		tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw targetSet;
		tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* T7_;
		T4_ = (NIM_BOOL)0;
		T4_ = eqeq___nilcheck_215(targetSetIndex, ((NI) -1));
		if (!!(T4_)) goto LA5_;
		nimZeroMem((void*)(&targetSet), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
		T7_ = (tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw*)0;
		T7_ = X5BX5D___nilcheck_1513((&(*map).sets), targetSetIndex);
		genericAssign((void*)(&targetSet), (void*)(&(*T7_)), (&NTIpackedset__THXDbzJSs2hcC9a33en2pdw_));
		{
			NI T10_;
			NI16 other;
			NI* T43_;
			tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* T44_;
			tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw newSet;
			NI T45_;
			NI T46_;
			T10_ = (NI)0;
			T10_ = len__nilcheck_1789((&targetSet));
			if (!(((NI) 1) < T10_)) goto LA11_;
			other = (NI16)0;
			{
				NI element;
				element = (NI)0;
				{
					if (!(targetSet.elems <= ((NI) 34))) goto LA16_;
					{
						NI i;
						NI i_2;
						i = (NI)0;
						i_2 = ((NI) 0);
						{
							while (1) {
								if (!(i_2 < targetSet.elems)) goto LA20;
								i = i_2;
								element = targetSet.a[(i)- 0];
								{
									NIM_BOOL T23_;
									T23_ = (NIM_BOOL)0;
									T23_ = eqeq___nilcheck_188(((NI16) (element)), targetIndex);
									if (!!(T23_)) goto LA24_;
									other = ((NI16) (element));
									goto LA13;
								}
								LA24_: ;
								i_2 += ((NI) 1);
							} LA20: ;
						}
					}
				}
				goto LA14_;
				LA16_: ;
				{
					tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* r;
					r = targetSet.head;
					{
						while (1) {
							NI i_3;
							if (!!((r == ((tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) NIM_NIL)))) goto LA28;
							i_3 = ((NI) 0);
							{
								while (1) {
									NU w;
									NI j;
									if (!(i_3 <= ((NI) 15))) goto LA30;
									w = (*r).bits[(i_3)- 0];
									j = ((NI) 0);
									{
										while (1) {
											if (!!((w == ((NU) 0)))) goto LA32;
											{
												NI T37_;
												if (!!(((NU)(w & ((NU) 1)) == ((NU) 0)))) goto LA35_;
												T37_ = (NI)0;
												T37_ = pluspercent___system_696((NI)((NU32)(i_3) << (NU32)(((NI) 5))), j);
												element = (NI)((NI)((NU32)((*r).key) << (NU32)(((NI) 9))) | T37_);
												{
													NIM_BOOL T40_;
													T40_ = (NIM_BOOL)0;
													T40_ = eqeq___nilcheck_188(((NI16) (element)), targetIndex);
													if (!!(T40_)) goto LA41_;
													other = ((NI16) (element));
													goto LA13;
												}
												LA41_: ;
											}
											LA35_: ;
											j += ((NI) 1);
											w = (NU)((NU32)(w) >> (NU32)(((NI) 1)));
										} LA32: ;
									}
									i_3 += ((NI) 1);
								} LA30: ;
							}
							r = (*r).next;
						} LA28: ;
					}
				}
				LA14_: ;
			} LA13: ;
			T43_ = (NI*)0;
			T43_ = X5BX5D___nilcheck_2477((&(*map).setIndices), other);
			T44_ = (tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw*)0;
			T44_ = X5BX5D___nilcheck_1513((&(*map).sets), (*T43_));
			excl__reorder_273(T44_, ((NI) (targetIndex)));
			nimZeroMem((void*)(&newSet), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
			initIntSet__pureZcollectionsZintsets_238((&newSet));
			incl__pureZcollectionsZintsets_55((&newSet), ((NI) (targetIndex)));
			add__nilcheck_640((&(*map).sets), (&newSet));
			T45_ = (NI)0;
			T45_ = len__nilcheck_3439((*map).sets);
			T46_ = (NI)0;
			T46_ = minus___nilcheck_223(T45_, ((NI) 1));
			X5BX5Deq___nilcheck_584((&(*map).setIndices), targetIndex, T46_);
		}
		LA11_: ;
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**, X5BX5D___nilcheck_1405)(tySequence__IeU9azYSNIK3V9b36Ir6NZcw** a, NI16 index) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** result;
	result = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
	result = &(*a)->data[index];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, moveOutDependants__nilcheck_3493)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* node) {
	NI16 index;
	index = index__nilcheck_1949(ctx, node);
	{
		NI dependant;
		tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw colontmp_;
		tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* T2_;
		dependant = (NI)0;
		nimZeroMem((void*)(&colontmp_), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
		T2_ = (tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw*)0;
		T2_ = X5BX5D___nilcheck_3555((&(*ctx).dependants), index);
		nimCopyMem((void*)(&colontmp_), (NIM_CONST void*)(&(*T2_)), sizeof(colontmp_));
		{
			if (!(colontmp_.elems <= ((NI) 34))) goto LA5_;
			{
				NI i;
				NI i_2;
				i = (NI)0;
				i_2 = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** T10_;
						if (!(i_2 < colontmp_.elems)) goto LA9;
						i = i_2;
						dependant = colontmp_.a[(i)- 0];
						T10_ = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
						T10_ = X5BX5D___nilcheck_1405((&(*ctx).expressions), ((NI16) (dependant)));
						moveOut__nilcheck_2992(ctx, map, (*T10_));
						i_2 += ((NI) 1);
					} LA9: ;
				}
			}
		}
		goto LA3_;
		LA5_: ;
		{
			tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* r;
			r = colontmp_.head;
			{
				while (1) {
					NI i_3;
					if (!!((r == ((tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) NIM_NIL)))) goto LA13;
					i_3 = ((NI) 0);
					{
						while (1) {
							NU w;
							NI j;
							if (!(i_3 <= ((NI) 15))) goto LA15;
							w = (*r).bits[(i_3)- 0];
							j = ((NI) 0);
							{
								while (1) {
									if (!!((w == ((NU) 0)))) goto LA17;
									{
										NI T22_;
										tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** T23_;
										if (!!(((NU)(w & ((NU) 1)) == ((NU) 0)))) goto LA20_;
										T22_ = (NI)0;
										T22_ = pluspercent___system_696((NI)((NU32)(i_3) << (NU32)(((NI) 5))), j);
										dependant = (NI)((NI)((NU32)((*r).key) << (NU32)(((NI) 9))) | T22_);
										T23_ = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
										T23_ = X5BX5D___nilcheck_1405((&(*ctx).expressions), ((NI16) (dependant)));
										moveOut__nilcheck_2992(ctx, map, (*T23_));
									}
									LA20_: ;
									j += ((NI) 1);
									w = (NU)((NU32)(w) >> (NU32)(((NI) 1)));
								} LA17: ;
							}
							i_3 += ((NI) 1);
						} LA15: ;
					}
					r = (*r).next;
				} LA13: ;
			}
		}
		LA3_: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, storeDependants__nilcheck_3627)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* node, tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA value) {
	NI16 index;
	index = index__nilcheck_1949(ctx, node);
	{
		NI dependant;
		tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw colontmp_;
		tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* T2_;
		dependant = (NI)0;
		nimZeroMem((void*)(&colontmp_), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
		T2_ = (tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw*)0;
		T2_ = X5BX5D___nilcheck_3555((&(*ctx).dependants), index);
		nimCopyMem((void*)(&colontmp_), (NIM_CONST void*)(&(*T2_)), sizeof(colontmp_));
		{
			if (!(colontmp_.elems <= ((NI) 34))) goto LA5_;
			{
				NI i;
				NI i_2;
				i = (NI)0;
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_.elems)) goto LA9;
						i = i_2;
						dependant = colontmp_.a[(i)- 0];
						store__nilcheck_2683(map, ctx, ((NI16) (dependant)), value, ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 8), (*node).info, node);
						i_2 += ((NI) 1);
					} LA9: ;
				}
			}
		}
		goto LA3_;
		LA5_: ;
		{
			tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* r;
			r = colontmp_.head;
			{
				while (1) {
					NI i_3;
					if (!!((r == ((tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg*) NIM_NIL)))) goto LA12;
					i_3 = ((NI) 0);
					{
						while (1) {
							NU w;
							NI j;
							if (!(i_3 <= ((NI) 15))) goto LA14;
							w = (*r).bits[(i_3)- 0];
							j = ((NI) 0);
							{
								while (1) {
									if (!!((w == ((NU) 0)))) goto LA16;
									{
										NI T21_;
										if (!!(((NU)(w & ((NU) 1)) == ((NU) 0)))) goto LA19_;
										T21_ = (NI)0;
										T21_ = pluspercent___system_696((NI)((NU32)(i_3) << (NU32)(((NI) 5))), j);
										dependant = (NI)((NI)((NU32)((*r).key) << (NU32)(((NI) 9))) | T21_);
										store__nilcheck_2683(map, ctx, ((NI16) (dependant)), value, ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 8), (*node).info, node);
									}
									LA19_: ;
									j += ((NI) 1);
									w = (NU)((NU32)(w) >> (NU32)(((NI) 1)));
								} LA16: ;
							}
							i_3 += ((NI) 1);
						} LA14: ;
					}
					r = (*r).next;
				} LA12: ;
			}
		}
		LA3_: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, checkCall__nilcheck_4068)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result) {
	NIM_BOOL isNew;
	(*Result).nilability = 0;
	unsureAsgnRef((void**)&(*Result).map, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).elements, NIM_NIL);
	isNew = NIM_FALSE;
	unsureAsgnRef((void**) (&(*Result).map), map);
	{
		NI i;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child;
		i = (NI)0;
		child = NIM_NIL;
		{
			NI i_2;
			NI colontmp_;
			NI i_3;
			i_2 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148(n);
			i_3 = ((NI) 0);
			{
				while (1) {
					tyObject_Check__7OzxEL6sl2sLK509ac4JShA T5_;
					if (!(i_3 < colontmp_)) goto LA4;
					i_2 = i_3;
					i = i_2;
					child = (*n)._kind_6.sons->data[i_2];
					nimZeroMem((void*)(&T5_), sizeof(tyObject_Check__7OzxEL6sl2sLK509ac4JShA));
					check__nilcheck_227(child, ctx, map, (&T5_));
					(void)(T5_);
					{
						if (!(((NI) 0) < i)) goto LA8_;
						{
							NIM_BOOL T12_;
							NIM_BOOL T13_;
							NIM_BOOL T14_;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg;
							NI16 a;
							T12_ = (NIM_BOOL)0;
							T13_ = (NIM_BOOL)0;
							T14_ = (NIM_BOOL)0;
							T14_ = ((*child).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64));
							if (!(T14_)) goto LA15_;
							T14_ = !(((*child).typ == 0));
							LA15_: ;
							T13_ = T14_;
							if (!(T13_)) goto LA16_;
							T13_ = ((*(*child).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23));
							LA16_: ;
							T12_ = T13_;
							if (!(T12_)) goto LA17_;
							T12_ = ((*(*(*child).typ).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22));
							LA17_: ;
							if (!T12_) goto LA18_;
							{
								if (!!(isNew)) goto LA22_;
								unsureAsgnRef((void**) (&(*Result).map), newNilMap__nilcheck_237(map, ((NI) -1)));
								isNew = NIM_TRUE;
							}
							LA22_: ;
							arg = child;
							{
								while (1) {
									if (!((*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64))) goto LA25;
									arg = (*arg)._kind_6.sons->data[((NI) 0)];
								} LA25: ;
							}
							a = index__nilcheck_1949(ctx, arg);
							{
								NIM_BOOL T28_;
								T28_ = (NIM_BOOL)0;
								T28_ = eqeq___nilcheck_188(a, ((NI16) -1));
								if (!!(T28_)) goto LA29_;
								moveOut__nilcheck_2992(ctx, (*Result).map, arg);
								moveOutDependants__nilcheck_3493(ctx, (*Result).map, arg);
								store__nilcheck_2683((*Result).map, ctx, a, ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 2), ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 4), (*n).info, arg);
								storeDependants__nilcheck_3627(ctx, (*Result).map, arg, ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 2));
							}
							LA29_: ;
						}
						goto LA10_;
						LA18_: ;
						{
							NIM_BOOL T32_;
							T32_ = (NIM_BOOL)0;
							T32_ = !(((*child).typ == 0));
							if (!(T32_)) goto LA33_;
							T32_ = ((*(*child).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22));
							LA33_: ;
							if (!T32_) goto LA34_;
							{
								NIM_BOOL T38_;
								NIM_BOOL T40_;
								NI16 a_2;
								T38_ = (NIM_BOOL)0;
								T38_ = ((*child).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3) || (*child).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45));
								if (T38_) goto LA39_;
								T40_ = (NIM_BOOL)0;
								T40_ = ((*child).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42));
								if (!(T40_)) goto LA41_;
								T40_ = ((nkLiterals__ast_3033[(NU)((*(*child)._kind_6.sons->data[((NI) 1)]).kind)>>3] &(1U<<((NU)((*(*child)._kind_6.sons->data[((NI) 1)]).kind)&7U)))!=0);
								LA41_: ;
								T38_ = T40_;
								LA39_: ;
								if (!T38_) goto LA42_;
								a_2 = index__nilcheck_1949(ctx, child);
								{
									tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* T46_;
									NI T47_;
									T46_ = (tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw*)0;
									T46_ = X5BX5D___nilcheck_3555((&(*ctx).dependants), a_2);
									T47_ = (NI)0;
									T47_ = len__nilcheck_1789((&(*T46_)));
									if (!(((NI) 0) < T47_)) goto LA48_;
									{
										if (!!(isNew)) goto LA52_;
										unsureAsgnRef((void**) (&(*Result).map), newNilMap__nilcheck_237(map, ((NI) -1)));
										isNew = NIM_TRUE;
									}
									LA52_: ;
									moveOutDependants__nilcheck_3493(ctx, (*Result).map, child);
									storeDependants__nilcheck_3627(ctx, (*Result).map, child, ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 2));
								}
								LA48_: ;
							}
							LA42_: ;
						}
						goto LA10_;
						LA34_: ;
						LA10_: ;
					}
					LA8_: ;
					i_3 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	{
		NIM_BOOL T56_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* value;
		NI16 b;
		T56_ = (NIM_BOOL)0;
		T56_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		if (!(T56_)) goto LA57_;
		T56_ = ((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 32));
		LA57_: ;
		if (!T56_) goto LA58_;
		{
			if (!((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65))) goto LA62_;
			value = (*(*n)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 0)];
		}
		goto LA60_;
		LA62_: ;
		{
			value = (*n)._kind_6.sons->data[((NI) 1)];
		}
		LA60_: ;
		b = index__nilcheck_1949(ctx, value);
		store__nilcheck_2683((*Result).map, ctx, b, ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1), ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 1), (*value).info, value);
		(*Result).nilability = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1);
	}
	goto LA54_;
	LA58_: ;
	{
		{
			if (!!(((*n).typ == 0))) goto LA68_;
			(*Result).nilability = typeNilability__nilcheck_4066((*n).typ);
		}
		goto LA66_;
		LA68_: ;
		{
			(*Result).nilability = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1);
		}
		LA66_: ;
	}
	LA54_: ;
}
static N_NIMCALL(void, Marker_tySequence__AHhlrIyws6DwjcjqnuoVWQ)(void* p, NI op) {
	tySequence__AHhlrIyws6DwjcjqnuoVWQ* a;
	NI T1_;
	a = (tySequence__AHhlrIyws6DwjcjqnuoVWQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field0, op);
	}
}
N_LIB_PRIVATE N_NIMCALL(void, checkRefExpr__nilcheck_5799)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_Check__7OzxEL6sl2sLK509ac4JShA check, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result) {
	(*Result).nilability = check.nilability;
	unsureAsgnRef((void**) (&(*Result).map), check.map);
	genericSeqAssign((&(*Result).elements), check.elements, (&NTIseqLLpnode_nilabilityTT__AHhlrIyws6DwjcjqnuoVWQ_));
	{
		if (!!(((*(*n).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22)))) goto LA3_;
		(*Result).nilability = typeNilability__nilcheck_4066((*n).typ);
	}
	goto LA1_;
	LA3_: ;
	{
		if (!!((((*(*n).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 17))&63U)))!=0))) goto LA6_;
		{
			NIM_BOOL T10_;
			NIM_BOOL T12_;
			NI16 key;
			T10_ = (NIM_BOOL)0;
			T10_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45));
			if (T10_) goto LA11_;
			T12_ = (NIM_BOOL)0;
			T12_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42));
			if (!(T12_)) goto LA13_;
			T12_ = ((nkLiterals__ast_3033[(NU)((*(*n)._kind_6.sons->data[((NI) 1)]).kind)>>3] &(1U<<((NU)((*(*n)._kind_6.sons->data[((NI) 1)]).kind)&7U)))!=0);
			LA13_: ;
			T10_ = T12_;
			LA11_: ;
			if (!T10_) goto LA14_;
			key = index__nilcheck_1949(ctx, n);
			(*Result).nilability = X5BX5D___nilcheck_865((*Result).map, key);
		}
		goto LA8_;
		LA14_: ;
		{
			if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42))) goto LA17_;
			(*Result).nilability = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 2);
		}
		goto LA8_;
		LA17_: ;
		{
			(*Result).nilability = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 2);
		}
		LA8_: ;
	}
	goto LA1_;
	LA6_: ;
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, checkDotExpr__nilcheck_5830)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result) {
	tyObject_Check__7OzxEL6sl2sLK509ac4JShA T1_;
	check__nilcheck_227((*n)._kind_6.sons->data[((NI) 0)], ctx, map, Result);
	nimZeroMem((void*)(&T1_), sizeof(tyObject_Check__7OzxEL6sl2sLK509ac4JShA));
	checkRefExpr__nilcheck_5799(n, ctx, (*Result), (&T1_));
	(*Result).nilability = T1_.nilability;
	unsureAsgnRef((void**) (&(*Result).map), T1_.map);
	unsureAsgnRef((void**) (&(*Result).elements), T1_.elements);
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, derefWarning__nilcheck_4274)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA kind) {
	tySequence__ShKVNN7kN9a0hT6rhE7ADzg* a;
	NimStringDesc* res;
	NimStringDesc* issue;
	NimStringDesc* T15_;
	NimStringDesc* T16_;
{	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = contains__nilcheck_4332((*ctx).warningLocations, (*n).info);
		if (!T3_) goto LA4_;
		goto BeforeRet_;
	}
	LA4_: ;
	incl__nilcheck_4627((&(*ctx).warningLocations), (*n).info);
	a = NIM_NIL;
	{
		NI16 T10_;
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA8_;
		T10_ = (NI16)0;
		T10_ = index__nilcheck_1949(ctx, n);
		a = history__nilcheck_1071(map, T10_);
	}
	LA8_: ;
	res = ((NimStringDesc*) NIM_NIL);
	switch (kind) {
	case ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 3):
	{
		issue = copyString(((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_20));
	}
	break;
	case ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 2):
	{
		issue = copyString(((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_21));
	}
	break;
	case ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 4):
	{
		issue = copyString(((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_22));
	}
	break;
	default:
	{
		issue = ((NimStringDesc*) NIM_NIL);
	}
	break;
	}
	T15_ = NIM_NIL;
	T16_ = NIM_NIL;
	T16_ = dollar___renderer_2116(n);
	T15_ = rawNewString((T16_ ? T16_->Sup.len : 0) + (issue ? issue->Sup.len : 0) + 14);
appendString(T15_, ((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_23));
appendString(T15_, T16_);
appendString(T15_, ((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_24));
appendString(T15_, issue);
	res = resizeString(res, (T15_ ? T15_->Sup.len : 0) + 0);
appendString(res, T15_);
	{
		NI T19_;
		T19_ = (a ? a->Sup.len : 0);
		if (!(((NI) 0) < T19_)) goto LA20_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_25));
	}
	LA20_: ;
	{
		tyObject_History__nemqwCae5qEp6Zk6QXd7RA* b;
		NI i;
		NI L;
		NI T23_;
		b = (tyObject_History__nemqwCae5qEp6Zk6QXd7RA*)0;
		i = ((NI) 0);
		T23_ = (a ? a->Sup.len : 0);
		L = T23_;
		{
			while (1) {
				NimStringDesc* T26_;
				NimStringDesc* T27_;
				NimStringDesc* T37_;
				NimStringDesc* T38_;
				if (!(i < L)) goto LA25;
				b = (&a->data[i]);
				T26_ = NIM_NIL;
				T27_ = NIM_NIL;
				switch ((*b).kind) {
				case ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 0):
				{
					T27_ = copyString(((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_27));
				}
				break;
				case ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 3):
				{
					T27_ = copyString(((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_28));
				}
				break;
				case ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 1):
				{
					T27_ = copyString(((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_29));
				}
				break;
				case ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 4):
				{
					T27_ = copyString(((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_30));
				}
				break;
				case ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 5):
				{
					T27_ = copyString(((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_31));
				}
				break;
				case ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 2):
				{
					T27_ = copyString(((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_32));
				}
				break;
				case ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 6):
				{
					T27_ = copyString(((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_33));
				}
				break;
				case ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 7):
				{
					T27_ = copyString(((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_34));
				}
				break;
				case ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 8):
				{
					T27_ = copyString(((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_35));
				}
				break;
				}
				T37_ = NIM_NIL;
				T37_ = dollar___systemZdollars_9(((NU64) ((*b).info.line)));
				T38_ = NIM_NIL;
				T38_ = dollar___systemZdollars_3(((NI) ((*b).info.col)));
				T26_ = rawNewString((T27_ ? T27_->Sup.len : 0) + (T37_ ? T37_->Sup.len : 0) + (T38_ ? T38_->Sup.len : 0) + 12);
appendString(T26_, ((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_26));
appendString(T26_, T27_);
appendString(T26_, ((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_36));
appendString(T26_, T37_);
appendString(T26_, ((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_37));
appendString(T26_, T38_);
				res = resizeString(res, (T26_ ? T26_->Sup.len : 0) + 0);
appendString(res, T26_);
				i += ((NI) 1);
			} LA25: ;
		}
	}
	liMessage__msgs_1128((*ctx).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 59), res, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9a75rVZu7sg4HRrHPMS3VUw_38, NIM_FALSE);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, handleNilability__nilcheck_5787)(tyObject_Check__7OzxEL6sl2sLK509ac4JShA check, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map) {
	switch (check.nilability) {
	case ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 3):
	{
		derefWarning__nilcheck_4274(n, ctx, map, ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 3));
	}
	break;
	case ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 2):
	{
		derefWarning__nilcheck_4274(n, ctx, map, ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 2));
	}
	break;
	case ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 4):
	{
		derefWarning__nilcheck_4274(n, ctx, map, ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 4));
	}
	break;
	default:
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, checkDeref__nilcheck_5792)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result) {
	check__nilcheck_227((*n)._kind_6.sons->data[((NI) 0)], ctx, map, Result);
	handleNilability__nilcheck_5787((*Result), (*n)._kind_6.sons->data[((NI) 0)], ctx, map);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A*, copyMap__nilcheck_4056)(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map) {
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* result;
{	result = NIM_NIL;
	{
		if (!(map == 0)) goto LA3_;
		result = ((tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A*) NIM_NIL);
		goto BeforeRet_;
	}
	LA3_: ;
	result = newNilMap__nilcheck_237((*map).parent, ((NI) -1));
	genericSeqAssign((&(*result).expressions), (*map).expressions, (&NTIseqLnilabilityT__kGCKZrVGM65uzo2SGY9bxMQ_));
	genericSeqAssign((&(*result).history), (*map).history, (&NTIseqLseqLhistoryTT__TXTtz79abNCf5jWrlvNZpOw_));
	genericSeqAssign((&(*result).sets), (*map).sets, (&NTIseqLintsetT__wbHXzzfwTCmsKuzoRrgI3g_));
	genericSeqAssign((&(*result).setIndices), (*map).setIndices, (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA, reverse__nilcheck_6447)(tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA value) {
	tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA result;
	result = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA)0;
	switch (value) {
	case ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 3):
	{
		result = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1);
	}
	break;
	case ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 2):
	{
		result = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 2);
	}
	break;
	case ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1):
	{
		result = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 3);
	}
	break;
	case ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 0):
	{
		result = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 0);
	}
	break;
	case ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 4):
	{
		result = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 4);
	}
	break;
	}
	return result;
}
static N_INLINE(tyObject_History__nemqwCae5qEp6Zk6QXd7RA*, X5BX5D___nilcheck_6635)(tyObject_History__nemqwCae5qEp6Zk6QXd7RA* s, NI sLen_0, NI i) {
	tyObject_History__nemqwCae5qEp6Zk6QXd7RA* result;
	result = (tyObject_History__nemqwCae5qEp6Zk6QXd7RA*)0;
	result = (&s[(NI)(sLen_0 - i)]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA, reverse__nilcheck_6450)(tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA kind) {
	tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA result;
	result = (tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA)0;
	switch (kind) {
	case ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 3):
	{
		result = ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 6);
	}
	break;
	case ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 6):
	{
		result = ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 3);
	}
	break;
	case ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 7):
	{
		result = ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 7);
	}
	break;
	default:
	{
		result = kind;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A*, reverseDirect__nilcheck_1223)(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map) {
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* result;
	result = NIM_NIL;
	result = copyMap__nilcheck_4056(map);
	{
		NI16 index;
		tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA value;
		index = (NI16)0;
		value = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA)0;
		{
			NI i;
			tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA element;
			tySequence__kGCKZrVGM65uzo2SGY9bxMQ* colontmp_;
			NI i_2;
			NI L;
			NI T3_;
			i = (NI)0;
			element = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA)0;
			colontmp_ = NIM_NIL;
			colontmp_ = (*result).expressions;
			i_2 = ((NI) 0);
			T3_ = (colontmp_ ? colontmp_->Sup.len : 0);
			L = T3_;
			{
				while (1) {
					tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA T6_;
					if (!(i_2 < L)) goto LA5;
					i = i_2;
					element = colontmp_->data[i_2];
					index = ((NI16) (i));
					value = element;
					T6_ = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA)0;
					T6_ = reverse__nilcheck_6447(value);
					X5BX5Deq___nilcheck_2731((&(*result).expressions), index, T6_);
					{
						tySequence__ShKVNN7kN9a0hT6rhE7ADzg** T9_;
						NI T10_;
						tySequence__ShKVNN7kN9a0hT6rhE7ADzg** T13_;
						tyObject_History__nemqwCae5qEp6Zk6QXd7RA* T14_;
						tySequence__ShKVNN7kN9a0hT6rhE7ADzg** T15_;
						tyObject_History__nemqwCae5qEp6Zk6QXd7RA* T16_;
						tySequence__ShKVNN7kN9a0hT6rhE7ADzg** T17_;
						tyObject_History__nemqwCae5qEp6Zk6QXd7RA* T18_;
						tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA* T19_;
						T9_ = (tySequence__ShKVNN7kN9a0hT6rhE7ADzg**)0;
						T9_ = X5BX5D___nilcheck_1191((&(*result).history), index);
						T10_ = ((*T9_) ? (*T9_)->Sup.len : 0);
						if (!(((NI) 0) < T10_)) goto LA11_;
						T13_ = (tySequence__ShKVNN7kN9a0hT6rhE7ADzg**)0;
						T13_ = X5BX5D___nilcheck_1191((&(*result).history), index);
						T14_ = (tyObject_History__nemqwCae5qEp6Zk6QXd7RA*)0;
						T14_ = X5BX5D___nilcheck_6635((*T13_) ? ((*T13_)->data) : NIM_NIL, ((*T13_) ? (*T13_)->Sup.len : 0), ((NI) 1));
						T15_ = (tySequence__ShKVNN7kN9a0hT6rhE7ADzg**)0;
						T15_ = X5BX5D___nilcheck_1191((&(*result).history), index);
						T16_ = (tyObject_History__nemqwCae5qEp6Zk6QXd7RA*)0;
						T16_ = X5BX5D___nilcheck_6635((*T15_) ? ((*T15_)->data) : NIM_NIL, ((*T15_) ? (*T15_)->Sup.len : 0), ((NI) 1));
						(*T14_).kind = reverse__nilcheck_6450((*T16_).kind);
						T17_ = (tySequence__ShKVNN7kN9a0hT6rhE7ADzg**)0;
						T17_ = X5BX5D___nilcheck_1191((&(*result).history), index);
						T18_ = (tyObject_History__nemqwCae5qEp6Zk6QXd7RA*)0;
						T18_ = X5BX5D___nilcheck_6635((*T17_) ? ((*T17_)->data) : NIM_NIL, ((*T17_) ? (*T17_)->Sup.len : 0), ((NI) 1));
						T19_ = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA*)0;
						T19_ = X5BX5D___nilcheck_989((&(*result).expressions), index);
						(*T18_).nilability = (*T19_);
					}
					LA11_: ;
					i_2 += ((NI) 1);
				} LA5: ;
			}
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A*, add__nilcheck_5969)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* l, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* r) {
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* result;
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* common;
	NI16 T8_;
{	result = NIM_NIL;
	{
		if (!(l == 0)) goto LA3_;
		result = r;
		goto BeforeRet_;
	}
	goto LA1_;
	LA3_: ;
	{
		if (!(r == 0)) goto LA6_;
		result = l;
		goto BeforeRet_;
	}
	goto LA1_;
	LA6_: ;
	LA1_: ;
	common = findCommonParent__nilcheck_5850(l, r);
	T8_ = (NI16)0;
	T8_ = len__nilcheck_5932((*ctx).expressions);
	result = newNilMap__nilcheck_237(common, ((NI) (T8_)));
	{
		NI16 index;
		tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA value;
		index = (NI16)0;
		value = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA)0;
		{
			NI16 index_2;
			tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA value_2;
			index_2 = (NI16)0;
			value_2 = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA)0;
			{
				NI i;
				tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA element;
				tySequence__kGCKZrVGM65uzo2SGY9bxMQ* colontmp_;
				NI i_2;
				NI L;
				NI T12_;
				i = (NI)0;
				element = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA)0;
				colontmp_ = NIM_NIL;
				colontmp_ = (*l).expressions;
				i_2 = ((NI) 0);
				T12_ = (colontmp_ ? colontmp_->Sup.len : 0);
				L = T12_;
				{
					while (1) {
						tySequence__ShKVNN7kN9a0hT6rhE7ADzg* h;
						tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
						tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA T22_;
						if (!(i_2 < L)) goto LA14;
						i = i_2;
						element = colontmp_->data[i_2];
						index_2 = ((NI16) (i));
						value_2 = element;
						index = index_2;
						value = X5BX5D___nilcheck_865(l, index_2);
						h = history__nilcheck_1071(r, index);
						{
							NI T17_;
							tyObject_History__nemqwCae5qEp6Zk6QXd7RA T20_;
							T17_ = (h ? h->Sup.len : 0);
							if (!(((NI) 0) < T17_)) goto LA18_;
							nimZeroMem((void*)(&T20_), sizeof(tyObject_History__nemqwCae5qEp6Zk6QXd7RA));
							X5BX5D___nilcheck_5946((h) ? (h->data) : NIM_NIL, (h ? h->Sup.len : 0), ((NI) 1), (&T20_));
							info = T20_.info;
						}
						goto LA15_;
						LA18_: ;
						{
							nimZeroMem((void*)(&info), sizeof(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw));
							info.line = ((NU16) 0);
						}
						LA15_: ;
						T22_ = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA)0;
						{
							tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA T25_;
							T25_ = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA)0;
							T25_ = X5BX5D___nilcheck_865(r, index);
							if (!(value == T25_)) goto LA26_;
							T22_ = value;
						}
						goto LA23_;
						LA26_: ;
						{
							if (!(value == ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 0))) goto LA29_;
							T22_ = X5BX5D___nilcheck_865(r, index);
						}
						goto LA23_;
						LA29_: ;
						{
							tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA T32_;
							T32_ = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA)0;
							T32_ = X5BX5D___nilcheck_865(r, index);
							if (!(T32_ == ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 0))) goto LA33_;
							T22_ = value;
						}
						goto LA23_;
						LA33_: ;
						{
							NIM_BOOL T36_;
							tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA T38_;
							T36_ = (NIM_BOOL)0;
							T36_ = (value == ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 4));
							if (T36_) goto LA37_;
							T38_ = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA)0;
							T38_ = X5BX5D___nilcheck_865(r, index);
							T36_ = (T38_ == ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 4));
							LA37_: ;
							if (!T36_) goto LA39_;
							T22_ = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 4);
						}
						goto LA23_;
						LA39_: ;
						{
							if (!(value == ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 2))) goto LA42_;
							T22_ = X5BX5D___nilcheck_865(r, index);
						}
						goto LA23_;
						LA42_: ;
						{
							tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA T45_;
							T45_ = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA)0;
							T45_ = X5BX5D___nilcheck_865(r, index);
							if (!(T45_ == ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 2))) goto LA46_;
							T22_ = value;
						}
						goto LA23_;
						LA46_: ;
						{
							T22_ = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 4);
						}
						LA23_: ;
						store__nilcheck_2683(result, ctx, index, T22_, ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 1), info, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
						i_2 += ((NI) 1);
					} LA14: ;
				}
			}
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkBranch__nilcheck_1225)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result) {
	check__nilcheck_227(n, ctx, map, Result);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasUnstructuredControlFlowJump__nilcheck_1229)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child;
			child = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA5;
						i = i_2;
						child = (*n)._kind_6.sons->data[i];
						{
							NIM_BOOL T8_;
							T8_ = (NIM_BOOL)0;
							T8_ = hasUnstructuredControlFlowJump__nilcheck_1229(child);
							if (!T8_) goto LA9_;
							result = NIM_TRUE;
							goto BeforeRet_;
						}
						LA9_: ;
						i_2 += ((NI) 1);
					} LA5: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 109):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 110):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 111):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 108):
	{
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 92):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 48):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 49):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 88):
	{
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	break;
	default:
	{
	}
	break;
	}
	result = NIM_FALSE;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkIf__nilcheck_6230)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result) {
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* mapIf;
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* mapCondition;
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* layerHistory;
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* afterLayer;
	tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA nilability;
	(*Result).nilability = 0;
	unsureAsgnRef((void**)&(*Result).map, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).elements, NIM_NIL);
	mapIf = map;
	mapCondition = checkCondition__nilcheck_231((*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)], ctx, mapIf, NIM_FALSE, NIM_TRUE);
	layerHistory = newNilMap__nilcheck_237(mapIf, ((NI) -1));
	afterLayer = NIM_NIL;
	nilability = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1);
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** branch;
		tySequence__IeU9azYSNIK3V9b36Ir6NZcw* colontmp_;
		NI i;
		NI L;
		NI T2_;
		branch = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
		colontmp_ = NIM_NIL;
		colontmp_ = (*n)._kind_6.sons;
		i = ((NI) 0);
		T2_ = (colontmp_ ? colontmp_->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* branchConditionLayer;
				tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* branchLayer;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* code;
				tyObject_Check__7OzxEL6sl2sLK509ac4JShA branchCheck;
				if (!(i < L)) goto LA4;
				branch = &colontmp_->data[i];
				branchConditionLayer = newNilMap__nilcheck_237(layerHistory, ((NI) -1));
				branchLayer = NIM_NIL;
				code = NIM_NIL;
				{
					tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* mapCondition_2;
					tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* reverseMapCondition;
					if (!((*(*branch)).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 92) || (*(*branch)).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 86))) goto LA7_;
					mapCondition_2 = checkCondition__nilcheck_231((*(*branch))._kind_6.sons->data[((NI) 0)], ctx, branchConditionLayer, NIM_FALSE, NIM_TRUE);
					reverseMapCondition = reverseDirect__nilcheck_1223(mapCondition_2);
					layerHistory = add__nilcheck_5969(ctx, layerHistory, reverseMapCondition);
					branchLayer = mapCondition_2;
					code = (*(*branch))._kind_6.sons->data[((NI) 1)];
				}
				goto LA5_;
				LA7_: ;
				{
					branchLayer = layerHistory;
					code = (*branch);
				}
				LA5_: ;
				nimZeroMem((void*)(&branchCheck), sizeof(tyObject_Check__7OzxEL6sl2sLK509ac4JShA));
				checkBranch__nilcheck_1225(code, ctx, branchLayer, (&branchCheck));
				afterLayer = union__nilcheck_5865(ctx, afterLayer, branchCheck.map);
				{
					if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 92))) goto LA12_;
					nilability = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1);
				}
				goto LA10_;
				LA12_: ;
				{
					{
						if (!(nilability == branchCheck.nilability)) goto LA17_;
						nilability = nilability;
					}
					goto LA15_;
					LA17_: ;
					{
						nilability = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 2);
					}
					LA15_: ;
				}
				LA10_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
	{
		NI T22_;
		T22_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
		if (!(((NI) 1) < T22_)) goto LA23_;
		unsureAsgnRef((void**) (&(*Result).map), afterLayer);
		(*Result).nilability = nilability;
	}
	goto LA20_;
	LA23_: ;
	{
		{
			NIM_BOOL T28_;
			T28_ = (NIM_BOOL)0;
			T28_ = hasUnstructuredControlFlowJump__nilcheck_1229((*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)]);
			if (!!(T28_)) goto LA29_;
			unsureAsgnRef((void**) (&(*Result).map), union__nilcheck_5865(ctx, layerHistory, afterLayer));
			(*Result).nilability = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1);
		}
		goto LA26_;
		LA29_: ;
		{
			unsureAsgnRef((void**) (&(*Result).map), layerHistory);
			(*Result).nilability = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1);
		}
		LA26_: ;
	}
	LA20_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, move__nilcheck_3699)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* target, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* assigned) {
	NI16 targetIndex;
	NI16 assignedIndex;
	NI targetSetIndex;
	NI* T1_;
	NI assignedSetIndex;
	targetIndex = index__nilcheck_1949(ctx, target);
	assignedIndex = (NI16)0;
	T1_ = (NI*)0;
	T1_ = X5BX5D___nilcheck_2477((&(*map).setIndices), targetIndex);
	targetSetIndex = (*T1_);
	assignedSetIndex = (NI)0;
	{
		NI* T6_;
		if (!((*assigned).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA4_;
		assignedIndex = index__nilcheck_1949(ctx, assigned);
		T6_ = (NI*)0;
		T6_ = X5BX5D___nilcheck_2477((&(*map).setIndices), assignedIndex);
		assignedSetIndex = (*T6_);
	}
	goto LA2_;
	LA4_: ;
	{
		assignedIndex = ((NI16) -1);
		assignedSetIndex = ((NI) -1);
	}
	LA2_: ;
	{
		NIM_BOOL T10_;
		T10_ = (NIM_BOOL)0;
		T10_ = eqeq___nilcheck_188(assignedIndex, ((NI16) -1));
		if (!T10_) goto LA11_;
		moveOut__nilcheck_2992(ctx, map, target);
	}
	goto LA8_;
	LA11_: ;
	{
		NIM_BOOL T14_;
		tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* T17_;
		tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* T18_;
		T14_ = (NIM_BOOL)0;
		T14_ = eqeq___nilcheck_215(targetSetIndex, assignedSetIndex);
		if (!!(T14_)) goto LA15_;
		T17_ = (tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw*)0;
		T17_ = X5BX5D___nilcheck_1513((&(*map).sets), targetSetIndex);
		excl__reorder_273(T17_, ((NI) (targetIndex)));
		T18_ = (tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw*)0;
		T18_ = X5BX5D___nilcheck_1513((&(*map).sets), assignedSetIndex);
		incl__pureZcollectionsZintsets_55(T18_, ((NI) (targetIndex)));
		X5BX5Deq___nilcheck_584((&(*map).setIndices), targetIndex, assignedSetIndex);
	}
	goto LA8_;
	LA15_: ;
	LA8_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, checkAsgn__nilcheck_6079)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* target, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* assigned, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result) {
	tyObject_Check__7OzxEL6sl2sLK509ac4JShA T6_;
	{
		if (!!(((*assigned).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)))) goto LA3_;
		check__nilcheck_227(assigned, ctx, map, Result);
	}
	goto LA1_;
	LA3_: ;
	{
		(*Result).nilability = 0;
		unsureAsgnRef((void**)&(*Result).map, NIM_NIL);
		unsureAsgnRef((void**)&(*Result).elements, NIM_NIL);
		(*Result).nilability = typeNilability__nilcheck_4066((*target).typ);
		unsureAsgnRef((void**) (&(*Result).map), map);
	}
	LA1_: ;
	nimZeroMem((void*)(&T6_), sizeof(tyObject_Check__7OzxEL6sl2sLK509ac4JShA));
	check__nilcheck_227(target, ctx, map, (&T6_));
	(void)(T6_);
	{
		if (!((*Result).map == 0)) goto LA9_;
		unsureAsgnRef((void**) (&(*Result).map), map);
	}
	LA9_: ;
	{
		NIM_BOOL T13_;
		NIM_BOOL T15_;
		NI16 t;
		T13_ = (NIM_BOOL)0;
		T13_ = ((*target).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3) || (*target).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45));
		if (T13_) goto LA14_;
		T15_ = (NIM_BOOL)0;
		T15_ = ((*target).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42));
		if (!(T15_)) goto LA16_;
		T15_ = ((nkLiterals__ast_3033[(NU)((*(*target)._kind_6.sons->data[((NI) 1)]).kind)>>3] &(1U<<((NU)((*(*target)._kind_6.sons->data[((NI) 1)]).kind)&7U)))!=0);
		LA16_: ;
		T13_ = T15_;
		LA14_: ;
		if (!T13_) goto LA17_;
		t = index__nilcheck_1949(ctx, target);
		move__nilcheck_3699(ctx, map, target, assigned);
		switch ((*assigned).kind) {
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
		{
			store__nilcheck_2683((*Result).map, ctx, t, ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 3), ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 1), (*target).info, target);
		}
		break;
		default:
		{
			store__nilcheck_2683((*Result).map, ctx, t, (*Result).nilability, ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 1), (*target).info, target);
			moveOutDependants__nilcheck_3493(ctx, map, target);
			storeDependants__nilcheck_3627(ctx, map, target, ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 2));
			{
				if (!((*assigned).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 38) || (*assigned).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 160))) goto LA23_;
				{
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** element;
					tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA* value;
					NI i;
					NI L;
					NI T26_;
					element = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
					value = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA*)0;
					i = ((NI) 0);
					T26_ = ((*Result).elements ? (*Result).elements->Sup.len : 0);
					L = T26_;
					{
						while (1) {
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* elementNode;
							tyArray__Nfk9cOEzg2bRz9c1V8fGzONg T29_;
							tyArray__iegsN9bf6GqRiWprrJjTAoA T30_;
							if (!(i < L)) goto LA28;
							element = &(*Result).elements->data[i].Field0;
							value = (&(*Result).elements->data[i].Field1);
							nimZeroMem((void*)T29_, sizeof(tyArray__Nfk9cOEzg2bRz9c1V8fGzONg));
							nimZeroMem((void*)T30_, sizeof(tyArray__iegsN9bf6GqRiWprrJjTAoA));
							T30_[0] = target;
							T29_[0] = newTree__ast_3356(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65), T30_, 1);
							T29_[1] = (*element);
							elementNode = newTree__ast_3356(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45), T29_, 2);
							{
								NI T33_;
								NIM_BOOL T34_;
								NI16 elementIndex;
								T33_ = (NI)0;
								T33_ = symbol__nilcheck_1219(elementNode);
								T34_ = (NIM_BOOL)0;
								T34_ = contains__nilcheck_6185((*ctx).symbolIndices, T33_);
								if (!T34_) goto LA35_;
								elementIndex = index__nilcheck_1949(ctx, elementNode);
								store__nilcheck_2683((*Result).map, ctx, elementIndex, (*value), ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 1), (*target).info, elementNode);
							}
							LA35_: ;
							i += ((NI) 1);
						} LA28: ;
					}
				}
			}
			LA23_: ;
		}
		break;
		}
	}
	LA17_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, checkFor__nilcheck_6269)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result) {
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* m;
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map0;
	tyObject_Check__7OzxEL6sl2sLK509ac4JShA T1_;
	tyObject_Check__7OzxEL6sl2sLK509ac4JShA check2;
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map2;
	(*Result).nilability = 0;
	unsureAsgnRef((void**)&(*Result).map, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).elements, NIM_NIL);
	m = copyMap__nilcheck_4056(map);
	map0 = copyMap__nilcheck_4056(map);
	nimZeroMem((void*)(&T1_), sizeof(tyObject_Check__7OzxEL6sl2sLK509ac4JShA));
	check__nilcheck_227((*n)._kind_6.sons->data[((NI) 2)], ctx, map, (&T1_));
	m = copyMap__nilcheck_4056(T1_.map);
	{
		NI16 T6_;
		tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA T7_;
		if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA4_;
		T6_ = (NI16)0;
		T6_ = index__nilcheck_1949(ctx, (*n)._kind_6.sons->data[((NI) 0)]);
		T7_ = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA)0;
		T7_ = typeNilability__nilcheck_4066((*(*n)._kind_6.sons->data[((NI) 0)]).typ);
		store__nilcheck_2683(m, ctx, T6_, T7_, ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 1), (*(*n)._kind_6.sons->data[((NI) 0)]).info, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
	}
	LA4_: ;
	nimZeroMem((void*)(&check2), sizeof(tyObject_Check__7OzxEL6sl2sLK509ac4JShA));
	check__nilcheck_227((*n)._kind_6.sons->data[((NI) 2)], ctx, m, (&check2));
	map2 = check2.map;
	unsureAsgnRef((void**) (&(*Result).map), union__nilcheck_5865(ctx, map0, m));
	unsureAsgnRef((void**) (&(*Result).map), union__nilcheck_5865(ctx, (*Result).map, map2));
	(*Result).nilability = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1);
}
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextSymId__ast_3103)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x) {
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*x).symId += ((NI) 1);
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	result.module = (*x).module;
	result.item = (*x).symId;
	return result;
}
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextTypeId__ast_3122)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x) {
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*x).typeId_0 += ((NI) 1);
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	result.module = (*x).module;
	result.item = (*x).typeId_0;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, infix__nilcheck_6349)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* l, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* r, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	NimStringDesc* name;
	tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* op;
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T5_;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T6_;
	tyArray__id9c0PBojP5C2oM2bRQSViA T7_;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T8_;
	result = NIM_NIL;
	switch (magic) {
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 87):
	{
		name = copyString(((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_40));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 109):
	{
		name = copyString(((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_41));
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 110):
	{
		name = copyString(((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_42));
	}
	break;
	default:
	{
		name = ((NimStringDesc*) NIM_NIL);
	}
	break;
	}
	cache = newIdentCache__idents_161();
	T5_ = NIM_NIL;
	T5_ = getIdent__idents_152(cache, name);
	T6_ = nextSymId__ast_3103((*ctx).idgen);
	op = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8), T5_, T6_, ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL), (*r).info, 0);
	(*op).magic = magic;
	nimZeroMem((void*)T7_, sizeof(tyArray__id9c0PBojP5C2oM2bRQSViA));
	T7_[0] = newSymNode__ast_3707(op, (*r).info);
	T7_[1] = l;
	T7_[2] = r;
	result = newTree__ast_3356(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29), T7_, 3);
	T8_ = nextTypeId__ast_3122((*ctx).idgen);
	asgnRef((void**) (&(*result).typ), newType__ast_3884(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1), T8_, ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, infixEq__nilcheck_6373)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* l, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* r) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = infix__nilcheck_6349(ctx, l, r, ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 87));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, infixOr__nilcheck_6378)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* l, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* r) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = infix__nilcheck_6349(ctx, l, r, ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 110));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, prefixNot__nilcheck_6367)(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* node) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* op;
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T1_;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T2_;
	tyArray__Nfk9cOEzg2bRz9c1V8fGzONg T3_;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T4_;
	result = NIM_NIL;
	cache = newIdentCache__idents_161();
	T1_ = NIM_NIL;
	T1_ = getIdent__idents_152(cache, ((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_43));
	T2_ = nextSymId__ast_3103((*ctx).idgen);
	op = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8), T1_, T2_, ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL), (*node).info, 0);
	(*op).magic = ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 96);
	nimZeroMem((void*)T3_, sizeof(tyArray__Nfk9cOEzg2bRz9c1V8fGzONg));
	T3_[0] = newSymNode__ast_3707(op, (*node).info);
	T3_[1] = node;
	result = newTree__ast_3356(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30), T3_, 2);
	T4_ = nextTypeId__ast_3122((*ctx).idgen);
	asgnRef((void**) (&(*result).typ), newType__ast_3884(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1), T4_, ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkCase__nilcheck_6383)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* base;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a;
	(*Result).nilability = 0;
	unsureAsgnRef((void**)&(*Result).map, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).elements, NIM_NIL);
	base = (*n)._kind_6.sons->data[((NI) 0)];
	unsureAsgnRef((void**) (&(*Result).map), copyMap__nilcheck_4056(map));
	(*Result).nilability = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1);
	a = NIM_NIL;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child;
		child = NIM_NIL;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					child = (*n)._kind_6.sons->data[i];
					{
						switch ((*child).kind) {
						case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 85):
						{
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* branchBase;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* code;
							NI T12_;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* test;
							tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* conditionMap;
							tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* T18_;
							tyObject_Check__7OzxEL6sl2sLK509ac4JShA newCheck;
							{
								NI T9_;
								T9_ = (NI)0;
								T9_ = len__ast_3155(child);
								if (!(T9_ < ((NI) 2))) goto LA10_;
								goto LA5;
							}
							LA10_: ;
							branchBase = (*child)._kind_6.sons->data[((NI) 0)];
							T12_ = (NI)0;
							T12_ = len__ast_3155(child);
							code = (*child)._kind_6.sons->data[(NI)(T12_ - ((NI) 1))];
							test = infixEq__nilcheck_6373(ctx, base, branchBase);
							{
								if (!(a == 0)) goto LA15_;
								a = test;
							}
							goto LA13_;
							LA15_: ;
							{
								a = infixOr__nilcheck_6378(ctx, a, test);
							}
							LA13_: ;
							T18_ = NIM_NIL;
							T18_ = copyMap__nilcheck_4056(map);
							conditionMap = checkCondition__nilcheck_231(test, ctx, T18_, NIM_FALSE, NIM_FALSE);
							nimZeroMem((void*)(&newCheck), sizeof(tyObject_Check__7OzxEL6sl2sLK509ac4JShA));
							checkBranch__nilcheck_1225(code, ctx, conditionMap, (&newCheck));
							unsureAsgnRef((void**) (&(*Result).map), union__nilcheck_5865(ctx, (*Result).map, newCheck.map));
							{
								if (!((*Result).nilability == newCheck.nilability)) goto LA21_;
								(*Result).nilability = (*Result).nilability;
							}
							goto LA19_;
							LA21_: ;
							{
								(*Result).nilability = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 2);
							}
							LA19_: ;
						}
						break;
						case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 86):
						{
						}
						break;
						case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 88):
						{
							tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* mapElse;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T26_;
							tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* T27_;
							tyObject_Check__7OzxEL6sl2sLK509ac4JShA newCheck_2;
							T26_ = NIM_NIL;
							T26_ = prefixNot__nilcheck_6367(ctx, a);
							T27_ = NIM_NIL;
							T27_ = copyMap__nilcheck_4056(map);
							mapElse = checkCondition__nilcheck_231(T26_, ctx, T27_, NIM_FALSE, NIM_FALSE);
							nimZeroMem((void*)(&newCheck_2), sizeof(tyObject_Check__7OzxEL6sl2sLK509ac4JShA));
							checkBranch__nilcheck_1225((*child)._kind_6.sons->data[((NI) 0)], ctx, mapElse, (&newCheck_2));
							unsureAsgnRef((void**) (&(*Result).map), union__nilcheck_5865(ctx, (*Result).map, newCheck_2.map));
							{
								if (!((*Result).nilability == newCheck_2.nilability)) goto LA30_;
								(*Result).nilability = (*Result).nilability;
							}
							goto LA28_;
							LA30_: ;
							{
								(*Result).nilability = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 2);
							}
							LA28_: ;
						}
						break;
						default:
						{
						}
						break;
						}
					} LA5: ;
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, checkReturn__nilcheck_6224)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result) {
	check__nilcheck_227((*n)._kind_6.sons->data[((NI) 0)], ctx, map, Result);
	store__nilcheck_2683((*Result).map, ctx, ((NI16) 0), (*Result).nilability, ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 1), (*n).info, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
}
N_LIB_PRIVATE N_NIMCALL(void, checkBracketExpr__nilcheck_5836)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result) {
	tyObject_Check__7OzxEL6sl2sLK509ac4JShA T1_;
	tyObject_Check__7OzxEL6sl2sLK509ac4JShA T2_;
	check__nilcheck_227((*n)._kind_6.sons->data[((NI) 0)], ctx, map, Result);
	handleNilability__nilcheck_5787((*Result), (*n)._kind_6.sons->data[((NI) 0)], ctx, map);
	nimZeroMem((void*)(&T1_), sizeof(tyObject_Check__7OzxEL6sl2sLK509ac4JShA));
	check__nilcheck_227((*n)._kind_6.sons->data[((NI) 1)], ctx, (*Result).map, (&T1_));
	(*Result).nilability = T1_.nilability;
	unsureAsgnRef((void**) (&(*Result).map), T1_.map);
	unsureAsgnRef((void**) (&(*Result).elements), T1_.elements);
	nimZeroMem((void*)(&T2_), sizeof(tyObject_Check__7OzxEL6sl2sLK509ac4JShA));
	checkRefExpr__nilcheck_5799(n, ctx, (*Result), (&T2_));
	(*Result).nilability = T2_.nilability;
	unsureAsgnRef((void**) (&(*Result).map), T2_.map);
	unsureAsgnRef((void**) (&(*Result).elements), T2_.elements);
}
N_LIB_PRIVATE N_NIMCALL(void, checkTry__nilcheck_6420)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result) {
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* newMap;
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* currentMap;
	NIM_BOOL canRaise;
	NIM_BOOL hasFinally;
	tyObject_Check__7OzxEL6sl2sLK509ac4JShA tryCheck;
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* afterTryMap;
	newMap = copyMap__nilcheck_4056(map);
	currentMap = map;
	canRaise = NIM_FALSE;
	hasFinally = NIM_FALSE;
	nimZeroMem((void*)(&tryCheck), sizeof(tyObject_Check__7OzxEL6sl2sLK509ac4JShA));
	check__nilcheck_227((*n)._kind_6.sons->data[((NI) 0)], ctx, currentMap, (&tryCheck));
	newMap = union__nilcheck_5865(ctx, currentMap, tryCheck.map);
	canRaise = canRaise__ast_5100((*n)._kind_6.sons->data[((NI) 0)]);
	afterTryMap = newMap;
	{
		NI a;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* branch;
		a = (NI)0;
		branch = NIM_NIL;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					a = i;
					branch = (*n)._kind_6.sons->data[i];
					{
						if (!(((NI) 0) < a)) goto LA7_;
						switch ((*branch).kind) {
						case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 107):
						{
							tyObject_Check__7OzxEL6sl2sLK509ac4JShA childCheck;
							newMap = union__nilcheck_5865(ctx, afterTryMap, newMap);
							nimZeroMem((void*)(&childCheck), sizeof(tyObject_Check__7OzxEL6sl2sLK509ac4JShA));
							check__nilcheck_227((*branch)._kind_6.sons->data[((NI) 0)], ctx, newMap, (&childCheck));
							newMap = union__nilcheck_5865(ctx, newMap, childCheck.map);
							hasFinally = NIM_TRUE;
						}
						break;
						case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 87):
						{
							{
								tyObject_Check__7OzxEL6sl2sLK509ac4JShA childCheck_2;
								NI T15_;
								if (!canRaise) goto LA13_;
								nimZeroMem((void*)(&childCheck_2), sizeof(tyObject_Check__7OzxEL6sl2sLK509ac4JShA));
								T15_ = (NI)0;
								T15_ = len__ast_3155(branch);
								check__nilcheck_227((*branch)._kind_6.sons->data[(NI)(T15_ - ((NI) 1))], ctx, newMap, (&childCheck_2));
								newMap = union__nilcheck_5865(ctx, newMap, childCheck_2.map);
							}
							LA13_: ;
						}
						break;
						default:
						{
						}
						break;
						}
					}
					LA7_: ;
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	{
		if (!!(hasFinally)) goto LA19_;
		newMap = union__nilcheck_5865(ctx, afterTryMap, newMap);
	}
	LA19_: ;
	(*Result).nilability = 0;
	unsureAsgnRef((void**)&(*Result).map, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).elements, NIM_NIL);
	(*Result).nilability = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1);
	unsureAsgnRef((void**) (&(*Result).map), newMap);
}
N_LIB_PRIVATE N_NIMCALL(void, checkWhile__nilcheck_6286)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result) {
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* m;
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map0;
	tyObject_Check__7OzxEL6sl2sLK509ac4JShA T1_;
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map1;
	tyObject_Check__7OzxEL6sl2sLK509ac4JShA check2;
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map2;
	(*Result).nilability = 0;
	unsureAsgnRef((void**)&(*Result).map, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).elements, NIM_NIL);
	m = checkCondition__nilcheck_231((*n)._kind_6.sons->data[((NI) 0)], ctx, map, NIM_FALSE, NIM_FALSE);
	map0 = copyMap__nilcheck_4056(map);
	nimZeroMem((void*)(&T1_), sizeof(tyObject_Check__7OzxEL6sl2sLK509ac4JShA));
	check__nilcheck_227((*n)._kind_6.sons->data[((NI) 1)], ctx, m, (&T1_));
	m = T1_.map;
	map1 = copyMap__nilcheck_4056(m);
	nimZeroMem((void*)(&check2), sizeof(tyObject_Check__7OzxEL6sl2sLK509ac4JShA));
	check__nilcheck_227((*n)._kind_6.sons->data[((NI) 1)], ctx, m, (&check2));
	map2 = check2.map;
	unsureAsgnRef((void**) (&(*Result).map), union__nilcheck_5865(ctx, map0, map1));
	unsureAsgnRef((void**) (&(*Result).map), union__nilcheck_5865(ctx, (*Result).map, map2));
	(*Result).nilability = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, check__nilcheck_227)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map, tyObject_Check__7OzxEL6sl2sLK509ac4JShA* Result) {
	(*Result).nilability = 0;
	unsureAsgnRef((void**)&(*Result).map, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).elements, NIM_NIL);
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		NI16 T2_;
		(*Result).nilability = 0;
		unsureAsgnRef((void**)&(*Result).map, NIM_NIL);
		unsureAsgnRef((void**)&(*Result).elements, NIM_NIL);
		T2_ = (NI16)0;
		T2_ = index__nilcheck_1949(ctx, n);
		(*Result).nilability = X5BX5D___nilcheck_865(map, T2_);
		unsureAsgnRef((void**) (&(*Result).map), map);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
	{
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* callSym;
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA6_;
			callSym = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
			switch ((*callSym).magic) {
			case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 109):
			case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 110):
			{
				checkInfix__nilcheck_6297(n, ctx, map, Result);
			}
			break;
			case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 143):
			{
				checkIsNil__nilcheck_6340(n, ctx, map, NIM_FALSE, Result);
			}
			break;
			default:
			{
				checkCall__nilcheck_4068(n, ctx, map, Result);
			}
			break;
			}
		}
		goto LA4_;
		LA6_: ;
		{
			checkCall__nilcheck_4068(n, ctx, map, Result);
		}
		LA4_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 60):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 33):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 61):
	{
		check__nilcheck_227((*n)._kind_6.sons->data[((NI) 1)], ctx, map, Result);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 68):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 69):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 70):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 39):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 37):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 160):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 155):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 38):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 88):
	{
		unsureAsgnRef((void**) (&(*Result).map), map);
		{
			tySequence__AHhlrIyws6DwjcjqnuoVWQ* elements;
			if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 38) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 160))) goto LA16_;
			elements = NIM_NIL;
			{
				NI i;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child;
				i = (NI)0;
				child = NIM_NIL;
				{
					NI i_2;
					NI colontmp_;
					NI i_3;
					i_2 = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = safeLen__ast_3148(n);
					i_3 = ((NI) 0);
					{
						while (1) {
							tyObject_Check__7OzxEL6sl2sLK509ac4JShA T22_;
							if (!(i_3 < colontmp_)) goto LA21;
							i_2 = i_3;
							i = i_2;
							child = (*n)._kind_6.sons->data[i_2];
							nimZeroMem((void*)(&T22_), sizeof(tyObject_Check__7OzxEL6sl2sLK509ac4JShA));
							check__nilcheck_227(child, ctx, (*Result).map, (&T22_));
							(*Result).nilability = T22_.nilability;
							unsureAsgnRef((void**) (&(*Result).map), T22_.map);
							unsureAsgnRef((void**) (&(*Result).elements), T22_.elements);
							{
								if (!(((NI) 0) < i)) goto LA25_;
								{
									tyTuple__3w8Q5T9cOF5FQ54JItYYe3Q T31_;
									NI T32_;
									if (!((*child).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34))) goto LA29_;
									nimZeroMem((void*)(&T31_), sizeof(tyTuple__3w8Q5T9cOF5FQ54JItYYe3Q));
									T31_.Field0 = (*child)._kind_6.sons->data[((NI) 0)];
									T31_.Field1 = (*Result).nilability;
									elements = (tySequence__AHhlrIyws6DwjcjqnuoVWQ*) incrSeqV3((TGenericSeq*)(elements), (&NTIseqLLpnode_nilabilityTT__AHhlrIyws6DwjcjqnuoVWQ_));
									T32_ = elements->Sup.len++;
									asgnRef((void**) (&elements->data[T32_].Field0), T31_.Field0);
									elements->data[T32_].Field1 = T31_.Field1;
								}
								LA29_: ;
							}
							LA25_: ;
							i_3 += ((NI) 1);
						} LA21: ;
					}
				}
			}
			genericSeqAssign((&(*Result).elements), elements, (&NTIseqLLpnode_nilabilityTT__AHhlrIyws6DwjcjqnuoVWQ_));
			(*Result).nilability = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1);
		}
		goto LA14_;
		LA16_: ;
		{
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child_2;
				child_2 = NIM_NIL;
				{
					NI i_4;
					NI colontmp__2;
					NI i_5;
					i_4 = (NI)0;
					colontmp__2 = (NI)0;
					colontmp__2 = safeLen__ast_3148(n);
					i_5 = ((NI) 0);
					{
						while (1) {
							tyObject_Check__7OzxEL6sl2sLK509ac4JShA T38_;
							if (!(i_5 < colontmp__2)) goto LA37;
							i_4 = i_5;
							child_2 = (*n)._kind_6.sons->data[i_4];
							nimZeroMem((void*)(&T38_), sizeof(tyObject_Check__7OzxEL6sl2sLK509ac4JShA));
							check__nilcheck_227(child_2, ctx, (*Result).map, (&T38_));
							(*Result).nilability = T38_.nilability;
							unsureAsgnRef((void**) (&(*Result).map), T38_.map);
							unsureAsgnRef((void**) (&(*Result).elements), T38_.elements);
							i_5 += ((NI) 1);
						} LA37: ;
					}
				}
			}
		}
		LA14_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45):
	{
		checkDotExpr__nilcheck_5830(n, ctx, map, Result);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 47):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65):
	{
		checkDeref__nilcheck_5792(n, ctx, map, Result);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64):
	{
		check__nilcheck_227((*n)._kind_6.sons->data[((NI) 0)], ctx, map, Result);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 92):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 48):
	{
		checkIf__nilcheck_6230(n, ctx, map, Result);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 73):
	{
		checkAsgn__nilcheck_6079((*n)._kind_6.sons->data[((NI) 0)], (*n)._kind_6.sons->data[((NI) 1)], ctx, map, Result);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 99):
	{
		unsureAsgnRef((void**) (&(*Result).map), map);
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child_3;
			child_3 = NIM_NIL;
			{
				NI i_6;
				NI colontmp__3;
				NI i_7;
				i_6 = (NI)0;
				colontmp__3 = (NI)0;
				colontmp__3 = safeLen__ast_3148(n);
				i_7 = ((NI) 0);
				{
					while (1) {
						tyObject_Check__7OzxEL6sl2sLK509ac4JShA T49_;
						if (!(i_7 < colontmp__3)) goto LA48;
						i_6 = i_7;
						child_3 = (*n)._kind_6.sons->data[i_6];
						nimZeroMem((void*)(&T49_), sizeof(tyObject_Check__7OzxEL6sl2sLK509ac4JShA));
						checkAsgn__nilcheck_6079((*child_3)._kind_6.sons->data[((NI) 0)], (*child_3)._kind_6.sons->data[((NI) 2)], ctx, (*Result).map, (&T49_));
						(*Result).nilability = T49_.nilability;
						unsureAsgnRef((void**) (&(*Result).map), T49_.map);
						unsureAsgnRef((void**) (&(*Result).elements), T49_.elements);
						i_7 += ((NI) 1);
					} LA48: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 94):
	{
		checkFor__nilcheck_6269(n, ctx, map, Result);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 97):
	{
		checkCase__nilcheck_6383(n, ctx, map, Result);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 109):
	{
		checkReturn__nilcheck_6224(n, ctx, map, Result);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42):
	{
		checkBracketExpr__nilcheck_5836(n, ctx, map, Result);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 106):
	{
		checkTry__nilcheck_6420(n, ctx, map, Result);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 96):
	{
		checkWhile__nilcheck_6286(n, ctx, map, Result);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 4) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 98):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 81):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 80):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 82):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 83):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 51):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 52):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 101):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 102):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 121):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 116):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 118):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 90):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 125):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 158):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 132):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 123):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 122):
	{
		(*Result).nilability = 0;
		unsureAsgnRef((void**)&(*Result).map, NIM_NIL);
		unsureAsgnRef((void**)&(*Result).elements, NIM_NIL);
		(*Result).nilability = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 3);
		unsureAsgnRef((void**) (&(*Result).map), map);
	}
	break;
	default:
	{
		tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* elementMap;
		tyObject_Check__7OzxEL6sl2sLK509ac4JShA elementCheck;
		elementMap = copyMap__nilcheck_4056(map);
		nimZeroMem((void*)(&elementCheck), sizeof(tyObject_Check__7OzxEL6sl2sLK509ac4JShA));
		elementCheck.map = elementMap;
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* element;
			element = NIM_NIL;
			{
				NI i_8;
				NI colontmp__4;
				NI i_9;
				i_8 = (NI)0;
				colontmp__4 = (NI)0;
				colontmp__4 = safeLen__ast_3148(n);
				i_9 = ((NI) 0);
				{
					while (1) {
						tyObject_Check__7OzxEL6sl2sLK509ac4JShA T62_;
						if (!(i_9 < colontmp__4)) goto LA61;
						i_8 = i_9;
						element = (*n)._kind_6.sons->data[i_8];
						nimZeroMem((void*)(&T62_), sizeof(tyObject_Check__7OzxEL6sl2sLK509ac4JShA));
						check__nilcheck_227(element, ctx, elementCheck.map, (&T62_));
						elementCheck.nilability = T62_.nilability;
						elementCheck.map = T62_.map;
						elementCheck.elements = T62_.elements;
						i_9 += ((NI) 1);
					} LA61: ;
				}
			}
		}
		(*Result).nilability = 0;
		unsureAsgnRef((void**)&(*Result).map, NIM_NIL);
		unsureAsgnRef((void**)&(*Result).elements, NIM_NIL);
		(*Result).nilability = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 3);
		unsureAsgnRef((void**) (&(*Result).map), elementCheck.map);
	}
	break;
	}
}
static N_INLINE(NIM_BOOL, contains__nilcheck_9550)(tyObject_HSlice__7TOOBlADhY009aGwq7hyBaw s, NI16 value) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = lteq___nilcheck_176(s.a, value);
	if (!(T1_)) goto LA2_;
	T1_ = lteq___nilcheck_176(value, s.b);
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(tyObject_HSlice__7TOOBlADhY009aGwq7hyBaw, dotdot___nilcheck_9478)(NI16 a, NI16 b) {
	tyObject_HSlice__7TOOBlADhY009aGwq7hyBaw result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__7TOOBlADhY009aGwq7hyBaw));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__7TOOBlADhY009aGwq7hyBaw));
	result.a = a;
	result.b = b;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI16, low__nilcheck_9453)(tySequence__TXTtz79abNCf5jWrlvNZpOw* a) {
	NI16 result;
	result = (NI16)0;
	result = ((NI16) 0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI16, high__nilcheck_9461)(tySequence__TXTtz79abNCf5jWrlvNZpOw* a) {
	NI16 result;
	NI T1_;
	result = (NI16)0;
	T1_ = ((a ? a->Sup.len : 0)-1);
	result = ((NI16) (T1_));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkResult__nilcheck_6944)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* ctx, tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map) {
	tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA resultNilability;
	resultNilability = X5BX5D___nilcheck_865(map, ((NI16) 0));
	switch (resultNilability) {
	case ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 3):
	{
		liMessage__msgs_1128((*ctx).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 59), ((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_44), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9a75rVZu7sg4HRrHPMS3VUw_45, NIM_FALSE);
	}
	break;
	case ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 2):
	{
		liMessage__msgs_1128((*ctx).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 59), ((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_46), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9a75rVZu7sg4HRrHPMS3VUw_47, NIM_FALSE);
	}
	break;
	case ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 4):
	{
		liMessage__msgs_1128((*ctx).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 59), ((NimStringDesc*) &TM__9a75rVZu7sg4HRrHPMS3VUw_48), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__9a75rVZu7sg4HRrHPMS3VUw_49, NIM_FALSE);
	}
	break;
	case ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1):
	case ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 0):
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, checkNil__nilcheck_9362)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen) {
	NU16 line;
	NI fileIndex;
	NimStringDesc* filename;
	tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* context;
	tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow* T1_;
	tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A* map;
	NI T2_;
	tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA T18_;
	tyObject_Check__7OzxEL6sl2sLK509ac4JShA res;
	NIM_BOOL canCheck;
	NI16 T26_;
	NI16 T27_;
	tyObject_HSlice__7TOOBlADhY009aGwq7hyBaw T28_;
	line = (*(*s).ast).info.line;
	fileIndex = ((NI) ((*(*s).ast).info.fileIndex));
	filename = copyString((*conf).m.fileInfos->data[fileIndex].fullPath);
	T1_ = NIM_NIL;
	T1_ = (tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow*) newObj((&NTInilcheckercontext__9bnT9cUqmgQIJCayD7fHaOUw_), sizeof(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow));
	asgnRef((void**) (&(*T1_).config), conf);
	asgnRef((void**) (&(*T1_).idgen), idgen);
	context = T1_;
	preVisit__nilcheck_8813(context, s, body, conf);
	T2_ = (NI)0;
	T2_ = len__nilcheck_9426((*context).symbolIndices);
	map = newNilMap__nilcheck_237(((tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A*) NIM_NIL), T2_);
	{
		NI i;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child;
		tySequence__IeU9azYSNIK3V9b36Ir6NZcw* colontmp_;
		NI i_2;
		NI L;
		NI T4_;
		i = (NI)0;
		child = NIM_NIL;
		colontmp_ = NIM_NIL;
		colontmp_ = (*(*(*s).typ).n)._kind_6.sons;
		i_2 = ((NI) 0);
		T4_ = (colontmp_ ? colontmp_->Sup.len : 0);
		L = T4_;
		{
			while (1) {
				if (!(i_2 < L)) goto LA6;
				i = i_2;
				child = colontmp_->data[i_2];
				{
					{
						NI16 T16_;
						tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA T17_;
						if (!(((NI) 0) < i)) goto LA10_;
						{
							if (!!(((*child).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)))) goto LA14_;
							goto LA7;
						}
						LA14_: ;
						T16_ = (NI16)0;
						T16_ = index__nilcheck_1949(context, child);
						T17_ = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA)0;
						T17_ = typeNilability__nilcheck_4066((*child).typ);
						store__nilcheck_2683(map, context, T16_, T17_, ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 0), (*child).info, child);
					}
					LA10_: ;
				} LA7: ;
				i_2 += ((NI) 1);
			} LA6: ;
		}
	}
	T18_ = (tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA)0;
	{
		NIM_BOOL T21_;
		T21_ = (NIM_BOOL)0;
		T21_ = !(((*(*s).typ).sons->data[((NI) 0)] == 0));
		if (!(T21_)) goto LA22_;
		T21_ = ((*(*(*s).typ).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22));
		LA22_: ;
		if (!T21_) goto LA23_;
		T18_ = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 3);
	}
	goto LA19_;
	LA23_: ;
	{
		T18_ = ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1);
	}
	LA19_: ;
	store__nilcheck_2683(map, context, ((NI16) 0), T18_, ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 5), (*(*s).ast).info, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
	nimZeroMem((void*)(&res), sizeof(tyObject_Check__7OzxEL6sl2sLK509ac4JShA));
	check__nilcheck_227(body, context, map, (&res));
	T26_ = (NI16)0;
	T26_ = low__nilcheck_9453((*res.map).history);
	T27_ = (NI16)0;
	T27_ = high__nilcheck_9461((*res.map).history);
	T28_ = dotdot___nilcheck_9478(T26_, T27_);
	canCheck = contains__nilcheck_9550(T28_, ((NI16) 0));
	{
		NIM_BOOL T31_;
		NIM_BOOL T32_;
		tySequence__ShKVNN7kN9a0hT6rhE7ADzg** T35_;
		NI T36_;
		T31_ = (NIM_BOOL)0;
		T32_ = (NIM_BOOL)0;
		T32_ = (res.nilability == ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1));
		if (!(T32_)) goto LA33_;
		T32_ = canCheck;
		LA33_: ;
		T31_ = T32_;
		if (!(T31_)) goto LA34_;
		T35_ = (tySequence__ShKVNN7kN9a0hT6rhE7ADzg**)0;
		T35_ = X5BX5D___nilcheck_1191((&(*res.map).history), ((NI16) 0));
		T36_ = ((*T35_) ? (*T35_)->Sup.len : 0);
		T31_ = (T36_ <= ((NI) 1));
		LA34_: ;
		if (!T31_) goto LA37_;
		store__nilcheck_2683(res.map, context, ((NI16) 0), ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1), ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 1), (*(*s).ast).info, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
	}
	goto LA29_;
	LA37_: ;
	{
		{
			if (!(res.nilability == ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1))) goto LA42_;
			store__nilcheck_2683(res.map, context, ((NI16) 0), ((tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA) 1), ((tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA) 1), (*(*s).ast).info, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
		}
		LA42_: ;
	}
	LA29_: ;
	{
		NIM_BOOL T46_;
		NIM_BOOL T47_;
		T46_ = (NIM_BOOL)0;
		T47_ = (NIM_BOOL)0;
		T47_ = !(((*(*s).typ).sons->data[((NI) 0)] == 0));
		if (!(T47_)) goto LA48_;
		T47_ = ((*(*(*s).typ).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22));
		LA48_: ;
		T46_ = T47_;
		if (!(T46_)) goto LA49_;
		T46_ = (((*(*(*s).typ).sons->data[((NI) 0)]).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 17))&63U)))!=0);
		LA49_: ;
		if (!T46_) goto LA50_;
		checkResult__nilcheck_6944((*s).ast, context, res.map);
	}
	LA50_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, atmnilcheckdotnim_DatInit000)(void) {
static TNimNode* TM__9a75rVZu7sg4HRrHPMS3VUw_2_6[6];
static TNimNode* TM__9a75rVZu7sg4HRrHPMS3VUw_3_2[2];
static TNimNode* TM__9a75rVZu7sg4HRrHPMS3VUw_4_3[3];
static TNimNode* TM__9a75rVZu7sg4HRrHPMS3VUw_5_2[2];
static TNimNode* TM__9a75rVZu7sg4HRrHPMS3VUw_6_2[2];
static TNimNode* TM__9a75rVZu7sg4HRrHPMS3VUw_9_5[5];
static TNimNode* TM__9a75rVZu7sg4HRrHPMS3VUw_10_5[5];
NI TM__9a75rVZu7sg4HRrHPMS3VUw_12;
static char* NIM_CONST TM__9a75rVZu7sg4HRrHPMS3VUw_11[5] = {
"Parent", 
"Safe", 
"MaybeNil", 
"Nil", 
"Unreachable"};
static TNimNode* TM__9a75rVZu7sg4HRrHPMS3VUw_13_4[4];
static TNimNode* TM__9a75rVZu7sg4HRrHPMS3VUw_14_9[9];
NI TM__9a75rVZu7sg4HRrHPMS3VUw_16;
static char* NIM_CONST TM__9a75rVZu7sg4HRrHPMS3VUw_15[9] = {
"TArg", 
"TAssign", 
"TType", 
"TNil", 
"TVarArg", 
"TResult", 
"TSafe", 
"TPotentialAlias", 
"TDependant"};
static TNimNode* TM__9a75rVZu7sg4HRrHPMS3VUw_19_2[2];
static TNimNode TM__9a75rVZu7sg4HRrHPMS3VUw_0[50];
NTInilcheckercontext58objecttype__r0vZFiu6Xw1EWAX9crgVyow_.size = sizeof(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow);
NTInilcheckercontext58objecttype__r0vZFiu6Xw1EWAX9crgVyow_.align = NIM_ALIGNOF(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow);
NTInilcheckercontext58objecttype__r0vZFiu6Xw1EWAX9crgVyow_.kind = 18;
NTInilcheckercontext58objecttype__r0vZFiu6Xw1EWAX9crgVyow_.base = 0;
NTInilcheckercontext58objecttype__r0vZFiu6Xw1EWAX9crgVyow_.flags = 2;
TM__9a75rVZu7sg4HRrHPMS3VUw_2_6[0] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[1];
NTItable__rDTSDzC8VietpxpD1ELe1g_.size = sizeof(tyObject_Table__rDTSDzC8VietpxpD1ELe1g);
NTItable__rDTSDzC8VietpxpD1ELe1g_.align = NIM_ALIGNOF(tyObject_Table__rDTSDzC8VietpxpD1ELe1g);
NTItable__rDTSDzC8VietpxpD1ELe1g_.kind = 18;
NTItable__rDTSDzC8VietpxpD1ELe1g_.base = 0;
NTItable__rDTSDzC8VietpxpD1ELe1g_.flags = 2;
TM__9a75rVZu7sg4HRrHPMS3VUw_3_2[0] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[3];
NTIkeyvaluepair__X9bWVAqRSgByRpQwn6owzEA_.size = sizeof(tyTuple__X9bWVAqRSgByRpQwn6owzEA);
NTIkeyvaluepair__X9bWVAqRSgByRpQwn6owzEA_.align = NIM_ALIGNOF(tyTuple__X9bWVAqRSgByRpQwn6owzEA);
NTIkeyvaluepair__X9bWVAqRSgByRpQwn6owzEA_.kind = 18;
NTIkeyvaluepair__X9bWVAqRSgByRpQwn6owzEA_.base = 0;
NTIkeyvaluepair__X9bWVAqRSgByRpQwn6owzEA_.flags = 3;
TM__9a75rVZu7sg4HRrHPMS3VUw_4_3[0] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[5];
TM__9a75rVZu7sg4HRrHPMS3VUw_0[5].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[5].offset = offsetof(tyTuple__X9bWVAqRSgByRpQwn6owzEA, Field0);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[5].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[5].name = "Field0";
TM__9a75rVZu7sg4HRrHPMS3VUw_4_3[1] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[6];
TM__9a75rVZu7sg4HRrHPMS3VUw_0[6].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[6].offset = offsetof(tyTuple__X9bWVAqRSgByRpQwn6owzEA, Field1);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[6].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[6].name = "Field1";
TM__9a75rVZu7sg4HRrHPMS3VUw_4_3[2] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[7];
TM__9a75rVZu7sg4HRrHPMS3VUw_0[7].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[7].offset = offsetof(tyTuple__X9bWVAqRSgByRpQwn6owzEA, Field2);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[7].typ = (&NTIint4954__kDPg4wXyR8DDyA0MeEjIsw_);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[7].name = "Field2";
TM__9a75rVZu7sg4HRrHPMS3VUw_0[4].len = 3; TM__9a75rVZu7sg4HRrHPMS3VUw_0[4].kind = 2; TM__9a75rVZu7sg4HRrHPMS3VUw_0[4].sons = &TM__9a75rVZu7sg4HRrHPMS3VUw_4_3[0];
NTIkeyvaluepair__X9bWVAqRSgByRpQwn6owzEA_.node = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[4];
NTIkeyvaluepairseq__dAjyAaabi52TN36Jp0fAXQ_.size = sizeof(tySequence__dAjyAaabi52TN36Jp0fAXQ*);
NTIkeyvaluepairseq__dAjyAaabi52TN36Jp0fAXQ_.align = NIM_ALIGNOF(tySequence__dAjyAaabi52TN36Jp0fAXQ*);
NTIkeyvaluepairseq__dAjyAaabi52TN36Jp0fAXQ_.kind = 24;
NTIkeyvaluepairseq__dAjyAaabi52TN36Jp0fAXQ_.base = (&NTIkeyvaluepair__X9bWVAqRSgByRpQwn6owzEA_);
NTIkeyvaluepairseq__dAjyAaabi52TN36Jp0fAXQ_.flags = 2;
NTIkeyvaluepairseq__dAjyAaabi52TN36Jp0fAXQ_.marker = Marker_tySequence__dAjyAaabi52TN36Jp0fAXQ;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[3].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[3].offset = offsetof(tyObject_Table__rDTSDzC8VietpxpD1ELe1g, data);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[3].typ = (&NTIkeyvaluepairseq__dAjyAaabi52TN36Jp0fAXQ_);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[3].name = "data";
TM__9a75rVZu7sg4HRrHPMS3VUw_3_2[1] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[8];
TM__9a75rVZu7sg4HRrHPMS3VUw_0[8].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[8].offset = offsetof(tyObject_Table__rDTSDzC8VietpxpD1ELe1g, counter);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[8].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[8].name = "counter";
TM__9a75rVZu7sg4HRrHPMS3VUw_0[2].len = 2; TM__9a75rVZu7sg4HRrHPMS3VUw_0[2].kind = 2; TM__9a75rVZu7sg4HRrHPMS3VUw_0[2].sons = &TM__9a75rVZu7sg4HRrHPMS3VUw_3_2[0];
NTItable__rDTSDzC8VietpxpD1ELe1g_.node = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[2];
TM__9a75rVZu7sg4HRrHPMS3VUw_0[1].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[1].offset = offsetof(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow, symbolIndices);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[1].typ = (&NTItable__rDTSDzC8VietpxpD1ELe1g_);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[1].name = "symbolIndices";
TM__9a75rVZu7sg4HRrHPMS3VUw_2_6[1] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[9];
TM__9a75rVZu7sg4HRrHPMS3VUw_0[9].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[9].offset = offsetof(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow, expressions);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[9].typ = (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[9].name = "expressions";
TM__9a75rVZu7sg4HRrHPMS3VUw_2_6[2] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[10];
NTIseqLintsetT__wbHXzzfwTCmsKuzoRrgI3g_.size = sizeof(tySequence__wbHXzzfwTCmsKuzoRrgI3g*);
NTIseqLintsetT__wbHXzzfwTCmsKuzoRrgI3g_.align = NIM_ALIGNOF(tySequence__wbHXzzfwTCmsKuzoRrgI3g*);
NTIseqLintsetT__wbHXzzfwTCmsKuzoRrgI3g_.kind = 24;
NTIseqLintsetT__wbHXzzfwTCmsKuzoRrgI3g_.base = (&NTIpackedset__THXDbzJSs2hcC9a33en2pdw_);
NTIseqLintsetT__wbHXzzfwTCmsKuzoRrgI3g_.flags = 2;
NTIseqLintsetT__wbHXzzfwTCmsKuzoRrgI3g_.marker = Marker_tySequence__wbHXzzfwTCmsKuzoRrgI3g;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[10].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[10].offset = offsetof(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow, dependants);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[10].typ = (&NTIseqLintsetT__wbHXzzfwTCmsKuzoRrgI3g_);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[10].name = "dependants";
TM__9a75rVZu7sg4HRrHPMS3VUw_2_6[3] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[11];
NTIhashset__zVZZy9cn25qKcaABhU9aN2vw_.size = sizeof(tyObject_HashSet__zVZZy9cn25qKcaABhU9aN2vw);
NTIhashset__zVZZy9cn25qKcaABhU9aN2vw_.align = NIM_ALIGNOF(tyObject_HashSet__zVZZy9cn25qKcaABhU9aN2vw);
NTIhashset__zVZZy9cn25qKcaABhU9aN2vw_.kind = 18;
NTIhashset__zVZZy9cn25qKcaABhU9aN2vw_.base = 0;
NTIhashset__zVZZy9cn25qKcaABhU9aN2vw_.flags = 2;
TM__9a75rVZu7sg4HRrHPMS3VUw_5_2[0] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[13];
NTIkeyvaluepair__QJASEmMHDLGFAvbisAV7AA_.size = sizeof(tyTuple__QJASEmMHDLGFAvbisAV7AA);
NTIkeyvaluepair__QJASEmMHDLGFAvbisAV7AA_.align = NIM_ALIGNOF(tyTuple__QJASEmMHDLGFAvbisAV7AA);
NTIkeyvaluepair__QJASEmMHDLGFAvbisAV7AA_.kind = 18;
NTIkeyvaluepair__QJASEmMHDLGFAvbisAV7AA_.base = 0;
NTIkeyvaluepair__QJASEmMHDLGFAvbisAV7AA_.flags = 3;
TM__9a75rVZu7sg4HRrHPMS3VUw_6_2[0] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[15];
TM__9a75rVZu7sg4HRrHPMS3VUw_0[15].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[15].offset = offsetof(tyTuple__QJASEmMHDLGFAvbisAV7AA, Field0);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[15].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[15].name = "Field0";
TM__9a75rVZu7sg4HRrHPMS3VUw_6_2[1] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[16];
TM__9a75rVZu7sg4HRrHPMS3VUw_0[16].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[16].offset = offsetof(tyTuple__QJASEmMHDLGFAvbisAV7AA, Field1);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[16].typ = (&NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[16].name = "Field1";
TM__9a75rVZu7sg4HRrHPMS3VUw_0[14].len = 2; TM__9a75rVZu7sg4HRrHPMS3VUw_0[14].kind = 2; TM__9a75rVZu7sg4HRrHPMS3VUw_0[14].sons = &TM__9a75rVZu7sg4HRrHPMS3VUw_6_2[0];
NTIkeyvaluepair__QJASEmMHDLGFAvbisAV7AA_.node = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[14];
NTIkeyvaluepairseq__nueg5spSfGVW7EdegG2fTw_.size = sizeof(tySequence__nueg5spSfGVW7EdegG2fTw*);
NTIkeyvaluepairseq__nueg5spSfGVW7EdegG2fTw_.align = NIM_ALIGNOF(tySequence__nueg5spSfGVW7EdegG2fTw*);
NTIkeyvaluepairseq__nueg5spSfGVW7EdegG2fTw_.kind = 24;
NTIkeyvaluepairseq__nueg5spSfGVW7EdegG2fTw_.base = (&NTIkeyvaluepair__QJASEmMHDLGFAvbisAV7AA_);
NTIkeyvaluepairseq__nueg5spSfGVW7EdegG2fTw_.flags = 2;
NTIkeyvaluepairseq__nueg5spSfGVW7EdegG2fTw_.marker = Marker_tySequence__nueg5spSfGVW7EdegG2fTw;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[13].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[13].offset = offsetof(tyObject_HashSet__zVZZy9cn25qKcaABhU9aN2vw, data);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[13].typ = (&NTIkeyvaluepairseq__nueg5spSfGVW7EdegG2fTw_);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[13].name = "data";
TM__9a75rVZu7sg4HRrHPMS3VUw_5_2[1] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[17];
TM__9a75rVZu7sg4HRrHPMS3VUw_0[17].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[17].offset = offsetof(tyObject_HashSet__zVZZy9cn25qKcaABhU9aN2vw, counter);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[17].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[17].name = "counter";
TM__9a75rVZu7sg4HRrHPMS3VUw_0[12].len = 2; TM__9a75rVZu7sg4HRrHPMS3VUw_0[12].kind = 2; TM__9a75rVZu7sg4HRrHPMS3VUw_0[12].sons = &TM__9a75rVZu7sg4HRrHPMS3VUw_5_2[0];
NTIhashset__zVZZy9cn25qKcaABhU9aN2vw_.node = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[12];
TM__9a75rVZu7sg4HRrHPMS3VUw_0[11].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[11].offset = offsetof(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow, warningLocations);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[11].typ = (&NTIhashset__zVZZy9cn25qKcaABhU9aN2vw_);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[11].name = "warningLocations";
TM__9a75rVZu7sg4HRrHPMS3VUw_2_6[4] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[18];
TM__9a75rVZu7sg4HRrHPMS3VUw_0[18].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[18].offset = offsetof(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow, idgen);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[18].typ = (&NTIidgenerator__M4gwBCp6eTol0yFD6lAxTQ_);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[18].name = "idgen";
TM__9a75rVZu7sg4HRrHPMS3VUw_2_6[5] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[19];
TM__9a75rVZu7sg4HRrHPMS3VUw_0[19].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[19].offset = offsetof(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow, config);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[19].typ = (&NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[19].name = "config";
TM__9a75rVZu7sg4HRrHPMS3VUw_0[0].len = 6; TM__9a75rVZu7sg4HRrHPMS3VUw_0[0].kind = 2; TM__9a75rVZu7sg4HRrHPMS3VUw_0[0].sons = &TM__9a75rVZu7sg4HRrHPMS3VUw_2_6[0];
NTInilcheckercontext58objecttype__r0vZFiu6Xw1EWAX9crgVyow_.node = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[0];
NTInilcheckercontext__9bnT9cUqmgQIJCayD7fHaOUw_.size = sizeof(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow*);
NTInilcheckercontext__9bnT9cUqmgQIJCayD7fHaOUw_.align = NIM_ALIGNOF(tyObject_NilCheckerContextcolonObjectType___r0vZFiu6Xw1EWAX9crgVyow*);
NTInilcheckercontext__9bnT9cUqmgQIJCayD7fHaOUw_.kind = 22;
NTInilcheckercontext__9bnT9cUqmgQIJCayD7fHaOUw_.base = (&NTInilcheckercontext58objecttype__r0vZFiu6Xw1EWAX9crgVyow_);
NTInilcheckercontext__9bnT9cUqmgQIJCayD7fHaOUw_.flags = 2;
NTInilcheckercontext__9bnT9cUqmgQIJCayD7fHaOUw_.marker = Marker_tyRef__9bnT9cUqmgQIJCayD7fHaOUw;
NTInilmap58objecttype__2Zw1RuVpNwptw8NipVHY8A_.size = sizeof(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A);
NTInilmap58objecttype__2Zw1RuVpNwptw8NipVHY8A_.align = NIM_ALIGNOF(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A);
NTInilmap58objecttype__2Zw1RuVpNwptw8NipVHY8A_.kind = 18;
NTInilmap58objecttype__2Zw1RuVpNwptw8NipVHY8A_.base = 0;
TM__9a75rVZu7sg4HRrHPMS3VUw_9_5[0] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[21];
NTInilability__XDKthSvkddpY2lzfr6uPgA_.size = sizeof(tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA);
NTInilability__XDKthSvkddpY2lzfr6uPgA_.align = NIM_ALIGNOF(tyEnum_Nilability__XDKthSvkddpY2lzfr6uPgA);
NTInilability__XDKthSvkddpY2lzfr6uPgA_.kind = 14;
NTInilability__XDKthSvkddpY2lzfr6uPgA_.base = 0;
NTInilability__XDKthSvkddpY2lzfr6uPgA_.flags = 3;
for (TM__9a75rVZu7sg4HRrHPMS3VUw_12 = 0; TM__9a75rVZu7sg4HRrHPMS3VUw_12 < 5; TM__9a75rVZu7sg4HRrHPMS3VUw_12++) {
TM__9a75rVZu7sg4HRrHPMS3VUw_0[TM__9a75rVZu7sg4HRrHPMS3VUw_12+22].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[TM__9a75rVZu7sg4HRrHPMS3VUw_12+22].offset = TM__9a75rVZu7sg4HRrHPMS3VUw_12;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[TM__9a75rVZu7sg4HRrHPMS3VUw_12+22].name = TM__9a75rVZu7sg4HRrHPMS3VUw_11[TM__9a75rVZu7sg4HRrHPMS3VUw_12];
TM__9a75rVZu7sg4HRrHPMS3VUw_10_5[TM__9a75rVZu7sg4HRrHPMS3VUw_12] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[TM__9a75rVZu7sg4HRrHPMS3VUw_12+22];
}
TM__9a75rVZu7sg4HRrHPMS3VUw_0[27].len = 5; TM__9a75rVZu7sg4HRrHPMS3VUw_0[27].kind = 2; TM__9a75rVZu7sg4HRrHPMS3VUw_0[27].sons = &TM__9a75rVZu7sg4HRrHPMS3VUw_10_5[0];
NTInilability__XDKthSvkddpY2lzfr6uPgA_.node = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[27];
NTIseqLnilabilityT__kGCKZrVGM65uzo2SGY9bxMQ_.size = sizeof(tySequence__kGCKZrVGM65uzo2SGY9bxMQ*);
NTIseqLnilabilityT__kGCKZrVGM65uzo2SGY9bxMQ_.align = NIM_ALIGNOF(tySequence__kGCKZrVGM65uzo2SGY9bxMQ*);
NTIseqLnilabilityT__kGCKZrVGM65uzo2SGY9bxMQ_.kind = 24;
NTIseqLnilabilityT__kGCKZrVGM65uzo2SGY9bxMQ_.base = (&NTInilability__XDKthSvkddpY2lzfr6uPgA_);
NTIseqLnilabilityT__kGCKZrVGM65uzo2SGY9bxMQ_.flags = 2;
NTIseqLnilabilityT__kGCKZrVGM65uzo2SGY9bxMQ_.marker = Marker_tySequence__kGCKZrVGM65uzo2SGY9bxMQ;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[21].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[21].offset = offsetof(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A, expressions);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[21].typ = (&NTIseqLnilabilityT__kGCKZrVGM65uzo2SGY9bxMQ_);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[21].name = "expressions";
TM__9a75rVZu7sg4HRrHPMS3VUw_9_5[1] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[28];
NTIhistory__nemqwCae5qEp6Zk6QXd7RA_.size = sizeof(tyObject_History__nemqwCae5qEp6Zk6QXd7RA);
NTIhistory__nemqwCae5qEp6Zk6QXd7RA_.align = NIM_ALIGNOF(tyObject_History__nemqwCae5qEp6Zk6QXd7RA);
NTIhistory__nemqwCae5qEp6Zk6QXd7RA_.kind = 18;
NTIhistory__nemqwCae5qEp6Zk6QXd7RA_.base = 0;
NTIhistory__nemqwCae5qEp6Zk6QXd7RA_.flags = 2;
TM__9a75rVZu7sg4HRrHPMS3VUw_13_4[0] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[30];
TM__9a75rVZu7sg4HRrHPMS3VUw_0[30].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[30].offset = offsetof(tyObject_History__nemqwCae5qEp6Zk6QXd7RA, info);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[30].typ = (&NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[30].name = "info";
TM__9a75rVZu7sg4HRrHPMS3VUw_13_4[1] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[31];
TM__9a75rVZu7sg4HRrHPMS3VUw_0[31].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[31].offset = offsetof(tyObject_History__nemqwCae5qEp6Zk6QXd7RA, nilability);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[31].typ = (&NTInilability__XDKthSvkddpY2lzfr6uPgA_);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[31].name = "nilability";
TM__9a75rVZu7sg4HRrHPMS3VUw_13_4[2] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[32];
NTItransitionkind__MTYoDYWJEv6ZS8OvFNF5IA_.size = sizeof(tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA);
NTItransitionkind__MTYoDYWJEv6ZS8OvFNF5IA_.align = NIM_ALIGNOF(tyEnum_TransitionKind__MTYoDYWJEv6ZS8OvFNF5IA);
NTItransitionkind__MTYoDYWJEv6ZS8OvFNF5IA_.kind = 14;
NTItransitionkind__MTYoDYWJEv6ZS8OvFNF5IA_.base = 0;
NTItransitionkind__MTYoDYWJEv6ZS8OvFNF5IA_.flags = 3;
for (TM__9a75rVZu7sg4HRrHPMS3VUw_16 = 0; TM__9a75rVZu7sg4HRrHPMS3VUw_16 < 9; TM__9a75rVZu7sg4HRrHPMS3VUw_16++) {
TM__9a75rVZu7sg4HRrHPMS3VUw_0[TM__9a75rVZu7sg4HRrHPMS3VUw_16+33].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[TM__9a75rVZu7sg4HRrHPMS3VUw_16+33].offset = TM__9a75rVZu7sg4HRrHPMS3VUw_16;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[TM__9a75rVZu7sg4HRrHPMS3VUw_16+33].name = TM__9a75rVZu7sg4HRrHPMS3VUw_15[TM__9a75rVZu7sg4HRrHPMS3VUw_16];
TM__9a75rVZu7sg4HRrHPMS3VUw_14_9[TM__9a75rVZu7sg4HRrHPMS3VUw_16] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[TM__9a75rVZu7sg4HRrHPMS3VUw_16+33];
}
TM__9a75rVZu7sg4HRrHPMS3VUw_0[42].len = 9; TM__9a75rVZu7sg4HRrHPMS3VUw_0[42].kind = 2; TM__9a75rVZu7sg4HRrHPMS3VUw_0[42].sons = &TM__9a75rVZu7sg4HRrHPMS3VUw_14_9[0];
NTItransitionkind__MTYoDYWJEv6ZS8OvFNF5IA_.node = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[42];
TM__9a75rVZu7sg4HRrHPMS3VUw_0[32].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[32].offset = offsetof(tyObject_History__nemqwCae5qEp6Zk6QXd7RA, kind);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[32].typ = (&NTItransitionkind__MTYoDYWJEv6ZS8OvFNF5IA_);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[32].name = "kind";
TM__9a75rVZu7sg4HRrHPMS3VUw_13_4[3] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[43];
TM__9a75rVZu7sg4HRrHPMS3VUw_0[43].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[43].offset = offsetof(tyObject_History__nemqwCae5qEp6Zk6QXd7RA, node);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[43].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[43].name = "node";
TM__9a75rVZu7sg4HRrHPMS3VUw_0[29].len = 4; TM__9a75rVZu7sg4HRrHPMS3VUw_0[29].kind = 2; TM__9a75rVZu7sg4HRrHPMS3VUw_0[29].sons = &TM__9a75rVZu7sg4HRrHPMS3VUw_13_4[0];
NTIhistory__nemqwCae5qEp6Zk6QXd7RA_.node = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[29];
NTIseqLhistoryT__ShKVNN7kN9a0hT6rhE7ADzg_.size = sizeof(tySequence__ShKVNN7kN9a0hT6rhE7ADzg*);
NTIseqLhistoryT__ShKVNN7kN9a0hT6rhE7ADzg_.align = NIM_ALIGNOF(tySequence__ShKVNN7kN9a0hT6rhE7ADzg*);
NTIseqLhistoryT__ShKVNN7kN9a0hT6rhE7ADzg_.kind = 24;
NTIseqLhistoryT__ShKVNN7kN9a0hT6rhE7ADzg_.base = (&NTIhistory__nemqwCae5qEp6Zk6QXd7RA_);
NTIseqLhistoryT__ShKVNN7kN9a0hT6rhE7ADzg_.flags = 2;
NTIseqLhistoryT__ShKVNN7kN9a0hT6rhE7ADzg_.marker = Marker_tySequence__ShKVNN7kN9a0hT6rhE7ADzg;
NTIseqLseqLhistoryTT__TXTtz79abNCf5jWrlvNZpOw_.size = sizeof(tySequence__TXTtz79abNCf5jWrlvNZpOw*);
NTIseqLseqLhistoryTT__TXTtz79abNCf5jWrlvNZpOw_.align = NIM_ALIGNOF(tySequence__TXTtz79abNCf5jWrlvNZpOw*);
NTIseqLseqLhistoryTT__TXTtz79abNCf5jWrlvNZpOw_.kind = 24;
NTIseqLseqLhistoryTT__TXTtz79abNCf5jWrlvNZpOw_.base = (&NTIseqLhistoryT__ShKVNN7kN9a0hT6rhE7ADzg_);
NTIseqLseqLhistoryTT__TXTtz79abNCf5jWrlvNZpOw_.flags = 2;
NTIseqLseqLhistoryTT__TXTtz79abNCf5jWrlvNZpOw_.marker = Marker_tySequence__TXTtz79abNCf5jWrlvNZpOw;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[28].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[28].offset = offsetof(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A, history);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[28].typ = (&NTIseqLseqLhistoryTT__TXTtz79abNCf5jWrlvNZpOw_);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[28].name = "history";
TM__9a75rVZu7sg4HRrHPMS3VUw_9_5[2] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[44];
TM__9a75rVZu7sg4HRrHPMS3VUw_0[44].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[44].offset = offsetof(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A, setIndices);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[44].typ = (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[44].name = "setIndices";
TM__9a75rVZu7sg4HRrHPMS3VUw_9_5[3] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[45];
TM__9a75rVZu7sg4HRrHPMS3VUw_0[45].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[45].offset = offsetof(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A, sets);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[45].typ = (&NTIseqLintsetT__wbHXzzfwTCmsKuzoRrgI3g_);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[45].name = "sets";
TM__9a75rVZu7sg4HRrHPMS3VUw_9_5[4] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[46];
TM__9a75rVZu7sg4HRrHPMS3VUw_0[46].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[46].offset = offsetof(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A, parent);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[46].typ = (&NTInilmap__4xhug3qIp2asVjvZ3bVlPQ_);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[46].name = "parent";
TM__9a75rVZu7sg4HRrHPMS3VUw_0[20].len = 5; TM__9a75rVZu7sg4HRrHPMS3VUw_0[20].kind = 2; TM__9a75rVZu7sg4HRrHPMS3VUw_0[20].sons = &TM__9a75rVZu7sg4HRrHPMS3VUw_9_5[0];
NTInilmap58objecttype__2Zw1RuVpNwptw8NipVHY8A_.node = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[20];
NTInilmap__4xhug3qIp2asVjvZ3bVlPQ_.size = sizeof(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A*);
NTInilmap__4xhug3qIp2asVjvZ3bVlPQ_.align = NIM_ALIGNOF(tyObject_NilMapcolonObjectType___2Zw1RuVpNwptw8NipVHY8A*);
NTInilmap__4xhug3qIp2asVjvZ3bVlPQ_.kind = 22;
NTInilmap__4xhug3qIp2asVjvZ3bVlPQ_.base = (&NTInilmap58objecttype__2Zw1RuVpNwptw8NipVHY8A_);
NTInilmap__4xhug3qIp2asVjvZ3bVlPQ_.marker = Marker_tyRef__4xhug3qIp2asVjvZ3bVlPQ;
NTILpnode_nilabilityT__3w8Q5T9cOF5FQ54JItYYe3Q_.size = sizeof(tyTuple__3w8Q5T9cOF5FQ54JItYYe3Q);
NTILpnode_nilabilityT__3w8Q5T9cOF5FQ54JItYYe3Q_.align = NIM_ALIGNOF(tyTuple__3w8Q5T9cOF5FQ54JItYYe3Q);
NTILpnode_nilabilityT__3w8Q5T9cOF5FQ54JItYYe3Q_.kind = 18;
NTILpnode_nilabilityT__3w8Q5T9cOF5FQ54JItYYe3Q_.base = 0;
NTILpnode_nilabilityT__3w8Q5T9cOF5FQ54JItYYe3Q_.flags = 2;
TM__9a75rVZu7sg4HRrHPMS3VUw_19_2[0] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[48];
TM__9a75rVZu7sg4HRrHPMS3VUw_0[48].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[48].offset = offsetof(tyTuple__3w8Q5T9cOF5FQ54JItYYe3Q, Field0);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[48].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[48].name = "Field0";
TM__9a75rVZu7sg4HRrHPMS3VUw_19_2[1] = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[49];
TM__9a75rVZu7sg4HRrHPMS3VUw_0[49].kind = 1;
TM__9a75rVZu7sg4HRrHPMS3VUw_0[49].offset = offsetof(tyTuple__3w8Q5T9cOF5FQ54JItYYe3Q, Field1);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[49].typ = (&NTInilability__XDKthSvkddpY2lzfr6uPgA_);
TM__9a75rVZu7sg4HRrHPMS3VUw_0[49].name = "Field1";
TM__9a75rVZu7sg4HRrHPMS3VUw_0[47].len = 2; TM__9a75rVZu7sg4HRrHPMS3VUw_0[47].kind = 2; TM__9a75rVZu7sg4HRrHPMS3VUw_0[47].sons = &TM__9a75rVZu7sg4HRrHPMS3VUw_19_2[0];
NTILpnode_nilabilityT__3w8Q5T9cOF5FQ54JItYYe3Q_.node = &TM__9a75rVZu7sg4HRrHPMS3VUw_0[47];
NTIseqLLpnode_nilabilityTT__AHhlrIyws6DwjcjqnuoVWQ_.size = sizeof(tySequence__AHhlrIyws6DwjcjqnuoVWQ*);
NTIseqLLpnode_nilabilityTT__AHhlrIyws6DwjcjqnuoVWQ_.align = NIM_ALIGNOF(tySequence__AHhlrIyws6DwjcjqnuoVWQ*);
NTIseqLLpnode_nilabilityTT__AHhlrIyws6DwjcjqnuoVWQ_.kind = 24;
NTIseqLLpnode_nilabilityTT__AHhlrIyws6DwjcjqnuoVWQ_.base = (&NTILpnode_nilabilityT__3w8Q5T9cOF5FQ54JItYYe3Q_);
NTIseqLLpnode_nilabilityTT__AHhlrIyws6DwjcjqnuoVWQ_.flags = 2;
NTIseqLLpnode_nilabilityTT__AHhlrIyws6DwjcjqnuoVWQ_.marker = Marker_tySequence__AHhlrIyws6DwjcjqnuoVWQ;
}

