/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 32

#include "nimbase.h"
#include <string.h>
#include <dirent.h>
#include <setjmp.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <time.h>
#include <stdio.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ;
typedef struct RootObj RootObj;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tySequence__ng4kcoK184wyb3xemBLQmw tySequence__ng4kcoK184wyb3xemBLQmw;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_RstFileTable__JJYG5kijP4PSa5F9a7da5tw tyObject_RstFileTable__JJYG5kijP4PSa5F9a7da5tw;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyObject_Table__NKkg36PLm9cXyIIgbxq1hGQ tyObject_Table__NKkg36PLm9cXyIIgbxq1hGQ;
typedef struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og tySequence__pUxI6Ljo6IKKHXKOZkQ7Og;
typedef struct tyObject_TocEntry__8s9aRe62JHXKMgO2pStC19cA tyObject_TocEntry__8s9aRe62JHXKMgO2pStC19cA;
typedef struct tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ;
typedef struct tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ;
typedef struct tyTuple__JfHvHzMrhKkWAUvQKe0i1A tyTuple__JfHvHzMrhKkWAUvQKe0i1A;
typedef struct tyObject_Env_rstgendotnim_RstGenerator___diB2NTuAIWY0FO9c5IUJRGg tyObject_Env_rstgendotnim_RstGenerator___diB2NTuAIWY0FO9c5IUJRGg;
typedef struct tySequence__xv3aaFd3JCw8NbmALHiezQ tySequence__xv3aaFd3JCw8NbmALHiezQ;
typedef struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tyTuple__7q7q3E6Oj24ZNVJb9aonhAg;
typedef struct tyObject_GeneralTokenizer__VRAep1bu6pPMSDyuqMGQyg tyObject_GeneralTokenizer__VRAep1bu6pPMSDyuqMGQyg;
typedef struct tyObject_TLineInfo__AUK89aIO9ccPtw38jya2kdpA tyObject_TLineInfo__AUK89aIO9ccPtw38jya2kdpA;
typedef struct tySequence__jo4WO9beNiWGoaKRjSrOMJQ tySequence__jo4WO9beNiWGoaKRjSrOMJQ;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw;
typedef struct tyTuple__qsoB9cWzItmjtA8wRSiKBbA tyTuple__qsoB9cWzItmjtA8wRSiKBbA;
typedef struct tyObject_CodeBlockParams__9aOEbhOZz0OzaP4azOrleuA tyObject_CodeBlockParams__9aOEbhOZz0OzaP4azOrleuA;
typedef struct tyTuple__UV3llMMYFckfui8YMBuUZA tyTuple__UV3llMMYFckfui8YMBuUZA;
typedef struct tyTuple__9aBSJwMgaASaEGDGtYmlj6w tyTuple__9aBSJwMgaASaEGDGtYmlj6w;
typedef struct tySequence__mQGg5S79bnlEvqSZ53aiYNQ tySequence__mQGg5S79bnlEvqSZ53aiYNQ;
typedef struct tySequence__hf5PiuqqytWiEcddgIR5sQ tySequence__hf5PiuqqytWiEcddgIR5sQ;
typedef struct tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA;
typedef struct tyObject_Table__0eDcTDUP9ap4EVATy5ptGQw tyObject_Table__0eDcTDUP9ap4EVATy5ptGQw;
typedef struct tyTuple__0bWXDvqglYSS6aTKl80IVQ tyTuple__0bWXDvqglYSS6aTKl80IVQ;
typedef struct Exception Exception;
typedef struct tySequence__QbmGqFaLnb1IWWToREeaIA tySequence__QbmGqFaLnb1IWWToREeaIA;
typedef struct TSafePoint TSafePoint;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__sPaDkVPSC0MkcoXCxPH9ccA tyTuple__sPaDkVPSC0MkcoXCxPH9ccA;
typedef struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA;
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct RootObj {
TNimType* m_type;
};
typedef NU8 tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef struct {
N_NIMCALL_PTR(NimStringDesc*, ClP_0) (NimStringDesc* filename, void* ClE_0);
void* ClE_0;
} tyProc__oFHfEKFsiYTMAy9a42cSiKw;
typedef NU8 tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* filename, NI line, NI col, tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg msgKind, NimStringDesc* arg, void* ClE_0);
void* ClE_0;
} tyProc__gd6fvPtd9aVRsRjs9bLyzE9bQ;
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_RstFileTable__JJYG5kijP4PSa5F9a7da5tw {
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIdx;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* idxToFilename;
};
typedef NimStringDesc* tyArray__2cm2du8CnvAGpSJPsQ9bNhw[5];
struct tyObject_Table__NKkg36PLm9cXyIIgbxq1hGQ {
tySequence__pUxI6Ljo6IKKHXKOZkQ7Og* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, NimStringDesc* filename, NimStringDesc* cmd, NI status, NimStringDesc* content, void* ClE_0);
void* ClE_0;
} tyProc__bvoZymnzBMzGoI59bjcrthA;
typedef NU8 tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg;
struct tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ {
  RootObj Sup;
tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ target;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* config;
NI splitAfter;
NI listingCounter;
tySequence__ng4kcoK184wyb3xemBLQmw* tocPart;
NIM_BOOL hasToc;
NimStringDesc* theIndex;
tyProc__oFHfEKFsiYTMAy9a42cSiKw findFile;
tyProc__gd6fvPtd9aVRsRjs9bLyzE9bQ msgHandler;
NimStringDesc* outDir;
NimStringDesc* destFile;
tyObject_RstFileTable__JJYG5kijP4PSa5F9a7da5tw filenames;
NimStringDesc* filename;
tyArray__2cm2du8CnvAGpSJPsQ9bNhw meta;
NimStringDesc* currentSection;
tyObject_Table__NKkg36PLm9cXyIIgbxq1hGQ seenIndexTerms;
NI id;
tyProc__bvoZymnzBMzGoI59bjcrthA onTestSnippet;
tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg escMode;
};
struct tyObject_TocEntry__8s9aRe62JHXKMgO2pStC19cA {
tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n;
NimStringDesc* refname;
NimStringDesc* header;
};
struct tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ {
NI Field0;
NimStringDesc* Field1;
NI Field2;
};
struct tyTuple__JfHvHzMrhKkWAUvQKe0i1A {
void* Field0;
tyObject_Env_rstgendotnim_RstGenerator___diB2NTuAIWY0FO9c5IUJRGg* Field1;
};
typedef NU8 tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA;
struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA {
  RootObj Sup;
NI counter;
tySequence__xv3aaFd3JCw8NbmALHiezQ* data;
tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA mode;
};
struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
};
typedef NU8 tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ;
typedef NU8 tyEnum_SourceLanguage__caWYuN9aCrrNgLAxHN3okug;
typedef NU8 tyEnum_TokenClass__RdrR6Svvyw1PZnyzCQYlWA;
struct tyObject_GeneralTokenizer__VRAep1bu6pPMSDyuqMGQyg {
  RootObj Sup;
tyEnum_TokenClass__RdrR6Svvyw1PZnyzCQYlWA kind;
NI start;
NI length;
NCSTRING buf;
NI pos;
tyEnum_TokenClass__RdrR6Svvyw1PZnyzCQYlWA state;
tyEnum_SourceLanguage__caWYuN9aCrrNgLAxHN3okug lang;
};
typedef NimStringDesc* tyArray__Re75IspeoxXy2oCZHwcRrA[2];
typedef NimStringDesc* tyArray__EioREI4AIANcdNaP09cPs7Q[37];
typedef NU8 tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg;
struct tyObject_TLineInfo__AUK89aIO9ccPtw38jya2kdpA {
NU16 line;
NI16 col;
NI32 fileIndex;
};
struct tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ {
tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg kind;
union{
struct {NimStringDesc* text;
} _kind_1;
struct {NimStringDesc* labelFmt;
} _kind_2;
struct {NimStringDesc* lineIndent;
} _kind_3;
struct {NimStringDesc* adType;
} _kind_4;
struct {NI level;
} _kind_5;
struct {NI order;
} _kind_6;
struct {tyObject_TLineInfo__AUK89aIO9ccPtw38jya2kdpA info;
} _kind_7;
};
NimStringDesc* anchor;
tySequence__jo4WO9beNiWGoaKRjSrOMJQ* sons;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
typedef NimStringDesc* tyArray__yt5VDPNtUGx9cBkOVakHwdQ[6];
typedef NimStringDesc* tyArray__haiLFy0nBviVTKFGuwztzQ[5];
struct tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw {
NI a;
NI b;
};
typedef NimStringDesc* tyArray__nHXaesL0DJZHyVS07ARPRA[1];
struct tyTuple__qsoB9cWzItmjtA8wRSiKBbA {
NIM_CHAR Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
typedef NimStringDesc* tyArray__sMpvt1sOxOJ3LFGulnbeMQ[4];
typedef NimStringDesc* tyArray__24KAM9afIUgUaqBaEBB6r9bg[3];
struct tyObject_CodeBlockParams__9aOEbhOZz0OzaP4azOrleuA {
NIM_BOOL numberLines;
NI startLine;
NimStringDesc* langStr;
tyEnum_SourceLanguage__caWYuN9aCrrNgLAxHN3okug lang;
NimStringDesc* filename;
NimStringDesc* testCmd;
NI status;
};
typedef N_CLOSURE_PTR(void, TM__vYBWrr780p7faFzauVMtPg_212) (tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, NimStringDesc* filename, NimStringDesc* cmd, NI status, NimStringDesc* content);
struct tyTuple__UV3llMMYFckfui8YMBuUZA {
NimStringDesc* Field0;
NimStringDesc* Field1;
};
typedef NimStringDesc* tyArray__o2NNn8BozErWfWgROFKAEg[10];
typedef NimStringDesc* tyArray__8ZvwQIddfpj2THRVPsFzIQ[1];
struct tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA {
NimStringDesc* keyword;
NimStringDesc* link;
NimStringDesc* linkTitle;
NimStringDesc* linkDesc;
};
struct tyObject_Table__0eDcTDUP9ap4EVATy5ptGQw {
tySequence__mQGg5S79bnlEvqSZ53aiYNQ* data;
NI counter;
};
struct tyTuple__9aBSJwMgaASaEGDGtYmlj6w {
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* Field0;
tySequence__hf5PiuqqytWiEcddgIR5sQ* Field1;
tyObject_Table__0eDcTDUP9ap4EVATy5ptGQw Field2;
};
struct tyTuple__0bWXDvqglYSS6aTKl80IVQ {
NI Field0;
tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA Field1;
tySequence__hf5PiuqqytWiEcddgIR5sQ* Field2;
};
typedef NU8 tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw;
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__QbmGqFaLnb1IWWToREeaIA* trace;
Exception* up;
};
struct TSafePoint {
TSafePoint* prev;
NI status;
jmp_buf context;
};
typedef NIM_CHAR tyArray__dTlC27m9c9aWd5dvuePYanug[256];
typedef NU8 tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w;
typedef tyTuple__UV3llMMYFckfui8YMBuUZA tyArray__0ipey9aZuUA8jy4OAHzODQg[3];
typedef struct {
N_NIMCALL_PTR(NI, ClP_0) (NimStringDesc* x, NimStringDesc* y, void* ClE_0);
void* ClE_0;
} tyProc__3pmh9bG9bLpdxUjFu9cDtbZaA;
typedef NU8 tyEnum_SortOrder__TcYjciSJ3jKUT4ygglumjg;
typedef N_CLOSURE_PTR(NI, TM__vYBWrr780p7faFzauVMtPg_266) (NimStringDesc* x, NimStringDesc* y, void* ClE_0);
typedef struct {
N_NIMCALL_PTR(NI, ClP_0) (tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA x, tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA y, void* ClE_0);
void* ClE_0;
} tyProc__5YgYRgMJZsuh62P0m8Lehw;
typedef N_CLOSURE_PTR(NI, TM__vYBWrr780p7faFzauVMtPg_268) (tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA x, tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA y, void* ClE_0);
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyTuple__sPaDkVPSC0MkcoXCxPH9ccA {
NimStringDesc* Field0;
NimStringDesc* Field1;
NIM_BOOL Field2;
};
struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA {
NCSTRING procname;
NI line;
NCSTRING filename;
};
struct tySequence__ng4kcoK184wyb3xemBLQmw {
  TGenericSeq Sup;
  tyObject_TocEntry__8s9aRe62JHXKMgO2pStC19cA data[SEQ_DECL_SIZE];
};
struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og {
  TGenericSeq Sup;
  tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ data[SEQ_DECL_SIZE];
};
struct tySequence__jo4WO9beNiWGoaKRjSrOMJQ {
  TGenericSeq Sup;
  tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__hf5PiuqqytWiEcddgIR5sQ {
  TGenericSeq Sup;
  tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA data[SEQ_DECL_SIZE];
};
struct tySequence__mQGg5S79bnlEvqSZ53aiYNQ {
  TGenericSeq Sup;
  tyTuple__0bWXDvqglYSS6aTKl80IVQ data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__xv3aaFd3JCw8NbmALHiezQ {
  TGenericSeq Sup;
  tyTuple__sPaDkVPSC0MkcoXCxPH9ccA data[SEQ_DECL_SIZE];
};
struct tySequence__QbmGqFaLnb1IWWToREeaIA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__ng4kcoK184wyb3xemBLQmw)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__pUxI6Ljo6IKKHXKOZkQ7Og)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(void, genericSeqAssign)(void* dest, void* src, TNimType* mt);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void, nossplitFile)(NimStringDesc* path, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(void, initTable__packagesZdocutilsZrstgen_108)(NI initialSize, tyObject_Table__NKkg36PLm9cXyIIgbxq1hGQ* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getOrDefault__pureZstrtabs_173)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, NimStringDesc* key, NimStringDesc* default_0);
N_LIB_PRIVATE N_NIMCALL(NI, nsuParseInt)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NI, nextSplitPoint__packagesZdocutilsZrstgen_233)(NimStringDesc* s, NI start);
static N_INLINE(void, addSplitter__packagesZdocutilsZrstgen_230)(tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ target, NimStringDesc** dest);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
static N_INLINE(void, escChar__packagesZdocutilsZrstgen_225)(tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ target, NimStringDesc** dest, NIM_CHAR c, tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg escMode);
N_LIB_PRIVATE N_NIMCALL(void, addHtmlChar__packagesZdocutilsZrstgen_205)(NimStringDesc** dest, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(void, addTexChar__packagesZdocutilsZrstgen_208)(NimStringDesc** dest, NIM_CHAR c, tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg escMode);
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(void, renderCodeLang__packagesZdocutilsZrstgen_8242)(NimStringDesc** result, tyEnum_SourceLanguage__caWYuN9aCrrNgLAxHN3okug lang, NimStringDesc* code, tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ target);
N_LIB_PRIVATE N_NIMCALL(void, initGeneralTokenizer__packagesZdocutilsZhighlite_166)(tyObject_GeneralTokenizer__VRAep1bu6pPMSDyuqMGQyg* g, NimStringDesc* buf);
N_LIB_PRIVATE N_NIMCALL(void, getNextToken__packagesZdocutilsZhighlite_1760)(tyObject_GeneralTokenizer__VRAep1bu6pPMSDyuqMGQyg* g, tyEnum_SourceLanguage__caWYuN9aCrrNgLAxHN3okug lang);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__system_7744)(NimStringDesc* s, NI first, NI last);
N_LIB_PRIVATE N_NIMCALL(void, dispA__packagesZdocutilsZrstgen_294)(tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ target, NimStringDesc** dest, NimStringDesc* xml, NimStringDesc* tex, NimStringDesc** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, nsuAddf)(NimStringDesc** s, NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, esc__packagesZdocutilsZrstgen_249)(tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ target, NimStringDesc* s, NI splitAfter, tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg escMode);
N_LIB_PRIVATE N_NIMCALL(void, deinitGeneralTokenizer__packagesZdocutilsZhighlite_169)(tyObject_GeneralTokenizer__VRAep1bu6pPMSDyuqMGQyg* g);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, quoteIndexColumn__packagesZdocutilsZrstgen_337)(NimStringDesc* text);
N_NIMCALL(NimStringDesc*, rawNewString)(NI cap);
N_LIB_PRIVATE N_NIMCALL(void, insert__system_7471)(NimStringDesc** x, NimStringDesc* item, NI i);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuReplaceStr)(NimStringDesc* s, NimStringDesc* sub, NimStringDesc* by);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, noschangeFileExt)(NimStringDesc* filename, NimStringDesc* ext);
N_LIB_PRIVATE N_NIMCALL(void, renderAux__packagesZdocutilsZrstgen_312)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc** result);
N_LIB_PRIVATE N_NIMCALL(NI, len__packagesZdocutilsZrstast_102)(tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n);
N_LIB_PRIVATE N_NIMCALL(void, renderRstToOut__packagesZdocutilsZrstgen_308)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc** result);
N_LIB_PRIVATE N_NIMCALL(void, renderHeadline__packagesZdocutilsZrstgen_8025)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc** result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rstnodeToRefname__packagesZdocutilsZrst_61)(tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderRstToText__packagesZdocutilsZrstast_462)(tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* node);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
static N_INLINE(void, decRef__system_5317)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5315)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5266)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5272)(void* usr);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5310)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___systemZdollars_3)(NI x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimCharToStr)(NIM_CHAR x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosextractFilename)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosrelativePath)(NimStringDesc* path, NimStringDesc* base, NIM_CHAR sep);
N_LIB_PRIVATE N_NIMCALL(void, setIndexTerm__packagesZdocutilsZrstgen_353)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, NimStringDesc* htmlFile, NimStringDesc* id, NimStringDesc* term, NimStringDesc* linkTitle, NimStringDesc* linkDesc);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, stripTocHtml__packagesZdocutilsZrstgen_8020)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NI, nsuFindChar)(NimStringDesc* s, NIM_CHAR sub, NI start, NI last);
N_LIB_PRIVATE N_NIMCALL(void, nsuDelete)(NimStringDesc** s, NI first, NI last);
static N_INLINE(NimStringDesc*, spaces__pureZstrutils_1029)(NI n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuRepeatChar)(NIM_CHAR c, NI count);
N_LIB_PRIVATE N_NIMCALL(void, renderOverline__packagesZdocutilsZrstgen_8077)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc** result);
N_LIB_PRIVATE N_NIMCALL(void, renderAux__packagesZdocutilsZrstgen_324)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc* html, NimStringDesc* tex, NimStringDesc** result);
N_LIB_PRIVATE N_NIMCALL(void, renderEnumList__packagesZdocutilsZrstgen_8331)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc** result);
static N_INLINE(NIM_CHAR*, X5BX5D___system_7362)(NimStringDesc** s, NI i);
static N_INLINE(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw, dotdot___pureZunicode_840)(NI a, NI b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuIsDigitChar)(NIM_CHAR c);
static N_INLINE(NimStringDesc*, X5BX5D___pureZunicode_865)(NimStringDesc* s, tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw x);
N_NIMCALL(NimStringDesc*, mnewString)(NI len);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuIsUpperAsciiChar)(NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(void, renderField__packagesZdocutilsZrstgen_8320)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc** result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addNodes__packagesZdocutilsZrst_63)(tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuStrip)(NimStringDesc* s, NIM_BOOL leading, NIM_BOOL trailing, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreStyle)(NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__systemZassertions_56)(NimStringDesc* msg);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___system_3126)(NF x);
static N_INLINE(NF, toFloat__system_1702)(NI i);
N_LIB_PRIVATE N_NIMCALL(void, renderAdmonition__packagesZdocutilsZrstgen_8429)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc** result);
N_LIB_PRIVATE N_NIMCALL(NI, hashString)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuCapitalizeAscii)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, texColumns__packagesZdocutilsZrstgen_8313)(tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuRepeatStr)(NimStringDesc* s, NI n);
N_LIB_PRIVATE N_NIMCALL(void, renderHyperlink__packagesZdocutilsZrstgen_8438)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* text, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* link, NimStringDesc** result, NIM_BOOL external);
N_LIB_PRIVATE N_NIMCALL(void, safeProtocol__packagesZdocutilsZrstgen_8104)(NimStringDesc** linkStr);
N_LIB_PRIVATE N_NIMCALL(NI, parseIdent__pureZparseutils_57)(NimStringDesc* s, NimStringDesc** ident, NI start);
static N_INLINE(NI, skip__pureZparseutils_117)(NimStringDesc* s, NimStringDesc* token, NI start);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreCase)(NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ*, lastSon__packagesZdocutilsZrstast_200)(tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n);
N_LIB_PRIVATE N_NIMCALL(void, renderImage__packagesZdocutilsZrstgen_8149)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc** result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getArgument__packagesZdocutilsZrst_68)(tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getFieldValue__packagesZdocutilsZrst_65)(tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc* fieldname);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dispF__packagesZdocutilsZrstgen_284)(tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ target, NimStringDesc* xml, NimStringDesc* tex, NimStringDesc** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuEndsWith)(NimStringDesc* s, NimStringDesc* suffix);
N_LIB_PRIVATE N_NIMCALL(void, renderCode__packagesZdocutilsZrstgen_8252)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc** result);
N_LIB_PRIVATE N_NIMCALL(void, parseCodeBlockParams__packagesZdocutilsZrstgen_8195)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, tyObject_CodeBlockParams__9aOEbhOZz0OzaP4azOrleuA* Result);
N_LIB_PRIVATE N_NIMCALL(void, init__packagesZdocutilsZrstgen_88)(tyObject_CodeBlockParams__9aOEbhOZz0OzaP4azOrleuA* p);
N_LIB_PRIVATE N_NIMCALL(void, parseCodeBlockField__packagesZdocutilsZrstgen_8191)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, tyObject_CodeBlockParams__9aOEbhOZz0OzaP4azOrleuA* params);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuToLowerAsciiStr)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NI, getField1Int__packagesZdocutilsZrstgen_8163)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc* fieldName);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getFieldValue__packagesZdocutilsZrst_5216)(tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n);
N_LIB_PRIVATE N_NIMCALL(NI, npuParseInt)(NimStringDesc* s, NI* number, NI start);
N_LIB_PRIVATE N_NIMCALL(void, rstMessage__packagesZdocutilsZrst_2080)(tyObject_RstFileTable__JJYG5kijP4PSa5F9a7da5tw filenames, tyProc__gd6fvPtd9aVRsRjs9bLyzE9bQ f, tyObject_TLineInfo__AUK89aIO9ccPtw38jya2kdpA info, tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg msgKind, NimStringDesc* arg);
static N_INLINE(NimStringDesc*, X5BX5D___pureZunicode_3215)(NimStringDesc* s, tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw x);
static N_INLINE(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw, dotdot___stdZenumutils_90)(NI a, NI b);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuUnescape)(NimStringDesc* s, NimStringDesc* prefix, NimStringDesc* suffix);
N_LIB_PRIVATE N_NIMCALL(tyEnum_SourceLanguage__caWYuN9aCrrNgLAxHN3okug, getSourceLanguage__packagesZdocutilsZhighlite_97)(NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(void, buildLinesHtmlTable__packagesZdocutilsZrstgen_8216)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_CodeBlockParams__9aOEbhOZz0OzaP4azOrleuA* params, NimStringDesc* code, NimStringDesc* idStr, tyTuple__UV3llMMYFckfui8YMBuUZA* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatSingleElem)(NimStringDesc* formatstr, NimStringDesc* a);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCountLines)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(void, renderContainer__packagesZdocutilsZrstgen_8307)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc** result);
N_LIB_PRIVATE N_NIMCALL(void, renderIndexTerm__packagesZdocutilsZrstgen_374)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc** result);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__packagesZdocutilsZrstgen_419)(tyObject_Table__NKkg36PLm9cXyIIgbxq1hGQ t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___packagesZdocutilsZrstgen_831)(tyObject_Table__NKkg36PLm9cXyIIgbxq1hGQ* t, NimStringDesc* key, NI val);
N_LIB_PRIVATE N_NIMCALL(NI, getOrDefault__packagesZdocutilsZrstgen_727)(tyObject_Table__NKkg36PLm9cXyIIgbxq1hGQ t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(void, renderSmiley__packagesZdocutilsZrstgen_8159)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc** result);
N_LIB_PRIVATE N_NIMCALL(void, renderTocEntry__packagesZdocutilsZrstgen_8131)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_TocEntry__8s9aRe62JHXKMgO2pStC19cA e, NimStringDesc** result);
N_LIB_PRIVATE N_NIMCALL(void, renderTocEntries__packagesZdocutilsZrstgen_8135)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, NI* j, NI lvl, NimStringDesc** result);
N_LIB_PRIVATE N_NIMCALL(void, writeFile__systemZio_476)(NimStringDesc* filename, NimStringDesc* content);
N_LIB_PRIVATE N_NIMCALL(void, readIndexDir__packagesZdocutilsZrstgen_6719)(NimStringDesc* dir, tyTuple__9aBSJwMgaASaEGDGtYmlj6w* Result);
N_LIB_PRIVATE N_NIMCALL(void, initTable__packagesZdocutilsZrstgen_6729)(NI initialSize, tyObject_Table__0eDcTDUP9ap4EVATy5ptGQw* Result);
static N_NIMCALL(void, Marker_tySequence__hf5PiuqqytWiEcddgIR5sQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__mQGg5S79bnlEvqSZ53aiYNQ)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void*, newSeq)(TNimType* typ, NI len);
static N_INLINE(NimStringDesc*, pop__pureZos_1366)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ** s);
static N_INLINE(NimStringDesc*, slash___pureZos_121)(NimStringDesc* head, NimStringDesc* tail);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosjoinPath)(NimStringDesc* head, NimStringDesc* tail);
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringDesc* s);
N_LIB_PRIVATE N_NOINLINE(void, raiseOSError__pureZos_405)(NI32 errorCode, NimStringDesc* additionalInfo);
N_LIB_PRIVATE N_NIMCALL(NI32, osLastError__pureZos_408)(void);
static N_INLINE(void, pushSafePoint)(TSafePoint* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, cstrToNimstr)(NCSTRING str);
N_LIB_PRIVATE N_NIMCALL(tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw, getSymlinkFileKind__pureZos_1224)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(FILE*, open__systemZio_432)(NimStringDesc* filename, tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w mode, NI bufSize);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, readLine__systemZio_240)(FILE* f, NimStringDesc** line);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__system_7756)(NimStringDesc* s, NI first);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDocumentationTitle__packagesZdocutilsZrstgen_2066)(NimStringDesc* hyperlink);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ*, nsuSplitChar)(NimStringDesc* s, NIM_CHAR sep, NI maxsplit);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, unquoteIndexColumn__packagesZdocutilsZrstgen_341)(NimStringDesc* text);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, multiReplace__pureZstrutils_1678)(NimStringDesc* s, tyTuple__UV3llMMYFckfui8YMBuUZA* replacements, NI replacementsLen_0);
static N_INLINE(void, popSafePoint)(void);
N_LIB_PRIVATE N_NIMCALL(void, close__systemZio_218)(FILE* f);
N_LIB_PRIVATE N_NIMCALL(void, nimLeaveFinally)(void);
N_LIB_PRIVATE N_NIMCALL(void, reraiseException)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, setLengthStr)(NimStringDesc* s, NI newLen);
N_LIB_PRIVATE N_NIMCALL(NI, len__packagesZdocutilsZrstgen_5651)(tyObject_Table__0eDcTDUP9ap4EVATy5ptGQw t);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___packagesZdocutilsZrstgen_6889)(tyObject_Table__0eDcTDUP9ap4EVATy5ptGQw* t, tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA key, tySequence__hf5PiuqqytWiEcddgIR5sQ* val);
static N_INLINE(NI, emarkamp___pureZhashes_3)(NI h, NI val);
N_LIB_PRIVATE N_NIMCALL(NI, hash__pureZhashes_279)(NimStringDesc* x);
static N_INLINE(NI, emarkdollar___pureZhashes_18)(NI h);
N_LIB_PRIVATE N_NIMCALL(void, sort__sem_1836)(NimStringDesc** a, NI aLen_0, tyProc__3pmh9bG9bLpdxUjFu9cDtbZaA cmp, tyEnum_SortOrder__TcYjciSJ3jKUT4ygglumjg order);
N_LIB_PRIVATE N_NIMCALL(NI, cmp__system_1549)(NimStringDesc* x, NimStringDesc* y);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, generateDocumentationJumps__packagesZdocutilsZrstgen_6586)(tyObject_Table__0eDcTDUP9ap4EVATy5ptGQw docs);
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_31)(NI hcode);
N_LIB_PRIVATE N_NIMCALL(void, sort__packagesZdocutilsZrstgen_6113)(tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA* a, NI aLen_0, tyProc__5YgYRgMJZsuh62P0m8Lehw cmp, tyEnum_SortOrder__TcYjciSJ3jKUT4ygglumjg order);
N_LIB_PRIVATE N_NIMCALL(NI, cmp__packagesZdocutilsZrstgen_1995)(tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA a, tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA b);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuJoinSep)(NimStringDesc** a, NI aLen_0, NimStringDesc* sep);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, generateModuleJumps__packagesZdocutilsZrstgen_6703)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* modules);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, prettyLink__packagesZdocutilsZrstgen_85)(NimStringDesc* file);
N_LIB_PRIVATE N_NIMCALL(void, sortIndex__packagesZdocutilsZrstgen_2005)(tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA* a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(void, ltminus___packagesZdocutilsZrstgen_2002)(tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA* a, tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA b);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, generateSymbolIndex__packagesZdocutilsZrstgen_2045)(tySequence__hf5PiuqqytWiEcddgIR5sQ* symbols);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, escapeLink__packagesZdocutilsZrstgen_2030)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toHex__pureZstrutils_1788)(NI x, NI len);
extern TNimType NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_;
N_LIB_PRIVATE TNimType NTIrstgenerator__qr285fchxFL31hqgMYpbNQ_;
N_LIB_PRIVATE TNimType NTIoutputtarget__9aM59bezht8Qas1PkBOyPLJQ_;
extern TNimType NTIstringtableref__frXcOWngaP9adxeuIUa3iBg_;
extern TNimType NTIint__rR5Bzr1D5krxoo1NcNyeMA_;
N_LIB_PRIVATE TNimType NTItocentry__8s9aRe62JHXKMgO2pStC19cA_;
extern TNimType NTIprstnode__yfV9aZUcV0SioJcvRrGyZlg_;
extern TNimType NTIstring__77mFvmsOLKik79ci2hXkHEg_;
N_LIB_PRIVATE TNimType NTIseqLtocentryT__ng4kcoK184wyb3xemBLQmw_;
extern TNimType NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_;
extern TNimType NTIfindfilehandler__oFHfEKFsiYTMAy9a42cSiKw_;
extern TNimType NTImsghandler__gd6fvPtd9aVRsRjs9bLyzE9bQ_;
extern TNimType NTIrstfiletable__JJYG5kijP4PSa5F9a7da5tw_;
N_LIB_PRIVATE TNimType NTIarrayLmetaenum_stringT__2cm2du8CnvAGpSJPsQ9bNhw_;
N_LIB_PRIVATE TNimType NTItable__NKkg36PLm9cXyIIgbxq1hGQ_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__sr3s7uVHpu9cEbbDnCSg8yQ_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__pUxI6Ljo6IKKHXKOZkQ7Og_;
N_LIB_PRIVATE TNimType NTIprocLd58varrstgenerator_filename58string_cmd58string_status58int_content58stringTLOclosureOT__bvoZymnzBMzGoI59bjcrthA_;
extern TNimType NTIpointer__vr5DoT1jILTGdRlYv1OYpw_;
extern TNimType NTIrefobject__HsJiUUcO9cHBdUCi0HwkSTA_;
N_LIB_PRIVATE TNimType NTIescapemode__j9aHxQ3kKlc4KvedeVQimjg_;
extern TNimType NTIkeyvaluepairseq__7lEisrXlQEzwtUKW5pzRCw_;
extern TNimType NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_;
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_13, ".nim", 4);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_14, "Module ", 7);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_15, "split.item.toc", 14);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_16, "<wbr />", 7);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_17, "\\-", 2);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_18, "&amp;", 5);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_19, "&lt;", 4);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_20, "&gt;", 4);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_21, "&quot;", 6);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_22, "\\", 1);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_23, "{}", 2);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_24, "\\textasciigrave{}", 17);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_25, "\\textbackslash{}", 16);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_26, "\\%7B", 4);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_27, "\\{", 2);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_28, "\\%7D", 4);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_29, "\\}", 2);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_30, "\\text{]}", 8);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_31, "]", 1);
extern TNimType NTIgeneraltokenizer__VRAep1bu6pPMSDyuqMGQyg_;
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_32, "<span class=\"$2\">$1</span>", 26);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_33, "\\span$2{$1}", 11);
extern NIM_CONST tyArray__EioREI4AIANcdNaP09cPs7Q tokenClassToStr__packagesZdocutilsZhighlite_68;
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_34, "\\n", 2);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_35, "\\t", 2);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_36, "\012", 1);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_37, "_._", 3);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_38, "..", 2);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_39, "-", 1);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_40, "\012<h$1><a class=\"toc-backref\"$2 href=\"#$5\">$3</a></h$1>", 54);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_41, "\\rsth$4[$6]{$3}$2\012", 18);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_42, " id=\"", 5);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_43, "\"", 1);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_44, "\\label{", 7);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_45, "}\\hypertarget{", 14);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_46, "}{}", 3);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_47, "\012<h$1$2>$3</h$1>", 16);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_48, "\\rsth$4[$5]{$3}$2\012", 18);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_49, "html", 4);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_50, "<h$1$2><center>$3</center></h$1>", 32);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_51, "\\rstov$4[$5]{$3}$2\012", 19);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_52, "<hr$2 />\012", 9);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_53, "\012\012\\vspace{0.6em}\\hrule$2\012", 25);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_54, "<p$2>$1</p>\012", 12);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_55, "\012\012$2\012$1\012\012", 9);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_56, "<ul$2 class=\"simple\">$1</ul>\012", 29);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_57, "\\begin{itemize}\012$2\012$1\\end{itemize}\012", 35);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_58, "<li$2>$1</li>\012", 14);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_59, "\\item $2$1\012", 11);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_60, "(", 1);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_61, "\012%", 2);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_62, "label=", 6);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_63, "\\arabic*", 8);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_64, ",", 1);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_65, "1", 1);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_66, "start=$1", 8);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_67, "[$1$2]", 6);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_68, "\\Alph*", 6);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_69, "\\alph*", 6);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_70, ",start=", 7);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_71, " start=\"$1\"", 11);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_72, "class=\"simple\"", 14);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_74, "class=\"upperalpha simple\"", 25);
static NIM_CONST tyTuple__qsoB9cWzItmjtA8wRSiKBbA TM__vYBWrr780p7faFzauVMtPg_73 = {65,
((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_74)}
;
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_76, "class=\"loweralpha simple\"", 25);
static NIM_CONST tyTuple__qsoB9cWzItmjtA8wRSiKBbA TM__vYBWrr780p7faFzauVMtPg_75 = {97,
((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_76)}
;
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_77, "<ol$2 ", 6);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_78, ">$1</ol>\012", 9);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_79, "\\begin{enumerate}", 17);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_80, "$2$1\\end{enumerate}\012", 20);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_81, "<dl$2 class=\"docutils\">$1</dl>\012", 31);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_82, "\\begin{description}\012$2\012$1\\end{description}\012", 43);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_83, "<dt$2>$1</dt>\012", 14);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_84, "$2\\item[$1]\\  ", 14);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_85, "<dd$2>$1</dd>\012", 14);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_86, "$2\012$1\012", 6);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_87, "<table$2 class=\"docinfo\" frame=\"void\" rules=\"none\"><col class=\"docinfo-name\" /><col class=\"docinfo-content\" /><tbody valign=\"top\">$1</tbody></table>", 148);
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__vYBWrr780p7faFzauVMtPg_88 = {
0x00, 0x3e, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_89, "author", 6);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_90, "authors", 7);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_91, "version", 7);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_92, "<tr>$1</tr>\012", 12);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_93, "$1", 2);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_94, "<th class=\"docinfo-name\">$1:</th>", 33);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_95, "\\item[$1:]", 10);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_96, "<td>$1</td>", 11);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_97, " $1\012", 4);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_98, "<div$2 class=\"option-list\">$1</div>", 35);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_99, "\\begin{rstoptlist}$2\012$1\\end{rstoptlist}", 39);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_100, " odd", 4);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_101, "<div class=\"option-list-item", 28);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_102, "\">$1</div>\012", 11);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_103, "<div class=\"option-list-label\"><tt><span class=\"option\">$1</span></tt></div>", 76);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_104, "\\item[\\rstcodeitem{\\spanoption{$1}}]", 36);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_105, "<div class=\"option-list-description\">$1</div>", 45);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_106, "rstgen.nim(1273, 14) `false` renderRstToOut", 43);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_107, "<pre$2>$1</pre>\012", 16);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_108, "\012\012$2\\begin{rstpre}\012$1\012\\end{rstpre}\012\012", 36);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_109, "rstgen.nim(1278, 14) `false` renderRstToOut", 43);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_110, "<p$2>$1</p> ", 12);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_111, "\012\012$2\012$1", 7);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_112, "<p$2>$1</p>", 11);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_113, "\012\\vspace{0.5em}$2\012$1\\vspace{0.5em}\012", 35);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_114, "$1<br/>", 7);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_115, "\\noindent $1\012\012", 14);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_116, "<br/>", 5);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_117, "\\vspace{1em}\012", 13);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_118, "em", 2);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_119, "<span style=\"margin-left: ", 26);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_120, "\">$1</span><br/>", 16);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_121, "\\noindent\\hspace{", 17);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_122, "}$1\012\012", 5);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_123, "<blockquote$2><p>$1</p></blockquote>\012", 37);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_124, "\\begin{quote}\012$2\012$1\\end{quote}\012", 31);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_125, "admonition_warning", 18);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_126, "\\large", 6);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_127, "orange", 6);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_128, "hint", 4);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_129, "note", 4);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_130, "tip", 3);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_131, "attention", 9);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_132, "admonition", 10);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_133, "important", 9);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_134, "warning", 7);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_135, "caution", 7);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_136, "danger", 6);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_137, "error", 5);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_138, "admonition-info", 15);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_139, "\\normalsize", 11);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_140, "green", 5);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_141, "admonition-warning", 18);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_142, "admonition-error", 16);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_143, "\\Large", 6);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_144, "red", 3);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_145, "<div class=\"admonition ", 23);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_146, "\">", 2);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_147, "<span$2 class=\"", 15);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_148, "-text\"><b>", 10);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_149, ":</b></span>\012$1</div>\012", 22);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_150, "\012\012\\begin{rstadmonition}[borderline west={0.2em}{0pt}{", 53);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_151, "}]$2\012{", 6);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_152, "\\color{", 7);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_153, "}{\\textbf{", 10);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_154, ":}}} $1\012\\end{rstadmonition}\012", 28);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_155, "<table$2 border=\"1\" class=\"docutils\">$1</table>", 47);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_156, "\012$2\012\\begin{rsttab}{", 19);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_157, "L", 1);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_158, "}\012\\hline\012$1\\end{rsttab}", 23);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_159, " & ", 3);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_160, "\\\\\012\\hline\012", 10);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_161, "<tr>", 4);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_162, "</tr>\012", 6);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_163, "<th>$1</th>", 11);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_164, "\\textbf{$1}", 11);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_165, "<hr class=\"footnote\"><div class=\"footnote-group\">\012$1</div>\012", 59);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_166, "\012\012\\noindent\\rule{0.25\\linewidth}{.4pt}\012\\begin{rstfootnote}\012$1\\end{rstfootnote}\012\012", 80);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_167, "<div$2><div class=\"footnote-label\"><sup><strong><a href=\"#$4\">[$3]</a></strong></sup></div> &ensp; $1\012</div>\012", 109);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_168, "\\item[\\textsuperscript{[$3]}]$2 $1\012", 35);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_169, ":", 1);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_170, "http", 4);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_171, "https", 5);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_172, "ftp", 3);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_173, "<a class=\"reference external\" href=\"$2\">$1</a>", 46);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_174, "\\href{$2}{$1}", 13);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_175, "<a class=\"reference internal\" href=\"#$2\">$1</a>", 47);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_176, "\\hyperlink{$2}{$1} (p.~\\pageref{$2})", 36);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_177, "[", 1);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_178, "<sup><strong><a class=\"reference internal\" href=\"#$2\">$1</a></strong></sup>", 75);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_179, "\\textsuperscript{\\hyperlink{$2}{\\textbf{$1}}}", 45);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_180, "scale", 5);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_181, " scale=\"$1\"", 11);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_182, " scale=$1", 9);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_183, "height", 6);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_184, " height=\"$1\"", 12);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_185, " height=$1", 10);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_186, "width", 5);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_187, " width=\"$1\"", 11);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_188, " width=$1", 9);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_189, "alt", 3);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_190, " alt=\"$1\"", 9);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_191, "align", 5);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_192, " align=\"$1\"", 11);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_193, "[$1]", 4);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_194, ".mp4", 4);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_195, ".ogg", 4);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_196, ".webm", 5);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_197, "      <video$3 src=\"$1\"$2 autoPlay=\'true\' loop=\'true\' muted=\'true\'>\012      Sorry, your browser doesn\'t support embedded videos\012      </video>\012    ", 145);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_198, "<img$3 src=\"$1\"$2/>", 19);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_199, "target", 6);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_200, "$3\\includegraphics$2{$1}", 24);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_201, "number-lines", 12);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_202, "file", 4);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_203, "filename", 8);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_204, "test", 4);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_205, "status", 6);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_206, "exitcode", 8);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_207, "default-language", 16);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_208, "field $1 requires an integer, but \'$2\' was given", 48);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_209, "extra arguments were given to $1: \'$2\'", 38);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_210, "$nim r --backend:$backend --lib:$libpath $docCmd $options", 57);
static NIM_CONST tyProc__bvoZymnzBMzGoI59bjcrthA TM__vYBWrr780p7faFzauVMtPg_211 = {NIM_NIL,NIM_NIL};
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_213, "doc.listing_start", 17);
extern NIM_CONST tyArray__o2NNn8BozErWfWgROFKAEg sourceLanguageToStr__packagesZdocutilsZhighlite_66;
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_214, "doc.listing_end", 15);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_215, "<table$1 class=\"line-nums-table\">", 33);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_216, "<tbody><tr><td class=\"blob-line-nums\"><pre class=\"line-nums\">", 61);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_217, "</pre></td><td>", 15);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_218, "</td></tr></tbody></table>", 26);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_219, "doc.listing_button", 18);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_220, "<tt class=\"docutils literal\"><span class=\"pre\">", 47);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_221, "</span></tt>", 12);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_222, "\012\012", 2);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_223, "\\begin{rstpre}\012", 15);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_224, "\012\\end{rstpre}\012\012", 15);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_225, "\\rstcode{", 9);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_226, "}", 1);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_227, "<div>$1</div>", 13);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_228, "<div class=\"$1\">$2</div>", 24);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_229, "$2", 2);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_230, "|$1|", 4);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_231, "Other", 5);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_232, "<tt class=\"docutils literal\"><span class=\"pre $2\">$1</span></tt>", 64);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_233, "\\rstcode{\\span$2{$1}}", 21);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_234, "<sub>$1</sub>", 13);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_235, "\\rstsub{$1}", 11);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_236, "<sup>$1</sup>", 13);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_237, "\\rstsup{$1}", 11);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_238, "<em>$1</em>", 11);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_239, "\\emph{$1}", 9);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_240, "<strong>$1</strong>", 19);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_241, "<strong><em>$1</em></strong>", 28);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_242, "\\textbf{emph{$1}}", 17);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_243, "<span id=\"$1\">$2</span>", 23);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_244, "\\nimindexterm{$1}{$2}", 21);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_245, "<tt class=\"docutils literal\"><span class=\"pre\">$1</span></tt>", 61);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_246, "\\rstcode{$1}", 12);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_247, "<span class=\"target\" id=\"$2\">$1</span>", 38);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_248, "\\label{$2}\\hypertarget{$2}{$1}", 30);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_249, "<img src=\"$1\" width=\"15\"\012        height=\"17\" hspace=\"2\" vspace=\"2\" class=\"smiley\" />", 84);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_250, "\\includegraphics{$1}", 20);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_251, "doc.smiley_format", 17);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_252, "<li><a class=\"reference\" id=\"$1_toc\" href=\"#$1\">$2</a></li>\012", 60);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_253, "\\item\\label{$1_toc} $2\\ref{$1}\012", 31);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_254, "<ul class=\"simple\">$1</ul>", 26);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_255, "\\begin{enumerate}$1\\end{enumerate}", 34);
N_LIB_PRIVATE TNimType NTIkeyvaluepair__0bWXDvqglYSS6aTKl80IVQ_;
N_LIB_PRIVATE TNimType NTIindexentry__1q6h3V1uWiazOcEBnOLqyA_;
N_LIB_PRIVATE TNimType NTIseqLindexentryT__hf5PiuqqytWiEcddgIR5sQ_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__mQGg5S79bnlEvqSZ53aiYNQ_;
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_259, ".", 1);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_260, ".idx", 4);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_263, "\011", 1);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_264, "\\\\", 2);
static NIM_CONST tyArray__0ipey9aZuUA8jy4OAHzODQg TM__vYBWrr780p7faFzauVMtPg_262 = {{((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_35),
((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_263)}
,
{((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_34),
((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_36)}
,
{((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_264),
((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_22)}
}
;
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_265, "doc_toc_", 8);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_267, "Documents: ", 11);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_269, "<a href=\"", 9);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_270, "</a>", 4);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_271, ", ", 2);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_272, ".<br/>", 6);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_273, "<p />", 5);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_274, "Modules: ", 9);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_275, "<a href=\"$1.html\">$2</a>", 24);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_276, "<h2>API symbols</h2>\012", 21);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_277, "<dl>", 4);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_278, "%", 1);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_279, "<dt><a name=\"$2\" href=\"#$2\"><span>$1:</span></a></dt><dd><ul class=\"simple\">\012", 77);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_280, "<li><a class=\"reference external\"\012          title=\"$3\" data-doc-search-tag=\"$2\" href=\"$1\">$2</a></li>\012          ", 112);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_281, "<li><a class=\"reference external\"\012          data-doc-search-tag=\"$2\" href=\"$1\">$2</a></li>\012          ", 101);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_282, "</ul></dd>\012", 11);
STRING_LITERAL(TM__vYBWrr780p7faFzauVMtPg_283, "</dl>", 5);
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5219;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
static N_NIMCALL(void, Marker_tySequence__ng4kcoK184wyb3xemBLQmw)(void* p, NI op) {
	tySequence__ng4kcoK184wyb3xemBLQmw* a;
	NI T1_;
	a = (tySequence__ng4kcoK184wyb3xemBLQmw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].n, op);
	nimGCvisit((void*)a->data[T1_].refname, op);
	nimGCvisit((void*)a->data[T1_].header, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__pUxI6Ljo6IKKHXKOZkQ7Og)(void* p, NI op) {
	tySequence__pUxI6Ljo6IKKHXKOZkQ7Og* a;
	NI T1_;
	a = (tySequence__pUxI6Ljo6IKKHXKOZkQ7Og*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field1, op);
	}
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, initRstGenerator__packagesZdocutilsZrstgen_90)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* g, tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ target, tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* config, NimStringDesc* filename, tyProc__oFHfEKFsiYTMAy9a42cSiKw findFile, tyProc__gd6fvPtd9aVRsRjs9bLyzE9bQ msgHandler, tyObject_RstFileTable__JJYG5kijP4PSa5F9a7da5tw filenames) {
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg fileParts;
	NimStringDesc* s;
	unsureAsgnRef((void**) (&(*g).config), config);
	(*g).target = target;
	unsureAsgnRef((void**) (&(*g).tocPart), NIM_NIL);
	unsureAsgnRef((void**) (&(*g).filename), copyString(filename));
	genericSeqAssign((&(*g).filenames.filenameToIdx.data), filenames.filenameToIdx.data, (&NTIkeyvaluepairseq__7lEisrXlQEzwtUKW5pzRCw_));
	(*g).filenames.filenameToIdx.counter = filenames.filenameToIdx.counter;
	genericSeqAssign((&(*g).filenames.idxToFilename), filenames.idxToFilename, (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_));
	(*g).splitAfter = ((NI) 20);
	unsureAsgnRef((void**) (&(*g).theIndex), ((NimStringDesc*) NIM_NIL));
	unsureAsgnRef((void**) (&(*g).findFile.ClE_0), findFile.ClE_0);
	(*g).findFile.ClP_0 = findFile.ClP_0;
	unsureAsgnRef((void**) (&(*g).currentSection), ((NimStringDesc*) NIM_NIL));
	(*g).id = ((NI) 0);
	(*g).escMode = ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0);
	nimZeroMem((void*)(&fileParts), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	nossplitFile(filename, (&fileParts));
	{
		NimStringDesc* T5_;
		if (!eqStrings(fileParts.Field2, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_13))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = rawNewString((fileParts.Field1 ? fileParts.Field1->Sup.len : 0) + 7);
appendString(T5_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_14));
appendString(T5_, fileParts.Field1);
		unsureAsgnRef((void**) (&(*g).currentSection), T5_);
	}
	LA3_: ;
	initTable__packagesZdocutilsZrstgen_108(((NI) 32), (&(*g).seenIndexTerms));
	unsureAsgnRef((void**) (&(*g).msgHandler.ClE_0), msgHandler.ClE_0);
	(*g).msgHandler.ClP_0 = msgHandler.ClP_0;
	s = getOrDefault__pureZstrtabs_173(config, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_15), ((NimStringDesc*) NIM_NIL));
	{
		if (!!(((s ? s->Sup.len : 0) == 0))) goto LA8_;
		(*g).splitAfter = nsuParseInt(s);
	}
	LA8_: ;
	{
		tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ i;
		NI res;
		i = (tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ)0;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= ((NI) 4))) goto LA12;
				i = ((tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ) (res));
				unsureAsgnRef((void**) (&(*g).meta[(i)- 0]), ((NimStringDesc*) NIM_NIL));
				res += ((NI) 1);
			} LA12: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(NI, nextSplitPoint__packagesZdocutilsZrstgen_233)(NimStringDesc* s, NI start) {
	NI result;
{	result = (NI)0;
	result = start;
	{
		while (1) {
			if (!(result < (NI)((s ? s->Sup.len : 0) + ((NI) 0)))) goto LA2;
			switch (((NU8)(s->data[result]))) {
			case 95:
			{
				goto BeforeRet_;
			}
			break;
			case 97 ... 122:
			{
				{
					if (!((NI)(result + ((NI) 1)) < (NI)((s ? s->Sup.len : 0) + ((NI) 0)))) goto LA7_;
					{
						if (!(((NU8)(s->data[(NI)(result + ((NI) 1))])) >= ((NU8)(65)) && ((NU8)(s->data[(NI)(result + ((NI) 1))])) <= ((NU8)(90)))) goto LA11_;
						goto BeforeRet_;
					}
					LA11_: ;
				}
				LA7_: ;
			}
			break;
			default:
			{
			}
			break;
			}
			result += ((NI) 1);
		} LA2: ;
	}
	result -= ((NI) 1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, addSplitter__packagesZdocutilsZrstgen_230)(tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ target, NimStringDesc** dest) {
	switch (target) {
	case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 0):
	{
		unsureAsgnRef((void**) (&(*dest)), resizeString((*dest), 7));
appendString((*dest), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_16));
	}
	break;
	case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 1):
	{
		unsureAsgnRef((void**) (&(*dest)), resizeString((*dest), 2));
appendString((*dest), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_17));
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, addHtmlChar__packagesZdocutilsZrstgen_205)(NimStringDesc** dest, NIM_CHAR c) {
	switch (((NU8)(c))) {
	case 38:
	{
		unsureAsgnRef((void**) (&(*dest)), resizeString((*dest), 5));
appendString((*dest), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_18));
	}
	break;
	case 60:
	{
		unsureAsgnRef((void**) (&(*dest)), resizeString((*dest), 4));
appendString((*dest), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_19));
	}
	break;
	case 62:
	{
		unsureAsgnRef((void**) (&(*dest)), resizeString((*dest), 4));
appendString((*dest), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_20));
	}
	break;
	case 34:
	{
		unsureAsgnRef((void**) (&(*dest)), resizeString((*dest), 6));
appendString((*dest), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_21));
	}
	break;
	default:
	{
		unsureAsgnRef((void**) (&(*dest)), addChar((*dest), c));
	}
	break;
	}
}
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c) {
	(*dest).data[(*dest).Sup.len] = c;
	(*dest).data[(NI)((*dest).Sup.len + ((NI) 1))] = 0;
	(*dest).Sup.len += ((NI) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, addTexChar__packagesZdocutilsZrstgen_208)(NimStringDesc** dest, NIM_CHAR c, tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg escMode) {
	switch (((NU8)(c))) {
	case 95:
	case 36:
	case 38:
	case 35:
	case 37:
	{
		NimStringDesc* T2_;
		T2_ = NIM_NIL;
		T2_ = rawNewString(2);
appendString(T2_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_22));
appendChar(T2_, c);
		unsureAsgnRef((void**) (&(*dest)), resizeString((*dest), (T2_ ? T2_->Sup.len : 0) + 0));
appendString((*dest), T2_);
	}
	break;
	case 126:
	case 94:
	{
		NimStringDesc* T4_;
		T4_ = NIM_NIL;
		T4_ = rawNewString(4);
appendString(T4_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_22));
appendChar(T4_, c);
appendString(T4_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_23));
		unsureAsgnRef((void**) (&(*dest)), resizeString((*dest), (T4_ ? T4_->Sup.len : 0) + 0));
appendString((*dest), T4_);
	}
	break;
	case 96:
	{
		unsureAsgnRef((void**) (&(*dest)), resizeString((*dest), 17));
appendString((*dest), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_24));
	}
	break;
	case 92:
	{
		unsureAsgnRef((void**) (&(*dest)), resizeString((*dest), 16));
appendString((*dest), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_25));
	}
	break;
	case 123:
	{
		NimStringDesc* T8_;
		T8_ = NIM_NIL;
		{
			if (!(escMode == ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 2))) goto LA11_;
			T8_ = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_26));
		}
		goto LA9_;
		LA11_: ;
		{
			T8_ = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_27));
		}
		LA9_: ;
		unsureAsgnRef((void**) (&(*dest)), resizeString((*dest), (T8_ ? T8_->Sup.len : 0) + 0));
appendString((*dest), T8_);
	}
	break;
	case 125:
	{
		NimStringDesc* T15_;
		T15_ = NIM_NIL;
		{
			if (!(escMode == ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 2))) goto LA18_;
			T15_ = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_28));
		}
		goto LA16_;
		LA18_: ;
		{
			T15_ = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_29));
		}
		LA16_: ;
		unsureAsgnRef((void**) (&(*dest)), resizeString((*dest), (T15_ ? T15_->Sup.len : 0) + 0));
appendString((*dest), T15_);
	}
	break;
	case 93:
	{
		NimStringDesc* T22_;
		T22_ = NIM_NIL;
		{
			if (!(escMode == ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 1))) goto LA25_;
			T22_ = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_30));
		}
		goto LA23_;
		LA25_: ;
		{
			T22_ = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_31));
		}
		LA23_: ;
		unsureAsgnRef((void**) (&(*dest)), resizeString((*dest), (T22_ ? T22_->Sup.len : 0) + 0));
appendString((*dest), T22_);
	}
	break;
	default:
	{
		unsureAsgnRef((void**) (&(*dest)), addChar((*dest), c));
	}
	break;
	}
}
static N_INLINE(void, escChar__packagesZdocutilsZrstgen_225)(tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ target, NimStringDesc** dest, NIM_CHAR c, tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg escMode) {
	switch (target) {
	case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 0):
	{
		addHtmlChar__packagesZdocutilsZrstgen_205(dest, c);
	}
	break;
	case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 1):
	{
		addTexChar__packagesZdocutilsZrstgen_208(dest, c, escMode);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, esc__packagesZdocutilsZrstgen_249)(tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ target, NimStringDesc* s, NI splitAfter, tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg escMode) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = ((NimStringDesc*) NIM_NIL);
	{
		NI partLen;
		NI j;
		if (!(((NI) 0) <= splitAfter)) goto LA3_;
		partLen = ((NI) 0);
		j = ((NI) 0);
		{
			while (1) {
				NI k;
				if (!(j < (s ? s->Sup.len : 0))) goto LA6;
				k = nextSplitPoint__packagesZdocutilsZrstgen_233(s, j);
				partLen = ((NI) 0);
				addSplitter__packagesZdocutilsZrstgen_230(target, (&result));
				{
					NI i;
					NI res;
					i = (NI)0;
					res = j;
					{
						while (1) {
							if (!(res <= k)) goto LA9;
							i = res;
							escChar__packagesZdocutilsZrstgen_225(target, (&result), s->data[i], escMode);
							res += ((NI) 1);
						} LA9: ;
					}
				}
				partLen += (NI)((NI)(k - j) + ((NI) 1));
				j = (NI)(k + ((NI) 1));
			} LA6: ;
		}
	}
	goto LA1_;
	LA3_: ;
	{
		{
			NI i_2;
			NI colontmp_;
			NI res_2;
			i_2 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = (NI)((s ? s->Sup.len : 0) - ((NI) 1));
			res_2 = ((NI) 0);
			{
				while (1) {
					if (!(res_2 <= colontmp_)) goto LA13;
					i_2 = res_2;
					escChar__packagesZdocutilsZrstgen_225(target, (&result), s->data[i_2], escMode);
					res_2 += ((NI) 1);
				} LA13: ;
			}
		}
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, dispA__packagesZdocutilsZrstgen_294)(tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ target, NimStringDesc** dest, NimStringDesc* xml, NimStringDesc* tex, NimStringDesc** args, NI argsLen_0) {
	{
		if (!!((target == ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 1)))) goto LA3_;
		nsuAddf(dest, xml, args, argsLen_0);
	}
	goto LA1_;
	LA3_: ;
	{
		nsuAddf(dest, tex, args, argsLen_0);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, renderCodeLang__packagesZdocutilsZrstgen_8242)(NimStringDesc** result, tyEnum_SourceLanguage__caWYuN9aCrrNgLAxHN3okug lang, NimStringDesc* code, tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ target) {
	tyObject_GeneralTokenizer__VRAep1bu6pPMSDyuqMGQyg g;
	nimZeroMem((void*)(&g), sizeof(tyObject_GeneralTokenizer__VRAep1bu6pPMSDyuqMGQyg));
	g.Sup.m_type = (&NTIgeneraltokenizer__VRAep1bu6pPMSDyuqMGQyg_);
	initGeneralTokenizer__packagesZdocutilsZhighlite_166((&g), code);
	{
		while (1) {
			getNextToken__packagesZdocutilsZhighlite_1760((&g), lang);
			switch (g.kind) {
			case ((tyEnum_TokenClass__RdrR6Svvyw1PZnyzCQYlWA) 0):
			{
				goto LA1;
			}
			break;
			case ((tyEnum_TokenClass__RdrR6Svvyw1PZnyzCQYlWA) 1):
			case ((tyEnum_TokenClass__RdrR6Svvyw1PZnyzCQYlWA) 2):
			{
				NimStringDesc* T5_;
				T5_ = NIM_NIL;
				T5_ = substr__system_7744(code, g.start, (NI)((NI)(g.length + g.start) - ((NI) 1)));
				unsureAsgnRef((void**) (&(*result)), resizeString((*result), (T5_ ? T5_->Sup.len : 0) + 0));
appendString((*result), T5_);
			}
			break;
			default:
			{
				tyArray__Re75IspeoxXy2oCZHwcRrA T7_;
				NimStringDesc* T8_;
				nimZeroMem((void*)T7_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T8_ = NIM_NIL;
				T8_ = substr__system_7744(code, g.start, (NI)((NI)(g.length + g.start) - ((NI) 1)));
				T7_[0] = esc__packagesZdocutilsZrstgen_249(target, T8_, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
				T7_[1] = copyString(tokenClassToStr__packagesZdocutilsZhighlite_68[(g.kind)- 0]);
				dispA__packagesZdocutilsZrstgen_294(target, result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_32), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_33), T7_, 2);
			}
			break;
			}
		}
	} LA1: ;
	deinitGeneralTokenizer__packagesZdocutilsZhighlite_169((&g));
}
N_LIB_PRIVATE N_NIMCALL(void, renderNimCode__packagesZdocutilsZrstgen_8248)(NimStringDesc** result, NimStringDesc* code, tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ target) {
	renderCodeLang__packagesZdocutilsZrstgen_8242(result, ((tyEnum_SourceLanguage__caWYuN9aCrrNgLAxHN3okug) 1), code, target);
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, quoteIndexColumn__packagesZdocutilsZrstgen_337)(NimStringDesc* text) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = rawNewString(((NI) ((NI)((text ? text->Sup.len : 0) + ((NI) 3)))));
	{
		NIM_CHAR c;
		NI i;
		NI L;
		c = (NIM_CHAR)0;
		i = ((NI) 0);
		L = (text ? text->Sup.len : 0);
		{
			while (1) {
				if (!(i < L)) goto LA3;
				c = text->data[i];
				switch (((NU8)(c))) {
				case 92:
				{
					result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_22));
				}
				break;
				case 10:
				{
					result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_34));
				}
				break;
				case 13:
				{
				}
				break;
				case 9:
				{
					result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_35));
				}
				break;
				default:
				{
					result = addChar(result, c);
				}
				break;
				}
				i += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setIndexTerm__packagesZdocutilsZrstgen_353)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, NimStringDesc* htmlFile, NimStringDesc* id, NimStringDesc* term, NimStringDesc* linkTitle, NimStringDesc* linkDesc) {
	NimStringDesc* entry;
	NIM_BOOL isTitle;
	entry = copyString(term);
	isTitle = NIM_FALSE;
	entry = addChar(entry, 9);
	entry = resizeString(entry, (htmlFile ? htmlFile->Sup.len : 0) + 0);
appendString(entry, htmlFile);
	{
		if (!(((NI) 0) < (id ? id->Sup.len : 0))) goto LA3_;
		entry = addChar(entry, 35);
		entry = resizeString(entry, (id ? id->Sup.len : 0) + 0);
appendString(entry, id);
	}
	goto LA1_;
	LA3_: ;
	{
		isTitle = NIM_TRUE;
	}
	LA1_: ;
	{
		NIM_BOOL T8_;
		NimStringDesc* T12_;
		NimStringDesc* T13_;
		NimStringDesc* T14_;
		NimStringDesc* T15_;
		T8_ = (NIM_BOOL)0;
		T8_ = (((NI) 0) < (linkTitle ? linkTitle->Sup.len : 0));
		if (T8_) goto LA9_;
		T8_ = (((NI) 0) < (linkDesc ? linkDesc->Sup.len : 0));
		LA9_: ;
		if (!T8_) goto LA10_;
		T12_ = NIM_NIL;
		T13_ = NIM_NIL;
		T13_ = quoteIndexColumn__packagesZdocutilsZrstgen_337(linkTitle);
		T12_ = rawNewString((T13_ ? T13_->Sup.len : 0) + 1);
appendChar(T12_, 9);
appendString(T12_, T13_);
		entry = resizeString(entry, (T12_ ? T12_->Sup.len : 0) + 0);
appendString(entry, T12_);
		T14_ = NIM_NIL;
		T15_ = NIM_NIL;
		T15_ = quoteIndexColumn__packagesZdocutilsZrstgen_337(linkDesc);
		T14_ = rawNewString((T15_ ? T15_->Sup.len : 0) + 1);
appendChar(T14_, 9);
appendString(T14_, T15_);
		entry = resizeString(entry, (T14_ ? T14_->Sup.len : 0) + 0);
appendString(entry, T14_);
	}
	LA10_: ;
	entry = resizeString(entry, 1);
appendString(entry, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_36));
	{
		if (!isTitle) goto LA18_;
		insert__system_7471((&(*d).theIndex), entry, ((NI) 0));
	}
	goto LA16_;
	LA18_: ;
	{
		unsureAsgnRef((void**) (&(*d).theIndex), resizeString((*d).theIndex, (entry ? entry->Sup.len : 0) + 0));
appendString((*d).theIndex, entry);
	}
	LA16_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, prettyLink__packagesZdocutilsZrstgen_85)(NimStringDesc* file) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = noschangeFileExt(file, ((NimStringDesc*) NIM_NIL));
	result = nsuReplaceStr(T1_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_37), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_38));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, renderAux__packagesZdocutilsZrstgen_312)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc** result) {
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (NI)0;
		T2_ = len__packagesZdocutilsZrstast_102(n);
		colontmp_ = (NI)(T2_ - ((NI) 1));
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA4;
				i = res;
				renderRstToOut__packagesZdocutilsZrstgen_308(d, (*n).sons->data[i], result);
				res += ((NI) 1);
			} LA4: ;
		}
	}
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5315)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5266((&gch__system_5219.zct), c);
}
static N_INLINE(void, decRef__system_5317)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5315(c);
	}
	LA4_: ;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5272)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5272(p);
	decRef__system_5317(T1_);
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5310)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5272(src);
		incRef__system_5310(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5272((*dest));
		decRef__system_5317(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, stripTocHtml__packagesZdocutilsZrstgen_8020)(NimStringDesc* s) {
	NimStringDesc* result;
	NI first;
{	result = NIM_NIL;
	result = copyString(s);
	first = nsuFindChar(result, 60, ((NI) 0), ((NI) 0));
	{
		while (1) {
			NI last;
			if (!(((NI) 0) <= first)) goto LA2;
			last = nsuFindChar(result, 62, ((NI) (first)), ((NI) 0));
			{
				if (!(last < ((NI) 0))) goto LA5_;
				goto BeforeRet_;
			}
			LA5_: ;
			nsuDelete((&result), first, last);
			first = nsuFindChar(result, 60, ((NI) (first)), ((NI) 0));
		} LA2: ;
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NimStringDesc*, spaces__pureZstrutils_1029)(NI n) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = nsuRepeatChar(32, n);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, renderHeadline__packagesZdocutilsZrstgen_8025)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc** result) {
	NimStringDesc* tmp;
	NimStringDesc* sectionPrefix;
	NimStringDesc* refname;
	NimStringDesc* T15_;
	NimStringDesc* T16_;
	NimStringDesc* tocName;
	NimStringDesc* T17_;
	NimStringDesc* htmlFileRelPath;
	NimStringDesc* T52_;
	NimStringDesc* T53_;
	NimStringDesc* T54_;
	tmp = ((NimStringDesc*) NIM_NIL);
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (NI)0;
		T2_ = len__packagesZdocutilsZrstast_102(n);
		colontmp_ = (NI)(T2_ - ((NI) 1));
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA4;
				i = res;
				renderRstToOut__packagesZdocutilsZrstgen_308(d, (*n).sons->data[i], (&tmp));
				res += ((NI) 1);
			} LA4: ;
		}
	}
	unsureAsgnRef((void**) (&(*d).currentSection), copyString(tmp));
	sectionPrefix = ((NimStringDesc*) NIM_NIL);
	{
		NI i_2;
		NI colontmp__2;
		NI T6_;
		NI res_2;
		i_2 = (NI)0;
		colontmp__2 = (NI)0;
		T6_ = (((*d).tocPart ? (*d).tocPart->Sup.len : 0)-1);
		colontmp__2 = T6_;
		res_2 = colontmp__2;
		{
			while (1) {
				tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n2;
				if (!(((NI) 0) <= res_2)) goto LA8;
				i_2 = res_2;
				n2 = (*d).tocPart->data[i_2].n;
				{
					NimStringDesc* T13_;
					NimStringDesc* T14_;
					if (!((*n2)._kind_5.level < (*n)._kind_5.level)) goto LA11_;
					T13_ = NIM_NIL;
					T14_ = NIM_NIL;
					T14_ = rstnodeToRefname__packagesZdocutilsZrst_61(n2);
					T13_ = rawNewString((T14_ ? T14_->Sup.len : 0) + 1);
appendString(T13_, T14_);
appendString(T13_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_39));
					sectionPrefix = T13_;
					goto LA5;
				}
				LA11_: ;
				res_2 -= ((NI) 1);
			} LA8: ;
		}
	} LA5: ;
	T15_ = NIM_NIL;
	T16_ = NIM_NIL;
	T16_ = rstnodeToRefname__packagesZdocutilsZrst_61(n);
	T15_ = rawNewString((sectionPrefix ? sectionPrefix->Sup.len : 0) + (T16_ ? T16_->Sup.len : 0) + 0);
appendString(T15_, sectionPrefix);
appendString(T15_, T16_);
	refname = T15_;
	T17_ = NIM_NIL;
	T17_ = renderRstToText__packagesZdocutilsZrstast_462(n);
	tocName = esc__packagesZdocutilsZrstgen_249((*d).target, T17_, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 1));
	{
		NI length;
		NI T22_;
		NimStringDesc* T23_;
		NimStringDesc* T24_;
		tyArray__yt5VDPNtUGx9cBkOVakHwdQ T25_;
		if (!(*d).hasToc) goto LA20_;
		T22_ = ((*d).tocPart ? (*d).tocPart->Sup.len : 0);
		length = T22_;
		unsureAsgnRef((void**) (&(*d).tocPart), (tySequence__ng4kcoK184wyb3xemBLQmw*) setLengthSeqV2(((*d).tocPart)?&((*d).tocPart)->Sup:NIM_NIL, (&NTIseqLtocentryT__ng4kcoK184wyb3xemBLQmw_), ((NI) ((NI)(length + ((NI) 1))))));
		T23_ = NIM_NIL;
		T23_ = (*d).tocPart->data[length].refname; (*d).tocPart->data[length].refname = copyStringRC1(refname);
		if (T23_) nimGCunrefNoCycle(T23_);
		asgnRef((void**) (&(*d).tocPart->data[length].n), n);
		T24_ = NIM_NIL;
		T24_ = (*d).tocPart->data[length].header; (*d).tocPart->data[length].header = copyStringRC1(tmp);
		if (T24_) nimGCunrefNoCycle(T24_);
		nimZeroMem((void*)T25_, sizeof(tyArray__yt5VDPNtUGx9cBkOVakHwdQ));
		T25_[0] = dollar___systemZdollars_3((*n)._kind_5.level);
		{
			if (!((refname ? refname->Sup.len : 0) == 0)) goto LA28_;
			T25_[1] = ((NimStringDesc*) NIM_NIL);
		}
		goto LA26_;
		LA28_: ;
		{
			switch ((*d).target) {
			case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 0):
			{
				NimStringDesc* T32_;
				T32_ = NIM_NIL;
				T32_ = rawNewString((refname ? refname->Sup.len : 0) + 6);
appendString(T32_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_42));
appendString(T32_, refname);
appendString(T32_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_43));
				T25_[1] = T32_;
			}
			break;
			case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 1):
			{
				NimStringDesc* T34_;
				T34_ = NIM_NIL;
				T34_ = rawNewString((refname ? refname->Sup.len : 0) + (refname ? refname->Sup.len : 0) + 24);
appendString(T34_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_44));
appendString(T34_, refname);
appendString(T34_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_45));
appendString(T34_, refname);
appendString(T34_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_46));
				T25_[1] = T34_;
			}
			break;
			}
		}
		LA26_: ;
		T25_[2] = copyString(tmp);
		T25_[3] = nimCharToStr(((NIM_CHAR) (((NI) ((NI)((NI)((*n)._kind_5.level - ((NI) 1)) + ((NI) 65)))))));
		T25_[4] = copyString(refname);
		T25_[5] = copyString(tocName);
		dispA__packagesZdocutilsZrstgen_294((*d).target, result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_40), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_41), T25_, 6);
	}
	goto LA18_;
	LA20_: ;
	{
		tyArray__haiLFy0nBviVTKFGuwztzQ T36_;
		nimZeroMem((void*)T36_, sizeof(tyArray__haiLFy0nBviVTKFGuwztzQ));
		T36_[0] = dollar___systemZdollars_3((*n)._kind_5.level);
		{
			if (!((refname ? refname->Sup.len : 0) == 0)) goto LA39_;
			T36_[1] = ((NimStringDesc*) NIM_NIL);
		}
		goto LA37_;
		LA39_: ;
		{
			switch ((*d).target) {
			case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 0):
			{
				NimStringDesc* T43_;
				T43_ = NIM_NIL;
				T43_ = rawNewString((refname ? refname->Sup.len : 0) + 6);
appendString(T43_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_42));
appendString(T43_, refname);
appendString(T43_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_43));
				T36_[1] = T43_;
			}
			break;
			case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 1):
			{
				NimStringDesc* T45_;
				T45_ = NIM_NIL;
				T45_ = rawNewString((refname ? refname->Sup.len : 0) + (refname ? refname->Sup.len : 0) + 24);
appendString(T45_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_44));
appendString(T45_, refname);
appendString(T45_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_45));
appendString(T45_, refname);
appendString(T45_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_46));
				T36_[1] = T45_;
			}
			break;
			}
		}
		LA37_: ;
		T36_[2] = copyString(tmp);
		T36_[3] = nimCharToStr(((NIM_CHAR) (((NI) ((NI)((NI)((*n)._kind_5.level - ((NI) 1)) + ((NI) 65)))))));
		T36_[4] = copyString(tocName);
		dispA__packagesZdocutilsZrstgen_294((*d).target, result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_47), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_48), T36_, 5);
	}
	LA18_: ;
	{
		NimStringDesc* T50_;
		if (!(((*d).outDir ? (*d).outDir->Sup.len : 0) == ((NI) 0))) goto LA48_;
		T50_ = NIM_NIL;
		T50_ = nosextractFilename((*d).filename);
		htmlFileRelPath = noschangeFileExt(T50_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_49));
	}
	goto LA46_;
	LA48_: ;
	{
		htmlFileRelPath = nosrelativePath((*d).destFile, (*d).outDir, 47);
	}
	LA46_: ;
	T52_ = NIM_NIL;
	T52_ = stripTocHtml__packagesZdocutilsZrstgen_8020(tmp);
	T53_ = NIM_NIL;
	T54_ = NIM_NIL;
	T54_ = spaces__pureZstrutils_1029(((NI) (((((NI) 0) >= (*n)._kind_5.level) ? ((NI) 0) : (*n)._kind_5.level))));
	T53_ = rawNewString((T54_ ? T54_->Sup.len : 0) + (tmp ? tmp->Sup.len : 0) + 0);
appendString(T53_, T54_);
appendString(T53_, tmp);
	setIndexTerm__packagesZdocutilsZrstgen_353(d, htmlFileRelPath, refname, T52_, T53_, ((NimStringDesc*) NIM_NIL));
}
N_LIB_PRIVATE N_NIMCALL(void, renderOverline__packagesZdocutilsZrstgen_8077)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc** result) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n)._kind_5.level == ((NI) 0));
		if (!(T3_)) goto LA4_;
		T3_ = (((*d).meta[(((tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ) 1))- 0] ? (*d).meta[(((tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ) 1))- 0]->Sup.len : 0) == ((NI) 0));
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			NI i;
			NI colontmp_;
			NI T8_;
			NI res;
			i = (NI)0;
			colontmp_ = (NI)0;
			T8_ = (NI)0;
			T8_ = len__packagesZdocutilsZrstast_102(n);
			colontmp_ = (NI)(T8_ - ((NI) 1));
			res = ((NI) 0);
			{
				while (1) {
					if (!(res <= colontmp_)) goto LA10;
					i = res;
					renderRstToOut__packagesZdocutilsZrstgen_308(d, (*n).sons->data[i], (&(*d).meta[(((tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ) 1))- 0]));
					res += ((NI) 1);
				} LA10: ;
			}
		}
		unsureAsgnRef((void**) (&(*d).currentSection), copyString((*d).meta[(((tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ) 1))- 0]));
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T12_;
		T12_ = (NIM_BOOL)0;
		T12_ = ((*n)._kind_5.level == ((NI) 0));
		if (!(T12_)) goto LA13_;
		T12_ = (((*d).meta[(((tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ) 2))- 0] ? (*d).meta[(((tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ) 2))- 0]->Sup.len : 0) == ((NI) 0));
		LA13_: ;
		if (!T12_) goto LA14_;
		{
			NI i_2;
			NI colontmp__2;
			NI T17_;
			NI res_2;
			i_2 = (NI)0;
			colontmp__2 = (NI)0;
			T17_ = (NI)0;
			T17_ = len__packagesZdocutilsZrstast_102(n);
			colontmp__2 = (NI)(T17_ - ((NI) 1));
			res_2 = ((NI) 0);
			{
				while (1) {
					if (!(res_2 <= colontmp__2)) goto LA19;
					i_2 = res_2;
					renderRstToOut__packagesZdocutilsZrstgen_308(d, (*n).sons->data[i_2], (&(*d).meta[(((tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ) 2))- 0]));
					res_2 += ((NI) 1);
				} LA19: ;
			}
		}
		unsureAsgnRef((void**) (&(*d).currentSection), copyString((*d).meta[(((tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ) 2))- 0]));
	}
	goto LA1_;
	LA14_: ;
	{
		NimStringDesc* tmp;
		NimStringDesc* tocName;
		NimStringDesc* T25_;
		tyArray__haiLFy0nBviVTKFGuwztzQ T26_;
		tmp = ((NimStringDesc*) NIM_NIL);
		{
			NI i_3;
			NI colontmp__3;
			NI T22_;
			NI res_3;
			i_3 = (NI)0;
			colontmp__3 = (NI)0;
			T22_ = (NI)0;
			T22_ = len__packagesZdocutilsZrstast_102(n);
			colontmp__3 = (NI)(T22_ - ((NI) 1));
			res_3 = ((NI) 0);
			{
				while (1) {
					if (!(res_3 <= colontmp__3)) goto LA24;
					i_3 = res_3;
					renderRstToOut__packagesZdocutilsZrstgen_308(d, (*n).sons->data[i_3], (&tmp));
					res_3 += ((NI) 1);
				} LA24: ;
			}
		}
		unsureAsgnRef((void**) (&(*d).currentSection), copyString(tmp));
		T25_ = NIM_NIL;
		T25_ = renderRstToText__packagesZdocutilsZrstast_462(n);
		tocName = esc__packagesZdocutilsZrstgen_249((*d).target, T25_, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 1));
		nimZeroMem((void*)T26_, sizeof(tyArray__haiLFy0nBviVTKFGuwztzQ));
		T26_[0] = dollar___systemZdollars_3((*n)._kind_5.level);
		{
			NimStringDesc* T29_;
			T29_ = NIM_NIL;
			T29_ = rstnodeToRefname__packagesZdocutilsZrst_61(n);
			if (!((T29_ ? T29_->Sup.len : 0) == 0)) goto LA30_;
			T26_[1] = ((NimStringDesc*) NIM_NIL);
		}
		goto LA27_;
		LA30_: ;
		{
			switch ((*d).target) {
			case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 0):
			{
				NimStringDesc* T34_;
				NimStringDesc* T35_;
				T34_ = NIM_NIL;
				T35_ = NIM_NIL;
				T35_ = rstnodeToRefname__packagesZdocutilsZrst_61(n);
				T34_ = rawNewString((T35_ ? T35_->Sup.len : 0) + 6);
appendString(T34_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_42));
appendString(T34_, T35_);
appendString(T34_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_43));
				T26_[1] = T34_;
			}
			break;
			case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 1):
			{
				NimStringDesc* T37_;
				NimStringDesc* T38_;
				NimStringDesc* T39_;
				T37_ = NIM_NIL;
				T38_ = NIM_NIL;
				T38_ = rstnodeToRefname__packagesZdocutilsZrst_61(n);
				T39_ = NIM_NIL;
				T39_ = rstnodeToRefname__packagesZdocutilsZrst_61(n);
				T37_ = rawNewString((T38_ ? T38_->Sup.len : 0) + (T39_ ? T39_->Sup.len : 0) + 24);
appendString(T37_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_44));
appendString(T37_, T38_);
appendString(T37_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_45));
appendString(T37_, T39_);
appendString(T37_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_46));
				T26_[1] = T37_;
			}
			break;
			}
		}
		LA27_: ;
		T26_[2] = copyString(tmp);
		T26_[3] = nimCharToStr(((NIM_CHAR) (((NI) ((NI)((NI)((*n)._kind_5.level - ((NI) 1)) + ((NI) 65)))))));
		T26_[4] = copyString(tocName);
		dispA__packagesZdocutilsZrstgen_294((*d).target, result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_50), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_51), T26_, 5);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, renderAux__packagesZdocutilsZrstgen_324)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc* html, NimStringDesc* tex, NimStringDesc** result) {
	NimStringDesc* tmp;
	tmp = ((NimStringDesc*) NIM_NIL);
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (NI)0;
		T2_ = len__packagesZdocutilsZrstast_102(n);
		colontmp_ = (NI)(T2_ - ((NI) 1));
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA4;
				i = res;
				renderRstToOut__packagesZdocutilsZrstgen_308(d, (*n).sons->data[i], (&tmp));
				res += ((NI) 1);
			} LA4: ;
		}
	}
	switch ((*d).target) {
	case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 0):
	{
		tyArray__Re75IspeoxXy2oCZHwcRrA T6_;
		nimZeroMem((void*)T6_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
		T6_[0] = copyString(tmp);
		{
			if (!(((*n).anchor ? (*n).anchor->Sup.len : 0) == 0)) goto LA9_;
			T6_[1] = ((NimStringDesc*) NIM_NIL);
		}
		goto LA7_;
		LA9_: ;
		{
			switch ((*d).target) {
			case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 0):
			{
				NimStringDesc* T13_;
				T13_ = NIM_NIL;
				T13_ = rawNewString(((*n).anchor ? (*n).anchor->Sup.len : 0) + 6);
appendString(T13_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_42));
appendString(T13_, (*n).anchor);
appendString(T13_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_43));
				T6_[1] = T13_;
			}
			break;
			case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 1):
			{
				NimStringDesc* T15_;
				T15_ = NIM_NIL;
				T15_ = rawNewString(((*n).anchor ? (*n).anchor->Sup.len : 0) + ((*n).anchor ? (*n).anchor->Sup.len : 0) + 24);
appendString(T15_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_44));
appendString(T15_, (*n).anchor);
appendString(T15_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_45));
appendString(T15_, (*n).anchor);
appendString(T15_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_46));
				T6_[1] = T15_;
			}
			break;
			}
		}
		LA7_: ;
		nsuAddf(result, html, T6_, 2);
	}
	break;
	case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 1):
	{
		tyArray__Re75IspeoxXy2oCZHwcRrA T17_;
		nimZeroMem((void*)T17_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
		T17_[0] = copyString(tmp);
		{
			if (!(((*n).anchor ? (*n).anchor->Sup.len : 0) == 0)) goto LA20_;
			T17_[1] = ((NimStringDesc*) NIM_NIL);
		}
		goto LA18_;
		LA20_: ;
		{
			switch ((*d).target) {
			case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 0):
			{
				NimStringDesc* T24_;
				T24_ = NIM_NIL;
				T24_ = rawNewString(((*n).anchor ? (*n).anchor->Sup.len : 0) + 6);
appendString(T24_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_42));
appendString(T24_, (*n).anchor);
appendString(T24_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_43));
				T17_[1] = T24_;
			}
			break;
			case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 1):
			{
				NimStringDesc* T26_;
				T26_ = NIM_NIL;
				T26_ = rawNewString(((*n).anchor ? (*n).anchor->Sup.len : 0) + ((*n).anchor ? (*n).anchor->Sup.len : 0) + 24);
appendString(T26_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_44));
appendString(T26_, (*n).anchor);
appendString(T26_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_45));
appendString(T26_, (*n).anchor);
appendString(T26_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_46));
				T17_[1] = T26_;
			}
			break;
			}
		}
		LA18_: ;
		nsuAddf(result, tex, T17_, 2);
	}
	break;
	}
}
static N_INLINE(NIM_CHAR*, X5BX5D___system_7362)(NimStringDesc** s, NI i) {
	NIM_CHAR* result;
	result = (NIM_CHAR*)0;
	result = (&(*s)->data[(NI)(((*s) ? (*s)->Sup.len : 0) - i)]);
	return result;
}
static N_INLINE(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw, dotdot___pureZunicode_840)(NI a, NI b) {
	tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw));
	result.a = a;
	result.b = b;
	return result;
}
static N_INLINE(NimStringDesc*, X5BX5D___pureZunicode_865)(NimStringDesc* s, tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw x) {
	NimStringDesc* result;
	NI a;
	NI L;
	result = NIM_NIL;
	a = x.a;
	L = (NI)((NI)(x.b - a) + ((NI) 1));
	result = mnewString(((NI) (L)));
	{
		NI i;
		NI i_2;
		i = (NI)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < L)) goto LA3;
				i = i_2;
				result->data[i] = s->data[(NI)(i + a)];
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, renderEnumList__packagesZdocutilsZrstgen_8331)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc** result) {
	NimStringDesc* specifier;
	NimStringDesc* specStart;
	NI i1;
	NimStringDesc* pre;
	NI i2;
	NimStringDesc* post;
	tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw enumR;
	NimStringDesc* T88_;
	NimStringDesc* T89_;
	specifier = ((NimStringDesc*) NIM_NIL);
	specStart = ((NimStringDesc*) NIM_NIL);
	i1 = ((NI) 0);
	pre = ((NimStringDesc*) NIM_NIL);
	i2 = (NI)(((*n)._kind_2.labelFmt ? (*n)._kind_2.labelFmt->Sup.len : 0) - ((NI) 1));
	post = ((NimStringDesc*) NIM_NIL);
	{
		if (!((NU8)((*n)._kind_2.labelFmt->data[((NI) 0)]) == (NU8)(40))) goto LA3_;
		i1 = ((NI) 1);
		pre = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_60));
	}
	LA3_: ;
	{
		NIM_BOOL T7_;
		NIM_CHAR* T8_;
		NIM_CHAR* T10_;
		NIM_CHAR* T13_;
		T7_ = (NIM_BOOL)0;
		T8_ = (NIM_CHAR*)0;
		T8_ = X5BX5D___system_7362((&(*n)._kind_2.labelFmt), ((NI) 1));
		T7_ = ((NU8)((*T8_)) == (NU8)(41));
		if (T7_) goto LA9_;
		T10_ = (NIM_CHAR*)0;
		T10_ = X5BX5D___system_7362((&(*n)._kind_2.labelFmt), ((NI) 1));
		T7_ = ((NU8)((*T10_)) == (NU8)(46));
		LA9_: ;
		if (!T7_) goto LA11_;
		i2 = (NI)(((*n)._kind_2.labelFmt ? (*n)._kind_2.labelFmt->Sup.len : 0) - ((NI) 2));
		T13_ = (NIM_CHAR*)0;
		T13_ = X5BX5D___system_7362((&(*n)._kind_2.labelFmt), ((NI) 1));
		post = nimCharToStr((*T13_));
	}
	LA11_: ;
	enumR = dotdot___pureZunicode_840(i1, i2);
	{
		NimStringDesc* T18_;
		if (!((*d).target == ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 1))) goto LA16_;
		T18_ = NIM_NIL;
		T18_ = rawNewString(((*n)._kind_2.labelFmt ? (*n)._kind_2.labelFmt->Sup.len : 0) + 3);
appendString(T18_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_61));
appendString(T18_, (*n)._kind_2.labelFmt);
appendString(T18_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_36));
		unsureAsgnRef((void**) (&(*result)), resizeString((*result), (T18_ ? T18_->Sup.len : 0) + 0));
appendString((*result), T18_);
		{
			NIM_BOOL T21_;
			NimStringDesc* labelDef;
			T21_ = (NIM_BOOL)0;
			T21_ = nsuIsDigitChar((*n)._kind_2.labelFmt->data[i1]);
			if (!T21_) goto LA22_;
			labelDef = ((NimStringDesc*) NIM_NIL);
			{
				NIM_BOOL T26_;
				NimStringDesc* T30_;
				T26_ = (NIM_BOOL)0;
				T26_ = !(((pre ? pre->Sup.len : 0) == 0));
				if (T26_) goto LA27_;
				T26_ = !(((post ? post->Sup.len : 0) == 0));
				LA27_: ;
				if (!T26_) goto LA28_;
				T30_ = NIM_NIL;
				T30_ = rawNewString((pre ? pre->Sup.len : 0) + (post ? post->Sup.len : 0) + 15);
appendString(T30_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_62));
appendString(T30_, pre);
appendString(T30_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_63));
appendString(T30_, post);
appendString(T30_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_64));
				labelDef = T30_;
			}
			LA28_: ;
			{
				NimStringDesc* T33_;
				tyArray__nHXaesL0DJZHyVS07ARPRA T36_;
				T33_ = NIM_NIL;
				T33_ = X5BX5D___pureZunicode_865((*n)._kind_2.labelFmt, enumR);
				if (!!(eqStrings(T33_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_65)))) goto LA34_;
				nimZeroMem((void*)T36_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
				T36_[0] = X5BX5D___pureZunicode_865((*n)._kind_2.labelFmt, enumR);
				specStart = nsuFormatOpenArray(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_66), T36_, 1);
			}
			LA34_: ;
			{
				NIM_BOOL T39_;
				tyArray__Re75IspeoxXy2oCZHwcRrA T43_;
				T39_ = (NIM_BOOL)0;
				T39_ = !(((labelDef ? labelDef->Sup.len : 0) == 0));
				if (T39_) goto LA40_;
				T39_ = !(((specStart ? specStart->Sup.len : 0) == 0));
				LA40_: ;
				if (!T39_) goto LA41_;
				nimZeroMem((void*)T43_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T43_[0] = copyString(labelDef);
				T43_[1] = copyString(specStart);
				specifier = nsuFormatOpenArray(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_67), T43_, 2);
			}
			LA41_: ;
		}
		goto LA19_;
		LA22_: ;
		{
			tyTuple__qsoB9cWzItmjtA8wRSiKBbA T45_;
			NIM_CHAR first;
			NimStringDesc* labelDef_2;
			tyArray__Re75IspeoxXy2oCZHwcRrA T60_;
			nimZeroMem((void*)(&T45_), sizeof(tyTuple__qsoB9cWzItmjtA8wRSiKBbA));
			{
				NIM_BOOL T48_;
				NimStringDesc* T51_;
				T48_ = (NIM_BOOL)0;
				T48_ = nsuIsUpperAsciiChar((*n)._kind_2.labelFmt->data[i1]);
				if (!T48_) goto LA49_;
				T45_.Field0 = 65;
				T51_ = NIM_NIL;
				T51_ = rawNewString((pre ? pre->Sup.len : 0) + (post ? post->Sup.len : 0) + 12);
appendString(T51_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_62));
appendString(T51_, pre);
appendString(T51_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_68));
appendString(T51_, post);
				T45_.Field1 = T51_;
			}
			goto LA46_;
			LA49_: ;
			{
				NimStringDesc* T53_;
				T45_.Field0 = 97;
				T53_ = NIM_NIL;
				T53_ = rawNewString((pre ? pre->Sup.len : 0) + (post ? post->Sup.len : 0) + 12);
appendString(T53_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_62));
appendString(T53_, pre);
appendString(T53_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_69));
appendString(T53_, post);
				T45_.Field1 = T53_;
			}
			LA46_: ;
			first = (NIM_CHAR)0;
			first = T45_.Field0;
			labelDef_2 = NIM_NIL;
			labelDef_2 = T45_.Field1;
			{
				NimStringDesc* T58_;
				NimStringDesc* T59_;
				if (!!(((NU8)((*n)._kind_2.labelFmt->data[i1]) == (NU8)(first)))) goto LA56_;
				T58_ = NIM_NIL;
				T59_ = NIM_NIL;
				T59_ = dollar___systemZdollars_3((NI)((NI)(((NU8)((*n)._kind_2.labelFmt->data[i1])) - ((NU8)(first))) + ((NI) 1)));
				T58_ = rawNewString((T59_ ? T59_->Sup.len : 0) + 7);
appendString(T58_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_70));
appendString(T58_, T59_);
				specStart = T58_;
			}
			LA56_: ;
			nimZeroMem((void*)T60_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T60_[0] = copyString(labelDef_2);
			T60_[1] = copyString(specStart);
			specifier = nsuFormatOpenArray(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_67), T60_, 2);
		}
		LA19_: ;
	}
	goto LA14_;
	LA16_: ;
	{
		{
			NIM_BOOL T64_;
			NimStringDesc* T73_;
			T64_ = (NIM_BOOL)0;
			T64_ = nsuIsDigitChar((*n)._kind_2.labelFmt->data[i1]);
			if (!T64_) goto LA65_;
			{
				NimStringDesc* T69_;
				tyArray__nHXaesL0DJZHyVS07ARPRA T72_;
				T69_ = NIM_NIL;
				T69_ = X5BX5D___pureZunicode_865((*n)._kind_2.labelFmt, enumR);
				if (!!(eqStrings(T69_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_65)))) goto LA70_;
				nimZeroMem((void*)T72_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
				T72_[0] = X5BX5D___pureZunicode_865((*n)._kind_2.labelFmt, enumR);
				specStart = nsuFormatOpenArray(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_71), T72_, 1);
			}
			LA70_: ;
			T73_ = NIM_NIL;
			T73_ = rawNewString((specStart ? specStart->Sup.len : 0) + 14);
appendString(T73_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_72));
appendString(T73_, specStart);
			specifier = T73_;
		}
		goto LA62_;
		LA65_: ;
		{
			tyTuple__qsoB9cWzItmjtA8wRSiKBbA T75_;
			NIM_CHAR first_2;
			NimStringDesc* labelDef_3;
			NimStringDesc* T87_;
			nimZeroMem((void*)(&T75_), sizeof(tyTuple__qsoB9cWzItmjtA8wRSiKBbA));
			{
				NIM_BOOL T78_;
				T78_ = (NIM_BOOL)0;
				T78_ = nsuIsUpperAsciiChar((*n)._kind_2.labelFmt->data[i1]);
				if (!T78_) goto LA79_;
				T75_.Field0 = TM__vYBWrr780p7faFzauVMtPg_73.Field0;
				T75_.Field1 = copyString(TM__vYBWrr780p7faFzauVMtPg_73.Field1);
			}
			goto LA76_;
			LA79_: ;
			{
				T75_.Field0 = TM__vYBWrr780p7faFzauVMtPg_75.Field0;
				unsureAsgnRef((void**) (&T75_.Field1), copyString(TM__vYBWrr780p7faFzauVMtPg_75.Field1));
			}
			LA76_: ;
			first_2 = (NIM_CHAR)0;
			first_2 = T75_.Field0;
			labelDef_3 = NIM_NIL;
			labelDef_3 = copyString(T75_.Field1);
			{
				tyArray__nHXaesL0DJZHyVS07ARPRA T86_;
				if (!!(((NU8)((*n)._kind_2.labelFmt->data[i1]) == (NU8)(first_2)))) goto LA84_;
				nimZeroMem((void*)T86_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
				T86_[0] = dollar___systemZdollars_3((NI)((NI)(((NU8)((*n)._kind_2.labelFmt->data[i1])) - ((NU8)(first_2))) + ((NI) 1)));
				specStart = nsuFormatOpenArray(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_71), T86_, 1);
			}
			LA84_: ;
			T87_ = NIM_NIL;
			T87_ = rawNewString((labelDef_3 ? labelDef_3->Sup.len : 0) + (specStart ? specStart->Sup.len : 0) + 0);
appendString(T87_, labelDef_3);
appendString(T87_, specStart);
			specifier = T87_;
		}
		LA62_: ;
	}
	LA14_: ;
	T88_ = NIM_NIL;
	T88_ = rawNewString((specifier ? specifier->Sup.len : 0) + 15);
appendString(T88_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_77));
appendString(T88_, specifier);
appendString(T88_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_78));
	T89_ = NIM_NIL;
	T89_ = rawNewString((specifier ? specifier->Sup.len : 0) + 37);
appendString(T89_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_79));
appendString(T89_, specifier);
appendString(T89_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_80));
	renderAux__packagesZdocutilsZrstgen_324(d, n, T88_, T89_, result);
}
N_LIB_PRIVATE N_NIMCALL(void, renderField__packagesZdocutilsZrstgen_8320)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc** result) {
	NIM_BOOL b;
	b = NIM_FALSE;
	{
		NimStringDesc* fieldname;
		NimStringDesc* fieldval;
		NimStringDesc* T5_;
		NimStringDesc* T6_;
		if (!((*d).target == ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 1))) goto LA3_;
		fieldname = addNodes__packagesZdocutilsZrst_63((*n).sons->data[((NI) 0)]);
		T5_ = NIM_NIL;
		T5_ = addNodes__packagesZdocutilsZrst_63((*n).sons->data[((NI) 1)]);
		T6_ = NIM_NIL;
		T6_ = nsuStrip(T5_, NIM_TRUE, NIM_TRUE, TM__vYBWrr780p7faFzauVMtPg_88);
		fieldval = esc__packagesZdocutilsZrstgen_249((*d).target, T6_, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
		{
			NIM_BOOL T9_;
			NI T10_;
			NI T12_;
			T9_ = (NIM_BOOL)0;
			T10_ = (NI)0;
			T10_ = nsuCmpIgnoreStyle(fieldname, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_89));
			T9_ = (T10_ == ((NI) 0));
			if (T9_) goto LA11_;
			T12_ = (NI)0;
			T12_ = nsuCmpIgnoreStyle(fieldname, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_90));
			T9_ = (T12_ == ((NI) 0));
			LA11_: ;
			if (!T9_) goto LA13_;
			{
				if (!(((*d).meta[(((tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ) 3))- 0] ? (*d).meta[(((tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ) 3))- 0]->Sup.len : 0) == ((NI) 0))) goto LA17_;
				unsureAsgnRef((void**) (&(*d).meta[(((tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ) 3))- 0]), copyString(fieldval));
				b = NIM_TRUE;
			}
			LA17_: ;
		}
		goto LA7_;
		LA13_: ;
		{
			NI T20_;
			T20_ = (NI)0;
			T20_ = nsuCmpIgnoreStyle(fieldname, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_91));
			if (!(T20_ == ((NI) 0))) goto LA21_;
			{
				if (!(((*d).meta[(((tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ) 4))- 0] ? (*d).meta[(((tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ) 4))- 0]->Sup.len : 0) == ((NI) 0))) goto LA25_;
				unsureAsgnRef((void**) (&(*d).meta[(((tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ) 4))- 0]), copyString(fieldval));
				b = NIM_TRUE;
			}
			LA25_: ;
		}
		goto LA7_;
		LA21_: ;
		LA7_: ;
	}
	LA3_: ;
	{
		if (!!(b)) goto LA29_;
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_92), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_93), result);
	}
	LA29_: ;
}
static N_INLINE(NF, toFloat__system_1702)(NI i) {
	NF result;
	result = (NF)0;
	result = ((NF) (i));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, renderAdmonition__packagesZdocutilsZrstgen_8429)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc** result) {
	NimStringDesc* htmlCls;
	NimStringDesc* texSz;
	NimStringDesc* texColor;
	NimStringDesc* txt;
	NimStringDesc* htmlHead;
	NimStringDesc* T10_;
	NimStringDesc* T11_;
	NimStringDesc* T12_;
	htmlCls = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_125));
	texSz = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_126));
	texColor = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_127));
	switch (hashString((*n)._kind_4.adType) & 15) {
	case 2: 
if (eqStrings((*n)._kind_4.adType, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_131))) goto LA2_;
if (eqStrings((*n)._kind_4.adType, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_135))) goto LA2_;
break;
	case 5: 
if (eqStrings((*n)._kind_4.adType, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_136))) goto LA3_;
break;
	case 6: 
if (eqStrings((*n)._kind_4.adType, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_132))) goto LA2_;
if (eqStrings((*n)._kind_4.adType, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_133))) goto LA2_;
break;
	case 7: 
if (eqStrings((*n)._kind_4.adType, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_129))) goto LA1_;
break;
	case 8: 
if (eqStrings((*n)._kind_4.adType, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_130))) goto LA1_;
break;
	case 11: 
if (eqStrings((*n)._kind_4.adType, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_128))) goto LA1_;
break;
	case 12: 
if (eqStrings((*n)._kind_4.adType, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_134))) goto LA2_;
if (eqStrings((*n)._kind_4.adType, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_137))) goto LA3_;
break;
	}
	goto LA4_;
	LA1_: ;
	{
		htmlCls = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_138));
		texSz = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_139));
		texColor = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_140));
	}
	goto LA5_;
	LA2_: ;
	{
		htmlCls = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_141));
		texSz = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_126));
		texColor = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_127));
	}
	goto LA5_;
	LA3_: ;
	{
		htmlCls = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_142));
		texSz = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_143));
		texColor = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_144));
	}
	goto LA5_;
	LA4_: ;
	{
	}
	LA5_: ;
	txt = nsuCapitalizeAscii((*n)._kind_4.adType);
	T10_ = NIM_NIL;
	T10_ = rawNewString((htmlCls ? htmlCls->Sup.len : 0) + 25);
appendString(T10_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_145));
appendString(T10_, htmlCls);
appendString(T10_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_146));
	htmlHead = T10_;
	T11_ = NIM_NIL;
	T11_ = rawNewString((htmlHead ? htmlHead->Sup.len : 0) + (htmlCls ? htmlCls->Sup.len : 0) + (txt ? txt->Sup.len : 0) + 47);
appendString(T11_, htmlHead);
appendString(T11_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_147));
appendString(T11_, htmlCls);
appendString(T11_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_148));
appendString(T11_, txt);
appendString(T11_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_149));
	T12_ = NIM_NIL;
	T12_ = rawNewString((texColor ? texColor->Sup.len : 0) + (texSz ? texSz->Sup.len : 0) + (texColor ? texColor->Sup.len : 0) + (txt ? txt->Sup.len : 0) + 104);
appendString(T12_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_150));
appendString(T12_, texColor);
appendString(T12_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_151));
appendString(T12_, texSz);
appendString(T12_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_152));
appendString(T12_, texColor);
appendString(T12_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_153));
appendString(T12_, txt);
appendString(T12_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_154));
	renderAux__packagesZdocutilsZrstgen_324(d, n, T11_, T12_, result);
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, texColumns__packagesZdocutilsZrstgen_8313)(tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n) {
	NimStringDesc* result;
	NI nColumns;
	result = NIM_NIL;
	{
		NI T3_;
		T3_ = ((*n).sons ? (*n).sons->Sup.len : 0);
		if (!(((NI) 0) < T3_)) goto LA4_;
		nColumns = len__packagesZdocutilsZrstast_102((*n).sons->data[((NI) 0)]);
	}
	goto LA1_;
	LA4_: ;
	{
		nColumns = ((NI) 1);
	}
	LA1_: ;
	result = nsuRepeatStr(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_157), ((NI) (nColumns)));
	return result;
}
static N_INLINE(NI, skip__pureZparseutils_117)(NimStringDesc* s, NimStringDesc* token, NI start) {
	NI result;
	result = (NI)0;
	result = ((NI) 0);
	{
		while (1) {
			NIM_BOOL T3_;
			NIM_BOOL T4_;
			T3_ = (NIM_BOOL)0;
			T4_ = (NIM_BOOL)0;
			T4_ = ((NI)(start + result) < (s ? s->Sup.len : 0));
			if (!(T4_)) goto LA5_;
			T4_ = (result < (token ? token->Sup.len : 0));
			LA5_: ;
			T3_ = T4_;
			if (!(T3_)) goto LA6_;
			T3_ = ((NU8)(s->data[(NI)(result + start)]) == (NU8)(token->data[result]));
			LA6_: ;
			if (!T3_) goto LA2;
			result += ((NI) 1);
		} LA2: ;
	}
	{
		if (!!((result == (token ? token->Sup.len : 0)))) goto LA9_;
		result = ((NI) 0);
	}
	LA9_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, safeProtocol__packagesZdocutilsZrstgen_8104)(NimStringDesc** linkStr) {
	NimStringDesc* protocol;
	protocol = ((NimStringDesc*) NIM_NIL);
	{
		NimStringDesc* inp;
		NI idx;
		NIM_BOOL res;
		NI resLen;
		inp = (*linkStr);
		idx = ((NI) 0);
		res = NIM_FALSE;
		resLen = parseIdent__pureZparseutils_57(inp, (&protocol), idx);
		{
			NI resLen_2;
			if (!!((resLen == ((NI) 0)))) goto LA5_;
			idx += resLen;
			resLen_2 = skip__pureZparseutils_117(inp, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_169), idx);
			{
				if (!!((resLen_2 == ((NI) 0)))) goto LA9_;
				idx += resLen_2;
				res = NIM_TRUE;
			}
			LA9_: ;
		}
		LA5_: ;
		if (!res) goto LA11_;
		{
			NIM_BOOL T15_;
			NIM_BOOL T16_;
			NI T17_;
			NI T19_;
			NI T21_;
			T15_ = (NIM_BOOL)0;
			T16_ = (NIM_BOOL)0;
			T17_ = (NI)0;
			T17_ = nsuCmpIgnoreCase(protocol, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_170));
			T16_ = (T17_ == ((NI) 0));
			if (T16_) goto LA18_;
			T19_ = (NI)0;
			T19_ = nsuCmpIgnoreCase(protocol, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_171));
			T16_ = (T19_ == ((NI) 0));
			LA18_: ;
			T15_ = T16_;
			if (T15_) goto LA20_;
			T21_ = (NI)0;
			T21_ = nsuCmpIgnoreCase(protocol, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_172));
			T15_ = (T21_ == ((NI) 0));
			LA20_: ;
			if (!T15_) goto LA22_;
		}
		goto LA13_;
		LA22_: ;
		{
			unsureAsgnRef((void**) (&(*linkStr)), ((NimStringDesc*) NIM_NIL));
		}
		LA13_: ;
	}
	LA11_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, renderHyperlink__packagesZdocutilsZrstgen_8438)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* text, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* link, NimStringDesc** result, NIM_BOOL external) {
	NimStringDesc* linkStr;
	NimStringDesc* textStr;
	linkStr = ((NimStringDesc*) NIM_NIL);
	{
		tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg mode;
		mode = (*d).escMode;
		(*d).escMode = ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 2);
		renderRstToOut__packagesZdocutilsZrstgen_308(d, link, (&linkStr));
		(*d).escMode = mode;
	}
	safeProtocol__packagesZdocutilsZrstgen_8104((&linkStr));
	textStr = ((NimStringDesc*) NIM_NIL);
	renderRstToOut__packagesZdocutilsZrstgen_308(d, text, (&textStr));
	{
		tyArray__Re75IspeoxXy2oCZHwcRrA T6_;
		if (!external) goto LA4_;
		nimZeroMem((void*)T6_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
		T6_[0] = copyString(textStr);
		T6_[1] = copyString(linkStr);
		dispA__packagesZdocutilsZrstgen_294((*d).target, result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_173), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_174), T6_, 2);
	}
	goto LA2_;
	LA4_: ;
	{
		tyArray__Re75IspeoxXy2oCZHwcRrA T8_;
		nimZeroMem((void*)T8_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
		T8_[0] = copyString(textStr);
		T8_[1] = copyString(linkStr);
		dispA__packagesZdocutilsZrstgen_294((*d).target, result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_175), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_176), T8_, 2);
	}
	LA2_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dispF__packagesZdocutilsZrstgen_284)(tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ target, NimStringDesc* xml, NimStringDesc* tex, NimStringDesc** args, NI argsLen_0) {
	NimStringDesc* result;
	result = NIM_NIL;
	{
		if (!!((target == ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 1)))) goto LA3_;
		result = nsuFormatOpenArray(xml, args, argsLen_0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = nsuFormatOpenArray(tex, args, argsLen_0);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, renderImage__packagesZdocutilsZrstgen_8149)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc** result) {
	NimStringDesc* arg;
	NimStringDesc* options;
	NimStringDesc* s;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	NimStringDesc* T8_;
	NimStringDesc* T9_;
	NimStringDesc* T15_;
	NimStringDesc* T16_;
	NimStringDesc* T22_;
	NimStringDesc* T23_;
	NimStringDesc* T29_;
	NimStringDesc* T30_;
	NimStringDesc* htmlOut;
	NimStringDesc* target;
	NimStringDesc* T50_;
	NimStringDesc* T51_;
	tyArray__24KAM9afIUgUaqBaEBB6r9bg T57_;
	arg = getArgument__packagesZdocutilsZrst_68(n);
	options = ((NimStringDesc*) NIM_NIL);
	T1_ = NIM_NIL;
	T1_ = getFieldValue__packagesZdocutilsZrst_65(n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_180));
	T2_ = NIM_NIL;
	T2_ = nsuStrip(T1_, NIM_TRUE, NIM_TRUE, TM__vYBWrr780p7faFzauVMtPg_88);
	s = esc__packagesZdocutilsZrstgen_249((*d).target, T2_, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
	{
		tyArray__nHXaesL0DJZHyVS07ARPRA T7_;
		if (!(((NI) 0) < (s ? s->Sup.len : 0))) goto LA5_;
		nimZeroMem((void*)T7_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
		T7_[0] = copyString(s);
		dispA__packagesZdocutilsZrstgen_294((*d).target, (&options), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_181), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_182), T7_, 1);
	}
	LA5_: ;
	T8_ = NIM_NIL;
	T8_ = getFieldValue__packagesZdocutilsZrst_65(n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_183));
	T9_ = NIM_NIL;
	T9_ = nsuStrip(T8_, NIM_TRUE, NIM_TRUE, TM__vYBWrr780p7faFzauVMtPg_88);
	s = esc__packagesZdocutilsZrstgen_249((*d).target, T9_, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
	{
		tyArray__nHXaesL0DJZHyVS07ARPRA T14_;
		if (!(((NI) 0) < (s ? s->Sup.len : 0))) goto LA12_;
		nimZeroMem((void*)T14_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
		T14_[0] = copyString(s);
		dispA__packagesZdocutilsZrstgen_294((*d).target, (&options), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_184), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_185), T14_, 1);
	}
	LA12_: ;
	T15_ = NIM_NIL;
	T15_ = getFieldValue__packagesZdocutilsZrst_65(n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_186));
	T16_ = NIM_NIL;
	T16_ = nsuStrip(T15_, NIM_TRUE, NIM_TRUE, TM__vYBWrr780p7faFzauVMtPg_88);
	s = esc__packagesZdocutilsZrstgen_249((*d).target, T16_, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
	{
		tyArray__nHXaesL0DJZHyVS07ARPRA T21_;
		if (!(((NI) 0) < (s ? s->Sup.len : 0))) goto LA19_;
		nimZeroMem((void*)T21_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
		T21_[0] = copyString(s);
		dispA__packagesZdocutilsZrstgen_294((*d).target, (&options), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_187), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_188), T21_, 1);
	}
	LA19_: ;
	T22_ = NIM_NIL;
	T22_ = getFieldValue__packagesZdocutilsZrst_65(n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_189));
	T23_ = NIM_NIL;
	T23_ = nsuStrip(T22_, NIM_TRUE, NIM_TRUE, TM__vYBWrr780p7faFzauVMtPg_88);
	s = esc__packagesZdocutilsZrstgen_249((*d).target, T23_, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
	{
		tyArray__nHXaesL0DJZHyVS07ARPRA T28_;
		if (!(((NI) 0) < (s ? s->Sup.len : 0))) goto LA26_;
		nimZeroMem((void*)T28_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
		T28_[0] = copyString(s);
		dispA__packagesZdocutilsZrstgen_294((*d).target, (&options), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_190), ((NimStringDesc*) NIM_NIL), T28_, 1);
	}
	LA26_: ;
	T29_ = NIM_NIL;
	T29_ = getFieldValue__packagesZdocutilsZrst_65(n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_191));
	T30_ = NIM_NIL;
	T30_ = nsuStrip(T29_, NIM_TRUE, NIM_TRUE, TM__vYBWrr780p7faFzauVMtPg_88);
	s = esc__packagesZdocutilsZrstgen_249((*d).target, T30_, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
	{
		tyArray__nHXaesL0DJZHyVS07ARPRA T35_;
		if (!(((NI) 0) < (s ? s->Sup.len : 0))) goto LA33_;
		nimZeroMem((void*)T35_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
		T35_[0] = copyString(s);
		dispA__packagesZdocutilsZrstgen_294((*d).target, (&options), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_192), ((NimStringDesc*) NIM_NIL), T35_, 1);
	}
	LA33_: ;
	{
		tyArray__nHXaesL0DJZHyVS07ARPRA T40_;
		if (!(((NI) 0) < (options ? options->Sup.len : 0))) goto LA38_;
		nimZeroMem((void*)T40_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
		T40_[0] = copyString(options);
		options = dispF__packagesZdocutilsZrstgen_284((*d).target, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_93), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_193), T40_, 1);
	}
	LA38_: ;
	htmlOut = ((NimStringDesc*) NIM_NIL);
	{
		NIM_BOOL T43_;
		NIM_BOOL T44_;
		T43_ = (NIM_BOOL)0;
		T44_ = (NIM_BOOL)0;
		T44_ = nsuEndsWith(arg, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_194));
		if (T44_) goto LA45_;
		T44_ = nsuEndsWith(arg, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_195));
		LA45_: ;
		T43_ = T44_;
		if (T43_) goto LA46_;
		T43_ = nsuEndsWith(arg, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_196));
		LA46_: ;
		if (!T43_) goto LA47_;
		htmlOut = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_197));
	}
	goto LA41_;
	LA47_: ;
	{
		htmlOut = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_198));
	}
	LA41_: ;
	T50_ = NIM_NIL;
	T50_ = getFieldValue__packagesZdocutilsZrst_65(n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_199));
	T51_ = NIM_NIL;
	T51_ = nsuStrip(T50_, NIM_TRUE, NIM_TRUE, TM__vYBWrr780p7faFzauVMtPg_88);
	target = esc__packagesZdocutilsZrstgen_249((*d).target, T51_, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 2));
	safeProtocol__packagesZdocutilsZrstgen_8104((&target));
	{
		NimStringDesc* htmlOutWithLink;
		tyArray__Re75IspeoxXy2oCZHwcRrA T56_;
		if (!(((NI) 0) < (target ? target->Sup.len : 0))) goto LA54_;
		htmlOutWithLink = ((NimStringDesc*) NIM_NIL);
		nimZeroMem((void*)T56_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
		T56_[0] = copyString(htmlOut);
		T56_[1] = copyString(target);
		dispA__packagesZdocutilsZrstgen_294((*d).target, (&htmlOutWithLink), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_173), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_174), T56_, 2);
		htmlOut = copyString(htmlOutWithLink);
	}
	LA54_: ;
	nimZeroMem((void*)T57_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
	T57_[0] = esc__packagesZdocutilsZrstgen_249((*d).target, arg, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
	T57_[1] = copyString(options);
	{
		if (!(((*n).anchor ? (*n).anchor->Sup.len : 0) == 0)) goto LA60_;
		T57_[2] = ((NimStringDesc*) NIM_NIL);
	}
	goto LA58_;
	LA60_: ;
	{
		switch ((*d).target) {
		case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 0):
		{
			NimStringDesc* T64_;
			T64_ = NIM_NIL;
			T64_ = rawNewString(((*n).anchor ? (*n).anchor->Sup.len : 0) + 6);
appendString(T64_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_42));
appendString(T64_, (*n).anchor);
appendString(T64_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_43));
			T57_[2] = T64_;
		}
		break;
		case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 1):
		{
			NimStringDesc* T66_;
			T66_ = NIM_NIL;
			T66_ = rawNewString(((*n).anchor ? (*n).anchor->Sup.len : 0) + ((*n).anchor ? (*n).anchor->Sup.len : 0) + 24);
appendString(T66_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_44));
appendString(T66_, (*n).anchor);
appendString(T66_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_45));
appendString(T66_, (*n).anchor);
appendString(T66_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_46));
			T57_[2] = T66_;
		}
		break;
		}
	}
	LA58_: ;
	dispA__packagesZdocutilsZrstgen_294((*d).target, result, htmlOut, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_200), T57_, 3);
	{
		NI T69_;
		T69_ = (NI)0;
		T69_ = len__packagesZdocutilsZrstast_102(n);
		if (!(((NI) 3) <= T69_)) goto LA70_;
		renderRstToOut__packagesZdocutilsZrstgen_308(d, (*n).sons->data[((NI) 2)], result);
	}
	LA70_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, init__packagesZdocutilsZrstgen_88)(tyObject_CodeBlockParams__9aOEbhOZz0OzaP4azOrleuA* p) {
	(*p).startLine = ((NI) 1);
	(*p).lang = ((tyEnum_SourceLanguage__caWYuN9aCrrNgLAxHN3okug) 0);
	unsureAsgnRef((void**) (&(*p).langStr), ((NimStringDesc*) NIM_NIL));
}
static N_INLINE(NimStringDesc*, X5BX5D___pureZunicode_3215)(NimStringDesc* s, tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw x) {
	NimStringDesc* result;
	NI a;
	NI L;
	result = NIM_NIL;
	a = x.a;
	L = (NI)((NI)((NI)((s ? s->Sup.len : 0) - x.b) - a) + ((NI) 1));
	result = mnewString(((NI) (L)));
	{
		NI i;
		NI i_2;
		i = (NI)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < L)) goto LA3;
				i = i_2;
				result->data[i] = s->data[(NI)(i + a)];
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
static N_INLINE(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw, dotdot___stdZenumutils_90)(NI a, NI b) {
	tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw));
	result.a = a;
	result.b = b;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, getField1Int__packagesZdocutilsZrstgen_8163)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc* fieldName) {
	NI result;
	NimStringDesc* value;
	NI number;
	NI nChars;
	result = (NI)0;
	value = getFieldValue__packagesZdocutilsZrst_5216(n);
	number = (NI)0;
	nChars = npuParseInt(value, (&number), ((NI) 0));
	{
		if (!(nChars == ((NI) 0))) goto LA3_;
		{
			if (!((value ? value->Sup.len : 0) == ((NI) 0))) goto LA7_;
			result = ((NI) 1);
		}
		goto LA5_;
		LA7_: ;
		{
			tyArray__Re75IspeoxXy2oCZHwcRrA T10_;
			NimStringDesc* T11_;
			nimZeroMem((void*)T10_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T10_[0] = copyString(fieldName);
			T10_[1] = copyString(value);
			T11_ = NIM_NIL;
			T11_ = nsuFormatOpenArray(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_208), T10_, 2);
			rstMessage__packagesZdocutilsZrst_2080((*d).filenames, (*d).msgHandler, (*n)._kind_7.info, ((tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg) 7), T11_);
		}
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		tyArray__Re75IspeoxXy2oCZHwcRrA T15_;
		tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw T16_;
		NimStringDesc* T17_;
		if (!(nChars < (value ? value->Sup.len : 0))) goto LA13_;
		nimZeroMem((void*)T15_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
		T15_[0] = copyString(fieldName);
		T16_ = dotdot___stdZenumutils_90(nChars, ((NI) 1));
		T15_[1] = X5BX5D___pureZunicode_3215(value, T16_);
		T17_ = NIM_NIL;
		T17_ = nsuFormatOpenArray(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_209), T15_, 2);
		rstMessage__packagesZdocutilsZrst_2080((*d).filenames, (*d).msgHandler, (*n)._kind_7.info, ((tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg) 7), T17_);
	}
	goto LA1_;
	LA13_: ;
	{
		result = number;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, parseCodeBlockField__packagesZdocutilsZrstgen_8191)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, tyObject_CodeBlockParams__9aOEbhOZz0OzaP4azOrleuA* params) {
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	T1_ = NIM_NIL;
	T1_ = getArgument__packagesZdocutilsZrst_68(n);
	T2_ = NIM_NIL;
	T2_ = nsuToLowerAsciiStr(T1_);
	if (eqStrings(T2_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_201))) goto LA3_;
	if (eqStrings(T2_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_202))) goto LA4_;
	if (eqStrings(T2_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_203))) goto LA4_;
	if (eqStrings(T2_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_204))) goto LA5_;
	if (eqStrings(T2_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_205))) goto LA6_;
	if (eqStrings(T2_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_206))) goto LA6_;
	if (eqStrings(T2_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_207))) goto LA7_;
	goto LA8_;
	LA3_: ;
	{
		(*params).numberLines = NIM_TRUE;
		(*params).startLine = getField1Int__packagesZdocutilsZrstgen_8163(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_201));
	}
	goto LA9_;
	LA4_: ;
	{
		NimStringDesc* T12_;
		T12_ = NIM_NIL;
		T12_ = getFieldValue__packagesZdocutilsZrst_5216(n);
		unsureAsgnRef((void**) (&(*params).filename), nsuStrip(T12_, NIM_TRUE, NIM_TRUE, TM__vYBWrr780p7faFzauVMtPg_88));
	}
	goto LA9_;
	LA5_: ;
	{
		NimStringDesc* T14_;
		T14_ = NIM_NIL;
		T14_ = getFieldValue__packagesZdocutilsZrst_5216(n);
		unsureAsgnRef((void**) (&(*params).testCmd), nsuStrip(T14_, NIM_TRUE, NIM_TRUE, TM__vYBWrr780p7faFzauVMtPg_88));
		{
			if (!(((*params).testCmd ? (*params).testCmd->Sup.len : 0) == ((NI) 0))) goto LA17_;
			unsureAsgnRef((void**) (&(*params).testCmd), copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_210)));
		}
		goto LA15_;
		LA17_: ;
		{
			unsureAsgnRef((void**) (&(*params).testCmd), nsuUnescape((*params).testCmd, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_43), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_43)));
		}
		LA15_: ;
	}
	goto LA9_;
	LA6_: ;
	{
		NimStringDesc* T21_;
		T21_ = NIM_NIL;
		T21_ = getArgument__packagesZdocutilsZrst_68(n);
		(*params).status = getField1Int__packagesZdocutilsZrstgen_8163(d, n, T21_);
	}
	goto LA9_;
	LA7_: ;
	{
		NimStringDesc* T23_;
		T23_ = NIM_NIL;
		T23_ = getFieldValue__packagesZdocutilsZrst_5216(n);
		unsureAsgnRef((void**) (&(*params).langStr), nsuStrip(T23_, NIM_TRUE, NIM_TRUE, TM__vYBWrr780p7faFzauVMtPg_88));
		(*params).lang = getSourceLanguage__packagesZdocutilsZhighlite_97((*params).langStr);
	}
	goto LA9_;
	LA8_: ;
	{
		NimStringDesc* T25_;
		T25_ = NIM_NIL;
		T25_ = getArgument__packagesZdocutilsZrst_68(n);
		rstMessage__packagesZdocutilsZrst_2080((*d).filenames, (*d).msgHandler, (*n)._kind_7.info, ((tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg) 13), T25_);
	}
	LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, parseCodeBlockParams__packagesZdocutilsZrstgen_8195)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, tyObject_CodeBlockParams__9aOEbhOZz0OzaP4azOrleuA* Result) {
	NimStringDesc* T13_;
{	(*Result).numberLines = 0;
	(*Result).startLine = 0;
	unsureAsgnRef((void**)&(*Result).langStr, NIM_NIL);
	(*Result).lang = 0;
	unsureAsgnRef((void**)&(*Result).filename, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).testCmd, NIM_NIL);
	(*Result).status = 0;
	init__packagesZdocutilsZrstgen_88(Result);
	{
		if (!(n == 0)) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		if (!!(((*n).sons->data[((NI) 1)] == 0))) goto LA7_;
		{
			tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ** son;
			tySequence__jo4WO9beNiWGoaKRjSrOMJQ* colontmp_;
			NI i;
			NI L;
			NI T10_;
			son = (tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ**)0;
			colontmp_ = NIM_NIL;
			colontmp_ = (*(*n).sons->data[((NI) 1)]).sons;
			i = ((NI) 0);
			T10_ = (colontmp_ ? colontmp_->Sup.len : 0);
			L = T10_;
			{
				while (1) {
					if (!(i < L)) goto LA12;
					son = &colontmp_->data[i];
					parseCodeBlockField__packagesZdocutilsZrstgen_8191(d, (*son), Result);
					i += ((NI) 1);
				} LA12: ;
			}
		}
	}
	LA7_: ;
	T13_ = NIM_NIL;
	T13_ = getArgument__packagesZdocutilsZrst_68(n);
	unsureAsgnRef((void**) (&(*Result).langStr), nsuStrip(T13_, NIM_TRUE, NIM_TRUE, TM__vYBWrr780p7faFzauVMtPg_88));
	{
		if (!!((((*Result).langStr ? (*Result).langStr->Sup.len : 0) == 0))) goto LA16_;
		(*Result).lang = getSourceLanguage__packagesZdocutilsZhighlite_97((*Result).langStr);
	}
	LA16_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, buildLinesHtmlTable__packagesZdocutilsZrstgen_8216)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_CodeBlockParams__9aOEbhOZz0OzaP4azOrleuA* params, NimStringDesc* code, NimStringDesc* idStr, tyTuple__UV3llMMYFckfui8YMBuUZA* Result) {
	NimStringDesc* id;
	NI codeLines;
	NimStringDesc* T8_;
	NimStringDesc* T9_;
	tyArray__nHXaesL0DJZHyVS07ARPRA T10_;
	NimStringDesc* T11_;
	NI line;
	NimStringDesc* T16_;
	NimStringDesc* T17_;
	tyArray__24KAM9afIUgUaqBaEBB6r9bg T18_;
	NimStringDesc* T19_;
	NimStringDesc* T20_;
	NimStringDesc* T21_;
	NimStringDesc* T22_;
	NimStringDesc* T23_;
	NimStringDesc* T24_;
{	unsureAsgnRef((void**)&(*Result).Field0, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).Field1, NIM_NIL);
	(*d).listingCounter += ((NI) 1);
	id = dollar___systemZdollars_3((*d).listingCounter);
	{
		NimStringDesc* colontmp_;
		NimStringDesc* T5_;
		tyArray__24KAM9afIUgUaqBaEBB6r9bg T6_;
		NimStringDesc* colontmp__2;
		NimStringDesc* T7_;
		if (!!((*params).numberLines)) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = getOrDefault__pureZstrtabs_173((*d).config, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_213), ((NimStringDesc*) NIM_NIL));
		nimZeroMem((void*)T6_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
		T6_[0] = copyString(id);
		T6_[1] = copyString(sourceLanguageToStr__packagesZdocutilsZhighlite_66[((*params).lang)- 0]);
		T6_[2] = copyString(idStr);
		colontmp_ = nsuFormatOpenArray(T5_, T6_, 3);
		T7_ = NIM_NIL;
		T7_ = getOrDefault__pureZstrtabs_173((*d).config, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_214), ((NimStringDesc*) NIM_NIL));
		colontmp__2 = nsuFormatSingleElem(T7_, id);
		unsureAsgnRef((void**) (&(*Result).Field0), copyString(colontmp_));
		unsureAsgnRef((void**) (&(*Result).Field1), copyString(colontmp__2));
		goto BeforeRet_;
	}
	LA3_: ;
	T8_ = NIM_NIL;
	T8_ = nsuStrip(code, NIM_TRUE, NIM_TRUE, TM__vYBWrr780p7faFzauVMtPg_88);
	codeLines = nsuCountLines(T8_);
	T9_ = NIM_NIL;
	nimZeroMem((void*)T10_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
	T10_[0] = copyString(idStr);
	T11_ = NIM_NIL;
	T11_ = nsuFormatOpenArray(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_215), T10_, 1);
	T9_ = rawNewString((T11_ ? T11_->Sup.len : 0) + 61);
appendString(T9_, T11_);
appendString(T9_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_216));
	unsureAsgnRef((void**) (&(*Result).Field0), T9_);
	line = (*params).startLine;
	{
		while (1) {
			NimStringDesc* T14_;
			NimStringDesc* T15_;
			if (!(((NI) 0) < codeLines)) goto LA13;
			T14_ = NIM_NIL;
			T15_ = NIM_NIL;
			T15_ = dollar___systemZdollars_3(line);
			T14_ = rawNewString((T15_ ? T15_->Sup.len : 0) + 1);
appendString(T14_, T15_);
appendString(T14_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_36));
			unsureAsgnRef((void**) (&(*Result).Field0), resizeString((*Result).Field0, (T14_ ? T14_->Sup.len : 0) + 0));
appendString((*Result).Field0, T14_);
			line += ((NI) 1);
			codeLines -= ((NI) 1);
		} LA13: ;
	}
	T16_ = NIM_NIL;
	T17_ = NIM_NIL;
	T17_ = getOrDefault__pureZstrtabs_173((*d).config, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_213), ((NimStringDesc*) NIM_NIL));
	nimZeroMem((void*)T18_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
	T18_[0] = copyString(id);
	T18_[1] = copyString(sourceLanguageToStr__packagesZdocutilsZhighlite_66[((*params).lang)- 0]);
	T18_[2] = copyString(idStr);
	T19_ = NIM_NIL;
	T19_ = nsuFormatOpenArray(T17_, T18_, 3);
	T16_ = rawNewString((T19_ ? T19_->Sup.len : 0) + 15);
appendString(T16_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_217));
appendString(T16_, T19_);
	unsureAsgnRef((void**) (&(*Result).Field0), resizeString((*Result).Field0, (T16_ ? T16_->Sup.len : 0) + 0));
appendString((*Result).Field0, T16_);
	T20_ = NIM_NIL;
	T21_ = NIM_NIL;
	T21_ = getOrDefault__pureZstrtabs_173((*d).config, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_214), ((NimStringDesc*) NIM_NIL));
	T22_ = NIM_NIL;
	T22_ = nsuFormatSingleElem(T21_, id);
	T23_ = NIM_NIL;
	T23_ = getOrDefault__pureZstrtabs_173((*d).config, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_219), ((NimStringDesc*) NIM_NIL));
	T24_ = NIM_NIL;
	T24_ = nsuFormatSingleElem(T23_, id);
	T20_ = rawNewString((T22_ ? T22_->Sup.len : 0) + (T24_ ? T24_->Sup.len : 0) + 26);
appendString(T20_, T22_);
appendString(T20_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_218));
appendString(T20_, T24_);
	unsureAsgnRef((void**) (&(*Result).Field1), T20_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, renderCode__packagesZdocutilsZrstgen_8252)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc** result) {
	tyObject_CodeBlockParams__9aOEbhOZz0OzaP4azOrleuA params;
	tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* m;
	NimStringDesc* blockStart;
	NimStringDesc* blockEnd;
	tyArray__8ZvwQIddfpj2THRVPsFzIQ T44_;
	tyArray__8ZvwQIddfpj2THRVPsFzIQ T57_;
{	nimZeroMem((void*)(&params), sizeof(tyObject_CodeBlockParams__9aOEbhOZz0OzaP4azOrleuA));
	parseCodeBlockParams__packagesZdocutilsZrstgen_8195(d, n, (&params));
	{
		if (!((*n).sons->data[((NI) 2)] == ((tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	m = (*(*n).sons->data[((NI) 2)]).sons->data[((NI) 0)];
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = (((NI) 0) < (params.testCmd ? params.testCmd->Sup.len : 0));
		if (!(T7_)) goto LA8_;
		T7_ = !(((*d).onTestSnippet.ClP_0 == TM__vYBWrr780p7faFzauVMtPg_211.ClP_0 && (*d).onTestSnippet.ClE_0 == TM__vYBWrr780p7faFzauVMtPg_211.ClE_0));
		LA8_: ;
		if (!T7_) goto LA9_;
		(*d).onTestSnippet.ClE_0? (*d).onTestSnippet.ClP_0(d, params.filename, params.testCmd, params.status, (*m)._kind_1.text, (*d).onTestSnippet.ClE_0):((TM__vYBWrr780p7faFzauVMtPg_212)((*d).onTestSnippet.ClP_0))(d, params.filename, params.testCmd, params.status, (*m)._kind_1.text);
	}
	LA9_: ;
	blockStart = NIM_NIL;
	blockEnd = NIM_NIL;
	switch ((*d).target) {
	case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 0):
	{
		{
			tyTuple__UV3llMMYFckfui8YMBuUZA _;
			NimStringDesc* T16_;
			if (!((*n).kind == ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 51))) goto LA14_;
			nimZeroMem((void*)(&_), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
			T16_ = NIM_NIL;
			{
				if (!(((*n).anchor ? (*n).anchor->Sup.len : 0) == 0)) goto LA19_;
				T16_ = ((NimStringDesc*) NIM_NIL);
			}
			goto LA17_;
			LA19_: ;
			{
				switch ((*d).target) {
				case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 0):
				{
					NimStringDesc* T23_;
					T23_ = NIM_NIL;
					T23_ = rawNewString(((*n).anchor ? (*n).anchor->Sup.len : 0) + 6);
appendString(T23_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_42));
appendString(T23_, (*n).anchor);
appendString(T23_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_43));
					T16_ = T23_;
				}
				break;
				case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 1):
				{
					NimStringDesc* T25_;
					T25_ = NIM_NIL;
					T25_ = rawNewString(((*n).anchor ? (*n).anchor->Sup.len : 0) + ((*n).anchor ? (*n).anchor->Sup.len : 0) + 24);
appendString(T25_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_44));
appendString(T25_, (*n).anchor);
appendString(T25_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_45));
appendString(T25_, (*n).anchor);
appendString(T25_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_46));
					T16_ = T25_;
				}
				break;
				}
			}
			LA17_: ;
			buildLinesHtmlTable__packagesZdocutilsZrstgen_8216(d, (&params), (*m)._kind_1.text, T16_, (&_));
			blockStart = copyString(_.Field0);
			blockEnd = copyString(_.Field1);
		}
		goto LA12_;
		LA14_: ;
		{
			blockStart = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_220));
			blockEnd = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_221));
		}
		LA12_: ;
	}
	break;
	case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 1):
	{
		{
			NimStringDesc* T32_;
			NimStringDesc* T33_;
			if (!((*n).kind == ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 51))) goto LA30_;
			T32_ = NIM_NIL;
			T33_ = NIM_NIL;
			{
				if (!(((*n).anchor ? (*n).anchor->Sup.len : 0) == 0)) goto LA36_;
				T33_ = ((NimStringDesc*) NIM_NIL);
			}
			goto LA34_;
			LA36_: ;
			{
				switch ((*d).target) {
				case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 0):
				{
					NimStringDesc* T40_;
					T40_ = NIM_NIL;
					T40_ = rawNewString(((*n).anchor ? (*n).anchor->Sup.len : 0) + 6);
appendString(T40_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_42));
appendString(T40_, (*n).anchor);
appendString(T40_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_43));
					T33_ = T40_;
				}
				break;
				case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 1):
				{
					NimStringDesc* T42_;
					T42_ = NIM_NIL;
					T42_ = rawNewString(((*n).anchor ? (*n).anchor->Sup.len : 0) + ((*n).anchor ? (*n).anchor->Sup.len : 0) + 24);
appendString(T42_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_44));
appendString(T42_, (*n).anchor);
appendString(T42_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_45));
appendString(T42_, (*n).anchor);
appendString(T42_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_46));
					T33_ = T42_;
				}
				break;
				}
			}
			LA34_: ;
			T32_ = rawNewString((T33_ ? T33_->Sup.len : 0) + 17);
appendString(T32_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_222));
appendString(T32_, T33_);
appendString(T32_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_223));
			blockStart = T32_;
			blockEnd = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_224));
		}
		goto LA28_;
		LA30_: ;
		{
			blockStart = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_225));
			blockEnd = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_226));
		}
		LA28_: ;
	}
	break;
	}
	nimZeroMem((void*)T44_, sizeof(tyArray__8ZvwQIddfpj2THRVPsFzIQ));
	dispA__packagesZdocutilsZrstgen_294((*d).target, result, blockStart, blockStart, T44_, 0);
	{
		if (!(params.lang == ((tyEnum_SourceLanguage__caWYuN9aCrrNgLAxHN3okug) 0))) goto LA47_;
		{
			if (!(((NI) 0) < (params.langStr ? params.langStr->Sup.len : 0))) goto LA51_;
			rstMessage__packagesZdocutilsZrst_2080((*d).filenames, (*d).msgHandler, (*n)._kind_7.info, ((tyEnum_MsgKind__LqGn2jXOUcn3gFaPF4DWNg) 12), params.langStr);
		}
		LA51_: ;
		{
			NIM_CHAR letter;
			NimStringDesc* colontmp_;
			NI i;
			NI L;
			letter = (NIM_CHAR)0;
			colontmp_ = NIM_NIL;
			colontmp_ = (*m)._kind_1.text;
			i = ((NI) 0);
			L = (colontmp_ ? colontmp_->Sup.len : 0);
			{
				while (1) {
					if (!(i < L)) goto LA55;
					letter = colontmp_->data[i];
					escChar__packagesZdocutilsZrstgen_225((*d).target, result, letter, ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
					i += ((NI) 1);
				} LA55: ;
			}
		}
	}
	goto LA45_;
	LA47_: ;
	{
		renderCodeLang__packagesZdocutilsZrstgen_8242(result, params.lang, (*m)._kind_1.text, (*d).target);
	}
	LA45_: ;
	nimZeroMem((void*)T57_, sizeof(tyArray__8ZvwQIddfpj2THRVPsFzIQ));
	dispA__packagesZdocutilsZrstgen_294((*d).target, result, blockEnd, blockEnd, T57_, 0);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, renderContainer__packagesZdocutilsZrstgen_8307)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc** result) {
	NimStringDesc* tmp;
	NimStringDesc* arg;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	tmp = ((NimStringDesc*) NIM_NIL);
	renderRstToOut__packagesZdocutilsZrstgen_308(d, (*n).sons->data[((NI) 2)], (&tmp));
	T1_ = NIM_NIL;
	T1_ = getArgument__packagesZdocutilsZrst_68(n);
	T2_ = NIM_NIL;
	T2_ = nsuStrip(T1_, NIM_TRUE, NIM_TRUE, TM__vYBWrr780p7faFzauVMtPg_88);
	arg = esc__packagesZdocutilsZrstgen_249((*d).target, T2_, ((NI) -1), ((tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg) 0));
	{
		tyArray__nHXaesL0DJZHyVS07ARPRA T7_;
		if (!((arg ? arg->Sup.len : 0) == 0)) goto LA5_;
		nimZeroMem((void*)T7_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
		T7_[0] = copyString(tmp);
		dispA__packagesZdocutilsZrstgen_294((*d).target, result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_227), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_93), T7_, 1);
	}
	goto LA3_;
	LA5_: ;
	{
		tyArray__Re75IspeoxXy2oCZHwcRrA T9_;
		nimZeroMem((void*)T9_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
		T9_[0] = copyString(arg);
		T9_[1] = copyString(tmp);
		dispA__packagesZdocutilsZrstgen_294((*d).target, result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_228), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_229), T9_, 2);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, renderIndexTerm__packagesZdocutilsZrstgen_374)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc** result) {
	NimStringDesc* refname;
	NimStringDesc* id;
	NimStringDesc* T8_;
	NI T9_;
	NimStringDesc* T10_;
	NimStringDesc* term;
	NimStringDesc* T11_;
	NimStringDesc* T12_;
	tyArray__Re75IspeoxXy2oCZHwcRrA T13_;
	refname = rstnodeToRefname__packagesZdocutilsZrst_61(n);
	{
		NIM_BOOL T3_;
		NI T6_;
		T3_ = (NIM_BOOL)0;
		T3_ = hasKey__packagesZdocutilsZrstgen_419((*d).seenIndexTerms, refname);
		if (!T3_) goto LA4_;
		T6_ = (NI)0;
		T6_ = getOrDefault__packagesZdocutilsZrstgen_727((*d).seenIndexTerms, refname);
		X5BX5Deq___packagesZdocutilsZrstgen_831((&(*d).seenIndexTerms), refname, (NI)(T6_ + ((NI) 1)));
	}
	goto LA1_;
	LA4_: ;
	{
		X5BX5Deq___packagesZdocutilsZrstgen_831((&(*d).seenIndexTerms), refname, ((NI) 1));
	}
	LA1_: ;
	T8_ = NIM_NIL;
	T9_ = (NI)0;
	T9_ = getOrDefault__packagesZdocutilsZrstgen_727((*d).seenIndexTerms, refname);
	T10_ = NIM_NIL;
	T10_ = dollar___systemZdollars_3(T9_);
	T8_ = rawNewString((refname ? refname->Sup.len : 0) + (T10_ ? T10_->Sup.len : 0) + 1);
appendString(T8_, refname);
appendChar(T8_, 95);
appendString(T8_, T10_);
	id = T8_;
	term = ((NimStringDesc*) NIM_NIL);
	renderAux__packagesZdocutilsZrstgen_312(d, n, (&term));
	T11_ = NIM_NIL;
	T11_ = nosextractFilename((*d).filename);
	T12_ = NIM_NIL;
	T12_ = noschangeFileExt(T11_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_49));
	setIndexTerm__packagesZdocutilsZrstgen_353(d, T12_, id, term, (*d).currentSection, ((NimStringDesc*) NIM_NIL));
	nimZeroMem((void*)T13_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
	T13_[0] = copyString(id);
	T13_[1] = copyString(term);
	dispA__packagesZdocutilsZrstgen_294((*d).target, result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_243), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_244), T13_, 2);
}
N_LIB_PRIVATE N_NIMCALL(void, renderSmiley__packagesZdocutilsZrstgen_8159)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc** result) {
	tyArray__nHXaesL0DJZHyVS07ARPRA T1_;
	NimStringDesc* T2_;
	nimZeroMem((void*)T1_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
	T2_ = NIM_NIL;
	T2_ = getOrDefault__pureZstrtabs_173((*d).config, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_251), ((NimStringDesc*) NIM_NIL));
	T1_[0] = nsuFormatSingleElem(T2_, (*n)._kind_1.text);
	dispA__packagesZdocutilsZrstgen_294((*d).target, result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_249), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_250), T1_, 1);
}
N_LIB_PRIVATE N_NIMCALL(void, renderRstToOut__packagesZdocutilsZrstgen_308)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* n, NimStringDesc** result) {
{	{
		if (!(n == ((tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	switch ((*n).kind) {
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 0):
	{
		renderAux__packagesZdocutilsZrstgen_312(d, n, result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 1):
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 3):
	{
		renderHeadline__packagesZdocutilsZrstgen_8025(d, n, result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 2):
	{
		renderOverline__packagesZdocutilsZrstgen_8077(d, n, result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 4):
	{
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_52), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_53), result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 5):
	{
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_54), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_55), result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 6):
	{
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_56), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_57), result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 7):
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 9):
	{
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_58), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_59), result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 8):
	{
		renderEnumList__packagesZdocutilsZrstgen_8331(d, n, result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 10):
	{
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_81), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_82), result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 11):
	{
		renderAux__packagesZdocutilsZrstgen_312(d, n, result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 12):
	{
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_83), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_84), result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 13):
	{
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_85), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_86), result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 14):
	{
		NimStringDesc* tmp;
		tmp = ((NimStringDesc*) NIM_NIL);
		{
			NI i;
			NI colontmp_;
			NI T19_;
			NI res;
			i = (NI)0;
			colontmp_ = (NI)0;
			T19_ = (NI)0;
			T19_ = len__packagesZdocutilsZrstast_102(n);
			colontmp_ = (NI)(T19_ - ((NI) 1));
			res = ((NI) 0);
			{
				while (1) {
					if (!(res <= colontmp_)) goto LA21;
					i = res;
					renderRstToOut__packagesZdocutilsZrstgen_308(d, (*n).sons->data[i], (&tmp));
					res += ((NI) 1);
				} LA21: ;
			}
		}
		{
			tyArray__Re75IspeoxXy2oCZHwcRrA T26_;
			if (!!(((tmp ? tmp->Sup.len : 0) == ((NI) 0)))) goto LA24_;
			nimZeroMem((void*)T26_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T26_[0] = copyString(tmp);
			{
				if (!(((*n).anchor ? (*n).anchor->Sup.len : 0) == 0)) goto LA29_;
				T26_[1] = ((NimStringDesc*) NIM_NIL);
			}
			goto LA27_;
			LA29_: ;
			{
				switch ((*d).target) {
				case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 0):
				{
					NimStringDesc* T33_;
					T33_ = NIM_NIL;
					T33_ = rawNewString(((*n).anchor ? (*n).anchor->Sup.len : 0) + 6);
appendString(T33_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_42));
appendString(T33_, (*n).anchor);
appendString(T33_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_43));
					T26_[1] = T33_;
				}
				break;
				case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 1):
				{
					NimStringDesc* T35_;
					T35_ = NIM_NIL;
					T35_ = rawNewString(((*n).anchor ? (*n).anchor->Sup.len : 0) + ((*n).anchor ? (*n).anchor->Sup.len : 0) + 24);
appendString(T35_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_44));
appendString(T35_, (*n).anchor);
appendString(T35_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_45));
appendString(T35_, (*n).anchor);
appendString(T35_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_46));
					T26_[1] = T35_;
				}
				break;
				}
			}
			LA27_: ;
			dispA__packagesZdocutilsZrstgen_294((*d).target, result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_87), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_82), T26_, 2);
		}
		LA24_: ;
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 15):
	{
		renderField__packagesZdocutilsZrstgen_8320(d, n, result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 16):
	{
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_94), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_95), result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 17):
	{
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_96), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_97), result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 56):
	{
		renderRstToOut__packagesZdocutilsZrstgen_308(d, (*n).sons->data[((NI) 2)], result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 18):
	{
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_98), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_99), result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 19):
	{
		NimStringDesc* addclass;
		NimStringDesc* T47_;
		{
			if (!((NI)((*n)._kind_6.order % ((NI) 2)) == ((NI) 1))) goto LA44_;
			addclass = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_100));
		}
		goto LA42_;
		LA44_: ;
		{
			addclass = ((NimStringDesc*) NIM_NIL);
		}
		LA42_: ;
		T47_ = NIM_NIL;
		T47_ = rawNewString((addclass ? addclass->Sup.len : 0) + 39);
appendString(T47_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_101));
appendString(T47_, addclass);
appendString(T47_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_102));
		renderAux__packagesZdocutilsZrstgen_324(d, n, T47_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_93), result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 20):
	{
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_103), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_104), result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 24):
	{
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_105), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_97), result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 21):
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 22):
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 23):
	{
		{
			if (!NIM_TRUE) goto LA53_;
			failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_106));
		}
		LA53_: ;
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 25):
	{
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_107), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_108), result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 26):
	{
		{
			if (!NIM_TRUE) goto LA59_;
			failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_109));
		}
		LA59_: ;
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 27):
	{
		{
			NIM_BOOL T64_;
			NI T65_;
			T64_ = (NIM_BOOL)0;
			T65_ = ((*n).sons ? (*n).sons->Sup.len : 0);
			T64_ = (T65_ == ((NI) 1));
			if (!(T64_)) goto LA66_;
			T64_ = eqStrings((*(*n).sons->data[((NI) 0)])._kind_3.lineIndent, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_36));
			LA66_: ;
			if (!T64_) goto LA67_;
			renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_110), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_111), result);
		}
		goto LA62_;
		LA67_: ;
		{
			renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_112), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_113), result);
		}
		LA62_: ;
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 28):
	{
		{
			if (!(((*n)._kind_3.lineIndent ? (*n)._kind_3.lineIndent->Sup.len : 0) == ((NI) 0))) goto LA73_;
			renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_114), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_115), result);
		}
		goto LA71_;
		LA73_: ;
		{
			if (!eqStrings((*n)._kind_3.lineIndent, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_36))) goto LA76_;
			renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_116), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_117), result);
		}
		goto LA71_;
		LA76_: ;
		{
			NimStringDesc* indent;
			NimStringDesc* T79_;
			NF T80_;
			NimStringDesc* T81_;
			NimStringDesc* T82_;
			NimStringDesc* T83_;
			T79_ = NIM_NIL;
			T80_ = (NF)0;
			T80_ = toFloat__system_1702((NI)(((*n)._kind_3.lineIndent ? (*n)._kind_3.lineIndent->Sup.len : 0) - ((NI) 1)));
			T81_ = NIM_NIL;
			T81_ = dollar___system_3126(((NF)(0.5) * (NF)(T80_)));
			T79_ = rawNewString((T81_ ? T81_->Sup.len : 0) + 2);
appendString(T79_, T81_);
appendString(T79_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_118));
			indent = T79_;
			T82_ = NIM_NIL;
			T82_ = rawNewString((indent ? indent->Sup.len : 0) + 42);
appendString(T82_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_119));
appendString(T82_, indent);
appendString(T82_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_120));
			T83_ = NIM_NIL;
			T83_ = rawNewString((indent ? indent->Sup.len : 0) + 22);
appendString(T83_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_121));
appendString(T83_, indent);
appendString(T83_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_122));
			renderAux__packagesZdocutilsZrstgen_324(d, n, T82_, T83_, result);
		}
		LA71_: ;
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 29):
	{
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_123), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_124), result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 52):
	{
		renderAdmonition__packagesZdocutilsZrstgen_8429(d, n, result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 30):
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 31):
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 32):
	{
		NimStringDesc* T87_;
		NimStringDesc* T88_;
		T87_ = NIM_NIL;
		T88_ = NIM_NIL;
		T88_ = texColumns__packagesZdocutilsZrstgen_8313(n);
		T87_ = rawNewString((T88_ ? T88_->Sup.len : 0) + 42);
appendString(T87_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_156));
appendString(T87_, T88_);
appendString(T87_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_158));
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_155), T87_, result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 33):
	{
		{
			NI T92_;
			T92_ = (NI)0;
			T92_ = len__packagesZdocutilsZrstast_102(n);
			if (!(((NI) 1) <= T92_)) goto LA93_;
			{
				if (!((*d).target == ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 1))) goto LA97_;
				renderRstToOut__packagesZdocutilsZrstgen_308(d, (*n).sons->data[((NI) 0)], result);
				{
					NI i_2;
					NI colontmp__2;
					NI T100_;
					NI res_2;
					i_2 = (NI)0;
					colontmp__2 = (NI)0;
					T100_ = (NI)0;
					T100_ = len__packagesZdocutilsZrstast_102(n);
					colontmp__2 = (NI)(T100_ - ((NI) 1));
					res_2 = ((NI) 1);
					{
						while (1) {
							if (!(res_2 <= colontmp__2)) goto LA102;
							i_2 = res_2;
							unsureAsgnRef((void**) (&(*result)), resizeString((*result), 3));
appendString((*result), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_159));
							renderRstToOut__packagesZdocutilsZrstgen_308(d, (*n).sons->data[i_2], result);
							res_2 += ((NI) 1);
						} LA102: ;
					}
				}
				unsureAsgnRef((void**) (&(*result)), resizeString((*result), 10));
appendString((*result), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_160));
			}
			goto LA95_;
			LA97_: ;
			{
				unsureAsgnRef((void**) (&(*result)), resizeString((*result), 4));
appendString((*result), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_161));
				renderAux__packagesZdocutilsZrstgen_312(d, n, result);
				unsureAsgnRef((void**) (&(*result)), resizeString((*result), 6));
appendString((*result), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_162));
			}
			LA95_: ;
		}
		LA93_: ;
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 35):
	{
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_96), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_93), result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 34):
	{
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_163), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_164), result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 38):
	{
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_165), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_166), result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 36):
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 37):
	{
		NimStringDesc* mark;
		NimStringDesc* body;
		tyArray__sMpvt1sOxOJ3LFGulnbeMQ T108_;
		mark = ((NimStringDesc*) NIM_NIL);
		renderAux__packagesZdocutilsZrstgen_312(d, (*n).sons->data[((NI) 0)], (&mark));
		body = ((NimStringDesc*) NIM_NIL);
		renderRstToOut__packagesZdocutilsZrstgen_308(d, (*n).sons->data[((NI) 1)], (&body));
		nimZeroMem((void*)T108_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
		T108_[0] = copyString(body);
		{
			if (!(((*n).anchor ? (*n).anchor->Sup.len : 0) == 0)) goto LA111_;
			T108_[1] = ((NimStringDesc*) NIM_NIL);
		}
		goto LA109_;
		LA111_: ;
		{
			switch ((*d).target) {
			case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 0):
			{
				NimStringDesc* T115_;
				T115_ = NIM_NIL;
				T115_ = rawNewString(((*n).anchor ? (*n).anchor->Sup.len : 0) + 6);
appendString(T115_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_42));
appendString(T115_, (*n).anchor);
appendString(T115_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_43));
				T108_[1] = T115_;
			}
			break;
			case ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 1):
			{
				NimStringDesc* T117_;
				T117_ = NIM_NIL;
				T117_ = rawNewString(((*n).anchor ? (*n).anchor->Sup.len : 0) + ((*n).anchor ? (*n).anchor->Sup.len : 0) + 24);
appendString(T117_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_44));
appendString(T117_, (*n).anchor);
appendString(T117_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_45));
appendString(T117_, (*n).anchor);
appendString(T117_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_46));
				T108_[1] = T117_;
			}
			break;
			}
		}
		LA109_: ;
		T108_[2] = copyString(mark);
		T108_[3] = copyString((*n).anchor);
		dispA__packagesZdocutilsZrstgen_294((*d).target, result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_167), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_168), T108_, 4);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 41):
	{
		renderHyperlink__packagesZdocutilsZrstgen_8438(d, (*n).sons->data[((NI) 0)], (*n).sons->data[((NI) 0)], result, NIM_FALSE);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 39):
	{
		renderHyperlink__packagesZdocutilsZrstgen_8438(d, (*n).sons->data[((NI) 0)], (*n).sons->data[((NI) 0)], result, NIM_TRUE);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 42):
	{
		renderHyperlink__packagesZdocutilsZrstgen_8438(d, (*n).sons->data[((NI) 0)], (*n).sons->data[((NI) 1)], result, NIM_FALSE);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 40):
	{
		renderHyperlink__packagesZdocutilsZrstgen_8438(d, (*n).sons->data[((NI) 0)], (*n).sons->data[((NI) 1)], result, NIM_TRUE);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 43):
	{
		NimStringDesc* tmp_2;
		tyArray__Re75IspeoxXy2oCZHwcRrA T123_;
		tmp_2 = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_177));
		renderAux__packagesZdocutilsZrstgen_312(d, (*n).sons->data[((NI) 0)], (&tmp_2));
		tmp_2 = resizeString(tmp_2, 1);
appendString(tmp_2, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_31));
		nimZeroMem((void*)T123_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
		T123_[0] = copyString(tmp_2);
		T123_[1] = copyString((*(*n).sons->data[((NI) 1)])._kind_1.text);
		dispA__packagesZdocutilsZrstgen_294((*d).target, result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_178), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_179), T123_, 2);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 45):
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 46):
	{
		renderAux__packagesZdocutilsZrstgen_312(d, n, result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 53):
	{
		{
			NIM_BOOL T128_;
			tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* T130_;
			tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* T133_;
			NimStringDesc* T134_;
			T128_ = (NIM_BOOL)0;
			T128_ = !(((*d).target == ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 1)));
			if (!(T128_)) goto LA129_;
			T130_ = NIM_NIL;
			T130_ = lastSon__packagesZdocutilsZrstast_200(n);
			T128_ = !((T130_ == 0));
			LA129_: ;
			if (!T128_) goto LA131_;
			T133_ = NIM_NIL;
			T133_ = lastSon__packagesZdocutilsZrstast_200(n);
			T134_ = NIM_NIL;
			T134_ = addNodes__packagesZdocutilsZrst_63(T133_);
			unsureAsgnRef((void**) (&(*result)), resizeString((*result), (T134_ ? T134_->Sup.len : 0) + 0));
appendString((*result), T134_);
		}
		LA131_: ;
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 54):
	{
		{
			NIM_BOOL T138_;
			tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* T140_;
			tyObject_RstNode__o7Mf73b09cQpxU9cdK19aKkqQ* T143_;
			NimStringDesc* T144_;
			T138_ = (NIM_BOOL)0;
			T138_ = ((*d).target == ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 1));
			if (!(T138_)) goto LA139_;
			T140_ = NIM_NIL;
			T140_ = lastSon__packagesZdocutilsZrstast_200(n);
			T138_ = !((T140_ == 0));
			LA139_: ;
			if (!T138_) goto LA141_;
			T143_ = NIM_NIL;
			T143_ = lastSon__packagesZdocutilsZrstast_200(n);
			T144_ = NIM_NIL;
			T144_ = addNodes__packagesZdocutilsZrst_63(T143_);
			unsureAsgnRef((void**) (&(*result)), resizeString((*result), (T144_ ? T144_->Sup.len : 0) + 0));
appendString((*result), T144_);
		}
		LA141_: ;
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 49):
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 50):
	{
		renderImage__packagesZdocutilsZrstgen_8149(d, n, result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 51):
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 58):
	{
		renderCode__packagesZdocutilsZrstgen_8252(d, n, result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 55):
	{
		renderContainer__packagesZdocutilsZrstgen_8307(d, n, result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 70):
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 57):
	{
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_230), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_230), result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 44):
	{
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) NIM_NIL), ((NimStringDesc*) NIM_NIL), result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 60):
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 59):
	{
		NimStringDesc* tmp0;
		NimStringDesc* tmp1;
		NimStringDesc* class_1;
		tmp0 = ((NimStringDesc*) NIM_NIL);
		tmp1 = ((NimStringDesc*) NIM_NIL);
		renderRstToOut__packagesZdocutilsZrstgen_308(d, (*n).sons->data[((NI) 0)], (&tmp0));
		renderRstToOut__packagesZdocutilsZrstgen_308(d, (*n).sons->data[((NI) 1)], (&tmp1));
		class_1 = copyString(tmp1);
		{
			NIM_BOOL T153_;
			T153_ = (NIM_BOOL)0;
			T153_ = ((*d).target == ((tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ) 1));
			if (!(T153_)) goto LA154_;
			T153_ = ((*n).kind == ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 60));
			LA154_: ;
			if (!T153_) goto LA155_;
			class_1 = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_231));
		}
		LA155_: ;
		{
			tyArray__Re75IspeoxXy2oCZHwcRrA T161_;
			if (!((*n).kind == ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 59))) goto LA159_;
			nimZeroMem((void*)T161_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T161_[0] = copyString(tmp0);
			T161_[1] = copyString(class_1);
			dispA__packagesZdocutilsZrstgen_294((*d).target, result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_232), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_233), T161_, 2);
		}
		goto LA157_;
		LA159_: ;
		{
			tyArray__Re75IspeoxXy2oCZHwcRrA T163_;
			nimZeroMem((void*)T163_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T163_[0] = copyString(tmp0);
			T163_[1] = copyString(class_1);
			dispA__packagesZdocutilsZrstgen_294((*d).target, result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_32), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_33), T163_, 2);
		}
		LA157_: ;
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 61):
	{
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_234), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_235), result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 62):
	{
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_236), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_237), result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 64):
	{
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_238), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_239), result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 65):
	{
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_240), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_164), result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 66):
	{
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_241), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_242), result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 63):
	{
		renderIndexTerm__packagesZdocutilsZrstgen_374(d, n, result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 68):
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 67):
	{
		renderAux__packagesZdocutilsZrstgen_324(d, n, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_245), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_246), result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 69):
	{
		NimStringDesc* tmp_3;
		tyArray__Re75IspeoxXy2oCZHwcRrA T172_;
		tmp_3 = ((NimStringDesc*) NIM_NIL);
		renderAux__packagesZdocutilsZrstgen_312(d, n, (&tmp_3));
		nimZeroMem((void*)T172_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
		T172_[0] = copyString(tmp_3);
		T172_[1] = rstnodeToRefname__packagesZdocutilsZrst_61(n);
		dispA__packagesZdocutilsZrstgen_294((*d).target, result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_247), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_248), T172_, 2);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 71):
	{
		renderSmiley__packagesZdocutilsZrstgen_8159(d, n, result);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 73):
	{
		NimStringDesc* T175_;
		T175_ = NIM_NIL;
		T175_ = esc__packagesZdocutilsZrstgen_249((*d).target, (*n)._kind_1.text, ((NI) -1), (*d).escMode);
		unsureAsgnRef((void**) (&(*result)), resizeString((*result), (T175_ ? T175_->Sup.len : 0) + 0));
appendString((*result), T175_);
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 48):
	{
		(*d).hasToc = NIM_TRUE;
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 72):
	{
	}
	break;
	case ((tyEnum_RstNodeKind__ZgH3X3ZZR9bYozFm5ci6phg) 47):
	{
		unsureAsgnRef((void**) (&(*d).meta[(((tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ) 1))- 0]), ((NimStringDesc*) NIM_NIL));
		renderRstToOut__packagesZdocutilsZrstgen_308(d, (*n).sons->data[((NI) 0)], (&(*d).meta[(((tyEnum_MetaEnum__7CAjnN9bTVDxNA9cLu0E2hdQ) 1))- 0]));
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, renderTocEntry__packagesZdocutilsZrstgen_8131)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, tyObject_TocEntry__8s9aRe62JHXKMgO2pStC19cA e, NimStringDesc** result) {
	tyArray__Re75IspeoxXy2oCZHwcRrA T1_;
	nimZeroMem((void*)T1_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
	T1_[0] = copyString(e.refname);
	T1_[1] = copyString(e.header);
	dispA__packagesZdocutilsZrstgen_294((*d).target, result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_252), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_253), T1_, 2);
}
N_LIB_PRIVATE N_NIMCALL(void, renderTocEntries__packagesZdocutilsZrstgen_8135)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* d, NI* j, NI lvl, NimStringDesc** result) {
	NimStringDesc* tmp;
	tmp = ((NimStringDesc*) NIM_NIL);
	{
		while (1) {
			NI T3_;
			NI a;
			T3_ = (((*d).tocPart ? (*d).tocPart->Sup.len : 0)-1);
			if (!((*j) <= T3_)) goto LA2;
			a = ((*(*d).tocPart->data[(*j)].n)._kind_5.level > 0? ((*(*d).tocPart->data[(*j)].n)._kind_5.level) : -((*(*d).tocPart->data[(*j)].n)._kind_5.level));
			{
				if (!(a == lvl)) goto LA6_;
				renderTocEntry__packagesZdocutilsZrstgen_8131(d, (*d).tocPart->data[(*j)], (&tmp));
				(*j) += ((NI) 1);
			}
			goto LA4_;
			LA6_: ;
			{
				if (!(lvl < a)) goto LA9_;
				renderTocEntries__packagesZdocutilsZrstgen_8135(d, j, a, (&tmp));
			}
			goto LA4_;
			LA9_: ;
			{
				goto LA1;
			}
			LA4_: ;
		} LA2: ;
	} LA1: ;
	{
		tyArray__nHXaesL0DJZHyVS07ARPRA T16_;
		if (!(((NI) 1) < lvl)) goto LA14_;
		nimZeroMem((void*)T16_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
		T16_[0] = copyString(tmp);
		dispA__packagesZdocutilsZrstgen_294((*d).target, result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_254), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_255), T16_, 1);
	}
	goto LA12_;
	LA14_: ;
	{
		unsureAsgnRef((void**) (&(*result)), resizeString((*result), (tmp ? tmp->Sup.len : 0) + 0));
appendString((*result), tmp);
	}
	LA12_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, writeIndexFile__packagesZdocutilsZrstgen_202)(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ* g, NimStringDesc* outfile) {
	{
		if (!(((NI) 0) < ((*g).theIndex ? (*g).theIndex->Sup.len : 0))) goto LA3_;
		writeFile__systemZio_476(outfile, (*g).theIndex);
	}
	LA3_: ;
}
static N_NIMCALL(void, Marker_tySequence__hf5PiuqqytWiEcddgIR5sQ)(void* p, NI op) {
	tySequence__hf5PiuqqytWiEcddgIR5sQ* a;
	NI T1_;
	a = (tySequence__hf5PiuqqytWiEcddgIR5sQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].keyword, op);
	nimGCvisit((void*)a->data[T1_].link, op);
	nimGCvisit((void*)a->data[T1_].linkTitle, op);
	nimGCvisit((void*)a->data[T1_].linkDesc, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__mQGg5S79bnlEvqSZ53aiYNQ)(void* p, NI op) {
	tySequence__mQGg5S79bnlEvqSZ53aiYNQ* a;
	NI T1_;
	a = (tySequence__mQGg5S79bnlEvqSZ53aiYNQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field1.keyword, op);
	nimGCvisit((void*)a->data[T1_].Field1.link, op);
	nimGCvisit((void*)a->data[T1_].Field1.linkTitle, op);
	nimGCvisit((void*)a->data[T1_].Field1.linkDesc, op);
	nimGCvisit((void*)a->data[T1_].Field2, op);
	}
}
static N_INLINE(NimStringDesc*, pop__pureZos_1366)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ** s) {
	NimStringDesc* result;
	NI L;
	NI T1_;
	result = NIM_NIL;
	T1_ = ((*s) ? (*s)->Sup.len : 0);
	L = (NI)(T1_ - ((NI) 1));
	result = copyString((*s)->data[L]);
	unsureAsgnRef((void**) (&(*s)), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) setLengthSeqV2(((*s))?&((*s))->Sup:NIM_NIL, (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_), ((NI) (L))));
	return result;
}
static N_INLINE(NimStringDesc*, slash___pureZos_121)(NimStringDesc* head, NimStringDesc* tail) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = nosjoinPath(head, tail);
	return result;
}
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringDesc* s) {
	NCSTRING result;
	result = (NCSTRING)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (s == ((NimStringDesc*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = ((*s).Sup.len == ((NI) 0));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = "";
	}
	goto LA1_;
	LA5_: ;
	{
		result = ((NCSTRING) ((*s).data));
	}
	LA1_: ;
	return result;
}
static N_INLINE(void, pushSafePoint)(TSafePoint* s) {
	(*s).prev = excHandler__system_2565;
	excHandler__system_2565 = s;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDocumentationTitle__packagesZdocutilsZrstgen_2066)(NimStringDesc* hyperlink) {
	NIM_BOOL result;
	NI T1_;
	result = (NIM_BOOL)0;
	T1_ = (NI)0;
	T1_ = nsuFindChar(hyperlink, 35, ((NI) 0), ((NI) 0));
	result = (T1_ < ((NI) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, unquoteIndexColumn__packagesZdocutilsZrstgen_341)(NimStringDesc* text) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = multiReplace__pureZstrutils_1678(text, TM__vYBWrr780p7faFzauVMtPg_262, 3);
	return result;
}
static N_INLINE(void, popSafePoint)(void) {
	excHandler__system_2565 = (*excHandler__system_2565).prev;
}
static N_INLINE(NI, emarkamp___pureZhashes_3)(NI h, NI val) {
	NI result;
	NU h_2;
	NU val_2;
	NU res;
	result = (NI)0;
	h_2 = ((NU) (h));
	val_2 = ((NU) (val));
	res = (NU)((NU32)(h_2) + (NU32)(val_2));
	res = (NU)((NU32)(res) + (NU32)((NU)((NU32)(res) << (NU32)(((NI) 10)))));
	res = (NU)(res ^ (NU)((NU32)(res) >> (NU32)(((NI) 6))));
	result = ((NI) (res));
	return result;
}
static N_INLINE(NI, emarkdollar___pureZhashes_18)(NI h) {
	NI result;
	NU h_2;
	NU res;
	result = (NI)0;
	h_2 = ((NU) (h));
	res = (NU)((NU32)(h_2) + (NU32)((NU)((NU32)(h_2) << (NU32)(((NI) 3)))));
	res = (NU)(res ^ (NU)((NU32)(res) >> (NU32)(((NI) 11))));
	res = (NU)((NU32)(res) + (NU32)((NU)((NU32)(res) << (NU32)(((NI) 15)))));
	result = ((NI) (res));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, hash__packagesZdocutilsZrstgen_1999)(tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA x) {
	NI result;
	NI T1_;
	NI T2_;
	NI T3_;
	NI T4_;
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_279(x.keyword);
	T2_ = (NI)0;
	T2_ = hash__pureZhashes_279(x.link);
	result = emarkamp___pureZhashes_3(T1_, T2_);
	T3_ = (NI)0;
	T3_ = hash__pureZhashes_279(x.linkTitle);
	result = emarkamp___pureZhashes_3(result, T3_);
	T4_ = (NI)0;
	T4_ = hash__pureZhashes_279(x.linkDesc);
	result = emarkamp___pureZhashes_3(result, T4_);
	result = emarkdollar___pureZhashes_18(result);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, readIndexDir__packagesZdocutilsZrstgen_6719)(NimStringDesc* dir, tyTuple__9aBSJwMgaASaEGDGtYmlj6w* Result) {
	NI L;
	tyProc__3pmh9bG9bLpdxUjFu9cDtbZaA T133_;
	unsureAsgnRef((void**)&(*Result).Field0, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).Field1, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).Field2.data, NIM_NIL);
	(*Result).Field2.counter = 0;
	unsureAsgnRef((void**) (&(*Result).Field0), NIM_NIL);
	initTable__packagesZdocutilsZrstgen_6729(((NI) 32), (&(*Result).Field2));
	unsureAsgnRef((void**) (&(*Result).Field1), (tySequence__hf5PiuqqytWiEcddgIR5sQ*) newSeq((&NTIseqLindexentryT__hf5PiuqqytWiEcddgIR5sQ_), ((NI) 15000)));
	unsureAsgnRef((void**) (&(*Result).Field1), (tySequence__hf5PiuqqytWiEcddgIR5sQ*) setLengthSeqV2(((*Result).Field1)?&((*Result).Field1)->Sup:NIM_NIL, (&NTIseqLindexentryT__hf5PiuqqytWiEcddgIR5sQ_), ((NI) 0)));
	L = ((NI) 0);
	{
		NimStringDesc* path;
		tySequence__sM4lkSb7zS6F7OVMvW9cffQ* stack;
		NIM_BOOL checkDir;
		path = NIM_NIL;
		stack = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) newSeq((&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_), 1);
		asgnRef((void**) (&stack->data[0]), ((NimStringDesc*) NIM_NIL));
		checkDir = NIM_FALSE;
		{
			while (1) {
				NI T4_;
				NimStringDesc* d;
				T4_ = (stack ? stack->Sup.len : 0);
				if (!(((NI) 0) < T4_)) goto LA3;
				d = pop__pureZos_1366((&stack));
				{
					tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw k;
					NimStringDesc* p;
					NimStringDesc* colontmp_;
					DIR* d_2;
					k = (tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw)0;
					p = NIM_NIL;
					colontmp_ = NIM_NIL;
					colontmp_ = slash___pureZos_121(dir, d);
					d_2 = opendir(nimToCStringConv(colontmp_));
					{
						if (!(d_2 == ((DIR*) NIM_NIL))) goto LA8_;
						{
							NI32 T14_;
							if (!checkDir) goto LA12_;
							T14_ = (NI32)0;
							T14_ = osLastError__pureZos_408();
							raiseOSError__pureZos_405(T14_, colontmp_);
						}
						LA12_: ;
					}
					goto LA6_;
					LA8_: ;
					{
						TSafePoint TM__vYBWrr780p7faFzauVMtPg_258;
						pushSafePoint(&TM__vYBWrr780p7faFzauVMtPg_258);
						TM__vYBWrr780p7faFzauVMtPg_258.status = _setjmp(TM__vYBWrr780p7faFzauVMtPg_258.context);
						if (TM__vYBWrr780p7faFzauVMtPg_258.status == 0) {
						{
							while (1) {
								{
									struct dirent* x;
									NimStringDesc* y;
									x = readdir(d_2);
									{
										if (!(x == ((struct dirent*) NIM_NIL))) goto LA21_;
										goto LA16;
									}
									LA21_: ;
									y = cstrToNimstr(((NCSTRING) ((*x).d_name)));
									{
										NIM_BOOL T25_;
										struct stat s;
										NimStringDesc* path_2;
										tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw k_2;
										NimStringDesc* rel;
										T25_ = (NIM_BOOL)0;
										T25_ = !(eqStrings(y, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_259)));
										if (!(T25_)) goto LA26_;
										T25_ = !(eqStrings(y, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_38)));
										LA26_: ;
										if (!T25_) goto LA27_;
										nimZeroMem((void*)(&s), sizeof(struct stat));
										path_2 = slash___pureZos_121(colontmp_, y);
										{
											if (!NIM_FALSE) goto LA31_;
											y = copyString(path_2);
										}
										LA31_: ;
										k_2 = ((tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw) 0);
										{
											int T35_;
											T35_ = (int)0;
											T35_ = lstat(nimToCStringConv(path_2), (&s));
											if (!(T35_ < ((NI32) 0))) goto LA36_;
											goto LA18;
										}
										goto LA33_;
										LA36_: ;
										{
											NIM_BOOL T39_;
											T39_ = (NIM_BOOL)0;
											T39_ = S_ISDIR(s.st_mode);
											if (!T39_) goto LA40_;
											k_2 = ((tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw) 2);
										}
										goto LA33_;
										LA40_: ;
										{
											NIM_BOOL T43_;
											T43_ = (NIM_BOOL)0;
											T43_ = S_ISLNK(s.st_mode);
											if (!T43_) goto LA44_;
											k_2 = getSymlinkFileKind__pureZos_1224(path_2);
										}
										goto LA33_;
										LA44_: ;
										LA33_: ;
										k = k_2;
										p = y;
										rel = slash___pureZos_121(d, p);
										{
											NIM_BOOL T48_;
											NI T52_;
											NimStringDesc* T53_;
											T48_ = (NIM_BOOL)0;
											T48_ = ((12 &((NU8)1<<((NU)(k)&7U)))!=0);
											if (!(T48_)) goto LA49_;
											T48_ = ((4 &((NU8)1<<((NU)(k)&7U)))!=0);
											LA49_: ;
											if (!T48_) goto LA50_;
											stack = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)(stack), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_));
											T52_ = stack->Sup.len++;
											T53_ = NIM_NIL;
											T53_ = stack->data[T52_]; stack->data[T52_] = copyStringRC1(rel);
											if (T53_) nimGCunrefNoCycle(T53_);
										}
										LA50_: ;
										{
											if (!((1 &((NU8)1<<((NU)(k)&7U)))!=0)) goto LA56_;
											{
												if (!NIM_FALSE) goto LA60_;
												path = rel;
											}
											goto LA58_;
											LA60_: ;
											{
												path = slash___pureZos_121(dir, rel);
											}
											LA58_: ;
											{
												NIM_BOOL T65_;
												tySequence__hf5PiuqqytWiEcddgIR5sQ* fileEntries;
												tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA title;
												NI f;
												T65_ = (NIM_BOOL)0;
												T65_ = nsuEndsWith(path, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_260));
												if (!T65_) goto LA66_;
												fileEntries = NIM_NIL;
												nimZeroMem((void*)(&title), sizeof(tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA));
												f = ((NI) 0);
												fileEntries = (tySequence__hf5PiuqqytWiEcddgIR5sQ*) newSeq((&NTIseqLindexentryT__hf5PiuqqytWiEcddgIR5sQ_), ((NI) 500));
												fileEntries = (tySequence__hf5PiuqqytWiEcddgIR5sQ*) setLengthSeqV2((fileEntries)?&(fileEntries)->Sup:NIM_NIL, (&NTIseqLindexentryT__hf5PiuqqytWiEcddgIR5sQ_), ((NI) 0));
												{
													NimStringDesc* line;
													FILE* f_2;
													TSafePoint TM__vYBWrr780p7faFzauVMtPg_261;
													NimStringDesc* res;
													line = NIM_NIL;
													f_2 = open__systemZio_432(path, ((tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w) 0), ((NI) 8000));
													pushSafePoint(&TM__vYBWrr780p7faFzauVMtPg_261);
													TM__vYBWrr780p7faFzauVMtPg_261.status = _setjmp(TM__vYBWrr780p7faFzauVMtPg_261.context);
													if (TM__vYBWrr780p7faFzauVMtPg_261.status == 0) {
													res = rawNewString(((NI) 80));
													{
														while (1) {
															NIM_BOOL T71_;
															T71_ = (NIM_BOOL)0;
															T71_ = readLine__systemZio_240(f_2, (&res));
															if (!T71_) goto LA70;
															line = res;
															{
																NI s_2;
																s_2 = nsuFindChar(line, 9, ((NI) 0), ((NI) 0));
																{
																	if (!(s_2 < ((NI) 0))) goto LA75_;
																	goto LA72;
																}
																LA75_: ;
																fileEntries = (tySequence__hf5PiuqqytWiEcddgIR5sQ*) setLengthSeqV2((fileEntries)?&(fileEntries)->Sup:NIM_NIL, (&NTIseqLindexentryT__hf5PiuqqytWiEcddgIR5sQ_), ((NI) ((NI)(f + ((NI) 1)))));
																asgnRef((void**) (&fileEntries->data[f].keyword), substr__system_7744(line, ((NI) 0), (NI)(s_2 - ((NI) 1))));
																asgnRef((void**) (&fileEntries->data[f].link), substr__system_7756(line, (NI)(s_2 + ((NI) 1))));
																{
																	NIM_BOOL T79_;
																	T79_ = (NIM_BOOL)0;
																	T79_ = ((title.keyword ? title.keyword->Sup.len : 0) == ((NI) 0));
																	if (!(T79_)) goto LA80_;
																	T79_ = isDocumentationTitle__packagesZdocutilsZrstgen_2066(fileEntries->data[f].link);
																	LA80_: ;
																	if (!T79_) goto LA81_;
																	title.keyword = copyString(fileEntries->data[f].keyword);
																	title.link = copyString(fileEntries->data[f].link);
																}
																LA81_: ;
																{
																	NI T85_;
																	tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCols;
																	NimStringDesc* T88_;
																	T85_ = (NI)0;
																	T85_ = nsuFindChar(fileEntries->data[f].link, 9, ((NI) 0), ((NI) 0));
																	if (!(((NI) 0) < T85_)) goto LA86_;
																	extraCols = nsuSplitChar(fileEntries->data[f].link, 9, ((NI) -1));
																	T88_ = NIM_NIL;
																	T88_ = fileEntries->data[f].link; fileEntries->data[f].link = copyStringRC1(extraCols->data[((NI) 0)]);
																	if (T88_) nimGCunrefNoCycle(T88_);
																	asgnRef((void**) (&fileEntries->data[f].linkTitle), unquoteIndexColumn__packagesZdocutilsZrstgen_341(extraCols->data[((NI) 1)]));
																	asgnRef((void**) (&fileEntries->data[f].linkDesc), unquoteIndexColumn__packagesZdocutilsZrstgen_341(extraCols->data[((NI) 2)]));
																}
																goto LA83_;
																LA86_: ;
																{
																	asgnRef((void**) (&fileEntries->data[f].linkTitle), ((NimStringDesc*) NIM_NIL));
																	asgnRef((void**) (&fileEntries->data[f].linkDesc), ((NimStringDesc*) NIM_NIL));
																}
																LA83_: ;
																f += ((NI) 1);
															} LA72: ;
														} LA70: ;
													}
													popSafePoint();
													}
													else {
														popSafePoint();
													}
													{
														close__systemZio_218(f_2);
														if (TM__vYBWrr780p7faFzauVMtPg_261.status != 0) nimLeaveFinally();
													}
													if (TM__vYBWrr780p7faFzauVMtPg_261.status != 0) reraiseException();
												}
												{
													if (!((title.keyword ? title.keyword->Sup.len : 0) == ((NI) 0))) goto LA94_;
													{
														NI i;
														NI i_2;
														i = (NI)0;
														i_2 = ((NI) 0);
														{
															while (1) {
																if (!(i_2 < f)) goto LA98;
																i = i_2;
																{
																	NimStringDesc* toc;
																	NimStringDesc* T106_;
																	NimStringDesc* T107_;
																	NimStringDesc* T108_;
																	NimStringDesc* T109_;
																	toc = fileEntries->data[i].linkTitle;
																	{
																		NIM_BOOL T102_;
																		T102_ = (NIM_BOOL)0;
																		T102_ = (((NI) 0) < (toc ? toc->Sup.len : 0));
																		if (!(T102_)) goto LA103_;
																		T102_ = ((NU8)(toc->data[((NI) 0)]) == (NU8)(32));
																		LA103_: ;
																		if (!T102_) goto LA104_;
																		goto LA99;
																	}
																	LA104_: ;
																	unsureAsgnRef((void**) (&(*Result).Field1), (tySequence__hf5PiuqqytWiEcddgIR5sQ*) setLengthSeqV2(((*Result).Field1)?&((*Result).Field1)->Sup:NIM_NIL, (&NTIseqLindexentryT__hf5PiuqqytWiEcddgIR5sQ_), ((NI) ((NI)(L + ((NI) 1))))));
																	T106_ = NIM_NIL;
																	T106_ = (*Result).Field1->data[L].keyword; (*Result).Field1->data[L].keyword = copyStringRC1(fileEntries->data[i].keyword);
																	if (T106_) nimGCunrefNoCycle(T106_);
																	T107_ = NIM_NIL;
																	T107_ = (*Result).Field1->data[L].link; (*Result).Field1->data[L].link = copyStringRC1(fileEntries->data[i].link);
																	if (T107_) nimGCunrefNoCycle(T107_);
																	T108_ = NIM_NIL;
																	T108_ = (*Result).Field1->data[L].linkTitle; (*Result).Field1->data[L].linkTitle = copyStringRC1(fileEntries->data[i].linkTitle);
																	if (T108_) nimGCunrefNoCycle(T108_);
																	T109_ = NIM_NIL;
																	T109_ = (*Result).Field1->data[L].linkDesc; (*Result).Field1->data[L].linkDesc = copyStringRC1(fileEntries->data[i].linkDesc);
																	if (T109_) nimGCunrefNoCycle(T109_);
																	L += ((NI) 1);
																} LA99: ;
																i_2 += ((NI) 1);
															} LA98: ;
														}
													}
													{
														NI T112_;
														NimStringDesc* x_2;
														NI i_3;
														T112_ = (fileEntries ? fileEntries->Sup.len : 0);
														if (!(((NI) 0) < T112_)) goto LA113_;
														x_2 = copyString(fileEntries->data[((NI) 0)].link);
														i_3 = nsuFindChar(x_2, 35, ((NI) 0), ((NI) 0));
														{
															if (!(((NI) 0) < i_3)) goto LA117_;
															x_2 = setLengthStr(x_2, ((NI) (i_3)));
														}
														LA117_: ;
														{
															NimStringDesc* T123_;
															NI T124_;
															NimStringDesc* T125_;
															if (!!((i_3 == ((NI) 0)))) goto LA121_;
															T123_ = NIM_NIL;
															T123_ = noschangeFileExt(x_2, ((NimStringDesc*) NIM_NIL));
															unsureAsgnRef((void**) (&(*Result).Field0), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*Result).Field0), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
															T124_ = (*Result).Field0->Sup.len++;
															T125_ = NIM_NIL;
															T125_ = (*Result).Field0->data[T124_]; (*Result).Field0->data[T124_] = copyStringRC1(T123_);
															if (T125_) nimGCunrefNoCycle(T125_);
														}
														LA121_: ;
													}
													LA113_: ;
												}
												goto LA92_;
												LA94_: ;
												{
													NimStringDesc* T127_;
													NI T128_;
													NimStringDesc* T129_;
													T127_ = NIM_NIL;
													T128_ = (NI)0;
													T128_ = len__packagesZdocutilsZrstgen_5651((*Result).Field2);
													T129_ = NIM_NIL;
													T129_ = dollar___systemZdollars_3(T128_);
													T127_ = rawNewString((T129_ ? T129_->Sup.len : 0) + 8);
appendString(T127_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_265));
appendString(T127_, T129_);
													title.linkTitle = T127_;
													X5BX5Deq___packagesZdocutilsZrstgen_6889((&(*Result).Field2), title, fileEntries);
												}
												LA92_: ;
											}
											LA66_: ;
										}
										LA56_: ;
									}
									LA27_: ;
								} LA18: ;
							}
						} LA16: ;
						popSafePoint();
						}
						else {
							popSafePoint();
						}
						{
							int T132_;
							T132_ = (int)0;
							T132_ = closedir(d_2);
							(void)(T132_);
							if (TM__vYBWrr780p7faFzauVMtPg_258.status != 0) nimLeaveFinally();
						}
						if (TM__vYBWrr780p7faFzauVMtPg_258.status != 0) reraiseException();
					}
					LA6_: ;
				}
				checkDir = NIM_FALSE;
			} LA3: ;
		}
	}
	nimZeroMem((void*)(&T133_), sizeof(tyProc__3pmh9bG9bLpdxUjFu9cDtbZaA));
	T133_.ClP_0 = ((TM__vYBWrr780p7faFzauVMtPg_266) (cmp__system_1549)); T133_.ClE_0 = NIM_NIL;
	sort__sem_1836(((*Result).Field0) ? ((*Result).Field0->data) : NIM_NIL, ((*Result).Field0 ? (*Result).Field0->Sup.len : 0), T133_, ((tyEnum_SortOrder__TcYjciSJ3jKUT4ygglumjg) 1));
}
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_31)(NI hcode) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = !((hcode == ((NI) 0)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, cmp__packagesZdocutilsZrstgen_1995)(tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA a, tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA b) {
	NI result;
	result = (NI)0;
	result = nsuCmpIgnoreStyle(a.keyword, b.keyword);
	{
		if (!(result == ((NI) 0))) goto LA3_;
		result = nsuCmpIgnoreStyle(a.link, b.link);
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, generateDocumentationJumps__packagesZdocutilsZrstgen_6586)(tyObject_Table__0eDcTDUP9ap4EVATy5ptGQw docs) {
	NimStringDesc* result;
	tySequence__hf5PiuqqytWiEcddgIR5sQ* titles;
	tySequence__hf5PiuqqytWiEcddgIR5sQ* resultX60gensym80_;
	tyProc__5YgYRgMJZsuh62P0m8Lehw T16_;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ* chunks;
	NimStringDesc* T24_;
	NimStringDesc* T25_;
	result = NIM_NIL;
	result = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_267));
	resultX60gensym80_ = NIM_NIL;
	{
		tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA* xX60gensym80_;
		NI L;
		xX60gensym80_ = (tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA*)0;
		L = len__packagesZdocutilsZrstgen_5651(docs);
		{
			NI h;
			NI colontmp_;
			NI T3_;
			NI res;
			h = (NI)0;
			colontmp_ = (NI)0;
			T3_ = ((docs.data ? docs.data->Sup.len : 0)-1);
			colontmp_ = T3_;
			res = ((NI) 0);
			{
				while (1) {
					if (!(res <= colontmp_)) goto LA5;
					h = res;
					{
						NIM_BOOL T8_;
						NI T11_;
						NimStringDesc* T12_;
						NimStringDesc* T13_;
						NimStringDesc* T14_;
						NimStringDesc* T15_;
						T8_ = (NIM_BOOL)0;
						T8_ = isFilled__pureZcollectionsZtables_31(docs.data->data[h].Field0);
						if (!T8_) goto LA9_;
						xX60gensym80_ = (&docs.data->data[h].Field1);
						resultX60gensym80_ = (tySequence__hf5PiuqqytWiEcddgIR5sQ*) incrSeqV3((TGenericSeq*)(resultX60gensym80_), (&NTIseqLindexentryT__hf5PiuqqytWiEcddgIR5sQ_));
						T11_ = resultX60gensym80_->Sup.len++;
						T12_ = NIM_NIL;
						T12_ = resultX60gensym80_->data[T11_].keyword; resultX60gensym80_->data[T11_].keyword = copyStringRC1((*xX60gensym80_).keyword);
						if (T12_) nimGCunrefNoCycle(T12_);
						T13_ = NIM_NIL;
						T13_ = resultX60gensym80_->data[T11_].link; resultX60gensym80_->data[T11_].link = copyStringRC1((*xX60gensym80_).link);
						if (T13_) nimGCunrefNoCycle(T13_);
						T14_ = NIM_NIL;
						T14_ = resultX60gensym80_->data[T11_].linkTitle; resultX60gensym80_->data[T11_].linkTitle = copyStringRC1((*xX60gensym80_).linkTitle);
						if (T14_) nimGCunrefNoCycle(T14_);
						T15_ = NIM_NIL;
						T15_ = resultX60gensym80_->data[T11_].linkDesc; resultX60gensym80_->data[T11_].linkDesc = copyStringRC1((*xX60gensym80_).linkDesc);
						if (T15_) nimGCunrefNoCycle(T15_);
					}
					LA9_: ;
					res += ((NI) 1);
				} LA5: ;
			}
		}
	}
	genericSeqAssign((&titles), resultX60gensym80_, (&NTIseqLindexentryT__hf5PiuqqytWiEcddgIR5sQ_));
	nimZeroMem((void*)(&T16_), sizeof(tyProc__5YgYRgMJZsuh62P0m8Lehw));
	T16_.ClP_0 = ((TM__vYBWrr780p7faFzauVMtPg_268) (cmp__packagesZdocutilsZrstgen_1995)); T16_.ClE_0 = NIM_NIL;
	sort__packagesZdocutilsZrstgen_6113((titles) ? (titles->data) : NIM_NIL, (titles ? titles->Sup.len : 0), T16_, ((tyEnum_SortOrder__TcYjciSJ3jKUT4ygglumjg) 1));
	chunks = NIM_NIL;
	{
		tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA* title;
		NI i;
		NI L_2;
		NI T18_;
		title = (tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA*)0;
		i = ((NI) 0);
		T18_ = (titles ? titles->Sup.len : 0);
		L_2 = T18_;
		{
			while (1) {
				NimStringDesc* T21_;
				NI T22_;
				NimStringDesc* T23_;
				if (!(i < L_2)) goto LA20;
				title = (&titles->data[i]);
				T21_ = NIM_NIL;
				T21_ = rawNewString(((*title).link ? (*title).link->Sup.len : 0) + ((*title).keyword ? (*title).keyword->Sup.len : 0) + 15);
appendString(T21_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_269));
appendString(T21_, (*title).link);
appendString(T21_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_146));
appendString(T21_, (*title).keyword);
appendString(T21_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_270));
				chunks = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)(chunks), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_));
				T22_ = chunks->Sup.len++;
				T23_ = NIM_NIL;
				T23_ = chunks->data[T22_]; chunks->data[T22_] = copyStringRC1(T21_);
				if (T23_) nimGCunrefNoCycle(T23_);
				i += ((NI) 1);
			} LA20: ;
		}
	}
	T24_ = NIM_NIL;
	T25_ = NIM_NIL;
	T25_ = nsuJoinSep((chunks) ? (chunks->data) : NIM_NIL, (chunks ? chunks->Sup.len : 0), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_271));
	T24_ = rawNewString((T25_ ? T25_->Sup.len : 0) + 6);
appendString(T24_, T25_);
appendString(T24_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_272));
	result = resizeString(result, (T24_ ? T24_->Sup.len : 0) + 0);
appendString(result, T24_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, generateModuleJumps__packagesZdocutilsZrstgen_6703)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* modules) {
	NimStringDesc* result;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ* chunks;
	NimStringDesc* T9_;
	NimStringDesc* T10_;
	result = NIM_NIL;
	result = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_274));
	chunks = NIM_NIL;
	{
		NimStringDesc** name;
		NI i;
		NI L;
		NI T2_;
		name = (NimStringDesc**)0;
		i = ((NI) 0);
		T2_ = (modules ? modules->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				tyArray__Re75IspeoxXy2oCZHwcRrA T5_;
				NimStringDesc* T6_;
				NI T7_;
				NimStringDesc* T8_;
				if (!(i < L)) goto LA4;
				name = (&modules->data[i]);
				nimZeroMem((void*)T5_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T5_[0] = copyString((*name));
				T5_[1] = prettyLink__packagesZdocutilsZrstgen_85((*name));
				T6_ = NIM_NIL;
				T6_ = nsuFormatOpenArray(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_275), T5_, 2);
				chunks = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)(chunks), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_));
				T7_ = chunks->Sup.len++;
				T8_ = NIM_NIL;
				T8_ = chunks->data[T7_]; chunks->data[T7_] = copyStringRC1(T6_);
				if (T8_) nimGCunrefNoCycle(T8_);
				i += ((NI) 1);
			} LA4: ;
		}
	}
	T9_ = NIM_NIL;
	T10_ = NIM_NIL;
	T10_ = nsuJoinSep((chunks) ? (chunks->data) : NIM_NIL, (chunks ? chunks->Sup.len : 0), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_271));
	T9_ = rawNewString((T10_ ? T10_->Sup.len : 0) + 6);
appendString(T9_, T10_);
appendString(T9_, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_272));
	result = resizeString(result, (T9_ ? T9_->Sup.len : 0) + 0);
appendString(result, T9_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, ltminus___packagesZdocutilsZrstgen_2002)(tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA* a, tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA b) {
	unsureAsgnRef((void**) (&(*a).keyword), b.keyword);
	unsureAsgnRef((void**) (&(*a).link), b.link);
	unsureAsgnRef((void**) (&(*a).linkTitle), b.linkTitle);
	unsureAsgnRef((void**) (&(*a).linkDesc), b.linkDesc);
}
N_LIB_PRIVATE N_NIMCALL(void, sortIndex__packagesZdocutilsZrstgen_2005)(tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA* a, NI aLen_0) {
	NI n;
	NI h;
	n = aLen_0;
	h = ((NI) 1);
	{
		while (1) {
			h = (NI)((NI)(((NI) 3) * h) + ((NI) 1));
			{
				if (!(n < h)) goto LA5_;
				goto LA1;
			}
			LA5_: ;
		}
	} LA1: ;
	{
		while (1) {
			h = (NI)(h / ((NI) 3));
			{
				NI i;
				NI colontmp_;
				NI res;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = (NI)(n - ((NI) 1));
				res = h;
				{
					while (1) {
						tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA v;
						NI j;
						if (!(res <= colontmp_)) goto LA11;
						i = res;
						nimZeroMem((void*)(&v), sizeof(tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA));
						ltminus___packagesZdocutilsZrstgen_2002((&v), a[i]);
						j = i;
						{
							while (1) {
								NI T14_;
								T14_ = (NI)0;
								T14_ = cmp__packagesZdocutilsZrstgen_1995(a[(NI)(j - h)], v);
								if (!(((NI) 0) <= T14_)) goto LA13;
								ltminus___packagesZdocutilsZrstgen_2002((&a[j]), a[(NI)(j - h)]);
								j = (NI)(j - h);
								{
									if (!(j < h)) goto LA17_;
									goto LA12;
								}
								LA17_: ;
							} LA13: ;
						} LA12: ;
						ltminus___packagesZdocutilsZrstgen_2002((&a[j]), v);
						res += ((NI) 1);
					} LA11: ;
				}
			}
			{
				if (!(h == ((NI) 1))) goto LA21_;
				goto LA7;
			}
			LA21_: ;
		}
	} LA7: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, escapeLink__packagesZdocutilsZrstgen_2030)(NimStringDesc* s) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = rawNewString(((NI) ((NI)((s ? s->Sup.len : 0) + (NI)((NI32)((s ? s->Sup.len : 0)) >> (NU32)(((NI) 2)))))));
	{
		NIM_CHAR c;
		NI i;
		NI L;
		c = (NIM_CHAR)0;
		i = ((NI) 0);
		L = (s ? s->Sup.len : 0);
		{
			while (1) {
				if (!(i < L)) goto LA3;
				c = s->data[i];
				switch (((NU8)(c))) {
				case 97 ... 122:
				case 65 ... 90:
				case 48 ... 57:
				case 45:
				case 46:
				case 95:
				case 126:
				{
					result = addChar(result, c);
				}
				break;
				case 35:
				case 47:
				{
					result = addChar(result, c);
				}
				break;
				default:
				{
					NimStringDesc* T7_;
					result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_278));
					T7_ = NIM_NIL;
					T7_ = toHex__pureZstrutils_1788(((NU8)(c)), ((NI) 2));
					result = resizeString(result, (T7_ ? T7_->Sup.len : 0) + 0);
appendString(result, T7_);
				}
				break;
				}
				i += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, generateSymbolIndex__packagesZdocutilsZrstgen_2045)(tySequence__hf5PiuqqytWiEcddgIR5sQ* symbols) {
	NimStringDesc* result;
	NI i;
	result = NIM_NIL;
	result = copyString(((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_277));
	i = ((NI) 0);
	{
		while (1) {
			NI T3_;
			NimStringDesc* keyword;
			NimStringDesc* cleanedKeyword;
			tyArray__Re75IspeoxXy2oCZHwcRrA T4_;
			NI j;
			T3_ = (symbols ? symbols->Sup.len : 0);
			if (!(i < T3_)) goto LA2;
			keyword = symbols->data[i].keyword;
			cleanedKeyword = escapeLink__packagesZdocutilsZrstgen_2030(keyword);
			nimZeroMem((void*)T4_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T4_[0] = copyString(keyword);
			T4_[1] = copyString(cleanedKeyword);
			nsuAddf((&result), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_279), T4_, 2);
			j = i;
			{
				while (1) {
					NIM_BOOL T7_;
					NI T8_;
					NimStringDesc* url;
					NimStringDesc* text;
					NimStringDesc* desc;
					T7_ = (NIM_BOOL)0;
					T8_ = (symbols ? symbols->Sup.len : 0);
					T7_ = (j < T8_);
					if (!(T7_)) goto LA9_;
					T7_ = eqStrings(keyword, symbols->data[j].keyword);
					LA9_: ;
					if (!T7_) goto LA6;
					url = escapeLink__packagesZdocutilsZrstgen_2030(symbols->data[j].link);
					{
						if (!(((NI) 0) < (symbols->data[j].linkTitle ? symbols->data[j].linkTitle->Sup.len : 0))) goto LA12_;
						text = symbols->data[j].linkTitle;
					}
					goto LA10_;
					LA12_: ;
					{
						text = url;
					}
					LA10_: ;
					{
						if (!(((NI) 0) < (symbols->data[j].linkDesc ? symbols->data[j].linkDesc->Sup.len : 0))) goto LA17_;
						desc = symbols->data[j].linkDesc;
					}
					goto LA15_;
					LA17_: ;
					{
						desc = ((NimStringDesc*) NIM_NIL);
					}
					LA15_: ;
					{
						tyArray__24KAM9afIUgUaqBaEBB6r9bg T24_;
						if (!(((NI) 0) < (desc ? desc->Sup.len : 0))) goto LA22_;
						nimZeroMem((void*)T24_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
						T24_[0] = copyString(url);
						T24_[1] = copyString(text);
						T24_[2] = copyString(desc);
						nsuAddf((&result), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_280), T24_, 3);
					}
					goto LA20_;
					LA22_: ;
					{
						tyArray__Re75IspeoxXy2oCZHwcRrA T26_;
						nimZeroMem((void*)T26_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
						T26_[0] = copyString(url);
						T26_[1] = copyString(text);
						nsuAddf((&result), ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_281), T26_, 2);
					}
					LA20_: ;
					j += ((NI) 1);
				} LA6: ;
			}
			result = resizeString(result, 11);
appendString(result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_282));
			i = j;
		} LA2: ;
	}
	result = resizeString(result, 5);
appendString(result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_283));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, mergeIndexes__packagesZdocutilsZrstgen_7942)(NimStringDesc* dir) {
	NimStringDesc* result;
	tyTuple__9aBSJwMgaASaEGDGtYmlj6w T1_;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ* modules;
	tySequence__hf5PiuqqytWiEcddgIR5sQ* symbols;
	tyObject_Table__0eDcTDUP9ap4EVATy5ptGQw docs;
	result = NIM_NIL;
	nimZeroMem((void*)(&T1_), sizeof(tyTuple__9aBSJwMgaASaEGDGtYmlj6w));
	readIndexDir__packagesZdocutilsZrstgen_6719(dir, (&T1_));
	modules = NIM_NIL;
	genericSeqAssign((&modules), T1_.Field0, (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_));
	symbols = NIM_NIL;
	genericSeqAssign((&symbols), T1_.Field1, (&NTIseqLindexentryT__hf5PiuqqytWiEcddgIR5sQ_));
	nimZeroMem((void*)(&docs), sizeof(tyObject_Table__0eDcTDUP9ap4EVATy5ptGQw));
	genericSeqAssign((&docs.data), T1_.Field2.data, (&NTIkeyvaluepairseq__mQGg5S79bnlEvqSZ53aiYNQ_));
	docs.counter = T1_.Field2.counter;
	result = ((NimStringDesc*) NIM_NIL);
	{
		NI T4_;
		NimStringDesc* T7_;
		T4_ = (NI)0;
		T4_ = len__packagesZdocutilsZrstgen_5651(docs);
		if (!(((NI) 0) < T4_)) goto LA5_;
		T7_ = NIM_NIL;
		T7_ = generateDocumentationJumps__packagesZdocutilsZrstgen_6586(docs);
		result = resizeString(result, (T7_ ? T7_->Sup.len : 0) + 0);
appendString(result, T7_);
		result = resizeString(result, 5);
appendString(result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_273));
	}
	LA5_: ;
	{
		NI T10_;
		NimStringDesc* T13_;
		T10_ = (modules ? modules->Sup.len : 0);
		if (!(((NI) 0) < T10_)) goto LA11_;
		T13_ = NIM_NIL;
		T13_ = generateModuleJumps__packagesZdocutilsZrstgen_6703(modules);
		result = resizeString(result, (T13_ ? T13_->Sup.len : 0) + 0);
appendString(result, T13_);
		result = resizeString(result, 5);
appendString(result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_273));
	}
	LA11_: ;
	{
		NI T16_;
		NimStringDesc* T19_;
		T16_ = (symbols ? symbols->Sup.len : 0);
		if (!(((NI) 0) < T16_)) goto LA17_;
		sortIndex__packagesZdocutilsZrstgen_2005((symbols) ? (symbols->data) : NIM_NIL, (symbols ? symbols->Sup.len : 0));
		result = resizeString(result, 21);
appendString(result, ((NimStringDesc*) &TM__vYBWrr780p7faFzauVMtPg_276));
		T19_ = NIM_NIL;
		T19_ = generateSymbolIndex__packagesZdocutilsZrstgen_2045(symbols);
		result = resizeString(result, (T19_ ? T19_->Sup.len : 0) + 0);
appendString(result, T19_);
	}
	LA17_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, atmdotdotatslibatspackagesatsdocutilsatsrstgendotnim_DatInit000)(void) {
static TNimNode* TM__vYBWrr780p7faFzauVMtPg_2_19[19];
static TNimNode* TM__vYBWrr780p7faFzauVMtPg_3_2[2];
NI TM__vYBWrr780p7faFzauVMtPg_5;
static char* NIM_CONST TM__vYBWrr780p7faFzauVMtPg_4[2] = {
"outHtml", 
"outLatex"};
static TNimNode* TM__vYBWrr780p7faFzauVMtPg_6_3[3];
static TNimNode* TM__vYBWrr780p7faFzauVMtPg_7_2[2];
static TNimNode* TM__vYBWrr780p7faFzauVMtPg_8_3[3];
static TNimNode* TM__vYBWrr780p7faFzauVMtPg_9_2[2];
static TNimNode* TM__vYBWrr780p7faFzauVMtPg_10_3[3];
NI TM__vYBWrr780p7faFzauVMtPg_12;
static char* NIM_CONST TM__vYBWrr780p7faFzauVMtPg_11[3] = {
"emText", 
"emOption", 
"emUrl"};
static TNimNode* TM__vYBWrr780p7faFzauVMtPg_256_3[3];
static TNimNode* TM__vYBWrr780p7faFzauVMtPg_257_4[4];
static TNimNode TM__vYBWrr780p7faFzauVMtPg_0[50];
NTIrstgenerator__qr285fchxFL31hqgMYpbNQ_.size = sizeof(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ);
NTIrstgenerator__qr285fchxFL31hqgMYpbNQ_.align = NIM_ALIGNOF(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ);
NTIrstgenerator__qr285fchxFL31hqgMYpbNQ_.kind = 17;
NTIrstgenerator__qr285fchxFL31hqgMYpbNQ_.base = (&NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_);
TM__vYBWrr780p7faFzauVMtPg_2_19[0] = &TM__vYBWrr780p7faFzauVMtPg_0[1];
NTIoutputtarget__9aM59bezht8Qas1PkBOyPLJQ_.size = sizeof(tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ);
NTIoutputtarget__9aM59bezht8Qas1PkBOyPLJQ_.align = NIM_ALIGNOF(tyEnum_OutputTarget__9aM59bezht8Qas1PkBOyPLJQ);
NTIoutputtarget__9aM59bezht8Qas1PkBOyPLJQ_.kind = 14;
NTIoutputtarget__9aM59bezht8Qas1PkBOyPLJQ_.base = 0;
NTIoutputtarget__9aM59bezht8Qas1PkBOyPLJQ_.flags = 3;
for (TM__vYBWrr780p7faFzauVMtPg_5 = 0; TM__vYBWrr780p7faFzauVMtPg_5 < 2; TM__vYBWrr780p7faFzauVMtPg_5++) {
TM__vYBWrr780p7faFzauVMtPg_0[TM__vYBWrr780p7faFzauVMtPg_5+2].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[TM__vYBWrr780p7faFzauVMtPg_5+2].offset = TM__vYBWrr780p7faFzauVMtPg_5;
TM__vYBWrr780p7faFzauVMtPg_0[TM__vYBWrr780p7faFzauVMtPg_5+2].name = TM__vYBWrr780p7faFzauVMtPg_4[TM__vYBWrr780p7faFzauVMtPg_5];
TM__vYBWrr780p7faFzauVMtPg_3_2[TM__vYBWrr780p7faFzauVMtPg_5] = &TM__vYBWrr780p7faFzauVMtPg_0[TM__vYBWrr780p7faFzauVMtPg_5+2];
}
TM__vYBWrr780p7faFzauVMtPg_0[4].len = 2; TM__vYBWrr780p7faFzauVMtPg_0[4].kind = 2; TM__vYBWrr780p7faFzauVMtPg_0[4].sons = &TM__vYBWrr780p7faFzauVMtPg_3_2[0];
NTIoutputtarget__9aM59bezht8Qas1PkBOyPLJQ_.node = &TM__vYBWrr780p7faFzauVMtPg_0[4];
TM__vYBWrr780p7faFzauVMtPg_0[1].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[1].offset = offsetof(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ, target);
TM__vYBWrr780p7faFzauVMtPg_0[1].typ = (&NTIoutputtarget__9aM59bezht8Qas1PkBOyPLJQ_);
TM__vYBWrr780p7faFzauVMtPg_0[1].name = "target";
TM__vYBWrr780p7faFzauVMtPg_2_19[1] = &TM__vYBWrr780p7faFzauVMtPg_0[5];
TM__vYBWrr780p7faFzauVMtPg_0[5].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[5].offset = offsetof(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ, config);
TM__vYBWrr780p7faFzauVMtPg_0[5].typ = (&NTIstringtableref__frXcOWngaP9adxeuIUa3iBg_);
TM__vYBWrr780p7faFzauVMtPg_0[5].name = "config";
TM__vYBWrr780p7faFzauVMtPg_2_19[2] = &TM__vYBWrr780p7faFzauVMtPg_0[6];
TM__vYBWrr780p7faFzauVMtPg_0[6].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[6].offset = offsetof(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ, splitAfter);
TM__vYBWrr780p7faFzauVMtPg_0[6].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__vYBWrr780p7faFzauVMtPg_0[6].name = "splitAfter";
TM__vYBWrr780p7faFzauVMtPg_2_19[3] = &TM__vYBWrr780p7faFzauVMtPg_0[7];
TM__vYBWrr780p7faFzauVMtPg_0[7].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[7].offset = offsetof(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ, listingCounter);
TM__vYBWrr780p7faFzauVMtPg_0[7].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__vYBWrr780p7faFzauVMtPg_0[7].name = "listingCounter";
TM__vYBWrr780p7faFzauVMtPg_2_19[4] = &TM__vYBWrr780p7faFzauVMtPg_0[8];
NTItocentry__8s9aRe62JHXKMgO2pStC19cA_.size = sizeof(tyObject_TocEntry__8s9aRe62JHXKMgO2pStC19cA);
NTItocentry__8s9aRe62JHXKMgO2pStC19cA_.align = NIM_ALIGNOF(tyObject_TocEntry__8s9aRe62JHXKMgO2pStC19cA);
NTItocentry__8s9aRe62JHXKMgO2pStC19cA_.kind = 18;
NTItocentry__8s9aRe62JHXKMgO2pStC19cA_.base = 0;
NTItocentry__8s9aRe62JHXKMgO2pStC19cA_.flags = 2;
TM__vYBWrr780p7faFzauVMtPg_6_3[0] = &TM__vYBWrr780p7faFzauVMtPg_0[10];
TM__vYBWrr780p7faFzauVMtPg_0[10].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[10].offset = offsetof(tyObject_TocEntry__8s9aRe62JHXKMgO2pStC19cA, n);
TM__vYBWrr780p7faFzauVMtPg_0[10].typ = (&NTIprstnode__yfV9aZUcV0SioJcvRrGyZlg_);
TM__vYBWrr780p7faFzauVMtPg_0[10].name = "n";
TM__vYBWrr780p7faFzauVMtPg_6_3[1] = &TM__vYBWrr780p7faFzauVMtPg_0[11];
TM__vYBWrr780p7faFzauVMtPg_0[11].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[11].offset = offsetof(tyObject_TocEntry__8s9aRe62JHXKMgO2pStC19cA, refname);
TM__vYBWrr780p7faFzauVMtPg_0[11].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__vYBWrr780p7faFzauVMtPg_0[11].name = "refname";
TM__vYBWrr780p7faFzauVMtPg_6_3[2] = &TM__vYBWrr780p7faFzauVMtPg_0[12];
TM__vYBWrr780p7faFzauVMtPg_0[12].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[12].offset = offsetof(tyObject_TocEntry__8s9aRe62JHXKMgO2pStC19cA, header);
TM__vYBWrr780p7faFzauVMtPg_0[12].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__vYBWrr780p7faFzauVMtPg_0[12].name = "header";
TM__vYBWrr780p7faFzauVMtPg_0[9].len = 3; TM__vYBWrr780p7faFzauVMtPg_0[9].kind = 2; TM__vYBWrr780p7faFzauVMtPg_0[9].sons = &TM__vYBWrr780p7faFzauVMtPg_6_3[0];
NTItocentry__8s9aRe62JHXKMgO2pStC19cA_.node = &TM__vYBWrr780p7faFzauVMtPg_0[9];
NTIseqLtocentryT__ng4kcoK184wyb3xemBLQmw_.size = sizeof(tySequence__ng4kcoK184wyb3xemBLQmw*);
NTIseqLtocentryT__ng4kcoK184wyb3xemBLQmw_.align = NIM_ALIGNOF(tySequence__ng4kcoK184wyb3xemBLQmw*);
NTIseqLtocentryT__ng4kcoK184wyb3xemBLQmw_.kind = 24;
NTIseqLtocentryT__ng4kcoK184wyb3xemBLQmw_.base = (&NTItocentry__8s9aRe62JHXKMgO2pStC19cA_);
NTIseqLtocentryT__ng4kcoK184wyb3xemBLQmw_.flags = 2;
NTIseqLtocentryT__ng4kcoK184wyb3xemBLQmw_.marker = Marker_tySequence__ng4kcoK184wyb3xemBLQmw;
TM__vYBWrr780p7faFzauVMtPg_0[8].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[8].offset = offsetof(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ, tocPart);
TM__vYBWrr780p7faFzauVMtPg_0[8].typ = (&NTIseqLtocentryT__ng4kcoK184wyb3xemBLQmw_);
TM__vYBWrr780p7faFzauVMtPg_0[8].name = "tocPart";
TM__vYBWrr780p7faFzauVMtPg_2_19[5] = &TM__vYBWrr780p7faFzauVMtPg_0[13];
TM__vYBWrr780p7faFzauVMtPg_0[13].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[13].offset = offsetof(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ, hasToc);
TM__vYBWrr780p7faFzauVMtPg_0[13].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__vYBWrr780p7faFzauVMtPg_0[13].name = "hasToc";
TM__vYBWrr780p7faFzauVMtPg_2_19[6] = &TM__vYBWrr780p7faFzauVMtPg_0[14];
TM__vYBWrr780p7faFzauVMtPg_0[14].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[14].offset = offsetof(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ, theIndex);
TM__vYBWrr780p7faFzauVMtPg_0[14].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__vYBWrr780p7faFzauVMtPg_0[14].name = "theIndex";
TM__vYBWrr780p7faFzauVMtPg_2_19[7] = &TM__vYBWrr780p7faFzauVMtPg_0[15];
TM__vYBWrr780p7faFzauVMtPg_0[15].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[15].offset = offsetof(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ, findFile);
TM__vYBWrr780p7faFzauVMtPg_0[15].typ = (&NTIfindfilehandler__oFHfEKFsiYTMAy9a42cSiKw_);
TM__vYBWrr780p7faFzauVMtPg_0[15].name = "findFile";
TM__vYBWrr780p7faFzauVMtPg_2_19[8] = &TM__vYBWrr780p7faFzauVMtPg_0[16];
TM__vYBWrr780p7faFzauVMtPg_0[16].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[16].offset = offsetof(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ, msgHandler);
TM__vYBWrr780p7faFzauVMtPg_0[16].typ = (&NTImsghandler__gd6fvPtd9aVRsRjs9bLyzE9bQ_);
TM__vYBWrr780p7faFzauVMtPg_0[16].name = "msgHandler";
TM__vYBWrr780p7faFzauVMtPg_2_19[9] = &TM__vYBWrr780p7faFzauVMtPg_0[17];
TM__vYBWrr780p7faFzauVMtPg_0[17].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[17].offset = offsetof(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ, outDir);
TM__vYBWrr780p7faFzauVMtPg_0[17].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__vYBWrr780p7faFzauVMtPg_0[17].name = "outDir";
TM__vYBWrr780p7faFzauVMtPg_2_19[10] = &TM__vYBWrr780p7faFzauVMtPg_0[18];
TM__vYBWrr780p7faFzauVMtPg_0[18].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[18].offset = offsetof(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ, destFile);
TM__vYBWrr780p7faFzauVMtPg_0[18].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__vYBWrr780p7faFzauVMtPg_0[18].name = "destFile";
TM__vYBWrr780p7faFzauVMtPg_2_19[11] = &TM__vYBWrr780p7faFzauVMtPg_0[19];
TM__vYBWrr780p7faFzauVMtPg_0[19].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[19].offset = offsetof(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ, filenames);
TM__vYBWrr780p7faFzauVMtPg_0[19].typ = (&NTIrstfiletable__JJYG5kijP4PSa5F9a7da5tw_);
TM__vYBWrr780p7faFzauVMtPg_0[19].name = "filenames";
TM__vYBWrr780p7faFzauVMtPg_2_19[12] = &TM__vYBWrr780p7faFzauVMtPg_0[20];
TM__vYBWrr780p7faFzauVMtPg_0[20].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[20].offset = offsetof(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ, filename);
TM__vYBWrr780p7faFzauVMtPg_0[20].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__vYBWrr780p7faFzauVMtPg_0[20].name = "filename";
TM__vYBWrr780p7faFzauVMtPg_2_19[13] = &TM__vYBWrr780p7faFzauVMtPg_0[21];
NTIarrayLmetaenum_stringT__2cm2du8CnvAGpSJPsQ9bNhw_.size = sizeof(tyArray__2cm2du8CnvAGpSJPsQ9bNhw);
NTIarrayLmetaenum_stringT__2cm2du8CnvAGpSJPsQ9bNhw_.align = NIM_ALIGNOF(tyArray__2cm2du8CnvAGpSJPsQ9bNhw);
NTIarrayLmetaenum_stringT__2cm2du8CnvAGpSJPsQ9bNhw_.kind = 16;
NTIarrayLmetaenum_stringT__2cm2du8CnvAGpSJPsQ9bNhw_.base = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
NTIarrayLmetaenum_stringT__2cm2du8CnvAGpSJPsQ9bNhw_.flags = 2;
TM__vYBWrr780p7faFzauVMtPg_0[21].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[21].offset = offsetof(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ, meta);
TM__vYBWrr780p7faFzauVMtPg_0[21].typ = (&NTIarrayLmetaenum_stringT__2cm2du8CnvAGpSJPsQ9bNhw_);
TM__vYBWrr780p7faFzauVMtPg_0[21].name = "meta";
TM__vYBWrr780p7faFzauVMtPg_2_19[14] = &TM__vYBWrr780p7faFzauVMtPg_0[22];
TM__vYBWrr780p7faFzauVMtPg_0[22].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[22].offset = offsetof(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ, currentSection);
TM__vYBWrr780p7faFzauVMtPg_0[22].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__vYBWrr780p7faFzauVMtPg_0[22].name = "currentSection";
TM__vYBWrr780p7faFzauVMtPg_2_19[15] = &TM__vYBWrr780p7faFzauVMtPg_0[23];
NTItable__NKkg36PLm9cXyIIgbxq1hGQ_.size = sizeof(tyObject_Table__NKkg36PLm9cXyIIgbxq1hGQ);
NTItable__NKkg36PLm9cXyIIgbxq1hGQ_.align = NIM_ALIGNOF(tyObject_Table__NKkg36PLm9cXyIIgbxq1hGQ);
NTItable__NKkg36PLm9cXyIIgbxq1hGQ_.kind = 18;
NTItable__NKkg36PLm9cXyIIgbxq1hGQ_.base = 0;
NTItable__NKkg36PLm9cXyIIgbxq1hGQ_.flags = 2;
TM__vYBWrr780p7faFzauVMtPg_7_2[0] = &TM__vYBWrr780p7faFzauVMtPg_0[25];
NTIkeyvaluepair__sr3s7uVHpu9cEbbDnCSg8yQ_.size = sizeof(tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ);
NTIkeyvaluepair__sr3s7uVHpu9cEbbDnCSg8yQ_.align = NIM_ALIGNOF(tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ);
NTIkeyvaluepair__sr3s7uVHpu9cEbbDnCSg8yQ_.kind = 18;
NTIkeyvaluepair__sr3s7uVHpu9cEbbDnCSg8yQ_.base = 0;
NTIkeyvaluepair__sr3s7uVHpu9cEbbDnCSg8yQ_.flags = 2;
TM__vYBWrr780p7faFzauVMtPg_8_3[0] = &TM__vYBWrr780p7faFzauVMtPg_0[27];
TM__vYBWrr780p7faFzauVMtPg_0[27].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[27].offset = offsetof(tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ, Field0);
TM__vYBWrr780p7faFzauVMtPg_0[27].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__vYBWrr780p7faFzauVMtPg_0[27].name = "Field0";
TM__vYBWrr780p7faFzauVMtPg_8_3[1] = &TM__vYBWrr780p7faFzauVMtPg_0[28];
TM__vYBWrr780p7faFzauVMtPg_0[28].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[28].offset = offsetof(tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ, Field1);
TM__vYBWrr780p7faFzauVMtPg_0[28].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__vYBWrr780p7faFzauVMtPg_0[28].name = "Field1";
TM__vYBWrr780p7faFzauVMtPg_8_3[2] = &TM__vYBWrr780p7faFzauVMtPg_0[29];
TM__vYBWrr780p7faFzauVMtPg_0[29].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[29].offset = offsetof(tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ, Field2);
TM__vYBWrr780p7faFzauVMtPg_0[29].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__vYBWrr780p7faFzauVMtPg_0[29].name = "Field2";
TM__vYBWrr780p7faFzauVMtPg_0[26].len = 3; TM__vYBWrr780p7faFzauVMtPg_0[26].kind = 2; TM__vYBWrr780p7faFzauVMtPg_0[26].sons = &TM__vYBWrr780p7faFzauVMtPg_8_3[0];
NTIkeyvaluepair__sr3s7uVHpu9cEbbDnCSg8yQ_.node = &TM__vYBWrr780p7faFzauVMtPg_0[26];
NTIkeyvaluepairseq__pUxI6Ljo6IKKHXKOZkQ7Og_.size = sizeof(tySequence__pUxI6Ljo6IKKHXKOZkQ7Og*);
NTIkeyvaluepairseq__pUxI6Ljo6IKKHXKOZkQ7Og_.align = NIM_ALIGNOF(tySequence__pUxI6Ljo6IKKHXKOZkQ7Og*);
NTIkeyvaluepairseq__pUxI6Ljo6IKKHXKOZkQ7Og_.kind = 24;
NTIkeyvaluepairseq__pUxI6Ljo6IKKHXKOZkQ7Og_.base = (&NTIkeyvaluepair__sr3s7uVHpu9cEbbDnCSg8yQ_);
NTIkeyvaluepairseq__pUxI6Ljo6IKKHXKOZkQ7Og_.flags = 2;
NTIkeyvaluepairseq__pUxI6Ljo6IKKHXKOZkQ7Og_.marker = Marker_tySequence__pUxI6Ljo6IKKHXKOZkQ7Og;
TM__vYBWrr780p7faFzauVMtPg_0[25].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[25].offset = offsetof(tyObject_Table__NKkg36PLm9cXyIIgbxq1hGQ, data);
TM__vYBWrr780p7faFzauVMtPg_0[25].typ = (&NTIkeyvaluepairseq__pUxI6Ljo6IKKHXKOZkQ7Og_);
TM__vYBWrr780p7faFzauVMtPg_0[25].name = "data";
TM__vYBWrr780p7faFzauVMtPg_7_2[1] = &TM__vYBWrr780p7faFzauVMtPg_0[30];
TM__vYBWrr780p7faFzauVMtPg_0[30].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[30].offset = offsetof(tyObject_Table__NKkg36PLm9cXyIIgbxq1hGQ, counter);
TM__vYBWrr780p7faFzauVMtPg_0[30].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__vYBWrr780p7faFzauVMtPg_0[30].name = "counter";
TM__vYBWrr780p7faFzauVMtPg_0[24].len = 2; TM__vYBWrr780p7faFzauVMtPg_0[24].kind = 2; TM__vYBWrr780p7faFzauVMtPg_0[24].sons = &TM__vYBWrr780p7faFzauVMtPg_7_2[0];
NTItable__NKkg36PLm9cXyIIgbxq1hGQ_.node = &TM__vYBWrr780p7faFzauVMtPg_0[24];
TM__vYBWrr780p7faFzauVMtPg_0[23].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[23].offset = offsetof(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ, seenIndexTerms);
TM__vYBWrr780p7faFzauVMtPg_0[23].typ = (&NTItable__NKkg36PLm9cXyIIgbxq1hGQ_);
TM__vYBWrr780p7faFzauVMtPg_0[23].name = "seenIndexTerms";
TM__vYBWrr780p7faFzauVMtPg_2_19[16] = &TM__vYBWrr780p7faFzauVMtPg_0[31];
TM__vYBWrr780p7faFzauVMtPg_0[31].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[31].offset = offsetof(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ, id);
TM__vYBWrr780p7faFzauVMtPg_0[31].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__vYBWrr780p7faFzauVMtPg_0[31].name = "id";
TM__vYBWrr780p7faFzauVMtPg_2_19[17] = &TM__vYBWrr780p7faFzauVMtPg_0[32];
NTIprocLd58varrstgenerator_filename58string_cmd58string_status58int_content58stringTLOclosureOT__bvoZymnzBMzGoI59bjcrthA_.size = sizeof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTIprocLd58varrstgenerator_filename58string_cmd58string_status58int_content58stringTLOclosureOT__bvoZymnzBMzGoI59bjcrthA_.align = NIM_ALIGNOF(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTIprocLd58varrstgenerator_filename58string_cmd58string_status58int_content58stringTLOclosureOT__bvoZymnzBMzGoI59bjcrthA_.kind = 18;
NTIprocLd58varrstgenerator_filename58string_cmd58string_status58int_content58stringTLOclosureOT__bvoZymnzBMzGoI59bjcrthA_.base = 0;
TM__vYBWrr780p7faFzauVMtPg_9_2[0] = &TM__vYBWrr780p7faFzauVMtPg_0[34];
TM__vYBWrr780p7faFzauVMtPg_0[34].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[34].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field0);
TM__vYBWrr780p7faFzauVMtPg_0[34].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__vYBWrr780p7faFzauVMtPg_0[34].name = "Field0";
TM__vYBWrr780p7faFzauVMtPg_9_2[1] = &TM__vYBWrr780p7faFzauVMtPg_0[35];
TM__vYBWrr780p7faFzauVMtPg_0[35].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[35].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field1);
TM__vYBWrr780p7faFzauVMtPg_0[35].typ = (&NTIrefobject__HsJiUUcO9cHBdUCi0HwkSTA_);
TM__vYBWrr780p7faFzauVMtPg_0[35].name = "Field1";
TM__vYBWrr780p7faFzauVMtPg_0[33].len = 2; TM__vYBWrr780p7faFzauVMtPg_0[33].kind = 2; TM__vYBWrr780p7faFzauVMtPg_0[33].sons = &TM__vYBWrr780p7faFzauVMtPg_9_2[0];
NTIprocLd58varrstgenerator_filename58string_cmd58string_status58int_content58stringTLOclosureOT__bvoZymnzBMzGoI59bjcrthA_.node = &TM__vYBWrr780p7faFzauVMtPg_0[33];
TM__vYBWrr780p7faFzauVMtPg_0[32].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[32].offset = offsetof(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ, onTestSnippet);
TM__vYBWrr780p7faFzauVMtPg_0[32].typ = (&NTIprocLd58varrstgenerator_filename58string_cmd58string_status58int_content58stringTLOclosureOT__bvoZymnzBMzGoI59bjcrthA_);
TM__vYBWrr780p7faFzauVMtPg_0[32].name = "onTestSnippet";
TM__vYBWrr780p7faFzauVMtPg_2_19[18] = &TM__vYBWrr780p7faFzauVMtPg_0[36];
NTIescapemode__j9aHxQ3kKlc4KvedeVQimjg_.size = sizeof(tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg);
NTIescapemode__j9aHxQ3kKlc4KvedeVQimjg_.align = NIM_ALIGNOF(tyEnum_EscapeMode__j9aHxQ3kKlc4KvedeVQimjg);
NTIescapemode__j9aHxQ3kKlc4KvedeVQimjg_.kind = 14;
NTIescapemode__j9aHxQ3kKlc4KvedeVQimjg_.base = 0;
NTIescapemode__j9aHxQ3kKlc4KvedeVQimjg_.flags = 3;
for (TM__vYBWrr780p7faFzauVMtPg_12 = 0; TM__vYBWrr780p7faFzauVMtPg_12 < 3; TM__vYBWrr780p7faFzauVMtPg_12++) {
TM__vYBWrr780p7faFzauVMtPg_0[TM__vYBWrr780p7faFzauVMtPg_12+37].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[TM__vYBWrr780p7faFzauVMtPg_12+37].offset = TM__vYBWrr780p7faFzauVMtPg_12;
TM__vYBWrr780p7faFzauVMtPg_0[TM__vYBWrr780p7faFzauVMtPg_12+37].name = TM__vYBWrr780p7faFzauVMtPg_11[TM__vYBWrr780p7faFzauVMtPg_12];
TM__vYBWrr780p7faFzauVMtPg_10_3[TM__vYBWrr780p7faFzauVMtPg_12] = &TM__vYBWrr780p7faFzauVMtPg_0[TM__vYBWrr780p7faFzauVMtPg_12+37];
}
TM__vYBWrr780p7faFzauVMtPg_0[40].len = 3; TM__vYBWrr780p7faFzauVMtPg_0[40].kind = 2; TM__vYBWrr780p7faFzauVMtPg_0[40].sons = &TM__vYBWrr780p7faFzauVMtPg_10_3[0];
NTIescapemode__j9aHxQ3kKlc4KvedeVQimjg_.node = &TM__vYBWrr780p7faFzauVMtPg_0[40];
TM__vYBWrr780p7faFzauVMtPg_0[36].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[36].offset = offsetof(tyObject_RstGenerator__qr285fchxFL31hqgMYpbNQ, escMode);
TM__vYBWrr780p7faFzauVMtPg_0[36].typ = (&NTIescapemode__j9aHxQ3kKlc4KvedeVQimjg_);
TM__vYBWrr780p7faFzauVMtPg_0[36].name = "escMode";
TM__vYBWrr780p7faFzauVMtPg_0[0].len = 19; TM__vYBWrr780p7faFzauVMtPg_0[0].kind = 2; TM__vYBWrr780p7faFzauVMtPg_0[0].sons = &TM__vYBWrr780p7faFzauVMtPg_2_19[0];
NTIrstgenerator__qr285fchxFL31hqgMYpbNQ_.node = &TM__vYBWrr780p7faFzauVMtPg_0[0];
NTIkeyvaluepair__0bWXDvqglYSS6aTKl80IVQ_.size = sizeof(tyTuple__0bWXDvqglYSS6aTKl80IVQ);
NTIkeyvaluepair__0bWXDvqglYSS6aTKl80IVQ_.align = NIM_ALIGNOF(tyTuple__0bWXDvqglYSS6aTKl80IVQ);
NTIkeyvaluepair__0bWXDvqglYSS6aTKl80IVQ_.kind = 18;
NTIkeyvaluepair__0bWXDvqglYSS6aTKl80IVQ_.base = 0;
NTIkeyvaluepair__0bWXDvqglYSS6aTKl80IVQ_.flags = 2;
TM__vYBWrr780p7faFzauVMtPg_256_3[0] = &TM__vYBWrr780p7faFzauVMtPg_0[42];
TM__vYBWrr780p7faFzauVMtPg_0[42].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[42].offset = offsetof(tyTuple__0bWXDvqglYSS6aTKl80IVQ, Field0);
TM__vYBWrr780p7faFzauVMtPg_0[42].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__vYBWrr780p7faFzauVMtPg_0[42].name = "Field0";
TM__vYBWrr780p7faFzauVMtPg_256_3[1] = &TM__vYBWrr780p7faFzauVMtPg_0[43];
NTIindexentry__1q6h3V1uWiazOcEBnOLqyA_.size = sizeof(tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA);
NTIindexentry__1q6h3V1uWiazOcEBnOLqyA_.align = NIM_ALIGNOF(tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA);
NTIindexentry__1q6h3V1uWiazOcEBnOLqyA_.kind = 18;
NTIindexentry__1q6h3V1uWiazOcEBnOLqyA_.base = 0;
NTIindexentry__1q6h3V1uWiazOcEBnOLqyA_.flags = 2;
TM__vYBWrr780p7faFzauVMtPg_257_4[0] = &TM__vYBWrr780p7faFzauVMtPg_0[45];
TM__vYBWrr780p7faFzauVMtPg_0[45].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[45].offset = offsetof(tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA, keyword);
TM__vYBWrr780p7faFzauVMtPg_0[45].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__vYBWrr780p7faFzauVMtPg_0[45].name = "keyword";
TM__vYBWrr780p7faFzauVMtPg_257_4[1] = &TM__vYBWrr780p7faFzauVMtPg_0[46];
TM__vYBWrr780p7faFzauVMtPg_0[46].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[46].offset = offsetof(tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA, link);
TM__vYBWrr780p7faFzauVMtPg_0[46].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__vYBWrr780p7faFzauVMtPg_0[46].name = "link";
TM__vYBWrr780p7faFzauVMtPg_257_4[2] = &TM__vYBWrr780p7faFzauVMtPg_0[47];
TM__vYBWrr780p7faFzauVMtPg_0[47].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[47].offset = offsetof(tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA, linkTitle);
TM__vYBWrr780p7faFzauVMtPg_0[47].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__vYBWrr780p7faFzauVMtPg_0[47].name = "linkTitle";
TM__vYBWrr780p7faFzauVMtPg_257_4[3] = &TM__vYBWrr780p7faFzauVMtPg_0[48];
TM__vYBWrr780p7faFzauVMtPg_0[48].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[48].offset = offsetof(tyObject_IndexEntry__1q6h3V1uWiazOcEBnOLqyA, linkDesc);
TM__vYBWrr780p7faFzauVMtPg_0[48].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__vYBWrr780p7faFzauVMtPg_0[48].name = "linkDesc";
TM__vYBWrr780p7faFzauVMtPg_0[44].len = 4; TM__vYBWrr780p7faFzauVMtPg_0[44].kind = 2; TM__vYBWrr780p7faFzauVMtPg_0[44].sons = &TM__vYBWrr780p7faFzauVMtPg_257_4[0];
NTIindexentry__1q6h3V1uWiazOcEBnOLqyA_.node = &TM__vYBWrr780p7faFzauVMtPg_0[44];
TM__vYBWrr780p7faFzauVMtPg_0[43].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[43].offset = offsetof(tyTuple__0bWXDvqglYSS6aTKl80IVQ, Field1);
TM__vYBWrr780p7faFzauVMtPg_0[43].typ = (&NTIindexentry__1q6h3V1uWiazOcEBnOLqyA_);
TM__vYBWrr780p7faFzauVMtPg_0[43].name = "Field1";
TM__vYBWrr780p7faFzauVMtPg_256_3[2] = &TM__vYBWrr780p7faFzauVMtPg_0[49];
NTIseqLindexentryT__hf5PiuqqytWiEcddgIR5sQ_.size = sizeof(tySequence__hf5PiuqqytWiEcddgIR5sQ*);
NTIseqLindexentryT__hf5PiuqqytWiEcddgIR5sQ_.align = NIM_ALIGNOF(tySequence__hf5PiuqqytWiEcddgIR5sQ*);
NTIseqLindexentryT__hf5PiuqqytWiEcddgIR5sQ_.kind = 24;
NTIseqLindexentryT__hf5PiuqqytWiEcddgIR5sQ_.base = (&NTIindexentry__1q6h3V1uWiazOcEBnOLqyA_);
NTIseqLindexentryT__hf5PiuqqytWiEcddgIR5sQ_.flags = 2;
NTIseqLindexentryT__hf5PiuqqytWiEcddgIR5sQ_.marker = Marker_tySequence__hf5PiuqqytWiEcddgIR5sQ;
TM__vYBWrr780p7faFzauVMtPg_0[49].kind = 1;
TM__vYBWrr780p7faFzauVMtPg_0[49].offset = offsetof(tyTuple__0bWXDvqglYSS6aTKl80IVQ, Field2);
TM__vYBWrr780p7faFzauVMtPg_0[49].typ = (&NTIseqLindexentryT__hf5PiuqqytWiEcddgIR5sQ_);
TM__vYBWrr780p7faFzauVMtPg_0[49].name = "Field2";
TM__vYBWrr780p7faFzauVMtPg_0[41].len = 3; TM__vYBWrr780p7faFzauVMtPg_0[41].kind = 2; TM__vYBWrr780p7faFzauVMtPg_0[41].sons = &TM__vYBWrr780p7faFzauVMtPg_256_3[0];
NTIkeyvaluepair__0bWXDvqglYSS6aTKl80IVQ_.node = &TM__vYBWrr780p7faFzauVMtPg_0[41];
NTIkeyvaluepairseq__mQGg5S79bnlEvqSZ53aiYNQ_.size = sizeof(tySequence__mQGg5S79bnlEvqSZ53aiYNQ*);
NTIkeyvaluepairseq__mQGg5S79bnlEvqSZ53aiYNQ_.align = NIM_ALIGNOF(tySequence__mQGg5S79bnlEvqSZ53aiYNQ*);
NTIkeyvaluepairseq__mQGg5S79bnlEvqSZ53aiYNQ_.kind = 24;
NTIkeyvaluepairseq__mQGg5S79bnlEvqSZ53aiYNQ_.base = (&NTIkeyvaluepair__0bWXDvqglYSS6aTKl80IVQ_);
NTIkeyvaluepairseq__mQGg5S79bnlEvqSZ53aiYNQ_.flags = 2;
NTIkeyvaluepairseq__mQGg5S79bnlEvqSZ53aiYNQ_.marker = Marker_tySequence__mQGg5S79bnlEvqSZ53aiYNQ;
}

