/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tySequence__RNhZxf20g9beyq5VBOGxhDg tySequence__RNhZxf20g9beyq5VBOGxhDg;
typedef struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ;
typedef struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ tySequence__lFbCtu5P2Kf7YDYtGjkxAQ;
typedef struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA;
typedef struct tySequence__ijtae5OneaLys0hN9alAicA tySequence__ijtae5OneaLys0hN9alAicA;
typedef struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w;
typedef struct tySequence__SerjNoUujW2dUouVBrJiCw tySequence__SerjNoUujW2dUouVBrJiCw;
typedef struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyObject_Table__r0v8BdcBPKhl73K8p2VMUA;
typedef struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g tySequence__K9agbtcb0qPZuSJFXB9cTe6g;
typedef struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg;
typedef struct tySequence__m88qdML9cQOuqGAQn6XWL1A tySequence__m88qdML9cQOuqGAQn6XWL1A;
typedef struct tyObject_Table__1hIWbTQWYT4BmhdESze57A tyObject_Table__1hIWbTQWYT4BmhdESze57A;
typedef struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ tySequence__naEbXEp9b9aiW1zXJorqf9cXQ;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA;
typedef struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw;
typedef struct tySequence__ed0C0uAUZPhvw3RAc5hfYg tySequence__ed0C0uAUZPhvw3RAc5hfYg;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tyObject_Table__imojfg883tkWsWJwyshGqQ tyObject_Table__imojfg883tkWsWJwyshGqQ;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg tyObject_Table__BCPh85PHtwxox9bv7NLFrlg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA;
typedef struct tySequence__KgiZ29chkJAD01p9aLRB32qw tySequence__KgiZ29chkJAD01p9aLRB32qw;
typedef struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A tyObject_Table__LM44poVdVEn4Mo4N4L8c3A;
typedef struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw tySequence__rkYRZrbHVYL3nhXlQW3K9bw;
typedef struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ tySequence__IRFEb1e9bxgbJLuB5xrdZsQ;
typedef struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ;
typedef struct tySequence__YmPd0eWfcTfrVYrthlXPYA tySequence__YmPd0eWfcTfrVYrthlXPYA;
typedef struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q;
typedef struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg tySequence__Hz5SYwQU29b9aFLt09blvVQPg;
typedef struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg tyObject_Table__R7JnJQEipxxOlJWXQz7jWg;
typedef struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ tySequence__3G9aA9cLXaPxuRxMKm3anacQ;
typedef struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q tySequence__bPFv6ypvvCX2A9a9al8utL2Q;
typedef struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg;
typedef struct tyObject_Table__9bsFCZVRMIOwQDu3f4jLGbA tyObject_Table__9bsFCZVRMIOwQDu3f4jLGbA;
typedef struct tySequence__wuwY3G19cIPfMd9b1mDzZsNw tySequence__wuwY3G19cIPfMd9b1mDzZsNw;
typedef struct tyTuple__NR9cgWyhzHdz1XjqYbM8wVA tyTuple__NR9cgWyhzHdz1XjqYbM8wVA;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_LiftingPass__3COrF4ZRGkfAVWIFzu70AA tyObject_LiftingPass__3COrF4ZRGkfAVWIFzu70AA;
typedef struct tyObject_Table__b4JZGZzMTp9bAaQ4jWNeszQ tyObject_Table__b4JZGZzMTp9bAaQ4jWNeszQ;
typedef struct tySequence__WcRaozAFgJ6OG8h8DH4mow tySequence__WcRaozAFgJ6OG8h8DH4mow;
typedef struct tyTuple__j27tPFjtRhFKFqO9b6UrT5g tyTuple__j27tPFjtRhFKFqO9b6UrT5g;
typedef struct tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw;
typedef struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ;
typedef struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g tySequence__qeAsXh2i1GAL5Nl0g3OP8g;
typedef struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg;
typedef struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg;
typedef struct tySequence__4Murtwnm0Fyc7F9acrytEXw tySequence__4Murtwnm0Fyc7F9acrytEXw;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw;
typedef struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg tySequence__QnmOtn1Iv4LvxOXoMn8Rbg;
typedef struct tySequence__oKtVqsc9bQVCNyrijELM4OQ tySequence__oKtVqsc9bQVCNyrijELM4OQ;
typedef struct tySequence__qy6Iwdy00wN560qud54HTg tySequence__qy6Iwdy00wN560qud54HTg;
typedef struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ tySequence__k67v9bwvvQDmS1ynyGGUbeQ;
typedef struct tySequence__cLsClAAfd0MKkoBQVyvdvw tySequence__cLsClAAfd0MKkoBQVyvdvw;
typedef struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg tySequence__q9bTuOB0JXh1iZ3CSGdRLbg;
typedef struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw;
typedef struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ;
typedef struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ;
typedef struct tySequence__C3r8jsj9chA4sIlYfDN5aDw tySequence__C3r8jsj9chA4sIlYfDN5aDw;
typedef struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ;
typedef struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg tyTuple__UluY8x0Nj6cp9b0o88wJ0lg;
typedef struct tySequence__dlD6tEGzYLLpKVq3XwuFlA tySequence__dlD6tEGzYLLpKVq3XwuFlA;
typedef struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ;
typedef struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg;
typedef struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ;
typedef struct tyTuple__rZZA0skon1OsHdiEvT8RZQ tyTuple__rZZA0skon1OsHdiEvT8RZQ;
typedef struct tySequence__6OFCSvqRaxyEgUqWtnZSlw tySequence__6OFCSvqRaxyEgUqWtnZSlw;
typedef struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q;
typedef struct tySequence__UnGSk9aaLosDroi2QDrlOfQ tySequence__UnGSk9aaLosDroi2QDrlOfQ;
typedef struct tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA;
typedef struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA tyTuple__q13Zt16VkCqu6Zg5jWqwHA;
typedef struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA tyTuple__aWN9bNzF9bubXNJV9ciomgpfA;
typedef struct tySequence__m4PVWjcAAjfxlwJxLkKn8A tySequence__m4PVWjcAAjfxlwJxLkKn8A;
typedef struct tyTuple__RWXAsQlFoGYyEQZp1G65sg tyTuple__RWXAsQlFoGYyEQZp1G65sg;
typedef struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg;
typedef struct tyTuple__RmGJuqOgEaHckHndh0LEsw tyTuple__RmGJuqOgEaHckHndh0LEsw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__J4cxakKjhKxTIJR9bojMmXw tyTuple__J4cxakKjhKxTIJR9bojMmXw;
typedef struct tySequence__i89c5kdtWKzK3OEiI81pkkw tySequence__i89c5kdtWKzK3OEiI81pkkw;
typedef struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A;
typedef struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ;
typedef struct tySequence__GR8qmV1kNRcoQ2g76VFy3A tySequence__GR8qmV1kNRcoQ2g76VFy3A;
typedef struct tyTuple__a7QginWFapakKbWJBJ2vfA tyTuple__a7QginWFapakKbWJBJ2vfA;
typedef struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__kbX6x85REySUrk9auORL0vw tyTuple__kbX6x85REySUrk9auORL0vw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g;
typedef struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q;
typedef struct tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A;
typedef struct tyTuple__nF9cH4hinXgGEUwO4G2bshw tyTuple__nF9cH4hinXgGEUwO4G2bshw;
typedef struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA;
typedef struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__PsEhl3dzznmmJiLAuIXZOg tyTuple__PsEhl3dzznmmJiLAuIXZOg;
typedef struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w;
typedef struct tyTuple__Db8CrQifKGIsKc3w71w7Lw tyTuple__Db8CrQifKGIsKc3w71w7Lw;
typedef struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg;
typedef struct tySequence__lo3S1lKyiPLhGGB9cBawd6A tySequence__lo3S1lKyiPLhGGB9cBawd6A;
typedef struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ;
typedef struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw tyTuple__FEYH9alRJhHD0uTKF2vnIqw;
typedef struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA;
typedef struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA;
typedef struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw;
typedef struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg tyTuple__VUJ5Hjm4tKAResBsRHJvYg;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
typedef NU8 tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInst;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg uniqueId;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
typedef NU8 tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA {
tySequence__ijtae5OneaLys0hN9alAicA* data;
NI counter;
};
struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w {
tySequence__SerjNoUujW2dUouVBrJiCw* data;
NI counter;
};
struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA {
tySequence__K9agbtcb0qPZuSJFXB9cTe6g* data;
NI counter;
};
typedef tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyArray__46hjIasL27aUz9c7kgtWooQ[5];
struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg {
tySequence__m88qdML9cQOuqGAQn6XWL1A* data;
NI counter;
};
struct tyObject_Table__1hIWbTQWYT4BmhdESze57A {
tySequence__naEbXEp9b9aiW1zXJorqf9cXQ* data;
NI counter;
};
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
};
struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw {
NI counter;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* data;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__imojfg883tkWsWJwyshGqQ {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA {
tySequence__KgiZ29chkJAD01p9aLRB32qw* data;
NI counter;
};
struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A {
tySequence__rkYRZrbHVYL3nhXlQW3K9bw* data;
NI counter;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg[65];
struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ {
tySequence__YmPd0eWfcTfrVYrthlXPYA* data;
NI counter;
};
struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__I6rzVhdiYtUh7jwWJQoeyw) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__EQOAUyRkp9c3eeiGlHvCThA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q {
tySequence__Hz5SYwQU29b9aFLt09blvVQPg* data;
NI counter;
};
struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg {
tySequence__3G9aA9cLXaPxuRxMKm3anacQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__1CO5eEh25fBKUWGagpikwg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
typedef N_NIMCALL_PTR(void, tyProc__VcUg5jOhttLagdxUmVN8Tg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__XOkru1xuh2bHzmkw1UYzLA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formal, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* actual);
struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opNot;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opContains;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLe;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLt;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAnd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opOr;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opIsNil;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opEq;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAdd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opSub;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opMul;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opDiv;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg {
tySequence__RNhZxf20g9beyq5VBOGxhDg* ifaces;
tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* packed_0;
tySequence__lFbCtu5P2Kf7YDYtGjkxAQ* encoders;
tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA typeInstCache;
tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w procInstCache;
tyArray__46hjIasL27aUz9c7kgtWooQ attachedOps;
tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg methodsPerType;
tyObject_Table__1hIWbTQWYT4BmhdESze57A enumToStringProcs;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw emittedTypeInfo;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA startupPackedConfig;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw deps;
tyObject_Table__imojfg883tkWsWJwyshGqQ importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__BCPh85PHtwxox9bv7NLFrlg inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* usageSym;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* owners;
tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA suggestSymbols;
tyObject_Table__LM44poVdVEn4Mo4N4L8c3A suggestErrors;
tySequence__IRFEb1e9bxgbJLuB5xrdZsQ* methods;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* systemModule;
tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg sysTypes;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw compilerprocs;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw exposed;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageTypes;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* emptyNode;
tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ canonTypes;
tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw symBodyHashes;
tyProc__I6rzVhdiYtUh7jwWJQoeyw importModuleCallback;
tyProc__EQOAUyRkp9c3eeiGlHvCThA includeFileCallback;
tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q cacheSeqs;
tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g cacheCounters;
tyObject_Table__R7JnJQEipxxOlJWXQz7jWg cacheTables;
tySequence__bPFv6ypvvCX2A9a9al8utL2Q* passes;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinition;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinitionResolveForward;
tyProc__1CO5eEh25fBKUWGagpikwg onUsage;
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* globalDestructors;
tyProc__VcUg5jOhttLagdxUmVN8Tg strongSemCheck;
tyProc__XOkru1xuh2bHzmkw1UYzLA compatibleProps;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg operators;
};
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
struct tyObject_Table__9bsFCZVRMIOwQDu3f4jLGbA {
tySequence__wuwY3G19cIPfMd9b1mDzZsNw* data;
NI counter;
};
struct tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg {
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw processed;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw capturedVars;
tyObject_Table__9bsFCZVRMIOwQDu3f4jLGbA ownerToType;
NIM_BOOL somethingToDo;
tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
};
struct tyTuple__NR9cgWyhzHdz1XjqYbM8wVA {
NI Field0;
NI Field1;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* Field2;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg {
NI32 module;
NI32 symId;
NI32 typeId_0;
NIM_BOOL sealed;
};
struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg {
NI id;
NimStringDesc* s;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* next;
NI h;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg[9];
typedef NU8 tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ;
typedef NimStringDesc* tyArray__24KAM9afIUgUaqBaEBB6r9bg[3];
typedef NU8 tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg;
struct tyObject_Table__b4JZGZzMTp9bAaQ4jWNeszQ {
tySequence__WcRaozAFgJ6OG8h8DH4mow* data;
NI counter;
};
struct tyObject_LiftingPass__3COrF4ZRGkfAVWIFzu70AA {
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw processed;
tyObject_Table__b4JZGZzMTp9bAaQ4jWNeszQ envVars;
NI inContainer;
tyObject_Table__b4JZGZzMTp9bAaQ4jWNeszQ unownedEnvVars;
};
struct tyTuple__j27tPFjtRhFKFqO9b6UrT5g {
NI Field0;
NI Field1;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field2;
};
typedef tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* tyArray__Nfk9cOEzg2bRz9c1V8fGzONg[2];
typedef NU8 tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
typedef NU8 tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TSymKind__5avKs4TYFTeLPAJjwtJ4cg;
struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* converters;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* patterns;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* pureEnums;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interf;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interfHidden;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* uniqueName;
};
typedef NU8 tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg;
struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg {
tySequence__4Murtwnm0Fyc7F9acrytEXw* nodes;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ;
struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ {
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw {
tySequence__IHUFRsFxZNv7YydiUO2esQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag {
NimStringDesc* definedSymbols;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA moduleFlags;
tySequence__PXIzfWocnrafGz5p3CP5LA* includes;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* imports;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg toReplay;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg topLevel;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg bodies;
tySequence__b89aLriiJnVTD186H6zNIgg* exports;
tySequence__b89aLriiJnVTD186H6zNIgg* hidden;
tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw* reexports;
tySequence__b89aLriiJnVTD186H6zNIgg* compilerProcs;
tySequence__48JTohSgTy339bRxHzUD8KA* converters;
tySequence__48JTohSgTy339bRxHzUD8KA* methods;
tySequence__48JTohSgTy339bRxHzUD8KA* trmacros;
tySequence__48JTohSgTy339bRxHzUD8KA* pureEnums;
tySequence__QnmOtn1Iv4LvxOXoMn8Rbg* macroUsages;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* typeInstCache;
tySequence__qy6Iwdy00wN560qud54HTg* procInstCache;
tySequence__k67v9bwvvQDmS1ynyGGUbeQ* attachedOps;
tySequence__cLsClAAfd0MKkoBQVyvdvw* methodsPerType;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* enumToStringProcs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* emittedTypeInfo;
tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ backendFlags;
tySequence__q9bTuOB0JXh1iZ3CSGdRLbg* syms;
tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw* types;
tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ strings;
tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw numbers;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA cfg;
};
struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ {
tySequence__C3r8jsj9chA4sIlYfDN5aDw* data;
NI counter;
};
struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg {
tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg status;
NIM_BOOL symsInit;
NIM_BOOL typesInit;
NIM_BOOL loadedButAliveSetChanged;
tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag fromDisk;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* syms;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* types;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ iface;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ ifaceHidden;
};
struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ {
tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* data;
NI counter;
};
struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ {
NI32 thisModule;
NI32 lastFile;
NU32 lastLit;
tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ filenames;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* pendingTypes;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* pendingSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw typeMarker;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw symMarker;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
};
struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ {
NU32 module;
NI32 item;
};
struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg {
NI module;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ packed_0;
};
struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
};
struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__dlD6tEGzYLLpKVq3XwuFlA* Field2;
};
struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q {
NI module;
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg sym;
tySequence__UnGSk9aaLosDroi2QDrlOfQ* concreteTypes;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__rZZA0skon1OsHdiEvT8RZQ {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__6OFCSvqRaxyEgUqWtnZSlw* Field2;
};
struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field2;
};
struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
};
struct tyTuple__RWXAsQlFoGYyEQZp1G65sg {
NI Field0;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field1;
};
struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__m4PVWjcAAjfxlwJxLkKn8A* Field2;
};
struct tyTuple__RmGJuqOgEaHckHndh0LEsw {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field2;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
};
struct tyTuple__J4cxakKjhKxTIJR9bojMmXw {
NI Field0;
NI32 Field1;
tySequence__i89c5kdtWKzK3OEiI81pkkw* Field2;
};
struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ {
NI Field0;
NI32 Field1;
tySequence__GR8qmV1kNRcoQ2g76VFy3A* Field2;
};
struct tyTuple__a7QginWFapakKbWJBJ2vfA {
tySequence__ed0C0uAUZPhvw3RAc5hfYg* Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__kbX6x85REySUrk9auORL0vw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q {
tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A* root;
NI entries;
};
struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, tyProc__kqPx9c4py2HW6KcFMhNvxtg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__9c6qRjwy7Es8UkDTIUwAfFA) (tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__mv4BsRs5VEnhcxzV6pQU5w) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
struct tyTuple__nF9cH4hinXgGEUwO4G2bshw {
tyProc__kqPx9c4py2HW6KcFMhNvxtg Field0;
tyProc__9c6qRjwy7Es8UkDTIUwAfFA Field1;
tyProc__mv4BsRs5VEnhcxzV6pQU5w Field2;
NIM_BOOL Field3;
};
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
NU32 Field0;
NimStringDesc* Field1;
};
struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA {
NU16 line;
NI16 col;
NU32 file;
};
struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA {
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
NI32 operand;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeId_0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
};
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
NU32 Field0;
NI32 Field1;
};
struct tyTuple__PsEhl3dzznmmJiLAuIXZOg {
NU32 Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA Field1;
};
struct tyTuple__Db8CrQifKGIsKc3w71w7Lw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ key;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* concreteTypes;
};
typedef NU8 tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ;
struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ {
tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
NI Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
typedef NU8 tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ;
struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA {
tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
NU32 name;
NI32 path;
};
struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA {
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
NU32 name;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typ;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
NI32 ast;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ guard;
NI bitsize;
NI alignment;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
NU32 externalName;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw locFlags;
tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA annex;
NI32 constraint;
};
struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw {
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* types;
NI32 n;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeInst;
NI32 nonUniqueId;
};
struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg {
NI Field0;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* Field1;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* Field2;
};
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
NI Field0;
NI32 Field1;
NU32 Field2;
};
struct tySequence__wuwY3G19cIPfMd9b1mDzZsNw {
  TGenericSeq Sup;
  tyTuple__NR9cgWyhzHdz1XjqYbM8wVA data[SEQ_DECL_SIZE];
};
struct tySequence__WcRaozAFgJ6OG8h8DH4mow {
  TGenericSeq Sup;
  tyTuple__j27tPFjtRhFKFqO9b6UrT5g data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__RNhZxf20g9beyq5VBOGxhDg {
  TGenericSeq Sup;
  tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ data[SEQ_DECL_SIZE];
};
struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ {
  TGenericSeq Sup;
  tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg data[SEQ_DECL_SIZE];
};
struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ {
  TGenericSeq Sup;
  tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ data[SEQ_DECL_SIZE];
};
struct tySequence__dlD6tEGzYLLpKVq3XwuFlA {
  TGenericSeq Sup;
  tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ data[SEQ_DECL_SIZE];
};
struct tySequence__ijtae5OneaLys0hN9alAicA {
  TGenericSeq Sup;
  tyTuple__UluY8x0Nj6cp9b0o88wJ0lg data[SEQ_DECL_SIZE];
};
struct tySequence__6OFCSvqRaxyEgUqWtnZSlw {
  TGenericSeq Sup;
  tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q data[SEQ_DECL_SIZE];
};
struct tySequence__SerjNoUujW2dUouVBrJiCw {
  TGenericSeq Sup;
  tyTuple__rZZA0skon1OsHdiEvT8RZQ data[SEQ_DECL_SIZE];
};
struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g {
  TGenericSeq Sup;
  tyTuple__q13Zt16VkCqu6Zg5jWqwHA data[SEQ_DECL_SIZE];
};
struct tySequence__m4PVWjcAAjfxlwJxLkKn8A {
  TGenericSeq Sup;
  tyTuple__RWXAsQlFoGYyEQZp1G65sg data[SEQ_DECL_SIZE];
};
struct tySequence__m88qdML9cQOuqGAQn6XWL1A {
  TGenericSeq Sup;
  tyTuple__aWN9bNzF9bubXNJV9ciomgpfA data[SEQ_DECL_SIZE];
};
struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ {
  TGenericSeq Sup;
  tyTuple__RmGJuqOgEaHckHndh0LEsw data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__ed0C0uAUZPhvw3RAc5hfYg {
  TGenericSeq Sup;
  tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__i89c5kdtWKzK3OEiI81pkkw {
  TGenericSeq Sup;
  tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A data[SEQ_DECL_SIZE];
};
struct tySequence__KgiZ29chkJAD01p9aLRB32qw {
  TGenericSeq Sup;
  tyTuple__J4cxakKjhKxTIJR9bojMmXw data[SEQ_DECL_SIZE];
};
struct tySequence__GR8qmV1kNRcoQ2g76VFy3A {
  TGenericSeq Sup;
  tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* data[SEQ_DECL_SIZE];
};
struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw {
  TGenericSeq Sup;
  tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ data[SEQ_DECL_SIZE];
};
struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ {
  TGenericSeq Sup;
  tyTuple__a7QginWFapakKbWJBJ2vfA data[SEQ_DECL_SIZE];
};
struct tySequence__YmPd0eWfcTfrVYrthlXPYA {
  TGenericSeq Sup;
  tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg {
  TGenericSeq Sup;
  tyTuple__kbX6x85REySUrk9auORL0vw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ {
  TGenericSeq Sup;
  tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g data[SEQ_DECL_SIZE];
};
struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q {
  TGenericSeq Sup;
  tyTuple__nF9cH4hinXgGEUwO4G2bshw data[SEQ_DECL_SIZE];
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g {
  TGenericSeq Sup;
  tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg data[SEQ_DECL_SIZE];
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  TGenericSeq Sup;
  tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE];
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  TGenericSeq Sup;
  NU32 data[SEQ_DECL_SIZE];
};
struct tySequence__4Murtwnm0Fyc7F9acrytEXw {
  TGenericSeq Sup;
  tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA data[SEQ_DECL_SIZE];
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  TGenericSeq Sup;
  tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE];
};
struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw {
  TGenericSeq Sup;
  tyTuple__PsEhl3dzznmmJiLAuIXZOg data[SEQ_DECL_SIZE];
};
struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg {
  TGenericSeq Sup;
  tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w data[SEQ_DECL_SIZE];
};
struct tySequence__oKtVqsc9bQVCNyrijELM4OQ {
  TGenericSeq Sup;
  tyTuple__Db8CrQifKGIsKc3w71w7Lw data[SEQ_DECL_SIZE];
};
struct tySequence__qy6Iwdy00wN560qud54HTg {
  TGenericSeq Sup;
  tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg data[SEQ_DECL_SIZE];
};
struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ {
  TGenericSeq Sup;
  tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ data[SEQ_DECL_SIZE];
};
struct tySequence__cLsClAAfd0MKkoBQVyvdvw {
  TGenericSeq Sup;
  tyTuple__FEYH9alRJhHD0uTKF2vnIqw data[SEQ_DECL_SIZE];
};
struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg {
  TGenericSeq Sup;
  tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA data[SEQ_DECL_SIZE];
};
struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw {
  TGenericSeq Sup;
  tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw data[SEQ_DECL_SIZE];
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  TGenericSeq Sup;
  NI64 data[SEQ_DECL_SIZE];
};
struct tySequence__lo3S1lKyiPLhGGB9cBawd6A {
  TGenericSeq Sup;
  tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ data[SEQ_DECL_SIZE];
};
struct tySequence__C3r8jsj9chA4sIlYfDN5aDw {
  TGenericSeq Sup;
  tyTuple__VUJ5Hjm4tKAResBsRHJvYg data[SEQ_DECL_SIZE];
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  TGenericSeq Sup;
  tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE];
};
struct tySequence__UnGSk9aaLosDroi2QDrlOfQ {
  TGenericSeq Sup;
  tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg data[SEQ_DECL_SIZE];
};
static N_INLINE(NIM_BOOL, interestingVar__lambdalifting_151)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
static N_INLINE(NIM_BOOL, isGenericRoutine__ast_4647)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
static N_INLINE(NIM_BOOL, isGenericRoutine__ast_4628)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NIM_BOOL, isGenericParams__ast_4617)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, skipGenericOwner__ast_4659)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, propagateClosure__lambdalifting_5002)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* start, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* last);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void, initDetectionPass__lambdalifting_392)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fn, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* Result);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(void, initPackedSet__pureZcollectionsZintsets_16)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(void, initTable__lambdalifting_397)(NI initialSize, tyObject_Table__9bsFCZVRMIOwQDu3f4jLGbA* Result);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__wuwY3G19cIPfMd9b1mDzZsNw)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, incl__pureZcollectionsZintsets_55)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(void, detectCapturedVars__lambdalifting_1994)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* c);
N_LIB_PRIVATE N_NIMCALL(void, addClosureParam__lambdalifting_1967)(tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fn, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getEnvParam__lambdalifting_131)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* routine);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, lastSon__ast_4833)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, getEnvTypeForOwner__lambdalifting_436)(tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, getOrDefault__lambdalifting_536)(tyObject_Table__9bsFCZVRMIOwQDu3f4jLGbA t, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, newType__ast_3884)(tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg id, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner);
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextTypeId__ast_3122)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, createEnvObj__lambdalifting_56)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, createObj__lowerings_293)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NIM_BOOL final);
N_LIB_PRIVATE N_NIMCALL(void, rawAddField__lowerings_314)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* obj, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, createStateField__lambdalifting_51)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* iter, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, newSym__ast_3409)(tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw symKind, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg id, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*, getIdent__idents_152)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* ic, NimStringDesc* identifier);
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextSymId__ast_3103)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, createClosureIterStateType__lambdalifting_33)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* iter, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeI__ast_3320)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_4798)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newIntNode__ast_3711)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, NI64 intVal);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5311)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5273)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5318)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5316)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5267)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, nilOrSysInt__magicsys_8)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(void, rawAddSon__ast_4276)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* father, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* son, NIM_BOOL propagateHasAsgn);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___lambdalifting_887)(tyObject_Table__9bsFCZVRMIOwQDu3f4jLGbA* t, NI key, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* val);
N_LIB_PRIVATE N_NIMCALL(void, addHiddenParam__lambdalifting_80)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* routine, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* param);
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newSymNode__ast_3704)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInnerProc__lambdalifting_177)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__astalgo_402)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, transformBody__transf_16)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc, NIM_BOOL cache);
static N_INLINE(NIM_BOOL, interestingIterVar__lambdalifting_238)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, skipTypes__ast_3723)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kinds);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getHiddenParam__lambdalifting_106)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* routine);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, addField__lowerings_420)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* obj, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(void, markAsClosure__lambdalifting_354)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NIM_BOOL, illegalCapture__lambdalifting_166)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ, classifyViewType__typeallowed_579)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, typeToString__types_50)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg prefer);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___msgs_634)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, createUpField__lambdalifting_1944)(tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* dest, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* dep, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefined__options_2292)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* symbol);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, getEnvTypeForOwnerUp__lambdalifting_1938)(tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, lookupInRecord__astalgo_84)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* field);
N_LIB_PRIVATE N_NIMCALL(void, initLiftingPass__lambdalifting_2155)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fn, tyObject_LiftingPass__3COrF4ZRGkfAVWIFzu70AA* Result);
N_LIB_PRIVATE N_NIMCALL(void, initTable__lambdalifting_2168)(NI initialSize, tyObject_Table__b4JZGZzMTp9bAaQ4jWNeszQ* Result);
static N_NIMCALL(void, Marker_tySequence__WcRaozAFgJ6OG8h8DH4mow)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, liftCapturedVars__lambdalifting_4669)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* d, tyObject_LiftingPass__3COrF4ZRGkfAVWIFzu70AA* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, getOrDefault__lambdalifting_2344)(tyObject_Table__b4JZGZzMTp9bAaQ4jWNeszQ t, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newTree__ast_3356)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** children, NI childrenLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, rawClosureCreation__lambdalifting_3914)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* d, tyObject_LiftingPass__3COrF4ZRGkfAVWIFzu70AA* c, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, setupEnvVar__lambdalifting_2235)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* d, tyObject_LiftingPass__3COrF4ZRGkfAVWIFzu70AA* c, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newEnvVar__lambdalifting_2227)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, asOwnedRef__lambdalifting_1919)(tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___lambdalifting_2798)(tyObject_Table__b4JZGZzMTp9bAaQ4jWNeszQ* t, NI key, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* val);
N_LIB_PRIVATE N_NIMCALL(void, addVar__lowerings_63)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* v);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**, X5BX5D___lambdalifting_4030)(tyObject_Table__b4JZGZzMTp9bAaQ4jWNeszQ* t, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newCall__lambdalifting_21)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getSysSym__magicsys_16)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, copyTree__ast_4432)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newAsgnStmt__lambdalifting_192)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* le, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeI__ast_3324)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NI children);
N_LIB_PRIVATE N_NIMCALL(void, createTypeBoundOpsLL__lambdalifting_268)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* refType, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner);
N_LIB_PRIVATE N_NIMCALL(void, createTypeBoundOps__liftdestructors_47)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* orig, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, lastSon__ast_3731)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__astalgo_3489)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, indirectAccess__lowerings_616)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* b, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, getUpViaParam__lambdalifting_3896)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, rawIndirectAccess__lowerings_331)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, finishClosureCreation__lambdalifting_4325)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* d, tyObject_LiftingPass__3COrF4ZRGkfAVWIFzu70AA* c, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* res);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, X5BX5D___lambdalifting_4423)(tyObject_Table__b4JZGZzMTp9bAaQ4jWNeszQ t, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeIT__ast_3342)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, symToClosure__lambdalifting_4674)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* d, tyObject_LiftingPass__3COrF4ZRGkfAVWIFzu70AA* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, makeClosure__lambdalifting_199)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* env, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, getSysType__magicsys_60)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, skipConv__types_3661)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, closureCreationForIter__lambdalifting_4506)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* iter, tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* d, tyObject_LiftingPass__3COrF4ZRGkfAVWIFzu70AA* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, addUniqueField__lowerings_449)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* obj, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, accessViaEnvParam__lambdalifting_2197)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getFieldFromObj__lowerings_588)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* v);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, accessViaEnvVar__lambdalifting_4554)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* d, tyObject_LiftingPass__3COrF4ZRGkfAVWIFzu70AA* c);
static N_INLINE(NIM_BOOL, liftingHarmful__lambdalifting_251)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newIntTypeNode__ast_3771)(NI64 intVal, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(void, transitionToLet__ast_4407)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, transitionRoutineSymKind__ast_4394)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyEnum_TSymKind__5avKs4TYFTeLPAJjwtJ4cg kind);
N_LIB_PRIVATE TNimType NTIkeyvaluepair__NR9cgWyhzHdz1XjqYbM8wVA_;
extern TNimType NTIint__rR5Bzr1D5krxoo1NcNyeMA_;
extern TNimType NTIptype__q1v0zzhoMWrhMLs6UEp1IA_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__wuwY3G19cIPfMd9b1mDzZsNw_;
STRING_LITERAL(TM__8JPgS7d2itnucsgTch9cDzA_3, ":envP", 5);
STRING_LITERAL(TM__8JPgS7d2itnucsgTch9cDzA_4, ":state", 6);
STRING_LITERAL(TM__8JPgS7d2itnucsgTch9cDzA_5, "internal error: inconsistent environment type", 45);
STRING_LITERAL(TM__8JPgS7d2itnucsgTch9cDzA_7, "/home/runner/work/nightlies/nightlies/nim/compiler/lambdalifting.nim", 68);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__8JPgS7d2itnucsgTch9cDzA_6 = {((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_7),
((NI) 414),
((NI) 14)}
;
STRING_LITERAL(TM__8JPgS7d2itnucsgTch9cDzA_8, "internal error: could not find env param for ", 45);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__8JPgS7d2itnucsgTch9cDzA_9 = {((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_7),
((NI) 178),
((NI) 14)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__8JPgS7d2itnucsgTch9cDzA_10 = {
0x00, 0x00, 0x60, 0x00, 0x00, 0x20, 0x00, 0x00,
0x00}
;
STRING_LITERAL(TM__8JPgS7d2itnucsgTch9cDzA_11, "\'$1\' is of type <$2> which cannot be captured as it would violate memory safety, declared here: $3; using \'-d:nimNoLentIterators\' helps in some cases", 149);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__8JPgS7d2itnucsgTch9cDzA_12 = {((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_7),
((NI) 286),
((NI) 14)}
;
STRING_LITERAL(TM__8JPgS7d2itnucsgTch9cDzA_13, "illegal capture \'$1\' because \'$2\' has the calling convention: <$3>", 66);
extern TNimType NTItcallingconvention__5kpSva5OFmGFHujbio7C9cg_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__8JPgS7d2itnucsgTch9cDzA_14 = {((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_7),
((NI) 291),
((NI) 14)}
;
STRING_LITERAL(TM__8JPgS7d2itnucsgTch9cDzA_15, "nimCycleBreaker", 15);
STRING_LITERAL(TM__8JPgS7d2itnucsgTch9cDzA_16, "internal error: invalid up reference computed", 45);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__8JPgS7d2itnucsgTch9cDzA_17 = {((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_7),
((NI) 359),
((NI) 14)}
;
STRING_LITERAL(TM__8JPgS7d2itnucsgTch9cDzA_18, ":up", 3);
STRING_LITERAL(TM__8JPgS7d2itnucsgTch9cDzA_19, "internal error: up references do not agree", 42);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__8JPgS7d2itnucsgTch9cDzA_20 = {((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_7),
((NI) 365),
((NI) 16)}
;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__j27tPFjtRhFKFqO9b6UrT5g_;
extern TNimType NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__WcRaozAFgJ6OG8h8DH4mow_;
STRING_LITERAL(TM__8JPgS7d2itnucsgTch9cDzA_22, "internal error: could not determine closure type", 48);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__8JPgS7d2itnucsgTch9cDzA_23 = {((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_7),
((NI) 556),
((NI) 17)}
;
STRING_LITERAL(TM__8JPgS7d2itnucsgTch9cDzA_24, ":env", 4);
STRING_LITERAL(TM__8JPgS7d2itnucsgTch9cDzA_25, ":envAlt", 7);
STRING_LITERAL(TM__8JPgS7d2itnucsgTch9cDzA_26, "internalNew", 11);
STRING_LITERAL(TM__8JPgS7d2itnucsgTch9cDzA_27, "could not find up reference for closure iter", 44);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__8JPgS7d2itnucsgTch9cDzA_28 = {((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_7),
((NI) 571),
((NI) 16)}
;
STRING_LITERAL(TM__8JPgS7d2itnucsgTch9cDzA_29, "internal error: cannot create up reference", 42);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__8JPgS7d2itnucsgTch9cDzA_30 = {((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_7),
((NI) 626),
((NI) 16)}
;
STRING_LITERAL(TM__8JPgS7d2itnucsgTch9cDzA_31, "internal error: taking closure of closure", 41);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__8JPgS7d2itnucsgTch9cDzA_32 = {((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_7),
((NI) 217),
((NI) 16)}
;
STRING_LITERAL(TM__8JPgS7d2itnucsgTch9cDzA_33, "internal error: cannot create up reference for iter", 51);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__8JPgS7d2itnucsgTch9cDzA_34 = {((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_7),
((NI) 667),
((NI) 16)}
;
STRING_LITERAL(TM__8JPgS7d2itnucsgTch9cDzA_35, "internal error: no environment found", 36);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__8JPgS7d2itnucsgTch9cDzA_36 = {((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_7),
((NI) 712),
((NI) 18)}
;
STRING_LITERAL(TM__8JPgS7d2itnucsgTch9cDzA_37, "internal error: environment misses: ", 36);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__8JPgS7d2itnucsgTch9cDzA_38 = {((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_7),
((NI) 532),
((NI) 12)}
;
STRING_LITERAL(TM__8JPgS7d2itnucsgTch9cDzA_39, "internal error: not part of closure object type", 47);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__8JPgS7d2itnucsgTch9cDzA_40 = {((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_7),
((NI) 680),
((NI) 14)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__8JPgS7d2itnucsgTch9cDzA_41 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00,
0x00}
;
STRING_LITERAL(TM__8JPgS7d2itnucsgTch9cDzA_42, "ignored invalid for loop", 24);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__8JPgS7d2itnucsgTch9cDzA_43 = {((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_7),
((NI) 920),
((NI) 14)}
;
STRING_LITERAL(TM__8JPgS7d2itnucsgTch9cDzA_44, ":result", 7);
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5220;
static N_INLINE(NIM_BOOL, interestingVar__lambdalifting_151)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((2100008 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
	if (!(T2_)) goto LA3_;
	T2_ = !((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 3))&63U)))!=0));
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = !(((*(*s).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60) || (*(*s).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8)));
	LA4_: ;
	result = T1_;
	return result;
}
static N_INLINE(NIM_BOOL, isGenericParams__ast_4617)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = !((n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
	if (!(T1_)) goto LA2_;
	T1_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 75));
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(NIM_BOOL, isGenericRoutine__ast_4628)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = !((n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
	if (!(T2_)) goto LA3_;
	T2_ = ((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 51) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 52) || (*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159));
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = isGenericParams__ast_4617((*n)._kind_6.sons->data[((NI) 2)]);
	LA4_: ;
	result = T1_;
	return result;
}
static N_INLINE(NIM_BOOL, isGenericRoutine__ast_4647)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((520192 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
	if (!(T1_)) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T3_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 2))&63U)))!=0);
	if (T3_) goto LA4_;
	T3_ = isGenericRoutine__ast_4628((*s).ast);
	LA4_: ;
	T1_ = T3_;
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, propagateClosure__lambdalifting_5002)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* start, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* last) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* o;
	o = start;
	{
		while (1) {
			NIM_BOOL T3_;
			T3_ = (NIM_BOOL)0;
			T3_ = !((o == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
			if (!(T3_)) goto LA4_;
			T3_ = !(((*o).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6)));
			LA4_: ;
			if (!T3_) goto LA2;
			{
				if (!(o == last)) goto LA7_;
				goto LA1;
			}
			LA7_: ;
			(*(*o).typ).callConv = ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9);
			o = skipGenericOwner__ast_4659(o);
		} LA2: ;
	} LA1: ;
}
N_LIB_PRIVATE N_NIMCALL(void, semCaptureSym__lambdalifting_4999)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = interestingVar__lambdalifting_151(s);
		if (!(T3_)) goto LA4_;
		T3_ = !(((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 11)));
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			NIM_BOOL T9_;
			NIM_BOOL T11_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* o;
			T9_ = (NIM_BOOL)0;
			T9_ = !(((*owner).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
			if (!(T9_)) goto LA10_;
			T11_ = (NIM_BOOL)0;
			T11_ = isGenericRoutine__ast_4647(owner);
			T9_ = !(T11_);
			LA10_: ;
			if (!T9_) goto LA12_;
			o = skipGenericOwner__ast_4659(owner);
			{
				while (1) {
					NIM_BOOL T16_;
					T16_ = (NIM_BOOL)0;
					T16_ = !((o == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
					if (!(T16_)) goto LA17_;
					T16_ = !(((*o).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6)));
					LA17_: ;
					if (!T16_) goto LA15;
					{
						if (!((*s).owner == o)) goto LA20_;
						{
							NIM_BOOL T24_;
							NIM_BOOL T25_;
							NIM_BOOL T28_;
							tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T32_;
							T24_ = (NIM_BOOL)0;
							T25_ = (NIM_BOOL)0;
							T25_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
							if (T25_) goto LA26_;
							T25_ = ((*owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 15));
							LA26_: ;
							T24_ = T25_;
							if (T24_) goto LA27_;
							T28_ = (NIM_BOOL)0;
							T28_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 0));
							if (!(T28_)) goto LA29_;
							T28_ = !((((*(*owner).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 42))&63U)))!=0));
							LA29_: ;
							T24_ = T28_;
							LA27_: ;
							if (!T24_) goto LA30_;
							(*(*owner).typ).callConv = ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9);
							T32_ = NIM_NIL;
							T32_ = skipGenericOwner__ast_4659(owner);
							propagateClosure__lambdalifting_5002(T32_, (*s).owner);
						}
						goto LA22_;
						LA30_: ;
						{
						}
						LA22_: ;
					}
					LA20_: ;
					o = skipGenericOwner__ast_4659(o);
				} LA15: ;
			}
		}
		LA12_: ;
	}
	LA5_: ;
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result) {
	initPackedSet__pureZcollectionsZintsets_16(Result);
}
static N_NIMCALL(void, Marker_tySequence__wuwY3G19cIPfMd9b1mDzZsNw)(void* p, NI op) {
	tySequence__wuwY3G19cIPfMd9b1mDzZsNw* a;
	NI T1_;
	a = (tySequence__wuwY3G19cIPfMd9b1mDzZsNw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field2, op);
	}
}
N_LIB_PRIVATE N_NIMCALL(void, initDetectionPass__lambdalifting_392)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fn, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* Result) {
	NI T1_;
	NI T2_;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym50_;
	(*Result).processed.elems = 0;
	(*Result).processed.counter = 0;
	(*Result).processed.max = 0;
	unsureAsgnRef((void**)&(*Result).processed.head, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).processed.data, NIM_NIL);
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < 34; T1_++) {
	(*Result).processed.a[T1_] = 0;
	}
	(*Result).capturedVars.elems = 0;
	(*Result).capturedVars.counter = 0;
	(*Result).capturedVars.max = 0;
	unsureAsgnRef((void**)&(*Result).capturedVars.head, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).capturedVars.data, NIM_NIL);
	T2_ = (NI)0;
	for (T2_ = 0; T2_ < 34; T2_++) {
	(*Result).capturedVars.a[T2_] = 0;
	}
	unsureAsgnRef((void**)&(*Result).ownerToType.data, NIM_NIL);
	(*Result).ownerToType.counter = 0;
	(*Result).somethingToDo = 0;
	unsureAsgnRef((void**)&(*Result).graph, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).idgen, NIM_NIL);
	initIntSet__pureZcollectionsZintsets_238((&(*Result).processed));
	initIntSet__pureZcollectionsZintsets_238((&(*Result).capturedVars));
	initTable__lambdalifting_397(((NI) 32), (&(*Result).ownerToType));
	xX60gensym50_ = fn;
	incl__pureZcollectionsZintsets_55((&(*Result).processed), (NI)((NI)((NU64)(((NI) ((*xX60gensym50_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym50_).Sup.itemId.item))));
	unsureAsgnRef((void**) (&(*Result).graph), g);
	unsureAsgnRef((void**) (&(*Result).idgen), idgen);
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getEnvParam__lambdalifting_131)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* routine) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* params;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* hidden;
	result = NIM_NIL;
	params = (*(*routine).ast)._kind_6.sons->data[((NI) 3)];
	hidden = lastSon__ast_4833(params);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*hidden).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		if (!(T3_)) goto LA4_;
		T3_ = eqStrings((*(*(*hidden)._kind_4.sym).name).s, ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_3));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = (*hidden)._kind_4.sym;
	}
	LA5_: ;
	return result;
}
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextTypeId__ast_3122)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x) {
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*x).typeId_0 += ((NI) 1);
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	result.module = (*x).module;
	result.item = (*x).typeId_0;
	return result;
}
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextSymId__ast_3103)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x) {
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*x).symId += ((NI) 1);
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	result.module = (*x).module;
	result.item = (*x).symId;
	return result;
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5311)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5273)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5316)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5267((&gch__system_5220.zct), c);
}
static N_INLINE(void, decRef__system_5318)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5316(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5273(src);
		incRef__system_5311(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5273((*dest));
		decRef__system_5318(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, createClosureIterStateType__lambdalifting_33)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* iter, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T1_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T2_;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T3_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* intType;
	result = NIM_NIL;
	n = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 44), (*iter).info);
	T1_ = NIM_NIL;
	T1_ = newIntNode__ast_3711(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6), IL64(-1));
	add__ast_4798(n, T1_);
	T2_ = NIM_NIL;
	T2_ = newIntNode__ast_3711(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6), IL64(0));
	add__ast_4798(n, T2_);
	T3_ = nextTypeId__ast_3122(idgen);
	result = newType__ast_3884(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 20), T3_, iter);
	asgnRef((void**) (&(*result).n), n);
	intType = nilOrSysInt__magicsys_8(g);
	{
		tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T8_;
		if (!(intType == 0)) goto LA6_;
		T8_ = nextTypeId__ast_3122(idgen);
		intType = newType__ast_3884(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31), T8_, iter);
	}
	LA6_: ;
	rawAddSon__ast_4276(result, intType, NIM_TRUE);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, createStateField__lambdalifting_51)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* iter, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T1_;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T2_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = getIdent__idents_152((*g).cache, ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_4));
	T2_ = nextSymId__ast_3103(idgen);
	result = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19), T1_, T2_, iter, (*iter).info, 0);
	asgnRef((void**) (&(*result).typ), createClosureIterStateType__lambdalifting_33(g, iter, idgen));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, createEnvObj__lambdalifting_56)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T1_;
	result = NIM_NIL;
	result = createObj__lowerings_293(g, idgen, owner, info, NIM_FALSE);
	T1_ = NIM_NIL;
	T1_ = createStateField__lambdalifting_51(g, owner, idgen);
	rawAddField__lowerings_314(result, T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, getEnvTypeForOwner__lambdalifting_436)(tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym51_;
	result = NIM_NIL;
	xX60gensym51_ = owner;
	result = getOrDefault__lambdalifting_536((*c).ownerToType, (NI)((NI)((NU64)(((NI) ((*xX60gensym51_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym51_).Sup.itemId.item))));
	{
		tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T5_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* obj;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym56_;
		if (!(result == 0)) goto LA3_;
		T5_ = nextTypeId__ast_3122((*c).idgen);
		result = newType__ast_3884(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22), T5_, owner);
		obj = createEnvObj__lambdalifting_56((*c).graph, (*c).idgen, owner, info);
		rawAddSon__ast_4276(result, obj, NIM_TRUE);
		xX60gensym56_ = owner;
		X5BX5Deq___lambdalifting_887((&(*c).ownerToType), (NI)((NI)((NU64)(((NI) ((*xX60gensym56_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym56_).Sup.itemId.item))), result);
	}
	LA3_: ;
	return result;
}
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addHiddenParam__lambdalifting_80)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* routine, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* param) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* params;
	NI T1_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T2_;
	params = (*(*routine).ast)._kind_6.sons->data[((NI) 3)];
	T1_ = (NI)0;
	T1_ = len__ast_3155((*(*routine).typ).n);
	(*param).position = (NI)(T1_ - ((NI) 1));
	T2_ = NIM_NIL;
	T2_ = newSymNode__ast_3704(param);
	add__ast_4798(params, T2_);
}
N_LIB_PRIVATE N_NIMCALL(void, addClosureParam__lambdalifting_1967)(tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fn, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* cp;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	cp = getEnvParam__lambdalifting_131(fn);
	{
		if (!((*fn).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 15))) goto LA3_;
		owner = fn;
	}
	goto LA1_;
	LA3_: ;
	{
		owner = skipGenericOwner__ast_4659(fn);
	}
	LA1_: ;
	t = getEnvTypeForOwner__lambdalifting_436(c, owner, info);
	{
		tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T10_;
		tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T11_;
		if (!(cp == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA8_;
		T10_ = NIM_NIL;
		T10_ = getIdent__idents_152((*(*c).graph).cache, ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_3));
		T11_ = nextSymId__ast_3103((*c).idgen);
		cp = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3), T10_, T11_, fn, (*fn).info, 0);
		(*cp).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 2)) & 63);
		asgnRef((void**) (&(*cp).typ), t);
		addHiddenParam__lambdalifting_80(fn, cp);
	}
	goto LA6_;
	LA8_: ;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = !(((*cp).typ == t));
		if (!(T13_)) goto LA14_;
		T13_ = !(((*fn).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 15)));
		LA14_: ;
		if (!T13_) goto LA15_;
		liMessage__msgs_1128((*(*c).graph).config, (*fn).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_5), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__8JPgS7d2itnucsgTch9cDzA_6, NIM_FALSE);
	}
	goto LA6_;
	LA15_: ;
	LA6_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInnerProc__lambdalifting_177)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((126976 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
		if (!(T3_)) goto LA4_;
		T3_ = ((*s).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 0));
		LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = NIM_NIL;
		T7_ = skipGenericOwner__ast_4659(s);
		result = ((520192 &((NU32)1<<((NU)((*T7_).kind)&31U)))!=0);
	}
	LA5_: ;
	return result;
}
static N_INLINE(NIM_BOOL, interestingIterVar__lambdalifting_238)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((2100000 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
	if (!(T1_)) goto LA2_;
	T1_ = !((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 3))&63U)))!=0));
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getHiddenParam__lambdalifting_106)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* routine) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* params;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* hidden;
	result = NIM_NIL;
	params = (*(*routine).ast)._kind_6.sons->data[((NI) 3)];
	hidden = lastSon__ast_4833(params);
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*hidden).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		if (!(T4_)) goto LA5_;
		T4_ = ((*(*hidden)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA6_;
		T3_ = eqStrings((*(*(*hidden)._kind_4.sym).name).s, ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_3));
		LA6_: ;
		if (!T3_) goto LA7_;
		result = (*hidden)._kind_4.sym;
	}
	goto LA1_;
	LA7_: ;
	{
		NimStringDesc* T10_;
		T10_ = NIM_NIL;
		T10_ = rawNewString(((*(*routine).name).s ? (*(*routine).name).s->Sup.len : 0) + 45);
appendString(T10_, ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_8));
appendString(T10_, (*(*routine).name).s);
		liMessage__msgs_1128((*g).config, (*routine).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T10_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__8JPgS7d2itnucsgTch9cDzA_9, NIM_FALSE);
		result = routine;
	}
	LA1_: ;
	return result;
}
static N_INLINE(NIM_BOOL, illegalCapture__lambdalifting_166)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ)0;
	T2_ = classifyViewType__typeallowed_579((*s).typ);
	T1_ = !((T2_ == ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 0)));
	if (T1_) goto LA3_;
	T1_ = ((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 11));
	LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, markAsClosure__lambdalifting_354)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
	s = (*n)._kind_4.sym;
	{
		NIM_BOOL T3_;
		tyArray__24KAM9afIUgUaqBaEBB6r9bg T6_;
		NimStringDesc* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = illegalCapture__lambdalifting_166(s);
		if (!T3_) goto LA4_;
		nimZeroMem((void*)T6_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
		T6_[0] = copyString((*(*s).name).s);
		T6_[1] = typeToString__types_50((*s).typ, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
		T6_[2] = dollar___msgs_634((*g).config, (*s).info);
		T7_ = NIM_NIL;
		T7_ = nsuFormatOpenArray(((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_11), T6_, 3);
		liMessage__msgs_1128((*g).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T7_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__8JPgS7d2itnucsgTch9cDzA_12, NIM_FALSE);
	}
	goto LA1_;
	LA4_: ;
	{
		NIM_BOOL T9_;
		NIM_BOOL T11_;
		tyArray__24KAM9afIUgUaqBaEBB6r9bg T15_;
		NimStringDesc* T16_;
		T9_ = (NIM_BOOL)0;
		T9_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
		if (T9_) goto LA10_;
		T11_ = (NIM_BOOL)0;
		T11_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 0));
		if (!(T11_)) goto LA12_;
		T11_ = !((((*(*owner).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 42))&63U)))!=0));
		LA12_: ;
		T9_ = T11_;
		LA10_: ;
		if (!!(T9_)) goto LA13_;
		nimZeroMem((void*)T15_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
		T15_[0] = copyString((*(*s).name).s);
		T15_[1] = copyString((*(*owner).name).s);
		T15_[2] = reprEnum((NI)(*(*owner).typ).callConv, (&NTItcallingconvention__5kpSva5OFmGFHujbio7C9cg_));
		T16_ = NIM_NIL;
		T16_ = nsuFormatOpenArray(((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_13), T15_, 3);
		liMessage__msgs_1128((*g).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T16_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__8JPgS7d2itnucsgTch9cDzA_14, NIM_FALSE);
	}
	goto LA1_;
	LA13_: ;
	LA1_: ;
	(*(*owner).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 12)) & 63);
	(*(*owner).typ).callConv = ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, getEnvTypeForOwnerUp__lambdalifting_1938)(tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* r;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T1_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T2_;
	result = NIM_NIL;
	r = getEnvTypeForOwner__lambdalifting_436(c, owner, info);
	T1_ = nextTypeId__ast_3122((*c).idgen);
	result = newType__ast_3884(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21), T1_, owner);
	T2_ = NIM_NIL;
	T2_ = skipTypes__ast_3723(r, TM__8JPgS7d2itnucsgTch9cDzA_10);
	rawAddSon__ast_4276(result, T2_, NIM_TRUE);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, createUpField__lambdalifting_1944)(tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* dest, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* dep, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* refObj;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* obj;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* fieldType;
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* upIdent;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* upField;
	refObj = getEnvTypeForOwner__lambdalifting_436(c, dest, info);
	obj = skipTypes__ast_3723(refObj, TM__8JPgS7d2itnucsgTch9cDzA_10);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isDefined__options_2292((*(*c).graph).config, ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_15));
		if (!T3_) goto LA4_;
		fieldType = getEnvTypeForOwnerUp__lambdalifting_1938(c, dep, info);
	}
	goto LA1_;
	LA4_: ;
	{
		fieldType = getEnvTypeForOwner__lambdalifting_436(c, dep, info);
	}
	LA1_: ;
	{
		if (!(refObj == fieldType)) goto LA9_;
		liMessage__msgs_1128((*(*c).graph).config, (*dep).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_16), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__8JPgS7d2itnucsgTch9cDzA_17, NIM_FALSE);
	}
	LA9_: ;
	upIdent = getIdent__idents_152((*(*c).graph).cache, ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_18));
	upField = lookupInRecord__astalgo_84((*obj).n, upIdent);
	{
		if (!!((upField == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA13_;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T17_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T18_;
			T17_ = NIM_NIL;
			T17_ = skipTypes__ast_3723((*upField).typ, TM__8JPgS7d2itnucsgTch9cDzA_10);
			T18_ = NIM_NIL;
			T18_ = skipTypes__ast_3723(fieldType, TM__8JPgS7d2itnucsgTch9cDzA_10);
			if (!!((T17_ == T18_))) goto LA19_;
			liMessage__msgs_1128((*(*c).graph).config, (*dep).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_19), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__8JPgS7d2itnucsgTch9cDzA_20, NIM_FALSE);
		}
		LA19_: ;
	}
	goto LA11_;
	LA13_: ;
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
		tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T22_;
		T22_ = nextSymId__ast_3103((*c).idgen);
		result = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19), upIdent, T22_, (*obj).owner, (*(*obj).owner).info, 0);
		asgnRef((void**) (&(*result).typ), fieldType);
		rawAddField__lowerings_314(obj, result);
	}
	LA11_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, detectCapturedVars__lambdalifting_1994)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* c) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
		NIM_BOOL innerProc;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* ow;
		s = (*n)._kind_4.sym;
		{
			NIM_BOOL T4_;
			NIM_BOOL T5_;
			T4_ = (NIM_BOOL)0;
			T5_ = (NIM_BOOL)0;
			T5_ = ((126976 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
			if (!(T5_)) goto LA6_;
			T5_ = !(((*s).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
			LA6_: ;
			T4_ = T5_;
			if (!(T4_)) goto LA7_;
			T4_ = ((*(*s).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
			LA7_: ;
			if (!T4_) goto LA8_;
			addClosureParam__lambdalifting_1967(c, s, (*n).info);
			(*c).somethingToDo = NIM_TRUE;
		}
		LA8_: ;
		innerProc = isInnerProc__lambdalifting_177(s);
		{
			if (!innerProc) goto LA12_;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = ((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 15));
				if (!(T16_)) goto LA17_;
				T16_ = ((*(*s).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
				LA17_: ;
				if (!T16_) goto LA18_;
				(*c).somethingToDo = NIM_TRUE;
			}
			LA18_: ;
			{
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym85_;
				NIM_BOOL T22_;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body;
				xX60gensym85_ = s;
				T22_ = (NIM_BOOL)0;
				T22_ = containsOrIncl__astalgo_402((&(*c).processed), (NI)((NI)((NU64)(((NI) ((*xX60gensym85_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym85_).Sup.itemId.item))));
				if (!!(T22_)) goto LA23_;
				body = transformBody__transf_16((*c).graph, (*c).idgen, s, NIM_TRUE);
				detectCapturedVars__lambdalifting_1994(body, s, c);
			}
			LA23_: ;
		}
		LA12_: ;
		ow = skipGenericOwner__ast_4659(s);
		{
			if (!(ow == owner)) goto LA27_;
			{
				NIM_BOOL T31_;
				T31_ = (NIM_BOOL)0;
				T31_ = ((*owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 15));
				if (!(T31_)) goto LA32_;
				T31_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
				LA32_: ;
				if (!T31_) goto LA33_;
				(*c).somethingToDo = NIM_TRUE;
				addClosureParam__lambdalifting_1967(c, owner, (*n).info);
				{
					NIM_BOOL T37_;
					T37_ = (NIM_BOOL)0;
					T37_ = interestingIterVar__lambdalifting_238(s);
					if (!T37_) goto LA38_;
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym87_;
						NIM_BOOL T42_;
						tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* obj;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T45_;
						xX60gensym87_ = s;
						T42_ = (NIM_BOOL)0;
						T42_ = containsOrIncl__astalgo_402((&(*c).capturedVars), (NI)((NI)((NU64)(((NI) ((*xX60gensym87_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym87_).Sup.itemId.item))));
						if (!!(T42_)) goto LA43_;
						T45_ = NIM_NIL;
						T45_ = getHiddenParam__lambdalifting_106((*c).graph, owner);
						obj = skipTypes__ast_3723((*T45_).typ, TM__8JPgS7d2itnucsgTch9cDzA_10);
						{
							tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T48_;
							tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T51_;
							T48_ = NIM_NIL;
							T48_ = getIdent__idents_152((*(*c).graph).cache, ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_4));
							if (!((*(*s).name).id == (*T48_).id)) goto LA49_;
							nimZeroMem((void*)(&T51_), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
							T51_.module = (*s).Sup.itemId.module;
							T51_.item = ((NI32)-((*s).Sup.itemId.item));
							(*(*(*(*obj).n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).Sup.itemId = T51_;
						}
						goto LA46_;
						LA49_: ;
						{
							tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T53_;
							T53_ = NIM_NIL;
							T53_ = addField__lowerings_420(obj, s, (*(*c).graph).cache, (*c).idgen);
							(void)(T53_);
						}
						LA46_: ;
					}
					LA43_: ;
				}
				LA38_: ;
			}
			LA33_: ;
		}
		goto LA25_;
		LA27_: ;
		{
			NIM_BOOL T55_;
			NIM_BOOL T56_;
			NIM_BOOL T57_;
			NIM_BOOL T59_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* w;
			T55_ = (NIM_BOOL)0;
			T56_ = (NIM_BOOL)0;
			T57_ = (NIM_BOOL)0;
			T57_ = innerProc;
			if (!(T57_)) goto LA58_;
			T59_ = (NIM_BOOL)0;
			T59_ = ((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 15));
			if (!(T59_)) goto LA60_;
			T59_ = ((*(*s).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
			LA60_: ;
			T57_ = !(T59_);
			LA58_: ;
			T56_ = T57_;
			if (!(T56_)) goto LA61_;
			T56_ = ((*(*s).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
			LA61_: ;
			T55_ = T56_;
			if (T55_) goto LA62_;
			T55_ = interestingVar__lambdalifting_151(s);
			LA62_: ;
			if (!T55_) goto LA63_;
			(*c).somethingToDo = NIM_TRUE;
			markAsClosure__lambdalifting_354((*c).graph, owner, n);
			addClosureParam__lambdalifting_1967(c, owner, (*n).info);
			{
				NIM_BOOL T67_;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym90_;
				NIM_BOOL T69_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* obj_2;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T72_;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T73_;
				T67_ = (NIM_BOOL)0;
				T67_ = interestingVar__lambdalifting_151(s);
				if (!(T67_)) goto LA68_;
				xX60gensym90_ = s;
				T69_ = (NIM_BOOL)0;
				T69_ = containsOrIncl__astalgo_402((&(*c).capturedVars), (NI)((NI)((NU64)(((NI) ((*xX60gensym90_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym90_).Sup.itemId.item))));
				T67_ = !(T69_);
				LA68_: ;
				if (!T67_) goto LA70_;
				T72_ = NIM_NIL;
				T72_ = getEnvTypeForOwner__lambdalifting_436(c, ow, (*n).info);
				obj_2 = skipTypes__ast_3723(T72_, TM__8JPgS7d2itnucsgTch9cDzA_10);
				T73_ = NIM_NIL;
				T73_ = addField__lowerings_420(obj_2, s, (*(*c).graph).cache, (*c).idgen);
				(void)(T73_);
			}
			LA70_: ;
			w = skipGenericOwner__ast_4659(owner);
			{
				NIM_BOOL T76_;
				NIM_BOOL T78_;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* last;
				T76_ = (NIM_BOOL)0;
				T76_ = isInnerProc__lambdalifting_177(w);
				if (T76_) goto LA77_;
				T78_ = (NIM_BOOL)0;
				T78_ = ((*owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 15));
				if (!(T78_)) goto LA79_;
				T78_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
				LA79_: ;
				T76_ = T78_;
				LA77_: ;
				if (!T76_) goto LA80_;
				{
					NIM_BOOL T84_;
					T84_ = (NIM_BOOL)0;
					T84_ = ((*owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 15));
					if (!(T84_)) goto LA85_;
					T84_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
					LA85_: ;
					if (!T84_) goto LA86_;
					w = owner;
				}
				LA86_: ;
				{
					NIM_BOOL T90_;
					T90_ = (NIM_BOOL)0;
					T90_ = ((*ow).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 15));
					if (!(T90_)) goto LA91_;
					T90_ = ((*(*ow).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
					LA91_: ;
					if (!T90_) goto LA92_;
					last = skipGenericOwner__ast_4659(ow);
				}
				goto LA88_;
				LA92_: ;
				{
					last = ow;
				}
				LA88_: ;
				{
					while (1) {
						NIM_BOOL T97_;
						NIM_BOOL T98_;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* up;
						T97_ = (NIM_BOOL)0;
						T98_ = (NIM_BOOL)0;
						T98_ = !((w == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
						if (!(T98_)) goto LA99_;
						T98_ = !(((*w).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6)));
						LA99_: ;
						T97_ = T98_;
						if (!(T97_)) goto LA100_;
						T97_ = !((last == w));
						LA100_: ;
						if (!T97_) goto LA96;
						up = skipGenericOwner__ast_4659(w);
						markAsClosure__lambdalifting_354((*c).graph, w, n);
						addClosureParam__lambdalifting_1967(c, w, (*n).info);
						createUpField__lambdalifting_1944(c, w, up, (*n).info);
						w = up;
					} LA96: ;
				}
			}
			LA80_: ;
		}
		goto LA25_;
		LA63_: ;
		LA25_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 4) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 83):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 98):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 80):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 81):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 82):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 125):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 132):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 123):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 122):
	{
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 51) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 52):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84):
	{
		{
			if (!!(((*n).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA105_;
			detectCapturedVars__lambdalifting_1994((*n)._kind_6.sons->data[((NI) 0)], owner, c);
		}
		LA105_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 109):
	{
		detectCapturedVars__lambdalifting_1994((*n)._kind_6.sons->data[((NI) 0)], owner, c);
	}
	break;
	default:
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA111;
					i = i_2;
					detectCapturedVars__lambdalifting_1994((*n)._kind_6.sons->data[i], owner, c);
					i_2 += ((NI) 1);
				} LA111: ;
			}
		}
	}
	break;
	}
}
static N_NIMCALL(void, Marker_tySequence__WcRaozAFgJ6OG8h8DH4mow)(void* p, NI op) {
	tySequence__WcRaozAFgJ6OG8h8DH4mow* a;
	NI T1_;
	a = (tySequence__WcRaozAFgJ6OG8h8DH4mow*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field2, op);
	}
}
N_LIB_PRIVATE N_NIMCALL(void, initLiftingPass__lambdalifting_2155)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fn, tyObject_LiftingPass__3COrF4ZRGkfAVWIFzu70AA* Result) {
	NI T1_;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym101_;
	(*Result).processed.elems = 0;
	(*Result).processed.counter = 0;
	(*Result).processed.max = 0;
	unsureAsgnRef((void**)&(*Result).processed.head, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).processed.data, NIM_NIL);
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < 34; T1_++) {
	(*Result).processed.a[T1_] = 0;
	}
	unsureAsgnRef((void**)&(*Result).envVars.data, NIM_NIL);
	(*Result).envVars.counter = 0;
	(*Result).inContainer = 0;
	unsureAsgnRef((void**)&(*Result).unownedEnvVars.data, NIM_NIL);
	(*Result).unownedEnvVars.counter = 0;
	initIntSet__pureZcollectionsZintsets_238((&(*Result).processed));
	xX60gensym101_ = fn;
	incl__pureZcollectionsZintsets_55((&(*Result).processed), (NI)((NI)((NU64)(((NI) ((*xX60gensym101_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym101_).Sup.itemId.item))));
	initTable__lambdalifting_2168(((NI) 32), (&(*Result).envVars));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newEnvVar__lambdalifting_2227)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* v;
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T1_;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T2_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = getIdent__idents_152(cache, ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_24));
	T2_ = nextSymId__ast_3103(idgen);
	v = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8), T1_, T2_, owner, info, 0);
	(*v).flags = IL64(549789368320);
	asgnRef((void**) (&(*v).typ), typ);
	result = newSymNode__ast_3704(v);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, asOwnedRef__lambdalifting_1919)(tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	result = NIM_NIL;
	{
		tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T5_;
		if (!(((*(*(*c).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 42))&63U)))!=0)) goto LA3_;
		T5_ = nextTypeId__ast_3122((*c).idgen);
		result = newType__ast_3884(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45), T5_, (*t).owner);
		(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 4)) & 63);
		rawAddSon__ast_4276(result, t, NIM_TRUE);
	}
	goto LA1_;
	LA3_: ;
	{
		result = t;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, setupEnvVar__lambdalifting_2235)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* d, tyObject_LiftingPass__3COrF4ZRGkfAVWIFzu70AA* c, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym111_;
{	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 15));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
		LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = NIM_NIL;
		T7_ = getHiddenParam__lambdalifting_106((*d).graph, owner);
		result = newSymNode__ast_3704(T7_);
		goto BeforeRet_;
	}
	LA5_: ;
	xX60gensym111_ = owner;
	result = getOrDefault__lambdalifting_2344((*c).envVars, (NI)((NI)((NU64)(((NI) ((*xX60gensym111_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym111_).Sup.itemId.item))));
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* envVarType;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym116_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T16_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym119_;
		if (!(result == 0)) goto LA10_;
		xX60gensym116_ = owner;
		envVarType = getOrDefault__lambdalifting_536((*d).ownerToType, (NI)((NI)((NU64)(((NI) ((*xX60gensym116_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym116_).Sup.itemId.item))));
		{
			if (!(envVarType == 0)) goto LA14_;
			liMessage__msgs_1128((*(*d).graph).config, (*owner).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_22), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__8JPgS7d2itnucsgTch9cDzA_23, NIM_FALSE);
		}
		LA14_: ;
		T16_ = NIM_NIL;
		T16_ = asOwnedRef__lambdalifting_1919(d, envVarType);
		result = newEnvVar__lambdalifting_2227((*(*d).graph).cache, owner, T16_, info, (*d).idgen);
		xX60gensym119_ = owner;
		X5BX5Deq___lambdalifting_2798((&(*c).envVars), (NI)((NI)((NU64)(((NI) ((*xX60gensym119_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym119_).Sup.itemId.item))), result);
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* v;
			tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T21_;
			tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T22_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym133_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T23_;
			if (!(((*(*(*d).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 42))&63U)))!=0)) goto LA19_;
			T21_ = NIM_NIL;
			T21_ = getIdent__idents_152((*(*d).graph).cache, ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_25));
			T22_ = nextSymId__ast_3103((*d).idgen);
			v = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8), T21_, T22_, owner, info, 0);
			(*v).flags = IL64(549789368320);
			asgnRef((void**) (&(*v).typ), envVarType);
			xX60gensym133_ = owner;
			T23_ = NIM_NIL;
			T23_ = newSymNode__ast_3704(v);
			X5BX5Deq___lambdalifting_2798((&(*c).unownedEnvVars), (NI)((NI)((NU64)(((NI) ((*xX60gensym133_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym133_).Sup.itemId.item))), T23_);
		}
		LA19_: ;
	}
	LA10_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newCall__lambdalifting_21)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T1_;
	result = NIM_NIL;
	result = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27), (*a).info);
	T1_ = NIM_NIL;
	T1_ = newSymNode__ast_3704(a);
	add__ast_4798(result, T1_);
	add__ast_4798(result, b);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newAsgnStmt__lambdalifting_192)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* le, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = newNodeI__ast_3324(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 73), info, ((NI) 2));
	asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), le);
	asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), ri);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, createTypeBoundOpsLL__lambdalifting_268)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* refType, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner) {
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T5_;
		if (!!(((*owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 17)))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = lastSon__ast_3731(refType);
		createTypeBoundOps__liftdestructors_47(g, ((tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw*) NIM_NIL), T5_, info, idgen);
		createTypeBoundOps__liftdestructors_47(g, ((tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw*) NIM_NIL), refType, info, idgen);
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = (((*refType).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 31))&63U)))!=0);
			if (T8_) goto LA9_;
			T8_ = (((*(*g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0);
			LA9_: ;
			if (!T8_) goto LA10_;
			(*owner).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 42)) & 63);
		}
		LA10_: ;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, getUpViaParam__lambdalifting_3896)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* p;
	result = NIM_NIL;
	p = getHiddenParam__lambdalifting_106(g, owner);
	result = newSymNode__ast_3704(p);
	{
		NIM_BOOL T3_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* upField;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T7_;
		tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 15));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
		LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = NIM_NIL;
		T7_ = skipTypes__ast_3723((*p).typ, TM__8JPgS7d2itnucsgTch9cDzA_10);
		T8_ = NIM_NIL;
		T8_ = getIdent__idents_152((*g).cache, ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_18));
		upField = lookupInRecord__astalgo_84((*T7_).n, T8_);
		{
			if (!(upField == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA11_;
			liMessage__msgs_1128((*g).config, (*owner).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_27), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__8JPgS7d2itnucsgTch9cDzA_28, NIM_FALSE);
		}
		goto LA9_;
		LA11_: ;
		{
			result = rawIndirectAccess__lowerings_331(result, upField, (*p).info);
		}
		LA9_: ;
	}
	LA5_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, rawClosureCreation__lambdalifting_3914)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* d, tyObject_LiftingPass__3COrF4ZRGkfAVWIFzu70AA* c, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* env;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* upField;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T46_;
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T47_;
	result = NIM_NIL;
	result = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115), (*owner).info);
	env = NIM_NIL;
	{
		NIM_BOOL T3_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 15));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
		LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = NIM_NIL;
		T7_ = getHiddenParam__lambdalifting_106((*d).graph, owner);
		env = newSymNode__ast_3704(T7_);
	}
	goto LA1_;
	LA5_: ;
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T18_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T19_;
		env = setupEnvVar__lambdalifting_2235(owner, d, c, info);
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* v;
			if (!((*env).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA11_;
			v = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 99), (*env).info);
			addVar__lowerings_63(v, env);
			add__ast_4798(result, v);
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* unowned;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym139_;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** T17_;
				if (!(((*(*(*d).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 42))&63U)))!=0)) goto LA15_;
				xX60gensym139_ = owner;
				T17_ = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
				T17_ = X5BX5D___lambdalifting_4030((&(*c).unownedEnvVars), (NI)((NI)((NU64)(((NI) ((*xX60gensym139_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym139_).Sup.itemId.item))));
				unowned = (*T17_);
				addVar__lowerings_63(v, unowned);
			}
			LA15_: ;
		}
		LA11_: ;
		T18_ = NIM_NIL;
		T18_ = getSysSym__magicsys_16((*d).graph, (*env).info, ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_26));
		T19_ = NIM_NIL;
		T19_ = newCall__lambdalifting_21(T18_, env);
		add__ast_4798(result, T19_);
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* unowned_2;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym144_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** T24_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* env2;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T25_;
			if (!(((*(*(*d).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 42))&63U)))!=0)) goto LA22_;
			xX60gensym144_ = owner;
			T24_ = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
			T24_ = X5BX5D___lambdalifting_4030((&(*c).unownedEnvVars), (NI)((NI)((NU64)(((NI) ((*xX60gensym144_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym144_).Sup.itemId.item))));
			unowned_2 = (*T24_);
			env2 = copyTree__ast_4432(env);
			asgnRef((void**) (&(*env2).typ), (*unowned_2).typ);
			T25_ = NIM_NIL;
			T25_ = newAsgnStmt__lambdalifting_192(unowned_2, env2, (*env).info);
			add__ast_4798(result, T25_);
			createTypeBoundOpsLL__lambdalifting_268((*d).graph, (*unowned_2).typ, (*env).info, (*d).idgen, owner);
		}
		LA22_: ;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155((*(*owner).typ).n);
			i_2 = ((NI) 1);
			{
				while (1) {
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* local;
					if (!(i_2 < colontmp_)) goto LA28;
					i = i_2;
					local = (*(*(*(*owner).typ).n)._kind_6.sons->data[i])._kind_4.sym;
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym150_;
						NIM_BOOL T31_;
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* fieldAccess;
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T34_;
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T35_;
						xX60gensym150_ = local;
						T31_ = (NIM_BOOL)0;
						T31_ = contains__astalgo_3489((&(*d).capturedVars), (NI)((NI)((NU64)(((NI) ((*xX60gensym150_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym150_).Sup.itemId.item))));
						if (!T31_) goto LA32_;
						fieldAccess = indirectAccess__lowerings_616(env, local, (*env).info);
						T34_ = NIM_NIL;
						T34_ = newSymNode__ast_3704(local);
						T35_ = NIM_NIL;
						T35_ = newAsgnStmt__lambdalifting_192(fieldAccess, T34_, (*env).info);
						add__ast_4798(result, T35_);
						{
							if (!!(((*owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 17)))) goto LA38_;
							createTypeBoundOps__liftdestructors_47((*d).graph, ((tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw*) NIM_NIL), (*fieldAccess).typ, (*env).info, (*d).idgen);
						}
						LA38_: ;
						{
							NIM_BOOL T42_;
							T42_ = (NIM_BOOL)0;
							T42_ = (((*(*fieldAccess).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 31))&63U)))!=0);
							if (T42_) goto LA43_;
							T42_ = (((*(*(*d).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0);
							LA43_: ;
							if (!T42_) goto LA44_;
							(*owner).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 42)) & 63);
						}
						LA44_: ;
					}
					LA32_: ;
					i_2 += ((NI) 1);
				} LA28: ;
			}
		}
	}
	LA1_: ;
	T46_ = NIM_NIL;
	T46_ = skipTypes__ast_3723((*env).typ, TM__8JPgS7d2itnucsgTch9cDzA_10);
	T47_ = NIM_NIL;
	T47_ = getIdent__idents_152((*(*d).graph).cache, ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_18));
	upField = lookupInRecord__astalgo_84((*T46_).n, T47_);
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* up;
		if (!!((upField == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA50_;
		up = getUpViaParam__lambdalifting_3896((*d).graph, owner);
		{
			NIM_BOOL T54_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T56_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T57_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T60_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T61_;
			T54_ = (NIM_BOOL)0;
			T54_ = !((up == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
			if (!(T54_)) goto LA55_;
			T56_ = NIM_NIL;
			T56_ = skipTypes__ast_3723((*upField).typ, TM__8JPgS7d2itnucsgTch9cDzA_10);
			T57_ = NIM_NIL;
			T57_ = skipTypes__ast_3723((*up).typ, TM__8JPgS7d2itnucsgTch9cDzA_10);
			T54_ = (T56_ == T57_);
			LA55_: ;
			if (!T54_) goto LA58_;
			T60_ = NIM_NIL;
			T60_ = rawIndirectAccess__lowerings_331(env, upField, (*env).info);
			T61_ = NIM_NIL;
			T61_ = newAsgnStmt__lambdalifting_192(T60_, up, (*env).info);
			add__ast_4798(result, T61_);
		}
		goto LA52_;
		LA58_: ;
		{
			liMessage__msgs_1128((*(*d).graph).config, (*env).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_29), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__8JPgS7d2itnucsgTch9cDzA_30, NIM_FALSE);
		}
		LA52_: ;
	}
	LA50_: ;
	createTypeBoundOpsLL__lambdalifting_268((*d).graph, (*env).typ, (*owner).info, (*d).idgen, owner);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, finishClosureCreation__lambdalifting_4325)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* d, tyObject_LiftingPass__3COrF4ZRGkfAVWIFzu70AA* c, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* res) {
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* unowned;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym159_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nilLit;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T5_;
		if (!(((*(*(*d).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 42))&63U)))!=0)) goto LA3_;
		xX60gensym159_ = owner;
		unowned = X5BX5D___lambdalifting_4423((*c).unownedEnvVars, (NI)((NI)((NU64)(((NI) ((*xX60gensym159_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym159_).Sup.itemId.item))));
		nilLit = newNodeIT__ast_3342(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23), info, (*unowned).typ);
		T5_ = NIM_NIL;
		T5_ = newAsgnStmt__lambdalifting_192(unowned, nilLit, info);
		add__ast_4798(res, T5_);
		createTypeBoundOpsLL__lambdalifting_268((*d).graph, (*unowned).typ, info, (*d).idgen, owner);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, makeClosure__lambdalifting_199)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prc, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* env, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T1_;
	result = NIM_NIL;
	result = newNodeIT__ast_3342(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 155), info, (*prc).typ);
	T1_ = NIM_NIL;
	T1_ = newSymNode__ast_3704(prc);
	add__ast_4798(result, T1_);
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T6_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T7_;
		if (!(env == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA4_;
		T6_ = NIM_NIL;
		T6_ = getSysType__magicsys_60(g, info, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 5));
		T7_ = NIM_NIL;
		T7_ = newNodeIT__ast_3342(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23), info, T6_);
		add__ast_4798(result, T7_);
	}
	goto LA2_;
	LA4_: ;
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T11_;
			T11_ = NIM_NIL;
			T11_ = skipConv__types_3661(env);
			if (!((*T11_).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 155))) goto LA12_;
			liMessage__msgs_1128((*g).config, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_31), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__8JPgS7d2itnucsgTch9cDzA_32, NIM_FALSE);
		}
		LA12_: ;
		add__ast_4798(result, env);
	}
	LA2_: ;
	createTypeBoundOps__liftdestructors_47(g, ((tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw*) NIM_NIL), (*result).typ, info, idgen);
	{
		NIM_BOOL T16_;
		T16_ = (NIM_BOOL)0;
		T16_ = (((*(*result).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 31))&63U)))!=0);
		if (T16_) goto LA17_;
		T16_ = (((*(*g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0);
		LA17_: ;
		if (!T16_) goto LA18_;
		(*prc).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 42)) & 63);
	}
	LA18_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, closureCreationForIter__lambdalifting_4506)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* iter, tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* d, tyObject_LiftingPass__3COrF4ZRGkfAVWIFzu70AA* c) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* v;
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T1_;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T2_;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T3_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* vnode;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T14_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T15_;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* upField;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T16_;
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T17_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T31_;
	result = NIM_NIL;
	result = newNodeIT__ast_3342(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126), (*iter).info, (*(*iter)._kind_4.sym).typ);
	owner = skipGenericOwner__ast_4659((*iter)._kind_4.sym);
	T1_ = NIM_NIL;
	T1_ = getIdent__idents_152((*(*d).graph).cache, ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_24));
	T2_ = nextSymId__ast_3103((*d).idgen);
	v = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8), T1_, T2_, owner, (*iter).info, 0);
	(*v).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 25)) & 63);
	T3_ = NIM_NIL;
	T3_ = getHiddenParam__lambdalifting_106((*d).graph, (*iter)._kind_4.sym);
	asgnRef((void**) (&(*v).typ), asOwnedRef__lambdalifting_1919(d, (*T3_).typ));
	vnode = NIM_NIL;
	{
		NIM_BOOL T6_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* it;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T10_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T11_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T12_;
		T6_ = (NIM_BOOL)0;
		T6_ = ((*owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 15));
		if (!(T6_)) goto LA7_;
		T6_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
		LA7_: ;
		if (!T6_) goto LA8_;
		it = getHiddenParam__lambdalifting_106((*d).graph, owner);
		T10_ = NIM_NIL;
		T10_ = skipTypes__ast_3723((*it).typ, TM__8JPgS7d2itnucsgTch9cDzA_10);
		T11_ = NIM_NIL;
		T11_ = addUniqueField__lowerings_449(T10_, v, (*(*d).graph).cache, (*d).idgen);
		T12_ = NIM_NIL;
		T12_ = newSymNode__ast_3704(it);
		vnode = indirectAccess__lowerings_616(T12_, v, (*v).info);
	}
	goto LA4_;
	LA8_: ;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* vs;
		vnode = newSymNode__ast_3704(v);
		vs = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 99), (*iter).info);
		addVar__lowerings_63(vs, vnode);
		add__ast_4798(result, vs);
	}
	LA4_: ;
	T14_ = NIM_NIL;
	T14_ = getSysSym__magicsys_16((*d).graph, (*iter).info, ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_26));
	T15_ = NIM_NIL;
	T15_ = newCall__lambdalifting_21(T14_, vnode);
	add__ast_4798(result, T15_);
	createTypeBoundOpsLL__lambdalifting_268((*d).graph, (*vnode).typ, (*iter).info, (*d).idgen, owner);
	T16_ = NIM_NIL;
	T16_ = skipTypes__ast_3723((*v).typ, TM__8JPgS7d2itnucsgTch9cDzA_10);
	T17_ = NIM_NIL;
	T17_ = getIdent__idents_152((*(*d).graph).cache, ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_18));
	upField = lookupInRecord__astalgo_84((*T16_).n, T17_);
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* u;
		if (!!((upField == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA20_;
		u = setupEnvVar__lambdalifting_2235(owner, d, c, (*iter).info);
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T24_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T25_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T28_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T29_;
			T24_ = NIM_NIL;
			T24_ = skipTypes__ast_3723((*u).typ, TM__8JPgS7d2itnucsgTch9cDzA_10);
			T25_ = NIM_NIL;
			T25_ = skipTypes__ast_3723((*upField).typ, TM__8JPgS7d2itnucsgTch9cDzA_10);
			if (!(T24_ == T25_)) goto LA26_;
			T28_ = NIM_NIL;
			T28_ = rawIndirectAccess__lowerings_331(vnode, upField, (*iter).info);
			T29_ = NIM_NIL;
			T29_ = newAsgnStmt__lambdalifting_192(T28_, u, (*iter).info);
			add__ast_4798(result, T29_);
		}
		goto LA22_;
		LA26_: ;
		{
			liMessage__msgs_1128((*(*d).graph).config, (*iter).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_33), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__8JPgS7d2itnucsgTch9cDzA_34, NIM_FALSE);
		}
		LA22_: ;
	}
	LA20_: ;
	T31_ = NIM_NIL;
	T31_ = makeClosure__lambdalifting_199((*d).graph, (*d).idgen, (*iter)._kind_4.sym, vnode, (*iter).info);
	add__ast_4798(result, T31_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, symToClosure__lambdalifting_4674)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* d, tyObject_LiftingPass__3COrF4ZRGkfAVWIFzu70AA* c) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
{	result = NIM_NIL;
	s = (*n)._kind_4.sym;
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* available;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T5_;
		if (!(s == owner)) goto LA3_;
		available = getHiddenParam__lambdalifting_106((*d).graph, owner);
		T5_ = NIM_NIL;
		T5_ = newSymNode__ast_3704(available);
		result = makeClosure__lambdalifting_199((*d).graph, (*d).idgen, s, T5_, (*n).info);
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = ((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 15));
		if (!(T7_)) goto LA8_;
		T7_ = ((*(*s).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
		LA8_: ;
		if (!T7_) goto LA9_;
		result = closureCreationForIter__lambdalifting_4506(n, d, c);
	}
	goto LA1_;
	LA9_: ;
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T12_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T15_;
		T12_ = NIM_NIL;
		T12_ = skipGenericOwner__ast_4659(s);
		if (!(T12_ == owner)) goto LA13_;
		T15_ = NIM_NIL;
		T15_ = setupEnvVar__lambdalifting_2235(owner, d, c, (*n).info);
		result = makeClosure__lambdalifting_199((*d).graph, (*d).idgen, s, T15_, (*n).info);
	}
	goto LA1_;
	LA13_: ;
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* available_2;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* wanted;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T17_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* access;
		available_2 = getHiddenParam__lambdalifting_106((*d).graph, owner);
		T17_ = NIM_NIL;
		T17_ = getHiddenParam__lambdalifting_106((*d).graph, s);
		wanted = (*T17_).typ;
		access = newSymNode__ast_3704(available_2);
		{
			while (1) {
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* obj;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* upField;
				tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T24_;
				{
					if (!((*access).typ == wanted)) goto LA22_;
					result = makeClosure__lambdalifting_199((*d).graph, (*d).idgen, s, access, (*n).info);
					goto BeforeRet_;
				}
				LA22_: ;
				obj = skipTypes__ast_3723((*access).typ, TM__8JPgS7d2itnucsgTch9cDzA_10);
				T24_ = NIM_NIL;
				T24_ = getIdent__idents_152((*(*d).graph).cache, ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_18));
				upField = lookupInRecord__astalgo_84((*obj).n, T24_);
				{
					if (!(upField == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA27_;
					liMessage__msgs_1128((*(*d).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_35), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__8JPgS7d2itnucsgTch9cDzA_36, NIM_FALSE);
					result = n;
					goto BeforeRet_;
				}
				LA27_: ;
				access = rawIndirectAccess__lowerings_331(access, upField, (*n).info);
			}
		}
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, accessViaEnvParam__lambdalifting_2197)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* envParam;
	NimStringDesc* T16_;
{	result = NIM_NIL;
	s = (*n)._kind_4.sym;
	envParam = getHiddenParam__lambdalifting_106(g, owner);
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* access;
		if (!!((envParam == 0))) goto LA3_;
		access = newSymNode__ast_3704(envParam);
		{
			while (1) {
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* obj;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* upField;
				tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T11_;
				obj = (*(*access).typ).sons->data[((NI) 0)];
				field = getFieldFromObj__lowerings_588(obj, s);
				{
					if (!!((field == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA9_;
					result = rawIndirectAccess__lowerings_331(access, field, (*n).info);
					goto BeforeRet_;
				}
				LA9_: ;
				T11_ = NIM_NIL;
				T11_ = getIdent__idents_152((*g).cache, ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_18));
				upField = lookupInRecord__astalgo_84((*obj).n, T11_);
				{
					if (!(upField == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA14_;
					goto LA5;
				}
				LA14_: ;
				access = rawIndirectAccess__lowerings_331(access, upField, (*n).info);
			}
		} LA5: ;
	}
	LA3_: ;
	T16_ = NIM_NIL;
	T16_ = rawNewString(((*(*s).name).s ? (*(*s).name).s->Sup.len : 0) + 36);
appendString(T16_, ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_37));
appendString(T16_, (*(*s).name).s);
	liMessage__msgs_1128((*g).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T16_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__8JPgS7d2itnucsgTch9cDzA_38, NIM_FALSE);
	result = n;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, accessViaEnvVar__lambdalifting_4554)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* d, tyObject_LiftingPass__3COrF4ZRGkfAVWIFzu70AA* c) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* access;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* obj;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field;
	result = NIM_NIL;
	access = setupEnvVar__lambdalifting_2235(owner, d, c, (*n).info);
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym168_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** T5_;
		if (!(((*(*(*d).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 42))&63U)))!=0)) goto LA3_;
		xX60gensym168_ = owner;
		T5_ = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
		T5_ = X5BX5D___lambdalifting_4030((&(*c).unownedEnvVars), (NI)((NI)((NU64)(((NI) ((*xX60gensym168_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym168_).Sup.itemId.item))));
		access = (*T5_);
	}
	LA3_: ;
	obj = skipTypes__ast_3723((*access).typ, TM__8JPgS7d2itnucsgTch9cDzA_10);
	field = getFieldFromObj__lowerings_588(obj, (*n)._kind_4.sym);
	{
		if (!!((field == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA8_;
		result = rawIndirectAccess__lowerings_331(access, field, (*n).info);
	}
	goto LA6_;
	LA8_: ;
	{
		liMessage__msgs_1128((*(*d).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_39), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__8JPgS7d2itnucsgTch9cDzA_40, NIM_FALSE);
		result = n;
	}
	LA6_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, liftCapturedVars__lambdalifting_4669)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg* d, tyObject_LiftingPass__3COrF4ZRGkfAVWIFzu70AA* c) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
{	result = NIM_NIL;
	result = n;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
		s = (*n)._kind_4.sym;
		{
			NIM_BOOL T4_;
			T4_ = (NIM_BOOL)0;
			T4_ = isInnerProc__lambdalifting_177(s);
			if (!T4_) goto LA5_;
			{
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym176_;
				NIM_BOOL T9_;
				NI oldInContainer;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body;
				xX60gensym176_ = s;
				T9_ = (NIM_BOOL)0;
				T9_ = containsOrIncl__astalgo_402((&(*c).processed), (NI)((NI)((NU64)(((NI) ((*xX60gensym176_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym176_).Sup.itemId.item))));
				if (!!(T9_)) goto LA10_;
				oldInContainer = (*c).inContainer;
				(*c).inContainer = ((NI) 0);
				body = transformBody__transf_16((*d).graph, (*d).idgen, s, NIM_FALSE);
				body = liftCapturedVars__lambdalifting_4669(body, s, d, c);
				{
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym177_;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T14_;
					xX60gensym177_ = s;
					T14_ = NIM_NIL;
					T14_ = getOrDefault__lambdalifting_2344((*c).envVars, (NI)((NI)((NU64)(((NI) ((*xX60gensym177_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym177_).Sup.itemId.item))));
					if (!(T14_ == 0)) goto LA15_;
					asgnRef((void**) (&(*s)._kind_1.transformedBody), body);
				}
				goto LA12_;
				LA15_: ;
				{
					tyArray__Nfk9cOEzg2bRz9c1V8fGzONg T18_;
					nimZeroMem((void*)T18_, sizeof(tyArray__Nfk9cOEzg2bRz9c1V8fGzONg));
					T18_[0] = rawClosureCreation__lambdalifting_3914(s, d, c, (*n).info);
					T18_[1] = body;
					asgnRef((void**) (&(*s)._kind_1.transformedBody), newTree__ast_3356(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115), T18_, 2));
					finishClosureCreation__lambdalifting_4325(s, d, (&(*c)), (*n).info, (*s)._kind_1.transformedBody);
				}
				LA12_: ;
				(*c).inContainer = oldInContainer;
			}
			LA10_: ;
			{
				if (!((*(*s).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9))) goto LA21_;
				result = symToClosure__lambdalifting_4674(n, owner, d, c);
			}
			LA21_: ;
		}
		goto LA2_;
		LA5_: ;
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym179_;
			NIM_BOOL T24_;
			xX60gensym179_ = s;
			T24_ = (NIM_BOOL)0;
			T24_ = contains__astalgo_3489((&(*d).capturedVars), (NI)((NI)((NU64)(((NI) ((*xX60gensym179_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym179_).Sup.itemId.item))));
			if (!T24_) goto LA25_;
			{
				if (!!(((*s).owner == owner))) goto LA29_;
				result = accessViaEnvParam__lambdalifting_2197((*d).graph, n, owner);
			}
			goto LA27_;
			LA29_: ;
			{
				NIM_BOOL T32_;
				NIM_BOOL T33_;
				T32_ = (NIM_BOOL)0;
				T33_ = (NIM_BOOL)0;
				T33_ = ((*owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 15));
				if (!(T33_)) goto LA34_;
				T33_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
				LA34_: ;
				T32_ = T33_;
				if (!(T32_)) goto LA35_;
				T32_ = interestingIterVar__lambdalifting_238(s);
				LA35_: ;
				if (!T32_) goto LA36_;
				result = accessViaEnvParam__lambdalifting_2197((*d).graph, n, owner);
			}
			goto LA27_;
			LA36_: ;
			{
				result = accessViaEnvVar__lambdalifting_4554(n, owner, d, c);
			}
			LA27_: ;
		}
		goto LA2_;
		LA25_: ;
		LA2_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 4) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 24):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 83):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 98):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 80):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 81):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 82):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 123):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 122):
	{
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 155):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x;
			if (!((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA43_;
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), liftCapturedVars__lambdalifting_4669((*n)._kind_6.sons->data[((NI) 0)], owner, d, c));
			x = skipConv__types_3661((*n)._kind_6.sons->data[((NI) 0)]);
			{
				if (!((*x).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 155))) goto LA47_;
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), (*x)._kind_6.sons->data[((NI) 0)]);
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), (*x)._kind_6.sons->data[((NI) 1)]);
			}
			LA47_: ;
		}
		LA43_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 51) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 52):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84):
	{
		{
			NIM_BOOL T52_;
			NI oldInContainer_2;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* m;
			T52_ = (NIM_BOOL)0;
			T52_ = !(((*n).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
			if (!(T52_)) goto LA53_;
			T52_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
			LA53_: ;
			if (!T52_) goto LA54_;
			oldInContainer_2 = (*c).inContainer;
			(*c).inContainer = ((NI) 0);
			m = newSymNode__ast_3704((*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
			asgnRef((void**) (&(*m).typ), (*n).typ);
			result = liftCapturedVars__lambdalifting_4669(m, owner, d, c);
			(*c).inContainer = oldInContainer_2;
		}
		LA54_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58):
	{
		{
			NI T59_;
			T59_ = (NI)0;
			T59_ = len__ast_3155(n);
			if (!(T59_ == ((NI) 2))) goto LA60_;
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), liftCapturedVars__lambdalifting_4669((*n)._kind_6.sons->data[((NI) 1)], owner, d, c));
			{
				if (!((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 155))) goto LA64_;
				result = (*n)._kind_6.sons->data[((NI) 1)];
			}
			LA64_: ;
		}
		LA60_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 109):
	{
		{
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 73) || (*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 74))) goto LA69_;
			asgnRef((void**) (&(*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)]), liftCapturedVars__lambdalifting_4669((*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)], owner, d, c));
		}
		goto LA67_;
		LA69_: ;
		{
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), liftCapturedVars__lambdalifting_4669((*n)._kind_6.sons->data[((NI) 0)], owner, d, c));
		}
		LA67_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 132):
	{
		result = n;
	}
	break;
	default:
	{
		NIM_BOOL inContainer;
		{
			NIM_BOOL T76_;
			T76_ = (NIM_BOOL)0;
			T76_ = ((*owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 15));
			if (!(T76_)) goto LA77_;
			T76_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
			LA77_: ;
			if (!T76_) goto LA78_;
			{
				if (!(((*n).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg) 8))&31U)))!=0)) goto LA82_;
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), liftCapturedVars__lambdalifting_4669((*n)._kind_6.sons->data[((NI) 1)], owner, d, c));
				goto BeforeRet_;
			}
			LA82_: ;
		}
		LA78_: ;
		inContainer = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 38) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41));
		{
			if (!inContainer) goto LA86_;
			(*c).inContainer += ((NI) 1);
		}
		LA86_: ;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA90;
					i = i_2;
					asgnRef((void**) (&(*n)._kind_6.sons->data[i]), liftCapturedVars__lambdalifting_4669((*n)._kind_6.sons->data[i], owner, d, c));
					i_2 += ((NI) 1);
				} LA90: ;
			}
		}
		{
			if (!inContainer) goto LA93_;
			(*c).inContainer -= ((NI) 1);
		}
		LA93_: ;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, liftLambdas__lambdalifting_5141)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fn, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body, NIM_BOOL* tooEarly, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	NIM_BOOL isCompileTime;
	NIM_BOOL T1_;
	result = NIM_NIL;
	T1_ = (NIM_BOOL)0;
	T1_ = (((*fn).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 28))&63U)))!=0);
	if (T1_) goto LA2_;
	T1_ = ((*fn).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 17));
	LA2_: ;
	isCompileTime = T1_;
	{
		NIM_BOOL T5_;
		NIM_BOOL T6_;
		NIM_BOOL T8_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T11_;
		T5_ = (NIM_BOOL)0;
		T6_ = (NIM_BOOL)0;
		T6_ = ((*body).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1));
		if (T6_) goto LA7_;
		T8_ = (NIM_BOOL)0;
		T8_ = ((*(*g).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 3));
		if (!(T8_)) goto LA9_;
		T8_ = !(isCompileTime);
		LA9_: ;
		T6_ = T8_;
		LA7_: ;
		T5_ = T6_;
		if (T5_) goto LA10_;
		T11_ = NIM_NIL;
		T11_ = skipGenericOwner__ast_4659(fn);
		T5_ = !(((*T11_).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6)));
		LA10_: ;
		if (!T5_) goto LA12_;
		result = body;
		(*tooEarly) = NIM_TRUE;
	}
	goto LA3_;
	LA12_: ;
	{
		tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg d;
		nimZeroMem((void*)(&d), sizeof(tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg));
		initDetectionPass__lambdalifting_392(g, fn, idgen, (&d));
		detectCapturedVars__lambdalifting_1994(body, fn, (&d));
		{
			NIM_BOOL T17_;
			NIM_BOOL T19_;
			T17_ = (NIM_BOOL)0;
			T17_ = !(d.somethingToDo);
			if (!(T17_)) goto LA18_;
			T19_ = (NIM_BOOL)0;
			T19_ = ((*fn).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 15));
			if (!(T19_)) goto LA20_;
			T19_ = ((*(*fn).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
			LA20_: ;
			T17_ = T19_;
			LA18_: ;
			if (!T17_) goto LA21_;
			addClosureParam__lambdalifting_1967((&d), fn, (*body).info);
			d.somethingToDo = NIM_TRUE;
		}
		LA21_: ;
		{
			tyObject_LiftingPass__3COrF4ZRGkfAVWIFzu70AA c;
			if (!d.somethingToDo) goto LA25_;
			nimZeroMem((void*)(&c), sizeof(tyObject_LiftingPass__3COrF4ZRGkfAVWIFzu70AA));
			initLiftingPass__lambdalifting_2155(fn, (&c));
			result = liftCapturedVars__lambdalifting_4669(body, fn, (&d), (&c));
			{
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym224_;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T29_;
				tyArray__Nfk9cOEzg2bRz9c1V8fGzONg T32_;
				xX60gensym224_ = fn;
				T29_ = NIM_NIL;
				T29_ = getOrDefault__lambdalifting_2344(c.envVars, (NI)((NI)((NU64)(((NI) ((*xX60gensym224_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym224_).Sup.itemId.item))));
				if (!!((T29_ == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA30_;
				nimZeroMem((void*)T32_, sizeof(tyArray__Nfk9cOEzg2bRz9c1V8fGzONg));
				T32_[0] = rawClosureCreation__lambdalifting_3914(fn, (&d), (&c), (*body).info);
				T32_[1] = result;
				result = newTree__ast_3356(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115), T32_, 2);
				finishClosureCreation__lambdalifting_4325(fn, (&d), (&c), (*body).info, result);
			}
			LA30_: ;
		}
		goto LA23_;
		LA25_: ;
		{
			result = body;
		}
		LA23_: ;
	}
	LA3_: ;
	return result;
}
static N_INLINE(NIM_BOOL, liftingHarmful__lambdalifting_251)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner) {
	NIM_BOOL result;
	NIM_BOOL isCompileTime;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (((*owner).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 28))&63U)))!=0);
	if (T1_) goto LA2_;
	T1_ = ((*owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 17));
	LA2_: ;
	isCompileTime = T1_;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*conf).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 3));
	if (!(T3_)) goto LA4_;
	T3_ = !(isCompileTime);
	LA4_: ;
	result = T3_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, liftIterSym__lambdalifting_293)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* iter;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* hp;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* env;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T17_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T18_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T19_;
{	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = liftingHarmful__lambdalifting_251((*g).config, owner);
		if (!T3_) goto LA4_;
		result = n;
		goto BeforeRet_;
	}
	LA4_: ;
	iter = (*n)._kind_4.sym;
	result = newNodeIT__ast_3342(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126), (*n).info, (*n).typ);
	hp = getHiddenParam__lambdalifting_106(g, iter);
	env = NIM_NIL;
	{
		NIM_BOOL T8_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* it;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T12_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T13_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T14_;
		T8_ = (NIM_BOOL)0;
		T8_ = ((*owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 15));
		if (!(T8_)) goto LA9_;
		T8_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
		LA9_: ;
		if (!T8_) goto LA10_;
		it = getHiddenParam__lambdalifting_106(g, owner);
		T12_ = NIM_NIL;
		T12_ = skipTypes__ast_3723((*it).typ, TM__8JPgS7d2itnucsgTch9cDzA_41);
		T13_ = NIM_NIL;
		T13_ = addUniqueField__lowerings_449((*T12_).sons->data[((NI) 0)], hp, (*g).cache, idgen);
		T14_ = NIM_NIL;
		T14_ = newSymNode__ast_3704(it);
		env = indirectAccess__lowerings_616(T14_, hp, (*hp).info);
	}
	goto LA6_;
	LA10_: ;
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* e;
		tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T16_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* v;
		T16_ = nextSymId__ast_3103(idgen);
		e = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 9), (*iter).name, T16_, owner, (*n).info, 0);
		asgnRef((void**) (&(*e).typ), (*hp).typ);
		(*e).flags = (*hp).flags;
		env = newSymNode__ast_3704(e);
		v = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 99), (*n).info);
		addVar__lowerings_63(v, env);
		add__ast_4798(result, v);
	}
	LA6_: ;
	T17_ = NIM_NIL;
	T17_ = getSysSym__magicsys_16(g, (*n).info, ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_26));
	T18_ = NIM_NIL;
	T18_ = newCall__lambdalifting_21(T17_, env);
	add__ast_4798(result, T18_);
	createTypeBoundOpsLL__lambdalifting_268(g, (*env).typ, (*n).info, idgen, owner);
	T19_ = NIM_NIL;
	T19_ = makeClosure__lambdalifting_199(g, idgen, iter, env, (*n).info);
	add__ast_4798(result, T19_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, liftForLoop__lambdalifting_5287)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* call;
	NI T13_;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* env;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* op;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* loopBody;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* whileLoop;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T38_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* v2;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* vpart;
	tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw T39_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T54_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* bs;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ibs;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* elifBranch;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* br;
	NI T60_;
{	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = liftingHarmful__lambdalifting_251((*g).config, owner);
		if (!T3_) goto LA4_;
		result = body;
		goto BeforeRet_;
	}
	LA4_: ;
	{
		NIM_BOOL T8_;
		NI T10_;
		T8_ = (NIM_BOOL)0;
		T8_ = ((*body).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 94));
		if (!(T8_)) goto LA9_;
		T10_ = (NI)0;
		T10_ = len__ast_3155(body);
		T8_ = ((*(*body)._kind_6.sons->data[(NI)(T10_ - ((NI) 2))]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*(*body)._kind_6.sons->data[(NI)(T10_ - ((NI) 2))]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29) || (*(*body)._kind_6.sons->data[(NI)(T10_ - ((NI) 2))]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30) || (*(*body)._kind_6.sons->data[(NI)(T10_ - ((NI) 2))]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31) || (*(*body)._kind_6.sons->data[(NI)(T10_ - ((NI) 2))]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) || (*(*body)._kind_6.sons->data[(NI)(T10_ - ((NI) 2))]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28) || (*(*body)._kind_6.sons->data[(NI)(T10_ - ((NI) 2))]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32));
		LA9_: ;
		if (!!(T8_)) goto LA11_;
		liMessage__msgs_1128((*g).config, (*body).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_42), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__8JPgS7d2itnucsgTch9cDzA_43, NIM_FALSE);
		result = body;
		goto BeforeRet_;
	}
	LA11_: ;
	T13_ = (NI)0;
	T13_ = len__ast_3155(body);
	call = (*body)._kind_6.sons->data[(NI)(T13_ - ((NI) 2))];
	result = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115), (*body).info);
	env = NIM_NIL;
	op = (*call)._kind_6.sons->data[((NI) 0)];
	{
		NIM_BOOL T16_;
		NIM_BOOL T18_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* iter;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* hp;
		tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T22_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* v;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T23_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T24_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T25_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T26_;
		T16_ = (NIM_BOOL)0;
		T16_ = ((*op).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		if (!(T16_)) goto LA17_;
		T18_ = (NIM_BOOL)0;
		T18_ = ((*(*op)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 15));
		if (!(T18_)) goto LA19_;
		T18_ = ((*(*(*op)._kind_4.sym).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
		LA19_: ;
		T16_ = T18_;
		LA17_: ;
		if (!T16_) goto LA20_;
		iter = (*op)._kind_4.sym;
		hp = getHiddenParam__lambdalifting_106(g, iter);
		T22_ = nextSymId__ast_3103(idgen);
		env = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 9), (*iter).name, T22_, owner, (*body).info, 0);
		asgnRef((void**) (&(*env).typ), (*hp).typ);
		(*env).flags = (*hp).flags;
		v = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 99), (*body).info);
		T23_ = NIM_NIL;
		T23_ = newSymNode__ast_3704(env);
		addVar__lowerings_63(v, T23_);
		add__ast_4798(result, v);
		T24_ = NIM_NIL;
		T24_ = getSysSym__magicsys_16(g, (*env).info, ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_26));
		T25_ = NIM_NIL;
		T25_ = newSymNode__ast_3704(env);
		T26_ = NIM_NIL;
		T26_ = newCall__lambdalifting_21(T24_, T25_);
		add__ast_4798(result, T26_);
		createTypeBoundOpsLL__lambdalifting_268(g, (*env).typ, (*body).info, idgen, owner);
	}
	goto LA14_;
	LA20_: ;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* closure;
		if (!((*op).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126))) goto LA28_;
		closure = lastSon__ast_4833(op);
		{
			if (!((*closure).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 155))) goto LA32_;
			asgnRef((void**) (&(*call)._kind_6.sons->data[((NI) 0)]), closure);
			{
				NI i;
				NI colontmp_;
				NI T35_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				T35_ = (NI)0;
				T35_ = len__ast_3155(op);
				colontmp_ = (NI)(T35_ - ((NI) 1));
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA37;
						i = i_2;
						add__ast_4798(result, (*op)._kind_6.sons->data[i]);
						i_2 += ((NI) 1);
					} LA37: ;
				}
			}
		}
		LA32_: ;
	}
	goto LA14_;
	LA28_: ;
	LA14_: ;
	loopBody = newNodeI__ast_3324(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115), (*body).info, ((NI) 3));
	whileLoop = newNodeI__ast_3324(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 96), (*body).info, ((NI) 2));
	T38_ = NIM_NIL;
	T38_ = getSysType__magicsys_60(g, (*body).info, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1));
	asgnRef((void**) (&(*whileLoop)._kind_6.sons->data[((NI) 0)]), newIntTypeNode__ast_3771(IL64(1), T38_));
	asgnRef((void**) (&(*whileLoop)._kind_6.sons->data[((NI) 1)]), loopBody);
	add__ast_4798(result, whileLoop);
	v2 = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 100), (*body).info);
	T39_ = (tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw)0;
	{
		NI T42_;
		T42_ = (NI)0;
		T42_ = len__ast_3155(body);
		if (!(T42_ == ((NI) 3))) goto LA43_;
		T39_ = ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 35);
	}
	goto LA40_;
	LA43_: ;
	{
		T39_ = ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 36);
	}
	LA40_: ;
	vpart = newNodeI__ast_3320(T39_, (*body).info);
	{
		NI i_3;
		NI colontmp__2;
		NI T47_;
		NI i_4;
		i_3 = (NI)0;
		colontmp__2 = (NI)0;
		T47_ = (NI)0;
		T47_ = len__ast_3155(body);
		colontmp__2 = (NI)(T47_ - ((NI) 2));
		i_4 = ((NI) 0);
		{
			while (1) {
				if (!(i_4 < colontmp__2)) goto LA49;
				i_3 = i_4;
				{
					if (!((*(*body)._kind_6.sons->data[i_3]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA52_;
					transitionToLet__ast_4407((*(*body)._kind_6.sons->data[i_3])._kind_4.sym);
				}
				LA52_: ;
				add__ast_4798(vpart, (*body)._kind_6.sons->data[i_3]);
				i_4 += ((NI) 1);
			} LA49: ;
		}
	}
	T54_ = NIM_NIL;
	T54_ = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1), (*body).info);
	add__ast_4798(vpart, T54_);
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T59_;
		if (!!((env == 0))) goto LA57_;
		T59_ = NIM_NIL;
		T59_ = newSymNode__ast_3704(env);
		asgnRef((void**) (&(*call)._kind_6.sons->data[((NI) 0)]), makeClosure__lambdalifting_199(g, idgen, (*(*call)._kind_6.sons->data[((NI) 0)])._kind_4.sym, T59_, (*body).info));
	}
	LA57_: ;
	add__ast_4798(vpart, call);
	add__ast_4798(v2, vpart);
	asgnRef((void**) (&(*loopBody)._kind_6.sons->data[((NI) 0)]), v2);
	bs = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 158), (*body).info);
	add__ast_4798(bs, (*call)._kind_6.sons->data[((NI) 0)]);
	ibs = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 92), (*body).info);
	elifBranch = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 86), (*body).info);
	add__ast_4798(elifBranch, bs);
	br = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 110), (*body).info);
	add__ast_4798(br, (*g).emptyNode);
	add__ast_4798(elifBranch, br);
	add__ast_4798(ibs, elifBranch);
	asgnRef((void**) (&(*loopBody)._kind_6.sons->data[((NI) 1)]), ibs);
	T60_ = (NI)0;
	T60_ = len__ast_3155(body);
	asgnRef((void**) (&(*loopBody)._kind_6.sons->data[((NI) 2)]), (*body)._kind_6.sons->data[(NI)(T60_ - ((NI) 1))]);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, freshVarForClosureIter__lambdalifting_337)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* envParam;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* obj;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* access;
	result = NIM_NIL;
	envParam = getHiddenParam__lambdalifting_106(g, owner);
	obj = skipTypes__ast_3723((*envParam).typ, TM__8JPgS7d2itnucsgTch9cDzA_10);
	field = addField__lowerings_420(obj, s, (*g).cache, idgen);
	access = newSymNode__ast_3704(envParam);
	result = rawIndirectAccess__lowerings_331(access, field, (*s).info);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getClosureIterResult__lambdalifting_62)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* iter, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	result = NIM_NIL;
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__ast_3155((*iter).ast);
		if (!(((NI) 7) < T3_)) goto LA4_;
		result = (*(*(*iter).ast)._kind_6.sons->data[((NI) 7)])._kind_4.sym;
	}
	goto LA1_;
	LA4_: ;
	{
		tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T7_;
		tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T8_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T9_;
		T7_ = NIM_NIL;
		T7_ = getIdent__idents_152((*g).cache, ((NimStringDesc*) &TM__8JPgS7d2itnucsgTch9cDzA_44));
		T8_ = nextSymId__ast_3103(idgen);
		result = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 11), T7_, T8_, iter, (*iter).info, 0);
		asgnRef((void**) (&(*result).typ), (*(*iter).typ).sons->data[((NI) 0)]);
		(*result).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 0)) & 63);
		T9_ = NIM_NIL;
		T9_ = newSymNode__ast_3704(result);
		add__ast_4798((*iter).ast, T9_);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getStateField__lambdalifting_4664)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T1_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T2_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = getHiddenParam__lambdalifting_106(g, owner);
	T2_ = NIM_NIL;
	T2_ = skipTypes__ast_3723((*T1_).typ, TM__8JPgS7d2itnucsgTch9cDzA_10);
	result = (*(*(*T2_).n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, liftIterToProc__lambdalifting_5055)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fn, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ptrType, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg d;
	tyObject_LiftingPass__3COrF4ZRGkfAVWIFzu70AA c;
	tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw oldKind;
	tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg oldCC;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym219_;
	result = NIM_NIL;
	nimZeroMem((void*)(&d), sizeof(tyObject_DetectionPass__ND8qk62G1dDuPAYJtAUDlg));
	initDetectionPass__lambdalifting_392(g, fn, idgen, (&d));
	nimZeroMem((void*)(&c), sizeof(tyObject_LiftingPass__3COrF4ZRGkfAVWIFzu70AA));
	initLiftingPass__lambdalifting_2155(fn, (&c));
	oldKind = (*fn).kind;
	oldCC = (*(*fn).typ).callConv;
	transitionRoutineSymKind__ast_4394(fn, ((tyEnum_TSymKind__5avKs4TYFTeLPAJjwtJ4cg) 15));
	(*(*fn).typ).callConv = ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9);
	xX60gensym219_ = fn;
	X5BX5Deq___lambdalifting_887((&d.ownerToType), (NI)((NI)((NU64)(((NI) ((*xX60gensym219_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym219_).Sup.itemId.item))), ptrType);
	detectCapturedVars__lambdalifting_1994(body, fn, (&d));
	result = liftCapturedVars__lambdalifting_4669(body, fn, (&d), (&c));
	transitionRoutineSymKind__ast_4394(fn, ((tyEnum_TSymKind__5avKs4TYFTeLPAJjwtJ4cg) (oldKind)));
	(*(*fn).typ).callConv = oldCC;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, atmlambdaliftingdotnim_DatInit000)(void) {
static TNimNode* TM__8JPgS7d2itnucsgTch9cDzA_2_3[3];
static TNimNode* TM__8JPgS7d2itnucsgTch9cDzA_21_3[3];
static TNimNode TM__8JPgS7d2itnucsgTch9cDzA_0[8];
NTIkeyvaluepair__NR9cgWyhzHdz1XjqYbM8wVA_.size = sizeof(tyTuple__NR9cgWyhzHdz1XjqYbM8wVA);
NTIkeyvaluepair__NR9cgWyhzHdz1XjqYbM8wVA_.align = NIM_ALIGNOF(tyTuple__NR9cgWyhzHdz1XjqYbM8wVA);
NTIkeyvaluepair__NR9cgWyhzHdz1XjqYbM8wVA_.kind = 18;
NTIkeyvaluepair__NR9cgWyhzHdz1XjqYbM8wVA_.base = 0;
NTIkeyvaluepair__NR9cgWyhzHdz1XjqYbM8wVA_.flags = 2;
TM__8JPgS7d2itnucsgTch9cDzA_2_3[0] = &TM__8JPgS7d2itnucsgTch9cDzA_0[1];
TM__8JPgS7d2itnucsgTch9cDzA_0[1].kind = 1;
TM__8JPgS7d2itnucsgTch9cDzA_0[1].offset = offsetof(tyTuple__NR9cgWyhzHdz1XjqYbM8wVA, Field0);
TM__8JPgS7d2itnucsgTch9cDzA_0[1].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__8JPgS7d2itnucsgTch9cDzA_0[1].name = "Field0";
TM__8JPgS7d2itnucsgTch9cDzA_2_3[1] = &TM__8JPgS7d2itnucsgTch9cDzA_0[2];
TM__8JPgS7d2itnucsgTch9cDzA_0[2].kind = 1;
TM__8JPgS7d2itnucsgTch9cDzA_0[2].offset = offsetof(tyTuple__NR9cgWyhzHdz1XjqYbM8wVA, Field1);
TM__8JPgS7d2itnucsgTch9cDzA_0[2].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__8JPgS7d2itnucsgTch9cDzA_0[2].name = "Field1";
TM__8JPgS7d2itnucsgTch9cDzA_2_3[2] = &TM__8JPgS7d2itnucsgTch9cDzA_0[3];
TM__8JPgS7d2itnucsgTch9cDzA_0[3].kind = 1;
TM__8JPgS7d2itnucsgTch9cDzA_0[3].offset = offsetof(tyTuple__NR9cgWyhzHdz1XjqYbM8wVA, Field2);
TM__8JPgS7d2itnucsgTch9cDzA_0[3].typ = (&NTIptype__q1v0zzhoMWrhMLs6UEp1IA_);
TM__8JPgS7d2itnucsgTch9cDzA_0[3].name = "Field2";
TM__8JPgS7d2itnucsgTch9cDzA_0[0].len = 3; TM__8JPgS7d2itnucsgTch9cDzA_0[0].kind = 2; TM__8JPgS7d2itnucsgTch9cDzA_0[0].sons = &TM__8JPgS7d2itnucsgTch9cDzA_2_3[0];
NTIkeyvaluepair__NR9cgWyhzHdz1XjqYbM8wVA_.node = &TM__8JPgS7d2itnucsgTch9cDzA_0[0];
NTIkeyvaluepairseq__wuwY3G19cIPfMd9b1mDzZsNw_.size = sizeof(tySequence__wuwY3G19cIPfMd9b1mDzZsNw*);
NTIkeyvaluepairseq__wuwY3G19cIPfMd9b1mDzZsNw_.align = NIM_ALIGNOF(tySequence__wuwY3G19cIPfMd9b1mDzZsNw*);
NTIkeyvaluepairseq__wuwY3G19cIPfMd9b1mDzZsNw_.kind = 24;
NTIkeyvaluepairseq__wuwY3G19cIPfMd9b1mDzZsNw_.base = (&NTIkeyvaluepair__NR9cgWyhzHdz1XjqYbM8wVA_);
NTIkeyvaluepairseq__wuwY3G19cIPfMd9b1mDzZsNw_.flags = 2;
NTIkeyvaluepairseq__wuwY3G19cIPfMd9b1mDzZsNw_.marker = Marker_tySequence__wuwY3G19cIPfMd9b1mDzZsNw;
NTIkeyvaluepair__j27tPFjtRhFKFqO9b6UrT5g_.size = sizeof(tyTuple__j27tPFjtRhFKFqO9b6UrT5g);
NTIkeyvaluepair__j27tPFjtRhFKFqO9b6UrT5g_.align = NIM_ALIGNOF(tyTuple__j27tPFjtRhFKFqO9b6UrT5g);
NTIkeyvaluepair__j27tPFjtRhFKFqO9b6UrT5g_.kind = 18;
NTIkeyvaluepair__j27tPFjtRhFKFqO9b6UrT5g_.base = 0;
NTIkeyvaluepair__j27tPFjtRhFKFqO9b6UrT5g_.flags = 2;
TM__8JPgS7d2itnucsgTch9cDzA_21_3[0] = &TM__8JPgS7d2itnucsgTch9cDzA_0[5];
TM__8JPgS7d2itnucsgTch9cDzA_0[5].kind = 1;
TM__8JPgS7d2itnucsgTch9cDzA_0[5].offset = offsetof(tyTuple__j27tPFjtRhFKFqO9b6UrT5g, Field0);
TM__8JPgS7d2itnucsgTch9cDzA_0[5].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__8JPgS7d2itnucsgTch9cDzA_0[5].name = "Field0";
TM__8JPgS7d2itnucsgTch9cDzA_21_3[1] = &TM__8JPgS7d2itnucsgTch9cDzA_0[6];
TM__8JPgS7d2itnucsgTch9cDzA_0[6].kind = 1;
TM__8JPgS7d2itnucsgTch9cDzA_0[6].offset = offsetof(tyTuple__j27tPFjtRhFKFqO9b6UrT5g, Field1);
TM__8JPgS7d2itnucsgTch9cDzA_0[6].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__8JPgS7d2itnucsgTch9cDzA_0[6].name = "Field1";
TM__8JPgS7d2itnucsgTch9cDzA_21_3[2] = &TM__8JPgS7d2itnucsgTch9cDzA_0[7];
TM__8JPgS7d2itnucsgTch9cDzA_0[7].kind = 1;
TM__8JPgS7d2itnucsgTch9cDzA_0[7].offset = offsetof(tyTuple__j27tPFjtRhFKFqO9b6UrT5g, Field2);
TM__8JPgS7d2itnucsgTch9cDzA_0[7].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__8JPgS7d2itnucsgTch9cDzA_0[7].name = "Field2";
TM__8JPgS7d2itnucsgTch9cDzA_0[4].len = 3; TM__8JPgS7d2itnucsgTch9cDzA_0[4].kind = 2; TM__8JPgS7d2itnucsgTch9cDzA_0[4].sons = &TM__8JPgS7d2itnucsgTch9cDzA_21_3[0];
NTIkeyvaluepair__j27tPFjtRhFKFqO9b6UrT5g_.node = &TM__8JPgS7d2itnucsgTch9cDzA_0[4];
NTIkeyvaluepairseq__WcRaozAFgJ6OG8h8DH4mow_.size = sizeof(tySequence__WcRaozAFgJ6OG8h8DH4mow*);
NTIkeyvaluepairseq__WcRaozAFgJ6OG8h8DH4mow_.align = NIM_ALIGNOF(tySequence__WcRaozAFgJ6OG8h8DH4mow*);
NTIkeyvaluepairseq__WcRaozAFgJ6OG8h8DH4mow_.kind = 24;
NTIkeyvaluepairseq__WcRaozAFgJ6OG8h8DH4mow_.base = (&NTIkeyvaluepair__j27tPFjtRhFKFqO9b6UrT5g_);
NTIkeyvaluepairseq__WcRaozAFgJ6OG8h8DH4mow_.flags = 2;
NTIkeyvaluepairseq__WcRaozAFgJ6OG8h8DH4mow_.marker = Marker_tySequence__WcRaozAFgJ6OG8h8DH4mow;
}

