/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 32

#include "nimbase.h"
#include <string.h>
#include <setjmp.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_OptParser__Sj2pYlEalgMxSDrjh9cml3w tyObject_OptParser__Sj2pYlEalgMxSDrjh9cml3w;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tyTuple__7q7q3E6Oj24ZNVJb9aonhAg;
typedef struct Exception Exception;
typedef struct tySequence__QbmGqFaLnb1IWWToREeaIA tySequence__QbmGqFaLnb1IWWToREeaIA;
typedef struct TSafePoint TSafePoint;
typedef struct tyTuple__oa1dFn55BmC688WoXKTtUg tyTuple__oa1dFn55BmC688WoXKTtUg;
typedef struct tyTuple__cyyQdcuoDUp88Doe6rM7kA tyTuple__cyyQdcuoDUp88Doe6rM7kA;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
typedef struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA;
typedef NU8 tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w;
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
typedef NU8 tyEnum_CmdLineKind__9aoMk7Iv3Zzg24yOE69bmFEA;
struct tyObject_OptParser__Sj2pYlEalgMxSDrjh9cml3w {
  RootObj Sup;
NI pos;
NIM_BOOL inShortState;
NIM_BOOL allowWhitespaceAfterColon;
tySet_tyChar__nmiMWKVIe46vacnhAFrQvw shortNoVal;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* longNoVal;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cmds;
NI idx;
tyEnum_CmdLineKind__9aoMk7Iv3Zzg24yOE69bmFEA kind;
NimStringDesc* key;
NimStringDesc* val;
};
typedef NU8 tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NimStringDesc* tyArray__sMpvt1sOxOJ3LFGulnbeMQ[4];
struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
};
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__QbmGqFaLnb1IWWToREeaIA* trace;
Exception* up;
};
struct TSafePoint {
TSafePoint* prev;
NI status;
jmp_buf context;
};
typedef NimStringDesc* tyArray__Re75IspeoxXy2oCZHwcRrA[2];
typedef NU8 tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU16 tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw;
typedef NU8 tySet_tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ[14];
typedef NU8 tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA;
typedef tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA tyArray__aKb7f3tXhAVVrqA9c1fkI9aQ[4];
typedef NU8 tySet_tyEnum_MsgFlag__20vXBZGIzyW7fngd9aGsclQ;
typedef NU8 tySet_tyEnum_TInfoOSProp__zwoAJqKVL5t9aBqjgBrDcAA;
struct tyTuple__oa1dFn55BmC688WoXKTtUg {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
NimStringDesc* Field3;
NimStringDesc* Field4;
NimStringDesc* Field5;
NimStringDesc* Field6;
NimStringDesc* Field7;
NimStringDesc* Field8;
NimStringDesc* Field9;
NimStringDesc* Field10;
NimStringDesc* Field11;
tySet_tyEnum_TInfoOSProp__zwoAJqKVL5t9aBqjgBrDcAA Field12;
};
typedef tyTuple__oa1dFn55BmC688WoXKTtUg tyArray__zAjcTh151RgaydpulQUcEQ[33];
typedef NU8 tyEnum_Endianness__IxIU7d9c8Q9csHQviYDQM13A;
struct tyTuple__cyyQdcuoDUp88Doe6rM7kA {
NimStringDesc* Field0;
NI Field1;
tyEnum_Endianness__IxIU7d9c8Q9csHQviYDQM13A Field2;
NI Field3;
NI Field4;
};
typedef tyTuple__cyyQdcuoDUp88Doe6rM7kA tyArray__O7sksHvn7BNpHcBD2dBmog[26];
typedef NU8 tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA {
NCSTRING procname;
NI line;
NCSTRING filename;
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
struct tySequence__QbmGqFaLnb1IWWToREeaIA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuEndsWith)(NimStringDesc* s, NimStringDesc* suffix);
N_LIB_PRIVATE N_NIMCALL(void, setCmd__commands_829)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosunixToNativePath)(NimStringDesc* path, NimStringDesc* drive);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5302)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5264)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5309)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5307)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5258)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, npocmdLineRest)(tyObject_OptParser__Sj2pYlEalgMxSDrjh9cml3w* p);
N_LIB_PRIVATE N_NIMCALL(void, setCommandEarly__commands_832)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* command);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
N_LIB_PRIVATE N_NIMCALL(tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg, parseCommand__commands_817)(NimStringDesc* command);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuNormalize)(NimStringDesc* s);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(NI, hashString)(NimStringDesc* s);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(NI, nsuFindChar)(NimStringDesc* s, NIM_CHAR sub, NI start, NI last);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__system_7736)(NimStringDesc* s, NI first, NI last);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__system_7748)(NimStringDesc* s, NI first);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(void, processSwitch__commands_880)(NimStringDesc* switch_0, NimStringDesc* arg, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, expectArg__commands_262)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* switch_0, NimStringDesc* arg, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatSingleElem)(NimStringDesc* formatstr, NimStringDesc* a);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addPrefix__commands_171)(NimStringDesc* switch_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuToLowerAsciiStr)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__pureZstrutils_1627)(NimStringDesc* s, NimStringDesc* sub);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, removeTrailingDirSep__options_4131)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(void, addPath__nimblecmd_11)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* path, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, processCfgPath__commands_743)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* path, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuUnescape)(NimStringDesc* s, NimStringDesc* prefix, NimStringDesc* suffix);
N_LIB_PRIVATE N_NIMCALL(void, nossplitFile)(NimStringDesc* path, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPath__msgs_548)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosisAbsolute)(NimStringDesc* path);
static N_INLINE(NIM_BOOL, contains__pureZos_660)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item);
static N_INLINE(NI, find__pureZos_665)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item);
static N_INLINE(NimStringDesc*, slash___pureZos_121)(NimStringDesc* head, NimStringDesc* tail);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosjoinPath)(NimStringDesc* head, NimStringDesc* tail);
static N_INLINE(void, pushSafePoint)(TSafePoint* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, pathSubs__options_4207)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* p, NimStringDesc* config);
static N_INLINE(void, popSafePoint)(void);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isObj)(TNimType* obj, TNimType* subclass);
static N_INLINE(Exception*, nimBorrowCurrentException)(void);
static N_INLINE(void, popCurrentException)(void);
N_LIB_PRIVATE N_NIMCALL(void, reraiseException)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, processPath__commands_732)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* path, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NIM_BOOL notRelativeToProj);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosgetCurrentDir)(void);
static N_INLINE(void, warningDeprecated__msgs_1428)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getEnv__pureZos_418)(NimStringDesc* key, NimStringDesc* default_0);
static N_INLINE(NIM_BOOL, isEmpty__pathutils_94)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, slash___pathutils_112)(NimStringDesc* base, NimStringDesc* f);
N_LIB_PRIVATE N_NIMCALL(void, nimblePath__nimblecmd_2104)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* path, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, expectNoArg__commands_268)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* switch_0, NimStringDesc* arg, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, disableNimblePath__options_4134)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, clearNimblePath__options_4148)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___options_4108)(NimStringDesc* x, NimStringDesc* y);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuReplaceChar)(NimStringDesc* s, NIM_CHAR sub, NIM_CHAR by);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toAbsoluteDir__pathutils_72)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(void, processOnOffSwitchG__commands_244)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg op, NimStringDesc* arg, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TBackend__zoooocqvga73vZuhGAAy6A, parseEnum__commands_976)(NimStringDesc* s, tyEnum_TBackend__zoooocqvga73vZuhGAAy6A default_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__pureZstrutils_1631)(NimStringDesc* s, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars);
N_LIB_PRIVATE N_NIMCALL(void, splitSwitch__commands_183)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* switch_0, NimStringDesc** cmd, NimStringDesc** arg, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(void, invalidCmdLineOption__commands_178)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass, NimStringDesc* switch_0, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, specialDefine__commands_835)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* key, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreStyle)(NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(void, defineSymbol__condsyms_4)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols, NimStringDesc* symbol, NimStringDesc* value);
N_LIB_PRIVATE N_NIMCALL(void, undefSymbol__condsyms_8)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols, NimStringDesc* symbol);
N_LIB_PRIVATE N_NIMCALL(void, processCompile__commands_457)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, findFile__options_4487)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* f, NIM_BOOL suppressStdlib);
static N_INLINE(NIM_BOOL, isEmpty__options_4492)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(void, addExternalFileToCompile__extccomp_1087)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(void, addExternalFileToLink__extccomp_756)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, processOnOffSwitchOrList__commands_227)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ op, NimStringDesc* arg, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, listWarnings__msgs_1485)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, processSpecificNote__commands_274)(NimStringDesc* arg, tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw state, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* orig, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ, findStr__commands_321)(NimStringDesc* s, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ default_0);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ, findStr__commands_352)(NimStringDesc* s, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ default_0);
static N_INLINE(NIM_BOOL, contains__stdZenumutils_44)(NimStringDesc** a, NI aLen_0, NimStringDesc* item);
static N_INLINE(NI, find__stdZenumutils_49)(NimStringDesc** a, NI aLen_0, NimStringDesc* item);
static N_INLINE(void, X5BX5Deq___commands_430)(NU8* t, tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA key, NIM_BOOL val);
N_LIB_PRIVATE N_NIMCALL(void, listHints__msgs_1506)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, processOnOffSwitch__commands_209)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ op, NimStringDesc* arg, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hcrOn__options_582)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isVSCompatible__extccomp_577)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, addCompileOptionCmd__extccomp_701)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* option);
N_LIB_PRIVATE N_NIMCALL(void, addLinkOptionCmd__extccomp_698)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* option);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, findModule__options_4507)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* modulename, NimStringDesc* currentModule);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw, nameToOS__platform_816)(NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuJoinSep)(NimStringDesc** a, NI aLen_0, NimStringDesc* sep);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ*, listOSnames__platform_838)(void);
N_LIB_PRIVATE N_NIMCALL(void, setTarget__platform_760)(tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA* t, tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw o, tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ c);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ, nameToCPU__platform_857)(NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ*, listCPUnames__platform_879)(void);
N_LIB_PRIVATE N_NIMCALL(NI, nsuParseInt)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(void, writeVersionInfo__commands_159)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass);
N_LIB_PRIVATE N_NIMCALL(void, msgWriteln__msgs_657)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* s, tySet_tyEnum_MsgFlag__20vXBZGIzyW7fngd9aGsclQ flags);
N_LIB_PRIVATE N_NIMCALL(void, msgQuit__msgs_452)(NI8 x);
N_LIB_PRIVATE N_NIMCALL(void, writeAdvancedUsage__commands_145)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass);
N_LIB_PRIVATE N_NIMCALL(void, writeFullhelp__commands_152)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass);
N_LIB_PRIVATE N_NIMCALL(void, helpOnError__commands_137)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getCommandLineDesc__commands_134)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, setUseIc__ast_995)(NIM_BOOL useIc);
N_LIB_PRIVATE N_NIMCALL(void, putEnv__pureZos_426)(NimStringDesc* key, NimStringDesc* val);
N_LIB_PRIVATE N_NIMCALL(void, setCC__extccomp_651)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* ccname, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, track__commands_778)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* arg, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ*, nsuSplitChar)(NimStringDesc* s, NIM_CHAR sep, NI maxsplit);
N_LIB_PRIVATE N_NIMCALL(void, setTrackingInfo__commands_759)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* dirty, NimStringDesc* file, NimStringDesc* line, NimStringDesc* column, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(NI, npuParseInt)(NimStringDesc* s, NI* number, NI start);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, makeAbsolute__commands_756)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, normalizePath__pureZpathnorm_127)(NimStringDesc* path, NIM_CHAR dirSep);
static N_INLINE(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw, newLineInfo__msgs_408)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename, NI line, NI col);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw, newLineInfo__msgs_391)(NI32 fileInfoIdx, NI line, NI col);
N_LIB_PRIVATE N_NIMCALL(NI32, fileInfoIdx__msgs_376)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(void, setDirtyFile__msgs_556)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(void, trackDirty__commands_770)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* arg, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, trackIde__commands_786)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg cmd, NimStringDesc* arg, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, dynlibOverride__commands_795)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* switch_0, NimStringDesc* arg, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, inclDynlibOverride__options_4671)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* lib);
N_LIB_PRIVATE N_NIMCALL(tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw, parseEnum__commands_1298)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g, parseEnum__commands_1351)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(void, cppDefine__options_2530)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* c, NimStringDesc* define);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__systemZassertions_56)(NimStringDesc* msg);
N_LIB_PRIVATE N_NIMCALL(void, nstPut)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, NimStringDesc* key, NimStringDesc* val);
N_LIB_PRIVATE N_NIMCALL(void, handleStdinInput__commands_807)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getNimcacheDir__options_4185)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, setConfigVar__options_4059)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* key, NimStringDesc* val);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___systemZdollars_3)(NI x);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDynlibOverride__options_4674)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* lib);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_2, ".nims", 5);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_3, "c", 1);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_4, "cc", 2);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_5, "compile", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_6, "compiletoc", 10);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_7, "cpp", 3);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_8, "compiletocpp", 12);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_9, "objc", 4);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_10, "compiletooc", 11);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_11, "js", 2);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_12, "compiletojs", 11);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_13, "r", 1);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_14, "run", 3);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_15, "check", 5);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_16, "e", 1);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_17, "doc0", 4);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_18, "doc2", 4);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_19, "doc", 3);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_20, "doc2tex", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_21, "rst2html", 8);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_22, "rst2tex", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_23, "jsondoc0", 8);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_24, "jsondoc2", 8);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_25, "jsondoc", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_26, "ctags", 5);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_27, "buildindex", 10);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_28, "gendepend", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_29, "dump", 4);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_30, "parse", 5);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_31, "rod", 3);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_32, "secret", 6);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_33, "nop", 3);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_34, "help", 4);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_35, "jsonscript", 10);
static NIM_CONST tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA TM__aFkIL74T1q8RouIu9auwZ3g_36 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01,
0x00, 0x00, 0x00, 0x00}
;
static NIM_CONST tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA TM__aFkIL74T1q8RouIu9auwZ3g_37 = {
0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00,
0x06, 0x10, 0x20, 0x00}
;
extern TNimType NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_38, "eval", 4);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_39, "path", 4);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_40, "p", 1);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_41, "nimblepath", 10);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_42, "babelpath", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_43, "nonimblepath", 12);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_44, "nobabelpath", 11);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_45, "clearnimblepath", 15);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_46, "excludepath", 11);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_47, "nimcache", 8);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_48, "out", 3);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_49, "o", 1);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_50, "outdir", 6);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_51, "usenimcache", 11);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_52, "docseesrcurl", 12);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_53, "docroot", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_54, "backend", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_55, "b", 1);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_56, "doccmd", 6);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_57, "define", 6);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_58, "d", 1);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_59, "undef", 5);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_60, "u", 1);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_61, "link", 4);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_62, "debuginfo", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_63, "embedsrc", 8);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_64, "compileonly", 11);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_65, "nolinking", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_66, "nomain", 6);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_67, "forcebuild", 10);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_68, "f", 1);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_69, "project", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_70, "gc", 2);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_71, "mm", 2);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_72, "warnings", 8);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_73, "w", 1);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_74, "warning", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_75, "hint", 4);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_76, "warningaserror", 14);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_77, "hintaserror", 11);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_78, "hints", 5);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_79, "threadanalysis", 14);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_80, "stacktrace", 10);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_81, "stacktracemsgs", 14);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_82, "excessivestacktrace", 19);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_83, "linetrace", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_84, "debugger", 8);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_85, "g", 1);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_86, "profiler", 8);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_87, "memtracker", 10);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_88, "hotcodereloading", 16);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_89, "checks", 6);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_90, "x", 1);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_91, "floatchecks", 11);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_92, "infchecks", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_93, "nanchecks", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_94, "objchecks", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_95, "fieldchecks", 11);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_96, "rangechecks", 11);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_97, "boundchecks", 11);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_98, "refchecks", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_99, "overflowchecks", 14);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_100, "staticboundchecks", 17);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_101, "stylechecks", 11);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_102, "linedir", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_103, "assertions", 10);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_104, "a", 1);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_105, "threads", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_106, "tlsemulation", 12);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_107, "implicitstatic", 14);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_108, "patterns", 8);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_109, "trmacros", 8);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_110, "opt", 3);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_111, "app", 3);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_112, "passc", 5);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_113, "t", 1);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_114, "passl", 5);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_115, "l", 1);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_116, "cincludes", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_117, "clibdir", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_118, "clib", 4);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_119, "header", 6);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_120, "index", 5);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_121, "import", 6);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_122, "include", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_123, "listcmd", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_124, "asm", 3);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_125, "genmapping", 10);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_126, "os", 2);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_127, "cpu", 3);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_128, "maxloopiterationsvm", 19);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_129, "errormax", 8);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_130, "verbosity", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_131, "parallelbuild", 13);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_132, "version", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_133, "v", 1);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_134, "advanced", 8);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_135, "fullhelp", 8);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_136, "h", 1);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_137, "symbolfiles", 11);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_138, "incremental", 11);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_139, "ic", 2);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_140, "skipcfg", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_141, "skipprojcfg", 11);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_142, "skipusercfg", 11);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_143, "skipparentcfg", 13);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_144, "genscript", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_145, "gendeps", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_146, "colors", 6);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_147, "lib", 3);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_148, "putenv", 6);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_149, "track", 5);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_150, "trackdirty", 10);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_151, "suggest", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_152, "def", 3);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_153, "context", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_154, "usages", 6);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_155, "defusages", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_156, "stdout", 6);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_157, "filenames", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_158, "processing", 10);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_159, "unitsep", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_160, "listfullpaths", 13);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_161, "spellsuggest", 12);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_162, "declaredlocs", 12);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_163, "dynliboverride", 14);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_164, "dynliboverrideall", 17);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_165, "experimental", 12);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_166, "legacy", 6);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_167, "nocppexceptions", 15);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_168, "exceptions", 10);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_169, "cppdefine", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_170, "newruntime", 10);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_171, "seqsv2", 6);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_172, "stylecheck", 10);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_173, "showallmismatches", 17);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_174, "cppcompiletonamespace", 21);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_175, "docinternal", 11);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_176, "multimethods", 12);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_177, "expandmacro", 11);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_178, "expandarc", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_179, "useversion", 10);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_180, "benchmarkvm", 11);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_181, "profilevm", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_182, "sinkinference", 13);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_183, "cursorinference", 15);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_184, "panics", 6);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_185, "sourcemap", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_186, "deepcopy", 8);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_187, "nilseqs", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_188, "nilchecks", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_189, "symbol", 6);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_190, "taintmode", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_191, "cs", 2);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_192, "deadcodeelim", 12);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_193, "nimmainprefix", 13);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_194, "argument for command line option expected: \'$1\'", 47);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_195, "-", 1);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_196, "--", 2);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_198, "/home/runner/work/nightlies/nightlies/nim/compiler/commands.nim", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_197 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 174),
((NI) 14)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_199, "$nimblepath", 11);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_200, "$nimbledir", 10);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_201, "nimbledir", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_202, "\"", 1);
extern TNimType NTIvalueerror__5lcTdgqMq62cNGRwBb0thA_;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_204, "invalid path: ", 14);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_205 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 362),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_207 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 348),
((NI) 14)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_209, "/home/runner/work/nightlies/nightlies/nim/compiler/msgs.nim", 59);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_208 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_209),
((NI) 606),
((NI) 9)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_210, "\'$#\' is a deprecated alias for \'$#\'", 35);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_211, "NIMBLE_DIR", 10);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_212, "pkgs", 4);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_213, "invalid argument for command line option: \'$1\'", 46);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_214 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 178),
((NI) 14)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_215, "on", 2);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_216, "off", 3);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_217, "\'on\' or \'off\' expected, but \'$1\' found", 38);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_218 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 170),
((NI) 18)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_219, "@default", 8);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_220, "invalid backend: \'$1\'", 21);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_221 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 563),
((NI) 46)}
;
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__aFkIL74T1q8RouIu9auwZ3g_222 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x24,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_223, " ", 1);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_224, "invalid command line option: \'$1\'", 33);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_225 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 119),
((NI) 30)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_226 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 120),
((NI) 18)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_227, "nimQuirky", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_228, "release", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_229, "danger", 6);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_230, "quick", 5);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_231, "true", 4);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_232, "boehm", 5);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_233, "refc", 4);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_234, "markandsweep", 12);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_235, "destructors", 11);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_236, "arc", 3);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_237, "orc", 3);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_238, "hooks", 5);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_239, "go", 2);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_240, "none", 4);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_241, "stack", 5);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_242, "regions", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_243, "v2", 2);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_244, "boehmgc", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_245, "gcmarkandsweep", 14);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_246, "gcdestructors", 13);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_247, "gcarc", 5);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_248, "nimSeqsV2", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_249, "nimV2", 5);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_250, "gcorc", 5);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_251, "gchooks", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_252, "gogc", 4);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_253, "nogc", 4);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_254, "gcregions", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_255, "\'$#\' is deprecated, now a noop", 30);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_256, "\'arc\', \'orc\', \'markAndSweep\', \'boehm\', \'go\', \'none\', \'regions\', or \'refc\' expected, but \'$1\' found", 98);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_257 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 652),
((NI) 22)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_258, "list", 4);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_259, "\'on\', \'off\' or \'list\' expected, but \'$1\' found", 46);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_260 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 163),
((NI) 18)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_261, "all", 3);
static NIM_CONST tySet_tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ TM__aFkIL74T1q8RouIu9auwZ3g_262 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0xff, 0xff, 0xff, 0xff, 0x07}
;
static NIM_CONST tySet_tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ TM__aFkIL74T1q8RouIu9auwZ3g_263 = {
0x00, 0x00, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_264, "unknown $#: $#", 14);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_265 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 205),
((NI) 20)}
;
static NIM_CONST tyArray__Re75IspeoxXy2oCZHwcRrA TM__aFkIL74T1q8RouIu9auwZ3g_266 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_215),
((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_216)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_267 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 216),
((NI) 14)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_268, "only \'all:off\' is supported", 27);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_269 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 220),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_270 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 154),
((NI) 18)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_271, "native", 6);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_272, "gdb", 3);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_273, "expected native|gdb|on|off but found ", 37);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_274 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 677),
((NI) 16)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_275, "useNimRtl", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_276, "/MD", 3);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_277, "refchecks is deprecated!", 24);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_278, "speed", 5);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_279, "size", 4);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_280, "\'none\', \'speed\' or \'size\' expected, but \'$1\' found", 50);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_281 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 741),
((NI) 20)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_282, "gui", 3);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_283, "console", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_284, "staticlib", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_285, "executable", 10);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_286, "guiapp", 6);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_287, "consoleapp", 10);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_288, "library", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_289, "dll", 3);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_290, "\'gui\', \'console\' or \'lib\' expected, but \'$1\' found", 50);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_291 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 763),
((NI) 20)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_292, ", ", 2);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_293, "unknown OS: \'$1\'. Available options are: $2", 43);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_294 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 804),
((NI) 16)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_295, "unknown CPU: \'$1\'. Available options are: $2", 44);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_296 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 812),
((NI) 16)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_297, "invalid verbosity level: \'$1\'", 29);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_298 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 832),
((NI) 16)}
;
extern NIM_CONST tyArray__aKb7f3tXhAVVrqA9c1fkI9aQ NotesVerbosity__lineinfos_194;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_299, "Nim Compiler Version $1 [$2: $3]\012Compiled at $4\012Copyright (c) 2006-2023 by Andreas Rumpf\012", 89);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_300, "1.6.14", 6);
extern NIM_CONST tyArray__zAjcTh151RgaydpulQUcEQ OS__platform_518;
extern NIM_CONST tyArray__O7sksHvn7BNpHcBD2dBmog CPU__platform_705;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_301, "2023-06-27", 10);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_302, "git hash: 71ba2e7f3c5815d956b1ae0341b0743242b8fec6", 50);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_303, "active boot switches: -d:release -d:danger", 42);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_304, "Advanced commands:\012    compileToC, cc          compile project with C code generator\012    compileToCpp, cpp       compile project to C++ code\012    compileToOC, objc       compile project to Objective C code\012    js                      compile project to Javascript\012    e                       run a Nimscript file\012    rst2html                convert a reStructuredText file to HTML\012                            use `--docCmd:skip` to skip compiling snippets\012    rst2tex                 convert a reStructuredText file to LaTeX\012    doc2tex                 extract the documentation to a LaTeX file\012    jsondoc                 extract the documentation to a json file\012    ctags                   create a tags file\012    buildIndex              build an index for the whole documentation\012    genDepend               generate a DOT file containing the\012                            module dependency graph\012    dump                    dump all defined conditionals and search paths\012                            see also: --dump.format:json (useful with: `| jq`)\012    check                   checks the project for syntax and semantics\012                            (can be combined with --defusages)\012\012Runtime checks (see -x):\012  --objChecks:on|off        turn obj conversion checks on|off\012  --fieldChecks:on|off      turn case variant field checks on|off\012  --rangeChecks:on|off      turn range checks on|off\012  --boundChecks:on|off      turn bound checks on|off\012  --overflowChecks:on|off   turn int over-/underflow checks on|off\012  --floatChecks:on|off      turn all floating point (NaN/Inf) checks on|off\012  --nanChecks:on|off        turn NaN checks on|off\012  --infChecks:on|off        turn Inf checks on|off\012\012Advanced options:\012  --defusages:FILE,LINE,COL\012                            find the definition and all usages of a symbol\012  -o:FILE, --out:FILE       set the output filename\012  --outdir:DIR              set the path where the output file will be written\012  --usenimcache             will use `outdir=$nimcache`, whichever it resolves\012                            to after all options have been processed\012  --stdout:on|off           output to stdout\012  --colors:on|off           turn compiler messages coloring on|off\012  --filenames:abs|canonical|legacyRelProj\012                            customize how filenames are rendered in compiler messages,\012                            defaults to `abs` (absolute)\012  --processing:dots|filenames|off\012                            show files as they\'re being processed by nim compiler\012  --unitsep:on|off          use the ASCII unit separator (31) between error\012                            messages, useful for IDE-like tooling\012  --declaredLocs:on|off     show declaration locations in messages\012  --spellSuggest|:num       show at most `num >= 0` spelling suggestions on typos.\012                            if `num` is not specified (or `auto`), return\012                            an implementation defined set of suggestions.\012  --hints:on|off|list.      `on|off` enables or disables hints.\012                            `list` reports which hints are selected.\012  --hint:X:on|off           turn specific hint X on|off. `hint:X` means `hint:X:on`,\012                            as with similar flags. `all` is the set of all hints\012                            (only `all:off` is supported).\012  --hintAsError:X:on|off    turn specific hint X into an error on|off\012  -w:on|off|list, --warnings:on|off|list\012                            same as `--hints` but for warnings.\012  --warning:X:on|off        ditto\012  --warningAsError:X:on|off\012                            ditto\012  --styleCheck:off|hint|error\012                            produce hints or errors for Nim identifiers that\012                            do not adhere to Nim\'s official style guide\012                            https://nim-lang.org/docs/nep1.html\012  --styleCheck:usages       only enforce consistent spellings of identifiers,\012                            do not enforce the style on declarations\012  --showAllMismatches:on|off\012                            show all mismatching candidates in overloading\012                            resolution\012  --lib:PATH                set the system library path\012  --import:PATH             add an automatically imported module\012                            see also `patchFile` in nimscript which offers more flexibility.\012  --include:PATH            add an automatically included module\012  --nimcache:PATH           set the path used for generated files\012                            see also https://nim-lang.org/docs/nimc.html#compiler-usage-generated-c-code-directory\012  -c, --compileOnly:on|off  compile Nim files only; do not assemble or link\012  --noLinking:on|off        compile Nim and generated files but do not link\012  --noMain:on|off           do not generate a main procedure\012  --genScript:on|off        generate a compile script (in the \'nimcache\'\012                            subdirectory named \'compile_$project$scriptext\'),\012                            and a \'.deps\' file containing the dependencies;\012                            implies --compileOnly\012  --os:SYMBOL               set the target operating system (cross-compilation)\012  --cpu:SYMBOL              set the target processor (cross-compilation)\012  --debuginfo:on|off        enables debug information\012  -t, --passC:OPTION        pass an option to the C compiler\012  -l, --passL:OPTION        pass an option to the linker\012  --cc:SYMBOL               specify the C compiler\012  --cincludes:DIR           modify the C compiler header search path\012  --clibdir:DIR             modify the linker library search path\012  --clib:LIBNAME            link an additional C library\012                            (you should omit platform-specific extensions)\012  --project                 document the whole project (doc)\012  --docRoot:path            `nim doc --docRoot:/foo --project --outdir:docs /foo/sub/main.nim`\012                            generates: docs/sub/main.html\012                            if path == @pkg, will use nimble file enclosing dir\012                            if path == @path, will use first matching dir in `--path`\012                            if path == @default (the default and most useful), will use\012                            best match among @pkg,@path.\012                            if these are nonexistent, will use project path\012  -b, --backend:c|cpp|js|objc\012                            sets backend to use with commands like `nim doc` or `nim r`\012  --docCmd:cmd              if `cmd == skip`, skips runnableExamples\012                            else, runs runnableExamples with given options, e.g.:\012                            `--docCmd:\"-d:foo --threads:on\"`\012  --docSeeSrcUrl:url        activate \'see source\' for doc command\012                            (see doc.item.seesrc in config/nimdoc.cfg)\012  --docInternal             also generate documentation for non-exported symbols\012  --lineDir:on|off          generation of #line directive on|off\012  --embedsrc:on|off         embeds the original source code as comments\012                            in the generated output\012  --tlsEmulation:on|off     turn thread local storage emulation on|off\012  --implicitStatic:on|off   turn implicit compile time evaluation on|off\012  --trmacros:on|off         turn term rewriting macros on|off\012  --multimethods:on|off     turn multi-methods on|off\012  --hotCodeReloading:on|off\012                            turn support for hot code reloading on|off\012  --excessiveStackTrace:on|off\012                            stack traces use full file paths\012  --stackTraceMsgs:on|off   enable user defined stack frame msgs via `setFrameMsg`\012  --skipCfg:on|off          do not read the nim installation\'s configuration file\012  --skipUserCfg:on|off      do not read the user\'s configuration file\012  --skipParentCfg:on|off    do not read the parent dirs\' configuration files\012  --skipProjCfg:on|off      do not read the project\'s configuration file\012  --mm:orc|arc|refc|markAndSweep|boehm|go|none|regions\012                            select which memory management to use; default is \'refc\'\012                            recommended is \'orc\'\012  --exceptions:setjmp|cpp|goto|quirky\012                            select the exception handling implementation\012  --index:on|off            turn index file generation on|off\012  --putenv:key=value        set an environment variable\012  --NimblePath:PATH         add a path for Nimble support\012  --noNimblePath            deactivate the Nimble path\012  --clearNimblePath         empty the list of Nimble package search paths\012  --cppCompileToNamespace:namespace\012                            use the provided namespace for the generated C++ code,\012                            if no namespace is provided \"Nim\" will be used\012  --nimMainPrefix:prefix    use `{prefix}NimMain` instead of `NimMain` in the produced\012                            C/C++ code\012  --expandMacro:MACRO       dump every generated AST from MACRO\012  --expandArc:PROCNAME      show how PROCNAME looks like after diverse optimizations\012                            before the final backend phase (mostly ARC/ORC specific)\012  --excludePath:PATH        exclude a path from the list of search paths\012  --dynlibOverride:SYMBOL   marks SYMBOL so that dynlib:SYMBOL\012                            has no effect and can be statically linked instead;\012                            symbol matching is fuzzy so\012                            that --dynlibOverride:lua matches\012                            dynlib: \"liblua.so.3\"\012  --dynlibOverrideAll\012                            disables the effects of the dynlib pragma\012  --listCmd                 list the compilation commands; can be combined with\012                            `--hint:exec:on` and `--hint:link:on`\012  --asm                     produce assembler code\012  --parallelBuild:0|1|...   perform a parallel build\012                            value = number of processors (0 for auto-detect)\012  --incremental:on|off      only recompile the changed modules (experimental!)\012  --verbosity:0|1|2|3       set Nim\'s verbosity level (1 is default)\012  --errorMax:N              stop compilation after N errors; 0 means unlimited\012  --maxLoopIterationsVM:N   set max iterations for all VM loops\012  --experimental:implicitDeref|dotOperators|callOperator|parallel|destructor|notnil|dynamicBindSym|forLoopMacros|caseStmtMacros|codeReordering|compiletimeFFI|vmopsDanger|strictFuncs|views|strictNotNil|overloadableEnums|strictEffects|unicodeOperators|flexibleOptionalParams\012                            enable experimental language feature\012  --legacy:allowSemcheckedAstModification|checkUnsignedConversions\012                            enable obsolete/legacy language feature\012  --useVersion:1.0|1.2      emulate Nim version X of the Nim compiler, for testing\012  --benchmarkVM:on|off      turn benchmarking of VM code with cpuTime() on|off\012  --profileVM:on|off        turn compile time VM profiler on|off\012  --sinkInference:on|off    turn sink parameter inference on|off (default: on)\012  --panics:on|off           turn panics into process terminations (default: off)\012  --deepcopy:on|off         enable \'system.deepCopy\' for ``--mm:arc|orc``\012", 11061);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_305, "::\012\012    nim command [options] [projectfile] [arguments]\012\012Command:\012    compile, c              compile project with default code generator (C)\012    r                       compile to $nimcache/projname, run with [arguments]\012                            using backend specified by `--backend` (default: c)\012    doc                     generate the documentation for inputfile for\012                            backend specified by `--backend` (default: c)\012\012Arguments:\012  arguments are passed to the program being run (if --run option is selected)\012\012Options:\012  -p, --path:PATH           add path to search paths\012  -d, --define:SYMBOL(:VAL)\012                            define a conditional symbol\012                            (Optionally: Define the value for that symbol,\012                            see: \"compile time define pragmas\")\012  -u, --undef:SYMBOL        undefine a conditional symbol\012  -f, --forceBuild:on|off   force rebuilding of all modules\012  --stackTrace:on|off       turn stack tracing on|off\012  --lineTrace:on|off        turn line tracing on|off\012  --threads:on|off          turn support for multi-threading on|off\012  -x, --checks:on|off       turn all runtime checks on|off\012  -a, --assertions:on|off   turn assertions on|off\012  --opt:none|speed|size     optimize not at all or for speed|size\012                            Note: use -d:release for a release build!\012  --debugger:native         use native debugger (gdb)\012  --app:console|gui|lib|staticlib\012                            generate a console app|GUI app|DLL|static library\012  -r, --run                 run the compiled program with given arguments\012  --eval:cmd                evaluate nim code directly; e.g.: `nim --eval:\"echo 1\"`\012                            defaults to `e` (nimscript) but customizable:\012                            `nim r --eval:\'for a in stdin.lines: echo a\'`\012  --fullhelp                show all command line switches\012  -h, --help                show this help\012  -v, --version             show detailed version information\012\012Note, single letter options that take an argument require a colon. E.g. -p:PATH.\012Advanced commands:\012    compileToC, cc          compile project with C code generator\012    compileToCpp, cpp       compile project to C++ code\012    compileToOC, objc       compile project to Objective C code\012    js                      compile project to Javascript\012    e                       run a Nimscript file\012    rst2html                convert a reStructuredText file to HTML\012                            use `--docCmd:skip` to skip compiling snippets\012    rst2tex                 convert a reStructuredText file to LaTeX\012    doc2tex                 extract the documentation to a LaTeX file\012    jsondoc                 extract the documentation to a json file\012    ctags                   create a tags file\012    buildIndex              build an index for the whole documentation\012    genDepend               generate a DOT file containing the\012                            module dependency graph\012    dump                    dump all defined conditionals and search paths\012                            see also: --dump.format:json (useful with: `| jq`)\012    check                   checks the project for syntax and semantics\012                            (can be combined with --defusages)\012\012Runtime checks (see -x):\012  --objChecks:on|off        turn obj conversion checks on|off\012  --fieldChecks:on|off      turn case variant field checks on|off\012  --rangeChecks:on|off      turn range checks on|off\012  --boundChecks:on|off      turn bound checks on|off\012  --overflowChecks:on|off   turn int over-/underflow checks on|off\012  --floatChecks:on|off      turn all floating point (NaN/Inf) checks on|off\012  --nanChecks:on|off        turn NaN checks on|off\012  --infChecks:on|off        turn Inf checks on|off\012\012Advanced options:\012  --defusages:FILE,LINE,COL\012                            find the definition and all usages of a symbol\012  -o:FILE, --out:FILE       set the output filename\012  --outdir:DIR              set the path where the output file will be written\012  --usenimcache             will use `outdir=$nimcache`, whichever it resolves\012                            to after all options have been processed\012  --stdout:on|off           output to stdout\012  --colors:on|off           turn compiler messages coloring on|off\012  --filenames:abs|canonical|legacyRelProj\012                            customize how filenames are rendered in compiler messages,\012                            defaults to `abs` (absolute)\012  --processing:dots|filenames|off\012                            show files as they\'re being processed by nim compiler\012  --unitsep:on|off          use the ASCII unit separator (31) between error\012                            messages, useful for IDE-like tooling\012  --declaredLocs:on|off     show declaration locations in messages\012  --spellSuggest|:num       show at most `num >= 0` spelling suggestions on typos.\012                            if `num` is not specified (or `auto`), return\012                            an implementation defined set of suggestions.\012  --hints:on|off|list.      `on|off` enables or disables hints.\012                            `list` reports which hints are selected.\012  --hint:X:on|off           turn specific hint X on|off. `hint:X` means `hint:X:on`,\012                            as with similar flags. `all` is the set of all hints\012                            (only `all:off` is supported).\012  --hintAsError:X:on|off    turn specific hint X into an error on|off\012  -w:on|off|list, --warnings:on|off|list\012                            same as `--hints` but for warnings.\012  --warning:X:on|off        ditto\012  --warningAsError:X:on|off\012                            ditto\012  --styleCheck:off|hint|error\012                            produce hints or errors for Nim identifiers that\012                            do not adhere to Nim\'s official style guide\012                            https://nim-lang.org/docs/nep1.html\012  --styleCheck:usages       only enforce consistent spellings of identifiers,\012                            do not enforce the style on declarations\012  --showAllMismatches:on|off\012                            show all mismatching candidates in overloading\012                            resolution\012  --lib:PATH                set the system library path\012  --import:PATH             add an automatically imported module\012                            see also `patchFile` in nimscript which offers more flexibility.\012  --include:PATH            add an automatically included module\012  --nimcache:PATH           set the path used for generated files\012                            see also https://nim-lang.org/docs/nimc.html#compiler-usage-generated-c-code-directory\012  -c, --compileOnly:on|off  compile Nim files only; do not assemble or link\012  --noLinking:on|off        compile Nim and generated files but do not link\012  --noMain:on|off           do not generate a main procedure\012  --genScript:on|off        generate a compile script (in the \'nimcache\'\012                            subdirectory named \'compile_$project$scriptext\'),\012                            and a \'.deps\' file containing the dependencies;\012                            implies --compileOnly\012  --os:SYMBOL               set the target operating system (cross-compilation)\012  --cpu:SYMBOL              set the target processor (cross-compilation)\012  --debuginfo:on|off        enables debug information\012  -t, --passC:OPTION        pass an option to the C compiler\012  -l, --passL:OPTION        pass an option to the linker\012  --cc:SYMBOL               specify the C compiler\012  --cincludes:DIR           modify the C compiler header search path\012  --clibdir:DIR             modify the linker library search path\012  --clib:LIBNAME            link an additional C library\012                            (you should omit platform-specific extensions)\012  --project                 document the whole project (doc)\012  --docRoot:path            `nim doc --docRoot:/foo --project --outdir:docs /foo/sub/main.nim`\012                            generates: docs/sub/main.html\012                            if path == @pkg, will use nimble file enclosing dir\012                            if path == @path, will use first matching dir in `--path`\012                            if path == @default (the default and most useful), will use\012                            best match among @pkg,@path.\012                            if these are nonexistent, will use project path\012  -b, --backend:c|cpp|js|objc\012                            sets backend to use with commands like `nim doc` or `nim r`\012  --docCmd:cmd              if `cmd == skip`, skips runnableExamples\012                            else, runs runnableExamples with given options, e.g.:\012                            `--docCmd:\"-d:foo --threads:on\"`\012  --docSeeSrcUrl:url        activate \'see source\' for doc command\012                            (see doc.item.seesrc in config/nimdoc.cfg)\012  --docInternal             also generate documentation for non-exported symbols\012  --lineDir:on|off          generation of #line directive on|off\012  --embedsrc:on|off         embeds the original source code as comments\012                            in the generated output\012  --tlsEmulation:on|off     turn thread local storage emulation on|off\012  --implicitStatic:on|off   turn implicit compile time evaluation on|off\012  --trmacros:on|off         turn term rewriting macros on|off\012  --multimethods:on|off     turn multi-methods on|off\012  --hotCodeReloading:on|off\012                            turn support for hot code reloading on|off\012  --excessiveStackTrace:on|off\012                            stack traces use full file paths\012  --stackTraceMsgs:on|off   enable user defined stack frame msgs via `setFrameMsg`\012  --skipCfg:on|off          do not read the nim installation\'s configuration file\012  --skipUserCfg:on|off      do not read the user\'s configuration file\012  --skipParentCfg:on|off    do not read the parent dirs\' configuration files\012  --skipProjCfg:on|off      do not read the project\'s configuration file\012  --mm:orc|arc|refc|markAndSweep|boehm|go|none|regions\012                            select which memory management to use; default is \'refc\'\012                            recommended is \'orc\'\012  --exceptions:setjmp|cpp|goto|quirky\012                            select the exception handling implementation\012  --index:on|off            turn index file generation on|off\012  --putenv:key=value        set an environment variable\012  --NimblePath:PATH         add a path for Nimble support\012  --noNimblePath            deactivate the Nimble path\012  --clearNimblePath         empty the list of Nimble package search paths\012  --cppCompileToNamespace:namespace\012                            use the provided namespace for the generated C++ code,\012                            if no namespace is provided \"Nim\" will be used\012  --nimMainPrefix:prefix    use `{prefix}NimMain` instead of `NimMain` in the produced\012                            C/C++ code\012  --expandMacro:MACRO       dump every generated AST from MACRO\012  --expandArc:PROCNAME      show how PROCNAME looks like after diverse optimizations\012                            before the final backend phase (mostly ARC/ORC specific)\012  --excludePath:PATH        exclude a path from the list of search paths\012  --dynlibOverride:SYMBOL   marks SYMBOL so that dynlib:SYMBOL\012                            has no effect and can be statically linked instead;\012                            symbol matching is fuzzy so\012                            that --dynlibOverride:lua matches\012                            dynlib: \"liblua.so.3\"\012  --dynlibOverrideAll\012                            disables the effects of the dynlib pragma\012  --listCmd                 list the compilation commands; can be combined with\012                            `--hint:exec:on` and `--hint:link:on`\012  --asm                     produce assembler code\012  --parallelBuild:0|1|...   perform a parallel build\012                            value = number of processors (0 for auto-detect)\012  --incremental:on|off      only recompile the changed modules (experimental!)\012  --verbosity:0|1|2|3       set Nim\'s verbosity level (1 is default)\012  --errorMax:N              stop compilation after N errors; 0 means unlimited\012  --maxLoopIterationsVM:N   set max iterations for all VM loops\012  --experimental:implicitDeref|dotOperators|callOperator|parallel|destructor|notnil|dynamicBindSym|forLoopMacros|caseStmtMacros|codeReordering|compiletimeFFI|vmopsDanger|strictFuncs|views|strictNotNil|overloadableEnums|strictEffects|unicodeOperators|flexibleOptionalParams\012                            enable experimental language feature\012  --legacy:allowSemcheckedAstModification|checkUnsignedConversions\012                            enable obsolete/legacy language feature\012  --useVersion:1.0|1.2      emulate Nim version X of the Nim compiler, for testing\012  --benchmarkVM:on|off      turn benchmarking of VM code with cpuTime() on|off\012  --profileVM:on|off        turn compile time VM profiler on|off\012  --sinkInference:on|off    turn sink parameter inference on|off (default: on)\012  --panics:on|off           turn panics into process terminations (default: off)\012  --deepcopy:on|off         enable \'system.deepCopy\' for ``--mm:arc|orc``\012", 13143);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_306, "::\012\012    nim command [options] [projectfile] [arguments]\012\012Command:\012    compile, c              compile project with default code generator (C)\012    r                       compile to $nimcache/projname, run with [arguments]\012                            using backend specified by `--backend` (default: c)\012    doc                     generate the documentation for inputfile for\012                            backend specified by `--backend` (default: c)\012\012Arguments:\012  arguments are passed to the program being run (if --run option is selected)\012\012Options:\012  -p, --path:PATH           add path to search paths\012  -d, --define:SYMBOL(:VAL)\012                            define a conditional symbol\012                            (Optionally: Define the value for that symbol,\012                            see: \"compile time define pragmas\")\012  -u, --undef:SYMBOL        undefine a conditional symbol\012  -f, --forceBuild:on|off   force rebuilding of all modules\012  --stackTrace:on|off       turn stack tracing on|off\012  --lineTrace:on|off        turn line tracing on|off\012  --threads:on|off          turn support for multi-threading on|off\012  -x, --checks:on|off       turn all runtime checks on|off\012  -a, --assertions:on|off   turn assertions on|off\012  --opt:none|speed|size     optimize not at all or for speed|size\012                            Note: use -d:release for a release build!\012  --debugger:native         use native debugger (gdb)\012  --app:console|gui|lib|staticlib\012                            generate a console app|GUI app|DLL|static library\012  -r, --run                 run the compiled program with given arguments\012  --eval:cmd                evaluate nim code directly; e.g.: `nim --eval:\"echo 1\"`\012                            defaults to `e` (nimscript) but customizable:\012                            `nim r --eval:\'for a in stdin.lines: echo a\'`\012  --fullhelp                show all command line switches\012  -h, --help                show this help\012  -v, --version             show detailed version information\012\012Note, single letter options that take an argument require a colon. E.g. -p:PATH.\012", 2082);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_307, "writeonly", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_308, "readonly", 8);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_309, "stress", 6);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_310, "invalid option for --incremental: ", 34);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_311 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 865),
((NI) 22)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_312, "FILE,LINE,COLUMN expected", 25);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_313 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 400),
((NI) 27)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_314, "$1 is not a valid number", 24);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_315 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 379),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_316 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 381),
((NI) 14)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_317, "DIRTY_BUFFER,ORIGINAL_FILE,LINE,COLUMN expected", 47);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_318 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 394),
((NI) 27)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_319, "[DIRTY_BUFFER,]ORIGINAL_FILE,LINE,COLUMN expected", 49);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_320 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 412),
((NI) 14)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_321, "abs", 3);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_322, "canonical", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_323, "legacyrelproj", 13);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_324, "expected: abs|canonical|legacyRelProj, got: $1", 46);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_325 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 919),
((NI) 20)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_326, "dots", 4);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_327, "expected: dots|filenames|off, got: $1", 37);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_328 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 929),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_329 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 146),
((NI) 14)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_330, "\037", 1);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_331, "auto", 4);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_333, "unknown experimental feature", 28);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_334 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 952),
((NI) 18)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_336, "unknown obsolete feature", 24);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_337 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 957),
((NI) 16)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_338, "noCppExceptions", 15);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_339, "setjmp", 6);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_340, "quirky", 6);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_341, "goto", 4);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_342, "\'goto\', \'setjmp\', \'cpp\' or \'quirky\' expected, but \'$1\' found", 60);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_343 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 968),
((NI) 20)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_344, "newruntime is deprecated, use arc/orc instead!", 46);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_345, "commands.nim(977, 15) `conf != nil` ", 36);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_346, "nimOwnedEnabled", 15);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_347, "error", 5);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_348, "\'off\', \'hint\', \'error\' or \'usages\' expected, but \'$1\' found", 59);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_349 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 997),
((NI) 20)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_350, "Nim", 3);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_351, "cppCompileToNamespace", 21);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_352, "T", 1);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_353, "1.0", 3);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_354, "1.2", 3);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_355, "NimMajor", 8);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_356, "1", 1);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_357, "NimMinor", 8);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_358, "0", 1);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_359, "nimOldRelativePathBehavior", 26);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_360, "nimDoesntTrackDefects", 21);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_361, "2", 1);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_362, "unknown Nim version; currently supported values are: `1.0`, `1.2`", 65);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_363 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 1032),
((NI) 16)}
;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_364, "NimPatch", 8);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_365, "100", 3);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_366, "nimPanics", 9);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_367, "stdinfile", 9);
extern NIM_CONST tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw gCmdLineInfo__msgs_414;
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_368, "cmdfile", 7);
STRING_LITERAL(TM__aFkIL74T1q8RouIu9auwZ3g_369, "generational", 12);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_370 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 263),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_371 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 269),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_372 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 279),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__aFkIL74T1q8RouIu9auwZ3g_373 = {((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_198),
((NI) 288),
((NI) 20)}
;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5211;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern Exception* currException__system_2566;
extern Exception* currException__system_2566;
extern Exception* currException__system_2566;
extern tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw eqTypeFlags__ast_481;
N_LIB_PRIVATE N_NIMCALL(void, setCmd__commands_829)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd) {
	(*conf).cmd = cmd;
	switch (cmd) {
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 2):
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 6):
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 7):
	{
		(*conf).backend = ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 1);
	}
	break;
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 3):
	{
		(*conf).backend = ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2);
	}
	break;
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 4):
	{
		(*conf).backend = ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 4);
	}
	break;
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 5):
	{
		(*conf).backend = ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 3);
	}
	break;
	default:
	{
	}
	break;
	}
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5302)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5264)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5307)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5258((&gch__system_5211.zct), c);
}
static N_INLINE(void, decRef__system_5309)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5307(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5264(src);
		incRef__system_5302(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5264((*dest));
		decRef__system_5309(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5264(p);
	decRef__system_5309(T1_);
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg, parseCommand__commands_817)(NimStringDesc* command) {
	tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg result;
	NimStringDesc* T1_;
	result = (tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg)0;
	T1_ = NIM_NIL;
	T1_ = nsuNormalize(command);
	switch (hashString(T1_) & 63) {
	case 0: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_10))) goto LA4_;
break;
	case 1: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_17))) goto LA10_;
break;
	case 8: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_23))) goto LA15_;
break;
	case 10: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_4))) goto LA2_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_12))) goto LA5_;
break;
	case 11: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_28))) goto LA19_;
break;
	case 13: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_19))) goto LA11_;
break;
	case 14: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_25))) goto LA16_;
break;
	case 15: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_31))) goto LA22_;
break;
	case 16: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_16))) goto LA9_;
break;
	case 19: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_8))) goto LA3_;
break;
	case 20: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_24))) goto LA16_;
break;
	case 25: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_3))) goto LA2_;
break;
	case 27: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_11))) goto LA5_;
break;
	case 29: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_27))) goto LA18_;
break;
	case 31: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_9))) goto LA4_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_18))) goto LA11_;
break;
	case 32: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_5))) goto LA2_;
break;
	case 34: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_13))) goto LA6_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_29))) goto LA20_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_33))) goto LA24_;
break;
	case 35: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_35))) goto LA25_;
break;
	case 36: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_30))) goto LA21_;
break;
	case 39: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_21))) goto LA13_;
break;
	case 41: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_14))) goto LA7_;
break;
	case 42: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_15))) goto LA8_;
break;
	case 44: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_34))) goto LA24_;
break;
	case 45: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_22))) goto LA14_;
break;
	case 48: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_6))) goto LA2_;
break;
	case 53: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_20))) goto LA12_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_32))) goto LA23_;
break;
	case 59: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_7))) goto LA3_;
break;
	case 60: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_26))) goto LA17_;
break;
	}
	goto LA26_;
	LA2_: ;
	{
		result = ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 2);
	}
	goto LA27_;
	LA3_: ;
	{
		result = ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 3);
	}
	goto LA27_;
	LA4_: ;
	{
		result = ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 4);
	}
	goto LA27_;
	LA5_: ;
	{
		result = ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 5);
	}
	goto LA27_;
	LA6_: ;
	{
		result = ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 6);
	}
	goto LA27_;
	LA7_: ;
	{
		result = ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 7);
	}
	goto LA27_;
	LA8_: ;
	{
		result = ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 8);
	}
	goto LA27_;
	LA9_: ;
	{
		result = ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 12);
	}
	goto LA27_;
	LA10_: ;
	{
		result = ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 13);
	}
	goto LA27_;
	LA11_: ;
	{
		result = ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 14);
	}
	goto LA27_;
	LA12_: ;
	{
		result = ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 15);
	}
	goto LA27_;
	LA13_: ;
	{
		result = ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 16);
	}
	goto LA27_;
	LA14_: ;
	{
		result = ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 17);
	}
	goto LA27_;
	LA15_: ;
	{
		result = ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 18);
	}
	goto LA27_;
	LA16_: ;
	{
		result = ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 19);
	}
	goto LA27_;
	LA17_: ;
	{
		result = ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 20);
	}
	goto LA27_;
	LA18_: ;
	{
		result = ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 21);
	}
	goto LA27_;
	LA19_: ;
	{
		result = ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 22);
	}
	goto LA27_;
	LA20_: ;
	{
		result = ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 23);
	}
	goto LA27_;
	LA21_: ;
	{
		result = ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 9);
	}
	goto LA27_;
	LA22_: ;
	{
		result = ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 10);
	}
	goto LA27_;
	LA23_: ;
	{
		result = ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 24);
	}
	goto LA27_;
	LA24_: ;
	{
		result = ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 25);
	}
	goto LA27_;
	LA25_: ;
	{
		result = ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 26);
	}
	goto LA27_;
	LA26_: ;
	{
		result = ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 1);
	}
	LA27_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
N_LIB_PRIVATE N_NIMCALL(void, setCommandEarly__commands_832)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* command) {
	NimStringDesc* T1_;
	tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg T2_;
	T1_ = NIM_NIL;
	T1_ = (*conf).command; (*conf).command = copyStringRC1(command);
	if (T1_) nimGCunrefNoCycle(T1_);
	T2_ = (tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg)0;
	T2_ = parseCommand__commands_817(command);
	setCmd__commands_829(conf, T2_);
	switch ((*conf).cmd) {
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 16):
	case ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 17):
	{
		nimCopyMem((void*)(*conf).foreignPackageNotes, (NIM_CONST void*)TM__aFkIL74T1q8RouIu9auwZ3g_36, 12);
	}
	break;
	default:
	{
		nimCopyMem((void*)(*conf).foreignPackageNotes, (NIM_CONST void*)TM__aFkIL74T1q8RouIu9auwZ3g_37, 12);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, processArgument__commands_1522)(tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass, tyObject_OptParser__Sj2pYlEalgMxSDrjh9cml3w* p, NI* argsCount, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*argsCount) == ((NI) 0));
		if (!(T3_)) goto LA4_;
		T3_ = (*config).implicitCmd;
		LA4_: ;
		if (!T3_) goto LA5_;
		(*argsCount) += ((NI) 1);
	}
	LA5_: ;
	{
		if (!((*argsCount) == ((NI) 0))) goto LA9_;
		{
			NIM_BOOL T13_;
			T13_ = (NIM_BOOL)0;
			T13_ = nsuEndsWith((*p).key, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_2));
			if (!T13_) goto LA14_;
			setCmd__commands_829(config, ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 12));
			(*config).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 2)) & 63);
			asgnRef((void**) (&(*config).projectName), nosunixToNativePath((*p).key, ((NimStringDesc*) NIM_NIL)));
			asgnRef((void**) (&(*config).arguments), npocmdLineRest(p));
			result = NIM_TRUE;
		}
		goto LA11_;
		LA14_: ;
		{
			if (!!((pass == ((tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w) 1)))) goto LA17_;
			setCommandEarly__commands_832(config, (*p).key);
		}
		goto LA11_;
		LA17_: ;
		LA11_: ;
	}
	goto LA7_;
	LA9_: ;
	{
		{
			NI T24_;
			NimStringDesc* T25_;
			if (!(pass == ((tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w) 0))) goto LA22_;
			asgnRef((void**) (&(*config).commandArgs), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*config).commandArgs), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
			T24_ = (*config).commandArgs->Sup.len++;
			T25_ = NIM_NIL;
			T25_ = (*config).commandArgs->data[T24_]; (*config).commandArgs->data[T24_] = copyStringRC1((*p).key);
			if (T25_) nimGCunrefNoCycle(T25_);
		}
		LA22_: ;
		{
			if (!((*argsCount) == ((NI) 1))) goto LA28_;
			{
				NIM_BOOL T32_;
				T32_ = (NIM_BOOL)0;
				T32_ = nsuEndsWith((*p).key, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_2));
				if (!T32_) goto LA33_;
				(*config).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 2)) & 63);
			}
			LA33_: ;
			{
				if (!(((*config).projectName ? (*config).projectName->Sup.len : 0) == ((NI) 0))) goto LA37_;
				asgnRef((void**) (&(*config).projectName), nosunixToNativePath((*p).key, ((NimStringDesc*) NIM_NIL)));
			}
			LA37_: ;
			asgnRef((void**) (&(*config).arguments), npocmdLineRest(p));
			result = NIM_TRUE;
		}
		LA28_: ;
	}
	LA7_: ;
	(*argsCount) += ((NI) 1);
	return result;
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c) {
	(*dest).data[(*dest).Sup.len] = c;
	(*dest).data[(NI)((*dest).Sup.len + ((NI) 1))] = 0;
	(*dest).Sup.len += ((NI) 1);
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addPrefix__commands_171)(NimStringDesc* switch_0) {
	NimStringDesc* result;
	result = NIM_NIL;
	{
		NimStringDesc* T5_;
		if (!((switch_0 ? switch_0->Sup.len : 0) <= ((NI) 1))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = rawNewString((switch_0 ? switch_0->Sup.len : 0) + 1);
appendString(T5_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_195));
appendString(T5_, switch_0);
		result = T5_;
	}
	goto LA1_;
	LA3_: ;
	{
		NimStringDesc* T7_;
		T7_ = NIM_NIL;
		T7_ = rawNewString((switch_0 ? switch_0->Sup.len : 0) + 2);
appendString(T7_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_196));
appendString(T7_, switch_0);
		result = T7_;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, expectArg__commands_262)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* switch_0, NimStringDesc* arg, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	{
		NimStringDesc* T5_;
		NimStringDesc* T6_;
		if (!((arg ? arg->Sup.len : 0) == 0)) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = addPrefix__commands_171(switch_0);
		T6_ = NIM_NIL;
		T6_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_194), T5_);
		liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T6_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_197, NIM_FALSE);
	}
	LA3_: ;
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(NI, find__pureZos_665)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item) {
	NI result;
{	result = (NI)0;
	result = ((NI) 0);
	{
		NIM_CHAR i;
		NI i_2;
		i = (NIM_CHAR)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < aLen_0)) goto LA3;
				i = a[i_2];
				{
					if (!((NU8)(i) == (NU8)(item))) goto LA6_;
					goto BeforeRet_;
				}
				LA6_: ;
				result += ((NI) 1);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__pureZos_660)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item) {
	NIM_BOOL result;
	NI T1_;
{	result = (NIM_BOOL)0;
	T1_ = (NI)0;
	T1_ = find__pureZos_665(a, aLen_0, item);
	result = (((NI) 0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NimStringDesc*, slash___pureZos_121)(NimStringDesc* head, NimStringDesc* tail) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = nosjoinPath(head, tail);
	return result;
}
static N_INLINE(void, pushSafePoint)(TSafePoint* s) {
	(*s).prev = excHandler__system_2565;
	excHandler__system_2565 = s;
}
static N_INLINE(void, popSafePoint)(void) {
	excHandler__system_2565 = (*excHandler__system_2565).prev;
}
static N_INLINE(Exception*, nimBorrowCurrentException)(void) {
	Exception* result;
	result = NIM_NIL;
	result = currException__system_2566;
	return result;
}
static N_INLINE(void, popCurrentException)(void) {
	asgnRef((void**) (&currException__system_2566), (*currException__system_2566).up);
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, processCfgPath__commands_743)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* path, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NimStringDesc* volatile result;
	NimStringDesc* path_2;
	NimStringDesc* basedir;
	NimStringDesc* T8_;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T9_;
	NimStringDesc* p;
	TSafePoint TM__aFkIL74T1q8RouIu9auwZ3g_203;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((NI) 0) < (path ? path->Sup.len : 0));
		if (!(T3_)) goto LA4_;
		T3_ = ((NU8)(path->data[((NI) 0)]) == (NU8)(34));
		LA4_: ;
		if (!T3_) goto LA5_;
		path_2 = nsuUnescape(path, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_202), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_202));
	}
	goto LA1_;
	LA5_: ;
	{
		path_2 = path;
	}
	LA1_: ;
	T8_ = NIM_NIL;
	T8_ = toFullPath__msgs_548(conf, info.fileIndex);
	nimZeroMem((void*)(&T9_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	nossplitFile(T8_, (&T9_));
	basedir = T9_.Field0;
	{
		NIM_BOOL T12_;
		T12_ = (NIM_BOOL)0;
		T12_ = nosisAbsolute(path_2);
		if (T12_) goto LA13_;
		T12_ = contains__pureZos_660((path_2) ? (path_2->data) : NIM_NIL, (path_2 ? path_2->Sup.len : 0), 36);
		LA13_: ;
		if (!T12_) goto LA14_;
		p = path_2;
	}
	goto LA10_;
	LA14_: ;
	{
		p = slash___pureZos_121(basedir, path_2);
	}
	LA10_: ;
	pushSafePoint(&TM__aFkIL74T1q8RouIu9auwZ3g_203);
	TM__aFkIL74T1q8RouIu9auwZ3g_203.status = _setjmp(TM__aFkIL74T1q8RouIu9auwZ3g_203.context);
	if (TM__aFkIL74T1q8RouIu9auwZ3g_203.status == 0) {
	result = pathSubs__options_4207(conf, p, basedir);
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIvalueerror__5lcTdgqMq62cNGRwBb0thA_))) {
			NimStringDesc* T19_;
			TM__aFkIL74T1q8RouIu9auwZ3g_203.status = 0;
			T19_ = NIM_NIL;
			T19_ = rawNewString((p ? p->Sup.len : 0) + 14);
appendString(T19_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_204));
appendString(T19_, p);
			liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T19_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_205, NIM_FALSE);
			result = copyString(p);
			popCurrentException();
		}
	}
	if (TM__aFkIL74T1q8RouIu9auwZ3g_203.status != 0) reraiseException();
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, processPath__commands_732)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* path, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NIM_BOOL notRelativeToProj) {
	NimStringDesc* volatile result;
	NimStringDesc* p;
	TSafePoint TM__aFkIL74T1q8RouIu9auwZ3g_206;
	NimStringDesc* T12_;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T13_;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nosisAbsolute(path);
		if (T3_) goto LA4_;
		T3_ = contains__pureZos_660((path) ? (path->data) : NIM_NIL, (path ? path->Sup.len : 0), 36);
		LA4_: ;
		if (!T3_) goto LA5_;
		p = path;
	}
	goto LA1_;
	LA5_: ;
	{
		NimStringDesc* T10_;
		if (!notRelativeToProj) goto LA8_;
		T10_ = NIM_NIL;
		T10_ = nosgetCurrentDir();
		p = slash___pureZos_121(T10_, path);
	}
	goto LA1_;
	LA8_: ;
	{
		p = slash___pureZos_121((*conf).projectPath, path);
	}
	LA1_: ;
	pushSafePoint(&TM__aFkIL74T1q8RouIu9auwZ3g_206);
	TM__aFkIL74T1q8RouIu9auwZ3g_206.status = _setjmp(TM__aFkIL74T1q8RouIu9auwZ3g_206.context);
	if (TM__aFkIL74T1q8RouIu9auwZ3g_206.status == 0) {
	T12_ = NIM_NIL;
	T12_ = toFullPath__msgs_548(conf, info.fileIndex);
	nimZeroMem((void*)(&T13_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	nossplitFile(T12_, (&T13_));
	result = pathSubs__options_4207(conf, p, T13_.Field0);
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIvalueerror__5lcTdgqMq62cNGRwBb0thA_))) {
			NimStringDesc* T16_;
			TM__aFkIL74T1q8RouIu9auwZ3g_206.status = 0;
			T16_ = NIM_NIL;
			T16_ = rawNewString((p ? p->Sup.len : 0) + 14);
appendString(T16_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_204));
appendString(T16_, p);
			liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T16_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_207, NIM_FALSE);
			result = copyString(p);
			popCurrentException();
		}
	}
	if (TM__aFkIL74T1q8RouIu9auwZ3g_206.status != 0) reraiseException();
	return result;
}
static N_INLINE(void, warningDeprecated__msgs_1428)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg) {
	liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 21), msg, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_208, NIM_FALSE);
}
static N_INLINE(NIM_BOOL, isEmpty__pathutils_94)(NimStringDesc* x) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((x ? x->Sup.len : 0) == ((NI) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, expectNoArg__commands_268)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* switch_0, NimStringDesc* arg, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	{
		NimStringDesc* T5_;
		NimStringDesc* T6_;
		if (!!(((arg ? arg->Sup.len : 0) == 0))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = addPrefix__commands_171(switch_0);
		T6_ = NIM_NIL;
		T6_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_213), T5_);
		liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T6_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_214, NIM_FALSE);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processOnOffSwitchG__commands_244)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg op, NimStringDesc* arg, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NimStringDesc* T1_;
	T1_ = NIM_NIL;
	T1_ = nsuNormalize(arg);
	if (eqStrings(T1_, ((NimStringDesc*) NIM_NIL))) goto LA2_;
	if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_215))) goto LA2_;
	if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_216))) goto LA3_;
	goto LA4_;
	LA2_: ;
	{
		(*conf).globalOptions = ((*conf).globalOptions | op);
	}
	goto LA5_;
	LA3_: ;
	{
		(*conf).globalOptions = ((*conf).globalOptions & ~ op);
	}
	goto LA5_;
	LA4_: ;
	{
		NimStringDesc* T9_;
		T9_ = NIM_NIL;
		T9_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_217), arg);
		liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T9_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_218, NIM_FALSE);
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, invalidCmdLineOption__commands_178)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass, NimStringDesc* switch_0, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	{
		NimStringDesc* T5_;
		if (!eqStrings(switch_0, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_223))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_224), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_195));
		liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T5_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_225, NIM_FALSE);
	}
	goto LA1_;
	LA3_: ;
	{
		NimStringDesc* T7_;
		NimStringDesc* T8_;
		T7_ = NIM_NIL;
		T7_ = addPrefix__commands_171(switch_0);
		T8_ = NIM_NIL;
		T8_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_224), T7_);
		liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T8_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_226, NIM_FALSE);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, splitSwitch__commands_183)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* switch_0, NimStringDesc** cmd, NimStringDesc** arg, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NI i;
	unsureAsgnRef((void**) (&(*cmd)), ((NimStringDesc*) NIM_NIL));
	i = ((NI) 0);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (i < (switch_0 ? switch_0->Sup.len : 0));
		if (!(T3_)) goto LA4_;
		T3_ = ((NU8)(switch_0->data[i]) == (NU8)(45));
		LA4_: ;
		if (!T3_) goto LA5_;
		i += ((NI) 1);
	}
	LA5_: ;
	{
		NIM_BOOL T9_;
		T9_ = (NIM_BOOL)0;
		T9_ = (i < (switch_0 ? switch_0->Sup.len : 0));
		if (!(T9_)) goto LA10_;
		T9_ = ((NU8)(switch_0->data[i]) == (NU8)(45));
		LA10_: ;
		if (!T9_) goto LA11_;
		i += ((NI) 1);
	}
	LA11_: ;
	{
		while (1) {
			if (!(i < (switch_0 ? switch_0->Sup.len : 0))) goto LA14;
			switch (((NU8)(switch_0->data[i]))) {
			case 97 ... 122:
			case 65 ... 90:
			case 48 ... 57:
			case 95:
			case 46:
			{
				unsureAsgnRef((void**) (&(*cmd)), addChar((*cmd), switch_0->data[i]));
			}
			break;
			default:
			{
				goto LA13;
			}
			break;
			}
			i += ((NI) 1);
		} LA14: ;
	} LA13: ;
	{
		if (!((switch_0 ? switch_0->Sup.len : 0) <= i)) goto LA19_;
		unsureAsgnRef((void**) (&(*arg)), ((NimStringDesc*) NIM_NIL));
	}
	goto LA17_;
	LA19_: ;
	{
		if (!(((NU8)(switch_0->data[i])) == ((NU8)(58)) || ((NU8)(switch_0->data[i])) == ((NU8)(61)))) goto LA22_;
		unsureAsgnRef((void**) (&(*arg)), substr__system_7748(switch_0, (NI)(i + ((NI) 1))));
	}
	goto LA17_;
	LA22_: ;
	{
		if (!((NU8)(switch_0->data[i]) == (NU8)(91))) goto LA25_;
		unsureAsgnRef((void**) (&(*arg)), substr__system_7748(switch_0, i));
	}
	goto LA17_;
	LA25_: ;
	{
		invalidCmdLineOption__commands_178(conf, pass, switch_0, info);
	}
	LA17_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, specialDefine__commands_835)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* key, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass) {
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = nsuCmpIgnoreStyle(key, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_227));
		if (!(T3_ == ((NI) 0))) goto LA4_;
		(*conf).exc = ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 4);
	}
	goto LA1_;
	LA4_: ;
	{
		NIM_BOOL T7_;
		NI T8_;
		NI T10_;
		T7_ = (NIM_BOOL)0;
		T8_ = (NI)0;
		T8_ = nsuCmpIgnoreStyle(key, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_228));
		T7_ = (T8_ == ((NI) 0));
		if (T7_) goto LA9_;
		T10_ = (NI)0;
		T10_ = nsuCmpIgnoreStyle(key, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_229));
		T7_ = (T10_ == ((NI) 0));
		LA9_: ;
		if (!T7_) goto LA11_;
		{
			if (!((5 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA15_;
			(*conf).options = ((*conf).options & ~ 724992);
			(*conf).globalOptions = ((*conf).globalOptions & ~ IL64(2147483712));
			(*conf).options |= ((NU32)1)<<((((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 15)) & 31);
		}
		LA15_: ;
	}
	goto LA1_;
	LA11_: ;
	LA1_: ;
	{
		NIM_BOOL T19_;
		NI T20_;
		NI T22_;
		T19_ = (NIM_BOOL)0;
		T20_ = (NI)0;
		T20_ = nsuCmpIgnoreStyle(key, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_229));
		T19_ = (T20_ == ((NI) 0));
		if (T19_) goto LA21_;
		T22_ = (NI)0;
		T22_ = nsuCmpIgnoreStyle(key, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_230));
		T19_ = (T22_ == ((NI) 0));
		LA21_: ;
		if (!T19_) goto LA23_;
		{
			if (!((5 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA27_;
			(*conf).options = ((*conf).options & ~ 661566);
			(*conf).globalOptions = ((*conf).globalOptions & ~ 64);
		}
		LA27_: ;
	}
	LA23_: ;
}
static N_INLINE(NIM_BOOL, isEmpty__options_4492)(NimStringDesc* x) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((x ? x->Sup.len : 0) == ((NI) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processCompile__commands_457)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename) {
	NimStringDesc* found;
	found = findFile__options_4487(conf, filename, NIM_FALSE);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isEmpty__options_4492(found);
		if (!T3_) goto LA4_;
		found = copyString(filename);
	}
	LA4_: ;
	addExternalFileToCompile__extccomp_1087(conf, found);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, processOnOffSwitchOrList__commands_227)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ op, NimStringDesc* arg, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NIM_BOOL result;
	NimStringDesc* T1_;
	result = (NIM_BOOL)0;
	result = NIM_FALSE;
	T1_ = NIM_NIL;
	T1_ = nsuNormalize(arg);
	if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_215))) goto LA2_;
	if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_216))) goto LA3_;
	if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_258))) goto LA4_;
	goto LA5_;
	LA2_: ;
	{
		(*conf).options = ((*conf).options | op);
	}
	goto LA6_;
	LA3_: ;
	{
		(*conf).options = ((*conf).options & ~ op);
	}
	goto LA6_;
	LA4_: ;
	{
		result = NIM_TRUE;
	}
	goto LA6_;
	LA5_: ;
	{
		NimStringDesc* T11_;
		T11_ = NIM_NIL;
		T11_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_259), arg);
		liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T11_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_260, NIM_FALSE);
	}
	LA6_: ;
	return result;
}
static N_INLINE(NI, find__stdZenumutils_49)(NimStringDesc** a, NI aLen_0, NimStringDesc* item) {
	NI result;
{	result = (NI)0;
	result = ((NI) 0);
	{
		NimStringDesc** i;
		NI i_2;
		i = (NimStringDesc**)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < aLen_0)) goto LA3;
				i = (&a[i_2]);
				{
					if (!eqStrings((*i), item)) goto LA6_;
					goto BeforeRet_;
				}
				LA6_: ;
				result += ((NI) 1);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__stdZenumutils_44)(NimStringDesc** a, NI aLen_0, NimStringDesc* item) {
	NIM_BOOL result;
	NI T1_;
{	result = (NIM_BOOL)0;
	T1_ = (NI)0;
	T1_ = find__stdZenumutils_49(a, aLen_0, item);
	result = (((NI) 0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, X5BX5Deq___commands_430)(NU8* t, tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA key, NIM_BOOL val) {
	{
		if (!val) goto LA3_;
		t[(NU)((key- 17))>>3] |=(1U<<((key- 17)&7U));
	}
	goto LA1_;
	LA3_: ;
	{
		t[(NU)((key- 17))>>3] &= ~(1U<<((key- 17)&7U));
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processSpecificNote__commands_274)(NimStringDesc* arg, tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw state, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* orig, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NimStringDesc* id;
	NI i;
	tySet_tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ notes;
	NIM_BOOL isBracket;
	NIM_BOOL isSomeHint;
	NimStringDesc* T32_;
	NimStringDesc* val;
	NimStringDesc* T62_;
	id = ((NimStringDesc*) NIM_NIL);
	i = ((NI) 0);
	nimZeroMem((void*)notes, sizeof(tySet_tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ));
	isBracket = NIM_FALSE;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (i < (arg ? arg->Sup.len : 0));
		if (!(T3_)) goto LA4_;
		T3_ = ((NU8)(arg->data[i]) == (NU8)(91));
		LA4_: ;
		if (!T3_) goto LA5_;
		isBracket = NIM_TRUE;
		i += ((NI) 1);
	}
	LA5_: ;
	{
		while (1) {
			NIM_BOOL T9_;
			T9_ = (NIM_BOOL)0;
			T9_ = (i < (arg ? arg->Sup.len : 0));
			if (!(T9_)) goto LA10_;
			T9_ = !((((NU8)(arg->data[i])) == ((NU8)(58)) || ((NU8)(arg->data[i])) == ((NU8)(61)) || ((NU8)(arg->data[i])) == ((NU8)(93))));
			LA10_: ;
			if (!T9_) goto LA8;
			id = addChar(id, arg->data[i]);
			i += ((NI) 1);
		} LA8: ;
	}
	{
		if (!isBracket) goto LA13_;
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = (i < (arg ? arg->Sup.len : 0));
			if (!(T17_)) goto LA18_;
			T17_ = ((NU8)(arg->data[i]) == (NU8)(93));
			LA18_: ;
			if (!T17_) goto LA19_;
			i += ((NI) 1);
		}
		goto LA15_;
		LA19_: ;
		{
			invalidCmdLineOption__commands_178(conf, pass, orig, info);
		}
		LA15_: ;
	}
	LA13_: ;
	{
		if (!(i == (arg ? arg->Sup.len : 0))) goto LA24_;
	}
	goto LA22_;
	LA24_: ;
	{
		NIM_BOOL T27_;
		T27_ = (NIM_BOOL)0;
		T27_ = (i < (arg ? arg->Sup.len : 0));
		if (!(T27_)) goto LA28_;
		T27_ = (((NU8)(arg->data[i])) == ((NU8)(58)) || ((NU8)(arg->data[i])) == ((NU8)(61)));
		LA28_: ;
		if (!T27_) goto LA29_;
		i += ((NI) 1);
	}
	goto LA22_;
	LA29_: ;
	{
		invalidCmdLineOption__commands_178(conf, pass, orig, info);
	}
	LA22_: ;
	isSomeHint = (state == ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 124) || state == ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 126));
	T32_ = NIM_NIL;
	T32_ = nsuNormalize(id);
	if (eqStrings(T32_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_261))) goto LA33_;
	goto LA34_;
	LA33_: ;
	{
		{
			if (!isSomeHint) goto LA39_;
			nimCopyMem((void*)notes, (NIM_CONST void*)TM__aFkIL74T1q8RouIu9auwZ3g_262, 14);
		}
		goto LA37_;
		LA39_: ;
		{
			nimCopyMem((void*)notes, (NIM_CONST void*)TM__aFkIL74T1q8RouIu9auwZ3g_263, 14);
		}
		LA37_: ;
	}
	goto LA35_;
	LA34_: ;
	{
		{
			tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ xX60gensym36_;
			if (!isSomeHint) goto LA45_;
			xX60gensym36_ = findStr__commands_321(id, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 0));
			{
				if (!!((xX60gensym36_ == ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 0)))) goto LA49_;
				nimZeroMem(notes, sizeof(tySet_tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ));
				notes[(NU)(xX60gensym36_)>>3] |=(1U<<((NU)(xX60gensym36_)&7U));
			}
			goto LA47_;
			LA49_: ;
			{
				tyArray__Re75IspeoxXy2oCZHwcRrA T52_;
				NimStringDesc* T53_;
				nimZeroMem((void*)T52_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T52_[0] = copyString(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_75));
				T52_[1] = copyString(id);
				T53_ = NIM_NIL;
				T53_ = nsuFormatOpenArray(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_264), T52_, 2);
				liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T53_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_265, NIM_FALSE);
			}
			LA47_: ;
		}
		goto LA43_;
		LA45_: ;
		{
			tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ xX60gensym41_;
			xX60gensym41_ = findStr__commands_352(id, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 0));
			{
				if (!!((xX60gensym41_ == ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 0)))) goto LA57_;
				nimZeroMem(notes, sizeof(tySet_tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ));
				notes[(NU)(xX60gensym41_)>>3] |=(1U<<((NU)(xX60gensym41_)&7U));
			}
			goto LA55_;
			LA57_: ;
			{
				tyArray__Re75IspeoxXy2oCZHwcRrA T60_;
				NimStringDesc* T61_;
				nimZeroMem((void*)T60_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T60_[0] = copyString(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_74));
				T60_[1] = copyString(id);
				T61_ = NIM_NIL;
				T61_ = nsuFormatOpenArray(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_264), T60_, 2);
				liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T61_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_265, NIM_FALSE);
			}
			LA55_: ;
		}
		LA43_: ;
	}
	LA35_: ;
	T62_ = NIM_NIL;
	T62_ = substr__system_7748(arg, i);
	val = nsuNormalize(T62_);
	{
		if (!((val ? val->Sup.len : 0) == 0)) goto LA65_;
		val = copyString(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_215));
	}
	LA65_: ;
	{
		NIM_BOOL T69_;
		NimStringDesc* T72_;
		T69_ = (NIM_BOOL)0;
		T69_ = contains__stdZenumutils_44(TM__aFkIL74T1q8RouIu9auwZ3g_266, 2, val);
		if (!!(T69_)) goto LA70_;
		T72_ = NIM_NIL;
		T72_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_217), arg);
		liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T72_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_267, NIM_FALSE);
	}
	goto LA67_;
	LA70_: ;
	{
		NIM_BOOL isOn;
		isOn = eqStrings(val, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_215));
		{
			NIM_BOOL T76_;
			NimStringDesc* T78_;
			T76_ = (NIM_BOOL)0;
			T76_ = isOn;
			if (!(T76_)) goto LA77_;
			T78_ = NIM_NIL;
			T78_ = nsuNormalize(id);
			T76_ = eqStrings(T78_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_261));
			LA77_: ;
			if (!T76_) goto LA79_;
			liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_268), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_269, NIM_FALSE);
		}
		LA79_: ;
		{
			tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ n;
			NI i_2;
			n = (tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ)0;
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 <= ((NI) 106))) goto LA83;
					{
						if (!((notes[(NU)(((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) (i_2)))>>3] &(1U<<((NU)(((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) (i_2)))&7U)))!=0)) goto LA86_;
						n = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) (i_2));
						{
							NIM_BOOL T90_;
							T90_ = (NIM_BOOL)0;
							T90_ = !((((*conf).cmdlineNotes[(NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (n))- 17))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (n))- 17))&7U)))!=0));
							if (T90_) goto LA91_;
							T90_ = (pass == ((tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w) 0));
							LA91_: ;
							if (!T90_) goto LA92_;
							{
								if (!(pass == ((tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w) 0))) goto LA96_;
								(*conf).cmdlineNotes[(NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (n))- 17))>>3] |=(1U<<((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (n))- 17)&7U));
							}
							LA96_: ;
							(*conf).modifiedyNotes[(NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (n))- 17))>>3] |=(1U<<((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (n))- 17)&7U));
							{
								if (!(state == ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 125) || state == ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 126))) goto LA100_;
								X5BX5Deq___commands_430((*conf).warningAsErrors, ((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (n)), isOn);
							}
							goto LA98_;
							LA100_: ;
							{
								X5BX5Deq___commands_430((*conf).notes, ((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (n)), isOn);
								X5BX5Deq___commands_430((*conf).mainPackageNotes, ((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (n)), isOn);
							}
							LA98_: ;
							{
								if (!!(isOn)) goto LA105_;
								(*conf).foreignPackageNotes[(NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (n))- 17))>>3] &= ~(1U<<((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (n))- 17)&7U));
							}
							LA105_: ;
						}
						LA92_: ;
					}
					LA86_: ;
					i_2 += ((NI) 1);
				} LA83: ;
			}
		}
	}
	LA67_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processOnOffSwitch__commands_209)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ op, NimStringDesc* arg, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NimStringDesc* T1_;
	T1_ = NIM_NIL;
	T1_ = nsuNormalize(arg);
	if (eqStrings(T1_, ((NimStringDesc*) NIM_NIL))) goto LA2_;
	if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_215))) goto LA2_;
	if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_216))) goto LA3_;
	goto LA4_;
	LA2_: ;
	{
		(*conf).options = ((*conf).options | op);
	}
	goto LA5_;
	LA3_: ;
	{
		(*conf).options = ((*conf).options & ~ op);
	}
	goto LA5_;
	LA4_: ;
	{
		NimStringDesc* T9_;
		T9_ = NIM_NIL;
		T9_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_217), arg);
		liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T9_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_270, NIM_FALSE);
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, writeVersionInfo__commands_159)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass) {
	{
		tyArray__sMpvt1sOxOJ3LFGulnbeMQ T5_;
		NimStringDesc* T6_;
		if (!(pass == ((tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w) 0))) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
		T5_[0] = copyString(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_300));
		T5_[1] = copyString(OS__platform_518[((*conf).target.hostOS)- 1].Field0);
		T5_[2] = copyString(CPU__platform_705[((*conf).target.hostCPU)- 1].Field0);
		T5_[3] = copyString(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_301));
		T6_ = NIM_NIL;
		T6_ = nsuFormatOpenArray(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_299), T5_, 4);
		msgWriteln__msgs_657(conf, T6_, 1);
		msgWriteln__msgs_657(conf, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_302), 1);
		msgWriteln__msgs_657(conf, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_303), 1);
		msgQuit__msgs_452(((NI8) 0));
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, writeAdvancedUsage__commands_145)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass) {
	{
		NimStringDesc* T5_;
		tyArray__sMpvt1sOxOJ3LFGulnbeMQ T6_;
		NimStringDesc* T7_;
		if (!(pass == ((tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w) 0))) goto LA3_;
		T5_ = NIM_NIL;
		nimZeroMem((void*)T6_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
		T6_[0] = copyString(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_300));
		T6_[1] = copyString(OS__platform_518[((*conf).target.hostOS)- 1].Field0);
		T6_[2] = copyString(CPU__platform_705[((*conf).target.hostCPU)- 1].Field0);
		T6_[3] = copyString(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_301));
		T7_ = NIM_NIL;
		T7_ = nsuFormatOpenArray(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_299), T6_, 4);
		T5_ = rawNewString((T7_ ? T7_->Sup.len : 0) + 11061);
appendString(T5_, T7_);
appendString(T5_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_304));
		msgWriteln__msgs_657(conf, T5_, 1);
		msgQuit__msgs_452(((NI8) 0));
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, writeFullhelp__commands_152)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass) {
	{
		NimStringDesc* T5_;
		tyArray__sMpvt1sOxOJ3LFGulnbeMQ T6_;
		NimStringDesc* T7_;
		if (!(pass == ((tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w) 0))) goto LA3_;
		T5_ = NIM_NIL;
		nimZeroMem((void*)T6_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
		T6_[0] = copyString(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_300));
		T6_[1] = copyString(OS__platform_518[((*conf).target.hostOS)- 1].Field0);
		T6_[2] = copyString(CPU__platform_705[((*conf).target.hostCPU)- 1].Field0);
		T6_[3] = copyString(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_301));
		T7_ = NIM_NIL;
		T7_ = nsuFormatOpenArray(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_299), T6_, 4);
		T5_ = rawNewString((T7_ ? T7_->Sup.len : 0) + 13143);
appendString(T5_, T7_);
appendString(T5_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_305));
		msgWriteln__msgs_657(conf, T5_, 1);
		msgQuit__msgs_452(((NI8) 0));
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getCommandLineDesc__commands_134)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	tyArray__sMpvt1sOxOJ3LFGulnbeMQ T2_;
	NimStringDesc* T3_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	nimZeroMem((void*)T2_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
	T2_[0] = copyString(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_300));
	T2_[1] = copyString(OS__platform_518[((*conf).target.hostOS)- 1].Field0);
	T2_[2] = copyString(CPU__platform_705[((*conf).target.hostCPU)- 1].Field0);
	T2_[3] = copyString(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_301));
	T3_ = NIM_NIL;
	T3_ = nsuFormatOpenArray(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_299), T2_, 4);
	T1_ = rawNewString((T3_ ? T3_->Sup.len : 0) + 2082);
appendString(T1_, T3_);
appendString(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_306));
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, helpOnError__commands_137)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass) {
	{
		NimStringDesc* T5_;
		if (!(pass == ((tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w) 0))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = getCommandLineDesc__commands_134(conf);
		msgWriteln__msgs_657(conf, T5_, 1);
		msgQuit__msgs_452(((NI8) 0));
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, makeAbsolute__commands_756)(NimStringDesc* s) {
	NimStringDesc* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nosisAbsolute(s);
		if (!T3_) goto LA4_;
		result = normalizePath__pureZpathnorm_127(s, 47);
	}
	goto LA1_;
	LA4_: ;
	{
		NimStringDesc* T7_;
		NimStringDesc* T8_;
		T7_ = NIM_NIL;
		T7_ = nosgetCurrentDir();
		T8_ = NIM_NIL;
		T8_ = slash___pureZos_121(T7_, s);
		result = normalizePath__pureZpathnorm_127(T8_, 47);
	}
	LA1_: ;
	return result;
}
static N_INLINE(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw, newLineInfo__msgs_408)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename, NI line, NI col) {
	tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw result;
	NI32 T1_;
	nimZeroMem((void*)(&result), sizeof(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw));
	T1_ = (NI32)0;
	T1_ = fileInfoIdx__msgs_376(conf, filename);
	result = newLineInfo__msgs_391(T1_, line, col);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setTrackingInfo__commands_759)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* dirty, NimStringDesc* file, NimStringDesc* line, NimStringDesc* column, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NI ln;
	NI col;
	NimStringDesc* a;
	ln = (NI)0;
	col = (NI)0;
	{
		NI T3_;
		NimStringDesc* T6_;
		T3_ = (NI)0;
		T3_ = npuParseInt(line, (&ln), ((NI) 0));
		if (!(T3_ <= ((NI) 0))) goto LA4_;
		T6_ = NIM_NIL;
		T6_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_314), line);
		liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T6_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_315, NIM_FALSE);
	}
	LA4_: ;
	{
		NI T9_;
		NimStringDesc* T12_;
		T9_ = (NI)0;
		T9_ = npuParseInt(column, (&col), ((NI) 0));
		if (!(T9_ <= ((NI) 0))) goto LA10_;
		T12_ = NIM_NIL;
		T12_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_314), column);
		liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T12_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_316, NIM_FALSE);
	}
	LA10_: ;
	a = makeAbsolute__commands_756(file);
	{
		if (!((dirty ? dirty->Sup.len : 0) == 0)) goto LA15_;
		(*conf).m.trackPos = newLineInfo__msgs_408(conf, a, ln, col);
	}
	goto LA13_;
	LA15_: ;
	{
		NI32 dirtyOriginalIdx;
		dirtyOriginalIdx = fileInfoIdx__msgs_376(conf, a);
		{
			NimStringDesc* T22_;
			if (!(((NI32) 0) <= dirtyOriginalIdx)) goto LA20_;
			T22_ = NIM_NIL;
			T22_ = makeAbsolute__commands_756(dirty);
			setDirtyFile__msgs_556(conf, dirtyOriginalIdx, T22_);
		}
		LA20_: ;
		(*conf).m.trackPos = newLineInfo__msgs_391(dirtyOriginalIdx, ln, col);
	}
	LA13_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, track__commands_778)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* arg, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ* a;
	a = nsuSplitChar(arg, 44, ((NI) -1));
	{
		NI T3_;
		T3_ = (a ? a->Sup.len : 0);
		if (!!((T3_ == ((NI) 3)))) goto LA4_;
		liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_312), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_313, NIM_FALSE);
	}
	LA4_: ;
	setTrackingInfo__commands_759(conf, ((NimStringDesc*) NIM_NIL), a->data[((NI) 0)], a->data[((NI) 1)], a->data[((NI) 2)], info);
}
N_LIB_PRIVATE N_NIMCALL(void, trackDirty__commands_770)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* arg, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ* a;
	a = nsuSplitChar(arg, 44, ((NI) -1));
	{
		NI T3_;
		T3_ = (a ? a->Sup.len : 0);
		if (!!((T3_ == ((NI) 4)))) goto LA4_;
		liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_317), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_318, NIM_FALSE);
	}
	LA4_: ;
	setTrackingInfo__commands_759(conf, a->data[((NI) 0)], a->data[((NI) 1)], a->data[((NI) 2)], a->data[((NI) 3)], info);
}
N_LIB_PRIVATE N_NIMCALL(void, trackIde__commands_786)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg cmd, NimStringDesc* arg, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ* a;
	NI T1_;
	a = nsuSplitChar(arg, 44, ((NI) -1));
	T1_ = (a ? a->Sup.len : 0);
	switch (T1_) {
	case ((NI) 4):
	{
		setTrackingInfo__commands_759(conf, a->data[((NI) 0)], a->data[((NI) 1)], a->data[((NI) 2)], a->data[((NI) 3)], info);
	}
	break;
	case ((NI) 3):
	{
		setTrackingInfo__commands_759(conf, ((NimStringDesc*) NIM_NIL), a->data[((NI) 0)], a->data[((NI) 1)], a->data[((NI) 2)], info);
	}
	break;
	default:
	{
		liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_319), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_320, NIM_FALSE);
	}
	break;
	}
	(*conf).ideCmd = cmd;
}
N_LIB_PRIVATE N_NIMCALL(void, dynlibOverride__commands_795)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* switch_0, NimStringDesc* arg, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	{
		if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA3_;
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		inclDynlibOverride__options_4671(conf, arg);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, handleStdinInput__commands_807)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	T1_ = NIM_NIL;
	T1_ = (*conf).projectName; (*conf).projectName = copyStringRC1(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_367));
	if (T1_) nimGCunrefNoCycle(T1_);
	(*conf).projectIsStdin = NIM_TRUE;
	T2_ = NIM_NIL;
	T2_ = (*conf).projectFull; (*conf).projectFull = copyStringRC1((*conf).projectName);
	if (T2_) nimGCunrefNoCycle(T2_);
	asgnRef((void**) (&(*conf).projectPath), nosgetCurrentDir());
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = isEmpty__pathutils_94((*conf).outDir);
		if (!T5_) goto LA6_;
		asgnRef((void**) (&(*conf).outDir), getNimcacheDir__options_4185(conf));
	}
	LA6_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processSwitch__commands_880)(NimStringDesc* switch_0, NimStringDesc* arg, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NimStringDesc* key;
	NimStringDesc* val;
	NimStringDesc* T1_;
{	key = NIM_NIL;
	val = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = nsuNormalize(switch_0);
	switch (hashString(T1_) & 255) {
	case 0: 
if (eqStrings(T1_, ((NimStringDesc*) NIM_NIL))) goto LA135_;
break;
	case 1: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_44))) goto LA5_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_71))) goto LA27_;
break;
	case 3: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_141))) goto LA89_;
break;
	case 6: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_81))) goto LA36_;
break;
	case 8: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_117))) goto LA67_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_137))) goto LA87_;
break;
	case 11: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_85))) goto LA40_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_181))) goto LA129_;
break;
	case 12: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_53))) goto LA13_;
break;
	case 14: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_65))) goto LA23_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_103))) goto LA57_;
break;
	case 16: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_72))) goto LA28_;
break;
	case 17: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_111))) goto LA63_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_189))) goto LA136_;
break;
	case 19: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_59))) goto LA17_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_86))) goto LA41_;
break;
	case 24: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_67))) goto LA25_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_83))) goto LA38_;
break;
	case 27: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_75))) goto LA30_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_174))) goto LA122_;
break;
	case 28: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_191))) goto LA136_;
break;
	case 30: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_63))) goto LA21_;
break;
	case 32: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_5))) goto LA18_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_73))) goto LA28_;
break;
	case 34: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_192))) goto LA136_;
break;
	case 39: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_82))) goto LA37_;
break;
	case 40: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_135))) goto LA85_;
break;
	case 41: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_184))) goto LA132_;
break;
	case 43: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_152))) goto LA100_;
break;
	case 44: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_77))) goto LA32_;
break;
	case 46: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_129))) goto LA80_;
break;
	case 47: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_160))) goto LA108_;
break;
	case 50: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_164))) goto LA112_;
break;
	case 51: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_132))) goto LA83_;
break;
	case 52: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_50))) goto LA10_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_125))) goto LA75_;
break;
	case 54: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_163))) goto LA111_;
break;
	case 55: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_124))) goto LA74_;
break;
	case 57: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_120))) goto LA70_;
break;
	case 60: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_74))) goto LA29_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_112))) goto LA64_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_162))) goto LA110_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_171))) goto LA119_;
break;
	case 61: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_170))) goto LA118_;
break;
	case 63: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_157))) goto LA105_;
break;
	case 65: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_182))) goto LA130_;
break;
	case 66: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_104))) goto LA57_;
break;
	case 68: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_88))) goto LA43_;
break;
	case 71: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_126))) goto LA76_;
break;
	case 73: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_60))) goto LA17_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_79))) goto LA34_;
break;
	case 76: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_42))) goto LA4_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_190))) goto LA136_;
break;
	case 77: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_101))) goto LA55_;
break;
	case 79: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_139))) goto LA87_;
break;
	case 83: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_84))) goto LA39_;
break;
	case 86: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_179))) goto LA127_;
break;
	case 87: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_187))) goto LA136_;
break;
	case 89: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_3))) goto LA22_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_140))) goto LA88_;
break;
	case 90: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_45))) goto LA6_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_76))) goto LA31_;
break;
	case 93: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_66))) goto LA24_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_148))) goto LA95_;
break;
	case 94: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_56))) goto LA15_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_87))) goto LA42_;
break;
	case 97: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_168))) goto LA116_;
break;
	case 99: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_69))) goto LA26_;
break;
	case 100: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_94))) goto LA48_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_106))) goto LA59_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_122))) goto LA72_;
break;
	case 102: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_193))) goto LA137_;
break;
	case 103: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_146))) goto LA93_;
break;
	case 104: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_80))) goto LA35_;
break;
	case 105: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_14))) goto LA78_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_183))) goto LA131_;
break;
	case 108: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_153))) goto LA101_;
break;
	case 109: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_178))) goto LA126_;
break;
	case 110: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_180))) goto LA128_;
break;
	case 111: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_158))) goto LA106_;
break;
	case 112: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_130))) goto LA81_;
break;
	case 113: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_95))) goto LA49_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_128))) goto LA79_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_185))) goto LA133_;
break;
	case 115: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_118))) goto LA68_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_149))) goto LA97_;
break;
	case 119: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_121))) goto LA71_;
break;
	case 120: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_177))) goto LA125_;
break;
	case 122: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_100))) goto LA54_;
break;
	case 127: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_49))) goto LA9_;
break;
	case 129: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_89))) goto LA44_;
break;
	case 132: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_54))) goto LA14_;
break;
	case 133: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_58))) goto LA16_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_114))) goto LA65_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_154))) goto LA102_;
break;
	case 139: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_166))) goto LA114_;
break;
	case 141: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_172))) goto LA120_;
break;
	case 142: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_51))) goto LA11_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_156))) goto LA104_;
break;
	case 143: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_138))) goto LA87_;
break;
	case 144: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_48))) goto LA9_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_186))) goto LA134_;
break;
	case 148: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_169))) goto LA117_;
break;
	case 150: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_102))) goto LA56_;
break;
	case 152: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_161))) goto LA109_;
break;
	case 155: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_55))) goto LA14_;
break;
	case 156: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_47))) goto LA8_;
break;
	case 158: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_64))) goto LA22_;
break;
	case 165: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_98))) goto LA52_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_116))) goto LA66_;
break;
	case 167: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_134))) goto LA84_;
break;
	case 169: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_97))) goto LA51_;
break;
	case 170: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_144))) goto LA92_;
break;
	case 172: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_167))) goto LA115_;
break;
	case 173: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_70))) goto LA27_;
break;
	case 174: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_145))) goto LA92_;
break;
	case 178: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_123))) goto LA73_;
break;
	case 179: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_78))) goto LA33_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_151))) goto LA99_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_188))) goto LA136_;
break;
	case 181: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_39))) goto LA3_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_91))) goto LA45_;
break;
	case 182: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_46))) goto LA7_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_57))) goto LA16_;
break;
	case 183: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_142))) goto LA90_;
break;
	case 184: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_41))) goto LA4_;
break;
	case 190: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_107))) goto LA60_;
break;
	case 192: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_159))) goto LA107_;
break;
	case 197: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_110))) goto LA62_;
break;
	case 198: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_175))) goto LA123_;
break;
	case 200: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_93))) goto LA47_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_108))) goto LA61_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_109))) goto LA61_;
break;
	case 202: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_4))) goto LA96_;
break;
	case 206: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_96))) goto LA50_;
break;
	case 207: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_113))) goto LA64_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_155))) goto LA103_;
break;
	case 208: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_176))) goto LA124_;
break;
	case 210: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_127))) goto LA77_;
break;
	case 213: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_133))) goto LA83_;
break;
	case 216: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_173))) goto LA121_;
break;
	case 218: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_92))) goto LA46_;
break;
	case 219: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_52))) goto LA12_;
break;
	case 223: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_99))) goto LA53_;
break;
	case 226: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_13))) goto LA78_;
break;
	case 228: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_131))) goto LA82_;
break;
	case 229: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_90))) goto LA44_;
break;
	case 234: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_136))) goto LA86_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_143))) goto LA91_;
break;
	case 236: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_34))) goto LA86_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_147))) goto LA94_;
break;
	case 237: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_62))) goto LA20_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_165))) goto LA113_;
break;
	case 238: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_68))) goto LA25_;
break;
	case 239: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_38))) goto LA2_;
break;
	case 240: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_61))) goto LA19_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_150))) goto LA98_;
break;
	case 246: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_105))) goto LA58_;
break;
	case 248: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_115))) goto LA65_;
break;
	case 249: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_40))) goto LA3_;
break;
	case 254: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_43))) goto LA5_;
break;
	case 255: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_119))) goto LA69_;
break;
	}
	goto LA138_;
	LA2_: ;
	{
		NimStringDesc* T141_;
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		(*conf).projectIsCmd = NIM_TRUE;
		T141_ = NIM_NIL;
		T141_ = (*conf).cmdInput; (*conf).cmdInput = copyStringRC1(arg);
		if (T141_) nimGCunrefNoCycle(T141_);
		{
			NimStringDesc* T146_;
			if (!((*conf).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 0))) goto LA144_;
			T146_ = NIM_NIL;
			T146_ = (*conf).command; (*conf).command = copyStringRC1(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_16));
			if (T146_) nimGCunrefNoCycle(T146_);
			setCmd__commands_829(conf, ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 12));
			(*conf).implicitCmd = NIM_TRUE;
		}
		LA144_: ;
	}
	goto LA139_;
	LA3_: ;
	{
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		{
			NimStringDesc* path;
			NimStringDesc* pl;
			path = NIM_NIL;
			pl = nsuToLowerAsciiStr(arg);
			{
				NIM_BOOL T151_;
				T151_ = (NIM_BOOL)0;
				T151_ = contains__pureZstrutils_1627(pl, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_199));
				if (T151_) goto LA152_;
				T151_ = contains__pureZstrutils_1627(pl, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_200));
				LA152_: ;
				if (!T151_) goto LA153_;
				{
					NI i;
					NI colontmp_;
					NI T156_;
					NI res;
					i = (NI)0;
					colontmp_ = (NI)0;
					T156_ = ((*conf).nimblePaths ? (*conf).nimblePaths->Sup.len : 0);
					colontmp_ = (NI)(T156_ - ((NI) 1));
					res = colontmp_;
					{
						while (1) {
							NimStringDesc* nimblePath;
							tyArray__sMpvt1sOxOJ3LFGulnbeMQ T159_;
							NimStringDesc* T160_;
							if (!(((NI) 0) <= res)) goto LA158;
							i = res;
							nimblePath = removeTrailingDirSep__options_4131((*conf).nimblePaths->data[i]);
							nimZeroMem((void*)T159_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
							T159_[0] = copyString(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_41));
							T159_[1] = copyString(nimblePath);
							T159_[2] = copyString(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_201));
							T159_[3] = copyString(nimblePath);
							path = nsuFormatOpenArray(arg, T159_, 4);
							T160_ = NIM_NIL;
							{
								if (!(pass == ((tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w) 2))) goto LA163_;
								T160_ = processCfgPath__commands_743(conf, path, info);
							}
							goto LA161_;
							LA163_: ;
							{
								T160_ = processPath__commands_732(conf, path, info, NIM_FALSE);
							}
							LA161_: ;
							addPath__nimblecmd_11(conf, T160_, info);
							res -= ((NI) 1);
						} LA158: ;
					}
				}
			}
			goto LA149_;
			LA153_: ;
			{
				NimStringDesc* T167_;
				path = arg;
				T167_ = NIM_NIL;
				{
					if (!(pass == ((tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w) 2))) goto LA170_;
					T167_ = processCfgPath__commands_743(conf, path, info);
				}
				goto LA168_;
				LA170_: ;
				{
					T167_ = processPath__commands_732(conf, path, info, NIM_FALSE);
				}
				LA168_: ;
				addPath__nimblecmd_11(conf, T167_, info);
			}
			LA149_: ;
		}
	}
	goto LA139_;
	LA4_: ;
	{
		{
			NimStringDesc* T176_;
			tyArray__Re75IspeoxXy2oCZHwcRrA T179_;
			NimStringDesc* T180_;
			T176_ = NIM_NIL;
			T176_ = nsuNormalize(switch_0);
			if (!eqStrings(T176_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_42))) goto LA177_;
			nimZeroMem((void*)T179_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T179_[0] = copyString(switch_0);
			T179_[1] = copyString(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_41));
			T180_ = NIM_NIL;
			T180_ = nsuFormatOpenArray(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_210), T179_, 2);
			warningDeprecated__msgs_1428(conf, info, T180_);
		}
		LA177_: ;
		{
			NIM_BOOL T183_;
			NimStringDesc* path_2;
			NimStringDesc* nimbleDir;
			T183_ = (NIM_BOOL)0;
			T183_ = ((6 &((NU8)1<<((NU)(pass)&7U)))!=0);
			if (!(T183_)) goto LA184_;
			T183_ = !((((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 37))&63U)))!=0));
			LA184_: ;
			if (!T183_) goto LA185_;
			expectArg__commands_262(conf, switch_0, arg, pass, info);
			path_2 = processPath__commands_732(conf, arg, info, NIM_TRUE);
			nimbleDir = getEnv__pureZos_418(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_211), ((NimStringDesc*) NIM_NIL));
			{
				NIM_BOOL T189_;
				NIM_BOOL T190_;
				T189_ = (NIM_BOOL)0;
				T190_ = (NIM_BOOL)0;
				T190_ = isEmpty__pathutils_94(nimbleDir);
				T189_ = !(T190_);
				if (!(T189_)) goto LA191_;
				T189_ = (pass == ((tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w) 2));
				LA191_: ;
				if (!T189_) goto LA192_;
				path_2 = slash___pathutils_112(nimbleDir, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_212));
			}
			LA192_: ;
			nimblePath__nimblecmd_2104(conf, path_2, info);
		}
		LA185_: ;
	}
	goto LA139_;
	LA5_: ;
	{
		{
			NimStringDesc* T197_;
			tyArray__Re75IspeoxXy2oCZHwcRrA T200_;
			NimStringDesc* T201_;
			T197_ = NIM_NIL;
			T197_ = nsuNormalize(switch_0);
			if (!eqStrings(T197_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_44))) goto LA198_;
			nimZeroMem((void*)T200_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T200_[0] = copyString(switch_0);
			T200_[1] = copyString(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_43));
			T201_ = NIM_NIL;
			T201_ = nsuFormatOpenArray(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_210), T200_, 2);
			warningDeprecated__msgs_1428(conf, info, T201_);
		}
		LA198_: ;
		expectNoArg__commands_268(conf, switch_0, arg, pass, info);
		disableNimblePath__options_4134(conf);
	}
	goto LA139_;
	LA6_: ;
	{
		expectNoArg__commands_268(conf, switch_0, arg, pass, info);
		clearNimblePath__options_4148(conf);
	}
	goto LA139_;
	LA7_: ;
	{
		NimStringDesc* path_3;
		NI posX60gensym100_;
		NI posX60gensym103_;
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		path_3 = processPath__commands_732(conf, arg, info, NIM_FALSE);
		posX60gensym100_ = ((NI) 0);
		{
			NI iX60gensym100_;
			NI colontmp__2;
			NI T205_;
			NI i_2;
			iX60gensym100_ = (NI)0;
			colontmp__2 = (NI)0;
			T205_ = ((*conf).searchPaths ? (*conf).searchPaths->Sup.len : 0);
			colontmp__2 = T205_;
			i_2 = ((NI) 0);
			{
				while (1) {
					NimStringDesc* it;
					if (!(i_2 < colontmp__2)) goto LA207;
					iX60gensym100_ = i_2;
					it = (*conf).searchPaths->data[iX60gensym100_];
					{
						NIM_BOOL T210_;
						T210_ = (NIM_BOOL)0;
						T210_ = eqeq___options_4108(it, path_3);
						if (!!(T210_)) goto LA211_;
						{
							if (!!((posX60gensym100_ == iX60gensym100_))) goto LA215_;
							asgnRef((void**) (&(*conf).searchPaths->data[posX60gensym100_]), (*conf).searchPaths->data[iX60gensym100_]);
						}
						LA215_: ;
						posX60gensym100_ += ((NI) 1);
					}
					LA211_: ;
					i_2 += ((NI) 1);
				} LA207: ;
			}
		}
		asgnRef((void**) (&(*conf).searchPaths), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) setLengthSeqV2(((*conf).searchPaths)?&((*conf).searchPaths)->Sup:NIM_NIL, (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_), ((NI) (posX60gensym100_))));
		posX60gensym103_ = ((NI) 0);
		{
			NI iX60gensym103_;
			NI colontmp__3;
			NI T218_;
			NI i_3;
			iX60gensym103_ = (NI)0;
			colontmp__3 = (NI)0;
			T218_ = ((*conf).lazyPaths ? (*conf).lazyPaths->Sup.len : 0);
			colontmp__3 = T218_;
			i_3 = ((NI) 0);
			{
				while (1) {
					NimStringDesc* it_2;
					if (!(i_3 < colontmp__3)) goto LA220;
					iX60gensym103_ = i_3;
					it_2 = (*conf).lazyPaths->data[iX60gensym103_];
					{
						NIM_BOOL T223_;
						T223_ = (NIM_BOOL)0;
						T223_ = eqeq___options_4108(it_2, path_3);
						if (!!(T223_)) goto LA224_;
						{
							if (!!((posX60gensym103_ == iX60gensym103_))) goto LA228_;
							asgnRef((void**) (&(*conf).lazyPaths->data[posX60gensym103_]), (*conf).lazyPaths->data[iX60gensym103_]);
						}
						LA228_: ;
						posX60gensym103_ += ((NI) 1);
					}
					LA224_: ;
					i_3 += ((NI) 1);
				} LA220: ;
			}
		}
		asgnRef((void**) (&(*conf).lazyPaths), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) setLengthSeqV2(((*conf).lazyPaths)?&((*conf).lazyPaths)->Sup:NIM_NIL, (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_), ((NI) (posX60gensym103_))));
	}
	goto LA139_;
	LA8_: ;
	{
		NimStringDesc* arg_2;
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		arg_2 = copyString(arg);
		{
			NIM_BOOL T233_;
			T233_ = (NIM_BOOL)0;
			T233_ = ((*conf).target.targetOS == ((tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw) 2));
			if (!(T233_)) goto LA234_;
			T233_ = NIM_TRUE;
			LA234_: ;
			if (!T233_) goto LA235_;
			arg_2 = nsuReplaceChar(arg_2, 92, 47);
		}
		LA235_: ;
		asgnRef((void**) (&(*conf).nimcacheDir), processPath__commands_732(conf, arg_2, info, NIM_TRUE));
	}
	goto LA139_;
	LA9_: ;
	{
		tyTuple__7q7q3E6Oj24ZNVJb9aonhAg f;
		NimStringDesc* T238_;
		NimStringDesc* T239_;
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		nimZeroMem((void*)(&f), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
		T238_ = NIM_NIL;
		T238_ = processPath__commands_732(conf, arg, info, NIM_TRUE);
		nossplitFile(T238_, (&f));
		T239_ = NIM_NIL;
		T239_ = rawNewString((f.Field1 ? f.Field1->Sup.len : 0) + (f.Field2 ? f.Field2->Sup.len : 0) + 0);
appendString(T239_, f.Field1);
appendString(T239_, f.Field2);
		asgnRef((void**) (&(*conf).outFile), T239_);
		asgnRef((void**) (&(*conf).outDir), toAbsoluteDir__pathutils_72(f.Field0));
	}
	goto LA139_;
	LA10_: ;
	{
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		asgnRef((void**) (&(*conf).outDir), processPath__commands_732(conf, arg, info, NIM_TRUE));
	}
	goto LA139_;
	LA11_: ;
	{
		processOnOffSwitchG__commands_244(conf, 8192, arg, pass, info);
	}
	goto LA139_;
	LA12_: ;
	{
		NimStringDesc* T243_;
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		T243_ = NIM_NIL;
		T243_ = (*conf).docSeeSrcUrl; (*conf).docSeeSrcUrl = copyStringRC1(arg);
		if (T243_) nimGCunrefNoCycle(T243_);
	}
	goto LA139_;
	LA13_: ;
	{
		{
			NimStringDesc* T249_;
			if (!((arg ? arg->Sup.len : 0) == ((NI) 0))) goto LA247_;
			T249_ = NIM_NIL;
			T249_ = (*conf).docRoot; (*conf).docRoot = copyStringRC1(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_219));
			if (T249_) nimGCunrefNoCycle(T249_);
		}
		goto LA245_;
		LA247_: ;
		{
			NimStringDesc* T251_;
			T251_ = NIM_NIL;
			T251_ = (*conf).docRoot; (*conf).docRoot = copyStringRC1(arg);
			if (T251_) nimGCunrefNoCycle(T251_);
		}
		LA245_: ;
	}
	goto LA139_;
	LA14_: ;
	{
		tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
		NimStringDesc* T253_;
		tyEnum_TBackend__zoooocqvga73vZuhGAAy6A T254_;
		T253_ = NIM_NIL;
		T253_ = nsuNormalize(arg);
		T254_ = (tyEnum_TBackend__zoooocqvga73vZuhGAAy6A)0;
		backend = parseEnum__commands_976(T253_, T254_);
		{
			tyEnum_TBackend__zoooocqvga73vZuhGAAy6A T257_;
			NimStringDesc* T260_;
			T257_ = (tyEnum_TBackend__zoooocqvga73vZuhGAAy6A)0;
			if (!(backend == T257_)) goto LA258_;
			T260_ = NIM_NIL;
			T260_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_220), arg);
			liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T260_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_221, NIM_FALSE);
		}
		LA258_: ;
		(*conf).backend = backend;
	}
	goto LA139_;
	LA15_: ;
	{
		NimStringDesc* T262_;
		T262_ = NIM_NIL;
		T262_ = (*conf).docCmd; (*conf).docCmd = copyStringRC1(arg);
		if (T262_) nimGCunrefNoCycle(T262_);
	}
	goto LA139_;
	LA16_: ;
	{
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		{
			NIM_BOOL T266_;
			T266_ = (NIM_BOOL)0;
			T266_ = contains__pureZstrutils_1631(arg, TM__aFkIL74T1q8RouIu9auwZ3g_222);
			if (!T266_) goto LA267_;
			splitSwitch__commands_183(conf, arg, (&key), (&val), pass, info);
			specialDefine__commands_835(conf, key, pass);
			defineSymbol__condsyms_4((*conf).symbols, key, val);
		}
		goto LA264_;
		LA267_: ;
		{
			specialDefine__commands_835(conf, arg, pass);
			defineSymbol__condsyms_4((*conf).symbols, arg, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
		}
		LA264_: ;
	}
	goto LA139_;
	LA17_: ;
	{
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		undefSymbol__condsyms_8((*conf).symbols, arg);
	}
	goto LA139_;
	LA18_: ;
	{
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		{
			if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA274_;
			processCompile__commands_457(conf, arg);
		}
		LA274_: ;
	}
	goto LA139_;
	LA19_: ;
	{
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		{
			if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA279_;
			addExternalFileToLink__extccomp_756(conf, arg);
		}
		LA279_: ;
	}
	goto LA139_;
	LA20_: ;
	{
		processOnOffSwitchG__commands_244(conf, 64, arg, pass, info);
	}
	goto LA139_;
	LA21_: ;
	{
		processOnOffSwitchG__commands_244(conf, 268435456, arg, pass, info);
	}
	goto LA139_;
	LA22_: ;
	{
		processOnOffSwitchG__commands_244(conf, 16, arg, pass, info);
	}
	goto LA139_;
	LA23_: ;
	{
		processOnOffSwitchG__commands_244(conf, 32, arg, pass, info);
	}
	goto LA139_;
	LA24_: ;
	{
		processOnOffSwitchG__commands_244(conf, 2097152, arg, pass, info);
	}
	goto LA139_;
	LA25_: ;
	{
		processOnOffSwitchG__commands_244(conf, 2, arg, pass, info);
	}
	goto LA139_;
	LA26_: ;
	{
		processOnOffSwitchG__commands_244(conf, IL64(8724152320), arg, pass, info);
	}
	goto LA139_;
	LA27_: ;
	{
		{
			if (!((*conf).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 3))) goto LA291_;
			goto BeforeRet_;
		}
		LA291_: ;
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		{
			NimStringDesc* T297_;
			if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA295_;
			T297_ = NIM_NIL;
			T297_ = nsuNormalize(arg);
			switch (hashString(T297_) & 15) {
			case 1: 
if (eqStrings(T297_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_232))) goto LA298_;
if (eqStrings(T297_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_234))) goto LA300_;
if (eqStrings(T297_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_240))) goto LA305_;
break;
			case 2: 
if (eqStrings(T297_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_235))) goto LA301_;
break;
			case 3: 
if (eqStrings(T297_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_241))) goto LA306_;
break;
			case 6: 
if (eqStrings(T297_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_238))) goto LA303_;
break;
			case 7: 
if (eqStrings(T297_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_239))) goto LA304_;
break;
			case 9: 
if (eqStrings(T297_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_237))) goto LA302_;
break;
			case 10: 
if (eqStrings(T297_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_242))) goto LA306_;
break;
			case 11: 
if (eqStrings(T297_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_243))) goto LA307_;
break;
			case 13: 
if (eqStrings(T297_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_236))) goto LA301_;
break;
			case 14: 
if (eqStrings(T297_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_233))) goto LA299_;
break;
			}
			goto LA308_;
			LA298_: ;
			{
				(*conf).selectedGC = ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 2);
				defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_244), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
				(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 26)) & 63);
			}
			goto LA309_;
			LA299_: ;
			{
				(*conf).selectedGC = ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 8);
			}
			goto LA309_;
			LA300_: ;
			{
				(*conf).selectedGC = ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 6);
				defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_245), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
			}
			goto LA309_;
			LA301_: ;
			{
				(*conf).selectedGC = ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 4);
				defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_246), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
				defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_247), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
				(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40)) & 63);
				(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 41)) & 63);
				{
					if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA316_;
					defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_248), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
					defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_249), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
				}
				LA316_: ;
				{
					NIM_BOOL T320_;
					T320_ = (NIM_BOOL)0;
					T320_ = ((*conf).exc == ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 0));
					if (!(T320_)) goto LA321_;
					T320_ = !(((*conf).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2)));
					LA321_: ;
					if (!T320_) goto LA322_;
					(*conf).exc = ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 3);
				}
				LA322_: ;
			}
			goto LA309_;
			LA302_: ;
			{
				(*conf).selectedGC = ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 5);
				defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_246), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
				defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_250), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
				(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40)) & 63);
				(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 41)) & 63);
				{
					if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA327_;
					defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_248), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
					defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_249), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
				}
				LA327_: ;
				{
					NIM_BOOL T331_;
					T331_ = (NIM_BOOL)0;
					T331_ = ((*conf).exc == ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 0));
					if (!(T331_)) goto LA332_;
					T331_ = !(((*conf).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2)));
					LA332_: ;
					if (!T331_) goto LA333_;
					(*conf).exc = ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 3);
				}
				LA333_: ;
			}
			goto LA309_;
			LA303_: ;
			{
				(*conf).selectedGC = ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 7);
				defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_251), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
				(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40)) & 63);
				processOnOffSwitchG__commands_244(conf, IL64(1099511627776), arg, pass, info);
				{
					if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA338_;
					defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_248), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
				}
				LA338_: ;
			}
			goto LA309_;
			LA304_: ;
			{
				(*conf).selectedGC = ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 10);
				defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_252), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
			}
			goto LA309_;
			LA305_: ;
			{
				(*conf).selectedGC = ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 1);
				defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_253), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
			}
			goto LA309_;
			LA306_: ;
			{
				(*conf).selectedGC = ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 3);
				defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_254), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
			}
			goto LA309_;
			LA307_: ;
			{
				NimStringDesc* T344_;
				T344_ = NIM_NIL;
				T344_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_255), arg);
				warningDeprecated__msgs_1428(conf, info, T344_);
			}
			goto LA309_;
			LA308_: ;
			{
				NimStringDesc* T346_;
				T346_ = NIM_NIL;
				T346_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_256), arg);
				liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T346_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_257, NIM_FALSE);
			}
			LA309_: ;
		}
		LA295_: ;
	}
	goto LA139_;
	LA28_: ;
	{
		{
			NIM_BOOL T350_;
			T350_ = (NIM_BOOL)0;
			T350_ = processOnOffSwitchOrList__commands_227(conf, 8192, arg, pass, info);
			if (!T350_) goto LA351_;
			listWarnings__msgs_1485(conf);
		}
		LA351_: ;
	}
	goto LA139_;
	LA29_: ;
	{
		processSpecificNote__commands_274(arg, ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 123), pass, info, switch_0, conf);
	}
	goto LA139_;
	LA30_: ;
	{
		processSpecificNote__commands_274(arg, ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 124), pass, info, switch_0, conf);
	}
	goto LA139_;
	LA31_: ;
	{
		processSpecificNote__commands_274(arg, ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 125), pass, info, switch_0, conf);
	}
	goto LA139_;
	LA32_: ;
	{
		processSpecificNote__commands_274(arg, ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 126), pass, info, switch_0, conf);
	}
	goto LA139_;
	LA33_: ;
	{
		{
			NIM_BOOL T360_;
			T360_ = (NIM_BOOL)0;
			T360_ = processOnOffSwitchOrList__commands_227(conf, 16384, arg, pass, info);
			if (!T360_) goto LA361_;
			listHints__msgs_1506(conf);
		}
		LA361_: ;
	}
	goto LA139_;
	LA34_: ;
	{
		{
			if (!((*conf).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 3))) goto LA366_;
		}
		goto LA364_;
		LA366_: ;
		{
			processOnOffSwitchG__commands_244(conf, 33554432, arg, pass, info);
		}
		LA364_: ;
	}
	goto LA139_;
	LA35_: ;
	{
		processOnOffSwitch__commands_209(conf, 131072, arg, pass, info);
	}
	goto LA139_;
	LA36_: ;
	{
		processOnOffSwitch__commands_209(conf, 262144, arg, pass, info);
	}
	goto LA139_;
	LA37_: ;
	{
		processOnOffSwitchG__commands_244(conf, IL64(2147483648), arg, pass, info);
	}
	goto LA139_;
	LA38_: ;
	{
		processOnOffSwitch__commands_209(conf, 524288, arg, pass, info);
	}
	goto LA139_;
	LA39_: ;
	{
		NimStringDesc* T374_;
		T374_ = NIM_NIL;
		T374_ = nsuNormalize(arg);
		if (eqStrings(T374_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_215))) goto LA375_;
		if (eqStrings(T374_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_271))) goto LA375_;
		if (eqStrings(T374_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_272))) goto LA375_;
		if (eqStrings(T374_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_216))) goto LA376_;
		goto LA377_;
		LA375_: ;
		{
			(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 6)) & 63);
			(*conf).options |= ((NU32)1)<<((((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12)) & 31);
		}
		goto LA378_;
		LA376_: ;
		{
			(*conf).globalOptions &= ~(((NU64)1) << ((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 6)) & 63));
		}
		goto LA378_;
		LA377_: ;
		{
			NimStringDesc* T382_;
			T382_ = NIM_NIL;
			T382_ = rawNewString((arg ? arg->Sup.len : 0) + 37);
appendString(T382_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_273));
appendString(T382_, arg);
			liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T382_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_274, NIM_FALSE);
		}
		LA378_: ;
	}
	goto LA139_;
	LA40_: ;
	{
		(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 6)) & 63);
		(*conf).options |= ((NU32)1)<<((((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12)) & 31);
	}
	goto LA139_;
	LA41_: ;
	{
		processOnOffSwitch__commands_209(conf, 2097152, arg, pass, info);
		{
			if (!(((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 21))&31U)))!=0)) goto LA387_;
			defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_86), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
		}
		goto LA385_;
		LA387_: ;
		{
			undefSymbol__condsyms_8((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_86));
		}
		LA385_: ;
	}
	goto LA139_;
	LA42_: ;
	{
		processOnOffSwitch__commands_209(conf, 16777216, arg, pass, info);
		{
			if (!(((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 24))&31U)))!=0)) goto LA393_;
			defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_87), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
		}
		goto LA391_;
		LA393_: ;
		{
			undefSymbol__condsyms_8((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_87));
		}
		LA391_: ;
	}
	goto LA139_;
	LA43_: ;
	{
		processOnOffSwitchG__commands_244(conf, IL64(274877906944), arg, pass, info);
		{
			NIM_BOOL T399_;
			T399_ = (NIM_BOOL)0;
			T399_ = hcrOn__options_582(conf);
			if (!T399_) goto LA400_;
			defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_88), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
			defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_275), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
			{
				NIM_BOOL T404_;
				T404_ = (NIM_BOOL)0;
				T404_ = isVSCompatible__extccomp_577(conf);
				if (!T404_) goto LA405_;
				addCompileOptionCmd__extccomp_701(conf, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_276));
			}
			LA405_: ;
		}
		goto LA397_;
		LA400_: ;
		{
			undefSymbol__condsyms_8((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_88));
			undefSymbol__condsyms_8((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_275));
		}
		LA397_: ;
	}
	goto LA139_;
	LA44_: ;
	{
		processOnOffSwitch__commands_209(conf, 3518, arg, pass, info);
	}
	goto LA139_;
	LA45_: ;
	{
		processOnOffSwitch__commands_209(conf, 384, arg, pass, info);
	}
	goto LA139_;
	LA46_: ;
	{
		processOnOffSwitch__commands_209(conf, 256, arg, pass, info);
	}
	goto LA139_;
	LA47_: ;
	{
		processOnOffSwitch__commands_209(conf, 128, arg, pass, info);
	}
	goto LA139_;
	LA48_: ;
	{
		processOnOffSwitch__commands_209(conf, 2, arg, pass, info);
	}
	goto LA139_;
	LA49_: ;
	{
		processOnOffSwitch__commands_209(conf, 4, arg, pass, info);
	}
	goto LA139_;
	LA50_: ;
	{
		processOnOffSwitch__commands_209(conf, 8, arg, pass, info);
	}
	goto LA139_;
	LA51_: ;
	{
		processOnOffSwitch__commands_209(conf, 16, arg, pass, info);
	}
	goto LA139_;
	LA52_: ;
	{
		warningDeprecated__msgs_1428(conf, info, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_277));
		processOnOffSwitch__commands_209(conf, 64, arg, pass, info);
	}
	goto LA139_;
	LA53_: ;
	{
		processOnOffSwitch__commands_209(conf, 32, arg, pass, info);
	}
	goto LA139_;
	LA54_: ;
	{
		processOnOffSwitch__commands_209(conf, 512, arg, pass, info);
	}
	goto LA139_;
	LA55_: ;
	{
		processOnOffSwitch__commands_209(conf, 1024, arg, pass, info);
	}
	goto LA139_;
	LA56_: ;
	{
		processOnOffSwitch__commands_209(conf, 4096, arg, pass, info);
	}
	goto LA139_;
	LA57_: ;
	{
		processOnOffSwitch__commands_209(conf, 2048, arg, pass, info);
	}
	goto LA139_;
	LA58_: ;
	{
		{
			if (!((*conf).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 3))) goto LA425_;
		}
		goto LA423_;
		LA425_: ;
		{
			processOnOffSwitchG__commands_244(conf, 8388608, arg, pass, info);
		}
		LA423_: ;
	}
	goto LA139_;
	LA59_: ;
	{
		processOnOffSwitchG__commands_244(conf, 67108864, arg, pass, info);
	}
	goto LA139_;
	LA60_: ;
	{
		processOnOffSwitch__commands_209(conf, 4194304, arg, pass, info);
	}
	goto LA139_;
	LA61_: ;
	{
		{
			NimStringDesc* T433_;
			tyArray__Re75IspeoxXy2oCZHwcRrA T436_;
			NimStringDesc* T437_;
			T433_ = NIM_NIL;
			T433_ = nsuNormalize(switch_0);
			if (!eqStrings(T433_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_108))) goto LA434_;
			nimZeroMem((void*)T436_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T436_[0] = copyString(switch_0);
			T436_[1] = copyString(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_109));
			T437_ = NIM_NIL;
			T437_ = nsuFormatOpenArray(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_210), T436_, 2);
			warningDeprecated__msgs_1428(conf, info, T437_);
		}
		LA434_: ;
		processOnOffSwitch__commands_209(conf, 8388608, arg, pass, info);
	}
	goto LA139_;
	LA62_: ;
	{
		NimStringDesc* T439_;
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		T439_ = NIM_NIL;
		T439_ = nsuNormalize(arg);
		if (eqStrings(T439_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_278))) goto LA440_;
		if (eqStrings(T439_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_279))) goto LA441_;
		if (eqStrings(T439_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_240))) goto LA442_;
		goto LA443_;
		LA440_: ;
		{
			(*conf).options |= ((NU32)1)<<((((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 15)) & 31);
			(*conf).options &= ~(((NU32)1) << ((((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 16)) & 31));
		}
		goto LA444_;
		LA441_: ;
		{
			(*conf).options &= ~(((NU32)1) << ((((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 15)) & 31));
			(*conf).options |= ((NU32)1)<<((((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 16)) & 31);
		}
		goto LA444_;
		LA442_: ;
		{
			(*conf).options &= ~(((NU32)1) << ((((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 15)) & 31));
			(*conf).options &= ~(((NU32)1) << ((((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 16)) & 31));
		}
		goto LA444_;
		LA443_: ;
		{
			NimStringDesc* T449_;
			T449_ = NIM_NIL;
			T449_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_280), arg);
			liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T449_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_281, NIM_FALSE);
		}
		LA444_: ;
	}
	goto LA139_;
	LA63_: ;
	{
		NimStringDesc* T451_;
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		T451_ = NIM_NIL;
		T451_ = nsuNormalize(arg);
		if (eqStrings(T451_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_282))) goto LA452_;
		if (eqStrings(T451_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_283))) goto LA453_;
		if (eqStrings(T451_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_147))) goto LA454_;
		if (eqStrings(T451_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_284))) goto LA455_;
		goto LA456_;
		LA452_: ;
		{
			(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 9)) & 63);
			defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_285), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
			defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_286), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
		}
		goto LA457_;
		LA453_: ;
		{
			(*conf).globalOptions &= ~(((NU64)1) << ((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 9)) & 63));
			defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_285), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
			defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_287), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
		}
		goto LA457_;
		LA454_: ;
		{
			(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 7)) & 63);
			(*conf).globalOptions &= ~(((NU64)1) << ((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 9)) & 63));
			defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_288), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
			defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_289), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
		}
		goto LA457_;
		LA455_: ;
		{
			(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 8)) & 63);
			(*conf).globalOptions &= ~(((NU64)1) << ((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 9)) & 63));
			defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_288), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
			defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_284), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
		}
		goto LA457_;
		LA456_: ;
		{
			NimStringDesc* T463_;
			T463_ = NIM_NIL;
			T463_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_290), arg);
			liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T463_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_291, NIM_FALSE);
		}
		LA457_: ;
	}
	goto LA139_;
	LA64_: ;
	{
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		{
			if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA467_;
			addCompileOptionCmd__extccomp_701(conf, arg);
		}
		LA467_: ;
	}
	goto LA139_;
	LA65_: ;
	{
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		{
			if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA472_;
			addLinkOptionCmd__extccomp_698(conf, arg);
		}
		LA472_: ;
	}
	goto LA139_;
	LA66_: ;
	{
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		{
			NimStringDesc* T479_;
			NI T480_;
			NimStringDesc* T481_;
			if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA477_;
			T479_ = NIM_NIL;
			T479_ = processPath__commands_732(conf, arg, info, NIM_FALSE);
			asgnRef((void**) (&(*conf).cIncludes), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).cIncludes), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
			T480_ = (*conf).cIncludes->Sup.len++;
			T481_ = NIM_NIL;
			T481_ = (*conf).cIncludes->data[T480_]; (*conf).cIncludes->data[T480_] = copyStringRC1(T479_);
			if (T481_) nimGCunrefNoCycle(T481_);
		}
		LA477_: ;
	}
	goto LA139_;
	LA67_: ;
	{
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		{
			NimStringDesc* T487_;
			NI T488_;
			NimStringDesc* T489_;
			if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA485_;
			T487_ = NIM_NIL;
			T487_ = processPath__commands_732(conf, arg, info, NIM_FALSE);
			asgnRef((void**) (&(*conf).cLibs), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).cLibs), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
			T488_ = (*conf).cLibs->Sup.len++;
			T489_ = NIM_NIL;
			T489_ = (*conf).cLibs->data[T488_]; (*conf).cLibs->data[T488_] = copyStringRC1(T487_);
			if (T489_) nimGCunrefNoCycle(T489_);
		}
		LA485_: ;
	}
	goto LA139_;
	LA68_: ;
	{
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		{
			NI T495_;
			NimStringDesc* T496_;
			if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA493_;
			asgnRef((void**) (&(*conf).cLinkedLibs), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).cLinkedLibs), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
			T495_ = (*conf).cLinkedLibs->Sup.len++;
			T496_ = NIM_NIL;
			T496_ = (*conf).cLinkedLibs->data[T495_]; (*conf).cLinkedLibs->data[T495_] = copyStringRC1(arg);
			if (T496_) nimGCunrefNoCycle(T496_);
		}
		LA493_: ;
	}
	goto LA139_;
	LA69_: ;
	{
		{
			NimStringDesc* T502_;
			if (!!((conf == ((tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) NIM_NIL)))) goto LA500_;
			T502_ = NIM_NIL;
			T502_ = (*conf).headerFile; (*conf).headerFile = copyStringRC1(arg);
			if (T502_) nimGCunrefNoCycle(T502_);
		}
		LA500_: ;
		(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 27)) & 63);
	}
	goto LA139_;
	LA70_: ;
	{
		processOnOffSwitchG__commands_244(conf, 134217728, arg, pass, info);
	}
	goto LA139_;
	LA71_: ;
	{
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		{
			NimStringDesc* T509_;
			NimStringDesc* T510_;
			NI T511_;
			NimStringDesc* T512_;
			if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA507_;
			T509_ = NIM_NIL;
			T509_ = toFullPath__msgs_548(conf, info.fileIndex);
			T510_ = NIM_NIL;
			T510_ = findModule__options_4507(conf, arg, T509_);
			asgnRef((void**) (&(*conf).implicitImports), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).implicitImports), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
			T511_ = (*conf).implicitImports->Sup.len++;
			T512_ = NIM_NIL;
			T512_ = (*conf).implicitImports->data[T511_]; (*conf).implicitImports->data[T511_] = copyStringRC1(T510_);
			if (T512_) nimGCunrefNoCycle(T512_);
		}
		LA507_: ;
	}
	goto LA139_;
	LA72_: ;
	{
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		{
			NimStringDesc* T518_;
			NimStringDesc* T519_;
			NI T520_;
			NimStringDesc* T521_;
			if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA516_;
			T518_ = NIM_NIL;
			T518_ = toFullPath__msgs_548(conf, info.fileIndex);
			T519_ = NIM_NIL;
			T519_ = findModule__options_4507(conf, arg, T518_);
			asgnRef((void**) (&(*conf).implicitIncludes), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).implicitIncludes), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
			T520_ = (*conf).implicitIncludes->Sup.len++;
			T521_ = NIM_NIL;
			T521_ = (*conf).implicitIncludes->data[T520_]; (*conf).implicitIncludes->data[T520_] = copyStringRC1(T519_);
			if (T521_) nimGCunrefNoCycle(T521_);
		}
		LA516_: ;
	}
	goto LA139_;
	LA73_: ;
	{
		processOnOffSwitchG__commands_244(conf, 8, arg, pass, info);
	}
	goto LA139_;
	LA74_: ;
	{
		processOnOffSwitchG__commands_244(conf, IL64(35184372088832), arg, pass, info);
	}
	goto LA139_;
	LA75_: ;
	{
		processOnOffSwitchG__commands_244(conf, 2048, arg, pass, info);
	}
	goto LA139_;
	LA76_: ;
	{
		tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw theOS;
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		theOS = nameToOS__platform_816(arg);
		{
			NimStringDesc* osList;
			tySequence__sM4lkSb7zS6F7OVMvW9cffQ* T530_;
			tyArray__Re75IspeoxXy2oCZHwcRrA T531_;
			NimStringDesc* T532_;
			if (!(theOS == ((tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw) 0))) goto LA528_;
			T530_ = NIM_NIL;
			T530_ = listOSnames__platform_838();
			osList = nsuJoinSep((T530_) ? (T530_->data) : NIM_NIL, (T530_ ? T530_->Sup.len : 0), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_292));
			nimZeroMem((void*)T531_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T531_[0] = copyString(arg);
			T531_[1] = copyString(osList);
			T532_ = NIM_NIL;
			T532_ = nsuFormatOpenArray(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_293), T531_, 2);
			liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T532_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_294, NIM_FALSE);
		}
		goto LA526_;
		LA528_: ;
		{
			setTarget__platform_760((&(*conf).target), theOS, (*conf).target.targetCPU);
		}
		LA526_: ;
	}
	goto LA139_;
	LA77_: ;
	{
		tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ cpu;
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		cpu = nameToCPU__platform_857(arg);
		{
			NimStringDesc* cpuList;
			tySequence__sM4lkSb7zS6F7OVMvW9cffQ* T539_;
			tyArray__Re75IspeoxXy2oCZHwcRrA T540_;
			NimStringDesc* T541_;
			if (!(cpu == ((tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ) 0))) goto LA537_;
			T539_ = NIM_NIL;
			T539_ = listCPUnames__platform_879();
			cpuList = nsuJoinSep((T539_) ? (T539_->data) : NIM_NIL, (T539_ ? T539_->Sup.len : 0), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_292));
			nimZeroMem((void*)T540_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T540_[0] = copyString(arg);
			T540_[1] = copyString(cpuList);
			T541_ = NIM_NIL;
			T541_ = nsuFormatOpenArray(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_295), T540_, 2);
			liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T541_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_296, NIM_FALSE);
		}
		goto LA535_;
		LA537_: ;
		{
			setTarget__platform_760((&(*conf).target), (*conf).target.targetOS, cpu);
		}
		LA535_: ;
	}
	goto LA139_;
	LA78_: ;
	{
		processOnOffSwitchG__commands_244(conf, 4096, arg, pass, info);
	}
	goto LA139_;
	LA79_: ;
	{
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		(*conf).maxLoopIterationsVM = nsuParseInt(arg);
	}
	goto LA139_;
	LA80_: ;
	{
		NI ret;
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		ret = nsuParseInt(arg);
		{
			if (!(ret == ((NI) 0))) goto LA548_;
			(*conf).errorMax = ((NI) 2147483647);
		}
		goto LA546_;
		LA548_: ;
		{
			(*conf).errorMax = ret;
		}
		LA546_: ;
	}
	goto LA139_;
	LA81_: ;
	{
		NI verbosity;
		tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA verb;
		NI T557_;
		NI T558_;
		NI T559_;
		tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA T560_;
		tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA T561_;
		NI T562_;
		NI T563_;
		tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA T564_;
		tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA T565_;
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		verbosity = nsuParseInt(arg);
		{
			NimStringDesc* T556_;
			if (!!((verbosity >= ((NI) 0) && verbosity <= ((NI) 3)))) goto LA554_;
			T556_ = NIM_NIL;
			T556_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_297), arg);
			liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T556_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_298, NIM_FALSE);
		}
		LA554_: ;
		(*conf).verbosity = verbosity;
		nimZeroMem((void*)verb, sizeof(tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA));
		nimCopyMem((void*)verb, (NIM_CONST void*)NotesVerbosity__lineinfos_194[((*conf).verbosity)- 0], 12);
		T557_ = (NI)0;
		T558_ = (NI)0;
		T559_ = (NI)0;
		for (T559_ = 0; T559_ < 12; T559_++) 
  T560_[T559_] = (*conf).modifiedyNotes[T559_] & (*conf).notes[T559_];
		for (T558_ = 0; T558_ < 12; T558_++) 
  T561_[T558_] = T560_[T558_] | verb[T558_];
		T562_ = (NI)0;
		T563_ = (NI)0;
		for (T563_ = 0; T563_ < 12; T563_++) 
  T564_[T563_] = (*conf).modifiedyNotes[T563_] & verb[T563_];
		for (T562_ = 0; T562_ < 12; T562_++) 
  T565_[T562_] = T564_[T562_] & ~ (*conf).notes[T562_];
		for (T557_ = 0; T557_ < 12; T557_++) 
  (*conf).notes[T557_] = T561_[T557_] & ~ T565_[T557_];
		nimCopyMem((void*)(*conf).mainPackageNotes, (NIM_CONST void*)(*conf).notes, 12);
	}
	goto LA139_;
	LA82_: ;
	{
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		(*conf).numberOfProcessors = nsuParseInt(arg);
	}
	goto LA139_;
	LA83_: ;
	{
		expectNoArg__commands_268(conf, switch_0, arg, pass, info);
		writeVersionInfo__commands_159(conf, pass);
	}
	goto LA139_;
	LA84_: ;
	{
		expectNoArg__commands_268(conf, switch_0, arg, pass, info);
		writeAdvancedUsage__commands_145(conf, pass);
	}
	goto LA139_;
	LA85_: ;
	{
		expectNoArg__commands_268(conf, switch_0, arg, pass, info);
		writeFullhelp__commands_152(conf, pass);
	}
	goto LA139_;
	LA86_: ;
	{
		expectNoArg__commands_268(conf, switch_0, arg, pass, info);
		helpOnError__commands_137(conf, pass);
	}
	goto LA139_;
	LA87_: ;
	{
		{
			NimStringDesc* T574_;
			tyArray__Re75IspeoxXy2oCZHwcRrA T577_;
			NimStringDesc* T578_;
			T574_ = NIM_NIL;
			T574_ = nsuNormalize(switch_0);
			if (!eqStrings(T574_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_137))) goto LA575_;
			nimZeroMem((void*)T577_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T577_[0] = copyString(switch_0);
			T577_[1] = copyString(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_138));
			T578_ = NIM_NIL;
			T578_ = nsuFormatOpenArray(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_210), T577_, 2);
			warningDeprecated__msgs_1428(conf, info, T578_);
		}
		LA575_: ;
		{
			NimStringDesc* T583_;
			if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA581_;
			T583_ = NIM_NIL;
			T583_ = nsuNormalize(arg);
			if (eqStrings(T583_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_215))) goto LA584_;
			if (eqStrings(T583_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_216))) goto LA585_;
			if (eqStrings(T583_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_307))) goto LA586_;
			if (eqStrings(T583_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_308))) goto LA587_;
			if (eqStrings(T583_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_243))) goto LA588_;
			if (eqStrings(T583_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_309))) goto LA589_;
			goto LA590_;
			LA584_: ;
			{
				(*conf).symbolFiles = ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 3);
			}
			goto LA591_;
			LA585_: ;
			{
				(*conf).symbolFiles = ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0);
			}
			goto LA591_;
			LA586_: ;
			{
				(*conf).symbolFiles = ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 1);
			}
			goto LA591_;
			LA587_: ;
			{
				(*conf).symbolFiles = ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 2);
			}
			goto LA591_;
			LA588_: ;
			{
				(*conf).symbolFiles = ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 3);
			}
			goto LA591_;
			LA589_: ;
			{
				(*conf).symbolFiles = ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 4);
			}
			goto LA591_;
			LA590_: ;
			{
				NimStringDesc* T599_;
				T599_ = NIM_NIL;
				T599_ = rawNewString((arg ? arg->Sup.len : 0) + 34);
appendString(T599_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_310));
appendString(T599_, arg);
				liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T599_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_311, NIM_FALSE);
			}
			LA591_: ;
		}
		LA581_: ;
		setUseIc__ast_995(!(((*conf).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0))));
	}
	goto LA139_;
	LA88_: ;
	{
		processOnOffSwitchG__commands_244(conf, 131072, arg, pass, info);
	}
	goto LA139_;
	LA89_: ;
	{
		processOnOffSwitchG__commands_244(conf, 262144, arg, pass, info);
	}
	goto LA139_;
	LA90_: ;
	{
		processOnOffSwitchG__commands_244(conf, 524288, arg, pass, info);
	}
	goto LA139_;
	LA91_: ;
	{
		processOnOffSwitchG__commands_244(conf, 1048576, arg, pass, info);
	}
	goto LA139_;
	LA92_: ;
	{
		{
			NimStringDesc* T607_;
			tyArray__Re75IspeoxXy2oCZHwcRrA T610_;
			NimStringDesc* T611_;
			T607_ = NIM_NIL;
			T607_ = nsuNormalize(switch_0);
			if (!eqStrings(T607_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_145))) goto LA608_;
			nimZeroMem((void*)T610_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T610_[0] = copyString(switch_0);
			T610_[1] = copyString(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_144));
			T611_ = NIM_NIL;
			T611_ = nsuFormatOpenArray(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_210), T610_, 2);
			warningDeprecated__msgs_1428(conf, info, T611_);
		}
		LA608_: ;
		processOnOffSwitchG__commands_244(conf, 1024, arg, pass, info);
		processOnOffSwitchG__commands_244(conf, 16, arg, pass, info);
	}
	goto LA139_;
	LA93_: ;
	{
		processOnOffSwitchG__commands_244(conf, 4194304, arg, pass, info);
	}
	goto LA139_;
	LA94_: ;
	{
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		asgnRef((void**) (&(*conf).libpath), processPath__commands_732(conf, arg, info, NIM_TRUE));
	}
	goto LA139_;
	LA95_: ;
	{
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		splitSwitch__commands_183(conf, arg, (&key), (&val), pass, info);
		putEnv__pureZos_426(key, val);
	}
	goto LA139_;
	LA96_: ;
	{
		{
			if (!!(((*conf).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 3)))) goto LA618_;
			expectArg__commands_262(conf, switch_0, arg, pass, info);
			setCC__extccomp_651(conf, arg, info);
		}
		LA618_: ;
	}
	goto LA139_;
	LA97_: ;
	{
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		track__commands_778(conf, arg, info);
	}
	goto LA139_;
	LA98_: ;
	{
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		trackDirty__commands_770(conf, arg, info);
	}
	goto LA139_;
	LA99_: ;
	{
		expectNoArg__commands_268(conf, switch_0, arg, pass, info);
		(*conf).ideCmd = ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 1);
	}
	goto LA139_;
	LA100_: ;
	{
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		trackIde__commands_786(conf, ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 3), arg, info);
	}
	goto LA139_;
	LA101_: ;
	{
		expectNoArg__commands_268(conf, switch_0, arg, pass, info);
		(*conf).ideCmd = ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 2);
	}
	goto LA139_;
	LA102_: ;
	{
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		trackIde__commands_786(conf, ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 4), arg, info);
	}
	goto LA139_;
	LA103_: ;
	{
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		trackIde__commands_786(conf, ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 5), arg, info);
	}
	goto LA139_;
	LA104_: ;
	{
		processOnOffSwitchG__commands_244(conf, 16777216, arg, pass, info);
	}
	goto LA139_;
	LA105_: ;
	{
		NimStringDesc* T629_;
		T629_ = NIM_NIL;
		T629_ = nsuNormalize(arg);
		if (eqStrings(T629_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_321))) goto LA630_;
		if (eqStrings(T629_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_322))) goto LA631_;
		if (eqStrings(T629_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_323))) goto LA632_;
		goto LA633_;
		LA630_: ;
		{
			(*conf).filenameOption = ((tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w) 0);
		}
		goto LA634_;
		LA631_: ;
		{
			(*conf).filenameOption = ((tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w) 2);
		}
		goto LA634_;
		LA632_: ;
		{
			(*conf).filenameOption = ((tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w) 3);
		}
		goto LA634_;
		LA633_: ;
		{
			NimStringDesc* T639_;
			T639_ = NIM_NIL;
			T639_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_324), arg);
			liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T639_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_325, NIM_FALSE);
		}
		LA634_: ;
	}
	goto LA139_;
	LA106_: ;
	{
		NimStringDesc* T641_;
		(*conf).notes[(NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 83)- 17))>>3] |=(1U<<((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 83)- 17)&7U));
		(*conf).mainPackageNotes[(NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 83)- 17))>>3] |=(1U<<((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 83)- 17)&7U));
		T641_ = NIM_NIL;
		T641_ = nsuNormalize(arg);
		if (eqStrings(T641_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_326))) goto LA642_;
		if (eqStrings(T641_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_157))) goto LA643_;
		if (eqStrings(T641_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_216))) goto LA644_;
		goto LA645_;
		LA642_: ;
		{
			(*conf).hintProcessingDots = NIM_TRUE;
		}
		goto LA646_;
		LA643_: ;
		{
			(*conf).hintProcessingDots = NIM_FALSE;
		}
		goto LA646_;
		LA644_: ;
		{
			(*conf).notes[(NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 83)- 17))>>3] &= ~(1U<<((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 83)- 17)&7U));
			(*conf).mainPackageNotes[(NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 83)- 17))>>3] &= ~(1U<<((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 83)- 17)&7U));
		}
		goto LA646_;
		LA645_: ;
		{
			NimStringDesc* T651_;
			T651_ = NIM_NIL;
			T651_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_327), arg);
			liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T651_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_328, NIM_FALSE);
		}
		LA646_: ;
	}
	goto LA139_;
	LA107_: ;
	{
		{
			NIM_BOOL T655_;
			NimStringDesc* T656_;
			NimStringDesc* T667_;
			T655_ = (NIM_BOOL)0;
			T656_ = NIM_NIL;
			T656_ = nsuNormalize(arg);
			if (eqStrings(T656_, ((NimStringDesc*) NIM_NIL))) goto LA657_;
			if (eqStrings(T656_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_215))) goto LA657_;
			if (eqStrings(T656_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_216))) goto LA658_;
			goto LA659_;
			LA657_: ;
			{
				T655_ = NIM_TRUE;
			}
			goto LA660_;
			LA658_: ;
			{
				T655_ = NIM_FALSE;
			}
			goto LA660_;
			LA659_: ;
			{
				NimStringDesc* T664_;
				T664_ = NIM_NIL;
				T664_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_217), arg);
				liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T664_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_329, NIM_FALSE);
				T655_ = NIM_FALSE;
			}
			LA660_: ;
			if (!T655_) goto LA665_;
			T667_ = NIM_NIL;
			T667_ = (*conf).unitSep; (*conf).unitSep = copyStringRC1(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_330));
			if (T667_) nimGCunrefNoCycle(T667_);
		}
		goto LA653_;
		LA665_: ;
		{
			asgnRef((void**) (&(*conf).unitSep), ((NimStringDesc*) NIM_NIL));
		}
		LA653_: ;
	}
	goto LA139_;
	LA108_: ;
	{
		{
			NIM_BOOL T672_;
			NimStringDesc* T673_;
			T672_ = (NIM_BOOL)0;
			T673_ = NIM_NIL;
			T673_ = nsuNormalize(arg);
			if (eqStrings(T673_, ((NimStringDesc*) NIM_NIL))) goto LA674_;
			if (eqStrings(T673_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_215))) goto LA674_;
			if (eqStrings(T673_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_216))) goto LA675_;
			goto LA676_;
			LA674_: ;
			{
				T672_ = NIM_TRUE;
			}
			goto LA677_;
			LA675_: ;
			{
				T672_ = NIM_FALSE;
			}
			goto LA677_;
			LA676_: ;
			{
				NimStringDesc* T681_;
				T681_ = NIM_NIL;
				T681_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_217), arg);
				liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T681_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_329, NIM_FALSE);
				T672_ = NIM_FALSE;
			}
			LA677_: ;
			if (!T672_) goto LA682_;
			(*conf).filenameOption = ((tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w) 0);
		}
		goto LA670_;
		LA682_: ;
		{
			(*conf).filenameOption = ((tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w) 2);
		}
		LA670_: ;
	}
	goto LA139_;
	LA109_: ;
	{
		{
			if (!((arg ? arg->Sup.len : 0) == ((NI) 0))) goto LA688_;
			(*conf).spellSuggestMax = ((NI) -1);
		}
		goto LA686_;
		LA688_: ;
		{
			if (!eqStrings(arg, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_331))) goto LA691_;
			(*conf).spellSuggestMax = ((NI) -1);
		}
		goto LA686_;
		LA691_: ;
		{
			(*conf).spellSuggestMax = nsuParseInt(arg);
		}
		LA686_: ;
	}
	goto LA139_;
	LA110_: ;
	{
		processOnOffSwitchG__commands_244(conf, IL64(68719476736), arg, pass, info);
	}
	goto LA139_;
	LA111_: ;
	{
		dynlibOverride__commands_795(conf, switch_0, arg, pass, info);
	}
	goto LA139_;
	LA112_: ;
	{
		processOnOffSwitchG__commands_244(conf, IL64(549755813888), arg, pass, info);
	}
	goto LA139_;
	LA113_: ;
	{
		{
			if (!((arg ? arg->Sup.len : 0) == ((NI) 0))) goto LA700_;
			(*conf).features = ((*conf).features | 15);
		}
		goto LA698_;
		LA700_: ;
		{
			TSafePoint TM__aFkIL74T1q8RouIu9auwZ3g_332;
			tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw T703_;
			pushSafePoint(&TM__aFkIL74T1q8RouIu9auwZ3g_332);
			TM__aFkIL74T1q8RouIu9auwZ3g_332.status = _setjmp(TM__aFkIL74T1q8RouIu9auwZ3g_332.context);
			if (TM__aFkIL74T1q8RouIu9auwZ3g_332.status == 0) {
			T703_ = (tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw)0;
			T703_ = parseEnum__commands_1298(arg);
			(*conf).features |= ((NU32)1)<<((T703_) & 31);
			popSafePoint();
			}
			else {
				popSafePoint();
				if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIvalueerror__5lcTdgqMq62cNGRwBb0thA_))) {
					TM__aFkIL74T1q8RouIu9auwZ3g_332.status = 0;
					liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_333), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_334, NIM_FALSE);
					popCurrentException();
				}
			}
			if (TM__aFkIL74T1q8RouIu9auwZ3g_332.status != 0) reraiseException();
		}
		LA698_: ;
	}
	goto LA139_;
	LA114_: ;
	{
		TSafePoint TM__aFkIL74T1q8RouIu9auwZ3g_335;
		tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g T707_;
		pushSafePoint(&TM__aFkIL74T1q8RouIu9auwZ3g_335);
		TM__aFkIL74T1q8RouIu9auwZ3g_335.status = _setjmp(TM__aFkIL74T1q8RouIu9auwZ3g_335.context);
		if (TM__aFkIL74T1q8RouIu9auwZ3g_335.status == 0) {
		T707_ = (tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g)0;
		T707_ = parseEnum__commands_1351(arg);
		(*conf).legacyFeatures |= ((NU8)1)<<((T707_) & 7);
		popSafePoint();
		}
		else {
			popSafePoint();
			if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIvalueerror__5lcTdgqMq62cNGRwBb0thA_))) {
				TM__aFkIL74T1q8RouIu9auwZ3g_335.status = 0;
				liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_336), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_337, NIM_FALSE);
				popCurrentException();
			}
		}
		if (TM__aFkIL74T1q8RouIu9auwZ3g_335.status != 0) reraiseException();
	}
	goto LA139_;
	LA115_: ;
	{
		expectNoArg__commands_268(conf, switch_0, arg, pass, info);
		(*conf).exc = ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 0);
		defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_338), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
	}
	goto LA139_;
	LA116_: ;
	{
		NimStringDesc* T712_;
		T712_ = NIM_NIL;
		T712_ = nsuNormalize(arg);
		if (eqStrings(T712_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_7))) goto LA713_;
		if (eqStrings(T712_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_339))) goto LA714_;
		if (eqStrings(T712_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_340))) goto LA715_;
		if (eqStrings(T712_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_341))) goto LA716_;
		goto LA717_;
		LA713_: ;
		{
			(*conf).exc = ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 2);
		}
		goto LA718_;
		LA714_: ;
		{
			(*conf).exc = ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 1);
		}
		goto LA718_;
		LA715_: ;
		{
			(*conf).exc = ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 4);
		}
		goto LA718_;
		LA716_: ;
		{
			(*conf).exc = ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 3);
		}
		goto LA718_;
		LA717_: ;
		{
			NimStringDesc* T724_;
			T724_ = NIM_NIL;
			T724_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_342), arg);
			liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T724_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_343, NIM_FALSE);
		}
		LA718_: ;
	}
	goto LA139_;
	LA117_: ;
	{
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		{
			if (!!((conf == ((tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) NIM_NIL)))) goto LA728_;
			cppDefine__options_2530(conf, arg);
		}
		LA728_: ;
	}
	goto LA139_;
	LA118_: ;
	{
		warningDeprecated__msgs_1428(conf, info, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_344));
		expectNoArg__commands_268(conf, switch_0, arg, pass, info);
		{
			if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA733_;
			{
				if (!!(!((conf == ((tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) NIM_NIL))))) goto LA737_;
				failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_345));
			}
			LA737_: ;
			(*conf).features |= ((NU32)1)<<((((tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw) 4)) & 31);
			(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 41)) & 63);
			(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 42)) & 63);
			(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40)) & 63);
			defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_249), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
			(*conf).selectedGC = ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 7);
			defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_251), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
			defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_248), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
			defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_346), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
		}
		LA733_: ;
	}
	goto LA139_;
	LA119_: ;
	{
		processOnOffSwitchG__commands_244(conf, IL64(1099511627776), arg, pass, info);
		{
			if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA742_;
			defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_248), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
		}
		LA742_: ;
	}
	goto LA139_;
	LA120_: ;
	{
		NimStringDesc* T745_;
		T745_ = NIM_NIL;
		T745_ = nsuNormalize(arg);
		if (eqStrings(T745_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_216))) goto LA746_;
		if (eqStrings(T745_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_75))) goto LA747_;
		if (eqStrings(T745_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_347))) goto LA748_;
		if (eqStrings(T745_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_154))) goto LA749_;
		goto LA750_;
		LA746_: ;
		{
			(*conf).globalOptions = ((*conf).globalOptions & ~ 49152);
		}
		goto LA751_;
		LA747_: ;
		{
			(*conf).globalOptions = (((*conf).globalOptions | 16384) & ~ 32768);
		}
		goto LA751_;
		LA748_: ;
		{
			(*conf).globalOptions = ((*conf).globalOptions | 32768);
		}
		goto LA751_;
		LA749_: ;
		{
			(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 16)) & 63);
		}
		goto LA751_;
		LA750_: ;
		{
			NimStringDesc* T757_;
			T757_ = NIM_NIL;
			T757_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_348), arg);
			liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T757_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_349, NIM_FALSE);
		}
		LA751_: ;
	}
	goto LA139_;
	LA121_: ;
	{
		processOnOffSwitchG__commands_244(conf, IL64(4294967296), arg, pass, info);
	}
	goto LA139_;
	LA122_: ;
	{
		{
			NimStringDesc* T764_;
			if (!(((NI) 0) < (arg ? arg->Sup.len : 0))) goto LA762_;
			T764_ = NIM_NIL;
			T764_ = (*conf).cppCustomNamespace; (*conf).cppCustomNamespace = copyStringRC1(arg);
			if (T764_) nimGCunrefNoCycle(T764_);
		}
		goto LA760_;
		LA762_: ;
		{
			NimStringDesc* T766_;
			T766_ = NIM_NIL;
			T766_ = (*conf).cppCustomNamespace; (*conf).cppCustomNamespace = copyStringRC1(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_350));
			if (T766_) nimGCunrefNoCycle(T766_);
		}
		LA760_: ;
		defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_351), (*conf).cppCustomNamespace);
	}
	goto LA139_;
	LA123_: ;
	{
		processOnOffSwitchG__commands_244(conf, IL64(17179869184), arg, pass, info);
	}
	goto LA139_;
	LA124_: ;
	{
		processOnOffSwitchG__commands_244(conf, IL64(8796093022208), arg, pass, info);
	}
	goto LA139_;
	LA125_: ;
	{
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		nstPut((*conf).macrosToExpand, arg, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_352));
	}
	goto LA139_;
	LA126_: ;
	{
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		nstPut((*conf).arcToExpand, arg, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_352));
	}
	goto LA139_;
	LA127_: ;
	{
		expectArg__commands_262(conf, switch_0, arg, pass, info);
		if (eqStrings(arg, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_353))) goto LA772_;
		if (eqStrings(arg, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_354))) goto LA773_;
		goto LA774_;
		LA772_: ;
		{
			defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_355), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_356));
			defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_357), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_358));
			defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_359), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
			undefSymbol__condsyms_8((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_360));
			eqTypeFlags__ast_481 = (eqTypeFlags__ast_481 & ~ 130);
			(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 47)) & 63);
		}
		goto LA775_;
		LA773_: ;
		{
			defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_355), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_356));
			defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_357), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_361));
			(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 48)) & 63);
		}
		goto LA775_;
		LA774_: ;
		{
			liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_362), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_363, NIM_FALSE);
		}
		LA775_: ;
		defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_364), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_365));
	}
	goto LA139_;
	LA128_: ;
	{
		processOnOffSwitchG__commands_244(conf, IL64(17592186044416), arg, pass, info);
	}
	goto LA139_;
	LA129_: ;
	{
		processOnOffSwitchG__commands_244(conf, IL64(1125899906842624), arg, pass, info);
	}
	goto LA139_;
	LA130_: ;
	{
		processOnOffSwitch__commands_209(conf, 33554432, arg, pass, info);
	}
	goto LA139_;
	LA131_: ;
	{
		processOnOffSwitch__commands_209(conf, 67108864, arg, pass, info);
	}
	goto LA139_;
	LA132_: ;
	{
		processOnOffSwitchG__commands_244(conf, IL64(70368744177664), arg, pass, info);
		{
			if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 46))&63U)))!=0)) goto LA786_;
			defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_366), ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_231));
		}
		LA786_: ;
	}
	goto LA139_;
	LA133_: ;
	{
		(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 49)) & 63);
		(*conf).options |= ((NU32)1)<<((((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12)) & 31);
	}
	goto LA139_;
	LA134_: ;
	{
		processOnOffSwitchG__commands_244(conf, IL64(2251799813685248), arg, pass, info);
	}
	goto LA139_;
	LA135_: ;
	{
		handleStdinInput__commands_807(conf);
	}
	goto LA139_;
	LA136_: ;
	{
		NimStringDesc* T792_;
		T792_ = NIM_NIL;
		T792_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_255), switch_0);
		warningDeprecated__msgs_1428(conf, info, T792_);
	}
	goto LA139_;
	LA137_: ;
	{
		NimStringDesc* T794_;
		T794_ = NIM_NIL;
		T794_ = (*conf).nimMainPrefix; (*conf).nimMainPrefix = copyStringRC1(arg);
		if (T794_) nimGCunrefNoCycle(T794_);
	}
	goto LA139_;
	LA138_: ;
	{
		{
			NI T798_;
			T798_ = (NI)0;
			T798_ = nsuFindChar(switch_0, 46, ((NI) 0), ((NI) 0));
			if (!(((NI) 0) <= T798_)) goto LA799_;
			setConfigVar__options_4059(conf, switch_0, arg);
		}
		goto LA796_;
		LA799_: ;
		{
			invalidCmdLineOption__commands_178(conf, pass, switch_0, info);
		}
		LA796_: ;
	}
	LA139_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processSwitch__commands_1515)(tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass, tyObject_OptParser__Sj2pYlEalgMxSDrjh9cml3w* p, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config) {
	NI bracketLe;
	bracketLe = nsuFindChar((*p).key, 91, ((NI) 0), ((NI) 0));
	{
		NimStringDesc* key;
		NimStringDesc* val;
		NimStringDesc* T5_;
		NimStringDesc* T6_;
		if (!(((NI) 0) <= bracketLe)) goto LA3_;
		key = substr__system_7736((*p).key, ((NI) 0), (NI)(bracketLe - ((NI) 1)));
		T5_ = NIM_NIL;
		T6_ = NIM_NIL;
		T6_ = substr__system_7748((*p).key, bracketLe);
		T5_ = rawNewString((T6_ ? T6_->Sup.len : 0) + ((*p).val ? (*p).val->Sup.len : 0) + 1);
appendString(T5_, T6_);
appendChar(T5_, 58);
appendString(T5_, (*p).val);
		val = T5_;
		processSwitch__commands_880(key, val, pass, gCmdLineInfo__msgs_414, config);
	}
	goto LA1_;
	LA3_: ;
	{
		processSwitch__commands_880((*p).key, (*p).val, pass, gCmdLineInfo__msgs_414, config);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, writeCommandLineUsage__commands_169)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NimStringDesc* T1_;
	T1_ = NIM_NIL;
	T1_ = getCommandLineDesc__commands_134(conf);
	msgWriteln__msgs_657(conf, T1_, 1);
}
N_LIB_PRIVATE N_NIMCALL(void, handleCmdInput__commands_812)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	T1_ = NIM_NIL;
	T1_ = (*conf).projectName; (*conf).projectName = copyStringRC1(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_368));
	if (T1_) nimGCunrefNoCycle(T1_);
	T2_ = NIM_NIL;
	T2_ = (*conf).projectFull; (*conf).projectFull = copyStringRC1((*conf).projectName);
	if (T2_) nimGCunrefNoCycle(T2_);
	asgnRef((void**) (&(*conf).projectPath), nosgetCurrentDir());
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = isEmpty__pathutils_94((*conf).outDir);
		if (!T5_) goto LA6_;
		asgnRef((void**) (&(*conf).outDir), getNimcacheDir__options_4185(conf));
	}
	LA6_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, testCompileOption__commands_574)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* switch_0, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NIM_BOOL result;
	NimStringDesc* T1_;
	result = (NIM_BOOL)0;
	T1_ = NIM_NIL;
	T1_ = nsuNormalize(switch_0);
	switch (hashString(T1_) & 63) {
	case 1: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_89))) goto LA16_;
break;
	case 2: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_104))) goto LA29_;
break;
	case 6: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_81))) goto LA11_;
break;
	case 8: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_93))) goto LA19_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_137))) goto LA31_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_108))) goto LA36_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_109))) goto LA36_;
break;
	case 9: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_79))) goto LA9_;
break;
	case 12: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_190))) goto LA38_;
break;
	case 13: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_101))) goto LA27_;
break;
	case 14: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_65))) goto LA4_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_96))) goto LA22_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_103))) goto LA29_;
break;
	case 16: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_72))) goto LA7_;
break;
	case 19: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_84))) goto LA13_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_86))) goto LA14_;
break;
	case 22: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_102))) goto LA28_;
break;
	case 23: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_187))) goto LA38_;
break;
	case 24: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_67))) goto LA6_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_83))) goto LA12_;
break;
	case 25: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_3))) goto LA3_;
break;
	case 26: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_92))) goto LA18_;
break;
	case 29: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_66))) goto LA5_;
break;
	case 30: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_64))) goto LA3_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_87))) goto LA15_;
break;
	case 31: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_99))) goto LA25_;
break;
	case 32: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_73))) goto LA7_;
break;
	case 34: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_13))) goto LA30_;
break;
	case 36: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_94))) goto LA20_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_106))) goto LA34_;
break;
	case 37: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_90))) goto LA16_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_98))) goto LA24_;
break;
	case 39: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_82))) goto LA37_;
break;
	case 40: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_80))) goto LA10_;
break;
	case 41: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_97))) goto LA23_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_14))) goto LA30_;
break;
	case 42: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_144))) goto LA32_;
break;
	case 45: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_62))) goto LA2_;
break;
	case 46: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_68))) goto LA6_;
break;
	case 49: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_95))) goto LA21_;
break;
	case 51: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_78))) goto LA8_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_188))) goto LA38_;
break;
	case 53: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_91))) goto LA17_;
break;
	case 54: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_105))) goto LA33_;
break;
	case 58: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_100))) goto LA26_;
break;
	case 62: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_107))) goto LA35_;
break;
	}
	goto LA39_;
	LA2_: ;
	{
		result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 6))&63U)))!=0);
	}
	goto LA40_;
	LA3_: ;
	{
		result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 4))&63U)))!=0);
	}
	goto LA40_;
	LA4_: ;
	{
		result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 5))&63U)))!=0);
	}
	goto LA40_;
	LA5_: ;
	{
		result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 21))&63U)))!=0);
	}
	goto LA40_;
	LA6_: ;
	{
		result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 1))&63U)))!=0);
	}
	goto LA40_;
	LA7_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 13))&31U)))!=0);
	}
	goto LA40_;
	LA8_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 14))&31U)))!=0);
	}
	goto LA40_;
	LA9_: ;
	{
		result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 25))&63U)))!=0);
	}
	goto LA40_;
	LA10_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 17))&31U)))!=0);
	}
	goto LA40_;
	LA11_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 18))&31U)))!=0);
	}
	goto LA40_;
	LA12_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 19))&31U)))!=0);
	}
	goto LA40_;
	LA13_: ;
	{
		result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 6))&63U)))!=0);
	}
	goto LA40_;
	LA14_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 21))&31U)))!=0);
	}
	goto LA40_;
	LA15_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 24))&31U)))!=0);
	}
	goto LA40_;
	LA16_: ;
	{
		result = (((*conf).options & 3518) == 3518);
	}
	goto LA40_;
	LA17_: ;
	{
		result = (((*conf).options & 384) == 384);
	}
	goto LA40_;
	LA18_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 8))&31U)))!=0);
	}
	goto LA40_;
	LA19_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 7))&31U)))!=0);
	}
	goto LA40_;
	LA20_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 1))&31U)))!=0);
	}
	goto LA40_;
	LA21_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 2))&31U)))!=0);
	}
	goto LA40_;
	LA22_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 3))&31U)))!=0);
	}
	goto LA40_;
	LA23_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 4))&31U)))!=0);
	}
	goto LA40_;
	LA24_: ;
	{
		warningDeprecated__msgs_1428(conf, info, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_277));
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 6))&31U)))!=0);
	}
	goto LA40_;
	LA25_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 5))&31U)))!=0);
	}
	goto LA40_;
	LA26_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 9))&31U)))!=0);
	}
	goto LA40_;
	LA27_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 10))&31U)))!=0);
	}
	goto LA40_;
	LA28_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 12))&31U)))!=0);
	}
	goto LA40_;
	LA29_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 11))&31U)))!=0);
	}
	goto LA40_;
	LA30_: ;
	{
		result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 12))&63U)))!=0);
	}
	goto LA40_;
	LA31_: ;
	{
		result = !(((*conf).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0)));
	}
	goto LA40_;
	LA32_: ;
	{
		result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 10))&63U)))!=0);
	}
	goto LA40_;
	LA33_: ;
	{
		result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 23))&63U)))!=0);
	}
	goto LA40_;
	LA34_: ;
	{
		result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 26))&63U)))!=0);
	}
	goto LA40_;
	LA35_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 22))&31U)))!=0);
	}
	goto LA40_;
	LA36_: ;
	{
		{
			NimStringDesc* T78_;
			tyArray__Re75IspeoxXy2oCZHwcRrA T81_;
			NimStringDesc* T82_;
			T78_ = NIM_NIL;
			T78_ = nsuNormalize(switch_0);
			if (!eqStrings(T78_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_108))) goto LA79_;
			nimZeroMem((void*)T81_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T81_[0] = copyString(switch_0);
			T81_[1] = copyString(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_109));
			T82_ = NIM_NIL;
			T82_ = nsuFormatOpenArray(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_210), T81_, 2);
			warningDeprecated__msgs_1428(conf, info, T82_);
		}
		LA79_: ;
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 23))&31U)))!=0);
	}
	goto LA40_;
	LA37_: ;
	{
		result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 31))&63U)))!=0);
	}
	goto LA40_;
	LA38_: ;
	{
		NimStringDesc* T85_;
		T85_ = NIM_NIL;
		T85_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_255), switch_0);
		warningDeprecated__msgs_1428(conf, info, T85_);
	}
	goto LA40_;
	LA39_: ;
	{
		invalidCmdLineOption__commands_178(conf, ((tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w) 0), switch_0, info);
	}
	LA40_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, testCompileOptionArg__commands_473)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* switch_0, NimStringDesc* arg, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NIM_BOOL result;
	NimStringDesc* T1_;
	result = (NIM_BOOL)0;
	T1_ = NIM_NIL;
	T1_ = nsuNormalize(switch_0);
	if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_70))) goto LA2_;
	if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_71))) goto LA2_;
	if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_110))) goto LA3_;
	if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_130))) goto LA4_;
	if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_111))) goto LA5_;
	if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_163))) goto LA6_;
	if (eqStrings(T1_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_168))) goto LA7_;
	goto LA8_;
	LA2_: ;
	{
		NimStringDesc* T11_;
		T11_ = NIM_NIL;
		T11_ = nsuNormalize(arg);
		switch (hashString(T11_) & 15) {
		case 1: 
if (eqStrings(T11_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_232))) goto LA12_;
if (eqStrings(T11_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_234))) goto LA14_;
if (eqStrings(T11_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_240))) goto LA19_;
break;
		case 2: 
if (eqStrings(T11_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_235))) goto LA15_;
break;
		case 3: 
if (eqStrings(T11_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_241))) goto LA20_;
break;
		case 6: 
if (eqStrings(T11_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_238))) goto LA17_;
break;
		case 7: 
if (eqStrings(T11_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_239))) goto LA18_;
break;
		case 9: 
if (eqStrings(T11_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_237))) goto LA16_;
break;
		case 10: 
if (eqStrings(T11_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_242))) goto LA20_;
if (eqStrings(T11_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_369))) goto LA21_;
break;
		case 11: 
if (eqStrings(T11_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_243))) goto LA21_;
break;
		case 13: 
if (eqStrings(T11_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_236))) goto LA15_;
break;
		case 14: 
if (eqStrings(T11_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_233))) goto LA13_;
break;
		}
		goto LA22_;
		LA12_: ;
		{
			result = ((*conf).selectedGC == ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 2));
		}
		goto LA23_;
		LA13_: ;
		{
			result = ((*conf).selectedGC == ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 8));
		}
		goto LA23_;
		LA14_: ;
		{
			result = ((*conf).selectedGC == ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 6));
		}
		goto LA23_;
		LA15_: ;
		{
			result = ((*conf).selectedGC == ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 4));
		}
		goto LA23_;
		LA16_: ;
		{
			result = ((*conf).selectedGC == ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 5));
		}
		goto LA23_;
		LA17_: ;
		{
			result = ((*conf).selectedGC == ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 7));
		}
		goto LA23_;
		LA18_: ;
		{
			result = ((*conf).selectedGC == ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 10));
		}
		goto LA23_;
		LA19_: ;
		{
			result = ((*conf).selectedGC == ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 1));
		}
		goto LA23_;
		LA20_: ;
		{
			result = ((*conf).selectedGC == ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 3));
		}
		goto LA23_;
		LA21_: ;
		{
			NimStringDesc* T34_;
			T34_ = NIM_NIL;
			T34_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_255), arg);
			warningDeprecated__msgs_1428(conf, info, T34_);
		}
		goto LA23_;
		LA22_: ;
		{
			NimStringDesc* T36_;
			T36_ = NIM_NIL;
			T36_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_256), arg);
			liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T36_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_370, NIM_FALSE);
		}
		LA23_: ;
	}
	goto LA9_;
	LA3_: ;
	{
		NimStringDesc* T38_;
		T38_ = NIM_NIL;
		T38_ = nsuNormalize(arg);
		if (eqStrings(T38_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_278))) goto LA39_;
		if (eqStrings(T38_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_279))) goto LA40_;
		if (eqStrings(T38_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_240))) goto LA41_;
		goto LA42_;
		LA39_: ;
		{
			result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 15))&31U)))!=0);
		}
		goto LA43_;
		LA40_: ;
		{
			result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 16))&31U)))!=0);
		}
		goto LA43_;
		LA41_: ;
		{
			result = (((*conf).options & 98304) == 0);
		}
		goto LA43_;
		LA42_: ;
		{
			NimStringDesc* T48_;
			T48_ = NIM_NIL;
			T48_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_280), arg);
			liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T48_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_371, NIM_FALSE);
		}
		LA43_: ;
	}
	goto LA9_;
	LA4_: ;
	{
		NimStringDesc* T50_;
		T50_ = NIM_NIL;
		T50_ = dollar___systemZdollars_3((*conf).verbosity);
		result = eqStrings(T50_, arg);
	}
	goto LA9_;
	LA5_: ;
	{
		NimStringDesc* T52_;
		T52_ = NIM_NIL;
		T52_ = nsuNormalize(arg);
		if (eqStrings(T52_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_282))) goto LA53_;
		if (eqStrings(T52_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_283))) goto LA54_;
		if (eqStrings(T52_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_147))) goto LA55_;
		if (eqStrings(T52_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_284))) goto LA56_;
		goto LA57_;
		LA53_: ;
		{
			result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 9))&63U)))!=0);
		}
		goto LA58_;
		LA54_: ;
		{
			result = !((((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 9))&63U)))!=0));
		}
		goto LA58_;
		LA55_: ;
		{
			NIM_BOOL T62_;
			T62_ = (NIM_BOOL)0;
			T62_ = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 7))&63U)))!=0);
			if (!(T62_)) goto LA63_;
			T62_ = !((((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 9))&63U)))!=0));
			LA63_: ;
			result = T62_;
		}
		goto LA58_;
		LA56_: ;
		{
			NIM_BOOL T65_;
			T65_ = (NIM_BOOL)0;
			T65_ = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 8))&63U)))!=0);
			if (!(T65_)) goto LA66_;
			T65_ = !((((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 9))&63U)))!=0));
			LA66_: ;
			result = T65_;
		}
		goto LA58_;
		LA57_: ;
		{
			NimStringDesc* T68_;
			T68_ = NIM_NIL;
			T68_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_290), arg);
			liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T68_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_372, NIM_FALSE);
		}
		LA58_: ;
	}
	goto LA9_;
	LA6_: ;
	{
		result = isDynlibOverride__options_4674(conf, arg);
	}
	goto LA9_;
	LA7_: ;
	{
		NimStringDesc* T71_;
		T71_ = NIM_NIL;
		T71_ = nsuNormalize(arg);
		if (eqStrings(T71_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_7))) goto LA72_;
		if (eqStrings(T71_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_339))) goto LA73_;
		if (eqStrings(T71_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_340))) goto LA74_;
		if (eqStrings(T71_, ((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_341))) goto LA75_;
		goto LA76_;
		LA72_: ;
		{
			result = ((*conf).exc == ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 2));
		}
		goto LA77_;
		LA73_: ;
		{
			result = ((*conf).exc == ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 1));
		}
		goto LA77_;
		LA74_: ;
		{
			result = ((*conf).exc == ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 4));
		}
		goto LA77_;
		LA75_: ;
		{
			result = ((*conf).exc == ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 3));
		}
		goto LA77_;
		LA76_: ;
		{
			NimStringDesc* T83_;
			T83_ = NIM_NIL;
			T83_ = nsuFormatSingleElem(((NimStringDesc*) &TM__aFkIL74T1q8RouIu9auwZ3g_342), arg);
			liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T83_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__aFkIL74T1q8RouIu9auwZ3g_373, NIM_FALSE);
		}
		LA77_: ;
	}
	goto LA9_;
	LA8_: ;
	{
		invalidCmdLineOption__commands_178(conf, ((tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w) 0), switch_0, info);
	}
	LA9_: ;
	return result;
}
