/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 32

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tySequence__RNhZxf20g9beyq5VBOGxhDg tySequence__RNhZxf20g9beyq5VBOGxhDg;
typedef struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ;
typedef struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ tySequence__lFbCtu5P2Kf7YDYtGjkxAQ;
typedef struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA;
typedef struct tySequence__ijtae5OneaLys0hN9alAicA tySequence__ijtae5OneaLys0hN9alAicA;
typedef struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w;
typedef struct tySequence__SerjNoUujW2dUouVBrJiCw tySequence__SerjNoUujW2dUouVBrJiCw;
typedef struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyObject_Table__r0v8BdcBPKhl73K8p2VMUA;
typedef struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g tySequence__K9agbtcb0qPZuSJFXB9cTe6g;
typedef struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg;
typedef struct tySequence__m88qdML9cQOuqGAQn6XWL1A tySequence__m88qdML9cQOuqGAQn6XWL1A;
typedef struct tyObject_Table__1hIWbTQWYT4BmhdESze57A tyObject_Table__1hIWbTQWYT4BmhdESze57A;
typedef struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ tySequence__naEbXEp9b9aiW1zXJorqf9cXQ;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA;
typedef struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw;
typedef struct tySequence__ed0C0uAUZPhvw3RAc5hfYg tySequence__ed0C0uAUZPhvw3RAc5hfYg;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tyObject_Table__imojfg883tkWsWJwyshGqQ tyObject_Table__imojfg883tkWsWJwyshGqQ;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg tyObject_Table__BCPh85PHtwxox9bv7NLFrlg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct RootObj RootObj;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA;
typedef struct tySequence__KgiZ29chkJAD01p9aLRB32qw tySequence__KgiZ29chkJAD01p9aLRB32qw;
typedef struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A tyObject_Table__LM44poVdVEn4Mo4N4L8c3A;
typedef struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw tySequence__rkYRZrbHVYL3nhXlQW3K9bw;
typedef struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ tySequence__IRFEb1e9bxgbJLuB5xrdZsQ;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ;
typedef struct tySequence__YmPd0eWfcTfrVYrthlXPYA tySequence__YmPd0eWfcTfrVYrthlXPYA;
typedef struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q;
typedef struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg tySequence__Hz5SYwQU29b9aFLt09blvVQPg;
typedef struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg tyObject_Table__R7JnJQEipxxOlJWXQz7jWg;
typedef struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ tySequence__3G9aA9cLXaPxuRxMKm3anacQ;
typedef struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q tySequence__bPFv6ypvvCX2A9a9al8utL2Q;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ;
typedef struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g tySequence__qeAsXh2i1GAL5Nl0g3OP8g;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg;
typedef struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg;
typedef struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ;
typedef struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg tyTuple__UluY8x0Nj6cp9b0o88wJ0lg;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tySequence__dlD6tEGzYLLpKVq3XwuFlA tySequence__dlD6tEGzYLLpKVq3XwuFlA;
typedef struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ;
typedef struct tyTuple__rZZA0skon1OsHdiEvT8RZQ tyTuple__rZZA0skon1OsHdiEvT8RZQ;
typedef struct tySequence__6OFCSvqRaxyEgUqWtnZSlw tySequence__6OFCSvqRaxyEgUqWtnZSlw;
typedef struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q;
typedef struct tySequence__UnGSk9aaLosDroi2QDrlOfQ tySequence__UnGSk9aaLosDroi2QDrlOfQ;
typedef struct tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA;
typedef struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA tyTuple__q13Zt16VkCqu6Zg5jWqwHA;
typedef struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA tyTuple__aWN9bNzF9bubXNJV9ciomgpfA;
typedef struct tySequence__m4PVWjcAAjfxlwJxLkKn8A tySequence__m4PVWjcAAjfxlwJxLkKn8A;
typedef struct tyTuple__RWXAsQlFoGYyEQZp1G65sg tyTuple__RWXAsQlFoGYyEQZp1G65sg;
typedef struct tyTuple__RmGJuqOgEaHckHndh0LEsw tyTuple__RmGJuqOgEaHckHndh0LEsw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__JfHvHzMrhKkWAUvQKe0i1A tyTuple__JfHvHzMrhKkWAUvQKe0i1A;
typedef struct tyObject_Env_modulegraphsdotnim_ModuleGraph___diB2NTuAIWY0FO9c5IUJRGg tyObject_Env_modulegraphsdotnim_ModuleGraph___diB2NTuAIWY0FO9c5IUJRGg;
typedef struct tyTuple__J4cxakKjhKxTIJR9bojMmXw tyTuple__J4cxakKjhKxTIJR9bojMmXw;
typedef struct tySequence__i89c5kdtWKzK3OEiI81pkkw tySequence__i89c5kdtWKzK3OEiI81pkkw;
typedef struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A;
typedef struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ;
typedef struct tySequence__GR8qmV1kNRcoQ2g76VFy3A tySequence__GR8qmV1kNRcoQ2g76VFy3A;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyTuple__a7QginWFapakKbWJBJ2vfA tyTuple__a7QginWFapakKbWJBJ2vfA;
typedef struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__kbX6x85REySUrk9auORL0vw tyTuple__kbX6x85REySUrk9auORL0vw;
typedef struct NimStringDesc NimStringDesc;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g;
typedef struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q;
typedef struct tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A;
typedef struct tyTuple__nF9cH4hinXgGEUwO4G2bshw tyTuple__nF9cH4hinXgGEUwO4G2bshw;
typedef struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg;
typedef struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg;
typedef struct tySequence__4Murtwnm0Fyc7F9acrytEXw tySequence__4Murtwnm0Fyc7F9acrytEXw;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw;
typedef struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg tySequence__QnmOtn1Iv4LvxOXoMn8Rbg;
typedef struct tySequence__oKtVqsc9bQVCNyrijELM4OQ tySequence__oKtVqsc9bQVCNyrijELM4OQ;
typedef struct tySequence__qy6Iwdy00wN560qud54HTg tySequence__qy6Iwdy00wN560qud54HTg;
typedef struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ tySequence__k67v9bwvvQDmS1ynyGGUbeQ;
typedef struct tySequence__cLsClAAfd0MKkoBQVyvdvw tySequence__cLsClAAfd0MKkoBQVyvdvw;
typedef struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg tySequence__q9bTuOB0JXh1iZ3CSGdRLbg;
typedef struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw;
typedef struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ;
typedef struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ;
typedef struct tySequence__C3r8jsj9chA4sIlYfDN5aDw tySequence__C3r8jsj9chA4sIlYfDN5aDw;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A;
typedef struct tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g;
typedef struct tyObject_RodIter__L6nv9cakjPARHk068AFo6ww tyObject_RodIter__L6nv9cakjPARHk068AFo6ww;
typedef struct tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ;
typedef struct tySequence__lo3S1lKyiPLhGGB9cBawd6A tySequence__lo3S1lKyiPLhGGB9cBawd6A;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA;
typedef struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__PsEhl3dzznmmJiLAuIXZOg tyTuple__PsEhl3dzznmmJiLAuIXZOg;
typedef struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w;
typedef struct tyTuple__Db8CrQifKGIsKc3w71w7Lw tyTuple__Db8CrQifKGIsKc3w71w7Lw;
typedef struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg;
typedef struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ;
typedef struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw tyTuple__FEYH9alRJhHD0uTKF2vnIqw;
typedef struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA;
typedef struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA;
typedef struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw;
typedef struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg tyTuple__VUJ5Hjm4tKAResBsRHJvYg;
struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA {
tySequence__ijtae5OneaLys0hN9alAicA* data;
NI counter;
};
struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w {
tySequence__SerjNoUujW2dUouVBrJiCw* data;
NI counter;
};
struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA {
tySequence__K9agbtcb0qPZuSJFXB9cTe6g* data;
NI counter;
};
typedef tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyArray__46hjIasL27aUz9c7kgtWooQ[5];
struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg {
tySequence__m88qdML9cQOuqGAQn6XWL1A* data;
NI counter;
};
struct tyObject_Table__1hIWbTQWYT4BmhdESze57A {
tySequence__naEbXEp9b9aiW1zXJorqf9cXQ* data;
NI counter;
};
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
};
struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw {
NI counter;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* data;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__imojfg883tkWsWJwyshGqQ {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA {
tySequence__KgiZ29chkJAD01p9aLRB32qw* data;
NI counter;
};
struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A {
tySequence__rkYRZrbHVYL3nhXlQW3K9bw* data;
NI counter;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg[65];
struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ {
tySequence__YmPd0eWfcTfrVYrthlXPYA* data;
NI counter;
};
struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__I6rzVhdiYtUh7jwWJQoeyw) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__EQOAUyRkp9c3eeiGlHvCThA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q {
tySequence__Hz5SYwQU29b9aFLt09blvVQPg* data;
NI counter;
};
struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg {
tySequence__3G9aA9cLXaPxuRxMKm3anacQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__1CO5eEh25fBKUWGagpikwg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
typedef N_NIMCALL_PTR(void, tyProc__VcUg5jOhttLagdxUmVN8Tg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__XOkru1xuh2bHzmkw1UYzLA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formal, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* actual);
struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opNot;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opContains;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLe;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLt;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAnd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opOr;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opIsNil;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opEq;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAdd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opSub;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opMul;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opDiv;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg {
tySequence__RNhZxf20g9beyq5VBOGxhDg* ifaces;
tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* packed_0;
tySequence__lFbCtu5P2Kf7YDYtGjkxAQ* encoders;
tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA typeInstCache;
tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w procInstCache;
tyArray__46hjIasL27aUz9c7kgtWooQ attachedOps;
tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg methodsPerType;
tyObject_Table__1hIWbTQWYT4BmhdESze57A enumToStringProcs;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw emittedTypeInfo;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA startupPackedConfig;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw deps;
tyObject_Table__imojfg883tkWsWJwyshGqQ importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__BCPh85PHtwxox9bv7NLFrlg inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* usageSym;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* owners;
tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA suggestSymbols;
tyObject_Table__LM44poVdVEn4Mo4N4L8c3A suggestErrors;
tySequence__IRFEb1e9bxgbJLuB5xrdZsQ* methods;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* systemModule;
tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg sysTypes;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw compilerprocs;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw exposed;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageTypes;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* emptyNode;
tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ canonTypes;
tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw symBodyHashes;
tyProc__I6rzVhdiYtUh7jwWJQoeyw importModuleCallback;
tyProc__EQOAUyRkp9c3eeiGlHvCThA includeFileCallback;
tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q cacheSeqs;
tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g cacheCounters;
tyObject_Table__R7JnJQEipxxOlJWXQz7jWg cacheTables;
tySequence__bPFv6ypvvCX2A9a9al8utL2Q* passes;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinition;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinitionResolveForward;
tyProc__1CO5eEh25fBKUWGagpikwg onUsage;
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* globalDestructors;
tyProc__VcUg5jOhttLagdxUmVN8Tg strongSemCheck;
tyProc__XOkru1xuh2bHzmkw1UYzLA compatibleProps;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg operators;
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* converters;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* patterns;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* pureEnums;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interf;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interfHidden;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* uniqueName;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ {
NU32 module;
NI32 item;
};
struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg {
NI module;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ packed_0;
};
struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
};
struct TGenericSeq {
NI len;
NI reserved;
};
struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ {
tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* data;
NI counter;
};
struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ {
NI32 thisModule;
NI32 lastFile;
NU32 lastLit;
tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ filenames;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* pendingTypes;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* pendingSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw typeMarker;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw symMarker;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
};
struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__dlD6tEGzYLLpKVq3XwuFlA* Field2;
};
struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q {
NI module;
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg sym;
tySequence__UnGSk9aaLosDroi2QDrlOfQ* concreteTypes;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__rZZA0skon1OsHdiEvT8RZQ {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__6OFCSvqRaxyEgUqWtnZSlw* Field2;
};
struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field2;
};
struct tyTuple__RWXAsQlFoGYyEQZp1G65sg {
NI Field0;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field1;
};
struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__m4PVWjcAAjfxlwJxLkKn8A* Field2;
};
struct tyTuple__RmGJuqOgEaHckHndh0LEsw {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field2;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyTuple__JfHvHzMrhKkWAUvQKe0i1A {
void* Field0;
tyObject_Env_modulegraphsdotnim_ModuleGraph___diB2NTuAIWY0FO9c5IUJRGg* Field1;
};
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
};
struct tyTuple__J4cxakKjhKxTIJR9bojMmXw {
NI Field0;
NI32 Field1;
tySequence__i89c5kdtWKzK3OEiI81pkkw* Field2;
};
struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ {
NI Field0;
NI32 Field1;
tySequence__GR8qmV1kNRcoQ2g76VFy3A* Field2;
};
struct tyTuple__a7QginWFapakKbWJBJ2vfA {
tySequence__ed0C0uAUZPhvw3RAc5hfYg* Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyTuple__kbX6x85REySUrk9auORL0vw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q {
tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A* root;
NI entries;
};
struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q Field2;
};
typedef NimStringDesc* tyArray__9aijZrM1syqzleJpcL8bUyw[512];
typedef tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* tyArray__pWfcjNgdkCPhsQuXtCrjlQ[512];
typedef tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A* tyArray__VKNNDtxlcHt69avZNvnPyiQ[512];
struct tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A {
NI entries;
tyArray__9aijZrM1syqzleJpcL8bUyw keys;
NIM_BOOL isInternal;
union{
struct {tyArray__pWfcjNgdkCPhsQuXtCrjlQ vals;
} _isInternal_1;
struct {tyArray__VKNNDtxlcHt69avZNvnPyiQ links;
} _isInternal_2;
};
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, tyProc__kqPx9c4py2HW6KcFMhNvxtg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__9c6qRjwy7Es8UkDTIUwAfFA) (tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__mv4BsRs5VEnhcxzV6pQU5w) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
struct tyTuple__nF9cH4hinXgGEUwO4G2bshw {
tyProc__kqPx9c4py2HW6KcFMhNvxtg Field0;
tyProc__9c6qRjwy7Es8UkDTIUwAfFA Field1;
tyProc__mv4BsRs5VEnhcxzV6pQU5w Field2;
NIM_BOOL Field3;
};
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
typedef tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* tyArray__1iN2CWX9bK5w9bRjT9chFAABA[8192];
struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ {
tyArray__1iN2CWX9bK5w9bRjT9chFAABA buckets;
NI wordCounter;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* idAnon;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* idDelegator;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* emptyIdent;
};
struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg {
NI32 module;
NI32 symId;
NI32 typeId_0;
NIM_BOOL sealed;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
typedef NU8 tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg;
struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg {
tySequence__4Murtwnm0Fyc7F9acrytEXw* nodes;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ;
struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ {
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw {
tySequence__IHUFRsFxZNv7YydiUO2esQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag {
NimStringDesc* definedSymbols;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA moduleFlags;
tySequence__PXIzfWocnrafGz5p3CP5LA* includes;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* imports;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg toReplay;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg topLevel;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg bodies;
tySequence__b89aLriiJnVTD186H6zNIgg* exports;
tySequence__b89aLriiJnVTD186H6zNIgg* hidden;
tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw* reexports;
tySequence__b89aLriiJnVTD186H6zNIgg* compilerProcs;
tySequence__48JTohSgTy339bRxHzUD8KA* converters;
tySequence__48JTohSgTy339bRxHzUD8KA* methods;
tySequence__48JTohSgTy339bRxHzUD8KA* trmacros;
tySequence__48JTohSgTy339bRxHzUD8KA* pureEnums;
tySequence__QnmOtn1Iv4LvxOXoMn8Rbg* macroUsages;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* typeInstCache;
tySequence__qy6Iwdy00wN560qud54HTg* procInstCache;
tySequence__k67v9bwvvQDmS1ynyGGUbeQ* attachedOps;
tySequence__cLsClAAfd0MKkoBQVyvdvw* methodsPerType;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* enumToStringProcs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* emittedTypeInfo;
tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ backendFlags;
tySequence__q9bTuOB0JXh1iZ3CSGdRLbg* syms;
tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw* types;
tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ strings;
tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw numbers;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA cfg;
};
struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ {
tySequence__C3r8jsj9chA4sIlYfDN5aDw* data;
NI counter;
};
struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg {
tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg status;
NIM_BOOL symsInit;
NIM_BOOL typesInit;
NIM_BOOL loadedButAliveSetChanged;
tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag fromDisk;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* syms;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* types;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ iface;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ ifaceHidden;
};
typedef NU8 tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA;
struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg {
NI id;
NimStringDesc* s;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* next;
NI h;
};
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NimStringDesc* tyArray__haiLFy0nBviVTKFGuwztzQ[5];
typedef NU8 tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU8 tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ;
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInst;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg uniqueId;
};
typedef NU8 tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw {
  RootObj Sup;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
};
struct tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g {
NI h;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
};
struct tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ {
NI lastModule;
NU32 lastLit;
NI32 lastFile;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
};
struct tyObject_RodIter__L6nv9cakjPARHk068AFo6ww {
tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ decoder;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* values;
NI i;
NI module;
};
struct tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A {
NIM_BOOL fromRod;
NI modIndex;
tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g ti;
tyObject_RodIter__L6nv9cakjPARHk068AFo6ww rodIt;
NIM_BOOL importHidden;
};
typedef NimStringDesc* tyArray__TLUjAhnMfzBtYkb49czB0KA[64];
struct tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* concreteTypes;
NI compilesId;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
NI Field0;
NI32 Field1;
NU32 Field2;
};
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
NU32 Field0;
NimStringDesc* Field1;
};
struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA {
NU16 line;
NI16 col;
NU32 file;
};
struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA {
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
NI32 operand;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeId_0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
};
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
NU32 Field0;
NI32 Field1;
};
struct tyTuple__PsEhl3dzznmmJiLAuIXZOg {
NU32 Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA Field1;
};
struct tyTuple__Db8CrQifKGIsKc3w71w7Lw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ key;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* concreteTypes;
};
struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ {
tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
NI Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
typedef NU8 tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ;
struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA {
tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
NU32 name;
NI32 path;
};
struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA {
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
NU32 name;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typ;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
NI32 ast;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ guard;
NI bitsize;
NI alignment;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
NU32 externalName;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw locFlags;
tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA annex;
NI32 constraint;
};
struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw {
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* types;
NI32 n;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeInst;
NI32 nonUniqueId;
};
struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg {
NI Field0;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* Field1;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* Field2;
};
struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g {
  TGenericSeq Sup;
  tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg data[SEQ_DECL_SIZE];
};
struct tySequence__RNhZxf20g9beyq5VBOGxhDg {
  TGenericSeq Sup;
  tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ data[SEQ_DECL_SIZE];
};
struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ {
  TGenericSeq Sup;
  tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ data[SEQ_DECL_SIZE];
};
struct tySequence__dlD6tEGzYLLpKVq3XwuFlA {
  TGenericSeq Sup;
  tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ data[SEQ_DECL_SIZE];
};
struct tySequence__ijtae5OneaLys0hN9alAicA {
  TGenericSeq Sup;
  tyTuple__UluY8x0Nj6cp9b0o88wJ0lg data[SEQ_DECL_SIZE];
};
struct tySequence__6OFCSvqRaxyEgUqWtnZSlw {
  TGenericSeq Sup;
  tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q data[SEQ_DECL_SIZE];
};
struct tySequence__UnGSk9aaLosDroi2QDrlOfQ {
  TGenericSeq Sup;
  tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg data[SEQ_DECL_SIZE];
};
struct tySequence__SerjNoUujW2dUouVBrJiCw {
  TGenericSeq Sup;
  tyTuple__rZZA0skon1OsHdiEvT8RZQ data[SEQ_DECL_SIZE];
};
struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g {
  TGenericSeq Sup;
  tyTuple__q13Zt16VkCqu6Zg5jWqwHA data[SEQ_DECL_SIZE];
};
struct tySequence__m4PVWjcAAjfxlwJxLkKn8A {
  TGenericSeq Sup;
  tyTuple__RWXAsQlFoGYyEQZp1G65sg data[SEQ_DECL_SIZE];
};
struct tySequence__m88qdML9cQOuqGAQn6XWL1A {
  TGenericSeq Sup;
  tyTuple__aWN9bNzF9bubXNJV9ciomgpfA data[SEQ_DECL_SIZE];
};
struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ {
  TGenericSeq Sup;
  tyTuple__RmGJuqOgEaHckHndh0LEsw data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__i89c5kdtWKzK3OEiI81pkkw {
  TGenericSeq Sup;
  tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A data[SEQ_DECL_SIZE];
};
struct tySequence__KgiZ29chkJAD01p9aLRB32qw {
  TGenericSeq Sup;
  tyTuple__J4cxakKjhKxTIJR9bojMmXw data[SEQ_DECL_SIZE];
};
struct tySequence__GR8qmV1kNRcoQ2g76VFy3A {
  TGenericSeq Sup;
  tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* data[SEQ_DECL_SIZE];
};
struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw {
  TGenericSeq Sup;
  tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ data[SEQ_DECL_SIZE];
};
struct tySequence__ed0C0uAUZPhvw3RAc5hfYg {
  TGenericSeq Sup;
  tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* data[SEQ_DECL_SIZE];
};
struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ {
  TGenericSeq Sup;
  tyTuple__a7QginWFapakKbWJBJ2vfA data[SEQ_DECL_SIZE];
};
struct tySequence__YmPd0eWfcTfrVYrthlXPYA {
  TGenericSeq Sup;
  tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg {
  TGenericSeq Sup;
  tyTuple__kbX6x85REySUrk9auORL0vw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ {
  TGenericSeq Sup;
  tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g data[SEQ_DECL_SIZE];
};
struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q {
  TGenericSeq Sup;
  tyTuple__nF9cH4hinXgGEUwO4G2bshw data[SEQ_DECL_SIZE];
};
struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ {
  TGenericSeq Sup;
  tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  TGenericSeq Sup;
  tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE];
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  TGenericSeq Sup;
  tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE];
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  TGenericSeq Sup;
  NU32 data[SEQ_DECL_SIZE];
};
struct tySequence__4Murtwnm0Fyc7F9acrytEXw {
  TGenericSeq Sup;
  tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA data[SEQ_DECL_SIZE];
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  TGenericSeq Sup;
  tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE];
};
struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw {
  TGenericSeq Sup;
  tyTuple__PsEhl3dzznmmJiLAuIXZOg data[SEQ_DECL_SIZE];
};
struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg {
  TGenericSeq Sup;
  tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w data[SEQ_DECL_SIZE];
};
struct tySequence__oKtVqsc9bQVCNyrijELM4OQ {
  TGenericSeq Sup;
  tyTuple__Db8CrQifKGIsKc3w71w7Lw data[SEQ_DECL_SIZE];
};
struct tySequence__qy6Iwdy00wN560qud54HTg {
  TGenericSeq Sup;
  tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg data[SEQ_DECL_SIZE];
};
struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ {
  TGenericSeq Sup;
  tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ data[SEQ_DECL_SIZE];
};
struct tySequence__cLsClAAfd0MKkoBQVyvdvw {
  TGenericSeq Sup;
  tyTuple__FEYH9alRJhHD0uTKF2vnIqw data[SEQ_DECL_SIZE];
};
struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg {
  TGenericSeq Sup;
  tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA data[SEQ_DECL_SIZE];
};
struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw {
  TGenericSeq Sup;
  tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw data[SEQ_DECL_SIZE];
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  TGenericSeq Sup;
  NI64 data[SEQ_DECL_SIZE];
};
struct tySequence__lo3S1lKyiPLhGGB9cBawd6A {
  TGenericSeq Sup;
  tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ data[SEQ_DECL_SIZE];
};
struct tySequence__C3r8jsj9chA4sIlYfDN5aDw {
  TGenericSeq Sup;
  tyTuple__VUJ5Hjm4tKAResBsRHJvYg data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__qeAsXh2i1GAL5Nl0g3OP8g)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__RNhZxf20g9beyq5VBOGxhDg)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__lFbCtu5P2Kf7YDYtGjkxAQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__dlD6tEGzYLLpKVq3XwuFlA)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__ijtae5OneaLys0hN9alAicA)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__UnGSk9aaLosDroi2QDrlOfQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__6OFCSvqRaxyEgUqWtnZSlw)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__SerjNoUujW2dUouVBrJiCw)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__K9agbtcb0qPZuSJFXB9cTe6g)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__m4PVWjcAAjfxlwJxLkKn8A)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__m88qdML9cQOuqGAQn6XWL1A)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__naEbXEp9b9aiW1zXJorqf9cXQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__fdmz6VkIf1ewwrssKYqRFg)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__kxu4GK0onha2t9bo86mdVAg)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__i89c5kdtWKzK3OEiI81pkkw)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__KgiZ29chkJAD01p9aLRB32qw)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__GR8qmV1kNRcoQ2g76VFy3A)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__rkYRZrbHVYL3nhXlQW3K9bw)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__IRFEb1e9bxgbJLuB5xrdZsQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__YmPd0eWfcTfrVYrthlXPYA)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__fIB1rTQ55aFonoft9a9bmljQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__Hz5SYwQU29b9aFLt09blvVQPg)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__squ9b9bUH4OLHf6cEMrt6hVA)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__PH6d39ctBFaDFBx75WzCZNQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__3G9aA9cLXaPxuRxMKm3anacQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__bPFv6ypvvCX2A9a9al8utL2Q)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__AcDjMYSN0KX1UsX3HvPu2w)(void* p, NI op);
N_LIB_PRIVATE N_NOINLINE(void*, newObj)(TNimType* typ, NI size);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5310)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5272)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5317)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5315)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5266)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(void, initModuleGraphFields__modulegraphs_9130)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* result);
N_LIB_PRIVATE N_NIMCALL(void, initStrTable__ast_4076)(tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* x);
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(void, initPackedSet__pureZcollectionsZintsets_16)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(void, initTable__modulegraphs_9132)(NI initialSize, tyObject_Table__imojfg883tkWsWJwyshGqQ* Result);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
N_LIB_PRIVATE N_NIMCALL(void, initTable__modulegraphs_9160)(NI initialSize, tyObject_Table__BCPh85PHtwxox9bv7NLFrlg* Result);
N_LIB_PRIVATE N_NIMCALL(void, initTable__modulegraphs_9184)(NI initialSize, tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA* Result);
N_LIB_PRIVATE N_NIMCALL(void, initTable__modulegraphs_9204)(NI initialSize, tyObject_Table__LM44poVdVEn4Mo4N4L8c3A* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNode__ast_3289)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind);
N_LIB_PRIVATE N_NIMCALL(void, initTable__modulegraphs_9228)(NI initialSize, tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q* Result);
N_LIB_PRIVATE N_NIMCALL(void, initTable__modulegraphs_9248)(NI initialSize, tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g* Result);
N_LIB_PRIVATE N_NIMCALL(void, initTable__modulegraphs_9270)(NI initialSize, tyObject_Table__R7JnJQEipxxOlJWXQz7jWg* Result);
N_LIB_PRIVATE N_NIMCALL(void, initTable__modulegraphs_9290)(NI initialSize, tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ* Result);
N_LIB_PRIVATE N_NIMCALL(void, initTable__modulegraphs_9310)(NI initialSize, tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw* Result);
N_LIB_PRIVATE N_NIMCALL(void, initOperators__modulegraphs_9127)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg* Result);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, createMagic__modulegraphs_9052)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NimStringDesc* name, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag m);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, createMagic__modulegraphs_9046)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, NimStringDesc* name, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag m);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, newSym__ast_3409)(tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw symKind, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg id, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*, getIdent__idents_152)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* ic, NimStringDesc* identifier);
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextSymId__ast_3103)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void, initTable__lineinfos_327)(NI initialSize, tyObject_Table__9cHFtxtpgztIcDsypRz9byKw* Result);
N_LIB_PRIVATE N_NIMCALL(void, incl__pureZcollectionsZintsets_55)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
static N_INLINE(NI, dependsOn__modulegraphs_9593)(NI a, NI b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKeyOrPut__modulegraphs_9642)(tyObject_Table__BCPh85PHtwxox9bv7NLFrlg* t, NI32 key, NI32 val);
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_2710)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI module);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, moduleFromRodFile__icZic_8330)(tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, NI32 fileIdx, tySequence__48JTohSgTy339bRxHzUD8KA** cachedModules);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getPackage__packages_7)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, strTableGet__astalgo_3383)(tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw t, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name);
N_LIB_PRIVATE N_NIMCALL(void, strTableAdd__astalgo_3325)(tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* t, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* n);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, rope__ropes_109)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, uniqueModuleName__msgs_1521)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fid);
N_LIB_PRIVATE N_NIMCALL(void, genericShallowAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(void, initStrTables__modulegraphs_2703)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefined__options_2292)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* symbol);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFilenameOption__msgs_600)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx, tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w opt);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuRepeatStr)(NimStringDesc* s, NI n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(NI, getPackageId__packages_41)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getPackageSymbol__packages_17)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(void, saveRodFile__icZic_4386)(NimStringDesc* filename, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* encoder, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toRodFile__icZic_3146)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* f, NimStringDesc* ext);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPath__msgs_548)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(void, simulateCachedModule__modulegraphs_2726)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* moduleSym, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m);
N_LIB_PRIVATE N_NIMCALL(void, simulateLoadedModule__icZic_8467)(tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* moduleSym, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m);
N_LIB_PRIVATE N_NIMCALL(void, registerModule__modulegraphs_9057)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, someSym__modulegraphs_2849)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name);
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_2722)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, interfaceSymbol__icZic_9091)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI32 module, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name, NIM_BOOL importHidden);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getAttachedOp__modulegraphs_4049)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ op);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getOrDefault__modulegraphs_4132)(tyObject_Table__r0v8BdcBPKhl73K8p2VMUA t, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg key);
N_LIB_PRIVATE N_NIMCALL(void, setAttachedOp__modulegraphs_4445)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI module, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ op, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* value);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___modulegraphs_4491)(tyObject_Table__r0v8BdcBPKhl73K8p2VMUA* t, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg key, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* val);
N_LIB_PRIVATE N_NIMCALL(void, transitiveClosure__modulegraphs_11100)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* g, NI n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__astalgo_3489)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getModule__modulegraphs_9522)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDirty__modulegraphs_12920)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m);
N_LIB_PRIVATE N_NIMCALL(void, markDirty__modulegraphs_11296)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(void, del__modulegraphs_11344)(tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA* t, NI32 key);
N_LIB_PRIVATE N_NIMCALL(void, del__modulegraphs_12143)(tyObject_Table__LM44poVdVEn4Mo4N4L8c3A* t, NI32 key);
N_LIB_PRIVATE N_NIMCALL(void, markClientsDirty__modulegraphs_12928)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(void, initEncoder__icZic_2270)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* moduleSym, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA pc);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, loadTypeFromId__icZic_8398)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI module, tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ id);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, loadSymFromId__icZic_8413)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI module, tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ id);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, initRodIter__icZic_8497)(tyObject_RodIter__L6nv9cakjPARHk068AFo6ww* it, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI32 module, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name, NIM_BOOL importHidden);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, initIdentIter__astalgo_3420)(tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g* ti, tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tab, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, nextRodIter__icZic_8980)(tyObject_RodIter__L6nv9cakjPARHk068AFo6ww* it, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, nextIdentIter__astalgo_3401)(tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g* ti, tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tab);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toBase64a__modulegraphs_2616)(NCSTRING s, NI len);
N_NIMCALL(NimStringDesc*, rawNewString)(NI cap);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(NI32, searchForCompilerproc__icZic_9189)(tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg* m, NimStringDesc* name);
static N_INLINE(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ, toPackedItemId__icZpacked95ast_611)(NI32 item);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(void, toPackedGeneratedProcDef__icZic_3063)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* encoder, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m);
N_LIB_PRIVATE N_NIMCALL(tySequence__vKogasEnJSPhbQmA8r4Y9aA*, newSeq__modulegraphs_2931)(NI len);
N_LIB_PRIVATE N_NIMCALL(tySequence__m4PVWjcAAjfxlwJxLkKn8A**, mgetOrPut__modulegraphs_7763)(tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg* t, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg key, tySequence__m4PVWjcAAjfxlwJxLkKn8A* val);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___modulegraphs_6117)(tyObject_Table__1hIWbTQWYT4BmhdESze57A* t, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg key, tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg val);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, resolveSym__modulegraphs_2904)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg*, X5BX5D___modulegraphs_5743)(tyObject_Table__1hIWbTQWYT4BmhdESze57A* t, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg key);
N_LIB_PRIVATE N_NIMCALL(void, rememberStartupConfig__icZic_507)(tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA* dest, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config);
N_LIB_PRIVATE N_NIMCALL(void, clear__modulegraphs_320)(tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA* t);
N_LIB_PRIVATE N_NIMCALL(void, clear__modulegraphs_766)(tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w* t);
N_LIB_PRIVATE N_NIMCALL(void, clear__modulegraphs_1302)(tyObject_Table__r0v8BdcBPKhl73K8p2VMUA* t);
N_LIB_PRIVATE N_NIMCALL(void, clear__modulegraphs_1738)(tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg* t);
N_LIB_PRIVATE N_NIMCALL(void, clear__modulegraphs_2183)(tyObject_Table__1hIWbTQWYT4BmhdESze57A* t);
N_LIB_PRIVATE TNimType NTImodulegraph58objecttype__nOSrcYqJTxXt2ptNc0gnWg_;
N_LIB_PRIVATE TNimType NTIiface__4y9aWdJBxraQYTl5Pa1NMuQ_;
extern TNimType NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_;
N_LIB_PRIVATE TNimType NTIlazysym__Xts9a2Mw4b4jtq73p6MrfJg_;
N_LIB_PRIVATE TNimType NTIfullid__L64puUgQnoQ6OMvT9c6V9cPg_;
extern TNimType NTIint__rR5Bzr1D5krxoo1NcNyeMA_;
extern TNimType NTIpackeditemid__QkYBSICiQaMI6SmH4FJVoQ_;
N_LIB_PRIVATE TNimType NTIseqLlazysymT__qeAsXh2i1GAL5Nl0g3OP8g_;
extern TNimType NTItstrtable__CJQ42V2zij8fd39a9aMiwtZw_;
extern TNimType NTIrope__Ylz2qJFHq2oxQcAA5BJOQg_;
N_LIB_PRIVATE TNimType NTIseqLifaceT__RNhZxf20g9beyq5VBOGxhDg_;
extern TNimType NTIpackedmodulegraph__JbK5aK9aVhc9cJZzQYg1wQlQ_;
extern TNimType NTIpackedencoder__ftUl9bxYRlbT5ToKkxHdbfQ_;
N_LIB_PRIVATE TNimType NTIseqLpackedencoderT__lFbCtu5P2Kf7YDYtGjkxAQ_;
N_LIB_PRIVATE TNimType NTItable__nODIJ5l6JnEl9a6LYuqISLA_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__UluY8x0Nj6cp9b0o88wJ0lg_;
extern TNimType NTIitemid__wg9aowaxscbUe2F0nV9btZLg_;
N_LIB_PRIVATE TNimType NTIlazytype__wgv9a1JCOBXm9azerxcvz5gQ_;
extern TNimType NTIptype__q1v0zzhoMWrhMLs6UEp1IA_;
N_LIB_PRIVATE TNimType NTIseqLlazytypeT__dlD6tEGzYLLpKVq3XwuFlA_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__ijtae5OneaLys0hN9alAicA_;
N_LIB_PRIVATE TNimType NTItable__s3itmS9cUUFQ19alF7UA0T1w_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__rZZA0skon1OsHdiEvT8RZQ_;
N_LIB_PRIVATE TNimType NTIlazyinstantiation__0l1i6PfjQKnMEvpGMAoN8Q_;
N_LIB_PRIVATE TNimType NTIseqLfullidT__UnGSk9aaLosDroi2QDrlOfQ_;
extern TNimType NTIpinstantiation__eg8se9cZBHdzb5ZM7CrYNVg_;
N_LIB_PRIVATE TNimType NTIseqLlazyinstantiationT__6OFCSvqRaxyEgUqWtnZSlw_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__SerjNoUujW2dUouVBrJiCw_;
N_LIB_PRIVATE TNimType NTItable__r0v8BdcBPKhl73K8p2VMUA_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__q13Zt16VkCqu6Zg5jWqwHA_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__K9agbtcb0qPZuSJFXB9cTe6g_;
N_LIB_PRIVATE TNimType NTIarrayLttypeattachedop_tableLastOitemid_astOpsymTT__46hjIasL27aUz9c7kgtWooQ_;
N_LIB_PRIVATE TNimType NTItable__KsPP7K7LW9aa3YAq1XN9cDZg_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__aWN9bNzF9bubXNJV9ciomgpfA_;
N_LIB_PRIVATE TNimType NTILint_lazysymT__RWXAsQlFoGYyEQZp1G65sg_;
N_LIB_PRIVATE TNimType NTIseqLLint_lazysymTT__m4PVWjcAAjfxlwJxLkKn8A_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__m88qdML9cQOuqGAQn6XWL1A_;
N_LIB_PRIVATE TNimType NTItable__1hIWbTQWYT4BmhdESze57A_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__RmGJuqOgEaHckHndh0LEsw_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__naEbXEp9b9aiW1zXJorqf9cXQ_;
extern TNimType NTItable__9cHFtxtpgztIcDsypRz9byKw_;
extern TNimType NTIpackedconfig__aqQhF9bElTH51s7bVamv3vA_;
extern TNimType NTIpackedset__THXDbzJSs2hcC9a33en2pdw_;
N_LIB_PRIVATE TNimType NTItable__imojfg883tkWsWJwyshGqQ_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__1mtQ8sCEE7DbfIuQciv9b5Q_;
extern TNimType NTIint5150__sVg18TP9cLifHyygRe9cro9aA_;
extern TNimType NTIseqLint5150T__48JTohSgTy339bRxHzUD8KA_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__fdmz6VkIf1ewwrssKYqRFg_;
extern TNimType NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_;
N_LIB_PRIVATE TNimType NTItable__BCPh85PHtwxox9bv7NLFrlg_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__xDU9bZmv1ZbZkJDaATBekIQ_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__kxu4GK0onha2t9bo86mdVAg_;
extern TNimType NTIrootref__0vJvi4uHbxjbxlkkX7P1EA_;
extern TNimType NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_;
extern TNimType NTIidentcache__6ZZ9cf5acLVYxUxl0ehlA1g_;
N_LIB_PRIVATE TNimType NTIprocLT58boolLOclosureOT__In3g79a0qTcRmbTbJp9ba9ctg_;
extern TNimType NTIpointer__vr5DoT1jILTGdRlYv1OYpw_;
extern TNimType NTIrefobject__HsJiUUcO9cHBdUCi0HwkSTA_;
extern TNimType NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_;
N_LIB_PRIVATE TNimType NTItable__mLYbj79bHyPPDPv4GGJx9bqA_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__J4cxakKjhKxTIJR9bojMmXw_;
N_LIB_PRIVATE TNimType NTIsyminfopair__SjZT5Rln3r9befMWWSryQ0A_;
extern TNimType NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_;
N_LIB_PRIVATE TNimType NTIseqLsyminfopairT__i89c5kdtWKzK3OEiI81pkkw_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__KgiZ29chkJAD01p9aLRB32qw_;
N_LIB_PRIVATE TNimType NTItable__LM44poVdVEn4Mo4N4L8c3A_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__VwWg1orPZ9b5Rg9aZAI6SIaQ_;
extern TNimType NTIsuggest__vIaEYib9am0Aa2d8J2uMYdQ_;
N_LIB_PRIVATE TNimType NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__rkYRZrbHVYL3nhXlQW3K9bw_;
N_LIB_PRIVATE TNimType NTItupleLmethods58seqLpsymT_dispatcher58psymT__a7QginWFapakKbWJBJ2vfA_;
N_LIB_PRIVATE TNimType NTIseqLtupleLmethods58seqLpsymT_dispatcher58psymTT__IRFEb1e9bxgbJLuB5xrdZsQ_;
N_LIB_PRIVATE TNimType NTIarrayLttypekind_ptypeT__9atk2qEPO7ASGmt9cDlOE9b9cg_;
extern TNimType NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_;
N_LIB_PRIVATE TNimType NTItable__sEMwnZ9aATDhH19cNIt9bn9cyQ_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__mPT6B9cVWqwVnWb1Fxx9bgyA_;
extern TNimType NTImd53digest__qtqsWM5aXmcpMIVmvq3kAA_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__YmPd0eWfcTfrVYrthlXPYA_;
N_LIB_PRIVATE TNimType NTItable__WtPprFMQ6tkKi9bQSH3IVpw_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__OJFzEczluV8Jmo9bRpBfkzw_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__fIB1rTQ55aFonoft9a9bmljQ_;
N_LIB_PRIVATE TNimType NTIprocLgraph58modulegraph_m58psym_fileidx58fileindexT58psymLOnimcallOT__I6rzVhdiYtUh7jwWJQoeyw_;
N_LIB_PRIVATE TNimType NTIprocLgraph58modulegraph_m58psym_fileidx58fileindexT58pnodeLOnimcallOT__EQOAUyRkp9c3eeiGlHvCThA_;
N_LIB_PRIVATE TNimType NTItable__9cOd7jTOg5Zc4i0IfnGho1Q_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__kbX6x85REySUrk9auORL0vw_;
extern TNimType NTIstring__77mFvmsOLKik79ci2hXkHEg_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__Hz5SYwQU29b9aFLt09blvVQPg_;
N_LIB_PRIVATE TNimType NTItable__YnoEqrDMrd9cI9bBg8gj5H3g_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__F3gkSrMB1qp2Tvf9bixVXwg_;
extern TNimType NTIbiggestint__Aav8dQoMlCFnZRxA0IhTHQ_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__squ9b9bUH4OLHf6cEMrt6hVA_;
N_LIB_PRIVATE TNimType NTItable__R7JnJQEipxxOlJWXQz7jWg_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__Ah6ua9a8WyUOs9aO9afW59cy0g_;
N_LIB_PRIVATE TNimType NTIbtree__R2EgvhuH9cLMYvSPesdcu5Q_;
N_LIB_PRIVATE TNimType NTInode58objecttype__NOM0ZpqV9bLtofkCilAnZ8A_;
N_LIB_PRIVATE TNimType NTIarrayL48OO534949_stringT__9aijZrM1syqzleJpcL8bUyw_;
TNimNode* NimDT___NOM0ZpqV9bLtofkCilAnZ8A_isInternal[3];
N_LIB_PRIVATE TNimType NTIarrayL48OO534949_pnodeT__pWfcjNgdkCPhsQuXtCrjlQ_;
N_LIB_PRIVATE TNimType NTIarrayL48OO534949_nodeLsystemOstring_astOpnodeTT__VKNNDtxlcHt69avZNvnPyiQ_;
N_LIB_PRIVATE TNimType NTInode__PH6d39ctBFaDFBx75WzCZNQ_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__3G9aA9cLXaPxuRxMKm3anacQ_;
N_LIB_PRIVATE TNimType NTItpass__nF9cH4hinXgGEUwO4G2bshw_;
N_LIB_PRIVATE TNimType NTItpassopen__kqPx9c4py2HW6KcFMhNvxtg_;
N_LIB_PRIVATE TNimType NTItpassprocess__9c6qRjwy7Es8UkDTIUwAfFA_;
N_LIB_PRIVATE TNimType NTItpassclose__mv4BsRs5VEnhcxzV6pQU5w_;
N_LIB_PRIVATE TNimType NTIseqLtpassT__bPFv6ypvvCX2A9a9al8utL2Q_;
N_LIB_PRIVATE TNimType NTIprocLgraph58modulegraph_s58psym_info58tlineinfoTLOnimcallOT__1CO5eEh25fBKUWGagpikwg_;
extern TNimType NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_;
N_LIB_PRIVATE TNimType NTIprocLgraph58modulegraph_owner58psym_body58pnodeTLOnimcallOT__VcUg5jOhttLagdxUmVN8Tg_;
N_LIB_PRIVATE TNimType NTIprocLgraph58modulegraph_formal58ptype_actual58ptypeT58boolLOnimcallOT__XOkru1xuh2bHzmkw1UYzLA_;
extern TNimType NTIidgenerator__M4gwBCp6eTol0yFD6lAxTQ_;
N_LIB_PRIVATE TNimType NTIoperators__dR4s9bCO53rZjV9a30JJfUOg_;
N_LIB_PRIVATE TNimType NTImodulegraph__AcDjMYSN0KX1UsX3HvPu2w_;
extern NIM_CONST tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw unknownLineInfo__lineinfos_284;
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_44, "<=", 2);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_45, "<", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_46, "and", 3);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_47, "or", 2);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_48, "isnil", 5);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_49, "==", 2);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_50, "+", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_51, "-", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_52, "*", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_53, "div", 3);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_54, "len", 3);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_55, "not", 3);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_56, "contains", 8);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_57, "nimscript", 9);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_58, ">", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_59, "(toplevel)", 10);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_60, "(nims) ", 7);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_61, "$#$# $#: $#: $#", 15);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_63, "/home/runner/work/nightlies/nightlies/nim/compiler/modulegraphs.nim", 67);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__mff0c158N4EFFNgrs4pcEQ_62 = {((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_63),
((NI) 627),
((NI) 14)}
;
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_64, "rod", 3);
extern TNimType NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_;
N_LIB_PRIVATE TNimType NTItpasscontext__dmp6pRpfXxJk6gIZHkm7dw_;
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_65, "__", 2);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_66, "A", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_67, "B", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_68, "C", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_69, "D", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_70, "E", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_71, "F", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_72, "G", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_73, "H", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_74, "I", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_75, "J", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_76, "K", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_77, "L", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_78, "M", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_79, "N", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_80, "O", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_81, "P", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_82, "Q", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_83, "R", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_84, "S", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_85, "T", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_86, "U", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_87, "V", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_88, "W", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_89, "X", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_90, "Y", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_91, "Z", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_92, "a", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_93, "b", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_94, "c", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_95, "d", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_96, "e", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_97, "f", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_98, "g", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_99, "h", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_100, "i", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_101, "j", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_102, "k", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_103, "l", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_104, "m", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_105, "n", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_106, "o", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_107, "p", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_108, "q", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_109, "r", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_110, "s", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_111, "t", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_112, "u", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_113, "v", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_114, "w", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_115, "x", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_116, "y", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_117, "z", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_118, "0", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_119, "1", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_120, "2", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_121, "3", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_122, "4", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_123, "5", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_124, "6", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_125, "7", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_126, "8", 1);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_127, "9a", 2);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_128, "9b", 2);
STRING_LITERAL(TM__mff0c158N4EFFNgrs4pcEQ_129, "9c", 2);
N_LIB_PRIVATE NIM_CONST tyArray__TLUjAhnMfzBtYkb49czB0KA cb64__modulegraphs_2606 = {((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_66),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_67),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_68),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_69),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_70),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_71),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_72),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_73),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_74),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_75),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_76),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_77),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_78),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_79),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_80),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_81),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_82),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_83),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_84),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_85),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_86),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_87),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_88),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_89),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_90),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_91),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_92),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_93),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_94),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_95),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_96),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_97),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_98),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_99),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_100),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_101),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_102),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_103),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_104),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_105),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_106),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_107),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_108),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_109),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_110),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_111),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_112),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_113),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_114),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_115),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_116),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_117),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_118),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_119),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_120),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_121),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_122),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_123),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_124),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_125),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_126),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_127),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_128),
((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_129)}
;
extern TNimType NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5219;
static N_NIMCALL(void, Marker_tySequence__qeAsXh2i1GAL5Nl0g3OP8g)(void* p, NI op) {
	tySequence__qeAsXh2i1GAL5Nl0g3OP8g* a;
	NI T1_;
	a = (tySequence__qeAsXh2i1GAL5Nl0g3OP8g*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].sym, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__RNhZxf20g9beyq5VBOGxhDg)(void* p, NI op) {
	tySequence__RNhZxf20g9beyq5VBOGxhDg* a;
	NI T1_;
	a = (tySequence__RNhZxf20g9beyq5VBOGxhDg*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].module, op);
	nimGCvisit((void*)a->data[T1_].converters, op);
	nimGCvisit((void*)a->data[T1_].patterns, op);
	nimGCvisit((void*)a->data[T1_].pureEnums, op);
	nimGCvisit((void*)a->data[T1_].interf.data, op);
	nimGCvisit((void*)a->data[T1_].interfHidden.data, op);
	nimGCvisit((void*)a->data[T1_].uniqueName, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__lFbCtu5P2Kf7YDYtGjkxAQ)(void* p, NI op) {
	tySequence__lFbCtu5P2Kf7YDYtGjkxAQ* a;
	NI T1_;
	NI T2_;
	NI T3_;
	a = (tySequence__lFbCtu5P2Kf7YDYtGjkxAQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].filenames.data, op);
	nimGCvisit((void*)a->data[T1_].pendingTypes, op);
	nimGCvisit((void*)a->data[T1_].pendingSyms, op);
	nimGCvisit((void*)a->data[T1_].typeMarker.head, op);
	nimGCvisit((void*)a->data[T1_].typeMarker.data, op);
	T2_ = (NI)0;
	nimGCvisit((void*)a->data[T1_].symMarker.head, op);
	nimGCvisit((void*)a->data[T1_].symMarker.data, op);
	T3_ = (NI)0;
	nimGCvisit((void*)a->data[T1_].config, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__dlD6tEGzYLLpKVq3XwuFlA)(void* p, NI op) {
	tySequence__dlD6tEGzYLLpKVq3XwuFlA* a;
	NI T1_;
	a = (tySequence__dlD6tEGzYLLpKVq3XwuFlA*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].typ, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__ijtae5OneaLys0hN9alAicA)(void* p, NI op) {
	tySequence__ijtae5OneaLys0hN9alAicA* a;
	NI T1_;
	a = (tySequence__ijtae5OneaLys0hN9alAicA*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field2, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__UnGSk9aaLosDroi2QDrlOfQ)(void* p, NI op) {
	tySequence__UnGSk9aaLosDroi2QDrlOfQ* a;
	NI T1_;
	a = (tySequence__UnGSk9aaLosDroi2QDrlOfQ*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__6OFCSvqRaxyEgUqWtnZSlw)(void* p, NI op) {
	tySequence__6OFCSvqRaxyEgUqWtnZSlw* a;
	NI T1_;
	a = (tySequence__6OFCSvqRaxyEgUqWtnZSlw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].concreteTypes, op);
	nimGCvisit((void*)a->data[T1_].inst, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__SerjNoUujW2dUouVBrJiCw)(void* p, NI op) {
	tySequence__SerjNoUujW2dUouVBrJiCw* a;
	NI T1_;
	a = (tySequence__SerjNoUujW2dUouVBrJiCw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field2, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__K9agbtcb0qPZuSJFXB9cTe6g)(void* p, NI op) {
	tySequence__K9agbtcb0qPZuSJFXB9cTe6g* a;
	NI T1_;
	a = (tySequence__K9agbtcb0qPZuSJFXB9cTe6g*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field2, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__m4PVWjcAAjfxlwJxLkKn8A)(void* p, NI op) {
	tySequence__m4PVWjcAAjfxlwJxLkKn8A* a;
	NI T1_;
	a = (tySequence__m4PVWjcAAjfxlwJxLkKn8A*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field1.sym, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__m88qdML9cQOuqGAQn6XWL1A)(void* p, NI op) {
	tySequence__m88qdML9cQOuqGAQn6XWL1A* a;
	NI T1_;
	a = (tySequence__m88qdML9cQOuqGAQn6XWL1A*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field2, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__naEbXEp9b9aiW1zXJorqf9cXQ)(void* p, NI op) {
	tySequence__naEbXEp9b9aiW1zXJorqf9cXQ* a;
	NI T1_;
	a = (tySequence__naEbXEp9b9aiW1zXJorqf9cXQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field2.sym, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__fdmz6VkIf1ewwrssKYqRFg)(void* p, NI op) {
	tySequence__fdmz6VkIf1ewwrssKYqRFg* a;
	NI T1_;
	a = (tySequence__fdmz6VkIf1ewwrssKYqRFg*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field2, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__kxu4GK0onha2t9bo86mdVAg)(void* p, NI op) {
	tySequence__kxu4GK0onha2t9bo86mdVAg* a;
	NI T1_;
	a = (tySequence__kxu4GK0onha2t9bo86mdVAg*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__i89c5kdtWKzK3OEiI81pkkw)(void* p, NI op) {
	tySequence__i89c5kdtWKzK3OEiI81pkkw* a;
	NI T1_;
	a = (tySequence__i89c5kdtWKzK3OEiI81pkkw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].sym, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__KgiZ29chkJAD01p9aLRB32qw)(void* p, NI op) {
	tySequence__KgiZ29chkJAD01p9aLRB32qw* a;
	NI T1_;
	a = (tySequence__KgiZ29chkJAD01p9aLRB32qw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field2, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__GR8qmV1kNRcoQ2g76VFy3A)(void* p, NI op) {
	tySequence__GR8qmV1kNRcoQ2g76VFy3A* a;
	NI T1_;
	a = (tySequence__GR8qmV1kNRcoQ2g76VFy3A*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_], op);
	}
}
static N_NIMCALL(void, Marker_tySequence__rkYRZrbHVYL3nhXlQW3K9bw)(void* p, NI op) {
	tySequence__rkYRZrbHVYL3nhXlQW3K9bw* a;
	NI T1_;
	a = (tySequence__rkYRZrbHVYL3nhXlQW3K9bw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field2, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__IRFEb1e9bxgbJLuB5xrdZsQ)(void* p, NI op) {
	tySequence__IRFEb1e9bxgbJLuB5xrdZsQ* a;
	NI T1_;
	a = (tySequence__IRFEb1e9bxgbJLuB5xrdZsQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field0, op);
	nimGCvisit((void*)a->data[T1_].Field1, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__YmPd0eWfcTfrVYrthlXPYA)(void* p, NI op) {
	tySequence__YmPd0eWfcTfrVYrthlXPYA* a;
	NI T1_;
	NI T2_;
	a = (tySequence__YmPd0eWfcTfrVYrthlXPYA*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	T2_ = (NI)0;
	nimGCvisit((void*)a->data[T1_].Field2, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__fIB1rTQ55aFonoft9a9bmljQ)(void* p, NI op) {
	tySequence__fIB1rTQ55aFonoft9a9bmljQ* a;
	NI T1_;
	NI T2_;
	a = (tySequence__fIB1rTQ55aFonoft9a9bmljQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	T2_ = (NI)0;
	}
}
static N_NIMCALL(void, Marker_tySequence__Hz5SYwQU29b9aFLt09blvVQPg)(void* p, NI op) {
	tySequence__Hz5SYwQU29b9aFLt09blvVQPg* a;
	NI T1_;
	a = (tySequence__Hz5SYwQU29b9aFLt09blvVQPg*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field1, op);
	nimGCvisit((void*)a->data[T1_].Field2, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__squ9b9bUH4OLHf6cEMrt6hVA)(void* p, NI op) {
	tySequence__squ9b9bUH4OLHf6cEMrt6hVA* a;
	NI T1_;
	a = (tySequence__squ9b9bUH4OLHf6cEMrt6hVA*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field1, op);
	}
}
static N_NIMCALL(void, Marker_tyRef__PH6d39ctBFaDFBx75WzCZNQ)(void* p, NI op) {
	tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A* a;
	NI T1_;
	NI T2_;
	NI T3_;
	a = (tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < 512; T1_++) {
	nimGCvisit((void*)(*a).keys[T1_], op);
	}
	switch ((*a).isInternal) {
	case NIM_FALSE:
	T2_ = (NI)0;
	for (T2_ = 0; T2_ < 512; T2_++) {
	nimGCvisit((void*)(*a)._isInternal_1.vals[T2_], op);
	}
	break;
	case NIM_TRUE:
	T3_ = (NI)0;
	for (T3_ = 0; T3_ < 512; T3_++) {
	nimGCvisit((void*)(*a)._isInternal_2.links[T3_], op);
	}
	break;
	} 
}
static N_NIMCALL(void, Marker_tySequence__3G9aA9cLXaPxuRxMKm3anacQ)(void* p, NI op) {
	tySequence__3G9aA9cLXaPxuRxMKm3anacQ* a;
	NI T1_;
	a = (tySequence__3G9aA9cLXaPxuRxMKm3anacQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field1, op);
	nimGCvisit((void*)a->data[T1_].Field2.root, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__bPFv6ypvvCX2A9a9al8utL2Q)(void* p, NI op) {
	tySequence__bPFv6ypvvCX2A9a9al8utL2Q* a;
	NI T1_;
	a = (tySequence__bPFv6ypvvCX2A9a9al8utL2Q*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tyRef__AcDjMYSN0KX1UsX3HvPu2w)(void* p, NI op) {
	tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* a;
	NI T1_;
	NI T2_;
	NI T3_;
	a = (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg*)p;
	nimGCvisit((void*)(*a).ifaces, op);
	nimGCvisit((void*)(*a).packed_0, op);
	nimGCvisit((void*)(*a).encoders, op);
	nimGCvisit((void*)(*a).typeInstCache.data, op);
	nimGCvisit((void*)(*a).procInstCache.data, op);
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < 5; T1_++) {
	nimGCvisit((void*)(*a).attachedOps[T1_].data, op);
	}
	nimGCvisit((void*)(*a).methodsPerType.data, op);
	nimGCvisit((void*)(*a).enumToStringProcs.data, op);
	nimGCvisit((void*)(*a).emittedTypeInfo.data, op);
	nimGCvisit((void*)(*a).packageSyms.data, op);
	nimGCvisit((void*)(*a).deps.head, op);
	nimGCvisit((void*)(*a).deps.data, op);
	T2_ = (NI)0;
	nimGCvisit((void*)(*a).importDeps.data, op);
	nimGCvisit((void*)(*a).inclToMod.data, op);
	nimGCvisit((void*)(*a).importStack, op);
	nimGCvisit((void*)(*a).backend, op);
	nimGCvisit((void*)(*a).config, op);
	nimGCvisit((void*)(*a).cache, op);
	nimGCvisit((void*)(*a).vm, op);
	nimGCvisit((void*)(*a).doStopCompile.ClE_0, op);
	nimGCvisit((void*)(*a).usageSym, op);
	nimGCvisit((void*)(*a).owners, op);
	nimGCvisit((void*)(*a).suggestSymbols.data, op);
	nimGCvisit((void*)(*a).suggestErrors.data, op);
	nimGCvisit((void*)(*a).methods, op);
	nimGCvisit((void*)(*a).systemModule, op);
	T3_ = (NI)0;
	for (T3_ = 0; T3_ < 65; T3_++) {
	nimGCvisit((void*)(*a).sysTypes[T3_], op);
	}
	nimGCvisit((void*)(*a).compilerprocs.data, op);
	nimGCvisit((void*)(*a).exposed.data, op);
	nimGCvisit((void*)(*a).packageTypes.data, op);
	nimGCvisit((void*)(*a).emptyNode, op);
	nimGCvisit((void*)(*a).canonTypes.data, op);
	nimGCvisit((void*)(*a).symBodyHashes.data, op);
	nimGCvisit((void*)(*a).cacheSeqs.data, op);
	nimGCvisit((void*)(*a).cacheCounters.data, op);
	nimGCvisit((void*)(*a).cacheTables.data, op);
	nimGCvisit((void*)(*a).passes, op);
	nimGCvisit((void*)(*a).globalDestructors, op);
	nimGCvisit((void*)(*a).idgen, op);
	nimGCvisit((void*)(*a).operators.opNot, op);
	nimGCvisit((void*)(*a).operators.opContains, op);
	nimGCvisit((void*)(*a).operators.opLe, op);
	nimGCvisit((void*)(*a).operators.opLt, op);
	nimGCvisit((void*)(*a).operators.opAnd, op);
	nimGCvisit((void*)(*a).operators.opOr, op);
	nimGCvisit((void*)(*a).operators.opIsNil, op);
	nimGCvisit((void*)(*a).operators.opEq, op);
	nimGCvisit((void*)(*a).operators.opAdd, op);
	nimGCvisit((void*)(*a).operators.opSub, op);
	nimGCvisit((void*)(*a).operators.opMul, op);
	nimGCvisit((void*)(*a).operators.opDiv, op);
	nimGCvisit((void*)(*a).operators.opLen, op);
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5310)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5272)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5315)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5266((&gch__system_5219.zct), c);
}
static N_INLINE(void, decRef__system_5317)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5315(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5272(src);
		incRef__system_5310(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5272((*dest));
		decRef__system_5317(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result) {
	initPackedSet__pureZcollectionsZintsets_16(Result);
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5272(p);
	decRef__system_5317(T1_);
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextSymId__ast_3103)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x) {
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*x).symId += ((NI) 1);
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	result.module = (*x).module;
	result.item = (*x).symId;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, createMagic__modulegraphs_9046)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, NimStringDesc* name, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag m) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T1_;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T2_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = getIdent__idents_152((*g).cache, name);
	T2_ = nextSymId__ast_3103(idgen);
	result = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 12), T1_, T2_, ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL), unknownLineInfo__lineinfos_284, 0);
	(*result).magic = m;
	(*result).flags = IL64(8796093022208);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, createMagic__modulegraphs_9052)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NimStringDesc* name, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag m) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	result = NIM_NIL;
	result = createMagic__modulegraphs_9046(g, (*g).idgen, name, m);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initOperators__modulegraphs_9127)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg* Result) {
	unsureAsgnRef((void**)&(*Result).opNot, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).opContains, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).opLe, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).opLt, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).opAnd, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).opOr, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).opIsNil, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).opEq, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).opAdd, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).opSub, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).opMul, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).opDiv, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).opLen, NIM_NIL);
	unsureAsgnRef((void**) (&(*Result).opLe), createMagic__modulegraphs_9052(g, ((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_44), ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 71)));
	unsureAsgnRef((void**) (&(*Result).opLt), createMagic__modulegraphs_9052(g, ((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_45), ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 72)));
	unsureAsgnRef((void**) (&(*Result).opAnd), createMagic__modulegraphs_9052(g, ((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_46), ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 109)));
	unsureAsgnRef((void**) (&(*Result).opOr), createMagic__modulegraphs_9052(g, ((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_47), ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 110)));
	unsureAsgnRef((void**) (&(*Result).opIsNil), createMagic__modulegraphs_9052(g, ((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_48), ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 143)));
	unsureAsgnRef((void**) (&(*Result).opEq), createMagic__modulegraphs_9052(g, ((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_49), ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 70)));
	unsureAsgnRef((void**) (&(*Result).opAdd), createMagic__modulegraphs_9052(g, ((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_50), ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 46)));
	unsureAsgnRef((void**) (&(*Result).opSub), createMagic__modulegraphs_9052(g, ((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_51), ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 47)));
	unsureAsgnRef((void**) (&(*Result).opMul), createMagic__modulegraphs_9052(g, ((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_52), ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 48)));
	unsureAsgnRef((void**) (&(*Result).opDiv), createMagic__modulegraphs_9052(g, ((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_53), ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 49)));
	unsureAsgnRef((void**) (&(*Result).opLen), createMagic__modulegraphs_9052(g, ((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_54), ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 39)));
	unsureAsgnRef((void**) (&(*Result).opNot), createMagic__modulegraphs_9052(g, ((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_55), ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 96)));
	unsureAsgnRef((void**) (&(*Result).opContains), createMagic__modulegraphs_9052(g, ((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_56), ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 134)));
}
N_LIB_PRIVATE N_NIMCALL(void, initModuleGraphFields__modulegraphs_9130)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* result) {
	tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* T1_;
	T1_ = NIM_NIL;
	T1_ = (tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg*) newObj((&NTIidgenerator__M4gwBCp6eTol0yFD6lAxTQ_), sizeof(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg));
	(*T1_).module = ((NI32) -1);
	(*T1_).symId = ((NI32) 0);
	(*T1_).typeId_0 = ((NI32) 0);
	asgnRef((void**) (&(*result).idgen), T1_);
	initStrTable__ast_4076((&(*result).packageSyms));
	initIntSet__pureZcollectionsZintsets_238((&(*result).deps));
	initTable__modulegraphs_9132(((NI) 32), (&(*result).importDeps));
	if ((*result).ifaces) { nimGCunrefNoCycle((*result).ifaces); (*result).ifaces = NIM_NIL; }
	if ((*result).importStack) { nimGCunrefNoCycle((*result).importStack); (*result).importStack = NIM_NIL; }
	initTable__modulegraphs_9160(((NI) 32), (&(*result).inclToMod));
	if ((*result).owners) { nimGCunrefNoCycle((*result).owners); (*result).owners = NIM_NIL; }
	initTable__modulegraphs_9184(((NI) 32), (&(*result).suggestSymbols));
	initTable__modulegraphs_9204(((NI) 32), (&(*result).suggestErrors));
	if ((*result).methods) { nimGCunrefNoCycle((*result).methods); (*result).methods = NIM_NIL; }
	initStrTable__ast_4076((&(*result).compilerprocs));
	initStrTable__ast_4076((&(*result).exposed));
	initStrTable__ast_4076((&(*result).packageTypes));
	asgnRef((void**) (&(*result).emptyNode), newNode__ast_3289(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)));
	initTable__modulegraphs_9228(((NI) 32), (&(*result).cacheSeqs));
	initTable__modulegraphs_9248(((NI) 32), (&(*result).cacheCounters));
	initTable__modulegraphs_9270(((NI) 32), (&(*result).cacheTables));
	initTable__modulegraphs_9290(((NI) 32), (&(*result).canonTypes));
	initTable__modulegraphs_9310(((NI) 32), (&(*result).symBodyHashes));
	initOperators__modulegraphs_9127(result, (&(*result).operators));
	initTable__lineinfos_327(((NI) 32), (&(*result).emittedTypeInfo));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg*, newModuleGraph__modulegraphs_9478)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config) {
	tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* result;
	tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg*) newObj((&NTImodulegraph__AcDjMYSN0KX1UsX3HvPu2w_), sizeof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg));
	result = T1_;
	asgnRef((void**) (&(*result).config), config);
	asgnRef((void**) (&(*result).cache), cache);
	initModuleGraphFields__modulegraphs_9130(result);
	return result;
}
static N_INLINE(NI, dependsOn__modulegraphs_9593)(NI a, NI b) {
	NI result;
	result = (NI)0;
	result = (NI)((NI)((NU32)(a) << (NU32)(((NI) 15))) + b);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addDep__modulegraphs_9601)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 dep) {
	{
		NI T5_;
		if (!(*g).suggestMode) goto LA3_;
		T5_ = (NI)0;
		T5_ = dependsOn__modulegraphs_9593((*m).position, ((NI) (dep)));
		incl__pureZcollectionsZintsets_55((&(*g).deps), T5_);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addIncludeDep__modulegraphs_9612)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI32 module, NI32 includeFile) {
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = hasKeyOrPut__modulegraphs_9642((&(*g).inclToMod), includeFile, module);
	(void)(T1_);
}
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_2710)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI module) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = ((*g).packed_0 ? (*g).packed_0->Sup.len : 0);
	T1_ = (module < T2_);
	if (!(T1_)) goto LA3_;
	T1_ = ((*g).packed_0->data[module].status == ((tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg) 3));
	LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getModule__modulegraphs_9522)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI32 fileIdx) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	result = NIM_NIL;
	{
		if (!(((NI32) 0) <= fileIdx)) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = isCachedModule__modulegraphs_2710(g, ((NI) (fileIdx)));
			if (!T7_) goto LA8_;
			result = (*g).packed_0->data[fileIdx].module;
		}
		goto LA5_;
		LA8_: ;
		{
			NI T11_;
			T11_ = ((*g).ifaces ? (*g).ifaces->Sup.len : 0);
			if (!(((NI) (fileIdx)) < T11_)) goto LA12_;
			result = (*g).ifaces->data[fileIdx].module;
		}
		goto LA5_;
		LA12_: ;
		LA5_: ;
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, moduleFromRodFile__modulegraphs_13115)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI32 fileIdx, tySequence__48JTohSgTy339bRxHzUD8KA** cachedModules) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	result = NIM_NIL;
	{
		if (!((28 &((NU8)1<<((NU)((*(*g).config).symbolFiles)&7U)))!=0)) goto LA3_;
		result = moduleFromRodFile__icZic_8330((&(*g).packed_0), (*g).config, (*g).cache, fileIdx, cachedModules);
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getPackage__modulegraphs_13158)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, NI32 fileIdx) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* pkgSym;
	result = NIM_NIL;
	pkgSym = getPackage__packages_7((*graph).config, (*graph).cache, fileIdx);
	result = strTableGet__astalgo_3383((*graph).packageSyms, (*pkgSym).name);
	{
		if (!(result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA3_;
		result = pkgSym;
		strTableAdd__astalgo_3325((&(*graph).packageSyms), pkgSym);
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initStrTables__modulegraphs_2703)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m) {
	initStrTable__ast_4076((&(*g).ifaces->data[(*m).position].interf));
	initStrTable__ast_4076((&(*g).ifaces->data[(*m).position].interfHidden));
}
N_LIB_PRIVATE N_NIMCALL(void, registerModule__modulegraphs_9057)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m) {
	tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ T11_;
	NimStringDesc* T12_;
	{
		NI T3_;
		T3_ = ((*g).ifaces ? (*g).ifaces->Sup.len : 0);
		if (!(T3_ <= (*m).position)) goto LA4_;
		asgnRef((void**) (&(*g).ifaces), (tySequence__RNhZxf20g9beyq5VBOGxhDg*) setLengthSeqV2(((*g).ifaces)?&((*g).ifaces)->Sup:NIM_NIL, (&NTIseqLifaceT__RNhZxf20g9beyq5VBOGxhDg_), ((NI) ((NI)((*m).position + ((NI) 1))))));
	}
	LA4_: ;
	{
		NI T8_;
		T8_ = ((*g).packed_0 ? (*g).packed_0->Sup.len : 0);
		if (!(T8_ <= (*m).position)) goto LA9_;
		asgnRef((void**) (&(*g).packed_0), (tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ*) setLengthSeqV2(((*g).packed_0)?&((*g).packed_0)->Sup:NIM_NIL, (&NTIpackedmodulegraph__JbK5aK9aVhc9cJZzQYg1wQlQ_), ((NI) ((NI)((*m).position + ((NI) 1))))));
	}
	LA9_: ;
	nimZeroMem((void*)(&T11_), sizeof(tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ));
	nimZeroMem((void*)(&T11_), sizeof(tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ));
	T11_.module = m;
	T11_.converters = NIM_NIL;
	T11_.patterns = NIM_NIL;
	T12_ = NIM_NIL;
	T12_ = uniqueModuleName__msgs_1521((*g).config, ((NI32) ((*m).position)));
	T11_.uniqueName = rope__ropes_109(T12_);
	genericShallowAssign((void*)(&(*g).ifaces->data[(*m).position]), (void*)(&T11_), (&NTIiface__4y9aWdJBxraQYTl5Pa1NMuQ_));
	initStrTables__modulegraphs_2703(g, m);
}
N_LIB_PRIVATE N_NIMCALL(void, onProcessing__modulegraphs_13127)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, NI32 fileIdx, NimStringDesc* moduleStatus, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fromModule) {
	tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf;
	NIM_BOOL isNimscript;
	conf = (*graph).config;
	isNimscript = isDefined__options_2292(conf, ((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_57));
	{
		NIM_BOOL T3_;
		NimStringDesc* path;
		NimStringDesc* indent;
		NI T7_;
		NimStringDesc* fromModule2;
		NimStringDesc* mode;
		tyArray__haiLFy0nBviVTKFGuwztzQ T18_;
		NimStringDesc* T19_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(isNimscript);
		if (T3_) goto LA4_;
		T3_ = (((*conf).cmdlineNotes[(NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 83)- 17))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 83)- 17))&7U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		path = toFilenameOption__msgs_600(conf, fileIdx, (*conf).filenameOption);
		T7_ = ((*graph).importStack ? (*graph).importStack->Sup.len : 0);
		indent = nsuRepeatStr(((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_58), ((NI) (T7_)));
		{
			if (!!((fromModule == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA10_;
			fromModule2 = (*(*fromModule).name).s;
		}
		goto LA8_;
		LA10_: ;
		{
			fromModule2 = copyString(((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_59));
		}
		LA8_: ;
		{
			if (!isNimscript) goto LA15_;
			mode = copyString(((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_60));
		}
		goto LA13_;
		LA15_: ;
		{
			mode = ((NimStringDesc*) NIM_NIL);
		}
		LA13_: ;
		nimZeroMem((void*)T18_, sizeof(tyArray__haiLFy0nBviVTKFGuwztzQ));
		T18_[0] = copyString(mode);
		T18_[1] = copyString(indent);
		T18_[2] = copyString(fromModule2);
		T18_[3] = copyString(moduleStatus);
		T18_[4] = copyString(path);
		T19_ = NIM_NIL;
		T19_ = nsuFormatOpenArray(((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_61), T18_, 5);
		liMessage__msgs_1128(conf, unknownLineInfo__lineinfos_284, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 83), T19_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), TM__mff0c158N4EFFNgrs4pcEQ_62, NIM_FALSE);
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, belongsToStdlib__modulegraphs_13167)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	NIM_BOOL result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T1_;
	NI T2_;
	NI T3_;
	result = (NIM_BOOL)0;
	T1_ = NIM_NIL;
	T1_ = getPackageSymbol__packages_17(sym);
	T2_ = (NI)0;
	T2_ = getPackageId__packages_41(T1_);
	T3_ = (NI)0;
	T3_ = getPackageId__packages_41((*graph).systemModule);
	result = (T2_ == T3_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, simulateCachedModule__modulegraphs_2726)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* moduleSym, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m) {
	simulateLoadedModule__icZic_8467((&(*g).packed_0), (*g).config, (*g).cache, moduleSym, m);
}
N_LIB_PRIVATE N_NIMCALL(void, closeRodFile__modulegraphs_9579)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m) {
	{
		NI mint;
		NimStringDesc* T5_;
		NimStringDesc* T6_;
		if (!((12 &((NU8)1<<((NU)((*(*g).config).symbolFiles)&7U)))!=0)) goto LA3_;
		mint = (*m).position;
		T5_ = NIM_NIL;
		T5_ = toFullPath__msgs_548((*g).config, ((NI32) (mint)));
		T6_ = NIM_NIL;
		T6_ = toRodFile__icZic_3146((*g).config, T5_, ((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_64));
		saveRodFile__icZic_4386(T6_, (&(*g).encoders->data[mint]), (&(*g).packed_0->data[mint].fromDisk));
		(*g).packed_0->data[mint].status = ((tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg) 5);
	}
	goto LA1_;
	LA3_: ;
	{
		NI mint_2;
		if (!((*(*g).config).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 4))) goto LA8_;
		mint_2 = (*m).position;
		simulateCachedModule__modulegraphs_2726(g, m, (&(*g).packed_0->data[mint_2].fromDisk));
		(*g).packed_0->data[mint_2].status = ((tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg) 3);
	}
	goto LA1_;
	LA8_: ;
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, registerModuleById__modulegraphs_9124)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI32 m) {
	registerModule__modulegraphs_9057(g, (*g).packed_0->data[m].module);
}
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_2722)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = isCachedModule__modulegraphs_2710(g, (*m).position);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, someSym__modulegraphs_2849)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	NIM_BOOL importHidden;
	result = NIM_NIL;
	importHidden = (((*m).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 27))&31U)))!=0);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isCachedModule__modulegraphs_2722(g, m);
		if (!T3_) goto LA4_;
		result = interfaceSymbol__icZic_9091((*g).config, (*g).cache, (&(*g).packed_0), ((NI32) ((*m).position)), name, importHidden);
	}
	goto LA1_;
	LA4_: ;
	{
		tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* retX60gensym22_;
		retX60gensym22_ = (&(*g).ifaces->data[(*m).position].interf);
		{
			if (!importHidden) goto LA9_;
			retX60gensym22_ = (&(*g).ifaces->data[(*m).position].interfHidden);
		}
		LA9_: ;
		result = strTableGet__astalgo_3383((*retX60gensym22_), name);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, systemModuleSym__modulegraphs_2867)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	result = NIM_NIL;
	result = someSym__modulegraphs_2849(g, (*g).systemModule, name);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getAttachedOp__modulegraphs_4049)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ op) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	result = NIM_NIL;
	result = getOrDefault__modulegraphs_4132((*g).attachedOps[(op)- 0], (*t).Sup.itemId);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setAttachedOp__modulegraphs_4445)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI module, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ op, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* value) {
	X5BX5Deq___modulegraphs_4491((&(*g).attachedOps[(op)- 0]), (*t).Sup.itemId, value);
}
N_LIB_PRIVATE N_NIMCALL(void, copyTypeProps__modulegraphs_8910)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI module, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* dest, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* src) {
	{
		tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ k;
		NI res;
		k = (tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ)0;
		res = ((NI) 0);
		{
			while (1) {
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* op;
				if (!(res <= ((NI) 4))) goto LA3;
				k = ((tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ) (res));
				op = getAttachedOp__modulegraphs_4049(g, src, k);
				{
					if (!!((op == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA6_;
					setAttachedOp__modulegraphs_4445(g, module, dest, k, op);
				}
				LA6_: ;
				res += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDirty__modulegraphs_12920)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (*g).suggestMode;
	if (!(T1_)) goto LA2_;
	T1_ = (((*m).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 11))&63U)))!=0);
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, transitiveClosure__modulegraphs_11100)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* g, NI n) {
	{
		NI k;
		NI i;
		k = (NI)0;
		i = ((NI) 0);
		{
			while (1) {
				if (!(i < n)) goto LA3;
				k = i;
				{
					NI i_2;
					NI i_3;
					i_2 = (NI)0;
					i_3 = ((NI) 0);
					{
						while (1) {
							if (!(i_3 < n)) goto LA6;
							i_2 = i_3;
							{
								NI j;
								NI i_4;
								j = (NI)0;
								i_4 = ((NI) 0);
								{
									while (1) {
										if (!(i_4 < n)) goto LA9;
										j = i_4;
										{
											NIM_BOOL T12_;
											NI T14_;
											NIM_BOOL T15_;
											T12_ = (NIM_BOOL)0;
											T12_ = !((i_2 == j));
											if (!(T12_)) goto LA13_;
											T14_ = (NI)0;
											T14_ = dependsOn__modulegraphs_9593(i_2, j);
											T15_ = (NIM_BOOL)0;
											T15_ = contains__astalgo_3489((&(*g)), T14_);
											T12_ = !(T15_);
											LA13_: ;
											if (!T12_) goto LA16_;
											{
												NIM_BOOL T20_;
												NI T21_;
												NI T23_;
												NI T26_;
												T20_ = (NIM_BOOL)0;
												T21_ = (NI)0;
												T21_ = dependsOn__modulegraphs_9593(i_2, k);
												T20_ = contains__astalgo_3489((&(*g)), T21_);
												if (!(T20_)) goto LA22_;
												T23_ = (NI)0;
												T23_ = dependsOn__modulegraphs_9593(k, j);
												T20_ = contains__astalgo_3489((&(*g)), T23_);
												LA22_: ;
												if (!T20_) goto LA24_;
												T26_ = (NI)0;
												T26_ = dependsOn__modulegraphs_9593(i_2, j);
												incl__pureZcollectionsZintsets_55(g, T26_);
											}
											LA24_: ;
										}
										LA16_: ;
										i_4 += ((NI) 1);
									} LA9: ;
								}
							}
							i_3 += ((NI) 1);
						} LA6: ;
					}
				}
				i += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, markDirty__modulegraphs_11296)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI32 fileIdx) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m;
	m = getModule__modulegraphs_9522(g, fileIdx);
	{
		if (!!((m == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA3_;
		del__modulegraphs_11344((&(*g).suggestSymbols), fileIdx);
		del__modulegraphs_12143((&(*g).suggestErrors), fileIdx);
		(*m).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 11)) & 63);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, markClientsDirty__modulegraphs_12928)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI32 fileIdx) {
	{
		NI T5_;
		if (!(*g).invalidTransitiveClosure) goto LA3_;
		(*g).invalidTransitiveClosure = NIM_FALSE;
		T5_ = ((*g).ifaces ? (*g).ifaces->Sup.len : 0);
		transitiveClosure__modulegraphs_11100((&(*g).deps), T5_);
	}
	LA3_: ;
	{
		NI32 i;
		NI32 colontmp_;
		NI T7_;
		NI32 res;
		i = (NI32)0;
		colontmp_ = (NI32)0;
		T7_ = ((*g).ifaces ? (*g).ifaces->Sup.len : 0);
		colontmp_ = ((NI32) (T7_));
		res = ((NI32) 0);
		{
			while (1) {
				if (!(res < colontmp_)) goto LA9;
				i = res;
				{
					NI T12_;
					NIM_BOOL T13_;
					NI32 fi;
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
					T12_ = (NI)0;
					T12_ = dependsOn__modulegraphs_9593(((NI) (i)), ((NI) (fileIdx)));
					T13_ = (NIM_BOOL)0;
					T13_ = contains__astalgo_3489((&(*g).deps), T12_);
					if (!T13_) goto LA14_;
					fi = i;
					module = getModule__modulegraphs_9522(g, fi);
					{
						NIM_BOOL T18_;
						NIM_BOOL T20_;
						T18_ = (NIM_BOOL)0;
						T18_ = !((module == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
						if (!(T18_)) goto LA19_;
						T20_ = (NIM_BOOL)0;
						T20_ = isDirty__modulegraphs_12920(g, module);
						T18_ = !(T20_);
						LA19_: ;
						if (!T18_) goto LA21_;
						markDirty__modulegraphs_11296(g, fi);
						markClientsDirty__modulegraphs_12928(g, fi);
					}
					LA21_: ;
				}
				LA14_: ;
				res += ((NI) 1);
			} LA9: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, initEncoder__modulegraphs_2730)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module) {
	NI id;
	id = (*module).position;
	{
		NI T3_;
		T3_ = ((*g).encoders ? (*g).encoders->Sup.len : 0);
		if (!(T3_ <= id)) goto LA4_;
		asgnRef((void**) (&(*g).encoders), (tySequence__lFbCtu5P2Kf7YDYtGjkxAQ*) setLengthSeqV2(((*g).encoders)?&((*g).encoders)->Sup:NIM_NIL, (&NTIseqLpackedencoderT__lFbCtu5P2Kf7YDYtGjkxAQ_), ((NI) ((NI)(id + ((NI) 1))))));
	}
	LA4_: ;
	initEncoder__icZic_2270((&(*g).encoders->data[id]), (&(*g).packed_0->data[id].fromDisk), module, (*g).config, (*g).startupPackedConfig);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, resolveType__modulegraphs_2889)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ* t) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	result = NIM_NIL;
	result = (*t).typ;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (result == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
		if (!(T3_)) goto LA4_;
		T3_ = isCachedModule__modulegraphs_2710(g, (*t).id.module);
		LA4_: ;
		if (!T3_) goto LA5_;
		result = loadTypeFromId__icZic_8398((*g).config, (*g).cache, (&(*g).packed_0), (*t).id.module, (*t).id.packed_0);
		unsureAsgnRef((void**) (&(*t).typ), result);
	}
	LA5_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, resolveSym__modulegraphs_2904)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg* t) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	result = NIM_NIL;
	result = (*t).sym;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
		if (!(T3_)) goto LA4_;
		T3_ = isCachedModule__modulegraphs_2710(g, (*t).id.module);
		LA4_: ;
		if (!T3_) goto LA5_;
		result = loadSymFromId__icZic_8413((*g).config, (*g).cache, (&(*g).packed_0), (*t).id.module, (*t).id.packed_0);
		unsureAsgnRef((void**) (&(*t).sym), result);
	}
	LA5_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, initModuleIter__modulegraphs_2748)(tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A* mi, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	result = NIM_NIL;
	(*mi).modIndex = (*m).position;
	(*mi).fromRod = isCachedModule__modulegraphs_2710(g, (*mi).modIndex);
	(*mi).importHidden = (((*m).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 27))&31U)))!=0);
	{
		if (!(*mi).fromRod) goto LA3_;
		result = initRodIter__icZic_8497((&(*mi).rodIt), (*g).config, (*g).cache, (&(*g).packed_0), ((NI32) ((*mi).modIndex)), name, (*mi).importHidden);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* retX60gensym13_;
		retX60gensym13_ = (&(*g).ifaces->data[(*mi).modIndex].interf);
		{
			if (!(*mi).importHidden) goto LA8_;
			retX60gensym13_ = (&(*g).ifaces->data[(*mi).modIndex].interfHidden);
		}
		LA8_: ;
		result = initIdentIter__astalgo_3420((&(*mi).ti), (*retX60gensym13_), name);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, nextModuleIter__modulegraphs_2783)(tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A* mi, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	result = NIM_NIL;
	{
		if (!(*mi).fromRod) goto LA3_;
		result = nextRodIter__icZic_8980((&(*mi).rodIt), (&(*g).packed_0));
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* retX60gensym14_;
		retX60gensym14_ = (&(*g).ifaces->data[(*mi).modIndex].interf);
		{
			if (!(*mi).importHidden) goto LA8_;
			retX60gensym14_ = (&(*g).ifaces->data[(*mi).modIndex].interfHidden);
		}
		LA8_: ;
		result = nextIdentIter__astalgo_3401((&(*mi).ti), (*retX60gensym14_));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, strTableAdds__modulegraphs_2706)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	strTableAdd__astalgo_3325((&(*g).ifaces->data[(*m).position].interf), s);
	strTableAdd__astalgo_3325((&(*g).ifaces->data[(*m).position].interfHidden), s);
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toBase64a__modulegraphs_2616)(NCSTRING s, NI len) {
	NimStringDesc* result;
	NI i;
	result = NIM_NIL;
	result = rawNewString(((NI) ((NI)((NI)((NI)(len + ((NI) 2)) / ((NI) 3)) * ((NI) 4)))));
	result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__mff0c158N4EFFNgrs4pcEQ_65));
	i = ((NI) 0);
	{
		while (1) {
			NI a;
			NI b;
			NI c;
			if (!(i < (NI)(len - ((NI) 2)))) goto LA2;
			a = ((NU8)(s[i]));
			b = ((NU8)(s[(NI)(i + ((NI) 1))]));
			c = ((NU8)(s[(NI)(i + ((NI) 2))]));
			result = resizeString(result, (cb64__modulegraphs_2606[((NI)((NI32)(a) >> (NU32)(((NI) 2))))- 0] ? cb64__modulegraphs_2606[((NI)((NI32)(a) >> (NU32)(((NI) 2))))- 0]->Sup.len : 0) + 0);
appendString(result, cb64__modulegraphs_2606[((NI)((NI32)(a) >> (NU32)(((NI) 2))))- 0]);
			result = resizeString(result, (cb64__modulegraphs_2606[((NI)((NI)((NU32)((NI)(a & ((NI) 3))) << (NU32)(((NI) 4))) | (NI)((NI32)((NI)(b & ((NI) 240))) >> (NU32)(((NI) 4)))))- 0] ? cb64__modulegraphs_2606[((NI)((NI)((NU32)((NI)(a & ((NI) 3))) << (NU32)(((NI) 4))) | (NI)((NI32)((NI)(b & ((NI) 240))) >> (NU32)(((NI) 4)))))- 0]->Sup.len : 0) + 0);
appendString(result, cb64__modulegraphs_2606[((NI)((NI)((NU32)((NI)(a & ((NI) 3))) << (NU32)(((NI) 4))) | (NI)((NI32)((NI)(b & ((NI) 240))) >> (NU32)(((NI) 4)))))- 0]);
			result = resizeString(result, (cb64__modulegraphs_2606[((NI)((NI)((NU32)((NI)(b & ((NI) 15))) << (NU32)(((NI) 2))) | (NI)((NI32)((NI)(c & ((NI) 192))) >> (NU32)(((NI) 6)))))- 0] ? cb64__modulegraphs_2606[((NI)((NI)((NU32)((NI)(b & ((NI) 15))) << (NU32)(((NI) 2))) | (NI)((NI32)((NI)(c & ((NI) 192))) >> (NU32)(((NI) 6)))))- 0]->Sup.len : 0) + 0);
appendString(result, cb64__modulegraphs_2606[((NI)((NI)((NU32)((NI)(b & ((NI) 15))) << (NU32)(((NI) 2))) | (NI)((NI32)((NI)(c & ((NI) 192))) >> (NU32)(((NI) 6)))))- 0]);
			result = resizeString(result, (cb64__modulegraphs_2606[((NI)(c & ((NI) 63)))- 0] ? cb64__modulegraphs_2606[((NI)(c & ((NI) 63)))- 0]->Sup.len : 0) + 0);
appendString(result, cb64__modulegraphs_2606[((NI)(c & ((NI) 63)))- 0]);
			i += ((NI) 3);
		} LA2: ;
	}
	{
		NI a_2;
		NI b_2;
		if (!(i < (NI)(len - ((NI) 1)))) goto LA5_;
		a_2 = ((NU8)(s[i]));
		b_2 = ((NU8)(s[(NI)(i + ((NI) 1))]));
		result = resizeString(result, (cb64__modulegraphs_2606[((NI)((NI32)(a_2) >> (NU32)(((NI) 2))))- 0] ? cb64__modulegraphs_2606[((NI)((NI32)(a_2) >> (NU32)(((NI) 2))))- 0]->Sup.len : 0) + 0);
appendString(result, cb64__modulegraphs_2606[((NI)((NI32)(a_2) >> (NU32)(((NI) 2))))- 0]);
		result = resizeString(result, (cb64__modulegraphs_2606[((NI)((NI)((NU32)((NI)(a_2 & ((NI) 3))) << (NU32)(((NI) 4))) | (NI)((NI32)((NI)(b_2 & ((NI) 240))) >> (NU32)(((NI) 4)))))- 0] ? cb64__modulegraphs_2606[((NI)((NI)((NU32)((NI)(a_2 & ((NI) 3))) << (NU32)(((NI) 4))) | (NI)((NI32)((NI)(b_2 & ((NI) 240))) >> (NU32)(((NI) 4)))))- 0]->Sup.len : 0) + 0);
appendString(result, cb64__modulegraphs_2606[((NI)((NI)((NU32)((NI)(a_2 & ((NI) 3))) << (NU32)(((NI) 4))) | (NI)((NI32)((NI)(b_2 & ((NI) 240))) >> (NU32)(((NI) 4)))))- 0]);
		result = resizeString(result, (cb64__modulegraphs_2606[((NI)((NU32)((NI)(b_2 & ((NI) 15))) << (NU32)(((NI) 2))))- 0] ? cb64__modulegraphs_2606[((NI)((NU32)((NI)(b_2 & ((NI) 15))) << (NU32)(((NI) 2))))- 0]->Sup.len : 0) + 0);
appendString(result, cb64__modulegraphs_2606[((NI)((NU32)((NI)(b_2 & ((NI) 15))) << (NU32)(((NI) 2))))- 0]);
	}
	goto LA3_;
	LA5_: ;
	{
		NI a_3;
		if (!(i < len)) goto LA8_;
		a_3 = ((NU8)(s[i]));
		result = resizeString(result, (cb64__modulegraphs_2606[((NI)((NI32)(a_3) >> (NU32)(((NI) 2))))- 0] ? cb64__modulegraphs_2606[((NI)((NI32)(a_3) >> (NU32)(((NI) 2))))- 0]->Sup.len : 0) + 0);
appendString(result, cb64__modulegraphs_2606[((NI)((NI32)(a_3) >> (NU32)(((NI) 2))))- 0]);
		result = resizeString(result, (cb64__modulegraphs_2606[((NI)((NU32)((NI)(a_3 & ((NI) 3))) << (NU32)(((NI) 4))))- 0] ? cb64__modulegraphs_2606[((NI)((NU32)((NI)(a_3 & ((NI) 3))) << (NU32)(((NI) 4))))- 0]->Sup.len : 0) + 0);
appendString(result, cb64__modulegraphs_2606[((NI)((NU32)((NI)(a_3 & ((NI) 3))) << (NU32)(((NI) 4))))- 0]);
	}
	goto LA3_;
	LA8_: ;
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___modulegraphs_8985)(tyArray__qtqsWM5aXmcpMIVmvq3kAA u) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = toBase64a__modulegraphs_2616(((NCSTRING) (u)), ((NI) 16));
	return result;
}
static N_INLINE(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ, toPackedItemId__icZpacked95ast_611)(NI32 item) {
	tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ result;
	nimZeroMem((void*)(&result), sizeof(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ));
	nimZeroMem((void*)(&result), sizeof(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ));
	result.module = ((NU32) 0);
	result.item = item;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, loadCompilerProc__modulegraphs_8939)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NimStringDesc* name) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
{	result = NIM_NIL;
	{
		if (!((*(*g).config).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0))) goto LA3_;
		result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI module;
		NI colontmp_;
		NI T6_;
		NI res;
		module = (NI)0;
		colontmp_ = (NI)0;
		T6_ = (((*g).packed_0 ? (*g).packed_0->Sup.len : 0)-1);
		colontmp_ = T6_;
		res = ((NI) 0);
		{
			while (1) {
				NI32 x;
				if (!(res <= colontmp_)) goto LA8;
				module = res;
				x = searchForCompilerproc__icZic_9189((&(*g).packed_0->data[module]), name);
				{
					tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ T13_;
					if (!(((NI32) 0) <= x)) goto LA11_;
					T13_ = toPackedItemId__icZpacked95ast_611(x);
					result = loadSymFromId__icZic_8413((*g).config, (*g).cache, (&(*g).packed_0), module, T13_);
					{
						if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA16_;
						strTableAdd__astalgo_3325((&(*g).compilerprocs), result);
					}
					LA16_: ;
					goto BeforeRet_;
				}
				LA11_: ;
				res += ((NI) 1);
			} LA8: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, hash__modulegraphs_9001)(tyArray__qtqsWM5aXmcpMIVmvq3kAA u) {
	NI result;
	result = (NI)0;
	result = ((NI) 0);
	{
		NI x;
		NI res;
		x = (NI)0;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= ((NI) 3))) goto LA3;
				x = res;
				result = (NI)((NI)((NU32)(result) << (NU32)(((NI) 8))) | ((NI) (u[(x)- 0])));
				res += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___modulegraphs_8997)(tyArray__qtqsWM5aXmcpMIVmvq3kAA a, tyArray__qtqsWM5aXmcpMIVmvq3kAA b) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = equalMem__system_1741(((void*) (a)), ((void*) (b)), ((NI) 16));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setAttachedOpPartial__modulegraphs_5615)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI module, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ op, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* value) {
	X5BX5Deq___modulegraphs_4491((&(*g).attachedOps[(op)- 0]), (*t).Sup.itemId, value);
}
N_LIB_PRIVATE N_NIMCALL(void, completePartialOp__modulegraphs_5667)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI module, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ op, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* value) {
	{
		if (!!(((*(*g).config).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0)))) goto LA3_;
		toPackedGeneratedProcDef__icZic_3063(value, (&(*g).encoders->data[module]), (&(*g).packed_0->data[module].fromDisk));
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA*, resolveInst__modulegraphs_2919)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q* t) {
	tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* result;
	result = NIM_NIL;
	result = (*t).inst;
	{
		NIM_BOOL T3_;
		tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* T7_;
		NI T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = (result == ((tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA*) NIM_NIL));
		if (!(T3_)) goto LA4_;
		T3_ = isCachedModule__modulegraphs_2710(g, (*t).module);
		LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = NIM_NIL;
		T7_ = (tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA*) newObj((&NTIpinstantiation__eg8se9cZBHdzb5ZM7CrYNVg_), sizeof(tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA));
		asgnRef((void**) (&(*T7_).sym), loadSymFromId__icZic_8413((*g).config, (*g).cache, (&(*g).packed_0), (*t).sym.module, (*t).sym.packed_0));
		result = T7_;
		T8_ = ((*t).concreteTypes ? (*t).concreteTypes->Sup.len : 0);
		asgnRef((void**) (&(*result).concreteTypes), newSeq__modulegraphs_2931(((NI) (T8_))));
		{
			NI i;
			NI colontmp_;
			NI T10_;
			NI res;
			i = (NI)0;
			colontmp_ = (NI)0;
			T10_ = (((*result).concreteTypes ? (*result).concreteTypes->Sup.len : 0)-1);
			colontmp_ = T10_;
			res = ((NI) 0);
			{
				while (1) {
					if (!(res <= colontmp_)) goto LA12;
					i = res;
					asgnRef((void**) (&(*result).concreteTypes->data[i]), loadTypeFromId__icZic_8398((*g).config, (*g).cache, (&(*g).packed_0), (*t).concreteTypes->data[i].module, (*t).concreteTypes->data[i].packed_0));
					res += ((NI) 1);
				} LA12: ;
			}
		}
		unsureAsgnRef((void**) (&(*t).inst), result);
	}
	LA5_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addMethodToGeneric__modulegraphs_7727)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI module, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, NI col, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m) {
	tySequence__m4PVWjcAAjfxlwJxLkKn8A* T1_;
	tySequence__m4PVWjcAAjfxlwJxLkKn8A** T2_;
	tyTuple__RWXAsQlFoGYyEQZp1G65sg T3_;
	tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg T4_;
	NI T5_;
	T1_ = NIM_NIL;
	T1_ = NIM_NIL;
	T2_ = (tySequence__m4PVWjcAAjfxlwJxLkKn8A**)0;
	T2_ = mgetOrPut__modulegraphs_7763((&(*g).methodsPerType), (*t).Sup.itemId, T1_);
	nimZeroMem((void*)(&T3_), sizeof(tyTuple__RWXAsQlFoGYyEQZp1G65sg));
	T3_.Field0 = col;
	nimZeroMem((void*)(&T4_), sizeof(tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg));
	nimZeroMem((void*)(&T4_), sizeof(tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg));
	T4_.sym = m;
	T3_.Field1.id = T4_.id;
	T3_.Field1.sym = T4_.sym;
	unsureAsgnRef((void**) (&(*T2_)), (tySequence__m4PVWjcAAjfxlwJxLkKn8A*) incrSeqV3((TGenericSeq*)((*T2_)), (&NTIseqLLint_lazysymTT__m4PVWjcAAjfxlwJxLkKn8A_)));
	T5_ = (*T2_)->Sup.len++;
	(*T2_)->data[T5_].Field0 = T3_.Field0;
	(*T2_)->data[T5_].Field1.id = T3_.Field1.id;
	asgnRef((void**) (&(*T2_)->data[T5_].Field1.sym), T3_.Field1.sym);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasDisabledAsgn__modulegraphs_8897)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	NIM_BOOL result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* op;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	op = getAttachedOp__modulegraphs_4049(g, t, ((tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ) 1));
	T1_ = (NIM_BOOL)0;
	T1_ = !((op == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
	if (!(T1_)) goto LA2_;
	T1_ = (((*op).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 24))&63U)))!=0);
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setToStringProc__modulegraphs_6073)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* value) {
	tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg T1_;
	nimZeroMem((void*)(&T1_), sizeof(tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg));
	T1_.sym = value;
	X5BX5Deq___modulegraphs_6117((&(*g).enumToStringProcs), (*t).Sup.itemId, T1_);
}
N_LIB_PRIVATE N_NIMCALL(void, loadPackedSym__modulegraphs_8978)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg* s) {
	{
		if (!((*s).sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA3_;
		unsureAsgnRef((void**) (&(*s).sym), loadSymFromId__icZic_8413((*g).config, (*g).cache, (&(*g).packed_0), (*s).id.module, (*s).id.packed_0));
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rememberEmittedTypeInfo__modulegraphs_9541)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI32 m, NimStringDesc* ti) {
	{
		NI T5_;
		NimStringDesc* T6_;
		if (!!(((*(*g).config).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0)))) goto LA3_;
		asgnRef((void**) (&(*g).packed_0->data[m].fromDisk.emittedTypeInfo), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*g).packed_0->data[m].fromDisk.emittedTypeInfo), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
		T5_ = (*g).packed_0->data[m].fromDisk.emittedTypeInfo->Sup.len++;
		T6_ = NIM_NIL;
		T6_ = (*g).packed_0->data[m].fromDisk.emittedTypeInfo->data[T5_]; (*g).packed_0->data[m].fromDisk.emittedTypeInfo->data[T5_] = copyStringRC1(ti);
		if (T6_) nimGCunrefNoCycle(T6_);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getToStringProc__modulegraphs_5686)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg* T1_;
	result = NIM_NIL;
	T1_ = (tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg*)0;
	T1_ = X5BX5D___modulegraphs_5743((&(*g).enumToStringProcs), (*t).Sup.itemId);
	result = resolveSym__modulegraphs_2904(g, T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, configComplete__modulegraphs_13124)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	rememberStartupConfig__icZic_507((&(*g).startupPackedConfig), (*g).config);
}
N_LIB_PRIVATE N_NIMCALL(void, resetForBackend__modulegraphs_278)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	initStrTable__ast_4076((&(*g).compilerprocs));
	clear__modulegraphs_320((&(*g).typeInstCache));
	clear__modulegraphs_766((&(*g).procInstCache));
	{
		tyObject_Table__r0v8BdcBPKhl73K8p2VMUA* a;
		tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ i;
		a = (tyObject_Table__r0v8BdcBPKhl73K8p2VMUA*)0;
		i = ((tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ) 0);
		{
			while (1) {
				a = (&(*g).attachedOps[(i)- 0]);
				clear__modulegraphs_1302(a);
				{
					if (!(((tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ) 4) <= i)) goto LA6_;
					goto LA2;
				}
				LA6_: ;
				i += ((NI) 1);
			}
		} LA2: ;
	}
	clear__modulegraphs_1738((&(*g).methodsPerType));
	clear__modulegraphs_2183((&(*g).enumToStringProcs));
}
N_LIB_PRIVATE N_NIMCALL(void, atmmodulegraphsdotnim_DatInit000)(void) {
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_2_49[49];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_3_7[7];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_4_2[2];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_5_2[2];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_6_2[2];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_7_3[3];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_8_2[2];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_9_2[2];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_10_3[3];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_11_4[4];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_12_2[2];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_13_3[3];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_14_2[2];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_15_3[3];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_16_2[2];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_17_2[2];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_18_3[3];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_19_2[2];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_20_3[3];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_21_2[2];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_22_3[3];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_23_2[2];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_24_2[2];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_25_3[3];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_26_2[2];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_27_2[2];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_28_3[3];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_29_2[2];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_30_2[2];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_31_3[3];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_32_2[2];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_33_3[3];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_34_2[2];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_35_3[3];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_36_2[2];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_37_3[3];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_38_2[2];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_39_3[3];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_40_2[2];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_41_3[3];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_42_4[4];
static TNimNode* TM__mff0c158N4EFFNgrs4pcEQ_43_13[13];
static TNimNode TM__mff0c158N4EFFNgrs4pcEQ_0[211];
NTImodulegraph58objecttype__nOSrcYqJTxXt2ptNc0gnWg_.size = sizeof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg);
NTImodulegraph58objecttype__nOSrcYqJTxXt2ptNc0gnWg_.align = NIM_ALIGNOF(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg);
NTImodulegraph58objecttype__nOSrcYqJTxXt2ptNc0gnWg_.kind = 18;
NTImodulegraph58objecttype__nOSrcYqJTxXt2ptNc0gnWg_.base = 0;
NTImodulegraph58objecttype__nOSrcYqJTxXt2ptNc0gnWg_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_2_49[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[1];
NTIiface__4y9aWdJBxraQYTl5Pa1NMuQ_.size = sizeof(tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ);
NTIiface__4y9aWdJBxraQYTl5Pa1NMuQ_.align = NIM_ALIGNOF(tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ);
NTIiface__4y9aWdJBxraQYTl5Pa1NMuQ_.kind = 18;
NTIiface__4y9aWdJBxraQYTl5Pa1NMuQ_.base = 0;
NTIiface__4y9aWdJBxraQYTl5Pa1NMuQ_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_3_7[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[3];
TM__mff0c158N4EFFNgrs4pcEQ_0[3].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[3].offset = offsetof(tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ, module);
TM__mff0c158N4EFFNgrs4pcEQ_0[3].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[3].name = "module";
TM__mff0c158N4EFFNgrs4pcEQ_3_7[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[4];
NTIlazysym__Xts9a2Mw4b4jtq73p6MrfJg_.size = sizeof(tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg);
NTIlazysym__Xts9a2Mw4b4jtq73p6MrfJg_.align = NIM_ALIGNOF(tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg);
NTIlazysym__Xts9a2Mw4b4jtq73p6MrfJg_.kind = 18;
NTIlazysym__Xts9a2Mw4b4jtq73p6MrfJg_.base = 0;
NTIlazysym__Xts9a2Mw4b4jtq73p6MrfJg_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_4_2[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[6];
NTIfullid__L64puUgQnoQ6OMvT9c6V9cPg_.size = sizeof(tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg);
NTIfullid__L64puUgQnoQ6OMvT9c6V9cPg_.align = NIM_ALIGNOF(tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg);
NTIfullid__L64puUgQnoQ6OMvT9c6V9cPg_.kind = 18;
NTIfullid__L64puUgQnoQ6OMvT9c6V9cPg_.base = 0;
NTIfullid__L64puUgQnoQ6OMvT9c6V9cPg_.flags = 3;
TM__mff0c158N4EFFNgrs4pcEQ_5_2[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[8];
TM__mff0c158N4EFFNgrs4pcEQ_0[8].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[8].offset = offsetof(tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg, module);
TM__mff0c158N4EFFNgrs4pcEQ_0[8].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[8].name = "module";
TM__mff0c158N4EFFNgrs4pcEQ_5_2[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[9];
TM__mff0c158N4EFFNgrs4pcEQ_0[9].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[9].offset = offsetof(tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg, packed_0);
TM__mff0c158N4EFFNgrs4pcEQ_0[9].typ = (&NTIpackeditemid__QkYBSICiQaMI6SmH4FJVoQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[9].name = "packed";
TM__mff0c158N4EFFNgrs4pcEQ_0[7].len = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[7].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[7].sons = &TM__mff0c158N4EFFNgrs4pcEQ_5_2[0];
NTIfullid__L64puUgQnoQ6OMvT9c6V9cPg_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[7];
TM__mff0c158N4EFFNgrs4pcEQ_0[6].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[6].offset = offsetof(tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg, id);
TM__mff0c158N4EFFNgrs4pcEQ_0[6].typ = (&NTIfullid__L64puUgQnoQ6OMvT9c6V9cPg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[6].name = "id";
TM__mff0c158N4EFFNgrs4pcEQ_4_2[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[10];
TM__mff0c158N4EFFNgrs4pcEQ_0[10].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[10].offset = offsetof(tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg, sym);
TM__mff0c158N4EFFNgrs4pcEQ_0[10].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[10].name = "sym";
TM__mff0c158N4EFFNgrs4pcEQ_0[5].len = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[5].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[5].sons = &TM__mff0c158N4EFFNgrs4pcEQ_4_2[0];
NTIlazysym__Xts9a2Mw4b4jtq73p6MrfJg_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[5];
NTIseqLlazysymT__qeAsXh2i1GAL5Nl0g3OP8g_.size = sizeof(tySequence__qeAsXh2i1GAL5Nl0g3OP8g*);
NTIseqLlazysymT__qeAsXh2i1GAL5Nl0g3OP8g_.align = NIM_ALIGNOF(tySequence__qeAsXh2i1GAL5Nl0g3OP8g*);
NTIseqLlazysymT__qeAsXh2i1GAL5Nl0g3OP8g_.kind = 24;
NTIseqLlazysymT__qeAsXh2i1GAL5Nl0g3OP8g_.base = (&NTIlazysym__Xts9a2Mw4b4jtq73p6MrfJg_);
NTIseqLlazysymT__qeAsXh2i1GAL5Nl0g3OP8g_.flags = 2;
NTIseqLlazysymT__qeAsXh2i1GAL5Nl0g3OP8g_.marker = Marker_tySequence__qeAsXh2i1GAL5Nl0g3OP8g;
TM__mff0c158N4EFFNgrs4pcEQ_0[4].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[4].offset = offsetof(tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ, converters);
TM__mff0c158N4EFFNgrs4pcEQ_0[4].typ = (&NTIseqLlazysymT__qeAsXh2i1GAL5Nl0g3OP8g_);
TM__mff0c158N4EFFNgrs4pcEQ_0[4].name = "converters";
TM__mff0c158N4EFFNgrs4pcEQ_3_7[2] = &TM__mff0c158N4EFFNgrs4pcEQ_0[11];
TM__mff0c158N4EFFNgrs4pcEQ_0[11].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[11].offset = offsetof(tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ, patterns);
TM__mff0c158N4EFFNgrs4pcEQ_0[11].typ = (&NTIseqLlazysymT__qeAsXh2i1GAL5Nl0g3OP8g_);
TM__mff0c158N4EFFNgrs4pcEQ_0[11].name = "patterns";
TM__mff0c158N4EFFNgrs4pcEQ_3_7[3] = &TM__mff0c158N4EFFNgrs4pcEQ_0[12];
TM__mff0c158N4EFFNgrs4pcEQ_0[12].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[12].offset = offsetof(tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ, pureEnums);
TM__mff0c158N4EFFNgrs4pcEQ_0[12].typ = (&NTIseqLlazysymT__qeAsXh2i1GAL5Nl0g3OP8g_);
TM__mff0c158N4EFFNgrs4pcEQ_0[12].name = "pureEnums";
TM__mff0c158N4EFFNgrs4pcEQ_3_7[4] = &TM__mff0c158N4EFFNgrs4pcEQ_0[13];
TM__mff0c158N4EFFNgrs4pcEQ_0[13].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[13].offset = offsetof(tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ, interf);
TM__mff0c158N4EFFNgrs4pcEQ_0[13].typ = (&NTItstrtable__CJQ42V2zij8fd39a9aMiwtZw_);
TM__mff0c158N4EFFNgrs4pcEQ_0[13].name = "interf";
TM__mff0c158N4EFFNgrs4pcEQ_3_7[5] = &TM__mff0c158N4EFFNgrs4pcEQ_0[14];
TM__mff0c158N4EFFNgrs4pcEQ_0[14].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[14].offset = offsetof(tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ, interfHidden);
TM__mff0c158N4EFFNgrs4pcEQ_0[14].typ = (&NTItstrtable__CJQ42V2zij8fd39a9aMiwtZw_);
TM__mff0c158N4EFFNgrs4pcEQ_0[14].name = "interfHidden";
TM__mff0c158N4EFFNgrs4pcEQ_3_7[6] = &TM__mff0c158N4EFFNgrs4pcEQ_0[15];
TM__mff0c158N4EFFNgrs4pcEQ_0[15].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[15].offset = offsetof(tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ, uniqueName);
TM__mff0c158N4EFFNgrs4pcEQ_0[15].typ = (&NTIrope__Ylz2qJFHq2oxQcAA5BJOQg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[15].name = "uniqueName";
TM__mff0c158N4EFFNgrs4pcEQ_0[2].len = 7; TM__mff0c158N4EFFNgrs4pcEQ_0[2].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[2].sons = &TM__mff0c158N4EFFNgrs4pcEQ_3_7[0];
NTIiface__4y9aWdJBxraQYTl5Pa1NMuQ_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[2];
NTIseqLifaceT__RNhZxf20g9beyq5VBOGxhDg_.size = sizeof(tySequence__RNhZxf20g9beyq5VBOGxhDg*);
NTIseqLifaceT__RNhZxf20g9beyq5VBOGxhDg_.align = NIM_ALIGNOF(tySequence__RNhZxf20g9beyq5VBOGxhDg*);
NTIseqLifaceT__RNhZxf20g9beyq5VBOGxhDg_.kind = 24;
NTIseqLifaceT__RNhZxf20g9beyq5VBOGxhDg_.base = (&NTIiface__4y9aWdJBxraQYTl5Pa1NMuQ_);
NTIseqLifaceT__RNhZxf20g9beyq5VBOGxhDg_.flags = 2;
NTIseqLifaceT__RNhZxf20g9beyq5VBOGxhDg_.marker = Marker_tySequence__RNhZxf20g9beyq5VBOGxhDg;
TM__mff0c158N4EFFNgrs4pcEQ_0[1].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[1].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, ifaces);
TM__mff0c158N4EFFNgrs4pcEQ_0[1].typ = (&NTIseqLifaceT__RNhZxf20g9beyq5VBOGxhDg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[1].name = "ifaces";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[16];
TM__mff0c158N4EFFNgrs4pcEQ_0[16].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[16].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, packed_0);
TM__mff0c158N4EFFNgrs4pcEQ_0[16].typ = (&NTIpackedmodulegraph__JbK5aK9aVhc9cJZzQYg1wQlQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[16].name = "packed";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[2] = &TM__mff0c158N4EFFNgrs4pcEQ_0[17];
NTIseqLpackedencoderT__lFbCtu5P2Kf7YDYtGjkxAQ_.size = sizeof(tySequence__lFbCtu5P2Kf7YDYtGjkxAQ*);
NTIseqLpackedencoderT__lFbCtu5P2Kf7YDYtGjkxAQ_.align = NIM_ALIGNOF(tySequence__lFbCtu5P2Kf7YDYtGjkxAQ*);
NTIseqLpackedencoderT__lFbCtu5P2Kf7YDYtGjkxAQ_.kind = 24;
NTIseqLpackedencoderT__lFbCtu5P2Kf7YDYtGjkxAQ_.base = (&NTIpackedencoder__ftUl9bxYRlbT5ToKkxHdbfQ_);
NTIseqLpackedencoderT__lFbCtu5P2Kf7YDYtGjkxAQ_.flags = 2;
NTIseqLpackedencoderT__lFbCtu5P2Kf7YDYtGjkxAQ_.marker = Marker_tySequence__lFbCtu5P2Kf7YDYtGjkxAQ;
TM__mff0c158N4EFFNgrs4pcEQ_0[17].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[17].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, encoders);
TM__mff0c158N4EFFNgrs4pcEQ_0[17].typ = (&NTIseqLpackedencoderT__lFbCtu5P2Kf7YDYtGjkxAQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[17].name = "encoders";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[3] = &TM__mff0c158N4EFFNgrs4pcEQ_0[18];
NTItable__nODIJ5l6JnEl9a6LYuqISLA_.size = sizeof(tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA);
NTItable__nODIJ5l6JnEl9a6LYuqISLA_.align = NIM_ALIGNOF(tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA);
NTItable__nODIJ5l6JnEl9a6LYuqISLA_.kind = 18;
NTItable__nODIJ5l6JnEl9a6LYuqISLA_.base = 0;
NTItable__nODIJ5l6JnEl9a6LYuqISLA_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_6_2[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[20];
NTIkeyvaluepair__UluY8x0Nj6cp9b0o88wJ0lg_.size = sizeof(tyTuple__UluY8x0Nj6cp9b0o88wJ0lg);
NTIkeyvaluepair__UluY8x0Nj6cp9b0o88wJ0lg_.align = NIM_ALIGNOF(tyTuple__UluY8x0Nj6cp9b0o88wJ0lg);
NTIkeyvaluepair__UluY8x0Nj6cp9b0o88wJ0lg_.kind = 18;
NTIkeyvaluepair__UluY8x0Nj6cp9b0o88wJ0lg_.base = 0;
NTIkeyvaluepair__UluY8x0Nj6cp9b0o88wJ0lg_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_7_3[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[22];
TM__mff0c158N4EFFNgrs4pcEQ_0[22].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[22].offset = offsetof(tyTuple__UluY8x0Nj6cp9b0o88wJ0lg, Field0);
TM__mff0c158N4EFFNgrs4pcEQ_0[22].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[22].name = "Field0";
TM__mff0c158N4EFFNgrs4pcEQ_7_3[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[23];
TM__mff0c158N4EFFNgrs4pcEQ_0[23].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[23].offset = offsetof(tyTuple__UluY8x0Nj6cp9b0o88wJ0lg, Field1);
TM__mff0c158N4EFFNgrs4pcEQ_0[23].typ = (&NTIitemid__wg9aowaxscbUe2F0nV9btZLg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[23].name = "Field1";
TM__mff0c158N4EFFNgrs4pcEQ_7_3[2] = &TM__mff0c158N4EFFNgrs4pcEQ_0[24];
NTIlazytype__wgv9a1JCOBXm9azerxcvz5gQ_.size = sizeof(tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ);
NTIlazytype__wgv9a1JCOBXm9azerxcvz5gQ_.align = NIM_ALIGNOF(tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ);
NTIlazytype__wgv9a1JCOBXm9azerxcvz5gQ_.kind = 18;
NTIlazytype__wgv9a1JCOBXm9azerxcvz5gQ_.base = 0;
NTIlazytype__wgv9a1JCOBXm9azerxcvz5gQ_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_8_2[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[26];
TM__mff0c158N4EFFNgrs4pcEQ_0[26].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[26].offset = offsetof(tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ, id);
TM__mff0c158N4EFFNgrs4pcEQ_0[26].typ = (&NTIfullid__L64puUgQnoQ6OMvT9c6V9cPg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[26].name = "id";
TM__mff0c158N4EFFNgrs4pcEQ_8_2[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[27];
TM__mff0c158N4EFFNgrs4pcEQ_0[27].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[27].offset = offsetof(tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ, typ);
TM__mff0c158N4EFFNgrs4pcEQ_0[27].typ = (&NTIptype__q1v0zzhoMWrhMLs6UEp1IA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[27].name = "typ";
TM__mff0c158N4EFFNgrs4pcEQ_0[25].len = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[25].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[25].sons = &TM__mff0c158N4EFFNgrs4pcEQ_8_2[0];
NTIlazytype__wgv9a1JCOBXm9azerxcvz5gQ_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[25];
NTIseqLlazytypeT__dlD6tEGzYLLpKVq3XwuFlA_.size = sizeof(tySequence__dlD6tEGzYLLpKVq3XwuFlA*);
NTIseqLlazytypeT__dlD6tEGzYLLpKVq3XwuFlA_.align = NIM_ALIGNOF(tySequence__dlD6tEGzYLLpKVq3XwuFlA*);
NTIseqLlazytypeT__dlD6tEGzYLLpKVq3XwuFlA_.kind = 24;
NTIseqLlazytypeT__dlD6tEGzYLLpKVq3XwuFlA_.base = (&NTIlazytype__wgv9a1JCOBXm9azerxcvz5gQ_);
NTIseqLlazytypeT__dlD6tEGzYLLpKVq3XwuFlA_.flags = 2;
NTIseqLlazytypeT__dlD6tEGzYLLpKVq3XwuFlA_.marker = Marker_tySequence__dlD6tEGzYLLpKVq3XwuFlA;
TM__mff0c158N4EFFNgrs4pcEQ_0[24].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[24].offset = offsetof(tyTuple__UluY8x0Nj6cp9b0o88wJ0lg, Field2);
TM__mff0c158N4EFFNgrs4pcEQ_0[24].typ = (&NTIseqLlazytypeT__dlD6tEGzYLLpKVq3XwuFlA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[24].name = "Field2";
TM__mff0c158N4EFFNgrs4pcEQ_0[21].len = 3; TM__mff0c158N4EFFNgrs4pcEQ_0[21].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[21].sons = &TM__mff0c158N4EFFNgrs4pcEQ_7_3[0];
NTIkeyvaluepair__UluY8x0Nj6cp9b0o88wJ0lg_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[21];
NTIkeyvaluepairseq__ijtae5OneaLys0hN9alAicA_.size = sizeof(tySequence__ijtae5OneaLys0hN9alAicA*);
NTIkeyvaluepairseq__ijtae5OneaLys0hN9alAicA_.align = NIM_ALIGNOF(tySequence__ijtae5OneaLys0hN9alAicA*);
NTIkeyvaluepairseq__ijtae5OneaLys0hN9alAicA_.kind = 24;
NTIkeyvaluepairseq__ijtae5OneaLys0hN9alAicA_.base = (&NTIkeyvaluepair__UluY8x0Nj6cp9b0o88wJ0lg_);
NTIkeyvaluepairseq__ijtae5OneaLys0hN9alAicA_.flags = 2;
NTIkeyvaluepairseq__ijtae5OneaLys0hN9alAicA_.marker = Marker_tySequence__ijtae5OneaLys0hN9alAicA;
TM__mff0c158N4EFFNgrs4pcEQ_0[20].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[20].offset = offsetof(tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA, data);
TM__mff0c158N4EFFNgrs4pcEQ_0[20].typ = (&NTIkeyvaluepairseq__ijtae5OneaLys0hN9alAicA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[20].name = "data";
TM__mff0c158N4EFFNgrs4pcEQ_6_2[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[28];
TM__mff0c158N4EFFNgrs4pcEQ_0[28].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[28].offset = offsetof(tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA, counter);
TM__mff0c158N4EFFNgrs4pcEQ_0[28].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[28].name = "counter";
TM__mff0c158N4EFFNgrs4pcEQ_0[19].len = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[19].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[19].sons = &TM__mff0c158N4EFFNgrs4pcEQ_6_2[0];
NTItable__nODIJ5l6JnEl9a6LYuqISLA_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[19];
TM__mff0c158N4EFFNgrs4pcEQ_0[18].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[18].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, typeInstCache);
TM__mff0c158N4EFFNgrs4pcEQ_0[18].typ = (&NTItable__nODIJ5l6JnEl9a6LYuqISLA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[18].name = "typeInstCache";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[4] = &TM__mff0c158N4EFFNgrs4pcEQ_0[29];
NTItable__s3itmS9cUUFQ19alF7UA0T1w_.size = sizeof(tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w);
NTItable__s3itmS9cUUFQ19alF7UA0T1w_.align = NIM_ALIGNOF(tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w);
NTItable__s3itmS9cUUFQ19alF7UA0T1w_.kind = 18;
NTItable__s3itmS9cUUFQ19alF7UA0T1w_.base = 0;
NTItable__s3itmS9cUUFQ19alF7UA0T1w_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_9_2[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[31];
NTIkeyvaluepair__rZZA0skon1OsHdiEvT8RZQ_.size = sizeof(tyTuple__rZZA0skon1OsHdiEvT8RZQ);
NTIkeyvaluepair__rZZA0skon1OsHdiEvT8RZQ_.align = NIM_ALIGNOF(tyTuple__rZZA0skon1OsHdiEvT8RZQ);
NTIkeyvaluepair__rZZA0skon1OsHdiEvT8RZQ_.kind = 18;
NTIkeyvaluepair__rZZA0skon1OsHdiEvT8RZQ_.base = 0;
NTIkeyvaluepair__rZZA0skon1OsHdiEvT8RZQ_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_10_3[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[33];
TM__mff0c158N4EFFNgrs4pcEQ_0[33].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[33].offset = offsetof(tyTuple__rZZA0skon1OsHdiEvT8RZQ, Field0);
TM__mff0c158N4EFFNgrs4pcEQ_0[33].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[33].name = "Field0";
TM__mff0c158N4EFFNgrs4pcEQ_10_3[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[34];
TM__mff0c158N4EFFNgrs4pcEQ_0[34].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[34].offset = offsetof(tyTuple__rZZA0skon1OsHdiEvT8RZQ, Field1);
TM__mff0c158N4EFFNgrs4pcEQ_0[34].typ = (&NTIitemid__wg9aowaxscbUe2F0nV9btZLg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[34].name = "Field1";
TM__mff0c158N4EFFNgrs4pcEQ_10_3[2] = &TM__mff0c158N4EFFNgrs4pcEQ_0[35];
NTIlazyinstantiation__0l1i6PfjQKnMEvpGMAoN8Q_.size = sizeof(tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q);
NTIlazyinstantiation__0l1i6PfjQKnMEvpGMAoN8Q_.align = NIM_ALIGNOF(tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q);
NTIlazyinstantiation__0l1i6PfjQKnMEvpGMAoN8Q_.kind = 18;
NTIlazyinstantiation__0l1i6PfjQKnMEvpGMAoN8Q_.base = 0;
NTIlazyinstantiation__0l1i6PfjQKnMEvpGMAoN8Q_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_11_4[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[37];
TM__mff0c158N4EFFNgrs4pcEQ_0[37].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[37].offset = offsetof(tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q, module);
TM__mff0c158N4EFFNgrs4pcEQ_0[37].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[37].name = "module";
TM__mff0c158N4EFFNgrs4pcEQ_11_4[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[38];
TM__mff0c158N4EFFNgrs4pcEQ_0[38].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[38].offset = offsetof(tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q, sym);
TM__mff0c158N4EFFNgrs4pcEQ_0[38].typ = (&NTIfullid__L64puUgQnoQ6OMvT9c6V9cPg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[38].name = "sym";
TM__mff0c158N4EFFNgrs4pcEQ_11_4[2] = &TM__mff0c158N4EFFNgrs4pcEQ_0[39];
NTIseqLfullidT__UnGSk9aaLosDroi2QDrlOfQ_.size = sizeof(tySequence__UnGSk9aaLosDroi2QDrlOfQ*);
NTIseqLfullidT__UnGSk9aaLosDroi2QDrlOfQ_.align = NIM_ALIGNOF(tySequence__UnGSk9aaLosDroi2QDrlOfQ*);
NTIseqLfullidT__UnGSk9aaLosDroi2QDrlOfQ_.kind = 24;
NTIseqLfullidT__UnGSk9aaLosDroi2QDrlOfQ_.base = (&NTIfullid__L64puUgQnoQ6OMvT9c6V9cPg_);
NTIseqLfullidT__UnGSk9aaLosDroi2QDrlOfQ_.flags = 2;
NTIseqLfullidT__UnGSk9aaLosDroi2QDrlOfQ_.marker = Marker_tySequence__UnGSk9aaLosDroi2QDrlOfQ;
TM__mff0c158N4EFFNgrs4pcEQ_0[39].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[39].offset = offsetof(tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q, concreteTypes);
TM__mff0c158N4EFFNgrs4pcEQ_0[39].typ = (&NTIseqLfullidT__UnGSk9aaLosDroi2QDrlOfQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[39].name = "concreteTypes";
TM__mff0c158N4EFFNgrs4pcEQ_11_4[3] = &TM__mff0c158N4EFFNgrs4pcEQ_0[40];
TM__mff0c158N4EFFNgrs4pcEQ_0[40].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[40].offset = offsetof(tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q, inst);
TM__mff0c158N4EFFNgrs4pcEQ_0[40].typ = (&NTIpinstantiation__eg8se9cZBHdzb5ZM7CrYNVg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[40].name = "inst";
TM__mff0c158N4EFFNgrs4pcEQ_0[36].len = 4; TM__mff0c158N4EFFNgrs4pcEQ_0[36].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[36].sons = &TM__mff0c158N4EFFNgrs4pcEQ_11_4[0];
NTIlazyinstantiation__0l1i6PfjQKnMEvpGMAoN8Q_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[36];
NTIseqLlazyinstantiationT__6OFCSvqRaxyEgUqWtnZSlw_.size = sizeof(tySequence__6OFCSvqRaxyEgUqWtnZSlw*);
NTIseqLlazyinstantiationT__6OFCSvqRaxyEgUqWtnZSlw_.align = NIM_ALIGNOF(tySequence__6OFCSvqRaxyEgUqWtnZSlw*);
NTIseqLlazyinstantiationT__6OFCSvqRaxyEgUqWtnZSlw_.kind = 24;
NTIseqLlazyinstantiationT__6OFCSvqRaxyEgUqWtnZSlw_.base = (&NTIlazyinstantiation__0l1i6PfjQKnMEvpGMAoN8Q_);
NTIseqLlazyinstantiationT__6OFCSvqRaxyEgUqWtnZSlw_.flags = 2;
NTIseqLlazyinstantiationT__6OFCSvqRaxyEgUqWtnZSlw_.marker = Marker_tySequence__6OFCSvqRaxyEgUqWtnZSlw;
TM__mff0c158N4EFFNgrs4pcEQ_0[35].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[35].offset = offsetof(tyTuple__rZZA0skon1OsHdiEvT8RZQ, Field2);
TM__mff0c158N4EFFNgrs4pcEQ_0[35].typ = (&NTIseqLlazyinstantiationT__6OFCSvqRaxyEgUqWtnZSlw_);
TM__mff0c158N4EFFNgrs4pcEQ_0[35].name = "Field2";
TM__mff0c158N4EFFNgrs4pcEQ_0[32].len = 3; TM__mff0c158N4EFFNgrs4pcEQ_0[32].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[32].sons = &TM__mff0c158N4EFFNgrs4pcEQ_10_3[0];
NTIkeyvaluepair__rZZA0skon1OsHdiEvT8RZQ_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[32];
NTIkeyvaluepairseq__SerjNoUujW2dUouVBrJiCw_.size = sizeof(tySequence__SerjNoUujW2dUouVBrJiCw*);
NTIkeyvaluepairseq__SerjNoUujW2dUouVBrJiCw_.align = NIM_ALIGNOF(tySequence__SerjNoUujW2dUouVBrJiCw*);
NTIkeyvaluepairseq__SerjNoUujW2dUouVBrJiCw_.kind = 24;
NTIkeyvaluepairseq__SerjNoUujW2dUouVBrJiCw_.base = (&NTIkeyvaluepair__rZZA0skon1OsHdiEvT8RZQ_);
NTIkeyvaluepairseq__SerjNoUujW2dUouVBrJiCw_.flags = 2;
NTIkeyvaluepairseq__SerjNoUujW2dUouVBrJiCw_.marker = Marker_tySequence__SerjNoUujW2dUouVBrJiCw;
TM__mff0c158N4EFFNgrs4pcEQ_0[31].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[31].offset = offsetof(tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w, data);
TM__mff0c158N4EFFNgrs4pcEQ_0[31].typ = (&NTIkeyvaluepairseq__SerjNoUujW2dUouVBrJiCw_);
TM__mff0c158N4EFFNgrs4pcEQ_0[31].name = "data";
TM__mff0c158N4EFFNgrs4pcEQ_9_2[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[41];
TM__mff0c158N4EFFNgrs4pcEQ_0[41].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[41].offset = offsetof(tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w, counter);
TM__mff0c158N4EFFNgrs4pcEQ_0[41].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[41].name = "counter";
TM__mff0c158N4EFFNgrs4pcEQ_0[30].len = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[30].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[30].sons = &TM__mff0c158N4EFFNgrs4pcEQ_9_2[0];
NTItable__s3itmS9cUUFQ19alF7UA0T1w_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[30];
TM__mff0c158N4EFFNgrs4pcEQ_0[29].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[29].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, procInstCache);
TM__mff0c158N4EFFNgrs4pcEQ_0[29].typ = (&NTItable__s3itmS9cUUFQ19alF7UA0T1w_);
TM__mff0c158N4EFFNgrs4pcEQ_0[29].name = "procInstCache";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[5] = &TM__mff0c158N4EFFNgrs4pcEQ_0[42];
NTItable__r0v8BdcBPKhl73K8p2VMUA_.size = sizeof(tyObject_Table__r0v8BdcBPKhl73K8p2VMUA);
NTItable__r0v8BdcBPKhl73K8p2VMUA_.align = NIM_ALIGNOF(tyObject_Table__r0v8BdcBPKhl73K8p2VMUA);
NTItable__r0v8BdcBPKhl73K8p2VMUA_.kind = 18;
NTItable__r0v8BdcBPKhl73K8p2VMUA_.base = 0;
NTItable__r0v8BdcBPKhl73K8p2VMUA_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_12_2[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[44];
NTIkeyvaluepair__q13Zt16VkCqu6Zg5jWqwHA_.size = sizeof(tyTuple__q13Zt16VkCqu6Zg5jWqwHA);
NTIkeyvaluepair__q13Zt16VkCqu6Zg5jWqwHA_.align = NIM_ALIGNOF(tyTuple__q13Zt16VkCqu6Zg5jWqwHA);
NTIkeyvaluepair__q13Zt16VkCqu6Zg5jWqwHA_.kind = 18;
NTIkeyvaluepair__q13Zt16VkCqu6Zg5jWqwHA_.base = 0;
NTIkeyvaluepair__q13Zt16VkCqu6Zg5jWqwHA_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_13_3[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[46];
TM__mff0c158N4EFFNgrs4pcEQ_0[46].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[46].offset = offsetof(tyTuple__q13Zt16VkCqu6Zg5jWqwHA, Field0);
TM__mff0c158N4EFFNgrs4pcEQ_0[46].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[46].name = "Field0";
TM__mff0c158N4EFFNgrs4pcEQ_13_3[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[47];
TM__mff0c158N4EFFNgrs4pcEQ_0[47].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[47].offset = offsetof(tyTuple__q13Zt16VkCqu6Zg5jWqwHA, Field1);
TM__mff0c158N4EFFNgrs4pcEQ_0[47].typ = (&NTIitemid__wg9aowaxscbUe2F0nV9btZLg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[47].name = "Field1";
TM__mff0c158N4EFFNgrs4pcEQ_13_3[2] = &TM__mff0c158N4EFFNgrs4pcEQ_0[48];
TM__mff0c158N4EFFNgrs4pcEQ_0[48].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[48].offset = offsetof(tyTuple__q13Zt16VkCqu6Zg5jWqwHA, Field2);
TM__mff0c158N4EFFNgrs4pcEQ_0[48].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[48].name = "Field2";
TM__mff0c158N4EFFNgrs4pcEQ_0[45].len = 3; TM__mff0c158N4EFFNgrs4pcEQ_0[45].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[45].sons = &TM__mff0c158N4EFFNgrs4pcEQ_13_3[0];
NTIkeyvaluepair__q13Zt16VkCqu6Zg5jWqwHA_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[45];
NTIkeyvaluepairseq__K9agbtcb0qPZuSJFXB9cTe6g_.size = sizeof(tySequence__K9agbtcb0qPZuSJFXB9cTe6g*);
NTIkeyvaluepairseq__K9agbtcb0qPZuSJFXB9cTe6g_.align = NIM_ALIGNOF(tySequence__K9agbtcb0qPZuSJFXB9cTe6g*);
NTIkeyvaluepairseq__K9agbtcb0qPZuSJFXB9cTe6g_.kind = 24;
NTIkeyvaluepairseq__K9agbtcb0qPZuSJFXB9cTe6g_.base = (&NTIkeyvaluepair__q13Zt16VkCqu6Zg5jWqwHA_);
NTIkeyvaluepairseq__K9agbtcb0qPZuSJFXB9cTe6g_.flags = 2;
NTIkeyvaluepairseq__K9agbtcb0qPZuSJFXB9cTe6g_.marker = Marker_tySequence__K9agbtcb0qPZuSJFXB9cTe6g;
TM__mff0c158N4EFFNgrs4pcEQ_0[44].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[44].offset = offsetof(tyObject_Table__r0v8BdcBPKhl73K8p2VMUA, data);
TM__mff0c158N4EFFNgrs4pcEQ_0[44].typ = (&NTIkeyvaluepairseq__K9agbtcb0qPZuSJFXB9cTe6g_);
TM__mff0c158N4EFFNgrs4pcEQ_0[44].name = "data";
TM__mff0c158N4EFFNgrs4pcEQ_12_2[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[49];
TM__mff0c158N4EFFNgrs4pcEQ_0[49].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[49].offset = offsetof(tyObject_Table__r0v8BdcBPKhl73K8p2VMUA, counter);
TM__mff0c158N4EFFNgrs4pcEQ_0[49].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[49].name = "counter";
TM__mff0c158N4EFFNgrs4pcEQ_0[43].len = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[43].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[43].sons = &TM__mff0c158N4EFFNgrs4pcEQ_12_2[0];
NTItable__r0v8BdcBPKhl73K8p2VMUA_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[43];
NTIarrayLttypeattachedop_tableLastOitemid_astOpsymTT__46hjIasL27aUz9c7kgtWooQ_.size = sizeof(tyArray__46hjIasL27aUz9c7kgtWooQ);
NTIarrayLttypeattachedop_tableLastOitemid_astOpsymTT__46hjIasL27aUz9c7kgtWooQ_.align = NIM_ALIGNOF(tyArray__46hjIasL27aUz9c7kgtWooQ);
NTIarrayLttypeattachedop_tableLastOitemid_astOpsymTT__46hjIasL27aUz9c7kgtWooQ_.kind = 16;
NTIarrayLttypeattachedop_tableLastOitemid_astOpsymTT__46hjIasL27aUz9c7kgtWooQ_.base = (&NTItable__r0v8BdcBPKhl73K8p2VMUA_);
NTIarrayLttypeattachedop_tableLastOitemid_astOpsymTT__46hjIasL27aUz9c7kgtWooQ_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_0[42].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[42].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, attachedOps);
TM__mff0c158N4EFFNgrs4pcEQ_0[42].typ = (&NTIarrayLttypeattachedop_tableLastOitemid_astOpsymTT__46hjIasL27aUz9c7kgtWooQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[42].name = "attachedOps";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[6] = &TM__mff0c158N4EFFNgrs4pcEQ_0[50];
NTItable__KsPP7K7LW9aa3YAq1XN9cDZg_.size = sizeof(tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg);
NTItable__KsPP7K7LW9aa3YAq1XN9cDZg_.align = NIM_ALIGNOF(tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg);
NTItable__KsPP7K7LW9aa3YAq1XN9cDZg_.kind = 18;
NTItable__KsPP7K7LW9aa3YAq1XN9cDZg_.base = 0;
NTItable__KsPP7K7LW9aa3YAq1XN9cDZg_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_14_2[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[52];
NTIkeyvaluepair__aWN9bNzF9bubXNJV9ciomgpfA_.size = sizeof(tyTuple__aWN9bNzF9bubXNJV9ciomgpfA);
NTIkeyvaluepair__aWN9bNzF9bubXNJV9ciomgpfA_.align = NIM_ALIGNOF(tyTuple__aWN9bNzF9bubXNJV9ciomgpfA);
NTIkeyvaluepair__aWN9bNzF9bubXNJV9ciomgpfA_.kind = 18;
NTIkeyvaluepair__aWN9bNzF9bubXNJV9ciomgpfA_.base = 0;
NTIkeyvaluepair__aWN9bNzF9bubXNJV9ciomgpfA_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_15_3[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[54];
TM__mff0c158N4EFFNgrs4pcEQ_0[54].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[54].offset = offsetof(tyTuple__aWN9bNzF9bubXNJV9ciomgpfA, Field0);
TM__mff0c158N4EFFNgrs4pcEQ_0[54].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[54].name = "Field0";
TM__mff0c158N4EFFNgrs4pcEQ_15_3[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[55];
TM__mff0c158N4EFFNgrs4pcEQ_0[55].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[55].offset = offsetof(tyTuple__aWN9bNzF9bubXNJV9ciomgpfA, Field1);
TM__mff0c158N4EFFNgrs4pcEQ_0[55].typ = (&NTIitemid__wg9aowaxscbUe2F0nV9btZLg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[55].name = "Field1";
TM__mff0c158N4EFFNgrs4pcEQ_15_3[2] = &TM__mff0c158N4EFFNgrs4pcEQ_0[56];
NTILint_lazysymT__RWXAsQlFoGYyEQZp1G65sg_.size = sizeof(tyTuple__RWXAsQlFoGYyEQZp1G65sg);
NTILint_lazysymT__RWXAsQlFoGYyEQZp1G65sg_.align = NIM_ALIGNOF(tyTuple__RWXAsQlFoGYyEQZp1G65sg);
NTILint_lazysymT__RWXAsQlFoGYyEQZp1G65sg_.kind = 18;
NTILint_lazysymT__RWXAsQlFoGYyEQZp1G65sg_.base = 0;
NTILint_lazysymT__RWXAsQlFoGYyEQZp1G65sg_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_16_2[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[58];
TM__mff0c158N4EFFNgrs4pcEQ_0[58].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[58].offset = offsetof(tyTuple__RWXAsQlFoGYyEQZp1G65sg, Field0);
TM__mff0c158N4EFFNgrs4pcEQ_0[58].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[58].name = "Field0";
TM__mff0c158N4EFFNgrs4pcEQ_16_2[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[59];
TM__mff0c158N4EFFNgrs4pcEQ_0[59].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[59].offset = offsetof(tyTuple__RWXAsQlFoGYyEQZp1G65sg, Field1);
TM__mff0c158N4EFFNgrs4pcEQ_0[59].typ = (&NTIlazysym__Xts9a2Mw4b4jtq73p6MrfJg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[59].name = "Field1";
TM__mff0c158N4EFFNgrs4pcEQ_0[57].len = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[57].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[57].sons = &TM__mff0c158N4EFFNgrs4pcEQ_16_2[0];
NTILint_lazysymT__RWXAsQlFoGYyEQZp1G65sg_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[57];
NTIseqLLint_lazysymTT__m4PVWjcAAjfxlwJxLkKn8A_.size = sizeof(tySequence__m4PVWjcAAjfxlwJxLkKn8A*);
NTIseqLLint_lazysymTT__m4PVWjcAAjfxlwJxLkKn8A_.align = NIM_ALIGNOF(tySequence__m4PVWjcAAjfxlwJxLkKn8A*);
NTIseqLLint_lazysymTT__m4PVWjcAAjfxlwJxLkKn8A_.kind = 24;
NTIseqLLint_lazysymTT__m4PVWjcAAjfxlwJxLkKn8A_.base = (&NTILint_lazysymT__RWXAsQlFoGYyEQZp1G65sg_);
NTIseqLLint_lazysymTT__m4PVWjcAAjfxlwJxLkKn8A_.flags = 2;
NTIseqLLint_lazysymTT__m4PVWjcAAjfxlwJxLkKn8A_.marker = Marker_tySequence__m4PVWjcAAjfxlwJxLkKn8A;
TM__mff0c158N4EFFNgrs4pcEQ_0[56].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[56].offset = offsetof(tyTuple__aWN9bNzF9bubXNJV9ciomgpfA, Field2);
TM__mff0c158N4EFFNgrs4pcEQ_0[56].typ = (&NTIseqLLint_lazysymTT__m4PVWjcAAjfxlwJxLkKn8A_);
TM__mff0c158N4EFFNgrs4pcEQ_0[56].name = "Field2";
TM__mff0c158N4EFFNgrs4pcEQ_0[53].len = 3; TM__mff0c158N4EFFNgrs4pcEQ_0[53].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[53].sons = &TM__mff0c158N4EFFNgrs4pcEQ_15_3[0];
NTIkeyvaluepair__aWN9bNzF9bubXNJV9ciomgpfA_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[53];
NTIkeyvaluepairseq__m88qdML9cQOuqGAQn6XWL1A_.size = sizeof(tySequence__m88qdML9cQOuqGAQn6XWL1A*);
NTIkeyvaluepairseq__m88qdML9cQOuqGAQn6XWL1A_.align = NIM_ALIGNOF(tySequence__m88qdML9cQOuqGAQn6XWL1A*);
NTIkeyvaluepairseq__m88qdML9cQOuqGAQn6XWL1A_.kind = 24;
NTIkeyvaluepairseq__m88qdML9cQOuqGAQn6XWL1A_.base = (&NTIkeyvaluepair__aWN9bNzF9bubXNJV9ciomgpfA_);
NTIkeyvaluepairseq__m88qdML9cQOuqGAQn6XWL1A_.flags = 2;
NTIkeyvaluepairseq__m88qdML9cQOuqGAQn6XWL1A_.marker = Marker_tySequence__m88qdML9cQOuqGAQn6XWL1A;
TM__mff0c158N4EFFNgrs4pcEQ_0[52].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[52].offset = offsetof(tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg, data);
TM__mff0c158N4EFFNgrs4pcEQ_0[52].typ = (&NTIkeyvaluepairseq__m88qdML9cQOuqGAQn6XWL1A_);
TM__mff0c158N4EFFNgrs4pcEQ_0[52].name = "data";
TM__mff0c158N4EFFNgrs4pcEQ_14_2[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[60];
TM__mff0c158N4EFFNgrs4pcEQ_0[60].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[60].offset = offsetof(tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg, counter);
TM__mff0c158N4EFFNgrs4pcEQ_0[60].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[60].name = "counter";
TM__mff0c158N4EFFNgrs4pcEQ_0[51].len = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[51].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[51].sons = &TM__mff0c158N4EFFNgrs4pcEQ_14_2[0];
NTItable__KsPP7K7LW9aa3YAq1XN9cDZg_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[51];
TM__mff0c158N4EFFNgrs4pcEQ_0[50].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[50].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, methodsPerType);
TM__mff0c158N4EFFNgrs4pcEQ_0[50].typ = (&NTItable__KsPP7K7LW9aa3YAq1XN9cDZg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[50].name = "methodsPerType";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[7] = &TM__mff0c158N4EFFNgrs4pcEQ_0[61];
NTItable__1hIWbTQWYT4BmhdESze57A_.size = sizeof(tyObject_Table__1hIWbTQWYT4BmhdESze57A);
NTItable__1hIWbTQWYT4BmhdESze57A_.align = NIM_ALIGNOF(tyObject_Table__1hIWbTQWYT4BmhdESze57A);
NTItable__1hIWbTQWYT4BmhdESze57A_.kind = 18;
NTItable__1hIWbTQWYT4BmhdESze57A_.base = 0;
NTItable__1hIWbTQWYT4BmhdESze57A_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_17_2[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[63];
NTIkeyvaluepair__RmGJuqOgEaHckHndh0LEsw_.size = sizeof(tyTuple__RmGJuqOgEaHckHndh0LEsw);
NTIkeyvaluepair__RmGJuqOgEaHckHndh0LEsw_.align = NIM_ALIGNOF(tyTuple__RmGJuqOgEaHckHndh0LEsw);
NTIkeyvaluepair__RmGJuqOgEaHckHndh0LEsw_.kind = 18;
NTIkeyvaluepair__RmGJuqOgEaHckHndh0LEsw_.base = 0;
NTIkeyvaluepair__RmGJuqOgEaHckHndh0LEsw_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_18_3[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[65];
TM__mff0c158N4EFFNgrs4pcEQ_0[65].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[65].offset = offsetof(tyTuple__RmGJuqOgEaHckHndh0LEsw, Field0);
TM__mff0c158N4EFFNgrs4pcEQ_0[65].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[65].name = "Field0";
TM__mff0c158N4EFFNgrs4pcEQ_18_3[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[66];
TM__mff0c158N4EFFNgrs4pcEQ_0[66].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[66].offset = offsetof(tyTuple__RmGJuqOgEaHckHndh0LEsw, Field1);
TM__mff0c158N4EFFNgrs4pcEQ_0[66].typ = (&NTIitemid__wg9aowaxscbUe2F0nV9btZLg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[66].name = "Field1";
TM__mff0c158N4EFFNgrs4pcEQ_18_3[2] = &TM__mff0c158N4EFFNgrs4pcEQ_0[67];
TM__mff0c158N4EFFNgrs4pcEQ_0[67].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[67].offset = offsetof(tyTuple__RmGJuqOgEaHckHndh0LEsw, Field2);
TM__mff0c158N4EFFNgrs4pcEQ_0[67].typ = (&NTIlazysym__Xts9a2Mw4b4jtq73p6MrfJg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[67].name = "Field2";
TM__mff0c158N4EFFNgrs4pcEQ_0[64].len = 3; TM__mff0c158N4EFFNgrs4pcEQ_0[64].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[64].sons = &TM__mff0c158N4EFFNgrs4pcEQ_18_3[0];
NTIkeyvaluepair__RmGJuqOgEaHckHndh0LEsw_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[64];
NTIkeyvaluepairseq__naEbXEp9b9aiW1zXJorqf9cXQ_.size = sizeof(tySequence__naEbXEp9b9aiW1zXJorqf9cXQ*);
NTIkeyvaluepairseq__naEbXEp9b9aiW1zXJorqf9cXQ_.align = NIM_ALIGNOF(tySequence__naEbXEp9b9aiW1zXJorqf9cXQ*);
NTIkeyvaluepairseq__naEbXEp9b9aiW1zXJorqf9cXQ_.kind = 24;
NTIkeyvaluepairseq__naEbXEp9b9aiW1zXJorqf9cXQ_.base = (&NTIkeyvaluepair__RmGJuqOgEaHckHndh0LEsw_);
NTIkeyvaluepairseq__naEbXEp9b9aiW1zXJorqf9cXQ_.flags = 2;
NTIkeyvaluepairseq__naEbXEp9b9aiW1zXJorqf9cXQ_.marker = Marker_tySequence__naEbXEp9b9aiW1zXJorqf9cXQ;
TM__mff0c158N4EFFNgrs4pcEQ_0[63].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[63].offset = offsetof(tyObject_Table__1hIWbTQWYT4BmhdESze57A, data);
TM__mff0c158N4EFFNgrs4pcEQ_0[63].typ = (&NTIkeyvaluepairseq__naEbXEp9b9aiW1zXJorqf9cXQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[63].name = "data";
TM__mff0c158N4EFFNgrs4pcEQ_17_2[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[68];
TM__mff0c158N4EFFNgrs4pcEQ_0[68].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[68].offset = offsetof(tyObject_Table__1hIWbTQWYT4BmhdESze57A, counter);
TM__mff0c158N4EFFNgrs4pcEQ_0[68].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[68].name = "counter";
TM__mff0c158N4EFFNgrs4pcEQ_0[62].len = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[62].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[62].sons = &TM__mff0c158N4EFFNgrs4pcEQ_17_2[0];
NTItable__1hIWbTQWYT4BmhdESze57A_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[62];
TM__mff0c158N4EFFNgrs4pcEQ_0[61].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[61].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, enumToStringProcs);
TM__mff0c158N4EFFNgrs4pcEQ_0[61].typ = (&NTItable__1hIWbTQWYT4BmhdESze57A_);
TM__mff0c158N4EFFNgrs4pcEQ_0[61].name = "enumToStringProcs";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[8] = &TM__mff0c158N4EFFNgrs4pcEQ_0[69];
TM__mff0c158N4EFFNgrs4pcEQ_0[69].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[69].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, emittedTypeInfo);
TM__mff0c158N4EFFNgrs4pcEQ_0[69].typ = (&NTItable__9cHFtxtpgztIcDsypRz9byKw_);
TM__mff0c158N4EFFNgrs4pcEQ_0[69].name = "emittedTypeInfo";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[9] = &TM__mff0c158N4EFFNgrs4pcEQ_0[70];
TM__mff0c158N4EFFNgrs4pcEQ_0[70].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[70].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, startupPackedConfig);
TM__mff0c158N4EFFNgrs4pcEQ_0[70].typ = (&NTIpackedconfig__aqQhF9bElTH51s7bVamv3vA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[70].name = "startupPackedConfig";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[10] = &TM__mff0c158N4EFFNgrs4pcEQ_0[71];
TM__mff0c158N4EFFNgrs4pcEQ_0[71].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[71].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, packageSyms);
TM__mff0c158N4EFFNgrs4pcEQ_0[71].typ = (&NTItstrtable__CJQ42V2zij8fd39a9aMiwtZw_);
TM__mff0c158N4EFFNgrs4pcEQ_0[71].name = "packageSyms";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[11] = &TM__mff0c158N4EFFNgrs4pcEQ_0[72];
TM__mff0c158N4EFFNgrs4pcEQ_0[72].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[72].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, deps);
TM__mff0c158N4EFFNgrs4pcEQ_0[72].typ = (&NTIpackedset__THXDbzJSs2hcC9a33en2pdw_);
TM__mff0c158N4EFFNgrs4pcEQ_0[72].name = "deps";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[12] = &TM__mff0c158N4EFFNgrs4pcEQ_0[73];
NTItable__imojfg883tkWsWJwyshGqQ_.size = sizeof(tyObject_Table__imojfg883tkWsWJwyshGqQ);
NTItable__imojfg883tkWsWJwyshGqQ_.align = NIM_ALIGNOF(tyObject_Table__imojfg883tkWsWJwyshGqQ);
NTItable__imojfg883tkWsWJwyshGqQ_.kind = 18;
NTItable__imojfg883tkWsWJwyshGqQ_.base = 0;
NTItable__imojfg883tkWsWJwyshGqQ_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_19_2[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[75];
NTIkeyvaluepair__1mtQ8sCEE7DbfIuQciv9b5Q_.size = sizeof(tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q);
NTIkeyvaluepair__1mtQ8sCEE7DbfIuQciv9b5Q_.align = NIM_ALIGNOF(tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q);
NTIkeyvaluepair__1mtQ8sCEE7DbfIuQciv9b5Q_.kind = 18;
NTIkeyvaluepair__1mtQ8sCEE7DbfIuQciv9b5Q_.base = 0;
NTIkeyvaluepair__1mtQ8sCEE7DbfIuQciv9b5Q_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_20_3[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[77];
TM__mff0c158N4EFFNgrs4pcEQ_0[77].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[77].offset = offsetof(tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q, Field0);
TM__mff0c158N4EFFNgrs4pcEQ_0[77].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[77].name = "Field0";
TM__mff0c158N4EFFNgrs4pcEQ_20_3[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[78];
TM__mff0c158N4EFFNgrs4pcEQ_0[78].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[78].offset = offsetof(tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q, Field1);
TM__mff0c158N4EFFNgrs4pcEQ_0[78].typ = (&NTIint5150__sVg18TP9cLifHyygRe9cro9aA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[78].name = "Field1";
TM__mff0c158N4EFFNgrs4pcEQ_20_3[2] = &TM__mff0c158N4EFFNgrs4pcEQ_0[79];
TM__mff0c158N4EFFNgrs4pcEQ_0[79].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[79].offset = offsetof(tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q, Field2);
TM__mff0c158N4EFFNgrs4pcEQ_0[79].typ = (&NTIseqLint5150T__48JTohSgTy339bRxHzUD8KA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[79].name = "Field2";
TM__mff0c158N4EFFNgrs4pcEQ_0[76].len = 3; TM__mff0c158N4EFFNgrs4pcEQ_0[76].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[76].sons = &TM__mff0c158N4EFFNgrs4pcEQ_20_3[0];
NTIkeyvaluepair__1mtQ8sCEE7DbfIuQciv9b5Q_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[76];
NTIkeyvaluepairseq__fdmz6VkIf1ewwrssKYqRFg_.size = sizeof(tySequence__fdmz6VkIf1ewwrssKYqRFg*);
NTIkeyvaluepairseq__fdmz6VkIf1ewwrssKYqRFg_.align = NIM_ALIGNOF(tySequence__fdmz6VkIf1ewwrssKYqRFg*);
NTIkeyvaluepairseq__fdmz6VkIf1ewwrssKYqRFg_.kind = 24;
NTIkeyvaluepairseq__fdmz6VkIf1ewwrssKYqRFg_.base = (&NTIkeyvaluepair__1mtQ8sCEE7DbfIuQciv9b5Q_);
NTIkeyvaluepairseq__fdmz6VkIf1ewwrssKYqRFg_.flags = 2;
NTIkeyvaluepairseq__fdmz6VkIf1ewwrssKYqRFg_.marker = Marker_tySequence__fdmz6VkIf1ewwrssKYqRFg;
TM__mff0c158N4EFFNgrs4pcEQ_0[75].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[75].offset = offsetof(tyObject_Table__imojfg883tkWsWJwyshGqQ, data);
TM__mff0c158N4EFFNgrs4pcEQ_0[75].typ = (&NTIkeyvaluepairseq__fdmz6VkIf1ewwrssKYqRFg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[75].name = "data";
TM__mff0c158N4EFFNgrs4pcEQ_19_2[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[80];
TM__mff0c158N4EFFNgrs4pcEQ_0[80].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[80].offset = offsetof(tyObject_Table__imojfg883tkWsWJwyshGqQ, counter);
TM__mff0c158N4EFFNgrs4pcEQ_0[80].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[80].name = "counter";
TM__mff0c158N4EFFNgrs4pcEQ_0[74].len = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[74].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[74].sons = &TM__mff0c158N4EFFNgrs4pcEQ_19_2[0];
NTItable__imojfg883tkWsWJwyshGqQ_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[74];
TM__mff0c158N4EFFNgrs4pcEQ_0[73].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[73].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, importDeps);
TM__mff0c158N4EFFNgrs4pcEQ_0[73].typ = (&NTItable__imojfg883tkWsWJwyshGqQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[73].name = "importDeps";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[13] = &TM__mff0c158N4EFFNgrs4pcEQ_0[81];
TM__mff0c158N4EFFNgrs4pcEQ_0[81].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[81].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, suggestMode);
TM__mff0c158N4EFFNgrs4pcEQ_0[81].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[81].name = "suggestMode";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[14] = &TM__mff0c158N4EFFNgrs4pcEQ_0[82];
TM__mff0c158N4EFFNgrs4pcEQ_0[82].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[82].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, invalidTransitiveClosure);
TM__mff0c158N4EFFNgrs4pcEQ_0[82].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[82].name = "invalidTransitiveClosure";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[15] = &TM__mff0c158N4EFFNgrs4pcEQ_0[83];
NTItable__BCPh85PHtwxox9bv7NLFrlg_.size = sizeof(tyObject_Table__BCPh85PHtwxox9bv7NLFrlg);
NTItable__BCPh85PHtwxox9bv7NLFrlg_.align = NIM_ALIGNOF(tyObject_Table__BCPh85PHtwxox9bv7NLFrlg);
NTItable__BCPh85PHtwxox9bv7NLFrlg_.kind = 18;
NTItable__BCPh85PHtwxox9bv7NLFrlg_.base = 0;
NTItable__BCPh85PHtwxox9bv7NLFrlg_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_21_2[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[85];
NTIkeyvaluepair__xDU9bZmv1ZbZkJDaATBekIQ_.size = sizeof(tyTuple__xDU9bZmv1ZbZkJDaATBekIQ);
NTIkeyvaluepair__xDU9bZmv1ZbZkJDaATBekIQ_.align = NIM_ALIGNOF(tyTuple__xDU9bZmv1ZbZkJDaATBekIQ);
NTIkeyvaluepair__xDU9bZmv1ZbZkJDaATBekIQ_.kind = 18;
NTIkeyvaluepair__xDU9bZmv1ZbZkJDaATBekIQ_.base = 0;
NTIkeyvaluepair__xDU9bZmv1ZbZkJDaATBekIQ_.flags = 3;
TM__mff0c158N4EFFNgrs4pcEQ_22_3[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[87];
TM__mff0c158N4EFFNgrs4pcEQ_0[87].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[87].offset = offsetof(tyTuple__xDU9bZmv1ZbZkJDaATBekIQ, Field0);
TM__mff0c158N4EFFNgrs4pcEQ_0[87].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[87].name = "Field0";
TM__mff0c158N4EFFNgrs4pcEQ_22_3[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[88];
TM__mff0c158N4EFFNgrs4pcEQ_0[88].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[88].offset = offsetof(tyTuple__xDU9bZmv1ZbZkJDaATBekIQ, Field1);
TM__mff0c158N4EFFNgrs4pcEQ_0[88].typ = (&NTIint5150__sVg18TP9cLifHyygRe9cro9aA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[88].name = "Field1";
TM__mff0c158N4EFFNgrs4pcEQ_22_3[2] = &TM__mff0c158N4EFFNgrs4pcEQ_0[89];
TM__mff0c158N4EFFNgrs4pcEQ_0[89].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[89].offset = offsetof(tyTuple__xDU9bZmv1ZbZkJDaATBekIQ, Field2);
TM__mff0c158N4EFFNgrs4pcEQ_0[89].typ = (&NTIint5150__sVg18TP9cLifHyygRe9cro9aA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[89].name = "Field2";
TM__mff0c158N4EFFNgrs4pcEQ_0[86].len = 3; TM__mff0c158N4EFFNgrs4pcEQ_0[86].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[86].sons = &TM__mff0c158N4EFFNgrs4pcEQ_22_3[0];
NTIkeyvaluepair__xDU9bZmv1ZbZkJDaATBekIQ_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[86];
NTIkeyvaluepairseq__kxu4GK0onha2t9bo86mdVAg_.size = sizeof(tySequence__kxu4GK0onha2t9bo86mdVAg*);
NTIkeyvaluepairseq__kxu4GK0onha2t9bo86mdVAg_.align = NIM_ALIGNOF(tySequence__kxu4GK0onha2t9bo86mdVAg*);
NTIkeyvaluepairseq__kxu4GK0onha2t9bo86mdVAg_.kind = 24;
NTIkeyvaluepairseq__kxu4GK0onha2t9bo86mdVAg_.base = (&NTIkeyvaluepair__xDU9bZmv1ZbZkJDaATBekIQ_);
NTIkeyvaluepairseq__kxu4GK0onha2t9bo86mdVAg_.flags = 2;
NTIkeyvaluepairseq__kxu4GK0onha2t9bo86mdVAg_.marker = Marker_tySequence__kxu4GK0onha2t9bo86mdVAg;
TM__mff0c158N4EFFNgrs4pcEQ_0[85].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[85].offset = offsetof(tyObject_Table__BCPh85PHtwxox9bv7NLFrlg, data);
TM__mff0c158N4EFFNgrs4pcEQ_0[85].typ = (&NTIkeyvaluepairseq__kxu4GK0onha2t9bo86mdVAg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[85].name = "data";
TM__mff0c158N4EFFNgrs4pcEQ_21_2[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[90];
TM__mff0c158N4EFFNgrs4pcEQ_0[90].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[90].offset = offsetof(tyObject_Table__BCPh85PHtwxox9bv7NLFrlg, counter);
TM__mff0c158N4EFFNgrs4pcEQ_0[90].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[90].name = "counter";
TM__mff0c158N4EFFNgrs4pcEQ_0[84].len = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[84].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[84].sons = &TM__mff0c158N4EFFNgrs4pcEQ_21_2[0];
NTItable__BCPh85PHtwxox9bv7NLFrlg_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[84];
TM__mff0c158N4EFFNgrs4pcEQ_0[83].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[83].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, inclToMod);
TM__mff0c158N4EFFNgrs4pcEQ_0[83].typ = (&NTItable__BCPh85PHtwxox9bv7NLFrlg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[83].name = "inclToMod";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[16] = &TM__mff0c158N4EFFNgrs4pcEQ_0[91];
TM__mff0c158N4EFFNgrs4pcEQ_0[91].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[91].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, importStack);
TM__mff0c158N4EFFNgrs4pcEQ_0[91].typ = (&NTIseqLint5150T__48JTohSgTy339bRxHzUD8KA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[91].name = "importStack";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[17] = &TM__mff0c158N4EFFNgrs4pcEQ_0[92];
TM__mff0c158N4EFFNgrs4pcEQ_0[92].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[92].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, backend);
TM__mff0c158N4EFFNgrs4pcEQ_0[92].typ = (&NTIrootref__0vJvi4uHbxjbxlkkX7P1EA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[92].name = "backend";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[18] = &TM__mff0c158N4EFFNgrs4pcEQ_0[93];
TM__mff0c158N4EFFNgrs4pcEQ_0[93].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[93].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, config);
TM__mff0c158N4EFFNgrs4pcEQ_0[93].typ = (&NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[93].name = "config";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[19] = &TM__mff0c158N4EFFNgrs4pcEQ_0[94];
TM__mff0c158N4EFFNgrs4pcEQ_0[94].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[94].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, cache);
TM__mff0c158N4EFFNgrs4pcEQ_0[94].typ = (&NTIidentcache__6ZZ9cf5acLVYxUxl0ehlA1g_);
TM__mff0c158N4EFFNgrs4pcEQ_0[94].name = "cache";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[20] = &TM__mff0c158N4EFFNgrs4pcEQ_0[95];
TM__mff0c158N4EFFNgrs4pcEQ_0[95].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[95].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, vm);
TM__mff0c158N4EFFNgrs4pcEQ_0[95].typ = (&NTIrootref__0vJvi4uHbxjbxlkkX7P1EA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[95].name = "vm";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[21] = &TM__mff0c158N4EFFNgrs4pcEQ_0[96];
NTIprocLT58boolLOclosureOT__In3g79a0qTcRmbTbJp9ba9ctg_.size = sizeof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTIprocLT58boolLOclosureOT__In3g79a0qTcRmbTbJp9ba9ctg_.align = NIM_ALIGNOF(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTIprocLT58boolLOclosureOT__In3g79a0qTcRmbTbJp9ba9ctg_.kind = 18;
NTIprocLT58boolLOclosureOT__In3g79a0qTcRmbTbJp9ba9ctg_.base = 0;
TM__mff0c158N4EFFNgrs4pcEQ_23_2[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[98];
TM__mff0c158N4EFFNgrs4pcEQ_0[98].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[98].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field0);
TM__mff0c158N4EFFNgrs4pcEQ_0[98].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__mff0c158N4EFFNgrs4pcEQ_0[98].name = "Field0";
TM__mff0c158N4EFFNgrs4pcEQ_23_2[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[99];
TM__mff0c158N4EFFNgrs4pcEQ_0[99].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[99].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field1);
TM__mff0c158N4EFFNgrs4pcEQ_0[99].typ = (&NTIrefobject__HsJiUUcO9cHBdUCi0HwkSTA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[99].name = "Field1";
TM__mff0c158N4EFFNgrs4pcEQ_0[97].len = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[97].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[97].sons = &TM__mff0c158N4EFFNgrs4pcEQ_23_2[0];
NTIprocLT58boolLOclosureOT__In3g79a0qTcRmbTbJp9ba9ctg_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[97];
TM__mff0c158N4EFFNgrs4pcEQ_0[96].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[96].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, doStopCompile);
TM__mff0c158N4EFFNgrs4pcEQ_0[96].typ = (&NTIprocLT58boolLOclosureOT__In3g79a0qTcRmbTbJp9ba9ctg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[96].name = "doStopCompile";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[22] = &TM__mff0c158N4EFFNgrs4pcEQ_0[100];
TM__mff0c158N4EFFNgrs4pcEQ_0[100].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[100].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, usageSym);
TM__mff0c158N4EFFNgrs4pcEQ_0[100].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[100].name = "usageSym";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[23] = &TM__mff0c158N4EFFNgrs4pcEQ_0[101];
TM__mff0c158N4EFFNgrs4pcEQ_0[101].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[101].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, owners);
TM__mff0c158N4EFFNgrs4pcEQ_0[101].typ = (&NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[101].name = "owners";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[24] = &TM__mff0c158N4EFFNgrs4pcEQ_0[102];
NTItable__mLYbj79bHyPPDPv4GGJx9bqA_.size = sizeof(tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA);
NTItable__mLYbj79bHyPPDPv4GGJx9bqA_.align = NIM_ALIGNOF(tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA);
NTItable__mLYbj79bHyPPDPv4GGJx9bqA_.kind = 18;
NTItable__mLYbj79bHyPPDPv4GGJx9bqA_.base = 0;
NTItable__mLYbj79bHyPPDPv4GGJx9bqA_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_24_2[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[104];
NTIkeyvaluepair__J4cxakKjhKxTIJR9bojMmXw_.size = sizeof(tyTuple__J4cxakKjhKxTIJR9bojMmXw);
NTIkeyvaluepair__J4cxakKjhKxTIJR9bojMmXw_.align = NIM_ALIGNOF(tyTuple__J4cxakKjhKxTIJR9bojMmXw);
NTIkeyvaluepair__J4cxakKjhKxTIJR9bojMmXw_.kind = 18;
NTIkeyvaluepair__J4cxakKjhKxTIJR9bojMmXw_.base = 0;
NTIkeyvaluepair__J4cxakKjhKxTIJR9bojMmXw_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_25_3[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[106];
TM__mff0c158N4EFFNgrs4pcEQ_0[106].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[106].offset = offsetof(tyTuple__J4cxakKjhKxTIJR9bojMmXw, Field0);
TM__mff0c158N4EFFNgrs4pcEQ_0[106].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[106].name = "Field0";
TM__mff0c158N4EFFNgrs4pcEQ_25_3[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[107];
TM__mff0c158N4EFFNgrs4pcEQ_0[107].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[107].offset = offsetof(tyTuple__J4cxakKjhKxTIJR9bojMmXw, Field1);
TM__mff0c158N4EFFNgrs4pcEQ_0[107].typ = (&NTIint5150__sVg18TP9cLifHyygRe9cro9aA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[107].name = "Field1";
TM__mff0c158N4EFFNgrs4pcEQ_25_3[2] = &TM__mff0c158N4EFFNgrs4pcEQ_0[108];
NTIsyminfopair__SjZT5Rln3r9befMWWSryQ0A_.size = sizeof(tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A);
NTIsyminfopair__SjZT5Rln3r9befMWWSryQ0A_.align = NIM_ALIGNOF(tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A);
NTIsyminfopair__SjZT5Rln3r9befMWWSryQ0A_.kind = 18;
NTIsyminfopair__SjZT5Rln3r9befMWWSryQ0A_.base = 0;
NTIsyminfopair__SjZT5Rln3r9befMWWSryQ0A_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_26_2[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[110];
TM__mff0c158N4EFFNgrs4pcEQ_0[110].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[110].offset = offsetof(tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A, sym);
TM__mff0c158N4EFFNgrs4pcEQ_0[110].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[110].name = "sym";
TM__mff0c158N4EFFNgrs4pcEQ_26_2[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[111];
TM__mff0c158N4EFFNgrs4pcEQ_0[111].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[111].offset = offsetof(tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A, info);
TM__mff0c158N4EFFNgrs4pcEQ_0[111].typ = (&NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_);
TM__mff0c158N4EFFNgrs4pcEQ_0[111].name = "info";
TM__mff0c158N4EFFNgrs4pcEQ_0[109].len = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[109].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[109].sons = &TM__mff0c158N4EFFNgrs4pcEQ_26_2[0];
NTIsyminfopair__SjZT5Rln3r9befMWWSryQ0A_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[109];
NTIseqLsyminfopairT__i89c5kdtWKzK3OEiI81pkkw_.size = sizeof(tySequence__i89c5kdtWKzK3OEiI81pkkw*);
NTIseqLsyminfopairT__i89c5kdtWKzK3OEiI81pkkw_.align = NIM_ALIGNOF(tySequence__i89c5kdtWKzK3OEiI81pkkw*);
NTIseqLsyminfopairT__i89c5kdtWKzK3OEiI81pkkw_.kind = 24;
NTIseqLsyminfopairT__i89c5kdtWKzK3OEiI81pkkw_.base = (&NTIsyminfopair__SjZT5Rln3r9befMWWSryQ0A_);
NTIseqLsyminfopairT__i89c5kdtWKzK3OEiI81pkkw_.flags = 2;
NTIseqLsyminfopairT__i89c5kdtWKzK3OEiI81pkkw_.marker = Marker_tySequence__i89c5kdtWKzK3OEiI81pkkw;
TM__mff0c158N4EFFNgrs4pcEQ_0[108].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[108].offset = offsetof(tyTuple__J4cxakKjhKxTIJR9bojMmXw, Field2);
TM__mff0c158N4EFFNgrs4pcEQ_0[108].typ = (&NTIseqLsyminfopairT__i89c5kdtWKzK3OEiI81pkkw_);
TM__mff0c158N4EFFNgrs4pcEQ_0[108].name = "Field2";
TM__mff0c158N4EFFNgrs4pcEQ_0[105].len = 3; TM__mff0c158N4EFFNgrs4pcEQ_0[105].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[105].sons = &TM__mff0c158N4EFFNgrs4pcEQ_25_3[0];
NTIkeyvaluepair__J4cxakKjhKxTIJR9bojMmXw_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[105];
NTIkeyvaluepairseq__KgiZ29chkJAD01p9aLRB32qw_.size = sizeof(tySequence__KgiZ29chkJAD01p9aLRB32qw*);
NTIkeyvaluepairseq__KgiZ29chkJAD01p9aLRB32qw_.align = NIM_ALIGNOF(tySequence__KgiZ29chkJAD01p9aLRB32qw*);
NTIkeyvaluepairseq__KgiZ29chkJAD01p9aLRB32qw_.kind = 24;
NTIkeyvaluepairseq__KgiZ29chkJAD01p9aLRB32qw_.base = (&NTIkeyvaluepair__J4cxakKjhKxTIJR9bojMmXw_);
NTIkeyvaluepairseq__KgiZ29chkJAD01p9aLRB32qw_.flags = 2;
NTIkeyvaluepairseq__KgiZ29chkJAD01p9aLRB32qw_.marker = Marker_tySequence__KgiZ29chkJAD01p9aLRB32qw;
TM__mff0c158N4EFFNgrs4pcEQ_0[104].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[104].offset = offsetof(tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA, data);
TM__mff0c158N4EFFNgrs4pcEQ_0[104].typ = (&NTIkeyvaluepairseq__KgiZ29chkJAD01p9aLRB32qw_);
TM__mff0c158N4EFFNgrs4pcEQ_0[104].name = "data";
TM__mff0c158N4EFFNgrs4pcEQ_24_2[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[112];
TM__mff0c158N4EFFNgrs4pcEQ_0[112].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[112].offset = offsetof(tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA, counter);
TM__mff0c158N4EFFNgrs4pcEQ_0[112].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[112].name = "counter";
TM__mff0c158N4EFFNgrs4pcEQ_0[103].len = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[103].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[103].sons = &TM__mff0c158N4EFFNgrs4pcEQ_24_2[0];
NTItable__mLYbj79bHyPPDPv4GGJx9bqA_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[103];
TM__mff0c158N4EFFNgrs4pcEQ_0[102].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[102].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, suggestSymbols);
TM__mff0c158N4EFFNgrs4pcEQ_0[102].typ = (&NTItable__mLYbj79bHyPPDPv4GGJx9bqA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[102].name = "suggestSymbols";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[25] = &TM__mff0c158N4EFFNgrs4pcEQ_0[113];
NTItable__LM44poVdVEn4Mo4N4L8c3A_.size = sizeof(tyObject_Table__LM44poVdVEn4Mo4N4L8c3A);
NTItable__LM44poVdVEn4Mo4N4L8c3A_.align = NIM_ALIGNOF(tyObject_Table__LM44poVdVEn4Mo4N4L8c3A);
NTItable__LM44poVdVEn4Mo4N4L8c3A_.kind = 18;
NTItable__LM44poVdVEn4Mo4N4L8c3A_.base = 0;
NTItable__LM44poVdVEn4Mo4N4L8c3A_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_27_2[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[115];
NTIkeyvaluepair__VwWg1orPZ9b5Rg9aZAI6SIaQ_.size = sizeof(tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ);
NTIkeyvaluepair__VwWg1orPZ9b5Rg9aZAI6SIaQ_.align = NIM_ALIGNOF(tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ);
NTIkeyvaluepair__VwWg1orPZ9b5Rg9aZAI6SIaQ_.kind = 18;
NTIkeyvaluepair__VwWg1orPZ9b5Rg9aZAI6SIaQ_.base = 0;
NTIkeyvaluepair__VwWg1orPZ9b5Rg9aZAI6SIaQ_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_28_3[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[117];
TM__mff0c158N4EFFNgrs4pcEQ_0[117].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[117].offset = offsetof(tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ, Field0);
TM__mff0c158N4EFFNgrs4pcEQ_0[117].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[117].name = "Field0";
TM__mff0c158N4EFFNgrs4pcEQ_28_3[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[118];
TM__mff0c158N4EFFNgrs4pcEQ_0[118].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[118].offset = offsetof(tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ, Field1);
TM__mff0c158N4EFFNgrs4pcEQ_0[118].typ = (&NTIint5150__sVg18TP9cLifHyygRe9cro9aA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[118].name = "Field1";
TM__mff0c158N4EFFNgrs4pcEQ_28_3[2] = &TM__mff0c158N4EFFNgrs4pcEQ_0[119];
NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_.size = sizeof(tySequence__GR8qmV1kNRcoQ2g76VFy3A*);
NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_.align = NIM_ALIGNOF(tySequence__GR8qmV1kNRcoQ2g76VFy3A*);
NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_.kind = 24;
NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_.base = (&NTIsuggest__vIaEYib9am0Aa2d8J2uMYdQ_);
NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_.flags = 2;
NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_.marker = Marker_tySequence__GR8qmV1kNRcoQ2g76VFy3A;
TM__mff0c158N4EFFNgrs4pcEQ_0[119].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[119].offset = offsetof(tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ, Field2);
TM__mff0c158N4EFFNgrs4pcEQ_0[119].typ = (&NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_);
TM__mff0c158N4EFFNgrs4pcEQ_0[119].name = "Field2";
TM__mff0c158N4EFFNgrs4pcEQ_0[116].len = 3; TM__mff0c158N4EFFNgrs4pcEQ_0[116].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[116].sons = &TM__mff0c158N4EFFNgrs4pcEQ_28_3[0];
NTIkeyvaluepair__VwWg1orPZ9b5Rg9aZAI6SIaQ_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[116];
NTIkeyvaluepairseq__rkYRZrbHVYL3nhXlQW3K9bw_.size = sizeof(tySequence__rkYRZrbHVYL3nhXlQW3K9bw*);
NTIkeyvaluepairseq__rkYRZrbHVYL3nhXlQW3K9bw_.align = NIM_ALIGNOF(tySequence__rkYRZrbHVYL3nhXlQW3K9bw*);
NTIkeyvaluepairseq__rkYRZrbHVYL3nhXlQW3K9bw_.kind = 24;
NTIkeyvaluepairseq__rkYRZrbHVYL3nhXlQW3K9bw_.base = (&NTIkeyvaluepair__VwWg1orPZ9b5Rg9aZAI6SIaQ_);
NTIkeyvaluepairseq__rkYRZrbHVYL3nhXlQW3K9bw_.flags = 2;
NTIkeyvaluepairseq__rkYRZrbHVYL3nhXlQW3K9bw_.marker = Marker_tySequence__rkYRZrbHVYL3nhXlQW3K9bw;
TM__mff0c158N4EFFNgrs4pcEQ_0[115].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[115].offset = offsetof(tyObject_Table__LM44poVdVEn4Mo4N4L8c3A, data);
TM__mff0c158N4EFFNgrs4pcEQ_0[115].typ = (&NTIkeyvaluepairseq__rkYRZrbHVYL3nhXlQW3K9bw_);
TM__mff0c158N4EFFNgrs4pcEQ_0[115].name = "data";
TM__mff0c158N4EFFNgrs4pcEQ_27_2[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[120];
TM__mff0c158N4EFFNgrs4pcEQ_0[120].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[120].offset = offsetof(tyObject_Table__LM44poVdVEn4Mo4N4L8c3A, counter);
TM__mff0c158N4EFFNgrs4pcEQ_0[120].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[120].name = "counter";
TM__mff0c158N4EFFNgrs4pcEQ_0[114].len = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[114].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[114].sons = &TM__mff0c158N4EFFNgrs4pcEQ_27_2[0];
NTItable__LM44poVdVEn4Mo4N4L8c3A_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[114];
TM__mff0c158N4EFFNgrs4pcEQ_0[113].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[113].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, suggestErrors);
TM__mff0c158N4EFFNgrs4pcEQ_0[113].typ = (&NTItable__LM44poVdVEn4Mo4N4L8c3A_);
TM__mff0c158N4EFFNgrs4pcEQ_0[113].name = "suggestErrors";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[26] = &TM__mff0c158N4EFFNgrs4pcEQ_0[121];
NTItupleLmethods58seqLpsymT_dispatcher58psymT__a7QginWFapakKbWJBJ2vfA_.size = sizeof(tyTuple__a7QginWFapakKbWJBJ2vfA);
NTItupleLmethods58seqLpsymT_dispatcher58psymT__a7QginWFapakKbWJBJ2vfA_.align = NIM_ALIGNOF(tyTuple__a7QginWFapakKbWJBJ2vfA);
NTItupleLmethods58seqLpsymT_dispatcher58psymT__a7QginWFapakKbWJBJ2vfA_.kind = 18;
NTItupleLmethods58seqLpsymT_dispatcher58psymT__a7QginWFapakKbWJBJ2vfA_.base = 0;
NTItupleLmethods58seqLpsymT_dispatcher58psymT__a7QginWFapakKbWJBJ2vfA_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_29_2[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[123];
TM__mff0c158N4EFFNgrs4pcEQ_0[123].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[123].offset = offsetof(tyTuple__a7QginWFapakKbWJBJ2vfA, Field0);
TM__mff0c158N4EFFNgrs4pcEQ_0[123].typ = (&NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[123].name = "Field0";
TM__mff0c158N4EFFNgrs4pcEQ_29_2[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[124];
TM__mff0c158N4EFFNgrs4pcEQ_0[124].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[124].offset = offsetof(tyTuple__a7QginWFapakKbWJBJ2vfA, Field1);
TM__mff0c158N4EFFNgrs4pcEQ_0[124].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[124].name = "Field1";
TM__mff0c158N4EFFNgrs4pcEQ_0[122].len = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[122].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[122].sons = &TM__mff0c158N4EFFNgrs4pcEQ_29_2[0];
NTItupleLmethods58seqLpsymT_dispatcher58psymT__a7QginWFapakKbWJBJ2vfA_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[122];
NTIseqLtupleLmethods58seqLpsymT_dispatcher58psymTT__IRFEb1e9bxgbJLuB5xrdZsQ_.size = sizeof(tySequence__IRFEb1e9bxgbJLuB5xrdZsQ*);
NTIseqLtupleLmethods58seqLpsymT_dispatcher58psymTT__IRFEb1e9bxgbJLuB5xrdZsQ_.align = NIM_ALIGNOF(tySequence__IRFEb1e9bxgbJLuB5xrdZsQ*);
NTIseqLtupleLmethods58seqLpsymT_dispatcher58psymTT__IRFEb1e9bxgbJLuB5xrdZsQ_.kind = 24;
NTIseqLtupleLmethods58seqLpsymT_dispatcher58psymTT__IRFEb1e9bxgbJLuB5xrdZsQ_.base = (&NTItupleLmethods58seqLpsymT_dispatcher58psymT__a7QginWFapakKbWJBJ2vfA_);
NTIseqLtupleLmethods58seqLpsymT_dispatcher58psymTT__IRFEb1e9bxgbJLuB5xrdZsQ_.flags = 2;
NTIseqLtupleLmethods58seqLpsymT_dispatcher58psymTT__IRFEb1e9bxgbJLuB5xrdZsQ_.marker = Marker_tySequence__IRFEb1e9bxgbJLuB5xrdZsQ;
TM__mff0c158N4EFFNgrs4pcEQ_0[121].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[121].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, methods);
TM__mff0c158N4EFFNgrs4pcEQ_0[121].typ = (&NTIseqLtupleLmethods58seqLpsymT_dispatcher58psymTT__IRFEb1e9bxgbJLuB5xrdZsQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[121].name = "methods";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[27] = &TM__mff0c158N4EFFNgrs4pcEQ_0[125];
TM__mff0c158N4EFFNgrs4pcEQ_0[125].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[125].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, systemModule);
TM__mff0c158N4EFFNgrs4pcEQ_0[125].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[125].name = "systemModule";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[28] = &TM__mff0c158N4EFFNgrs4pcEQ_0[126];
NTIarrayLttypekind_ptypeT__9atk2qEPO7ASGmt9cDlOE9b9cg_.size = sizeof(tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg);
NTIarrayLttypekind_ptypeT__9atk2qEPO7ASGmt9cDlOE9b9cg_.align = NIM_ALIGNOF(tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg);
NTIarrayLttypekind_ptypeT__9atk2qEPO7ASGmt9cDlOE9b9cg_.kind = 16;
NTIarrayLttypekind_ptypeT__9atk2qEPO7ASGmt9cDlOE9b9cg_.base = (&NTIptype__q1v0zzhoMWrhMLs6UEp1IA_);
NTIarrayLttypekind_ptypeT__9atk2qEPO7ASGmt9cDlOE9b9cg_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_0[126].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[126].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, sysTypes);
TM__mff0c158N4EFFNgrs4pcEQ_0[126].typ = (&NTIarrayLttypekind_ptypeT__9atk2qEPO7ASGmt9cDlOE9b9cg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[126].name = "sysTypes";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[29] = &TM__mff0c158N4EFFNgrs4pcEQ_0[127];
TM__mff0c158N4EFFNgrs4pcEQ_0[127].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[127].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, compilerprocs);
TM__mff0c158N4EFFNgrs4pcEQ_0[127].typ = (&NTItstrtable__CJQ42V2zij8fd39a9aMiwtZw_);
TM__mff0c158N4EFFNgrs4pcEQ_0[127].name = "compilerprocs";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[30] = &TM__mff0c158N4EFFNgrs4pcEQ_0[128];
TM__mff0c158N4EFFNgrs4pcEQ_0[128].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[128].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, exposed);
TM__mff0c158N4EFFNgrs4pcEQ_0[128].typ = (&NTItstrtable__CJQ42V2zij8fd39a9aMiwtZw_);
TM__mff0c158N4EFFNgrs4pcEQ_0[128].name = "exposed";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[31] = &TM__mff0c158N4EFFNgrs4pcEQ_0[129];
TM__mff0c158N4EFFNgrs4pcEQ_0[129].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[129].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, packageTypes);
TM__mff0c158N4EFFNgrs4pcEQ_0[129].typ = (&NTItstrtable__CJQ42V2zij8fd39a9aMiwtZw_);
TM__mff0c158N4EFFNgrs4pcEQ_0[129].name = "packageTypes";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[32] = &TM__mff0c158N4EFFNgrs4pcEQ_0[130];
TM__mff0c158N4EFFNgrs4pcEQ_0[130].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[130].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, emptyNode);
TM__mff0c158N4EFFNgrs4pcEQ_0[130].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__mff0c158N4EFFNgrs4pcEQ_0[130].name = "emptyNode";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[33] = &TM__mff0c158N4EFFNgrs4pcEQ_0[131];
NTItable__sEMwnZ9aATDhH19cNIt9bn9cyQ_.size = sizeof(tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ);
NTItable__sEMwnZ9aATDhH19cNIt9bn9cyQ_.align = NIM_ALIGNOF(tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ);
NTItable__sEMwnZ9aATDhH19cNIt9bn9cyQ_.kind = 18;
NTItable__sEMwnZ9aATDhH19cNIt9bn9cyQ_.base = 0;
NTItable__sEMwnZ9aATDhH19cNIt9bn9cyQ_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_30_2[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[133];
NTIkeyvaluepair__mPT6B9cVWqwVnWb1Fxx9bgyA_.size = sizeof(tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA);
NTIkeyvaluepair__mPT6B9cVWqwVnWb1Fxx9bgyA_.align = NIM_ALIGNOF(tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA);
NTIkeyvaluepair__mPT6B9cVWqwVnWb1Fxx9bgyA_.kind = 18;
NTIkeyvaluepair__mPT6B9cVWqwVnWb1Fxx9bgyA_.base = 0;
NTIkeyvaluepair__mPT6B9cVWqwVnWb1Fxx9bgyA_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_31_3[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[135];
TM__mff0c158N4EFFNgrs4pcEQ_0[135].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[135].offset = offsetof(tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA, Field0);
TM__mff0c158N4EFFNgrs4pcEQ_0[135].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[135].name = "Field0";
TM__mff0c158N4EFFNgrs4pcEQ_31_3[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[136];
TM__mff0c158N4EFFNgrs4pcEQ_0[136].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[136].offset = offsetof(tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA, Field1);
TM__mff0c158N4EFFNgrs4pcEQ_0[136].typ = (&NTImd53digest__qtqsWM5aXmcpMIVmvq3kAA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[136].name = "Field1";
TM__mff0c158N4EFFNgrs4pcEQ_31_3[2] = &TM__mff0c158N4EFFNgrs4pcEQ_0[137];
TM__mff0c158N4EFFNgrs4pcEQ_0[137].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[137].offset = offsetof(tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA, Field2);
TM__mff0c158N4EFFNgrs4pcEQ_0[137].typ = (&NTIptype__q1v0zzhoMWrhMLs6UEp1IA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[137].name = "Field2";
TM__mff0c158N4EFFNgrs4pcEQ_0[134].len = 3; TM__mff0c158N4EFFNgrs4pcEQ_0[134].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[134].sons = &TM__mff0c158N4EFFNgrs4pcEQ_31_3[0];
NTIkeyvaluepair__mPT6B9cVWqwVnWb1Fxx9bgyA_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[134];
NTIkeyvaluepairseq__YmPd0eWfcTfrVYrthlXPYA_.size = sizeof(tySequence__YmPd0eWfcTfrVYrthlXPYA*);
NTIkeyvaluepairseq__YmPd0eWfcTfrVYrthlXPYA_.align = NIM_ALIGNOF(tySequence__YmPd0eWfcTfrVYrthlXPYA*);
NTIkeyvaluepairseq__YmPd0eWfcTfrVYrthlXPYA_.kind = 24;
NTIkeyvaluepairseq__YmPd0eWfcTfrVYrthlXPYA_.base = (&NTIkeyvaluepair__mPT6B9cVWqwVnWb1Fxx9bgyA_);
NTIkeyvaluepairseq__YmPd0eWfcTfrVYrthlXPYA_.flags = 2;
NTIkeyvaluepairseq__YmPd0eWfcTfrVYrthlXPYA_.marker = Marker_tySequence__YmPd0eWfcTfrVYrthlXPYA;
TM__mff0c158N4EFFNgrs4pcEQ_0[133].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[133].offset = offsetof(tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ, data);
TM__mff0c158N4EFFNgrs4pcEQ_0[133].typ = (&NTIkeyvaluepairseq__YmPd0eWfcTfrVYrthlXPYA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[133].name = "data";
TM__mff0c158N4EFFNgrs4pcEQ_30_2[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[138];
TM__mff0c158N4EFFNgrs4pcEQ_0[138].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[138].offset = offsetof(tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ, counter);
TM__mff0c158N4EFFNgrs4pcEQ_0[138].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[138].name = "counter";
TM__mff0c158N4EFFNgrs4pcEQ_0[132].len = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[132].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[132].sons = &TM__mff0c158N4EFFNgrs4pcEQ_30_2[0];
NTItable__sEMwnZ9aATDhH19cNIt9bn9cyQ_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[132];
TM__mff0c158N4EFFNgrs4pcEQ_0[131].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[131].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, canonTypes);
TM__mff0c158N4EFFNgrs4pcEQ_0[131].typ = (&NTItable__sEMwnZ9aATDhH19cNIt9bn9cyQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[131].name = "canonTypes";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[34] = &TM__mff0c158N4EFFNgrs4pcEQ_0[139];
NTItable__WtPprFMQ6tkKi9bQSH3IVpw_.size = sizeof(tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw);
NTItable__WtPprFMQ6tkKi9bQSH3IVpw_.align = NIM_ALIGNOF(tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw);
NTItable__WtPprFMQ6tkKi9bQSH3IVpw_.kind = 18;
NTItable__WtPprFMQ6tkKi9bQSH3IVpw_.base = 0;
NTItable__WtPprFMQ6tkKi9bQSH3IVpw_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_32_2[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[141];
NTIkeyvaluepair__OJFzEczluV8Jmo9bRpBfkzw_.size = sizeof(tyTuple__OJFzEczluV8Jmo9bRpBfkzw);
NTIkeyvaluepair__OJFzEczluV8Jmo9bRpBfkzw_.align = NIM_ALIGNOF(tyTuple__OJFzEczluV8Jmo9bRpBfkzw);
NTIkeyvaluepair__OJFzEczluV8Jmo9bRpBfkzw_.kind = 18;
NTIkeyvaluepair__OJFzEczluV8Jmo9bRpBfkzw_.base = 0;
NTIkeyvaluepair__OJFzEczluV8Jmo9bRpBfkzw_.flags = 3;
TM__mff0c158N4EFFNgrs4pcEQ_33_3[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[143];
TM__mff0c158N4EFFNgrs4pcEQ_0[143].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[143].offset = offsetof(tyTuple__OJFzEczluV8Jmo9bRpBfkzw, Field0);
TM__mff0c158N4EFFNgrs4pcEQ_0[143].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[143].name = "Field0";
TM__mff0c158N4EFFNgrs4pcEQ_33_3[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[144];
TM__mff0c158N4EFFNgrs4pcEQ_0[144].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[144].offset = offsetof(tyTuple__OJFzEczluV8Jmo9bRpBfkzw, Field1);
TM__mff0c158N4EFFNgrs4pcEQ_0[144].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[144].name = "Field1";
TM__mff0c158N4EFFNgrs4pcEQ_33_3[2] = &TM__mff0c158N4EFFNgrs4pcEQ_0[145];
TM__mff0c158N4EFFNgrs4pcEQ_0[145].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[145].offset = offsetof(tyTuple__OJFzEczluV8Jmo9bRpBfkzw, Field2);
TM__mff0c158N4EFFNgrs4pcEQ_0[145].typ = (&NTImd53digest__qtqsWM5aXmcpMIVmvq3kAA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[145].name = "Field2";
TM__mff0c158N4EFFNgrs4pcEQ_0[142].len = 3; TM__mff0c158N4EFFNgrs4pcEQ_0[142].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[142].sons = &TM__mff0c158N4EFFNgrs4pcEQ_33_3[0];
NTIkeyvaluepair__OJFzEczluV8Jmo9bRpBfkzw_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[142];
NTIkeyvaluepairseq__fIB1rTQ55aFonoft9a9bmljQ_.size = sizeof(tySequence__fIB1rTQ55aFonoft9a9bmljQ*);
NTIkeyvaluepairseq__fIB1rTQ55aFonoft9a9bmljQ_.align = NIM_ALIGNOF(tySequence__fIB1rTQ55aFonoft9a9bmljQ*);
NTIkeyvaluepairseq__fIB1rTQ55aFonoft9a9bmljQ_.kind = 24;
NTIkeyvaluepairseq__fIB1rTQ55aFonoft9a9bmljQ_.base = (&NTIkeyvaluepair__OJFzEczluV8Jmo9bRpBfkzw_);
NTIkeyvaluepairseq__fIB1rTQ55aFonoft9a9bmljQ_.flags = 2;
NTIkeyvaluepairseq__fIB1rTQ55aFonoft9a9bmljQ_.marker = Marker_tySequence__fIB1rTQ55aFonoft9a9bmljQ;
TM__mff0c158N4EFFNgrs4pcEQ_0[141].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[141].offset = offsetof(tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw, data);
TM__mff0c158N4EFFNgrs4pcEQ_0[141].typ = (&NTIkeyvaluepairseq__fIB1rTQ55aFonoft9a9bmljQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[141].name = "data";
TM__mff0c158N4EFFNgrs4pcEQ_32_2[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[146];
TM__mff0c158N4EFFNgrs4pcEQ_0[146].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[146].offset = offsetof(tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw, counter);
TM__mff0c158N4EFFNgrs4pcEQ_0[146].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[146].name = "counter";
TM__mff0c158N4EFFNgrs4pcEQ_0[140].len = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[140].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[140].sons = &TM__mff0c158N4EFFNgrs4pcEQ_32_2[0];
NTItable__WtPprFMQ6tkKi9bQSH3IVpw_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[140];
TM__mff0c158N4EFFNgrs4pcEQ_0[139].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[139].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, symBodyHashes);
TM__mff0c158N4EFFNgrs4pcEQ_0[139].typ = (&NTItable__WtPprFMQ6tkKi9bQSH3IVpw_);
TM__mff0c158N4EFFNgrs4pcEQ_0[139].name = "symBodyHashes";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[35] = &TM__mff0c158N4EFFNgrs4pcEQ_0[147];
NTIprocLgraph58modulegraph_m58psym_fileidx58fileindexT58psymLOnimcallOT__I6rzVhdiYtUh7jwWJQoeyw_.size = sizeof(tyProc__I6rzVhdiYtUh7jwWJQoeyw);
NTIprocLgraph58modulegraph_m58psym_fileidx58fileindexT58psymLOnimcallOT__I6rzVhdiYtUh7jwWJQoeyw_.align = NIM_ALIGNOF(tyProc__I6rzVhdiYtUh7jwWJQoeyw);
NTIprocLgraph58modulegraph_m58psym_fileidx58fileindexT58psymLOnimcallOT__I6rzVhdiYtUh7jwWJQoeyw_.kind = 25;
NTIprocLgraph58modulegraph_m58psym_fileidx58fileindexT58psymLOnimcallOT__I6rzVhdiYtUh7jwWJQoeyw_.base = 0;
NTIprocLgraph58modulegraph_m58psym_fileidx58fileindexT58psymLOnimcallOT__I6rzVhdiYtUh7jwWJQoeyw_.flags = 3;
TM__mff0c158N4EFFNgrs4pcEQ_0[147].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[147].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, importModuleCallback);
TM__mff0c158N4EFFNgrs4pcEQ_0[147].typ = (&NTIprocLgraph58modulegraph_m58psym_fileidx58fileindexT58psymLOnimcallOT__I6rzVhdiYtUh7jwWJQoeyw_);
TM__mff0c158N4EFFNgrs4pcEQ_0[147].name = "importModuleCallback";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[36] = &TM__mff0c158N4EFFNgrs4pcEQ_0[148];
NTIprocLgraph58modulegraph_m58psym_fileidx58fileindexT58pnodeLOnimcallOT__EQOAUyRkp9c3eeiGlHvCThA_.size = sizeof(tyProc__EQOAUyRkp9c3eeiGlHvCThA);
NTIprocLgraph58modulegraph_m58psym_fileidx58fileindexT58pnodeLOnimcallOT__EQOAUyRkp9c3eeiGlHvCThA_.align = NIM_ALIGNOF(tyProc__EQOAUyRkp9c3eeiGlHvCThA);
NTIprocLgraph58modulegraph_m58psym_fileidx58fileindexT58pnodeLOnimcallOT__EQOAUyRkp9c3eeiGlHvCThA_.kind = 25;
NTIprocLgraph58modulegraph_m58psym_fileidx58fileindexT58pnodeLOnimcallOT__EQOAUyRkp9c3eeiGlHvCThA_.base = 0;
NTIprocLgraph58modulegraph_m58psym_fileidx58fileindexT58pnodeLOnimcallOT__EQOAUyRkp9c3eeiGlHvCThA_.flags = 3;
TM__mff0c158N4EFFNgrs4pcEQ_0[148].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[148].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, includeFileCallback);
TM__mff0c158N4EFFNgrs4pcEQ_0[148].typ = (&NTIprocLgraph58modulegraph_m58psym_fileidx58fileindexT58pnodeLOnimcallOT__EQOAUyRkp9c3eeiGlHvCThA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[148].name = "includeFileCallback";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[37] = &TM__mff0c158N4EFFNgrs4pcEQ_0[149];
NTItable__9cOd7jTOg5Zc4i0IfnGho1Q_.size = sizeof(tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q);
NTItable__9cOd7jTOg5Zc4i0IfnGho1Q_.align = NIM_ALIGNOF(tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q);
NTItable__9cOd7jTOg5Zc4i0IfnGho1Q_.kind = 18;
NTItable__9cOd7jTOg5Zc4i0IfnGho1Q_.base = 0;
NTItable__9cOd7jTOg5Zc4i0IfnGho1Q_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_34_2[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[151];
NTIkeyvaluepair__kbX6x85REySUrk9auORL0vw_.size = sizeof(tyTuple__kbX6x85REySUrk9auORL0vw);
NTIkeyvaluepair__kbX6x85REySUrk9auORL0vw_.align = NIM_ALIGNOF(tyTuple__kbX6x85REySUrk9auORL0vw);
NTIkeyvaluepair__kbX6x85REySUrk9auORL0vw_.kind = 18;
NTIkeyvaluepair__kbX6x85REySUrk9auORL0vw_.base = 0;
NTIkeyvaluepair__kbX6x85REySUrk9auORL0vw_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_35_3[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[153];
TM__mff0c158N4EFFNgrs4pcEQ_0[153].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[153].offset = offsetof(tyTuple__kbX6x85REySUrk9auORL0vw, Field0);
TM__mff0c158N4EFFNgrs4pcEQ_0[153].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[153].name = "Field0";
TM__mff0c158N4EFFNgrs4pcEQ_35_3[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[154];
TM__mff0c158N4EFFNgrs4pcEQ_0[154].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[154].offset = offsetof(tyTuple__kbX6x85REySUrk9auORL0vw, Field1);
TM__mff0c158N4EFFNgrs4pcEQ_0[154].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[154].name = "Field1";
TM__mff0c158N4EFFNgrs4pcEQ_35_3[2] = &TM__mff0c158N4EFFNgrs4pcEQ_0[155];
TM__mff0c158N4EFFNgrs4pcEQ_0[155].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[155].offset = offsetof(tyTuple__kbX6x85REySUrk9auORL0vw, Field2);
TM__mff0c158N4EFFNgrs4pcEQ_0[155].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__mff0c158N4EFFNgrs4pcEQ_0[155].name = "Field2";
TM__mff0c158N4EFFNgrs4pcEQ_0[152].len = 3; TM__mff0c158N4EFFNgrs4pcEQ_0[152].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[152].sons = &TM__mff0c158N4EFFNgrs4pcEQ_35_3[0];
NTIkeyvaluepair__kbX6x85REySUrk9auORL0vw_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[152];
NTIkeyvaluepairseq__Hz5SYwQU29b9aFLt09blvVQPg_.size = sizeof(tySequence__Hz5SYwQU29b9aFLt09blvVQPg*);
NTIkeyvaluepairseq__Hz5SYwQU29b9aFLt09blvVQPg_.align = NIM_ALIGNOF(tySequence__Hz5SYwQU29b9aFLt09blvVQPg*);
NTIkeyvaluepairseq__Hz5SYwQU29b9aFLt09blvVQPg_.kind = 24;
NTIkeyvaluepairseq__Hz5SYwQU29b9aFLt09blvVQPg_.base = (&NTIkeyvaluepair__kbX6x85REySUrk9auORL0vw_);
NTIkeyvaluepairseq__Hz5SYwQU29b9aFLt09blvVQPg_.flags = 2;
NTIkeyvaluepairseq__Hz5SYwQU29b9aFLt09blvVQPg_.marker = Marker_tySequence__Hz5SYwQU29b9aFLt09blvVQPg;
TM__mff0c158N4EFFNgrs4pcEQ_0[151].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[151].offset = offsetof(tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q, data);
TM__mff0c158N4EFFNgrs4pcEQ_0[151].typ = (&NTIkeyvaluepairseq__Hz5SYwQU29b9aFLt09blvVQPg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[151].name = "data";
TM__mff0c158N4EFFNgrs4pcEQ_34_2[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[156];
TM__mff0c158N4EFFNgrs4pcEQ_0[156].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[156].offset = offsetof(tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q, counter);
TM__mff0c158N4EFFNgrs4pcEQ_0[156].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[156].name = "counter";
TM__mff0c158N4EFFNgrs4pcEQ_0[150].len = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[150].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[150].sons = &TM__mff0c158N4EFFNgrs4pcEQ_34_2[0];
NTItable__9cOd7jTOg5Zc4i0IfnGho1Q_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[150];
TM__mff0c158N4EFFNgrs4pcEQ_0[149].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[149].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, cacheSeqs);
TM__mff0c158N4EFFNgrs4pcEQ_0[149].typ = (&NTItable__9cOd7jTOg5Zc4i0IfnGho1Q_);
TM__mff0c158N4EFFNgrs4pcEQ_0[149].name = "cacheSeqs";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[38] = &TM__mff0c158N4EFFNgrs4pcEQ_0[157];
NTItable__YnoEqrDMrd9cI9bBg8gj5H3g_.size = sizeof(tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g);
NTItable__YnoEqrDMrd9cI9bBg8gj5H3g_.align = NIM_ALIGNOF(tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g);
NTItable__YnoEqrDMrd9cI9bBg8gj5H3g_.kind = 18;
NTItable__YnoEqrDMrd9cI9bBg8gj5H3g_.base = 0;
NTItable__YnoEqrDMrd9cI9bBg8gj5H3g_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_36_2[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[159];
NTIkeyvaluepair__F3gkSrMB1qp2Tvf9bixVXwg_.size = sizeof(tyTuple__F3gkSrMB1qp2Tvf9bixVXwg);
NTIkeyvaluepair__F3gkSrMB1qp2Tvf9bixVXwg_.align = NIM_ALIGNOF(tyTuple__F3gkSrMB1qp2Tvf9bixVXwg);
NTIkeyvaluepair__F3gkSrMB1qp2Tvf9bixVXwg_.kind = 18;
NTIkeyvaluepair__F3gkSrMB1qp2Tvf9bixVXwg_.base = 0;
NTIkeyvaluepair__F3gkSrMB1qp2Tvf9bixVXwg_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_37_3[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[161];
TM__mff0c158N4EFFNgrs4pcEQ_0[161].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[161].offset = offsetof(tyTuple__F3gkSrMB1qp2Tvf9bixVXwg, Field0);
TM__mff0c158N4EFFNgrs4pcEQ_0[161].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[161].name = "Field0";
TM__mff0c158N4EFFNgrs4pcEQ_37_3[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[162];
TM__mff0c158N4EFFNgrs4pcEQ_0[162].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[162].offset = offsetof(tyTuple__F3gkSrMB1qp2Tvf9bixVXwg, Field1);
TM__mff0c158N4EFFNgrs4pcEQ_0[162].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[162].name = "Field1";
TM__mff0c158N4EFFNgrs4pcEQ_37_3[2] = &TM__mff0c158N4EFFNgrs4pcEQ_0[163];
TM__mff0c158N4EFFNgrs4pcEQ_0[163].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[163].offset = offsetof(tyTuple__F3gkSrMB1qp2Tvf9bixVXwg, Field2);
TM__mff0c158N4EFFNgrs4pcEQ_0[163].typ = (&NTIbiggestint__Aav8dQoMlCFnZRxA0IhTHQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[163].name = "Field2";
TM__mff0c158N4EFFNgrs4pcEQ_0[160].len = 3; TM__mff0c158N4EFFNgrs4pcEQ_0[160].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[160].sons = &TM__mff0c158N4EFFNgrs4pcEQ_37_3[0];
NTIkeyvaluepair__F3gkSrMB1qp2Tvf9bixVXwg_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[160];
NTIkeyvaluepairseq__squ9b9bUH4OLHf6cEMrt6hVA_.size = sizeof(tySequence__squ9b9bUH4OLHf6cEMrt6hVA*);
NTIkeyvaluepairseq__squ9b9bUH4OLHf6cEMrt6hVA_.align = NIM_ALIGNOF(tySequence__squ9b9bUH4OLHf6cEMrt6hVA*);
NTIkeyvaluepairseq__squ9b9bUH4OLHf6cEMrt6hVA_.kind = 24;
NTIkeyvaluepairseq__squ9b9bUH4OLHf6cEMrt6hVA_.base = (&NTIkeyvaluepair__F3gkSrMB1qp2Tvf9bixVXwg_);
NTIkeyvaluepairseq__squ9b9bUH4OLHf6cEMrt6hVA_.flags = 2;
NTIkeyvaluepairseq__squ9b9bUH4OLHf6cEMrt6hVA_.marker = Marker_tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
TM__mff0c158N4EFFNgrs4pcEQ_0[159].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[159].offset = offsetof(tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g, data);
TM__mff0c158N4EFFNgrs4pcEQ_0[159].typ = (&NTIkeyvaluepairseq__squ9b9bUH4OLHf6cEMrt6hVA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[159].name = "data";
TM__mff0c158N4EFFNgrs4pcEQ_36_2[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[164];
TM__mff0c158N4EFFNgrs4pcEQ_0[164].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[164].offset = offsetof(tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g, counter);
TM__mff0c158N4EFFNgrs4pcEQ_0[164].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[164].name = "counter";
TM__mff0c158N4EFFNgrs4pcEQ_0[158].len = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[158].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[158].sons = &TM__mff0c158N4EFFNgrs4pcEQ_36_2[0];
NTItable__YnoEqrDMrd9cI9bBg8gj5H3g_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[158];
TM__mff0c158N4EFFNgrs4pcEQ_0[157].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[157].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, cacheCounters);
TM__mff0c158N4EFFNgrs4pcEQ_0[157].typ = (&NTItable__YnoEqrDMrd9cI9bBg8gj5H3g_);
TM__mff0c158N4EFFNgrs4pcEQ_0[157].name = "cacheCounters";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[39] = &TM__mff0c158N4EFFNgrs4pcEQ_0[165];
NTItable__R7JnJQEipxxOlJWXQz7jWg_.size = sizeof(tyObject_Table__R7JnJQEipxxOlJWXQz7jWg);
NTItable__R7JnJQEipxxOlJWXQz7jWg_.align = NIM_ALIGNOF(tyObject_Table__R7JnJQEipxxOlJWXQz7jWg);
NTItable__R7JnJQEipxxOlJWXQz7jWg_.kind = 18;
NTItable__R7JnJQEipxxOlJWXQz7jWg_.base = 0;
NTItable__R7JnJQEipxxOlJWXQz7jWg_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_38_2[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[167];
NTIkeyvaluepair__Ah6ua9a8WyUOs9aO9afW59cy0g_.size = sizeof(tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g);
NTIkeyvaluepair__Ah6ua9a8WyUOs9aO9afW59cy0g_.align = NIM_ALIGNOF(tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g);
NTIkeyvaluepair__Ah6ua9a8WyUOs9aO9afW59cy0g_.kind = 18;
NTIkeyvaluepair__Ah6ua9a8WyUOs9aO9afW59cy0g_.base = 0;
NTIkeyvaluepair__Ah6ua9a8WyUOs9aO9afW59cy0g_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_39_3[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[169];
TM__mff0c158N4EFFNgrs4pcEQ_0[169].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[169].offset = offsetof(tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g, Field0);
TM__mff0c158N4EFFNgrs4pcEQ_0[169].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[169].name = "Field0";
TM__mff0c158N4EFFNgrs4pcEQ_39_3[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[170];
TM__mff0c158N4EFFNgrs4pcEQ_0[170].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[170].offset = offsetof(tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g, Field1);
TM__mff0c158N4EFFNgrs4pcEQ_0[170].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[170].name = "Field1";
TM__mff0c158N4EFFNgrs4pcEQ_39_3[2] = &TM__mff0c158N4EFFNgrs4pcEQ_0[171];
NTIbtree__R2EgvhuH9cLMYvSPesdcu5Q_.size = sizeof(tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q);
NTIbtree__R2EgvhuH9cLMYvSPesdcu5Q_.align = NIM_ALIGNOF(tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q);
NTIbtree__R2EgvhuH9cLMYvSPesdcu5Q_.kind = 18;
NTIbtree__R2EgvhuH9cLMYvSPesdcu5Q_.base = 0;
NTIbtree__R2EgvhuH9cLMYvSPesdcu5Q_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_40_2[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[173];
NTInode58objecttype__NOM0ZpqV9bLtofkCilAnZ8A_.size = sizeof(tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A);
NTInode58objecttype__NOM0ZpqV9bLtofkCilAnZ8A_.align = NIM_ALIGNOF(tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A);
NTInode58objecttype__NOM0ZpqV9bLtofkCilAnZ8A_.kind = 18;
NTInode58objecttype__NOM0ZpqV9bLtofkCilAnZ8A_.base = 0;
NTInode58objecttype__NOM0ZpqV9bLtofkCilAnZ8A_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_41_3[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[175];
TM__mff0c158N4EFFNgrs4pcEQ_0[175].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[175].offset = offsetof(tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A, entries);
TM__mff0c158N4EFFNgrs4pcEQ_0[175].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[175].name = "entries";
TM__mff0c158N4EFFNgrs4pcEQ_41_3[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[176];
NTIarrayL48OO534949_stringT__9aijZrM1syqzleJpcL8bUyw_.size = sizeof(tyArray__9aijZrM1syqzleJpcL8bUyw);
NTIarrayL48OO534949_stringT__9aijZrM1syqzleJpcL8bUyw_.align = NIM_ALIGNOF(tyArray__9aijZrM1syqzleJpcL8bUyw);
NTIarrayL48OO534949_stringT__9aijZrM1syqzleJpcL8bUyw_.kind = 16;
NTIarrayL48OO534949_stringT__9aijZrM1syqzleJpcL8bUyw_.base = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
NTIarrayL48OO534949_stringT__9aijZrM1syqzleJpcL8bUyw_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_0[176].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[176].offset = offsetof(tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A, keys);
TM__mff0c158N4EFFNgrs4pcEQ_0[176].typ = (&NTIarrayL48OO534949_stringT__9aijZrM1syqzleJpcL8bUyw_);
TM__mff0c158N4EFFNgrs4pcEQ_0[176].name = "keys";
TM__mff0c158N4EFFNgrs4pcEQ_41_3[2] = &TM__mff0c158N4EFFNgrs4pcEQ_0[177];
TM__mff0c158N4EFFNgrs4pcEQ_0[177].kind = 3;
TM__mff0c158N4EFFNgrs4pcEQ_0[177].offset = offsetof(tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A, isInternal);
TM__mff0c158N4EFFNgrs4pcEQ_0[177].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[177].name = "isInternal";
TM__mff0c158N4EFFNgrs4pcEQ_0[177].sons = &NimDT___NOM0ZpqV9bLtofkCilAnZ8A_isInternal[0];
TM__mff0c158N4EFFNgrs4pcEQ_0[177].len = 2;
NTIarrayL48OO534949_pnodeT__pWfcjNgdkCPhsQuXtCrjlQ_.size = sizeof(tyArray__pWfcjNgdkCPhsQuXtCrjlQ);
NTIarrayL48OO534949_pnodeT__pWfcjNgdkCPhsQuXtCrjlQ_.align = NIM_ALIGNOF(tyArray__pWfcjNgdkCPhsQuXtCrjlQ);
NTIarrayL48OO534949_pnodeT__pWfcjNgdkCPhsQuXtCrjlQ_.kind = 16;
NTIarrayL48OO534949_pnodeT__pWfcjNgdkCPhsQuXtCrjlQ_.base = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
NTIarrayL48OO534949_pnodeT__pWfcjNgdkCPhsQuXtCrjlQ_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_0[178].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[178].offset = offsetof(tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A, _isInternal_1.vals);
TM__mff0c158N4EFFNgrs4pcEQ_0[178].typ = (&NTIarrayL48OO534949_pnodeT__pWfcjNgdkCPhsQuXtCrjlQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[178].name = "vals";
NimDT___NOM0ZpqV9bLtofkCilAnZ8A_isInternal[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[178];
NTIarrayL48OO534949_nodeLsystemOstring_astOpnodeTT__VKNNDtxlcHt69avZNvnPyiQ_.size = sizeof(tyArray__VKNNDtxlcHt69avZNvnPyiQ);
NTIarrayL48OO534949_nodeLsystemOstring_astOpnodeTT__VKNNDtxlcHt69avZNvnPyiQ_.align = NIM_ALIGNOF(tyArray__VKNNDtxlcHt69avZNvnPyiQ);
NTIarrayL48OO534949_nodeLsystemOstring_astOpnodeTT__VKNNDtxlcHt69avZNvnPyiQ_.kind = 16;
NTIarrayL48OO534949_nodeLsystemOstring_astOpnodeTT__VKNNDtxlcHt69avZNvnPyiQ_.base = (&NTInode__PH6d39ctBFaDFBx75WzCZNQ_);
NTIarrayL48OO534949_nodeLsystemOstring_astOpnodeTT__VKNNDtxlcHt69avZNvnPyiQ_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_0[179].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[179].offset = offsetof(tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A, _isInternal_2.links);
TM__mff0c158N4EFFNgrs4pcEQ_0[179].typ = (&NTIarrayL48OO534949_nodeLsystemOstring_astOpnodeTT__VKNNDtxlcHt69avZNvnPyiQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[179].name = "links";
NimDT___NOM0ZpqV9bLtofkCilAnZ8A_isInternal[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[179];
TM__mff0c158N4EFFNgrs4pcEQ_0[174].len = 3; TM__mff0c158N4EFFNgrs4pcEQ_0[174].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[174].sons = &TM__mff0c158N4EFFNgrs4pcEQ_41_3[0];
NTInode58objecttype__NOM0ZpqV9bLtofkCilAnZ8A_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[174];
NTInode__PH6d39ctBFaDFBx75WzCZNQ_.size = sizeof(tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A*);
NTInode__PH6d39ctBFaDFBx75WzCZNQ_.align = NIM_ALIGNOF(tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A*);
NTInode__PH6d39ctBFaDFBx75WzCZNQ_.kind = 22;
NTInode__PH6d39ctBFaDFBx75WzCZNQ_.base = (&NTInode58objecttype__NOM0ZpqV9bLtofkCilAnZ8A_);
NTInode__PH6d39ctBFaDFBx75WzCZNQ_.flags = 2;
NTInode__PH6d39ctBFaDFBx75WzCZNQ_.marker = Marker_tyRef__PH6d39ctBFaDFBx75WzCZNQ;
TM__mff0c158N4EFFNgrs4pcEQ_0[173].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[173].offset = offsetof(tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q, root);
TM__mff0c158N4EFFNgrs4pcEQ_0[173].typ = (&NTInode__PH6d39ctBFaDFBx75WzCZNQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[173].name = "root";
TM__mff0c158N4EFFNgrs4pcEQ_40_2[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[180];
TM__mff0c158N4EFFNgrs4pcEQ_0[180].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[180].offset = offsetof(tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q, entries);
TM__mff0c158N4EFFNgrs4pcEQ_0[180].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[180].name = "entries";
TM__mff0c158N4EFFNgrs4pcEQ_0[172].len = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[172].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[172].sons = &TM__mff0c158N4EFFNgrs4pcEQ_40_2[0];
NTIbtree__R2EgvhuH9cLMYvSPesdcu5Q_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[172];
TM__mff0c158N4EFFNgrs4pcEQ_0[171].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[171].offset = offsetof(tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g, Field2);
TM__mff0c158N4EFFNgrs4pcEQ_0[171].typ = (&NTIbtree__R2EgvhuH9cLMYvSPesdcu5Q_);
TM__mff0c158N4EFFNgrs4pcEQ_0[171].name = "Field2";
TM__mff0c158N4EFFNgrs4pcEQ_0[168].len = 3; TM__mff0c158N4EFFNgrs4pcEQ_0[168].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[168].sons = &TM__mff0c158N4EFFNgrs4pcEQ_39_3[0];
NTIkeyvaluepair__Ah6ua9a8WyUOs9aO9afW59cy0g_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[168];
NTIkeyvaluepairseq__3G9aA9cLXaPxuRxMKm3anacQ_.size = sizeof(tySequence__3G9aA9cLXaPxuRxMKm3anacQ*);
NTIkeyvaluepairseq__3G9aA9cLXaPxuRxMKm3anacQ_.align = NIM_ALIGNOF(tySequence__3G9aA9cLXaPxuRxMKm3anacQ*);
NTIkeyvaluepairseq__3G9aA9cLXaPxuRxMKm3anacQ_.kind = 24;
NTIkeyvaluepairseq__3G9aA9cLXaPxuRxMKm3anacQ_.base = (&NTIkeyvaluepair__Ah6ua9a8WyUOs9aO9afW59cy0g_);
NTIkeyvaluepairseq__3G9aA9cLXaPxuRxMKm3anacQ_.flags = 2;
NTIkeyvaluepairseq__3G9aA9cLXaPxuRxMKm3anacQ_.marker = Marker_tySequence__3G9aA9cLXaPxuRxMKm3anacQ;
TM__mff0c158N4EFFNgrs4pcEQ_0[167].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[167].offset = offsetof(tyObject_Table__R7JnJQEipxxOlJWXQz7jWg, data);
TM__mff0c158N4EFFNgrs4pcEQ_0[167].typ = (&NTIkeyvaluepairseq__3G9aA9cLXaPxuRxMKm3anacQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[167].name = "data";
TM__mff0c158N4EFFNgrs4pcEQ_38_2[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[181];
TM__mff0c158N4EFFNgrs4pcEQ_0[181].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[181].offset = offsetof(tyObject_Table__R7JnJQEipxxOlJWXQz7jWg, counter);
TM__mff0c158N4EFFNgrs4pcEQ_0[181].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[181].name = "counter";
TM__mff0c158N4EFFNgrs4pcEQ_0[166].len = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[166].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[166].sons = &TM__mff0c158N4EFFNgrs4pcEQ_38_2[0];
NTItable__R7JnJQEipxxOlJWXQz7jWg_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[166];
TM__mff0c158N4EFFNgrs4pcEQ_0[165].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[165].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, cacheTables);
TM__mff0c158N4EFFNgrs4pcEQ_0[165].typ = (&NTItable__R7JnJQEipxxOlJWXQz7jWg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[165].name = "cacheTables";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[40] = &TM__mff0c158N4EFFNgrs4pcEQ_0[182];
NTItpass__nF9cH4hinXgGEUwO4G2bshw_.size = sizeof(tyTuple__nF9cH4hinXgGEUwO4G2bshw);
NTItpass__nF9cH4hinXgGEUwO4G2bshw_.align = NIM_ALIGNOF(tyTuple__nF9cH4hinXgGEUwO4G2bshw);
NTItpass__nF9cH4hinXgGEUwO4G2bshw_.kind = 18;
NTItpass__nF9cH4hinXgGEUwO4G2bshw_.base = 0;
NTItpass__nF9cH4hinXgGEUwO4G2bshw_.flags = 3;
TM__mff0c158N4EFFNgrs4pcEQ_42_4[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[184];
NTItpassopen__kqPx9c4py2HW6KcFMhNvxtg_.size = sizeof(tyProc__kqPx9c4py2HW6KcFMhNvxtg);
NTItpassopen__kqPx9c4py2HW6KcFMhNvxtg_.align = NIM_ALIGNOF(tyProc__kqPx9c4py2HW6KcFMhNvxtg);
NTItpassopen__kqPx9c4py2HW6KcFMhNvxtg_.kind = 25;
NTItpassopen__kqPx9c4py2HW6KcFMhNvxtg_.base = 0;
NTItpassopen__kqPx9c4py2HW6KcFMhNvxtg_.flags = 3;
TM__mff0c158N4EFFNgrs4pcEQ_0[184].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[184].offset = offsetof(tyTuple__nF9cH4hinXgGEUwO4G2bshw, Field0);
TM__mff0c158N4EFFNgrs4pcEQ_0[184].typ = (&NTItpassopen__kqPx9c4py2HW6KcFMhNvxtg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[184].name = "Field0";
TM__mff0c158N4EFFNgrs4pcEQ_42_4[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[185];
NTItpassprocess__9c6qRjwy7Es8UkDTIUwAfFA_.size = sizeof(tyProc__9c6qRjwy7Es8UkDTIUwAfFA);
NTItpassprocess__9c6qRjwy7Es8UkDTIUwAfFA_.align = NIM_ALIGNOF(tyProc__9c6qRjwy7Es8UkDTIUwAfFA);
NTItpassprocess__9c6qRjwy7Es8UkDTIUwAfFA_.kind = 25;
NTItpassprocess__9c6qRjwy7Es8UkDTIUwAfFA_.base = 0;
NTItpassprocess__9c6qRjwy7Es8UkDTIUwAfFA_.flags = 3;
TM__mff0c158N4EFFNgrs4pcEQ_0[185].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[185].offset = offsetof(tyTuple__nF9cH4hinXgGEUwO4G2bshw, Field1);
TM__mff0c158N4EFFNgrs4pcEQ_0[185].typ = (&NTItpassprocess__9c6qRjwy7Es8UkDTIUwAfFA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[185].name = "Field1";
TM__mff0c158N4EFFNgrs4pcEQ_42_4[2] = &TM__mff0c158N4EFFNgrs4pcEQ_0[186];
NTItpassclose__mv4BsRs5VEnhcxzV6pQU5w_.size = sizeof(tyProc__mv4BsRs5VEnhcxzV6pQU5w);
NTItpassclose__mv4BsRs5VEnhcxzV6pQU5w_.align = NIM_ALIGNOF(tyProc__mv4BsRs5VEnhcxzV6pQU5w);
NTItpassclose__mv4BsRs5VEnhcxzV6pQU5w_.kind = 25;
NTItpassclose__mv4BsRs5VEnhcxzV6pQU5w_.base = 0;
NTItpassclose__mv4BsRs5VEnhcxzV6pQU5w_.flags = 3;
TM__mff0c158N4EFFNgrs4pcEQ_0[186].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[186].offset = offsetof(tyTuple__nF9cH4hinXgGEUwO4G2bshw, Field2);
TM__mff0c158N4EFFNgrs4pcEQ_0[186].typ = (&NTItpassclose__mv4BsRs5VEnhcxzV6pQU5w_);
TM__mff0c158N4EFFNgrs4pcEQ_0[186].name = "Field2";
TM__mff0c158N4EFFNgrs4pcEQ_42_4[3] = &TM__mff0c158N4EFFNgrs4pcEQ_0[187];
TM__mff0c158N4EFFNgrs4pcEQ_0[187].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[187].offset = offsetof(tyTuple__nF9cH4hinXgGEUwO4G2bshw, Field3);
TM__mff0c158N4EFFNgrs4pcEQ_0[187].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[187].name = "Field3";
TM__mff0c158N4EFFNgrs4pcEQ_0[183].len = 4; TM__mff0c158N4EFFNgrs4pcEQ_0[183].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[183].sons = &TM__mff0c158N4EFFNgrs4pcEQ_42_4[0];
NTItpass__nF9cH4hinXgGEUwO4G2bshw_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[183];
NTIseqLtpassT__bPFv6ypvvCX2A9a9al8utL2Q_.size = sizeof(tySequence__bPFv6ypvvCX2A9a9al8utL2Q*);
NTIseqLtpassT__bPFv6ypvvCX2A9a9al8utL2Q_.align = NIM_ALIGNOF(tySequence__bPFv6ypvvCX2A9a9al8utL2Q*);
NTIseqLtpassT__bPFv6ypvvCX2A9a9al8utL2Q_.kind = 24;
NTIseqLtpassT__bPFv6ypvvCX2A9a9al8utL2Q_.base = (&NTItpass__nF9cH4hinXgGEUwO4G2bshw_);
NTIseqLtpassT__bPFv6ypvvCX2A9a9al8utL2Q_.flags = 2;
NTIseqLtpassT__bPFv6ypvvCX2A9a9al8utL2Q_.marker = Marker_tySequence__bPFv6ypvvCX2A9a9al8utL2Q;
TM__mff0c158N4EFFNgrs4pcEQ_0[182].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[182].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, passes);
TM__mff0c158N4EFFNgrs4pcEQ_0[182].typ = (&NTIseqLtpassT__bPFv6ypvvCX2A9a9al8utL2Q_);
TM__mff0c158N4EFFNgrs4pcEQ_0[182].name = "passes";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[41] = &TM__mff0c158N4EFFNgrs4pcEQ_0[188];
NTIprocLgraph58modulegraph_s58psym_info58tlineinfoTLOnimcallOT__1CO5eEh25fBKUWGagpikwg_.size = sizeof(tyProc__1CO5eEh25fBKUWGagpikwg);
NTIprocLgraph58modulegraph_s58psym_info58tlineinfoTLOnimcallOT__1CO5eEh25fBKUWGagpikwg_.align = NIM_ALIGNOF(tyProc__1CO5eEh25fBKUWGagpikwg);
NTIprocLgraph58modulegraph_s58psym_info58tlineinfoTLOnimcallOT__1CO5eEh25fBKUWGagpikwg_.kind = 25;
NTIprocLgraph58modulegraph_s58psym_info58tlineinfoTLOnimcallOT__1CO5eEh25fBKUWGagpikwg_.base = 0;
NTIprocLgraph58modulegraph_s58psym_info58tlineinfoTLOnimcallOT__1CO5eEh25fBKUWGagpikwg_.flags = 3;
TM__mff0c158N4EFFNgrs4pcEQ_0[188].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[188].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, onDefinition);
TM__mff0c158N4EFFNgrs4pcEQ_0[188].typ = (&NTIprocLgraph58modulegraph_s58psym_info58tlineinfoTLOnimcallOT__1CO5eEh25fBKUWGagpikwg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[188].name = "onDefinition";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[42] = &TM__mff0c158N4EFFNgrs4pcEQ_0[189];
TM__mff0c158N4EFFNgrs4pcEQ_0[189].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[189].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, onDefinitionResolveForward);
TM__mff0c158N4EFFNgrs4pcEQ_0[189].typ = (&NTIprocLgraph58modulegraph_s58psym_info58tlineinfoTLOnimcallOT__1CO5eEh25fBKUWGagpikwg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[189].name = "onDefinitionResolveForward";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[43] = &TM__mff0c158N4EFFNgrs4pcEQ_0[190];
TM__mff0c158N4EFFNgrs4pcEQ_0[190].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[190].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, onUsage);
TM__mff0c158N4EFFNgrs4pcEQ_0[190].typ = (&NTIprocLgraph58modulegraph_s58psym_info58tlineinfoTLOnimcallOT__1CO5eEh25fBKUWGagpikwg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[190].name = "onUsage";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[44] = &TM__mff0c158N4EFFNgrs4pcEQ_0[191];
TM__mff0c158N4EFFNgrs4pcEQ_0[191].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[191].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, globalDestructors);
TM__mff0c158N4EFFNgrs4pcEQ_0[191].typ = (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_);
TM__mff0c158N4EFFNgrs4pcEQ_0[191].name = "globalDestructors";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[45] = &TM__mff0c158N4EFFNgrs4pcEQ_0[192];
NTIprocLgraph58modulegraph_owner58psym_body58pnodeTLOnimcallOT__VcUg5jOhttLagdxUmVN8Tg_.size = sizeof(tyProc__VcUg5jOhttLagdxUmVN8Tg);
NTIprocLgraph58modulegraph_owner58psym_body58pnodeTLOnimcallOT__VcUg5jOhttLagdxUmVN8Tg_.align = NIM_ALIGNOF(tyProc__VcUg5jOhttLagdxUmVN8Tg);
NTIprocLgraph58modulegraph_owner58psym_body58pnodeTLOnimcallOT__VcUg5jOhttLagdxUmVN8Tg_.kind = 25;
NTIprocLgraph58modulegraph_owner58psym_body58pnodeTLOnimcallOT__VcUg5jOhttLagdxUmVN8Tg_.base = 0;
NTIprocLgraph58modulegraph_owner58psym_body58pnodeTLOnimcallOT__VcUg5jOhttLagdxUmVN8Tg_.flags = 3;
TM__mff0c158N4EFFNgrs4pcEQ_0[192].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[192].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, strongSemCheck);
TM__mff0c158N4EFFNgrs4pcEQ_0[192].typ = (&NTIprocLgraph58modulegraph_owner58psym_body58pnodeTLOnimcallOT__VcUg5jOhttLagdxUmVN8Tg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[192].name = "strongSemCheck";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[46] = &TM__mff0c158N4EFFNgrs4pcEQ_0[193];
NTIprocLgraph58modulegraph_formal58ptype_actual58ptypeT58boolLOnimcallOT__XOkru1xuh2bHzmkw1UYzLA_.size = sizeof(tyProc__XOkru1xuh2bHzmkw1UYzLA);
NTIprocLgraph58modulegraph_formal58ptype_actual58ptypeT58boolLOnimcallOT__XOkru1xuh2bHzmkw1UYzLA_.align = NIM_ALIGNOF(tyProc__XOkru1xuh2bHzmkw1UYzLA);
NTIprocLgraph58modulegraph_formal58ptype_actual58ptypeT58boolLOnimcallOT__XOkru1xuh2bHzmkw1UYzLA_.kind = 25;
NTIprocLgraph58modulegraph_formal58ptype_actual58ptypeT58boolLOnimcallOT__XOkru1xuh2bHzmkw1UYzLA_.base = 0;
NTIprocLgraph58modulegraph_formal58ptype_actual58ptypeT58boolLOnimcallOT__XOkru1xuh2bHzmkw1UYzLA_.flags = 3;
TM__mff0c158N4EFFNgrs4pcEQ_0[193].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[193].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, compatibleProps);
TM__mff0c158N4EFFNgrs4pcEQ_0[193].typ = (&NTIprocLgraph58modulegraph_formal58ptype_actual58ptypeT58boolLOnimcallOT__XOkru1xuh2bHzmkw1UYzLA_);
TM__mff0c158N4EFFNgrs4pcEQ_0[193].name = "compatibleProps";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[47] = &TM__mff0c158N4EFFNgrs4pcEQ_0[194];
TM__mff0c158N4EFFNgrs4pcEQ_0[194].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[194].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, idgen);
TM__mff0c158N4EFFNgrs4pcEQ_0[194].typ = (&NTIidgenerator__M4gwBCp6eTol0yFD6lAxTQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[194].name = "idgen";
TM__mff0c158N4EFFNgrs4pcEQ_2_49[48] = &TM__mff0c158N4EFFNgrs4pcEQ_0[195];
NTIoperators__dR4s9bCO53rZjV9a30JJfUOg_.size = sizeof(tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg);
NTIoperators__dR4s9bCO53rZjV9a30JJfUOg_.align = NIM_ALIGNOF(tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg);
NTIoperators__dR4s9bCO53rZjV9a30JJfUOg_.kind = 18;
NTIoperators__dR4s9bCO53rZjV9a30JJfUOg_.base = 0;
NTIoperators__dR4s9bCO53rZjV9a30JJfUOg_.flags = 2;
TM__mff0c158N4EFFNgrs4pcEQ_43_13[0] = &TM__mff0c158N4EFFNgrs4pcEQ_0[197];
TM__mff0c158N4EFFNgrs4pcEQ_0[197].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[197].offset = offsetof(tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg, opNot);
TM__mff0c158N4EFFNgrs4pcEQ_0[197].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[197].name = "opNot";
TM__mff0c158N4EFFNgrs4pcEQ_43_13[1] = &TM__mff0c158N4EFFNgrs4pcEQ_0[198];
TM__mff0c158N4EFFNgrs4pcEQ_0[198].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[198].offset = offsetof(tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg, opContains);
TM__mff0c158N4EFFNgrs4pcEQ_0[198].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[198].name = "opContains";
TM__mff0c158N4EFFNgrs4pcEQ_43_13[2] = &TM__mff0c158N4EFFNgrs4pcEQ_0[199];
TM__mff0c158N4EFFNgrs4pcEQ_0[199].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[199].offset = offsetof(tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg, opLe);
TM__mff0c158N4EFFNgrs4pcEQ_0[199].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[199].name = "opLe";
TM__mff0c158N4EFFNgrs4pcEQ_43_13[3] = &TM__mff0c158N4EFFNgrs4pcEQ_0[200];
TM__mff0c158N4EFFNgrs4pcEQ_0[200].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[200].offset = offsetof(tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg, opLt);
TM__mff0c158N4EFFNgrs4pcEQ_0[200].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[200].name = "opLt";
TM__mff0c158N4EFFNgrs4pcEQ_43_13[4] = &TM__mff0c158N4EFFNgrs4pcEQ_0[201];
TM__mff0c158N4EFFNgrs4pcEQ_0[201].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[201].offset = offsetof(tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg, opAnd);
TM__mff0c158N4EFFNgrs4pcEQ_0[201].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[201].name = "opAnd";
TM__mff0c158N4EFFNgrs4pcEQ_43_13[5] = &TM__mff0c158N4EFFNgrs4pcEQ_0[202];
TM__mff0c158N4EFFNgrs4pcEQ_0[202].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[202].offset = offsetof(tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg, opOr);
TM__mff0c158N4EFFNgrs4pcEQ_0[202].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[202].name = "opOr";
TM__mff0c158N4EFFNgrs4pcEQ_43_13[6] = &TM__mff0c158N4EFFNgrs4pcEQ_0[203];
TM__mff0c158N4EFFNgrs4pcEQ_0[203].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[203].offset = offsetof(tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg, opIsNil);
TM__mff0c158N4EFFNgrs4pcEQ_0[203].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[203].name = "opIsNil";
TM__mff0c158N4EFFNgrs4pcEQ_43_13[7] = &TM__mff0c158N4EFFNgrs4pcEQ_0[204];
TM__mff0c158N4EFFNgrs4pcEQ_0[204].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[204].offset = offsetof(tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg, opEq);
TM__mff0c158N4EFFNgrs4pcEQ_0[204].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[204].name = "opEq";
TM__mff0c158N4EFFNgrs4pcEQ_43_13[8] = &TM__mff0c158N4EFFNgrs4pcEQ_0[205];
TM__mff0c158N4EFFNgrs4pcEQ_0[205].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[205].offset = offsetof(tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg, opAdd);
TM__mff0c158N4EFFNgrs4pcEQ_0[205].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[205].name = "opAdd";
TM__mff0c158N4EFFNgrs4pcEQ_43_13[9] = &TM__mff0c158N4EFFNgrs4pcEQ_0[206];
TM__mff0c158N4EFFNgrs4pcEQ_0[206].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[206].offset = offsetof(tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg, opSub);
TM__mff0c158N4EFFNgrs4pcEQ_0[206].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[206].name = "opSub";
TM__mff0c158N4EFFNgrs4pcEQ_43_13[10] = &TM__mff0c158N4EFFNgrs4pcEQ_0[207];
TM__mff0c158N4EFFNgrs4pcEQ_0[207].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[207].offset = offsetof(tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg, opMul);
TM__mff0c158N4EFFNgrs4pcEQ_0[207].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[207].name = "opMul";
TM__mff0c158N4EFFNgrs4pcEQ_43_13[11] = &TM__mff0c158N4EFFNgrs4pcEQ_0[208];
TM__mff0c158N4EFFNgrs4pcEQ_0[208].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[208].offset = offsetof(tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg, opDiv);
TM__mff0c158N4EFFNgrs4pcEQ_0[208].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[208].name = "opDiv";
TM__mff0c158N4EFFNgrs4pcEQ_43_13[12] = &TM__mff0c158N4EFFNgrs4pcEQ_0[209];
TM__mff0c158N4EFFNgrs4pcEQ_0[209].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[209].offset = offsetof(tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg, opLen);
TM__mff0c158N4EFFNgrs4pcEQ_0[209].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[209].name = "opLen";
TM__mff0c158N4EFFNgrs4pcEQ_0[196].len = 13; TM__mff0c158N4EFFNgrs4pcEQ_0[196].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[196].sons = &TM__mff0c158N4EFFNgrs4pcEQ_43_13[0];
NTIoperators__dR4s9bCO53rZjV9a30JJfUOg_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[196];
TM__mff0c158N4EFFNgrs4pcEQ_0[195].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[195].offset = offsetof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg, operators);
TM__mff0c158N4EFFNgrs4pcEQ_0[195].typ = (&NTIoperators__dR4s9bCO53rZjV9a30JJfUOg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[195].name = "operators";
TM__mff0c158N4EFFNgrs4pcEQ_0[0].len = 49; TM__mff0c158N4EFFNgrs4pcEQ_0[0].kind = 2; TM__mff0c158N4EFFNgrs4pcEQ_0[0].sons = &TM__mff0c158N4EFFNgrs4pcEQ_2_49[0];
NTImodulegraph58objecttype__nOSrcYqJTxXt2ptNc0gnWg_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[0];
NTImodulegraph__AcDjMYSN0KX1UsX3HvPu2w_.size = sizeof(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg*);
NTImodulegraph__AcDjMYSN0KX1UsX3HvPu2w_.align = NIM_ALIGNOF(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg*);
NTImodulegraph__AcDjMYSN0KX1UsX3HvPu2w_.kind = 22;
NTImodulegraph__AcDjMYSN0KX1UsX3HvPu2w_.base = (&NTImodulegraph58objecttype__nOSrcYqJTxXt2ptNc0gnWg_);
NTImodulegraph__AcDjMYSN0KX1UsX3HvPu2w_.flags = 2;
NTImodulegraph__AcDjMYSN0KX1UsX3HvPu2w_.marker = Marker_tyRef__AcDjMYSN0KX1UsX3HvPu2w;
NTItpasscontext__dmp6pRpfXxJk6gIZHkm7dw_.size = sizeof(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw);
NTItpasscontext__dmp6pRpfXxJk6gIZHkm7dw_.align = NIM_ALIGNOF(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw);
NTItpasscontext__dmp6pRpfXxJk6gIZHkm7dw_.kind = 17;
NTItpasscontext__dmp6pRpfXxJk6gIZHkm7dw_.base = (&NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_);
TM__mff0c158N4EFFNgrs4pcEQ_0[210].kind = 1;
TM__mff0c158N4EFFNgrs4pcEQ_0[210].offset = offsetof(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw, idgen);
TM__mff0c158N4EFFNgrs4pcEQ_0[210].typ = (&NTIidgenerator__M4gwBCp6eTol0yFD6lAxTQ_);
TM__mff0c158N4EFFNgrs4pcEQ_0[210].name = "idgen";
NTItpasscontext__dmp6pRpfXxJk6gIZHkm7dw_.node = &TM__mff0c158N4EFFNgrs4pcEQ_0[210];
}

