/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg;
typedef struct tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA;
typedef struct tySequence__dLJ0v9cLHnWw9bA0ZQgPURgA tySequence__dLJ0v9cLHnWw9bA0ZQgPURgA;
typedef struct tySequence__zeatLyX5s1CrMAiU9c9bWBSQ tySequence__zeatLyX5s1CrMAiU9c9bWBSQ;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A;
typedef struct tyObject_Connection__SFxQPgR9b9aWd2frrlyFQ2mA tyObject_Connection__SFxQPgR9b9aWd2frrlyFQ2mA;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
typedef struct tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tySequence__RNhZxf20g9beyq5VBOGxhDg tySequence__RNhZxf20g9beyq5VBOGxhDg;
typedef struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ;
typedef struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ tySequence__lFbCtu5P2Kf7YDYtGjkxAQ;
typedef struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA;
typedef struct tySequence__ijtae5OneaLys0hN9alAicA tySequence__ijtae5OneaLys0hN9alAicA;
typedef struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w;
typedef struct tySequence__SerjNoUujW2dUouVBrJiCw tySequence__SerjNoUujW2dUouVBrJiCw;
typedef struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyObject_Table__r0v8BdcBPKhl73K8p2VMUA;
typedef struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g tySequence__K9agbtcb0qPZuSJFXB9cTe6g;
typedef struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg;
typedef struct tySequence__m88qdML9cQOuqGAQn6XWL1A tySequence__m88qdML9cQOuqGAQn6XWL1A;
typedef struct tyObject_Table__1hIWbTQWYT4BmhdESze57A tyObject_Table__1hIWbTQWYT4BmhdESze57A;
typedef struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ tySequence__naEbXEp9b9aiW1zXJorqf9cXQ;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA;
typedef struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw;
typedef struct tySequence__ed0C0uAUZPhvw3RAc5hfYg tySequence__ed0C0uAUZPhvw3RAc5hfYg;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tyObject_Table__imojfg883tkWsWJwyshGqQ tyObject_Table__imojfg883tkWsWJwyshGqQ;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg tyObject_Table__BCPh85PHtwxox9bv7NLFrlg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA;
typedef struct tySequence__KgiZ29chkJAD01p9aLRB32qw tySequence__KgiZ29chkJAD01p9aLRB32qw;
typedef struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A tyObject_Table__LM44poVdVEn4Mo4N4L8c3A;
typedef struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw tySequence__rkYRZrbHVYL3nhXlQW3K9bw;
typedef struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ tySequence__IRFEb1e9bxgbJLuB5xrdZsQ;
typedef struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ;
typedef struct tySequence__YmPd0eWfcTfrVYrthlXPYA tySequence__YmPd0eWfcTfrVYrthlXPYA;
typedef struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q;
typedef struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg tySequence__Hz5SYwQU29b9aFLt09blvVQPg;
typedef struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg tyObject_Table__R7JnJQEipxxOlJWXQz7jWg;
typedef struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ tySequence__3G9aA9cLXaPxuRxMKm3anacQ;
typedef struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q tySequence__bPFv6ypvvCX2A9a9al8utL2Q;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tySequence__ugNUvYxERl9aaj9b1GeCSDAg tySequence__ugNUvYxERl9aaj9b1GeCSDAg;
typedef struct tyTuple__BHqtUW7ND5oD8ApFSF1wwQ tyTuple__BHqtUW7ND5oD8ApFSF1wwQ;
typedef struct tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw;
typedef struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ;
typedef struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g tySequence__qeAsXh2i1GAL5Nl0g3OP8g;
typedef struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg;
typedef struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg;
typedef struct tySequence__4Murtwnm0Fyc7F9acrytEXw tySequence__4Murtwnm0Fyc7F9acrytEXw;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw;
typedef struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg tySequence__QnmOtn1Iv4LvxOXoMn8Rbg;
typedef struct tySequence__oKtVqsc9bQVCNyrijELM4OQ tySequence__oKtVqsc9bQVCNyrijELM4OQ;
typedef struct tySequence__qy6Iwdy00wN560qud54HTg tySequence__qy6Iwdy00wN560qud54HTg;
typedef struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ tySequence__k67v9bwvvQDmS1ynyGGUbeQ;
typedef struct tySequence__cLsClAAfd0MKkoBQVyvdvw tySequence__cLsClAAfd0MKkoBQVyvdvw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg tySequence__q9bTuOB0JXh1iZ3CSGdRLbg;
typedef struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw;
typedef struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ;
typedef struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ;
typedef struct tySequence__C3r8jsj9chA4sIlYfDN5aDw tySequence__C3r8jsj9chA4sIlYfDN5aDw;
typedef struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ;
typedef struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg tyTuple__UluY8x0Nj6cp9b0o88wJ0lg;
typedef struct tySequence__dlD6tEGzYLLpKVq3XwuFlA tySequence__dlD6tEGzYLLpKVq3XwuFlA;
typedef struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ;
typedef struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg;
typedef struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ;
typedef struct tyTuple__rZZA0skon1OsHdiEvT8RZQ tyTuple__rZZA0skon1OsHdiEvT8RZQ;
typedef struct tySequence__6OFCSvqRaxyEgUqWtnZSlw tySequence__6OFCSvqRaxyEgUqWtnZSlw;
typedef struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q;
typedef struct tySequence__UnGSk9aaLosDroi2QDrlOfQ tySequence__UnGSk9aaLosDroi2QDrlOfQ;
typedef struct tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA;
typedef struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA tyTuple__q13Zt16VkCqu6Zg5jWqwHA;
typedef struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA tyTuple__aWN9bNzF9bubXNJV9ciomgpfA;
typedef struct tySequence__m4PVWjcAAjfxlwJxLkKn8A tySequence__m4PVWjcAAjfxlwJxLkKn8A;
typedef struct tyTuple__RWXAsQlFoGYyEQZp1G65sg tyTuple__RWXAsQlFoGYyEQZp1G65sg;
typedef struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg;
typedef struct tyTuple__RmGJuqOgEaHckHndh0LEsw tyTuple__RmGJuqOgEaHckHndh0LEsw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__J4cxakKjhKxTIJR9bojMmXw tyTuple__J4cxakKjhKxTIJR9bojMmXw;
typedef struct tySequence__i89c5kdtWKzK3OEiI81pkkw tySequence__i89c5kdtWKzK3OEiI81pkkw;
typedef struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A;
typedef struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ;
typedef struct tySequence__GR8qmV1kNRcoQ2g76VFy3A tySequence__GR8qmV1kNRcoQ2g76VFy3A;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyTuple__a7QginWFapakKbWJBJ2vfA tyTuple__a7QginWFapakKbWJBJ2vfA;
typedef struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__kbX6x85REySUrk9auORL0vw tyTuple__kbX6x85REySUrk9auORL0vw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g;
typedef struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q;
typedef struct tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A;
typedef struct tyTuple__nF9cH4hinXgGEUwO4G2bshw tyTuple__nF9cH4hinXgGEUwO4G2bshw;
typedef struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA;
typedef struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__PsEhl3dzznmmJiLAuIXZOg tyTuple__PsEhl3dzznmmJiLAuIXZOg;
typedef struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w;
typedef struct tyTuple__Db8CrQifKGIsKc3w71w7Lw tyTuple__Db8CrQifKGIsKc3w71w7Lw;
typedef struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg;
typedef struct tySequence__lo3S1lKyiPLhGGB9cBawd6A tySequence__lo3S1lKyiPLhGGB9cBawd6A;
typedef struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ;
typedef struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw tyTuple__FEYH9alRJhHD0uTKF2vnIqw;
typedef struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA;
typedef struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA;
typedef struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw;
typedef struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg tyTuple__VUJ5Hjm4tKAResBsRHJvYg;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef NU8 tySet_tyEnum_Goal__YflPrGhMLgZ4bbrBBVpmOA;
struct tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA {
NI abstractTime;
tySequence__dLJ0v9cLHnWw9bA0ZQgPURgA* s;
tySequence__zeatLyX5s1CrMAiU9c9bWBSQ* graphs;
tySet_tyEnum_Goal__YflPrGhMLgZ4bbrBBVpmOA goals;
NIM_BOOL unanalysableMutation;
NI inAsgnSource;
NI inConstructor;
NI inNoSideEffectSection;
NI inConditional;
NI inLoop;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g;
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInst;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg uniqueId;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
typedef NU8 tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w;
struct tyObject_Connection__SFxQPgR9b9aWd2frrlyFQ2mA {
tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w kind;
union{
NI parent;
NI graphIndex;
};
};
typedef NU8 tySet_tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw;
struct tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A {
tyObject_Connection__SFxQPgR9b9aWd2frrlyFQ2mA con;
tySet_tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw flags;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI reassignedTo;
NI aliveStart;
NI aliveEnd;
tySequence__qwqHTkRvwhrRyENtudHQ7g* borrowsFrom;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw;
typedef NU8 tySet_tyEnum_SubgraphFlag__YymRBOaunI7GAAzxsJI39cA;
struct tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* param;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw mutatedHere;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw connectedVia;
tySet_tyEnum_SubgraphFlag__YymRBOaunI7GAAzxsJI39cA flags;
NI maxMutation;
NI minConnection;
tySequence__qwqHTkRvwhrRyENtudHQ7g* mutations;
};
typedef NU8 tyEnum_SubgraphFlag__YymRBOaunI7GAAzxsJI39cA;
typedef NU8 tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg[9];
typedef NU8 tyEnum_Goal__YflPrGhMLgZ4bbrBBVpmOA;
typedef NU8 tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ;
typedef NU8 tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA {
tySequence__ijtae5OneaLys0hN9alAicA* data;
NI counter;
};
struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w {
tySequence__SerjNoUujW2dUouVBrJiCw* data;
NI counter;
};
struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA {
tySequence__K9agbtcb0qPZuSJFXB9cTe6g* data;
NI counter;
};
typedef tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyArray__46hjIasL27aUz9c7kgtWooQ[5];
struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg {
tySequence__m88qdML9cQOuqGAQn6XWL1A* data;
NI counter;
};
struct tyObject_Table__1hIWbTQWYT4BmhdESze57A {
tySequence__naEbXEp9b9aiW1zXJorqf9cXQ* data;
NI counter;
};
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
};
struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw {
NI counter;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* data;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__imojfg883tkWsWJwyshGqQ {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA {
tySequence__KgiZ29chkJAD01p9aLRB32qw* data;
NI counter;
};
struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A {
tySequence__rkYRZrbHVYL3nhXlQW3K9bw* data;
NI counter;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg[65];
struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ {
tySequence__YmPd0eWfcTfrVYrthlXPYA* data;
NI counter;
};
struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__I6rzVhdiYtUh7jwWJQoeyw) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__EQOAUyRkp9c3eeiGlHvCThA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q {
tySequence__Hz5SYwQU29b9aFLt09blvVQPg* data;
NI counter;
};
struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg {
tySequence__3G9aA9cLXaPxuRxMKm3anacQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__1CO5eEh25fBKUWGagpikwg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
typedef N_NIMCALL_PTR(void, tyProc__VcUg5jOhttLagdxUmVN8Tg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__XOkru1xuh2bHzmkw1UYzLA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formal, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* actual);
struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opNot;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opContains;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLe;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLt;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAnd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opOr;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opIsNil;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opEq;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAdd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opSub;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opMul;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opDiv;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg {
tySequence__RNhZxf20g9beyq5VBOGxhDg* ifaces;
tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* packed_0;
tySequence__lFbCtu5P2Kf7YDYtGjkxAQ* encoders;
tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA typeInstCache;
tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w procInstCache;
tyArray__46hjIasL27aUz9c7kgtWooQ attachedOps;
tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg methodsPerType;
tyObject_Table__1hIWbTQWYT4BmhdESze57A enumToStringProcs;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw emittedTypeInfo;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA startupPackedConfig;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw deps;
tyObject_Table__imojfg883tkWsWJwyshGqQ importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__BCPh85PHtwxox9bv7NLFrlg inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* usageSym;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* owners;
tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA suggestSymbols;
tyObject_Table__LM44poVdVEn4Mo4N4L8c3A suggestErrors;
tySequence__IRFEb1e9bxgbJLuB5xrdZsQ* methods;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* systemModule;
tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg sysTypes;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw compilerprocs;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw exposed;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageTypes;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* emptyNode;
tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ canonTypes;
tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw symBodyHashes;
tyProc__I6rzVhdiYtUh7jwWJQoeyw importModuleCallback;
tyProc__EQOAUyRkp9c3eeiGlHvCThA includeFileCallback;
tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q cacheSeqs;
tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g cacheCounters;
tyObject_Table__R7JnJQEipxxOlJWXQz7jWg cacheTables;
tySequence__bPFv6ypvvCX2A9a9al8utL2Q* passes;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinition;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinitionResolveForward;
tyProc__1CO5eEh25fBKUWGagpikwg onUsage;
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* globalDestructors;
tyProc__VcUg5jOhttLagdxUmVN8Tg strongSemCheck;
tyProc__XOkru1xuh2bHzmkw1UYzLA compatibleProps;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg operators;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
struct tyTuple__BHqtUW7ND5oD8ApFSF1wwQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field0;
NI Field1;
};
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__YqnJwApcJpsqiob8SlhPnA) (tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
typedef NU8 tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw {
NI a;
NI b;
};
struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg {
NI id;
NimStringDesc* s;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* next;
NI h;
};
struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* converters;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* patterns;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* pureEnums;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interf;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interfHidden;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* uniqueName;
};
typedef NU8 tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg;
struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg {
tySequence__4Murtwnm0Fyc7F9acrytEXw* nodes;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ;
struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ {
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw {
tySequence__IHUFRsFxZNv7YydiUO2esQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag {
NimStringDesc* definedSymbols;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA moduleFlags;
tySequence__PXIzfWocnrafGz5p3CP5LA* includes;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* imports;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg toReplay;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg topLevel;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg bodies;
tySequence__b89aLriiJnVTD186H6zNIgg* exports;
tySequence__b89aLriiJnVTD186H6zNIgg* hidden;
tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw* reexports;
tySequence__b89aLriiJnVTD186H6zNIgg* compilerProcs;
tySequence__48JTohSgTy339bRxHzUD8KA* converters;
tySequence__48JTohSgTy339bRxHzUD8KA* methods;
tySequence__48JTohSgTy339bRxHzUD8KA* trmacros;
tySequence__48JTohSgTy339bRxHzUD8KA* pureEnums;
tySequence__QnmOtn1Iv4LvxOXoMn8Rbg* macroUsages;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* typeInstCache;
tySequence__qy6Iwdy00wN560qud54HTg* procInstCache;
tySequence__k67v9bwvvQDmS1ynyGGUbeQ* attachedOps;
tySequence__cLsClAAfd0MKkoBQVyvdvw* methodsPerType;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* enumToStringProcs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* emittedTypeInfo;
tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ backendFlags;
tySequence__q9bTuOB0JXh1iZ3CSGdRLbg* syms;
tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw* types;
tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ strings;
tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw numbers;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA cfg;
};
struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ {
tySequence__C3r8jsj9chA4sIlYfDN5aDw* data;
NI counter;
};
struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg {
tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg status;
NIM_BOOL symsInit;
NIM_BOOL typesInit;
NIM_BOOL loadedButAliveSetChanged;
tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag fromDisk;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* syms;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* types;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ iface;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ ifaceHidden;
};
struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ {
tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* data;
NI counter;
};
struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ {
NI32 thisModule;
NI32 lastFile;
NU32 lastLit;
tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ filenames;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* pendingTypes;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* pendingSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw typeMarker;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw symMarker;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
};
struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ {
NU32 module;
NI32 item;
};
struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg {
NI module;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ packed_0;
};
struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
};
struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__dlD6tEGzYLLpKVq3XwuFlA* Field2;
};
struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q {
NI module;
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg sym;
tySequence__UnGSk9aaLosDroi2QDrlOfQ* concreteTypes;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__rZZA0skon1OsHdiEvT8RZQ {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__6OFCSvqRaxyEgUqWtnZSlw* Field2;
};
struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field2;
};
struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
};
struct tyTuple__RWXAsQlFoGYyEQZp1G65sg {
NI Field0;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field1;
};
struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__m4PVWjcAAjfxlwJxLkKn8A* Field2;
};
struct tyTuple__RmGJuqOgEaHckHndh0LEsw {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field2;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
};
struct tyTuple__J4cxakKjhKxTIJR9bojMmXw {
NI Field0;
NI32 Field1;
tySequence__i89c5kdtWKzK3OEiI81pkkw* Field2;
};
struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ {
NI Field0;
NI32 Field1;
tySequence__GR8qmV1kNRcoQ2g76VFy3A* Field2;
};
struct tyTuple__a7QginWFapakKbWJBJ2vfA {
tySequence__ed0C0uAUZPhvw3RAc5hfYg* Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__kbX6x85REySUrk9auORL0vw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q {
tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A* root;
NI entries;
};
struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, tyProc__kqPx9c4py2HW6KcFMhNvxtg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__9c6qRjwy7Es8UkDTIUwAfFA) (tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__mv4BsRs5VEnhcxzV6pQU5w) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
struct tyTuple__nF9cH4hinXgGEUwO4G2bshw {
tyProc__kqPx9c4py2HW6KcFMhNvxtg Field0;
tyProc__9c6qRjwy7Es8UkDTIUwAfFA Field1;
tyProc__mv4BsRs5VEnhcxzV6pQU5w Field2;
NIM_BOOL Field3;
};
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
NU32 Field0;
NimStringDesc* Field1;
};
struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA {
NU16 line;
NI16 col;
NU32 file;
};
struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA {
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
NI32 operand;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeId_0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
};
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
NU32 Field0;
NI32 Field1;
};
struct tyTuple__PsEhl3dzznmmJiLAuIXZOg {
NU32 Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA Field1;
};
struct tyTuple__Db8CrQifKGIsKc3w71w7Lw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ key;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* concreteTypes;
};
typedef NU8 tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ;
struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ {
tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
NI Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
typedef NU8 tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ;
struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA {
tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
NU32 name;
NI32 path;
};
struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA {
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
NU32 name;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typ;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
NI32 ast;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ guard;
NI bitsize;
NI alignment;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
NU32 externalName;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw locFlags;
tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA annex;
NI32 constraint;
};
struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw {
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* types;
NI32 n;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeInst;
NI32 nonUniqueId;
};
struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg {
NI Field0;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* Field1;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* Field2;
};
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
NI Field0;
NI32 Field1;
NU32 Field2;
};
struct tySequence__dLJ0v9cLHnWw9bA0ZQgPURgA {
  TGenericSeq Sup;
  tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A data[SEQ_DECL_SIZE];
};
struct tySequence__zeatLyX5s1CrMAiU9c9bWBSQ {
  TGenericSeq Sup;
  tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ data[SEQ_DECL_SIZE];
};
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  TGenericSeq Sup;
  NI data[SEQ_DECL_SIZE];
};
struct tySequence__ugNUvYxERl9aaj9b1GeCSDAg {
  TGenericSeq Sup;
  tyTuple__BHqtUW7ND5oD8ApFSF1wwQ data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__RNhZxf20g9beyq5VBOGxhDg {
  TGenericSeq Sup;
  tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ data[SEQ_DECL_SIZE];
};
struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ {
  TGenericSeq Sup;
  tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg data[SEQ_DECL_SIZE];
};
struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ {
  TGenericSeq Sup;
  tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ data[SEQ_DECL_SIZE];
};
struct tySequence__dlD6tEGzYLLpKVq3XwuFlA {
  TGenericSeq Sup;
  tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ data[SEQ_DECL_SIZE];
};
struct tySequence__ijtae5OneaLys0hN9alAicA {
  TGenericSeq Sup;
  tyTuple__UluY8x0Nj6cp9b0o88wJ0lg data[SEQ_DECL_SIZE];
};
struct tySequence__6OFCSvqRaxyEgUqWtnZSlw {
  TGenericSeq Sup;
  tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q data[SEQ_DECL_SIZE];
};
struct tySequence__SerjNoUujW2dUouVBrJiCw {
  TGenericSeq Sup;
  tyTuple__rZZA0skon1OsHdiEvT8RZQ data[SEQ_DECL_SIZE];
};
struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g {
  TGenericSeq Sup;
  tyTuple__q13Zt16VkCqu6Zg5jWqwHA data[SEQ_DECL_SIZE];
};
struct tySequence__m4PVWjcAAjfxlwJxLkKn8A {
  TGenericSeq Sup;
  tyTuple__RWXAsQlFoGYyEQZp1G65sg data[SEQ_DECL_SIZE];
};
struct tySequence__m88qdML9cQOuqGAQn6XWL1A {
  TGenericSeq Sup;
  tyTuple__aWN9bNzF9bubXNJV9ciomgpfA data[SEQ_DECL_SIZE];
};
struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ {
  TGenericSeq Sup;
  tyTuple__RmGJuqOgEaHckHndh0LEsw data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__ed0C0uAUZPhvw3RAc5hfYg {
  TGenericSeq Sup;
  tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__i89c5kdtWKzK3OEiI81pkkw {
  TGenericSeq Sup;
  tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A data[SEQ_DECL_SIZE];
};
struct tySequence__KgiZ29chkJAD01p9aLRB32qw {
  TGenericSeq Sup;
  tyTuple__J4cxakKjhKxTIJR9bojMmXw data[SEQ_DECL_SIZE];
};
struct tySequence__GR8qmV1kNRcoQ2g76VFy3A {
  TGenericSeq Sup;
  tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* data[SEQ_DECL_SIZE];
};
struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw {
  TGenericSeq Sup;
  tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ data[SEQ_DECL_SIZE];
};
struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ {
  TGenericSeq Sup;
  tyTuple__a7QginWFapakKbWJBJ2vfA data[SEQ_DECL_SIZE];
};
struct tySequence__YmPd0eWfcTfrVYrthlXPYA {
  TGenericSeq Sup;
  tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg {
  TGenericSeq Sup;
  tyTuple__kbX6x85REySUrk9auORL0vw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ {
  TGenericSeq Sup;
  tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g data[SEQ_DECL_SIZE];
};
struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q {
  TGenericSeq Sup;
  tyTuple__nF9cH4hinXgGEUwO4G2bshw data[SEQ_DECL_SIZE];
};
struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g {
  TGenericSeq Sup;
  tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg data[SEQ_DECL_SIZE];
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  TGenericSeq Sup;
  tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE];
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  TGenericSeq Sup;
  NU32 data[SEQ_DECL_SIZE];
};
struct tySequence__4Murtwnm0Fyc7F9acrytEXw {
  TGenericSeq Sup;
  tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA data[SEQ_DECL_SIZE];
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  TGenericSeq Sup;
  tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE];
};
struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw {
  TGenericSeq Sup;
  tyTuple__PsEhl3dzznmmJiLAuIXZOg data[SEQ_DECL_SIZE];
};
struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg {
  TGenericSeq Sup;
  tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w data[SEQ_DECL_SIZE];
};
struct tySequence__oKtVqsc9bQVCNyrijELM4OQ {
  TGenericSeq Sup;
  tyTuple__Db8CrQifKGIsKc3w71w7Lw data[SEQ_DECL_SIZE];
};
struct tySequence__qy6Iwdy00wN560qud54HTg {
  TGenericSeq Sup;
  tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg data[SEQ_DECL_SIZE];
};
struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ {
  TGenericSeq Sup;
  tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ data[SEQ_DECL_SIZE];
};
struct tySequence__cLsClAAfd0MKkoBQVyvdvw {
  TGenericSeq Sup;
  tyTuple__FEYH9alRJhHD0uTKF2vnIqw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg {
  TGenericSeq Sup;
  tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA data[SEQ_DECL_SIZE];
};
struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw {
  TGenericSeq Sup;
  tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw data[SEQ_DECL_SIZE];
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  TGenericSeq Sup;
  NI64 data[SEQ_DECL_SIZE];
};
struct tySequence__lo3S1lKyiPLhGGB9cBawd6A {
  TGenericSeq Sup;
  tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ data[SEQ_DECL_SIZE];
};
struct tySequence__C3r8jsj9chA4sIlYfDN5aDw {
  TGenericSeq Sup;
  tyTuple__VUJ5Hjm4tKAResBsRHJvYg data[SEQ_DECL_SIZE];
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  TGenericSeq Sup;
  tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE];
};
struct tySequence__UnGSk9aaLosDroi2QDrlOfQ {
  TGenericSeq Sup;
  tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, registerParam__varpartitions_273)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__dLJ0v9cLHnWw9bA0ZQgPURgA)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, genericAssign)(void* dest, void* src, TNimType* mt);
static N_NIMCALL(void, Marker_tySequence__zeatLyX5s1CrMAiU9c9bWBSQ)(void* p, NI op);
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, registerResult__varpartitions_214)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, computeLiveRanges__varpartitions_1469)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, lastSon__ast_4833)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, registerVariable__varpartitions_328)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NI, variableId__varpartitions_197)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* x);
static N_INLINE(void, markAsReassigned__varpartitions_1458)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, NI vid);
static N_INLINE(NI, max__varpartitions_1542)(NI x, NI y);
static N_INLINE(NI, min__varpartitions_490)(NI x, NI y);
static N_INLINE(NI, len__ast_3990)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, skipTypes__ast_3723)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kinds);
static N_INLINE(NIM_BOOL, isCompileTimeOnly__types_3592)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(void, traverse__varpartitions_1287)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, deps__varpartitions_1165)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* dest, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* src);
N_LIB_PRIVATE N_NIMCALL(void, borrowingAsgn__varpartitions_1113)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* dest, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* src);
N_LIB_PRIVATE N_NIMCALL(tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ, directViewType__typeallowed_583)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(void, borrowFrom__varpartitions_1039)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* dest, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, pathExpr__varpartitions_608)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* node, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, stupidStmtListExpr__trees_404)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ, classifyViewType__typeallowed_579)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag, getMagic__trees_137)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* op);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, borrowFromConstExpr__varpartitions_573)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toString__varpartitions_1032)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___renderer_2116)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5311)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5273)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5318)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5316)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5267)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isConstSym__varpartitions_1017)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, allRoots__varpartitions_668)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySequence__ugNUvYxERl9aaj9b1GeCSDAg** result, NI level);
static N_NIMCALL(void, Marker_tySequence__ugNUvYxERl9aaj9b1GeCSDAg)(void* p, NI op);
static N_INLINE(NIM_BOOL, isEmptyType__ast_4780)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canAlias__isolation95check_99)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* arg, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ret);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsPointer__varpartitions_1155)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, searchTypeFor__types_470)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyProc__YqnJwApcJpsqiob8SlhPnA predicate);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, wrap__varpartitions_1158)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(void, potentialMutation__varpartitions_359)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* v, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NI level, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(NI, root__varpartitions_339)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* v, NI start);
N_LIB_PRIVATE N_NIMCALL(void*, newSeq)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(void, connect__varpartitions_446)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* v, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* a, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* b, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, genericSeqAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___msgs_1003)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw a, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw b);
N_LIB_PRIVATE N_NIMCALL(void, add__varpartitions_536)(tySequence__qwqHTkRvwhrRyENtudHQ7g** x, NI* y, NI yLen_0);
N_LIB_PRIVATE N_NIMCALL(void, destMightOwn__varpartitions_794)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A* dest, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasDisabledAsgn__modulegraphs_8897)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(void, noCursor__varpartitions_1000)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, borrowingCall__varpartitions_1083)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* destType, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI i);
N_LIB_PRIVATE N_NIMCALL(void, potentialMutationViaArg__varpartitions_1270)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* callee);
N_LIB_PRIVATE N_NIMCALL(void, pretendOwnsData__varpartitions_1008)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, skipColon__ast_4949)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isNoSideEffectPragma__trees_257)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NIM_BOOL, mutationAfterConnection__varpartitions_105)(tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ* g);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, dangerousMutation__varpartitions_1661)(tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ* g, tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A* v);
static N_INLINE(NIM_BOOL, contains__varpartitions_1713)(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw s, NI value);
static N_INLINE(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw, dotdot___varpartitions_1692)(NI a, NI b);
N_LIB_PRIVATE N_NIMCALL(void, cannotBorrow__varpartitions_1729)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ* g);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___msgs_634)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, computeGraphPartitions__varpartitions_1622)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tySet_tyEnum_Goal__YflPrGhMLgZ4bbrBBVpmOA goals, tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* Result);
N_LIB_PRIVATE TNimType NTIvarindex__yOk84K16nGJiOC29biRT9b4A_;
N_LIB_PRIVATE TNimType NTIconnection__SFxQPgR9b9aWd2frrlyFQ2mA_;
N_LIB_PRIVATE TNimType NTIvarindexkind__6gmJu6oZ1VBqh2mKO9cHZ5w_;
TNimNode* NimDT___SFxQPgR9b9aWd2frrlyFQ2mA_kind[4];
extern TNimType NTIint__rR5Bzr1D5krxoo1NcNyeMA_;
N_LIB_PRIVATE TNimType NTIvarflag__bzKsGwCSV281SrVX80B6Kw_;
N_LIB_PRIVATE TNimType NTIsetLvarflagT__ZSU4Y9c9bV9bFj878q6AmNipQ_;
extern TNimType NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_;
extern TNimType NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_;
N_LIB_PRIVATE TNimType NTIseqLvarindexT__dLJ0v9cLHnWw9bA0ZQgPURgA_;
extern NIM_CONST tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw unknownLineInfo__lineinfos_284;
N_LIB_PRIVATE TNimType NTImutationinfo__gL2XNL3vfSXoqvlltP0JhQ_;
extern TNimType NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_;
N_LIB_PRIVATE TNimType NTIsubgraphflag__YymRBOaunI7GAAzxsJI39cA_;
N_LIB_PRIVATE TNimType NTIsetLsubgraphflagT__agpjcE5f9bu9aruHjbC9als3w_;
N_LIB_PRIVATE TNimType NTIseqLmutationinfoT__zeatLyX5s1CrMAiU9c9bWBSQ_;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__4R4QZluAmhY3f04fEZJ3nA_13 = {
0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
STRING_LITERAL(TM__4R4QZluAmhY3f04fEZJ3nA_14, "cannot borrow from ", 19);
STRING_LITERAL(TM__4R4QZluAmhY3f04fEZJ3nA_15, "<empty>", 7);
STRING_LITERAL(TM__4R4QZluAmhY3f04fEZJ3nA_16, ", it is not a path expression; see https://nim-lang.github.io/Nim/manual_experimental.html#view-types-algorithm-path-expressions for details", 140);
STRING_LITERAL(TM__4R4QZluAmhY3f04fEZJ3nA_18, "/home/runner/work/nightlies/nightlies/nim/compiler/varpartitions.nim", 68);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__4R4QZluAmhY3f04fEZJ3nA_17 = {((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_18),
((NI) 535),
((NI) 14)}
;
STRING_LITERAL(TM__4R4QZluAmhY3f04fEZJ3nA_19, "\'result\' must borrow from the first parameter", 45);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__4R4QZluAmhY3f04fEZJ3nA_20 = {((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_18),
((NI) 539),
((NI) 18)}
;
N_LIB_PRIVATE TNimType NTILpsym_intT__BHqtUW7ND5oD8ApFSF1wwQ_;
N_LIB_PRIVATE TNimType NTIseqLLpsym_intTT__ugNUvYxERl9aaj9b1GeCSDAg_;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__4R4QZluAmhY3f04fEZJ3nA_22 = {
0x10, 0xa9, 0x00, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__4R4QZluAmhY3f04fEZJ3nA_23 = {
0x10, 0x08, 0x80, 0x00, 0x00, 0xc0, 0x00, 0x00,
0x00}
;
STRING_LITERAL(TM__4R4QZluAmhY3f04fEZJ3nA_24, "cannot determine the target of the borrow", 41);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__4R4QZluAmhY3f04fEZJ3nA_25 = {((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_18),
((NI) 571),
((NI) 14)}
;
STRING_LITERAL(TM__4R4QZluAmhY3f04fEZJ3nA_26, "cannot borrow ", 14);
STRING_LITERAL(TM__4R4QZluAmhY3f04fEZJ3nA_27, "; what it borrows from is potentially mutated", 45);
STRING_LITERAL(TM__4R4QZluAmhY3f04fEZJ3nA_28, "\012", 1);
STRING_LITERAL(TM__4R4QZluAmhY3f04fEZJ3nA_29, " the mutation is here", 21);
STRING_LITERAL(TM__4R4QZluAmhY3f04fEZJ3nA_30, " is the statement that connected the mutation to the parameter", 62);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__4R4QZluAmhY3f04fEZJ3nA_31 = {((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_18),
((NI) 896),
((NI) 12)}
;
STRING_LITERAL(TM__4R4QZluAmhY3f04fEZJ3nA_32, "\'", 1);
STRING_LITERAL(TM__4R4QZluAmhY3f04fEZJ3nA_33, "\' borrows from location \'", 25);
STRING_LITERAL(TM__4R4QZluAmhY3f04fEZJ3nA_34, "\' which does not live long enough", 33);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__4R4QZluAmhY3f04fEZJ3nA_35 = {((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_18),
((NI) 911),
((NI) 24)}
;
STRING_LITERAL(TM__4R4QZluAmhY3f04fEZJ3nA_36, "\' borrows from the immutable location \'", 39);
STRING_LITERAL(TM__4R4QZluAmhY3f04fEZJ3nA_37, "\' and attempts to mutate it", 27);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__4R4QZluAmhY3f04fEZJ3nA_38 = {((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_18),
((NI) 914),
((NI) 24)}
;
STRING_LITERAL(TM__4R4QZluAmhY3f04fEZJ3nA_39, "\' borrows from an immutable location and attempts to mutate it", 62);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__4R4QZluAmhY3f04fEZJ3nA_40 = {((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_18),
((NI) 921),
((NI) 20)}
;
STRING_LITERAL(TM__4R4QZluAmhY3f04fEZJ3nA_41, "\012an object reachable from \'", 27);
STRING_LITERAL(TM__4R4QZluAmhY3f04fEZJ3nA_42, "\' is potentially mutated", 24);
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5220;
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_NIMCALL(void, Marker_tySequence__dLJ0v9cLHnWw9bA0ZQgPURgA)(void* p, NI op) {
	tySequence__dLJ0v9cLHnWw9bA0ZQgPURgA* a;
	NI T1_;
	a = (tySequence__dLJ0v9cLHnWw9bA0ZQgPURgA*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	switch (a->data[T1_].con.kind) {
	case ((tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w) 0):
	break;
	case ((tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w) 1):
	break;
	case ((tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w) 2):
	break;
	} 
	nimGCvisit((void*)a->data[T1_].sym, op);
	nimGCvisit((void*)a->data[T1_].borrowsFrom, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__zeatLyX5s1CrMAiU9c9bWBSQ)(void* p, NI op) {
	tySequence__zeatLyX5s1CrMAiU9c9bWBSQ* a;
	NI T1_;
	a = (tySequence__zeatLyX5s1CrMAiU9c9bWBSQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].param, op);
	nimGCvisit((void*)a->data[T1_].mutations, op);
	}
}
N_LIB_PRIVATE N_NIMCALL(void, registerParam__varpartitions_273)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NIM_BOOL T3_;
		tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A T7_;
		NI T8_;
		NI T9_;
		tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ T10_;
		NI T11_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		if (!(T3_)) goto LA4_;
		T3_ = !(((*(*(*n)._kind_4.sym).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*(*(*n)._kind_4.sym).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46)));
		LA4_: ;
		if (!T3_) goto LA5_;
		nimZeroMem((void*)(&T7_), sizeof(tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A));
		nimZeroMem((void*)(&T7_), sizeof(tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A));
		nimZeroMem((void*)(&T7_.con), sizeof(tyObject_Connection__SFxQPgR9b9aWd2frrlyFQ2mA));
		T7_.con.kind = ((tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w) 2);
		T8_ = ((*c).graphs ? (*c).graphs->Sup.len : 0);
		T7_.con.graphIndex = T8_;
		T7_.sym = (*n)._kind_4.sym;
		T7_.reassignedTo = ((NI) 0);
		T7_.aliveStart = (*c).abstractTime;
		T7_.aliveEnd = (*c).abstractTime;
		unsureAsgnRef((void**) (&(*c).s), (tySequence__dLJ0v9cLHnWw9bA0ZQgPURgA*) incrSeqV3((TGenericSeq*)((*c).s), (&NTIseqLvarindexT__dLJ0v9cLHnWw9bA0ZQgPURgA_)));
		T9_ = (*c).s->Sup.len++;
		genericAssign((void*)(&(*c).s->data[T9_]), (void*)(&T7_), (&NTIvarindex__yOk84K16nGJiOC29biRT9b4A_));
		nimZeroMem((void*)(&T10_), sizeof(tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ));
		nimZeroMem((void*)(&T10_), sizeof(tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ));
		T10_.param = (*n)._kind_4.sym;
		T10_.mutatedHere = unknownLineInfo__lineinfos_284;
		T10_.connectedVia = unknownLineInfo__lineinfos_284;
		T10_.flags = 8;
		T10_.maxMutation = ((NI) -1);
		T10_.minConnection = ((NI) IL64(9223372036854775807));
		T10_.mutations = NIM_NIL;
		unsureAsgnRef((void**) (&(*c).graphs), (tySequence__zeatLyX5s1CrMAiU9c9bWBSQ*) incrSeqV3((TGenericSeq*)((*c).graphs), (&NTIseqLmutationinfoT__zeatLyX5s1CrMAiU9c9bWBSQ_)));
		T11_ = (*c).graphs->Sup.len++;
		genericAssign((void*)(&(*c).graphs->data[T11_]), (void*)(&T10_), (&NTImutationinfo__gL2XNL3vfSXoqvlltP0JhQ_));
	}
	goto LA1_;
	LA5_: ;
	{
		tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A T13_;
		NI T14_;
		nimZeroMem((void*)(&T13_), sizeof(tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A));
		nimZeroMem((void*)(&T13_), sizeof(tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A));
		nimZeroMem((void*)(&T13_.con), sizeof(tyObject_Connection__SFxQPgR9b9aWd2frrlyFQ2mA));
		T13_.con.kind = ((tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w) 0);
		T13_.sym = (*n)._kind_4.sym;
		T13_.reassignedTo = ((NI) 0);
		T13_.aliveStart = (*c).abstractTime;
		T13_.aliveEnd = (*c).abstractTime;
		unsureAsgnRef((void**) (&(*c).s), (tySequence__dLJ0v9cLHnWw9bA0ZQgPURgA*) incrSeqV3((TGenericSeq*)((*c).s), (&NTIseqLvarindexT__dLJ0v9cLHnWw9bA0ZQgPURgA_)));
		T14_ = (*c).s->Sup.len++;
		genericAssign((void*)(&(*c).s->data[T14_]), (void*)(&T13_), (&NTIvarindex__yOk84K16nGJiOC29biRT9b4A_));
	}
	LA1_: ;
}
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__ast_3155(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, registerResult__varpartitions_214)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A T5_;
		NI T6_;
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA3_;
		nimZeroMem((void*)(&T5_), sizeof(tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A));
		nimZeroMem((void*)(&T5_), sizeof(tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A));
		nimZeroMem((void*)(&T5_.con), sizeof(tyObject_Connection__SFxQPgR9b9aWd2frrlyFQ2mA));
		T5_.con.kind = ((tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w) 0);
		T5_.sym = (*n)._kind_4.sym;
		T5_.reassignedTo = ((NI) 0);
		T5_.aliveStart = ((NI) IL64(9223372036854775807));
		T5_.aliveEnd = (*c).abstractTime;
		unsureAsgnRef((void**) (&(*c).s), (tySequence__dLJ0v9cLHnWw9bA0ZQgPURgA*) incrSeqV3((TGenericSeq*)((*c).s), (&NTIseqLvarindexT__dLJ0v9cLHnWw9bA0ZQgPURgA_)));
		T6_ = (*c).s->Sup.len++;
		genericAssign((void*)(&(*c).s->data[T6_]), (void*)(&T5_), (&NTIvarindex__yOk84K16nGJiOC29biRT9b4A_));
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, variableId__varpartitions_197)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* x) {
	NI result;
{	result = (NI)0;
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = ((*c).s ? (*c).s->Sup.len : 0);
		colontmp_ = T2_;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				{
					if (!((*c).s->data[i].sym == x)) goto LA7_;
					result = i;
					goto BeforeRet_;
				}
				LA7_: ;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	result = ((NI) -1);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, registerVariable__varpartitions_328)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NIM_BOOL T3_;
		NI T5_;
		tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A T8_;
		NI T9_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = variableId__varpartitions_197((&(*c)), (*n)._kind_4.sym);
		T3_ = (T5_ < ((NI) 0));
		LA4_: ;
		if (!T3_) goto LA6_;
		nimZeroMem((void*)(&T8_), sizeof(tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A));
		nimZeroMem((void*)(&T8_), sizeof(tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A));
		nimZeroMem((void*)(&T8_.con), sizeof(tyObject_Connection__SFxQPgR9b9aWd2frrlyFQ2mA));
		T8_.con.kind = ((tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w) 0);
		T8_.sym = (*n)._kind_4.sym;
		T8_.reassignedTo = ((NI) 0);
		T8_.aliveStart = (*c).abstractTime;
		T8_.aliveEnd = (*c).abstractTime;
		unsureAsgnRef((void**) (&(*c).s), (tySequence__dLJ0v9cLHnWw9bA0ZQgPURgA*) incrSeqV3((TGenericSeq*)((*c).s), (&NTIseqLvarindexT__dLJ0v9cLHnWw9bA0ZQgPURgA_)));
		T9_ = (*c).s->Sup.len++;
		genericAssign((void*)(&(*c).s->data[T9_]), (void*)(&T8_), (&NTIvarindex__yOk84K16nGJiOC29biRT9b4A_));
	}
	LA6_: ;
}
static N_INLINE(void, markAsReassigned__varpartitions_1458)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, NI vid) {
	(*c).s->data[vid].flags |= ((NU8)1)<<((((tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw) 2)) & 7);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((NI) 0) < (*c).inConditional);
		if (!(T3_)) goto LA4_;
		T3_ = (((NI) 0) < (*c).inLoop);
		LA4_: ;
		if (!T3_) goto LA5_;
		(*c).s->data[vid].flags |= ((NU8)1)<<((((tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw) 3)) & 7);
	}
	LA5_: ;
}
static N_INLINE(NI, max__varpartitions_1542)(NI x, NI y) {
	NI result;
	result = (NI)0;
	{
		if (!(y <= x)) goto LA3_;
		result = x;
	}
	goto LA1_;
	LA3_: ;
	{
		result = y;
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI, min__varpartitions_490)(NI x, NI y) {
	NI result;
	result = (NI)0;
	{
		if (!(x <= y)) goto LA3_;
		result = x;
	}
	goto LA1_;
	LA3_: ;
	{
		result = y;
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI, len__ast_3990)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n).sons ? (*n).sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(NIM_BOOL, isCompileTimeOnly__types_3592)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, computeLiveRanges__varpartitions_1469)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
{	(*c).abstractTime += ((NI) 1);
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 100):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 99):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child;
			child = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* last;
						if (!(i_2 < colontmp_)) goto LA5;
						i = i_2;
						child = (*n)._kind_6.sons->data[i];
						last = lastSon__ast_4833(child);
						computeLiveRanges__varpartitions_1469(c, last);
						{
							NIM_BOOL T8_;
							T8_ = (NIM_BOOL)0;
							T8_ = ((*child).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 36));
							if (!(T8_)) goto LA9_;
							T8_ = ((*last).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 37) || (*last).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 160));
							LA9_: ;
							if (!T8_) goto LA10_;
							{
								NI T14_;
								NI T15_;
								T14_ = (NI)0;
								T14_ = len__ast_3155(child);
								T15_ = (NI)0;
								T15_ = len__ast_3155(last);
								if (!!(((NI)(T14_ - ((NI) 2)) == T15_))) goto LA16_;
								goto BeforeRet_;
							}
							LA16_: ;
							{
								NI i_3;
								NI colontmp__2;
								NI T19_;
								NI i_4;
								i_3 = (NI)0;
								colontmp__2 = (NI)0;
								T19_ = (NI)0;
								T19_ = len__ast_3155(child);
								colontmp__2 = (NI)(T19_ - ((NI) 2));
								i_4 = ((NI) 0);
								{
									while (1) {
										if (!(i_4 < colontmp__2)) goto LA21;
										i_3 = i_4;
										registerVariable__varpartitions_328(c, (*child)._kind_6.sons->data[i_3]);
										i_4 += ((NI) 1);
									} LA21: ;
								}
							}
						}
						goto LA6_;
						LA10_: ;
						{
							{
								NI i_5;
								NI colontmp__3;
								NI T24_;
								NI i_6;
								i_5 = (NI)0;
								colontmp__3 = (NI)0;
								T24_ = (NI)0;
								T24_ = len__ast_3155(child);
								colontmp__3 = (NI)(T24_ - ((NI) 2));
								i_6 = ((NI) 0);
								{
									while (1) {
										if (!(i_6 < colontmp__3)) goto LA26;
										i_5 = i_6;
										registerVariable__varpartitions_328(c, (*child)._kind_6.sons->data[i_5]);
										i_6 += ((NI) 1);
									} LA26: ;
								}
							}
						}
						LA6_: ;
						i_2 += ((NI) 1);
					} LA5: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 73):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 74):
	{
		computeLiveRanges__varpartitions_1469(c, (*n)._kind_6.sons->data[((NI) 0)]);
		computeLiveRanges__varpartitions_1469(c, (*n)._kind_6.sons->data[((NI) 1)]);
		{
			NI vid;
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA30_;
			vid = variableId__varpartitions_197((&(*c)), (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
			{
				if (!(((NI) 0) <= vid)) goto LA34_;
				{
					NIM_BOOL T38_;
					NIM_BOOL T40_;
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym179_;
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym181_;
					T38_ = (NIM_BOOL)0;
					T38_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
					if (!(T38_)) goto LA39_;
					T40_ = (NIM_BOOL)0;
					T40_ = ((*c).s->data[vid].reassignedTo == ((NI) 0));
					if (T40_) goto LA41_;
					xX60gensym179_ = (*(*n)._kind_6.sons->data[((NI) 1)])._kind_4.sym;
					T40_ = ((*c).s->data[vid].reassignedTo == (NI)((NI)((NU64)(((NI) ((*xX60gensym179_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym179_).Sup.itemId.item))));
					LA41_: ;
					T38_ = T40_;
					LA39_: ;
					if (!T38_) goto LA42_;
					xX60gensym181_ = (*(*n)._kind_6.sons->data[((NI) 1)])._kind_4.sym;
					(*c).s->data[vid].reassignedTo = (NI)((NI)((NU64)(((NI) ((*xX60gensym181_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym181_).Sup.itemId.item)));
				}
				goto LA36_;
				LA42_: ;
				{
					markAsReassigned__varpartitions_1458(c, vid);
				}
				LA36_: ;
			}
			LA34_: ;
		}
		LA30_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		(*c).abstractTime -= ((NI) 1);
		{
			NI id;
			if (!((2100008 &((NU32)1<<((NU)((*(*n)._kind_4.sym).kind)&31U)))!=0)) goto LA48_;
			id = variableId__varpartitions_197((&(*c)), (*n)._kind_4.sym);
			{
				if (!(((NI) 0) <= id)) goto LA52_;
				(*c).s->data[id].aliveEnd = max__varpartitions_1542((*c).s->data[id].aliveEnd, (*c).abstractTime);
				{
					if (!((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 11))) goto LA56_;
					(*c).s->data[id].aliveStart = min__varpartitions_490((*c).s->data[id].aliveStart, (*c).abstractTime);
				}
				LA56_: ;
			}
			LA52_: ;
		}
		LA48_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 4) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 51) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 52):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 90):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 98):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 101) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 102):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 116):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 118):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 121) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 123):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 125):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 132):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 158) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159):
	{
		(*c).abstractTime -= ((NI) 1);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* parameters;
		NI L;
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child_2;
			child_2 = NIM_NIL;
			{
				NI i_7;
				NI colontmp__4;
				NI i_8;
				i_7 = (NI)0;
				colontmp__4 = (NI)0;
				colontmp__4 = safeLen__ast_3148(n);
				i_8 = ((NI) 0);
				{
					while (1) {
						if (!(i_8 < colontmp__4)) goto LA63;
						i_7 = i_8;
						child_2 = (*n)._kind_6.sons->data[i_7];
						computeLiveRanges__varpartitions_1469(c, child_2);
						i_8 += ((NI) 1);
					} LA63: ;
				}
			}
		}
		parameters = (*(*n)._kind_6.sons->data[((NI) 0)]).typ;
		{
			if (!!((parameters == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA66_;
			L = len__ast_3990(parameters);
		}
		goto LA64_;
		LA66_: ;
		{
			L = ((NI) 0);
		}
		LA64_: ;
		{
			NI i_9;
			NI colontmp__5;
			NI i_10;
			i_9 = (NI)0;
			colontmp__5 = (NI)0;
			colontmp__5 = len__ast_3155(n);
			i_10 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
					if (!(i_10 < colontmp__5)) goto LA71;
					i_9 = i_10;
					it = (*n)._kind_6.sons->data[i_9];
					{
						NIM_BOOL T74_;
						tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* paramType;
						T74_ = (NIM_BOOL)0;
						T74_ = ((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
						if (!(T74_)) goto LA75_;
						T74_ = (i_9 < L);
						LA75_: ;
						if (!T74_) goto LA76_;
						paramType = skipTypes__ast_3723((*parameters).sons->data[i_9], TM__4R4QZluAmhY3f04fEZJ3nA_13);
						{
							NIM_BOOL T80_;
							NIM_BOOL T81_;
							NI vid_2;
							T80_ = (NIM_BOOL)0;
							T81_ = (NIM_BOOL)0;
							T81_ = isCompileTimeOnly__types_3592(paramType);
							T80_ = !(T81_);
							if (!(T80_)) goto LA82_;
							T80_ = ((*paramType).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23));
							LA82_: ;
							if (!T80_) goto LA83_;
							vid_2 = variableId__varpartitions_197((&(*c)), (*it)._kind_4.sym);
							{
								if (!(((NI) 0) <= vid_2)) goto LA87_;
								markAsReassigned__varpartitions_1458(c, vid_2);
							}
							LA87_: ;
						}
						LA83_: ;
					}
					LA76_: ;
					i_10 += ((NI) 1);
				} LA71: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64):
	{
		computeLiveRanges__varpartitions_1469(c, (*n)._kind_6.sons->data[((NI) 0)]);
		{
			NI vid_3;
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA92_;
			vid_3 = variableId__varpartitions_197((&(*c)), (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
			{
				if (!(((NI) 0) <= vid_3)) goto LA96_;
				(*c).s->data[vid_3].flags |= ((NU8)1)<<((((tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw) 1)) & 7);
			}
			LA96_: ;
		}
		LA92_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 91):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T99_;
		T99_ = NIM_NIL;
		T99_ = lastSon__ast_4833(n);
		computeLiveRanges__varpartitions_1469(c, T99_);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 96):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 94):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 95):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child_3;
			child_3 = NIM_NIL;
			{
				NI i_11;
				NI colontmp__6;
				NI i_12;
				i_11 = (NI)0;
				colontmp__6 = (NI)0;
				colontmp__6 = safeLen__ast_3148(n);
				i_12 = ((NI) 0);
				{
					while (1) {
						if (!(i_12 < colontmp__6)) goto LA104;
						i_11 = i_12;
						child_3 = (*n)._kind_6.sons->data[i_11];
						computeLiveRanges__varpartitions_1469(c, child_3);
						i_12 += ((NI) 1);
					} LA104: ;
				}
			}
		}
		(*c).inLoop += ((NI) 1);
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child_4;
			child_4 = NIM_NIL;
			{
				NI i_13;
				NI colontmp__7;
				NI i_14;
				i_13 = (NI)0;
				colontmp__7 = (NI)0;
				colontmp__7 = safeLen__ast_3148(n);
				i_14 = ((NI) 0);
				{
					while (1) {
						if (!(i_14 < colontmp__7)) goto LA108;
						i_13 = i_14;
						child_4 = (*n)._kind_6.sons->data[i_13];
						computeLiveRanges__varpartitions_1469(c, child_4);
						i_14 += ((NI) 1);
					} LA108: ;
				}
			}
		}
		(*c).inLoop -= ((NI) 1);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 86):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 49):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 88):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 85):
	{
		(*c).inConditional += ((NI) 1);
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child_5;
			child_5 = NIM_NIL;
			{
				NI i_15;
				NI colontmp__8;
				NI i_16;
				i_15 = (NI)0;
				colontmp__8 = (NI)0;
				colontmp__8 = safeLen__ast_3148(n);
				i_16 = ((NI) 0);
				{
					while (1) {
						if (!(i_16 < colontmp__8)) goto LA113;
						i_15 = i_16;
						child_5 = (*n)._kind_6.sons->data[i_15];
						computeLiveRanges__varpartitions_1469(c, child_5);
						i_16 += ((NI) 1);
					} LA113: ;
				}
			}
		}
		(*c).inConditional -= ((NI) 1);
	}
	break;
	default:
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child_6;
			child_6 = NIM_NIL;
			{
				NI i_17;
				NI colontmp__9;
				NI i_18;
				i_17 = (NI)0;
				colontmp__9 = (NI)0;
				colontmp__9 = safeLen__ast_3148(n);
				i_18 = ((NI) 0);
				{
					while (1) {
						if (!(i_18 < colontmp__9)) goto LA118;
						i_17 = i_18;
						child_6 = (*n)._kind_6.sons->data[i_17];
						computeLiveRanges__varpartitions_1469(c, child_6);
						i_18 += ((NI) 1);
					} LA118: ;
				}
			}
		}
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, borrowFromConstExpr__varpartitions_573)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
	{
		result = NIM_TRUE;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 33):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 61):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 67):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 66):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T3_;
		T3_ = NIM_NIL;
		T3_ = lastSon__ast_4833(n);
		result = borrowFromConstExpr__varpartitions_573(T3_);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 39):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 37):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 160):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 38):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 155):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 44):
	{
		result = NIM_TRUE;
		{
			NI i;
			NI colontmp_;
			NI colontmp__2;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp__2 = (NI)0;
			colontmp_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 38));
			colontmp__2 = len__ast_3155(n);
			i_2 = colontmp_;
			{
				while (1) {
					if (!(i_2 < colontmp__2)) goto LA7;
					i = i_2;
					{
						NIM_BOOL T10_;
						T10_ = (NIM_BOOL)0;
						T10_ = borrowFromConstExpr__varpartitions_573((*n)._kind_6.sons->data[i]);
						if (!!(T10_)) goto LA11_;
						result = NIM_FALSE;
						goto BeforeRet_;
					}
					LA11_: ;
					i_2 += ((NI) 1);
				} LA7: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
	{
		{
			tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag T16_;
			T16_ = (tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag)0;
			T16_ = getMagic__trees_137(n);
			if (!(T16_ == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 144))) goto LA17_;
			result = NIM_TRUE;
			{
				NI i_3;
				NI colontmp__3;
				NI i_4;
				i_3 = (NI)0;
				colontmp__3 = (NI)0;
				colontmp__3 = len__ast_3155(n);
				i_4 = ((NI) 1);
				{
					while (1) {
						if (!(i_4 < colontmp__3)) goto LA21;
						i_3 = i_4;
						{
							NIM_BOOL T24_;
							T24_ = (NIM_BOOL)0;
							T24_ = borrowFromConstExpr__varpartitions_573((*n)._kind_6.sons->data[i_3]);
							if (!!(T24_)) goto LA25_;
							result = NIM_FALSE;
							goto BeforeRet_;
						}
						LA25_: ;
						i_4 += ((NI) 1);
					} LA21: ;
				}
			}
		}
		LA17_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, pathExpr__varpartitions_608)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* node, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
	result = NIM_NIL;
	n = node;
	result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
	{
		while (1) {
			switch ((*n).kind) {
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
			{
				switch ((*(*n)._kind_4.sym).kind) {
				case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3):
				case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 5):
				case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 11):
				case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 21):
				{
					{
						if (!((*(*n)._kind_4.sym).owner == owner)) goto LA7_;
						result = n;
					}
					LA7_: ;
				}
				break;
				case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8):
				{
					{
						NIM_BOOL T12_;
						T12_ = (NIM_BOOL)0;
						T12_ = ((*(*n)._kind_4.sym).owner == owner);
						if (T12_) goto LA13_;
						T12_ = (((*(*n)._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 26))&63U)))!=0);
						LA13_: ;
						if (!T12_) goto LA14_;
						result = n;
					}
					LA14_: ;
				}
				break;
				case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 9):
				case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 10):
				{
					{
						NIM_BOOL T19_;
						T19_ = (NIM_BOOL)0;
						T19_ = ((*(*n)._kind_4.sym).owner == owner);
						if (T19_) goto LA20_;
						T19_ = !(((67108872 & (*(*n)._kind_4.sym).flags) == 0));
						LA20_: ;
						if (!T19_) goto LA21_;
						result = n;
					}
					LA21_: ;
				}
				break;
				default:
				{
				}
				break;
				}
				goto LA1;
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 47):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 46):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64):
			{
				n = (*n)._kind_6.sons->data[((NI) 0)];
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 60):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 61):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 67):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 66):
			{
				n = lastSon__ast_4833(n);
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126):
			{
				{
					NIM_BOOL T29_;
					NI T30_;
					T29_ = (NIM_BOOL)0;
					T30_ = (NI)0;
					T30_ = len__ast_3155(n);
					T29_ = (((NI) 0) < T30_);
					if (!(T29_)) goto LA31_;
					T29_ = stupidStmtListExpr__trees_404(n);
					LA31_: ;
					if (!T29_) goto LA32_;
					n = lastSon__ast_4833(n);
				}
				goto LA27_;
				LA32_: ;
				{
					goto LA1;
				}
				LA27_: ;
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
			{
				{
					NI T38_;
					T38_ = (NI)0;
					T38_ = len__ast_3155(n);
					if (!(((NI) 1) < T38_)) goto LA39_;
					{
						NIM_BOOL T43_;
						NIM_BOOL T44_;
						tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ T46_;
						tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag T48_;
						T43_ = (NIM_BOOL)0;
						T44_ = (NIM_BOOL)0;
						T44_ = !(((*n).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
						if (!(T44_)) goto LA45_;
						T46_ = (tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ)0;
						T46_ = classifyViewType__typeallowed_579((*n).typ);
						T44_ = !((T46_ == ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 0)));
						LA45_: ;
						T43_ = T44_;
						if (T43_) goto LA47_;
						T48_ = (tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag)0;
						T48_ = getMagic__trees_137(n);
						T43_ = (T48_ == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 126));
						LA47_: ;
						if (!T43_) goto LA49_;
						n = (*n)._kind_6.sons->data[((NI) 1)];
					}
					goto LA41_;
					LA49_: ;
					{
						goto LA1;
					}
					LA41_: ;
				}
				goto LA36_;
				LA39_: ;
				{
					goto LA1;
				}
				LA36_: ;
			}
			break;
			default:
			{
				goto LA1;
			}
			break;
			}
		}
	} LA1: ;
	{
		NIM_BOOL T56_;
		T56_ = (NIM_BOOL)0;
		T56_ = (result == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
		if (!(T56_)) goto LA57_;
		T56_ = borrowFromConstExpr__varpartitions_573(n);
		LA57_: ;
		if (!T56_) goto LA58_;
		result = n;
	}
	LA58_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toString__varpartitions_1032)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NimStringDesc* result;
	result = NIM_NIL;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1))) goto LA3_;
		result = copyString(((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_15));
	}
	goto LA1_;
	LA3_: ;
	{
		result = dollar___renderer_2116(n);
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5311)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5273)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5316)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5267((&gch__system_5220.zct), c);
}
static N_INLINE(void, decRef__system_5318)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5316(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5273(src);
		incRef__system_5311(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5273((*dest));
		decRef__system_5318(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isConstSym__varpartitions_1017)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((1536 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
	if (T1_) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
	if (!(T3_)) goto LA4_;
	T3_ = !(((*(*s).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*(*s).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46)));
	LA4_: ;
	T1_ = T3_;
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, borrowFrom__varpartitions_1039)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* dest, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* src) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* s;
	s = pathExpr__varpartitions_608(src, (*c).owner);
	{
		NimStringDesc* T5_;
		NimStringDesc* T6_;
		if (!(s == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA3_;
		T5_ = NIM_NIL;
		T6_ = NIM_NIL;
		T6_ = toString__varpartitions_1032(src);
		T5_ = rawNewString((T6_ ? T6_->Sup.len : 0) + 159);
appendString(T5_, ((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_14));
appendString(T5_, T6_);
appendString(T5_, ((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_16));
		liMessage__msgs_1128((*(*c).g).config, (*src).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T5_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__4R4QZluAmhY3f04fEZJ3nA_17, NIM_FALSE);
	}
	goto LA1_;
	LA3_: ;
	{
		NI vid;
		if (!((*s).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA8_;
		{
			if (!((*dest).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 11))) goto LA12_;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = !(((*(*s)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3)));
				if (T16_) goto LA17_;
				T16_ = !(((*(*s)._kind_4.sym).position == ((NI) 0)));
				LA17_: ;
				if (!T16_) goto LA18_;
				liMessage__msgs_1128((*(*c).g).config, (*src).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_19), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__4R4QZluAmhY3f04fEZJ3nA_20, NIM_FALSE);
			}
			LA18_: ;
		}
		LA12_: ;
		vid = variableId__varpartitions_197((&(*c)), dest);
		{
			NI sourceIdx;
			NI T31_;
			if (!(((NI) 0) <= vid)) goto LA22_;
			sourceIdx = variableId__varpartitions_197((&(*c)), (*s)._kind_4.sym);
			{
				NI T28_;
				tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A T29_;
				NI T30_;
				if (!(sourceIdx < ((NI) 0))) goto LA26_;
				T28_ = ((*c).s ? (*c).s->Sup.len : 0);
				sourceIdx = T28_;
				nimZeroMem((void*)(&T29_), sizeof(tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A));
				nimZeroMem((void*)(&T29_), sizeof(tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A));
				nimZeroMem((void*)(&T29_.con), sizeof(tyObject_Connection__SFxQPgR9b9aWd2frrlyFQ2mA));
				T29_.con.kind = ((tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w) 0);
				T29_.sym = (*s)._kind_4.sym;
				T29_.reassignedTo = ((NI) 0);
				T29_.aliveStart = ((NI) -1);
				T29_.aliveEnd = ((NI) IL64(9223372036854775807));
				unsureAsgnRef((void**) (&(*c).s), (tySequence__dLJ0v9cLHnWw9bA0ZQgPURgA*) incrSeqV3((TGenericSeq*)((*c).s), (&NTIseqLvarindexT__dLJ0v9cLHnWw9bA0ZQgPURgA_)));
				T30_ = (*c).s->Sup.len++;
				genericAssign((void*)(&(*c).s->data[T30_]), (void*)(&T29_), (&NTIvarindex__yOk84K16nGJiOC29biRT9b4A_));
			}
			LA26_: ;
			asgnRef((void**) (&(*c).s->data[vid].borrowsFrom), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)((*c).s->data[vid].borrowsFrom), (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_)));
			T31_ = (*c).s->data[vid].borrowsFrom->Sup.len++;
			(*c).s->data[vid].borrowsFrom->data[T31_] = sourceIdx;
			{
				NIM_BOOL T34_;
				T34_ = (NIM_BOOL)0;
				T34_ = isConstSym__varpartitions_1017((*s)._kind_4.sym);
				if (!T34_) goto LA35_;
				(*c).s->data[vid].flags |= ((NU8)1)<<((((tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw) 5)) & 7);
			}
			LA35_: ;
		}
		LA22_: ;
	}
	goto LA1_;
	LA8_: ;
	{
		NI vid_2;
		vid_2 = variableId__varpartitions_197((&(*c)), dest);
		{
			if (!(((NI) 0) <= vid_2)) goto LA40_;
			(*c).s->data[vid_2].flags |= ((NU8)1)<<((((tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw) 5)) & 7);
		}
		LA40_: ;
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, borrowingAsgn__varpartitions_1113)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* dest, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* src) {
	{
		if (!((*dest).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA3_;
		{
			tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ T7_;
			T7_ = (tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ)0;
			T7_ = directViewType__typeallowed_583((*dest).typ);
			if (!!((T7_ == ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 0)))) goto LA8_;
			borrowFrom__varpartitions_1039(c, (*dest)._kind_4.sym, src);
		}
		LA8_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ T13_;
		if (!((*dest).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65) || (*dest).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 47) || (*dest).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42))) goto LA11_;
		T13_ = (tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ)0;
		T13_ = directViewType__typeallowed_583((*(*dest)._kind_6.sons->data[((NI) 0)]).typ);
		switch (T13_) {
		case ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 2):
		case ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 1):
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* viewOrigin;
			viewOrigin = pathExpr__varpartitions_608(dest, (*c).owner);
			{
				NI vid;
				if (!((*viewOrigin).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA17_;
				vid = variableId__varpartitions_197((&(*c)), (*viewOrigin)._kind_4.sym);
				{
					if (!(((NI) 0) <= vid)) goto LA21_;
					(*c).s->data[vid].flags |= ((NU8)1)<<((((tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw) 4)) & 7);
				}
				LA21_: ;
			}
			LA17_: ;
		}
		break;
		case ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 0):
		{
		}
		break;
		}
	}
	goto LA1_;
	LA11_: ;
	LA1_: ;
}
static N_NIMCALL(void, Marker_tySequence__ugNUvYxERl9aaj9b1GeCSDAg)(void* p, NI op) {
	tySequence__ugNUvYxERl9aaj9b1GeCSDAg* a;
	NI T1_;
	a = (tySequence__ugNUvYxERl9aaj9b1GeCSDAg*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field0, op);
	}
}
static N_INLINE(NIM_BOOL, isEmptyType__ast_4780)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (t == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
	if (T1_) goto LA2_;
	T1_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 63) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 7));
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, allRoots__varpartitions_668)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySequence__ugNUvYxERl9aaj9b1GeCSDAg** result, NI level) {
{	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		{
			tyTuple__BHqtUW7ND5oD8ApFSF1wwQ T6_;
			NI T7_;
			if (!((2100008 &((NU32)1<<((NU)((*(*n)._kind_4.sym).kind)&31U)))!=0)) goto LA4_;
			nimZeroMem((void*)(&T6_), sizeof(tyTuple__BHqtUW7ND5oD8ApFSF1wwQ));
			T6_.Field0 = (*n)._kind_4.sym;
			T6_.Field1 = level;
			unsureAsgnRef((void**) (&(*result)), (tySequence__ugNUvYxERl9aaj9b1GeCSDAg*) incrSeqV3((TGenericSeq*)((*result)), (&NTIseqLLpsym_intTT__ugNUvYxERl9aaj9b1GeCSDAg_)));
			T7_ = (*result)->Sup.len++;
			asgnRef((void**) (&(*result)->data[T7_].Field0), T6_.Field0);
			(*result)->data[T7_].Field1 = T6_.Field1;
		}
		LA4_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 47):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65):
	{
		allRoots__varpartitions_668((*n)._kind_6.sons->data[((NI) 0)], result, (NI)(level + ((NI) 1)));
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 46):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64):
	{
		allRoots__varpartitions_668((*n)._kind_6.sons->data[((NI) 0)], result, level);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 33):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 60):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 112):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 127):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 61):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 67):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 66):
	{
		{
			NI T13_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T16_;
			T13_ = (NI)0;
			T13_ = len__ast_3155(n);
			if (!(((NI) 0) < T13_)) goto LA14_;
			T16_ = NIM_NIL;
			T16_ = lastSon__ast_4833(n);
			allRoots__varpartitions_668(T16_, result, level);
		}
		LA14_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 97):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 38):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T21_;
					if (!(i_2 < colontmp_)) goto LA20;
					i = i_2;
					T21_ = NIM_NIL;
					T21_ = lastSon__ast_4833((*n)._kind_6.sons->data[i]);
					allRoots__varpartitions_668(T21_, result, level);
					i_2 += ((NI) 1);
				} LA20: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 92):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 48):
	{
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3155(n);
			i_4 = ((NI) 0);
			{
				while (1) {
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T26_;
					if (!(i_4 < colontmp__2)) goto LA25;
					i_3 = i_4;
					T26_ = NIM_NIL;
					T26_ = lastSon__ast_4833((*n)._kind_6.sons->data[i_3]);
					allRoots__varpartitions_668(T26_, result, level);
					i_4 += ((NI) 1);
				} LA25: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 160):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 37):
	{
		{
			NI i_5;
			NI colontmp__3;
			NI i_6;
			i_5 = (NI)0;
			colontmp__3 = (NI)0;
			colontmp__3 = len__ast_3155(n);
			i_6 = ((NI) 0);
			{
				while (1) {
					if (!(i_6 < colontmp__3)) goto LA30;
					i_5 = i_6;
					allRoots__varpartitions_668((*n)._kind_6.sons->data[i_5], result, (NI)(level - ((NI) 1)));
					i_6 += ((NI) 1);
				} LA30: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
	{
		{
			NIM_BOOL T34_;
			T34_ = (NIM_BOOL)0;
			T34_ = !(((*n).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
			if (!(T34_)) goto LA35_;
			T34_ = ((*(*n).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*(*n).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47));
			LA35_: ;
			if (!T34_) goto LA36_;
			{
				NI T40_;
				T40_ = (NI)0;
				T40_ = len__ast_3155(n);
				if (!(((NI) 1) < T40_)) goto LA41_;
				allRoots__varpartitions_668((*n)._kind_6.sons->data[((NI) 1)], result, ((NI) 1000));
			}
			LA41_: ;
		}
		goto LA32_;
		LA36_: ;
		{
			tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag m;
			m = getMagic__trees_137(n);
			switch (m) {
			case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 0):
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
				{
					if (!((*(*n)._kind_6.sons->data[((NI) 0)]).typ == 0)) goto LA47_;
					goto BeforeRet_;
				}
				LA47_: ;
				typ = (*(*n)._kind_6.sons->data[((NI) 0)]).typ;
				{
					if (!!((typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA51_;
					typ = skipTypes__ast_3723(typ, TM__4R4QZluAmhY3f04fEZJ3nA_22);
					{
						if (!!(((*typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25)))) goto LA55_;
						typ = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL);
					}
					goto LA53_;
					LA55_: ;
					{
					}
					LA53_: ;
				}
				LA51_: ;
				{
					NI i_7;
					NI colontmp__4;
					NI i_8;
					i_7 = (NI)0;
					colontmp__4 = (NI)0;
					colontmp__4 = len__ast_3155(n);
					i_8 = ((NI) 1);
					{
						while (1) {
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
							if (!(i_8 < colontmp__4)) goto LA60;
							i_7 = i_8;
							it = (*n)._kind_6.sons->data[i_7];
							{
								NIM_BOOL T63_;
								NI T65_;
								tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* paramType;
								T63_ = (NIM_BOOL)0;
								T63_ = !((typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
								if (!(T63_)) goto LA64_;
								T65_ = (NI)0;
								T65_ = len__ast_3990(typ);
								T63_ = (i_7 < T65_);
								LA64_: ;
								if (!T63_) goto LA66_;
								paramType = (*(*(*typ).n)._kind_6.sons->data[i_7]).typ;
								{
									NIM_BOOL T70_;
									NIM_BOOL T71_;
									NIM_BOOL T72_;
									NIM_BOOL T74_;
									T70_ = (NIM_BOOL)0;
									T71_ = (NIM_BOOL)0;
									T72_ = (NIM_BOOL)0;
									T72_ = isCompileTimeOnly__types_3592(paramType);
									T71_ = !(T72_);
									if (!(T71_)) goto LA73_;
									T74_ = (NIM_BOOL)0;
									T74_ = isEmptyType__ast_4780((*typ).sons->data[((NI) 0)]);
									T71_ = !(T74_);
									LA73_: ;
									T70_ = T71_;
									if (!(T70_)) goto LA75_;
									T70_ = canAlias__isolation95check_99(paramType, (*typ).sons->data[((NI) 0)]);
									LA75_: ;
									if (!T70_) goto LA76_;
									allRoots__varpartitions_668(it, result, ((NI) 1000));
								}
								LA76_: ;
							}
							goto LA61_;
							LA66_: ;
							{
								allRoots__varpartitions_668(it, result, ((NI) 1000));
							}
							LA61_: ;
							i_8 += ((NI) 1);
						} LA60: ;
					}
				}
			}
			break;
			case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 126):
			{
				allRoots__varpartitions_668((*n)._kind_6.sons->data[((NI) 1)], result, (NI)(level + ((NI) 1)));
			}
			break;
			default:
			{
			}
			break;
			}
		}
		LA32_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, wrap__varpartitions_1158)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsPointer__varpartitions_1155)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = searchTypeFor__types_470(t, wrap__varpartitions_1158);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, root__varpartitions_339)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* v, NI start) {
	NI result;
	NI depth;
	result = (NI)0;
	result = start;
	depth = ((NI) 0);
	{
		while (1) {
			if (!((*v).s->data[result].con.kind == ((tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w) 1))) goto LA2;
			result = (*v).s->data[result].con.parent;
			depth += ((NI) 1);
		} LA2: ;
	}
	{
		NI it;
		if (!(((NI) 0) < depth)) goto LA5_;
		it = start;
		{
			while (1) {
				NI next;
				tyObject_Connection__SFxQPgR9b9aWd2frrlyFQ2mA T9_;
				if (!((*v).s->data[it].con.kind == ((tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w) 1))) goto LA8;
				next = (*v).s->data[it].con.parent;
				nimZeroMem((void*)(&T9_), sizeof(tyObject_Connection__SFxQPgR9b9aWd2frrlyFQ2mA));
				T9_.kind = ((tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w) 1);
				T9_.parent = result;
				(*v).s->data[it].con = T9_;
				it = next;
			} LA8: ;
		}
	}
	LA5_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, potentialMutation__varpartitions_359)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* v, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NI level, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NI id;
	id = variableId__varpartitions_197((&(*v)), s);
	{
		NI r;
		tySet_tyEnum_SubgraphFlag__YymRBOaunI7GAAzxsJI39cA flags;
		if (!(((NI) 0) <= id)) goto LA3_;
		r = root__varpartitions_339(v, id);
		{
			if (!((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3))) goto LA7_;
			{
				NIM_BOOL T11_;
				T11_ = (NIM_BOOL)0;
				T11_ = ((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
				if (!(T11_)) goto LA12_;
				T11_ = !(((*(*s).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*(*s).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46)));
				LA12_: ;
				if (!T11_) goto LA13_;
				flags = 3;
			}
			goto LA9_;
			LA13_: ;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = ((*(*s).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23));
				if (!(T16_)) goto LA17_;
				T16_ = (level <= ((NI) 1));
				LA17_: ;
				if (!T16_) goto LA18_;
				flags = 4;
			}
			goto LA9_;
			LA18_: ;
			{
				flags = 1;
			}
			LA9_: ;
		}
		goto LA5_;
		LA7_: ;
		{
			flags = 1;
		}
		LA5_: ;
		switch ((*v).s->data[r].con.kind) {
		case ((tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w) 0):
		{
			tyObject_Connection__SFxQPgR9b9aWd2frrlyFQ2mA T23_;
			NI T24_;
			tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ T25_;
			NI T33_;
			nimZeroMem((void*)(&T23_), sizeof(tyObject_Connection__SFxQPgR9b9aWd2frrlyFQ2mA));
			T23_.kind = ((tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w) 2);
			T24_ = ((*v).graphs ? (*v).graphs->Sup.len : 0);
			T23_.graphIndex = T24_;
			(*v).s->data[r].con = T23_;
			nimZeroMem((void*)(&T25_), sizeof(tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ));
			nimZeroMem((void*)(&T25_), sizeof(tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ));
			{
				NIM_BOOL T28_;
				T28_ = (NIM_BOOL)0;
				T28_ = ((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
				if (!(T28_)) goto LA29_;
				T28_ = !(((*(*s).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*(*s).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46)));
				LA29_: ;
				if (!T28_) goto LA30_;
				T25_.param = s;
			}
			goto LA26_;
			LA30_: ;
			{
				T25_.param = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
			}
			LA26_: ;
			T25_.mutatedHere = info;
			T25_.connectedVia = unknownLineInfo__lineinfos_284;
			T25_.flags = flags;
			T25_.maxMutation = (*v).abstractTime;
			T25_.minConnection = ((NI) IL64(9223372036854775807));
			T25_.mutations = (tySequence__qwqHTkRvwhrRyENtudHQ7g*) newSeq((&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_), 1);
			T25_.mutations->data[0] = (*v).abstractTime;
			unsureAsgnRef((void**) (&(*v).graphs), (tySequence__zeatLyX5s1CrMAiU9c9bWBSQ*) incrSeqV3((TGenericSeq*)((*v).graphs), (&NTIseqLmutationinfoT__zeatLyX5s1CrMAiU9c9bWBSQ_)));
			T33_ = (*v).graphs->Sup.len++;
			genericAssign((void*)(&(*v).graphs->data[T33_]), (void*)(&T25_), (&NTImutationinfo__gL2XNL3vfSXoqvlltP0JhQ_));
		}
		break;
		case ((tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w) 2):
		{
			tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ* g;
			NI T47_;
			g = (&(*v).graphs->data[(*v).s->data[r].con.graphIndex]);
			{
				NIM_BOOL T37_;
				NIM_BOOL T39_;
				T37_ = (NIM_BOOL)0;
				T37_ = ((*g).param == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
				if (!(T37_)) goto LA38_;
				T39_ = (NIM_BOOL)0;
				T39_ = ((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
				if (!(T39_)) goto LA40_;
				T39_ = !(((*(*s).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*(*s).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46)));
				LA40_: ;
				T37_ = T39_;
				LA38_: ;
				if (!T37_) goto LA41_;
				unsureAsgnRef((void**) (&(*g).param), s);
			}
			LA41_: ;
			{
				if (!((*g).maxMutation < (*v).abstractTime)) goto LA45_;
				(*g).mutatedHere = info;
				(*g).maxMutation = (*v).abstractTime;
			}
			LA45_: ;
			(*g).flags = ((*g).flags | flags);
			unsureAsgnRef((void**) (&(*g).mutations), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)((*g).mutations), (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_)));
			T47_ = (*g).mutations->Sup.len++;
			(*g).mutations->data[T47_] = (*v).abstractTime;
		}
		break;
		default:
		{
		}
		break;
		}
	}
	goto LA1_;
	LA3_: ;
	{
		(*v).unanalysableMutation = NIM_TRUE;
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, connect__varpartitions_446)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* v, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* a, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* b, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NI aid;
	NI bid;
	NI ra;
	NI rb;
{	aid = variableId__varpartitions_197((&(*v)), a);
	{
		if (!(aid < ((NI) 0))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	bid = variableId__varpartitions_197((&(*v)), b);
	{
		if (!(bid < ((NI) 0))) goto LA7_;
		goto BeforeRet_;
	}
	LA7_: ;
	ra = root__varpartitions_339(v, aid);
	rb = root__varpartitions_339(v, bid);
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* param;
		tySet_tyEnum_SubgraphFlag__YymRBOaunI7GAAzxsJI39cA paramFlags;
		tySet_tyEnum_SubgraphFlag__YymRBOaunI7GAAzxsJI39cA rbFlags;
		tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw mutatedHere;
		NI mut;
		NI con;
		tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ* gb;
		tyObject_Connection__SFxQPgR9b9aWd2frrlyFQ2mA T37_;
		if (!!((ra == rb))) goto LA11_;
		param = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
		{
			NIM_BOOL T15_;
			T15_ = (NIM_BOOL)0;
			T15_ = ((*a).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			if (!(T15_)) goto LA16_;
			T15_ = !(((*(*a).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*(*a).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46)));
			LA16_: ;
			if (!T15_) goto LA17_;
			param = a;
		}
		goto LA13_;
		LA17_: ;
		{
			NIM_BOOL T20_;
			T20_ = (NIM_BOOL)0;
			T20_ = ((*b).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			if (!(T20_)) goto LA21_;
			T20_ = !(((*(*b).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*(*b).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46)));
			LA21_: ;
			if (!T20_) goto LA22_;
			param = b;
		}
		goto LA13_;
		LA22_: ;
		LA13_: ;
		{
			if (!!((param == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA26_;
			paramFlags = 8;
		}
		goto LA24_;
		LA26_: ;
		{
			paramFlags = 0;
		}
		LA24_: ;
		rbFlags = 0;
		mutatedHere = unknownLineInfo__lineinfos_284;
		mut = ((NI) 0);
		con = (*v).abstractTime;
		gb = ((tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ*) NIM_NIL);
		{
			if (!((*v).s->data[rb].con.kind == ((tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w) 2))) goto LA31_;
			gb = (&(*v).graphs->data[(*v).s->data[rb].con.graphIndex]);
			{
				if (!(param == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA35_;
				param = (*gb).param;
			}
			LA35_: ;
			mutatedHere = (*gb).mutatedHere;
			rbFlags = (*gb).flags;
			mut = (*gb).maxMutation;
			con = min__varpartitions_490(con, (*gb).minConnection);
		}
		LA31_: ;
		nimZeroMem((void*)(&T37_), sizeof(tyObject_Connection__SFxQPgR9b9aWd2frrlyFQ2mA));
		T37_.kind = ((tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w) 1);
		T37_.parent = ra;
		(*v).s->data[rb].con = T37_;
		switch ((*v).s->data[ra].con.kind) {
		case ((tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w) 0):
		{
			tyObject_Connection__SFxQPgR9b9aWd2frrlyFQ2mA T39_;
			NI T40_;
			tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ T41_;
			NI T47_;
			nimZeroMem((void*)(&T39_), sizeof(tyObject_Connection__SFxQPgR9b9aWd2frrlyFQ2mA));
			T39_.kind = ((tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w) 2);
			T40_ = ((*v).graphs ? (*v).graphs->Sup.len : 0);
			T39_.graphIndex = T40_;
			(*v).s->data[ra].con = T39_;
			nimZeroMem((void*)(&T41_), sizeof(tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ));
			nimZeroMem((void*)(&T41_), sizeof(tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ));
			T41_.param = param;
			T41_.mutatedHere = mutatedHere;
			T41_.connectedVia = info;
			T41_.flags = (paramFlags | rbFlags);
			T41_.maxMutation = mut;
			T41_.minConnection = con;
			{
				if (!!((gb == ((tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ*) NIM_NIL)))) goto LA44_;
				genericSeqAssign((&T41_.mutations), (*gb).mutations, (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_));
			}
			goto LA42_;
			LA44_: ;
			{
				T41_.mutations = NIM_NIL;
			}
			LA42_: ;
			unsureAsgnRef((void**) (&(*v).graphs), (tySequence__zeatLyX5s1CrMAiU9c9bWBSQ*) incrSeqV3((TGenericSeq*)((*v).graphs), (&NTIseqLmutationinfoT__zeatLyX5s1CrMAiU9c9bWBSQ_)));
			T47_ = (*v).graphs->Sup.len++;
			genericAssign((void*)(&(*v).graphs->data[T47_]), (void*)(&T41_), (&NTImutationinfo__gL2XNL3vfSXoqvlltP0JhQ_));
		}
		break;
		case ((tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w) 2):
		{
			tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ* g;
			g = (&(*v).graphs->data[(*v).s->data[ra].con.graphIndex]);
			{
				if (!((*g).param == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA51_;
				unsureAsgnRef((void**) (&(*g).param), param);
			}
			LA51_: ;
			{
				NIM_BOOL T55_;
				T55_ = (NIM_BOOL)0;
				T55_ = eqeq___msgs_1003((*g).mutatedHere, unknownLineInfo__lineinfos_284);
				if (!T55_) goto LA56_;
				(*g).mutatedHere = mutatedHere;
			}
			LA56_: ;
			(*g).minConnection = min__varpartitions_490((*g).minConnection, con);
			(*g).connectedVia = info;
			(*g).flags = ((*g).flags | (paramFlags | rbFlags));
			{
				if (!!((gb == ((tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ*) NIM_NIL)))) goto LA60_;
				add__varpartitions_536((&(*g).mutations), ((*gb).mutations) ? ((*gb).mutations->data) : NIM_NIL, ((*gb).mutations ? (*gb).mutations->Sup.len : 0));
			}
			LA60_: ;
		}
		break;
		default:
		{
		}
		break;
		}
	}
	LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, destMightOwn__varpartitions_794)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A* dest, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
	{
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 33):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 61):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 60):
	{
		destMightOwn__varpartitions_794(c, dest, (*n)._kind_6.sons->data[((NI) 1)]);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 92):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 48):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T7_;
					if (!(i_2 < colontmp_)) goto LA6;
					i = i_2;
					T7_ = NIM_NIL;
					T7_ = lastSon__ast_4833((*n)._kind_6.sons->data[i]);
					destMightOwn__varpartitions_794(c, dest, T7_);
					i_2 += ((NI) 1);
				} LA6: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 97):
	{
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3155(n);
			i_4 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T12_;
					if (!(i_4 < colontmp__2)) goto LA11;
					i_3 = i_4;
					T12_ = NIM_NIL;
					T12_ = lastSon__ast_4833((*n)._kind_6.sons->data[i_3]);
					destMightOwn__varpartitions_794(c, dest, T12_);
					i_4 += ((NI) 1);
				} LA11: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126):
	{
		{
			NI T16_;
			NI T19_;
			T16_ = (NI)0;
			T16_ = len__ast_3155(n);
			if (!(((NI) 0) < T16_)) goto LA17_;
			T19_ = (NI)0;
			T19_ = len__ast_3155(n);
			destMightOwn__varpartitions_794(c, dest, (*n)._kind_6.sons->data[(NI)(T19_ - ((NI) 1))]);
		}
		LA17_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 155):
	{
		{
			NI i_5;
			NI colontmp__3;
			NI i_6;
			i_5 = (NI)0;
			colontmp__3 = (NI)0;
			colontmp__3 = len__ast_3155(n);
			i_6 = ((NI) 1);
			{
				while (1) {
					if (!(i_6 < colontmp__3)) goto LA23;
					i_5 = i_6;
					destMightOwn__varpartitions_794(c, dest, (*n)._kind_6.sons->data[i_5]);
					i_6 += ((NI) 1);
				} LA23: ;
			}
		}
		(*dest).flags |= ((NU8)1)<<((((tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw) 0)) & 7);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 38):
	{
		{
			NI i_7;
			NI colontmp__4;
			NI i_8;
			i_7 = (NI)0;
			colontmp__4 = (NI)0;
			colontmp__4 = len__ast_3155(n);
			i_8 = ((NI) 1);
			{
				while (1) {
					if (!(i_8 < colontmp__4)) goto LA27;
					i_7 = i_8;
					destMightOwn__varpartitions_794(c, dest, (*n)._kind_6.sons->data[i_7]);
					i_8 += ((NI) 1);
				} LA27: ;
			}
		}
		{
			if (!!(((IL64(2147483664) & (*(*n).typ).flags) == 0))) goto LA30_;
			(*dest).flags |= ((NU8)1)<<((((tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw) 0)) & 7);
		}
		LA30_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 39):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 37):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 160):
	{
		(*c).inConstructor += ((NI) 1);
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* son;
			son = NIM_NIL;
			{
				NI i_9;
				NI colontmp__5;
				NI i_10;
				i_9 = (NI)0;
				colontmp__5 = (NI)0;
				colontmp__5 = safeLen__ast_3148(n);
				i_10 = ((NI) 0);
				{
					while (1) {
						if (!(i_10 < colontmp__5)) goto LA36;
						i_9 = i_10;
						son = (*n)._kind_6.sons->data[i_9];
						destMightOwn__varpartitions_794(c, dest, son);
						i_10 += ((NI) 1);
					} LA36: ;
				}
			}
		}
		(*c).inConstructor -= ((NI) 1);
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T39_;
			T39_ = NIM_NIL;
			T39_ = skipTypes__ast_3723((*n).typ, TM__4R4QZluAmhY3f04fEZJ3nA_22);
			if (!((*T39_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24))) goto LA40_;
			(*dest).flags |= ((NU8)1)<<((((tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw) 0)) & 7);
		}
		LA40_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		{
			if (!((2100008 &((NU32)1<<((NU)((*(*n)._kind_4.sym).kind)&31U)))!=0)) goto LA45_;
			{
				if (!!((((*(*n)._kind_4.sym).flags & 67108872) == 0))) goto LA49_;
				(*dest).flags |= ((NU8)1)<<((((tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw) 0)) & 7);
			}
			goto LA47_;
			LA49_: ;
			{
				connect__varpartitions_446(c, (*dest).sym, (*n)._kind_4.sym, (*n).info);
				{
					if (!(((NI) 0) < (*c).inConstructor)) goto LA54_;
					(*dest).flags |= ((NU8)1)<<((((tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw) 0)) & 7);
				}
				LA54_: ;
			}
			LA47_: ;
		}
		LA45_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 47):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 67):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 66):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 46):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64):
	{
		destMightOwn__varpartitions_794(c, dest, (*n)._kind_6.sons->data[((NI) 0)]);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
	{
		{
			if (!!(((*n).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA60_;
			{
				if (!!(((IL64(2147483664) & (*(*n).typ).flags) == 0))) goto LA64_;
				(*dest).flags |= ((NU8)1)<<((((tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw) 0)) & 7);
			}
			goto LA62_;
			LA64_: ;
			{
				NIM_BOOL T67_;
				NI T69_;
				tySequence__ugNUvYxERl9aaj9b1GeCSDAg* roots;
				T67_ = (NIM_BOOL)0;
				T67_ = ((*(*n).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47) || (*(*n).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23));
				if (!(T67_)) goto LA68_;
				T69_ = (NI)0;
				T69_ = len__ast_3155(n);
				T67_ = (((NI) 1) < T69_);
				LA68_: ;
				if (!T67_) goto LA70_;
				roots = NIM_NIL;
				allRoots__varpartitions_668((*n)._kind_6.sons->data[((NI) 1)], (&roots), ((NI) 1000));
				{
					tyTuple__BHqtUW7ND5oD8ApFSF1wwQ* r;
					NI i_11;
					NI L;
					NI T73_;
					r = (tyTuple__BHqtUW7ND5oD8ApFSF1wwQ*)0;
					i_11 = ((NI) 0);
					T73_ = (roots ? roots->Sup.len : 0);
					L = T73_;
					{
						while (1) {
							if (!(i_11 < L)) goto LA75;
							r = (&roots->data[i_11]);
							connect__varpartitions_446(c, (*dest).sym, (*r).Field0, (*(*n)._kind_6.sons->data[((NI) 1)]).info);
							i_11 += ((NI) 1);
						} LA75: ;
					}
				}
			}
			goto LA62_;
			LA70_: ;
			{
				tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
				{
					if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA79_;
					magic = (*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic;
				}
				goto LA77_;
				LA79_: ;
				{
					magic = ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 0);
				}
				LA77_: ;
				{
					if (!(magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 0) || magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 149) || magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 126) || magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 131) || magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 132) || magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 133) || magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 144) || magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 145))) goto LA84_;
					{
						NI i_12;
						NI colontmp__6;
						NI i_13;
						i_12 = (NI)0;
						colontmp__6 = (NI)0;
						colontmp__6 = len__ast_3155(n);
						i_13 = ((NI) 1);
						{
							while (1) {
								if (!(i_13 < colontmp__6)) goto LA88;
								i_12 = i_13;
								{
									tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T91_;
									T91_ = NIM_NIL;
									T91_ = skipTypes__ast_3723((*(*n)._kind_6.sons->data[i_12]).typ, TM__4R4QZluAmhY3f04fEZJ3nA_23);
									if (!!(((IL64(2147483664) & (*T91_).flags) == 0))) goto LA92_;
									destMightOwn__varpartitions_794(c, dest, (*n)._kind_6.sons->data[i_12]);
								}
								LA92_: ;
								i_13 += ((NI) 1);
							} LA88: ;
						}
					}
				}
				LA84_: ;
			}
			LA62_: ;
		}
		LA60_: ;
	}
	break;
	default:
	{
		(*dest).flags |= ((NU8)1)<<((((tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw) 1)) & 7);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, deps__varpartitions_1165)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* dest, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* src) {
	tySequence__ugNUvYxERl9aaj9b1GeCSDAg* targets;
	tySequence__ugNUvYxERl9aaj9b1GeCSDAg* sources;
	NIM_BOOL destIsComplex;
	{
		if (!(((*c).goals &((NU8)1<<((NU)(((tyEnum_Goal__YflPrGhMLgZ4bbrBBVpmOA) 1))&7U)))!=0)) goto LA3_;
		borrowingAsgn__varpartitions_1113(c, dest, src);
	}
	LA3_: ;
	targets = NIM_NIL;
	sources = NIM_NIL;
	allRoots__varpartitions_668(dest, (&targets), ((NI) 0));
	allRoots__varpartitions_668(src, (&sources), ((NI) 0));
	destIsComplex = containsPointer__varpartitions_1155((*dest).typ);
	{
		tyTuple__BHqtUW7ND5oD8ApFSF1wwQ* t;
		NI i;
		NI L;
		NI T6_;
		t = (tyTuple__BHqtUW7ND5oD8ApFSF1wwQ*)0;
		i = ((NI) 0);
		T6_ = (targets ? targets->Sup.len : 0);
		L = T6_;
		{
			while (1) {
				if (!(i < L)) goto LA8;
				t = (&targets->data[i]);
				{
					NIM_BOOL T11_;
					T11_ = (NIM_BOOL)0;
					T11_ = !(((*dest).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)));
					if (!(T11_)) goto LA12_;
					T11_ = ((*c).inNoSideEffectSection == ((NI) 0));
					LA12_: ;
					if (!T11_) goto LA13_;
					potentialMutation__varpartitions_359(c, (*t).Field0, (*t).Field1, (*dest).info);
				}
				LA13_: ;
				{
					if (!destIsComplex) goto LA17_;
					{
						tyTuple__BHqtUW7ND5oD8ApFSF1wwQ* s;
						NI i_2;
						NI L_2;
						NI T20_;
						s = (tyTuple__BHqtUW7ND5oD8ApFSF1wwQ*)0;
						i_2 = ((NI) 0);
						T20_ = (sources ? sources->Sup.len : 0);
						L_2 = T20_;
						{
							while (1) {
								if (!(i_2 < L_2)) goto LA22;
								s = (&sources->data[i_2]);
								connect__varpartitions_446(c, (*t).Field0, (*s).Field0, (*dest).info);
								i_2 += ((NI) 1);
							} LA22: ;
						}
					}
				}
				LA17_: ;
				i += ((NI) 1);
			} LA8: ;
		}
	}
	{
		NIM_BOOL T25_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* d;
		T25_ = (NIM_BOOL)0;
		T25_ = (((*c).goals &((NU8)1<<((NU)(((tyEnum_Goal__YflPrGhMLgZ4bbrBBVpmOA) 2))&7U)))!=0);
		if (!(T25_)) goto LA26_;
		T25_ = !(((*src).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)));
		LA26_: ;
		if (!T25_) goto LA27_;
		d = pathExpr__varpartitions_608(dest, (*c).owner);
		{
			NIM_BOOL T31_;
			NI vid;
			T31_ = (NIM_BOOL)0;
			T31_ = !((d == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
			if (!(T31_)) goto LA32_;
			T31_ = ((*d).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
			LA32_: ;
			if (!T31_) goto LA33_;
			vid = variableId__varpartitions_197((&(*c)), (*d)._kind_4.sym);
			{
				if (!(((NI) 0) <= vid)) goto LA37_;
				destMightOwn__varpartitions_794(c, (&(*c).s->data[vid]), src);
				{
					tyTuple__BHqtUW7ND5oD8ApFSF1wwQ* source;
					NI i_3;
					NI L_3;
					NI T40_;
					source = (tyTuple__BHqtUW7ND5oD8ApFSF1wwQ*)0;
					i_3 = ((NI) 0);
					T40_ = (sources ? sources->Sup.len : 0);
					L_3 = T40_;
					{
						while (1) {
							tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s_2;
							if (!(i_3 < L_3)) goto LA42;
							source = (&sources->data[i_3]);
							s_2 = (*source).Field0;
							{
								if (!(s_2 == (*d)._kind_4.sym)) goto LA45_;
							}
							goto LA43_;
							LA45_: ;
							{
								NIM_BOOL T48_;
								T48_ = (NIM_BOOL)0;
								T48_ = !(((67108872 & (*s_2).flags) == 0));
								if (T48_) goto LA49_;
								T48_ = hasDisabledAsgn__modulegraphs_8897((*c).g, (*s_2).typ);
								LA49_: ;
								if (!T48_) goto LA50_;
								(*c).s->data[vid].flags |= ((NU8)1)<<((((tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw) 1)) & 7);
							}
							goto LA43_;
							LA50_: ;
							{
								NI srcid;
								srcid = variableId__varpartitions_197((&(*c)), s_2);
								{
									if (!(((NI) 0) <= srcid)) goto LA55_;
									{
										NIM_BOOL T59_;
										T59_ = (NIM_BOOL)0;
										T59_ = !(((2056 &((NU32)1<<((NU)((*s_2).kind)&31U)))!=0));
										if (!(T59_)) goto LA60_;
										T59_ = ((*c).s->data[srcid].aliveEnd < (*c).s->data[vid].aliveEnd);
										LA60_: ;
										if (!T59_) goto LA61_;
										(*c).s->data[vid].flags |= ((NU8)1)<<((((tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw) 1)) & 7);
									}
									goto LA57_;
									LA61_: ;
									{
										if (!!(((6 & (*c).s->data[srcid].flags) == 0))) goto LA64_;
										(*c).s->data[vid].flags |= ((NU8)1)<<((((tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw) 1)) & 7);
									}
									goto LA57_;
									LA64_: ;
									{
										NIM_BOOL T67_;
										tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym135_;
										T67_ = (NIM_BOOL)0;
										T67_ = !(((*c).s->data[srcid].reassignedTo == ((NI) 0)));
										if (!(T67_)) goto LA68_;
										xX60gensym135_ = (*d)._kind_4.sym;
										T67_ = !(((*c).s->data[srcid].reassignedTo == (NI)((NI)((NU64)(((NI) ((*xX60gensym135_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym135_).Sup.itemId.item)))));
										LA68_: ;
										if (!T67_) goto LA69_;
										(*c).s->data[vid].flags |= ((NU8)1)<<((((tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw) 1)) & 7);
									}
									goto LA57_;
									LA69_: ;
									LA57_: ;
								}
								LA55_: ;
							}
							LA43_: ;
							i_3 += ((NI) 1);
						} LA42: ;
					}
				}
			}
			LA37_: ;
		}
		LA33_: ;
	}
	LA27_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, noCursor__varpartitions_1000)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NI vid;
	vid = variableId__varpartitions_197((&(*c)), s);
	{
		if (!(((NI) 0) <= vid)) goto LA3_;
		(*c).s->data[vid].flags |= ((NU8)1)<<((((tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw) 1)) & 7);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, borrowingCall__varpartitions_1083)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* destType, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI i) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* v;
	v = pathExpr__varpartitions_608((*n)._kind_6.sons->data[i], (*c).owner);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !((v == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((*v).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			NI j;
			NI colontmp_;
			NI colontmp__2;
			NI i_2;
			j = (NI)0;
			colontmp_ = (NI)0;
			colontmp__2 = (NI)0;
			colontmp_ = (NI)(i + ((NI) 1));
			colontmp__2 = len__ast_3155(n);
			i_2 = colontmp_;
			{
				while (1) {
					if (!(i_2 < colontmp__2)) goto LA9;
					j = i_2;
					{
						tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag T12_;
						T12_ = (tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag)0;
						T12_ = getMagic__trees_137((*n)._kind_6.sons->data[j]);
						if (!(T12_ == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 126))) goto LA13_;
						borrowFrom__varpartitions_1039(c, (*v)._kind_4.sym, (*n)._kind_6.sons->data[j]);
					}
					LA13_: ;
					i_2 += ((NI) 1);
				} LA9: ;
			}
		}
	}
	goto LA1_;
	LA5_: ;
	{
		liMessage__msgs_1128((*(*c).g).config, (*(*n)._kind_6.sons->data[i]).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_24), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__4R4QZluAmhY3f04fEZJ3nA_25, NIM_FALSE);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, potentialMutationViaArg__varpartitions_1270)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* callee) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((*c).goals &((NU8)1<<((NU)(((tyEnum_Goal__YflPrGhMLgZ4bbrBBVpmOA) 0))&7U)))!=0);
		if (!(T3_)) goto LA4_;
		T3_ = (((*callee).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 1))&63U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T8_;
		tySequence__ugNUvYxERl9aaj9b1GeCSDAg* roots;
		T8_ = (NIM_BOOL)0;
		T8_ = ((*c).inNoSideEffectSection == ((NI) 0));
		if (!(T8_)) goto LA9_;
		T8_ = containsPointer__varpartitions_1155((*n).typ);
		LA9_: ;
		if (!T8_) goto LA10_;
		roots = NIM_NIL;
		allRoots__varpartitions_668(n, (&roots), ((NI) 1000));
		{
			tyTuple__BHqtUW7ND5oD8ApFSF1wwQ* r;
			NI i;
			NI L;
			NI T13_;
			r = (tyTuple__BHqtUW7ND5oD8ApFSF1wwQ*)0;
			i = ((NI) 0);
			T13_ = (roots ? roots->Sup.len : 0);
			L = T13_;
			{
				while (1) {
					if (!(i < L)) goto LA15;
					r = (&roots->data[i]);
					potentialMutation__varpartitions_359(c, (*r).Field0, (*r).Field1, (*n).info);
					i += ((NI) 1);
				} LA15: ;
			}
		}
	}
	goto LA1_;
	LA10_: ;
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, pretendOwnsData__varpartitions_1008)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NI vid;
	vid = variableId__varpartitions_197((&(*c)), s);
	{
		if (!(((NI) 0) <= vid)) goto LA3_;
		(*c).s->data[vid].flags |= ((NU8)1)<<((((tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw) 0)) & 7);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, traverse__varpartitions_1287)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
{	(*c).abstractTime += ((NI) 1);
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 100):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 99):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child;
			child = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* last;
						if (!(i_2 < colontmp_)) goto LA5;
						i = i_2;
						child = (*n)._kind_6.sons->data[i];
						last = lastSon__ast_4833(child);
						traverse__varpartitions_1287(c, last);
						{
							NIM_BOOL T8_;
							T8_ = (NIM_BOOL)0;
							T8_ = ((*child).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 36));
							if (!(T8_)) goto LA9_;
							T8_ = ((*last).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 37) || (*last).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 160));
							LA9_: ;
							if (!T8_) goto LA10_;
							{
								NI T14_;
								NI T15_;
								T14_ = (NI)0;
								T14_ = len__ast_3155(child);
								T15_ = (NI)0;
								T15_ = len__ast_3155(last);
								if (!!(((NI)(T14_ - ((NI) 2)) == T15_))) goto LA16_;
								goto BeforeRet_;
							}
							LA16_: ;
							{
								NI i_3;
								NI colontmp__2;
								NI T19_;
								NI i_4;
								i_3 = (NI)0;
								colontmp__2 = (NI)0;
								T19_ = (NI)0;
								T19_ = len__ast_3155(child);
								colontmp__2 = (NI)(T19_ - ((NI) 2));
								i_4 = ((NI) 0);
								{
									while (1) {
										if (!(i_4 < colontmp__2)) goto LA21;
										i_3 = i_4;
										deps__varpartitions_1165(c, (*child)._kind_6.sons->data[i_3], (*last)._kind_6.sons->data[i_3]);
										i_4 += ((NI) 1);
									} LA21: ;
								}
							}
						}
						goto LA6_;
						LA10_: ;
						{
							{
								NI i_5;
								NI colontmp__3;
								NI T24_;
								NI i_6;
								i_5 = (NI)0;
								colontmp__3 = (NI)0;
								T24_ = (NI)0;
								T24_ = len__ast_3155(child);
								colontmp__3 = (NI)(T24_ - ((NI) 2));
								i_6 = ((NI) 0);
								{
									while (1) {
										if (!(i_6 < colontmp__3)) goto LA26;
										i_5 = i_6;
										deps__varpartitions_1165(c, (*child)._kind_6.sons->data[i_5], last);
										i_6 += ((NI) 1);
									} LA26: ;
								}
							}
						}
						LA6_: ;
						i_2 += ((NI) 1);
					} LA5: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 73):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 74):
	{
		traverse__varpartitions_1287(c, (*n)._kind_6.sons->data[((NI) 0)]);
		(*c).inAsgnSource += ((NI) 1);
		traverse__varpartitions_1287(c, (*n)._kind_6.sons->data[((NI) 1)]);
		(*c).inAsgnSource -= ((NI) 1);
		deps__varpartitions_1165(c, (*n)._kind_6.sons->data[((NI) 0)], (*n)._kind_6.sons->data[((NI) 1)]);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		(*c).abstractTime -= ((NI) 1);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 4) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 51) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 52):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 90):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 98):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 101) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 102):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 116):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 118):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 121) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 123):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 125):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 132):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 158) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159):
	{
		(*c).abstractTime -= ((NI) 1);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* parameters;
		NI L;
		tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag m;
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child_2;
			child_2 = NIM_NIL;
			{
				NI i_7;
				NI colontmp__4;
				NI i_8;
				i_7 = (NI)0;
				colontmp__4 = (NI)0;
				colontmp__4 = safeLen__ast_3148(n);
				i_8 = ((NI) 0);
				{
					while (1) {
						if (!(i_8 < colontmp__4)) goto LA34;
						i_7 = i_8;
						child_2 = (*n)._kind_6.sons->data[i_7];
						traverse__varpartitions_1287(c, child_2);
						i_8 += ((NI) 1);
					} LA34: ;
				}
			}
		}
		parameters = (*(*n)._kind_6.sons->data[((NI) 0)]).typ;
		{
			if (!!((parameters == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA37_;
			L = len__ast_3990(parameters);
		}
		goto LA35_;
		LA37_: ;
		{
			L = ((NI) 0);
		}
		LA35_: ;
		m = getMagic__trees_137(n);
		{
			NI i_9;
			NI colontmp__5;
			NI i_10;
			i_9 = (NI)0;
			colontmp__5 = (NI)0;
			colontmp__5 = len__ast_3155(n);
			i_10 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
					if (!(i_10 < colontmp__5)) goto LA42;
					i_9 = i_10;
					it = (*n)._kind_6.sons->data[i_9];
					{
						tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* paramType;
						if (!(i_9 < L)) goto LA45_;
						paramType = skipTypes__ast_3723((*parameters).sons->data[i_9], TM__4R4QZluAmhY3f04fEZJ3nA_13);
						{
							NIM_BOOL T49_;
							NIM_BOOL T50_;
							tySequence__ugNUvYxERl9aaj9b1GeCSDAg* roots;
							T49_ = (NIM_BOOL)0;
							T50_ = (NIM_BOOL)0;
							T50_ = isCompileTimeOnly__types_3592(paramType);
							T49_ = !(T50_);
							if (!(T49_)) goto LA51_;
							T49_ = ((*paramType).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*paramType).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46) || (*paramType).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45));
							LA51_: ;
							if (!T49_) goto LA52_;
							roots = NIM_NIL;
							allRoots__varpartitions_668(it, (&roots), ((NI) 1000));
							{
								if (!((*paramType).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23))) goto LA56_;
								{
									if (!((*c).inNoSideEffectSection == ((NI) 0))) goto LA60_;
									{
										tyTuple__BHqtUW7ND5oD8ApFSF1wwQ* r;
										NI i_11;
										NI L_2;
										NI T63_;
										r = (tyTuple__BHqtUW7ND5oD8ApFSF1wwQ*)0;
										i_11 = ((NI) 0);
										T63_ = (roots ? roots->Sup.len : 0);
										L_2 = T63_;
										{
											while (1) {
												if (!(i_11 < L_2)) goto LA65;
												r = (&roots->data[i_11]);
												potentialMutation__varpartitions_359(c, (*r).Field0, (*r).Field1, (*it).info);
												i_11 += ((NI) 1);
											} LA65: ;
										}
									}
								}
								LA60_: ;
								{
									tyTuple__BHqtUW7ND5oD8ApFSF1wwQ* r_2;
									NI i_12;
									NI L_3;
									NI T67_;
									r_2 = (tyTuple__BHqtUW7ND5oD8ApFSF1wwQ*)0;
									i_12 = ((NI) 0);
									T67_ = (roots ? roots->Sup.len : 0);
									L_3 = T67_;
									{
										while (1) {
											if (!(i_12 < L_3)) goto LA69;
											r_2 = (&roots->data[i_12]);
											noCursor__varpartitions_1000(c, (*r_2).Field0);
											i_12 += ((NI) 1);
										} LA69: ;
									}
								}
								{
									if (!(((*c).goals &((NU8)1<<((NU)(((tyEnum_Goal__YflPrGhMLgZ4bbrBBVpmOA) 1))&7U)))!=0)) goto LA72_;
									{
										NIM_BOOL T76_;
										tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ T77_;
										tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ T79_;
										T76_ = (NIM_BOOL)0;
										T77_ = (tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ)0;
										T77_ = directViewType__typeallowed_583((*paramType).sons->data[((NI) 0)]);
										T76_ = (T77_ == ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 0));
										if (!(T76_)) goto LA78_;
										T79_ = (tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ)0;
										T79_ = classifyViewType__typeallowed_579((*paramType).sons->data[((NI) 0)]);
										T76_ = !((T79_ == ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 0)));
										LA78_: ;
										if (!T76_) goto LA80_;
										borrowingCall__varpartitions_1083(c, (*paramType).sons->data[((NI) 0)], n, i_9);
									}
									LA80_: ;
								}
								LA72_: ;
							}
							LA56_: ;
						}
						goto LA47_;
						LA52_: ;
						{
							if (!(m == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 0))) goto LA83_;
							potentialMutationViaArg__varpartitions_1270(c, (*n)._kind_6.sons->data[i_9], parameters);
						}
						goto LA47_;
						LA83_: ;
						LA47_: ;
					}
					LA45_: ;
					i_10 += ((NI) 1);
				} LA42: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64):
	{
		traverse__varpartitions_1287(c, (*n)._kind_6.sons->data[((NI) 0)]);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 160):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child_3;
			child_3 = NIM_NIL;
			{
				NI i_13;
				NI colontmp__6;
				NI i_14;
				i_13 = (NI)0;
				colontmp__6 = (NI)0;
				colontmp__6 = safeLen__ast_3148(n);
				i_14 = ((NI) 0);
				{
					while (1) {
						if (!(i_14 < colontmp__6)) goto LA90;
						i_13 = i_14;
						child_3 = (*n)._kind_6.sons->data[i_13];
						traverse__varpartitions_1287(c, child_3);
						i_14 += ((NI) 1);
					} LA90: ;
				}
			}
		}
		{
			if (!(((NI) 0) < (*c).inAsgnSource)) goto LA93_;
			{
				NI i_15;
				NI colontmp__7;
				NI i_16;
				i_15 = (NI)0;
				colontmp__7 = (NI)0;
				colontmp__7 = len__ast_3155(n);
				i_16 = ((NI) 0);
				{
					while (1) {
						if (!(i_16 < colontmp__7)) goto LA97;
						i_15 = i_16;
						{
							if (!((*(*n)._kind_6.sons->data[i_15]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA100_;
							pretendOwnsData__varpartitions_1008(c, (*(*n)._kind_6.sons->data[i_15])._kind_4.sym);
						}
						LA100_: ;
						i_16 += ((NI) 1);
					} LA97: ;
				}
			}
		}
		LA93_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 38):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child_4;
			child_4 = NIM_NIL;
			{
				NI i_17;
				NI colontmp__8;
				NI i_18;
				i_17 = (NI)0;
				colontmp__8 = (NI)0;
				colontmp__8 = safeLen__ast_3148(n);
				i_18 = ((NI) 0);
				{
					while (1) {
						if (!(i_18 < colontmp__8)) goto LA106;
						i_17 = i_18;
						child_4 = (*n)._kind_6.sons->data[i_17];
						traverse__varpartitions_1287(c, child_4);
						i_18 += ((NI) 1);
					} LA106: ;
				}
			}
		}
		{
			if (!(((NI) 0) < (*c).inAsgnSource)) goto LA109_;
			{
				NI i_19;
				NI colontmp__9;
				NI i_20;
				i_19 = (NI)0;
				colontmp__9 = (NI)0;
				colontmp__9 = len__ast_3155(n);
				i_20 = ((NI) 1);
				{
					while (1) {
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it_2;
						if (!(i_20 < colontmp__9)) goto LA113;
						i_19 = i_20;
						it_2 = skipColon__ast_4949((*n)._kind_6.sons->data[i_19]);
						{
							if (!((*it_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA116_;
							pretendOwnsData__varpartitions_1008(c, (*it_2)._kind_4.sym);
						}
						LA116_: ;
						i_20 += ((NI) 1);
					} LA113: ;
				}
			}
		}
		LA109_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 91):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pragmaList;
		NI enforceNoSideEffects;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T127_;
		pragmaList = (*n)._kind_6.sons->data[((NI) 0)];
		enforceNoSideEffects = ((NI) 0);
		{
			NI i_21;
			NI colontmp__10;
			NI i_22;
			i_21 = (NI)0;
			colontmp__10 = (NI)0;
			colontmp__10 = len__ast_3155(pragmaList);
			i_22 = ((NI) 0);
			{
				while (1) {
					if (!(i_22 < colontmp__10)) goto LA121;
					i_21 = i_22;
					{
						NIM_BOOL T124_;
						T124_ = (NIM_BOOL)0;
						T124_ = isNoSideEffectPragma__trees_257((*pragmaList)._kind_6.sons->data[i_21]);
						if (!T124_) goto LA125_;
						enforceNoSideEffects = ((NI) 1);
						goto LA119;
					}
					LA125_: ;
					i_22 += ((NI) 1);
				} LA121: ;
			}
		} LA119: ;
		(*c).inNoSideEffectSection += enforceNoSideEffects;
		T127_ = NIM_NIL;
		T127_ = lastSon__ast_4833(n);
		traverse__varpartitions_1287(c, T127_);
		(*c).inNoSideEffectSection -= enforceNoSideEffects;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 96):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 94):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 95):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child_5;
			child_5 = NIM_NIL;
			{
				NI i_23;
				NI colontmp__11;
				NI i_24;
				i_23 = (NI)0;
				colontmp__11 = (NI)0;
				colontmp__11 = safeLen__ast_3148(n);
				i_24 = ((NI) 0);
				{
					while (1) {
						if (!(i_24 < colontmp__11)) goto LA132;
						i_23 = i_24;
						child_5 = (*n)._kind_6.sons->data[i_23];
						traverse__varpartitions_1287(c, child_5);
						i_24 += ((NI) 1);
					} LA132: ;
				}
			}
		}
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child_6;
			child_6 = NIM_NIL;
			{
				NI i_25;
				NI colontmp__12;
				NI i_26;
				i_25 = (NI)0;
				colontmp__12 = (NI)0;
				colontmp__12 = safeLen__ast_3148(n);
				i_26 = ((NI) 0);
				{
					while (1) {
						if (!(i_26 < colontmp__12)) goto LA136;
						i_25 = i_26;
						child_6 = (*n)._kind_6.sons->data[i_25];
						traverse__varpartitions_1287(c, child_6);
						i_26 += ((NI) 1);
					} LA136: ;
				}
			}
		}
	}
	break;
	default:
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child_7;
			child_7 = NIM_NIL;
			{
				NI i_27;
				NI colontmp__13;
				NI i_28;
				i_27 = (NI)0;
				colontmp__13 = (NI)0;
				colontmp__13 = safeLen__ast_3148(n);
				i_28 = ((NI) 0);
				{
					while (1) {
						if (!(i_28 < colontmp__13)) goto LA141;
						i_27 = i_28;
						child_7 = (*n)._kind_6.sons->data[i_27];
						traverse__varpartitions_1287(c, child_7);
						i_28 += ((NI) 1);
					} LA141: ;
				}
			}
		}
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, computeGraphPartitions__varpartitions_1622)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tySet_tyEnum_Goal__YflPrGhMLgZ4bbrBBVpmOA goals, tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* Result) {
	(*Result).abstractTime = 0;
	unsureAsgnRef((void**)&(*Result).s, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).graphs, NIM_NIL);
	(*Result).goals = 0;
	(*Result).unanalysableMutation = 0;
	(*Result).inAsgnSource = 0;
	(*Result).inConstructor = 0;
	(*Result).inNoSideEffectSection = 0;
	(*Result).inConditional = 0;
	(*Result).inLoop = 0;
	unsureAsgnRef((void**)&(*Result).owner, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).g, NIM_NIL);
	unsureAsgnRef((void**) (&(*Result).owner), s);
	unsureAsgnRef((void**) (&(*Result).g), g);
	(*Result).goals = goals;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* params;
		if (!!(((131136 &((NU32)1<<((NU)((*s).kind)&31U)))!=0))) goto LA3_;
		params = (*(*s).typ).n;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(params);
			i_2 = ((NI) 1);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA7;
					i = i_2;
					registerParam__varpartitions_273(Result, (*params)._kind_6.sons->data[i]);
					i_2 += ((NI) 1);
				} LA7: ;
			}
		}
		{
			NI T10_;
			T10_ = (NI)0;
			T10_ = safeLen__ast_3148((*s).ast);
			if (!(((NI) 7) < T10_)) goto LA11_;
			registerResult__varpartitions_214(Result, (*(*s).ast)._kind_6.sons->data[((NI) 7)]);
		}
		LA11_: ;
	}
	LA3_: ;
	computeLiveRanges__varpartitions_1469(Result, n);
	(*Result).abstractTime = ((NI) 0);
	traverse__varpartitions_1287(Result, n);
}
static N_INLINE(NIM_BOOL, mutationAfterConnection__varpartitions_105)(tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ* g) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((*g).minConnection < (*g).maxMutation);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasSideEffect__varpartitions_131)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ* info) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ* g;
		NI i;
		NI L;
		NI T2_;
		g = (tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ*)0;
		i = ((NI) 0);
		T2_ = ((*c).graphs ? (*c).graphs->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				g = (&(*c).graphs->data[i]);
				{
					NIM_BOOL T7_;
					NIM_BOOL T9_;
					T7_ = (NIM_BOOL)0;
					T7_ = (((*g).flags & 9) == 9);
					if (!(T7_)) goto LA8_;
					T9_ = (NIM_BOOL)0;
					T9_ = mutationAfterConnection__varpartitions_105((&(*g)));
					if (T9_) goto LA10_;
					T9_ = (((*g).flags &((NU8)1<<((NU)(((tyEnum_SubgraphFlag__YymRBOaunI7GAAzxsJI39cA) 1))&7U)))!=0);
					LA10_: ;
					T7_ = T9_;
					LA8_: ;
					if (!T7_) goto LA11_;
					genericAssign((void*)(&(*info)), (void*)(&(*g)), (&NTImutationinfo__gL2XNL3vfSXoqvlltP0JhQ_));
					result = NIM_TRUE;
					goto BeforeRet_;
				}
				LA11_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
	result = NIM_FALSE;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__varpartitions_1713)(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw s, NI value) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (s.a <= value);
	if (!(T1_)) goto LA2_;
	T1_ = (value <= s.b);
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw, dotdot___varpartitions_1692)(NI a, NI b) {
	tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw));
	result.a = a;
	result.b = b;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, dangerousMutation__varpartitions_1661)(tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ* g, tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A* v) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		if (!!(((5 & (*g).flags) == 0))) goto LA3_;
		{
			NI* m;
			NI i;
			NI L;
			NI T6_;
			m = (NI*)0;
			i = ((NI) 0);
			T6_ = ((*g).mutations ? (*g).mutations->Sup.len : 0);
			L = T6_;
			{
				while (1) {
					if (!(i < L)) goto LA8;
					m = (&(*g).mutations->data[i]);
					{
						tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw T11_;
						NIM_BOOL T12_;
						T11_ = dotdot___varpartitions_1692((*v).aliveStart, (*v).aliveEnd);
						T12_ = (NIM_BOOL)0;
						T12_ = contains__varpartitions_1713(T11_, (*m));
						if (!T12_) goto LA13_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA13_: ;
					i += ((NI) 1);
				} LA8: ;
			}
		}
	}
	LA3_: ;
	result = NIM_FALSE;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, cannotBorrow__varpartitions_1729)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ* g) {
	NimStringDesc* m;
	NimStringDesc* T1_;
	T1_ = NIM_NIL;
	T1_ = rawNewString(((*(*s).name).s ? (*(*s).name).s->Sup.len : 0) + 59);
appendString(T1_, ((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_26));
appendString(T1_, (*(*s).name).s);
appendString(T1_, ((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_27));
	m = T1_;
	{
		NIM_BOOL T4_;
		NimStringDesc* T7_;
		T4_ = (NIM_BOOL)0;
		T4_ = eqeq___msgs_1003((*g).mutatedHere, unknownLineInfo__lineinfos_284);
		if (!!(T4_)) goto LA5_;
		m = resizeString(m, 1);
appendString(m, ((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_28));
		T7_ = NIM_NIL;
		T7_ = dollar___msgs_634(config, (*g).mutatedHere);
		m = resizeString(m, (T7_ ? T7_->Sup.len : 0) + 0);
appendString(m, T7_);
		m = resizeString(m, 21);
appendString(m, ((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_29));
	}
	LA5_: ;
	{
		NIM_BOOL T10_;
		NimStringDesc* T13_;
		T10_ = (NIM_BOOL)0;
		T10_ = eqeq___msgs_1003((*g).connectedVia, unknownLineInfo__lineinfos_284);
		if (!!(T10_)) goto LA11_;
		m = resizeString(m, 1);
appendString(m, ((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_28));
		T13_ = NIM_NIL;
		T13_ = dollar___msgs_634(config, (*g).connectedVia);
		m = resizeString(m, (T13_ ? T13_->Sup.len : 0) + 0);
appendString(m, T13_);
		m = resizeString(m, 62);
appendString(m, ((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_30));
	}
	LA11_: ;
	liMessage__msgs_1128(config, (*s).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), m, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__4R4QZluAmhY3f04fEZJ3nA_31, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(void, checkBorrowedLocations__varpartitions_1734)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* par, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config) {
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = ((*par).s ? (*par).s->Sup.len : 0);
		colontmp_ = T2_;
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* v;
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				v = (*par).s->data[i].sym;
				{
					NIM_BOOL T7_;
					tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ T9_;
					NI rid;
					T7_ = (NIM_BOOL)0;
					T7_ = !(((*v).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3)));
					if (!(T7_)) goto LA8_;
					T9_ = (tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ)0;
					T9_ = classifyViewType__typeallowed_579((*v).typ);
					T7_ = !((T9_ == ((tyEnum_ViewTypeKind__u2B9a1gH4LPPJaSqULlL7yQ) 0)));
					LA8_: ;
					if (!T7_) goto LA10_;
					rid = root__varpartitions_339(par, i);
					{
						NIM_BOOL constViolation;
						if (!(((NI) 0) <= rid)) goto LA14_;
						constViolation = NIM_FALSE;
						{
							NI* b;
							tySequence__qwqHTkRvwhrRyENtudHQ7g* colontmp__2;
							NI i_3;
							NI L;
							NI T17_;
							b = (NI*)0;
							colontmp__2 = NIM_NIL;
							colontmp__2 = (*par).s->data[rid].borrowsFrom;
							i_3 = ((NI) 0);
							T17_ = (colontmp__2 ? colontmp__2->Sup.len : 0);
							L = T17_;
							{
								while (1) {
									NI sid;
									if (!(i_3 < L)) goto LA19;
									b = (&colontmp__2->data[i_3]);
									sid = root__varpartitions_339(par, (*b));
									{
										if (!(((NI) 0) <= sid)) goto LA22_;
										{
											NIM_BOOL T26_;
											T26_ = (NIM_BOOL)0;
											T26_ = ((*par).s->data[sid].con.kind == ((tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w) 2));
											if (!(T26_)) goto LA27_;
											T26_ = dangerousMutation__varpartitions_1661((&(*par).graphs->data[(*par).s->data[sid].con.graphIndex]), (&(*par).s->data[i]));
											LA27_: ;
											if (!T26_) goto LA28_;
											cannotBorrow__varpartitions_1729(config, v, (&(*par).graphs->data[(*par).s->data[sid].con.graphIndex]));
										}
										LA28_: ;
										{
											NIM_BOOL T32_;
											NimStringDesc* T36_;
											T32_ = (NIM_BOOL)0;
											T32_ = !(((*(*par).s->data[sid].sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3)));
											if (!(T32_)) goto LA33_;
											T32_ = ((*par).s->data[sid].aliveEnd < (*par).s->data[rid].aliveEnd);
											LA33_: ;
											if (!T32_) goto LA34_;
											T36_ = NIM_NIL;
											T36_ = rawNewString(((*(*v).name).s ? (*(*v).name).s->Sup.len : 0) + ((*(*(*par).s->data[sid].sym).name).s ? (*(*(*par).s->data[sid].sym).name).s->Sup.len : 0) + 59);
appendString(T36_, ((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_32));
appendString(T36_, (*(*v).name).s);
appendString(T36_, ((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_33));
appendString(T36_, (*(*(*par).s->data[sid].sym).name).s);
appendString(T36_, ((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_34));
											liMessage__msgs_1128(config, (*v).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T36_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__4R4QZluAmhY3f04fEZJ3nA_35, NIM_FALSE);
										}
										LA34_: ;
										{
											NIM_BOOL T39_;
											NimStringDesc* T43_;
											T39_ = (NIM_BOOL)0;
											T39_ = (((*par).s->data[rid].flags &((NU8)1<<((NU)(((tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw) 4))&7U)))!=0);
											if (!(T39_)) goto LA40_;
											T39_ = isConstSym__varpartitions_1017((*par).s->data[sid].sym);
											LA40_: ;
											if (!T39_) goto LA41_;
											T43_ = NIM_NIL;
											T43_ = rawNewString(((*(*v).name).s ? (*(*v).name).s->Sup.len : 0) + ((*(*(*par).s->data[sid].sym).name).s ? (*(*(*par).s->data[sid].sym).name).s->Sup.len : 0) + 67);
appendString(T43_, ((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_32));
appendString(T43_, (*(*v).name).s);
appendString(T43_, ((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_36));
appendString(T43_, (*(*(*par).s->data[sid].sym).name).s);
appendString(T43_, ((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_37));
											liMessage__msgs_1128(config, (*v).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T43_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__4R4QZluAmhY3f04fEZJ3nA_38, NIM_FALSE);
											constViolation = NIM_TRUE;
										}
										LA41_: ;
									}
									LA22_: ;
									i_3 += ((NI) 1);
								} LA19: ;
							}
						}
						{
							NIM_BOOL T46_;
							NimStringDesc* T50_;
							T46_ = (NIM_BOOL)0;
							T46_ = ((48 & (*par).s->data[rid].flags) == 48);
							if (!(T46_)) goto LA47_;
							T46_ = !(constViolation);
							LA47_: ;
							if (!T46_) goto LA48_;
							T50_ = NIM_NIL;
							T50_ = rawNewString(((*(*v).name).s ? (*(*v).name).s->Sup.len : 0) + 63);
appendString(T50_, ((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_32));
appendString(T50_, (*(*v).name).s);
appendString(T50_, ((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_39));
							liMessage__msgs_1128(config, (*v).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T50_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__4R4QZluAmhY3f04fEZJ3nA_40, NIM_FALSE);
						}
						LA48_: ;
					}
					LA14_: ;
				}
				LA10_: ;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___varpartitions_108)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ* g) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = ((NimStringDesc*) NIM_NIL);
	{
		if (!(((*g).flags & 9) == 9)) goto LA3_;
		result = resizeString(result, 27);
appendString(result, ((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_41));
		result = resizeString(result, ((*(*(*g).param).name).s ? (*(*(*g).param).name).s->Sup.len : 0) + 0);
appendString(result, (*(*(*g).param).name).s);
		result = resizeString(result, 24);
appendString(result, ((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_42));
		{
			NIM_BOOL T7_;
			NimStringDesc* T10_;
			T7_ = (NIM_BOOL)0;
			T7_ = eqeq___msgs_1003((*g).mutatedHere, unknownLineInfo__lineinfos_284);
			if (!!(T7_)) goto LA8_;
			result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_28));
			T10_ = NIM_NIL;
			T10_ = dollar___msgs_634(config, (*g).mutatedHere);
			result = resizeString(result, (T10_ ? T10_->Sup.len : 0) + 0);
appendString(result, T10_);
			result = resizeString(result, 21);
appendString(result, ((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_29));
		}
		LA8_: ;
		{
			NIM_BOOL T13_;
			NimStringDesc* T16_;
			T13_ = (NIM_BOOL)0;
			T13_ = eqeq___msgs_1003((*g).connectedVia, unknownLineInfo__lineinfos_284);
			if (!!(T13_)) goto LA14_;
			result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_28));
			T16_ = NIM_NIL;
			T16_ = dollar___msgs_634(config, (*g).connectedVia);
			result = resizeString(result, (T16_ ? T16_->Sup.len : 0) + 0);
appendString(result, T16_);
			result = resizeString(result, 62);
appendString(result, ((NimStringDesc*) &TM__4R4QZluAmhY3f04fEZJ3nA_30));
		}
		LA14_: ;
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, computeCursors__varpartitions_1798)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA par;
	nimZeroMem((void*)(&par), sizeof(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA));
	computeGraphPartitions__varpartitions_1622(s, n, g, 4, (&par));
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (par.s ? par.s->Sup.len : 0);
		colontmp_ = T2_;
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A* v;
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				v = (&par.s->data[i]);
				{
					NIM_BOOL T7_;
					NIM_BOOL T8_;
					NIM_BOOL T9_;
					NIM_BOOL T10_;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T15_;
					NI rid;
					T7_ = (NIM_BOOL)0;
					T8_ = (NIM_BOOL)0;
					T9_ = (NIM_BOOL)0;
					T10_ = (NIM_BOOL)0;
					T10_ = (((*v).flags & 11) == 0);
					if (!(T10_)) goto LA11_;
					T10_ = !(((2056 &((NU32)1<<((NU)((*(*v).sym).kind)&31U)))!=0));
					LA11_: ;
					T9_ = T10_;
					if (!(T9_)) goto LA12_;
					T9_ = (((*(*v).sym).flags & 67108872) == 0);
					LA12_: ;
					T8_ = T9_;
					if (!(T8_)) goto LA13_;
					T8_ = !(((IL64(2147483664) & (*(*(*v).sym).typ).flags) == 0));
					LA13_: ;
					T7_ = T8_;
					if (!(T7_)) goto LA14_;
					T15_ = NIM_NIL;
					T15_ = skipTypes__ast_3723((*(*v).sym).typ, TM__4R4QZluAmhY3f04fEZJ3nA_13);
					T7_ = !(((*T15_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45)));
					LA14_: ;
					if (!T7_) goto LA16_;
					rid = root__varpartitions_339((&par), i);
					{
						NIM_BOOL T20_;
						T20_ = (NIM_BOOL)0;
						T20_ = (par.s->data[rid].con.kind == ((tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w) 2));
						if (!(T20_)) goto LA21_;
						T20_ = dangerousMutation__varpartitions_1661((&par.graphs->data[par.s->data[rid].con.graphIndex]), (&par.s->data[i]));
						LA21_: ;
						if (!T20_) goto LA22_;
					}
					goto LA18_;
					LA22_: ;
					{
						(*(*v).sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 41)) & 63);
					}
					LA18_: ;
				}
				LA16_: ;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, atmvarpartitionsdotnim_DatInit000)(void) {
static TNimNode* TM__4R4QZluAmhY3f04fEZJ3nA_2_7[7];
static TNimNode* TM__4R4QZluAmhY3f04fEZJ3nA_3_3[3];
NI TM__4R4QZluAmhY3f04fEZJ3nA_5;
static char* NIM_CONST TM__4R4QZluAmhY3f04fEZJ3nA_4[3] = {
"isEmptyRoot", 
"dependsOn", 
"isRootOf"};
static TNimNode* TM__4R4QZluAmhY3f04fEZJ3nA_6_6[6];
NI TM__4R4QZluAmhY3f04fEZJ3nA_8;
static char* NIM_CONST TM__4R4QZluAmhY3f04fEZJ3nA_7[6] = {
"ownsData", 
"preventCursor", 
"isReassigned", 
"isConditionallyReassigned", 
"viewDoesMutate", 
"viewBorrowsFromConst"};
static TNimNode* TM__4R4QZluAmhY3f04fEZJ3nA_9_7[7];
static TNimNode* TM__4R4QZluAmhY3f04fEZJ3nA_10_4[4];
NI TM__4R4QZluAmhY3f04fEZJ3nA_12;
static char* NIM_CONST TM__4R4QZluAmhY3f04fEZJ3nA_11[4] = {
"isMutated", 
"isMutatedDirectly", 
"isMutatedByVarParam", 
"connectsConstParam"};
static TNimNode* TM__4R4QZluAmhY3f04fEZJ3nA_21_2[2];
static TNimNode TM__4R4QZluAmhY3f04fEZJ3nA_0[41];
NTIvarindex__yOk84K16nGJiOC29biRT9b4A_.size = sizeof(tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A);
NTIvarindex__yOk84K16nGJiOC29biRT9b4A_.align = NIM_ALIGNOF(tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A);
NTIvarindex__yOk84K16nGJiOC29biRT9b4A_.kind = 18;
NTIvarindex__yOk84K16nGJiOC29biRT9b4A_.base = 0;
NTIvarindex__yOk84K16nGJiOC29biRT9b4A_.flags = 2;
TM__4R4QZluAmhY3f04fEZJ3nA_2_7[0] = &TM__4R4QZluAmhY3f04fEZJ3nA_0[1];
NTIconnection__SFxQPgR9b9aWd2frrlyFQ2mA_.size = sizeof(tyObject_Connection__SFxQPgR9b9aWd2frrlyFQ2mA);
NTIconnection__SFxQPgR9b9aWd2frrlyFQ2mA_.align = NIM_ALIGNOF(tyObject_Connection__SFxQPgR9b9aWd2frrlyFQ2mA);
NTIconnection__SFxQPgR9b9aWd2frrlyFQ2mA_.kind = 18;
NTIconnection__SFxQPgR9b9aWd2frrlyFQ2mA_.base = 0;
NTIconnection__SFxQPgR9b9aWd2frrlyFQ2mA_.flags = 3;
NTIvarindexkind__6gmJu6oZ1VBqh2mKO9cHZ5w_.size = sizeof(tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w);
NTIvarindexkind__6gmJu6oZ1VBqh2mKO9cHZ5w_.align = NIM_ALIGNOF(tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w);
NTIvarindexkind__6gmJu6oZ1VBqh2mKO9cHZ5w_.kind = 14;
NTIvarindexkind__6gmJu6oZ1VBqh2mKO9cHZ5w_.base = 0;
NTIvarindexkind__6gmJu6oZ1VBqh2mKO9cHZ5w_.flags = 3;
for (TM__4R4QZluAmhY3f04fEZJ3nA_5 = 0; TM__4R4QZluAmhY3f04fEZJ3nA_5 < 3; TM__4R4QZluAmhY3f04fEZJ3nA_5++) {
TM__4R4QZluAmhY3f04fEZJ3nA_0[TM__4R4QZluAmhY3f04fEZJ3nA_5+3].kind = 1;
TM__4R4QZluAmhY3f04fEZJ3nA_0[TM__4R4QZluAmhY3f04fEZJ3nA_5+3].offset = TM__4R4QZluAmhY3f04fEZJ3nA_5;
TM__4R4QZluAmhY3f04fEZJ3nA_0[TM__4R4QZluAmhY3f04fEZJ3nA_5+3].name = TM__4R4QZluAmhY3f04fEZJ3nA_4[TM__4R4QZluAmhY3f04fEZJ3nA_5];
TM__4R4QZluAmhY3f04fEZJ3nA_3_3[TM__4R4QZluAmhY3f04fEZJ3nA_5] = &TM__4R4QZluAmhY3f04fEZJ3nA_0[TM__4R4QZluAmhY3f04fEZJ3nA_5+3];
}
TM__4R4QZluAmhY3f04fEZJ3nA_0[6].len = 3; TM__4R4QZluAmhY3f04fEZJ3nA_0[6].kind = 2; TM__4R4QZluAmhY3f04fEZJ3nA_0[6].sons = &TM__4R4QZluAmhY3f04fEZJ3nA_3_3[0];
NTIvarindexkind__6gmJu6oZ1VBqh2mKO9cHZ5w_.node = &TM__4R4QZluAmhY3f04fEZJ3nA_0[6];
TM__4R4QZluAmhY3f04fEZJ3nA_0[2].kind = 3;
TM__4R4QZluAmhY3f04fEZJ3nA_0[2].offset = offsetof(tyObject_Connection__SFxQPgR9b9aWd2frrlyFQ2mA, kind);
TM__4R4QZluAmhY3f04fEZJ3nA_0[2].typ = (&NTIvarindexkind__6gmJu6oZ1VBqh2mKO9cHZ5w_);
TM__4R4QZluAmhY3f04fEZJ3nA_0[2].name = "kind";
TM__4R4QZluAmhY3f04fEZJ3nA_0[2].sons = &NimDT___SFxQPgR9b9aWd2frrlyFQ2mA_kind[0];
TM__4R4QZluAmhY3f04fEZJ3nA_0[2].len = 3;
TM__4R4QZluAmhY3f04fEZJ3nA_0[7].len = 0; TM__4R4QZluAmhY3f04fEZJ3nA_0[7].kind = 2;
NimDT___SFxQPgR9b9aWd2frrlyFQ2mA_kind[0] = &TM__4R4QZluAmhY3f04fEZJ3nA_0[7];
TM__4R4QZluAmhY3f04fEZJ3nA_0[8].kind = 1;
TM__4R4QZluAmhY3f04fEZJ3nA_0[8].offset = offsetof(tyObject_Connection__SFxQPgR9b9aWd2frrlyFQ2mA, parent);
TM__4R4QZluAmhY3f04fEZJ3nA_0[8].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__4R4QZluAmhY3f04fEZJ3nA_0[8].name = "parent";
NimDT___SFxQPgR9b9aWd2frrlyFQ2mA_kind[1] = &TM__4R4QZluAmhY3f04fEZJ3nA_0[8];
TM__4R4QZluAmhY3f04fEZJ3nA_0[9].kind = 1;
TM__4R4QZluAmhY3f04fEZJ3nA_0[9].offset = offsetof(tyObject_Connection__SFxQPgR9b9aWd2frrlyFQ2mA, graphIndex);
TM__4R4QZluAmhY3f04fEZJ3nA_0[9].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__4R4QZluAmhY3f04fEZJ3nA_0[9].name = "graphIndex";
NimDT___SFxQPgR9b9aWd2frrlyFQ2mA_kind[2] = &TM__4R4QZluAmhY3f04fEZJ3nA_0[9];
NTIconnection__SFxQPgR9b9aWd2frrlyFQ2mA_.node = &TM__4R4QZluAmhY3f04fEZJ3nA_0[2];
TM__4R4QZluAmhY3f04fEZJ3nA_0[1].kind = 1;
TM__4R4QZluAmhY3f04fEZJ3nA_0[1].offset = offsetof(tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A, con);
TM__4R4QZluAmhY3f04fEZJ3nA_0[1].typ = (&NTIconnection__SFxQPgR9b9aWd2frrlyFQ2mA_);
TM__4R4QZluAmhY3f04fEZJ3nA_0[1].name = "con";
TM__4R4QZluAmhY3f04fEZJ3nA_2_7[1] = &TM__4R4QZluAmhY3f04fEZJ3nA_0[10];
NTIvarflag__bzKsGwCSV281SrVX80B6Kw_.size = sizeof(tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw);
NTIvarflag__bzKsGwCSV281SrVX80B6Kw_.align = NIM_ALIGNOF(tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw);
NTIvarflag__bzKsGwCSV281SrVX80B6Kw_.kind = 14;
NTIvarflag__bzKsGwCSV281SrVX80B6Kw_.base = 0;
NTIvarflag__bzKsGwCSV281SrVX80B6Kw_.flags = 3;
for (TM__4R4QZluAmhY3f04fEZJ3nA_8 = 0; TM__4R4QZluAmhY3f04fEZJ3nA_8 < 6; TM__4R4QZluAmhY3f04fEZJ3nA_8++) {
TM__4R4QZluAmhY3f04fEZJ3nA_0[TM__4R4QZluAmhY3f04fEZJ3nA_8+11].kind = 1;
TM__4R4QZluAmhY3f04fEZJ3nA_0[TM__4R4QZluAmhY3f04fEZJ3nA_8+11].offset = TM__4R4QZluAmhY3f04fEZJ3nA_8;
TM__4R4QZluAmhY3f04fEZJ3nA_0[TM__4R4QZluAmhY3f04fEZJ3nA_8+11].name = TM__4R4QZluAmhY3f04fEZJ3nA_7[TM__4R4QZluAmhY3f04fEZJ3nA_8];
TM__4R4QZluAmhY3f04fEZJ3nA_6_6[TM__4R4QZluAmhY3f04fEZJ3nA_8] = &TM__4R4QZluAmhY3f04fEZJ3nA_0[TM__4R4QZluAmhY3f04fEZJ3nA_8+11];
}
TM__4R4QZluAmhY3f04fEZJ3nA_0[17].len = 6; TM__4R4QZluAmhY3f04fEZJ3nA_0[17].kind = 2; TM__4R4QZluAmhY3f04fEZJ3nA_0[17].sons = &TM__4R4QZluAmhY3f04fEZJ3nA_6_6[0];
NTIvarflag__bzKsGwCSV281SrVX80B6Kw_.node = &TM__4R4QZluAmhY3f04fEZJ3nA_0[17];
NTIsetLvarflagT__ZSU4Y9c9bV9bFj878q6AmNipQ_.size = sizeof(tySet_tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw);
NTIsetLvarflagT__ZSU4Y9c9bV9bFj878q6AmNipQ_.align = NIM_ALIGNOF(tySet_tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw);
NTIsetLvarflagT__ZSU4Y9c9bV9bFj878q6AmNipQ_.kind = 19;
NTIsetLvarflagT__ZSU4Y9c9bV9bFj878q6AmNipQ_.base = (&NTIvarflag__bzKsGwCSV281SrVX80B6Kw_);
NTIsetLvarflagT__ZSU4Y9c9bV9bFj878q6AmNipQ_.flags = 3;
TM__4R4QZluAmhY3f04fEZJ3nA_0[18].len = 0; TM__4R4QZluAmhY3f04fEZJ3nA_0[18].kind = 0;
NTIsetLvarflagT__ZSU4Y9c9bV9bFj878q6AmNipQ_.node = &TM__4R4QZluAmhY3f04fEZJ3nA_0[18];
TM__4R4QZluAmhY3f04fEZJ3nA_0[10].kind = 1;
TM__4R4QZluAmhY3f04fEZJ3nA_0[10].offset = offsetof(tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A, flags);
TM__4R4QZluAmhY3f04fEZJ3nA_0[10].typ = (&NTIsetLvarflagT__ZSU4Y9c9bV9bFj878q6AmNipQ_);
TM__4R4QZluAmhY3f04fEZJ3nA_0[10].name = "flags";
TM__4R4QZluAmhY3f04fEZJ3nA_2_7[2] = &TM__4R4QZluAmhY3f04fEZJ3nA_0[19];
TM__4R4QZluAmhY3f04fEZJ3nA_0[19].kind = 1;
TM__4R4QZluAmhY3f04fEZJ3nA_0[19].offset = offsetof(tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A, sym);
TM__4R4QZluAmhY3f04fEZJ3nA_0[19].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__4R4QZluAmhY3f04fEZJ3nA_0[19].name = "sym";
TM__4R4QZluAmhY3f04fEZJ3nA_2_7[3] = &TM__4R4QZluAmhY3f04fEZJ3nA_0[20];
TM__4R4QZluAmhY3f04fEZJ3nA_0[20].kind = 1;
TM__4R4QZluAmhY3f04fEZJ3nA_0[20].offset = offsetof(tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A, reassignedTo);
TM__4R4QZluAmhY3f04fEZJ3nA_0[20].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__4R4QZluAmhY3f04fEZJ3nA_0[20].name = "reassignedTo";
TM__4R4QZluAmhY3f04fEZJ3nA_2_7[4] = &TM__4R4QZluAmhY3f04fEZJ3nA_0[21];
TM__4R4QZluAmhY3f04fEZJ3nA_0[21].kind = 1;
TM__4R4QZluAmhY3f04fEZJ3nA_0[21].offset = offsetof(tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A, aliveStart);
TM__4R4QZluAmhY3f04fEZJ3nA_0[21].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__4R4QZluAmhY3f04fEZJ3nA_0[21].name = "aliveStart";
TM__4R4QZluAmhY3f04fEZJ3nA_2_7[5] = &TM__4R4QZluAmhY3f04fEZJ3nA_0[22];
TM__4R4QZluAmhY3f04fEZJ3nA_0[22].kind = 1;
TM__4R4QZluAmhY3f04fEZJ3nA_0[22].offset = offsetof(tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A, aliveEnd);
TM__4R4QZluAmhY3f04fEZJ3nA_0[22].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__4R4QZluAmhY3f04fEZJ3nA_0[22].name = "aliveEnd";
TM__4R4QZluAmhY3f04fEZJ3nA_2_7[6] = &TM__4R4QZluAmhY3f04fEZJ3nA_0[23];
TM__4R4QZluAmhY3f04fEZJ3nA_0[23].kind = 1;
TM__4R4QZluAmhY3f04fEZJ3nA_0[23].offset = offsetof(tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A, borrowsFrom);
TM__4R4QZluAmhY3f04fEZJ3nA_0[23].typ = (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_);
TM__4R4QZluAmhY3f04fEZJ3nA_0[23].name = "borrowsFrom";
TM__4R4QZluAmhY3f04fEZJ3nA_0[0].len = 7; TM__4R4QZluAmhY3f04fEZJ3nA_0[0].kind = 2; TM__4R4QZluAmhY3f04fEZJ3nA_0[0].sons = &TM__4R4QZluAmhY3f04fEZJ3nA_2_7[0];
NTIvarindex__yOk84K16nGJiOC29biRT9b4A_.node = &TM__4R4QZluAmhY3f04fEZJ3nA_0[0];
NTIseqLvarindexT__dLJ0v9cLHnWw9bA0ZQgPURgA_.size = sizeof(tySequence__dLJ0v9cLHnWw9bA0ZQgPURgA*);
NTIseqLvarindexT__dLJ0v9cLHnWw9bA0ZQgPURgA_.align = NIM_ALIGNOF(tySequence__dLJ0v9cLHnWw9bA0ZQgPURgA*);
NTIseqLvarindexT__dLJ0v9cLHnWw9bA0ZQgPURgA_.kind = 24;
NTIseqLvarindexT__dLJ0v9cLHnWw9bA0ZQgPURgA_.base = (&NTIvarindex__yOk84K16nGJiOC29biRT9b4A_);
NTIseqLvarindexT__dLJ0v9cLHnWw9bA0ZQgPURgA_.flags = 2;
NTIseqLvarindexT__dLJ0v9cLHnWw9bA0ZQgPURgA_.marker = Marker_tySequence__dLJ0v9cLHnWw9bA0ZQgPURgA;
NTImutationinfo__gL2XNL3vfSXoqvlltP0JhQ_.size = sizeof(tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ);
NTImutationinfo__gL2XNL3vfSXoqvlltP0JhQ_.align = NIM_ALIGNOF(tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ);
NTImutationinfo__gL2XNL3vfSXoqvlltP0JhQ_.kind = 18;
NTImutationinfo__gL2XNL3vfSXoqvlltP0JhQ_.base = 0;
NTImutationinfo__gL2XNL3vfSXoqvlltP0JhQ_.flags = 2;
TM__4R4QZluAmhY3f04fEZJ3nA_9_7[0] = &TM__4R4QZluAmhY3f04fEZJ3nA_0[25];
TM__4R4QZluAmhY3f04fEZJ3nA_0[25].kind = 1;
TM__4R4QZluAmhY3f04fEZJ3nA_0[25].offset = offsetof(tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ, param);
TM__4R4QZluAmhY3f04fEZJ3nA_0[25].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__4R4QZluAmhY3f04fEZJ3nA_0[25].name = "param";
TM__4R4QZluAmhY3f04fEZJ3nA_9_7[1] = &TM__4R4QZluAmhY3f04fEZJ3nA_0[26];
TM__4R4QZluAmhY3f04fEZJ3nA_0[26].kind = 1;
TM__4R4QZluAmhY3f04fEZJ3nA_0[26].offset = offsetof(tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ, mutatedHere);
TM__4R4QZluAmhY3f04fEZJ3nA_0[26].typ = (&NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_);
TM__4R4QZluAmhY3f04fEZJ3nA_0[26].name = "mutatedHere";
TM__4R4QZluAmhY3f04fEZJ3nA_9_7[2] = &TM__4R4QZluAmhY3f04fEZJ3nA_0[27];
TM__4R4QZluAmhY3f04fEZJ3nA_0[27].kind = 1;
TM__4R4QZluAmhY3f04fEZJ3nA_0[27].offset = offsetof(tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ, connectedVia);
TM__4R4QZluAmhY3f04fEZJ3nA_0[27].typ = (&NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_);
TM__4R4QZluAmhY3f04fEZJ3nA_0[27].name = "connectedVia";
TM__4R4QZluAmhY3f04fEZJ3nA_9_7[3] = &TM__4R4QZluAmhY3f04fEZJ3nA_0[28];
NTIsubgraphflag__YymRBOaunI7GAAzxsJI39cA_.size = sizeof(tyEnum_SubgraphFlag__YymRBOaunI7GAAzxsJI39cA);
NTIsubgraphflag__YymRBOaunI7GAAzxsJI39cA_.align = NIM_ALIGNOF(tyEnum_SubgraphFlag__YymRBOaunI7GAAzxsJI39cA);
NTIsubgraphflag__YymRBOaunI7GAAzxsJI39cA_.kind = 14;
NTIsubgraphflag__YymRBOaunI7GAAzxsJI39cA_.base = 0;
NTIsubgraphflag__YymRBOaunI7GAAzxsJI39cA_.flags = 3;
for (TM__4R4QZluAmhY3f04fEZJ3nA_12 = 0; TM__4R4QZluAmhY3f04fEZJ3nA_12 < 4; TM__4R4QZluAmhY3f04fEZJ3nA_12++) {
TM__4R4QZluAmhY3f04fEZJ3nA_0[TM__4R4QZluAmhY3f04fEZJ3nA_12+29].kind = 1;
TM__4R4QZluAmhY3f04fEZJ3nA_0[TM__4R4QZluAmhY3f04fEZJ3nA_12+29].offset = TM__4R4QZluAmhY3f04fEZJ3nA_12;
TM__4R4QZluAmhY3f04fEZJ3nA_0[TM__4R4QZluAmhY3f04fEZJ3nA_12+29].name = TM__4R4QZluAmhY3f04fEZJ3nA_11[TM__4R4QZluAmhY3f04fEZJ3nA_12];
TM__4R4QZluAmhY3f04fEZJ3nA_10_4[TM__4R4QZluAmhY3f04fEZJ3nA_12] = &TM__4R4QZluAmhY3f04fEZJ3nA_0[TM__4R4QZluAmhY3f04fEZJ3nA_12+29];
}
TM__4R4QZluAmhY3f04fEZJ3nA_0[33].len = 4; TM__4R4QZluAmhY3f04fEZJ3nA_0[33].kind = 2; TM__4R4QZluAmhY3f04fEZJ3nA_0[33].sons = &TM__4R4QZluAmhY3f04fEZJ3nA_10_4[0];
NTIsubgraphflag__YymRBOaunI7GAAzxsJI39cA_.node = &TM__4R4QZluAmhY3f04fEZJ3nA_0[33];
NTIsetLsubgraphflagT__agpjcE5f9bu9aruHjbC9als3w_.size = sizeof(tySet_tyEnum_SubgraphFlag__YymRBOaunI7GAAzxsJI39cA);
NTIsetLsubgraphflagT__agpjcE5f9bu9aruHjbC9als3w_.align = NIM_ALIGNOF(tySet_tyEnum_SubgraphFlag__YymRBOaunI7GAAzxsJI39cA);
NTIsetLsubgraphflagT__agpjcE5f9bu9aruHjbC9als3w_.kind = 19;
NTIsetLsubgraphflagT__agpjcE5f9bu9aruHjbC9als3w_.base = (&NTIsubgraphflag__YymRBOaunI7GAAzxsJI39cA_);
NTIsetLsubgraphflagT__agpjcE5f9bu9aruHjbC9als3w_.flags = 3;
TM__4R4QZluAmhY3f04fEZJ3nA_0[34].len = 0; TM__4R4QZluAmhY3f04fEZJ3nA_0[34].kind = 0;
NTIsetLsubgraphflagT__agpjcE5f9bu9aruHjbC9als3w_.node = &TM__4R4QZluAmhY3f04fEZJ3nA_0[34];
TM__4R4QZluAmhY3f04fEZJ3nA_0[28].kind = 1;
TM__4R4QZluAmhY3f04fEZJ3nA_0[28].offset = offsetof(tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ, flags);
TM__4R4QZluAmhY3f04fEZJ3nA_0[28].typ = (&NTIsetLsubgraphflagT__agpjcE5f9bu9aruHjbC9als3w_);
TM__4R4QZluAmhY3f04fEZJ3nA_0[28].name = "flags";
TM__4R4QZluAmhY3f04fEZJ3nA_9_7[4] = &TM__4R4QZluAmhY3f04fEZJ3nA_0[35];
TM__4R4QZluAmhY3f04fEZJ3nA_0[35].kind = 1;
TM__4R4QZluAmhY3f04fEZJ3nA_0[35].offset = offsetof(tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ, maxMutation);
TM__4R4QZluAmhY3f04fEZJ3nA_0[35].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__4R4QZluAmhY3f04fEZJ3nA_0[35].name = "maxMutation";
TM__4R4QZluAmhY3f04fEZJ3nA_9_7[5] = &TM__4R4QZluAmhY3f04fEZJ3nA_0[36];
TM__4R4QZluAmhY3f04fEZJ3nA_0[36].kind = 1;
TM__4R4QZluAmhY3f04fEZJ3nA_0[36].offset = offsetof(tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ, minConnection);
TM__4R4QZluAmhY3f04fEZJ3nA_0[36].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__4R4QZluAmhY3f04fEZJ3nA_0[36].name = "minConnection";
TM__4R4QZluAmhY3f04fEZJ3nA_9_7[6] = &TM__4R4QZluAmhY3f04fEZJ3nA_0[37];
TM__4R4QZluAmhY3f04fEZJ3nA_0[37].kind = 1;
TM__4R4QZluAmhY3f04fEZJ3nA_0[37].offset = offsetof(tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ, mutations);
TM__4R4QZluAmhY3f04fEZJ3nA_0[37].typ = (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_);
TM__4R4QZluAmhY3f04fEZJ3nA_0[37].name = "mutations";
TM__4R4QZluAmhY3f04fEZJ3nA_0[24].len = 7; TM__4R4QZluAmhY3f04fEZJ3nA_0[24].kind = 2; TM__4R4QZluAmhY3f04fEZJ3nA_0[24].sons = &TM__4R4QZluAmhY3f04fEZJ3nA_9_7[0];
NTImutationinfo__gL2XNL3vfSXoqvlltP0JhQ_.node = &TM__4R4QZluAmhY3f04fEZJ3nA_0[24];
NTIseqLmutationinfoT__zeatLyX5s1CrMAiU9c9bWBSQ_.size = sizeof(tySequence__zeatLyX5s1CrMAiU9c9bWBSQ*);
NTIseqLmutationinfoT__zeatLyX5s1CrMAiU9c9bWBSQ_.align = NIM_ALIGNOF(tySequence__zeatLyX5s1CrMAiU9c9bWBSQ*);
NTIseqLmutationinfoT__zeatLyX5s1CrMAiU9c9bWBSQ_.kind = 24;
NTIseqLmutationinfoT__zeatLyX5s1CrMAiU9c9bWBSQ_.base = (&NTImutationinfo__gL2XNL3vfSXoqvlltP0JhQ_);
NTIseqLmutationinfoT__zeatLyX5s1CrMAiU9c9bWBSQ_.flags = 2;
NTIseqLmutationinfoT__zeatLyX5s1CrMAiU9c9bWBSQ_.marker = Marker_tySequence__zeatLyX5s1CrMAiU9c9bWBSQ;
NTILpsym_intT__BHqtUW7ND5oD8ApFSF1wwQ_.size = sizeof(tyTuple__BHqtUW7ND5oD8ApFSF1wwQ);
NTILpsym_intT__BHqtUW7ND5oD8ApFSF1wwQ_.align = NIM_ALIGNOF(tyTuple__BHqtUW7ND5oD8ApFSF1wwQ);
NTILpsym_intT__BHqtUW7ND5oD8ApFSF1wwQ_.kind = 18;
NTILpsym_intT__BHqtUW7ND5oD8ApFSF1wwQ_.base = 0;
NTILpsym_intT__BHqtUW7ND5oD8ApFSF1wwQ_.flags = 2;
TM__4R4QZluAmhY3f04fEZJ3nA_21_2[0] = &TM__4R4QZluAmhY3f04fEZJ3nA_0[39];
TM__4R4QZluAmhY3f04fEZJ3nA_0[39].kind = 1;
TM__4R4QZluAmhY3f04fEZJ3nA_0[39].offset = offsetof(tyTuple__BHqtUW7ND5oD8ApFSF1wwQ, Field0);
TM__4R4QZluAmhY3f04fEZJ3nA_0[39].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__4R4QZluAmhY3f04fEZJ3nA_0[39].name = "Field0";
TM__4R4QZluAmhY3f04fEZJ3nA_21_2[1] = &TM__4R4QZluAmhY3f04fEZJ3nA_0[40];
TM__4R4QZluAmhY3f04fEZJ3nA_0[40].kind = 1;
TM__4R4QZluAmhY3f04fEZJ3nA_0[40].offset = offsetof(tyTuple__BHqtUW7ND5oD8ApFSF1wwQ, Field1);
TM__4R4QZluAmhY3f04fEZJ3nA_0[40].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__4R4QZluAmhY3f04fEZJ3nA_0[40].name = "Field1";
TM__4R4QZluAmhY3f04fEZJ3nA_0[38].len = 2; TM__4R4QZluAmhY3f04fEZJ3nA_0[38].kind = 2; TM__4R4QZluAmhY3f04fEZJ3nA_0[38].sons = &TM__4R4QZluAmhY3f04fEZJ3nA_21_2[0];
NTILpsym_intT__BHqtUW7ND5oD8ApFSF1wwQ_.node = &TM__4R4QZluAmhY3f04fEZJ3nA_0[38];
NTIseqLLpsym_intTT__ugNUvYxERl9aaj9b1GeCSDAg_.size = sizeof(tySequence__ugNUvYxERl9aaj9b1GeCSDAg*);
NTIseqLLpsym_intTT__ugNUvYxERl9aaj9b1GeCSDAg_.align = NIM_ALIGNOF(tySequence__ugNUvYxERl9aaj9b1GeCSDAg*);
NTIseqLLpsym_intTT__ugNUvYxERl9aaj9b1GeCSDAg_.kind = 24;
NTIseqLLpsym_intTT__ugNUvYxERl9aaj9b1GeCSDAg_.base = (&NTILpsym_intT__BHqtUW7ND5oD8ApFSF1wwQ_);
NTIseqLLpsym_intTT__ugNUvYxERl9aaj9b1GeCSDAg_.flags = 2;
NTIseqLLpsym_intTT__ugNUvYxERl9aaj9b1GeCSDAg_.marker = Marker_tySequence__ugNUvYxERl9aaj9b1GeCSDAg;
}

