/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 32

#include "nimbase.h"
#include <string.h>
#include <stdio.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg;
typedef struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg;
typedef struct tySequence__4Murtwnm0Fyc7F9acrytEXw tySequence__4Murtwnm0Fyc7F9acrytEXw;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg tySequence__QnmOtn1Iv4LvxOXoMn8Rbg;
typedef struct tySequence__oKtVqsc9bQVCNyrijELM4OQ tySequence__oKtVqsc9bQVCNyrijELM4OQ;
typedef struct tySequence__qy6Iwdy00wN560qud54HTg tySequence__qy6Iwdy00wN560qud54HTg;
typedef struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ tySequence__k67v9bwvvQDmS1ynyGGUbeQ;
typedef struct tySequence__cLsClAAfd0MKkoBQVyvdvw tySequence__cLsClAAfd0MKkoBQVyvdvw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg tySequence__q9bTuOB0JXh1iZ3CSGdRLbg;
typedef struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw;
typedef struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ;
typedef struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA;
typedef struct tySequence__ed0C0uAUZPhvw3RAc5hfYg tySequence__ed0C0uAUZPhvw3RAc5hfYg;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ;
typedef struct tySequence__C3r8jsj9chA4sIlYfDN5aDw tySequence__C3r8jsj9chA4sIlYfDN5aDw;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__PsEhl3dzznmmJiLAuIXZOg tyTuple__PsEhl3dzznmmJiLAuIXZOg;
typedef struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ;
typedef struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w;
typedef struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA;
typedef struct tyTuple__Db8CrQifKGIsKc3w71w7Lw tyTuple__Db8CrQifKGIsKc3w71w7Lw;
typedef struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg;
typedef struct tySequence__lo3S1lKyiPLhGGB9cBawd6A tySequence__lo3S1lKyiPLhGGB9cBawd6A;
typedef struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ;
typedef struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw tyTuple__FEYH9alRJhHD0uTKF2vnIqw;
typedef struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA;
typedef struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA;
typedef struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw;
typedef struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg tyTuple__VUJ5Hjm4tKAResBsRHJvYg;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ;
typedef struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ;
typedef struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct RootObj RootObj;
typedef struct tySequence__xv3aaFd3JCw8NbmALHiezQ tySequence__xv3aaFd3JCw8NbmALHiezQ;
typedef struct tyTuple__sPaDkVPSC0MkcoXCxPH9ccA tyTuple__sPaDkVPSC0MkcoXCxPH9ccA;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tyTuple__7q7q3E6Oj24ZNVJb9aonhAg;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ;
typedef struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct tyObject_RodIter__L6nv9cakjPARHk068AFo6ww tyObject_RodIter__L6nv9cakjPARHk068AFo6ww;
typedef struct tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
typedef NU8 tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg {
tySequence__4Murtwnm0Fyc7F9acrytEXw* nodes;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ;
struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ {
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw {
tySequence__IHUFRsFxZNv7YydiUO2esQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
};
struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag {
NimStringDesc* definedSymbols;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA moduleFlags;
tySequence__PXIzfWocnrafGz5p3CP5LA* includes;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* imports;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg toReplay;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg topLevel;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg bodies;
tySequence__b89aLriiJnVTD186H6zNIgg* exports;
tySequence__b89aLriiJnVTD186H6zNIgg* hidden;
tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw* reexports;
tySequence__b89aLriiJnVTD186H6zNIgg* compilerProcs;
tySequence__48JTohSgTy339bRxHzUD8KA* converters;
tySequence__48JTohSgTy339bRxHzUD8KA* methods;
tySequence__48JTohSgTy339bRxHzUD8KA* trmacros;
tySequence__48JTohSgTy339bRxHzUD8KA* pureEnums;
tySequence__QnmOtn1Iv4LvxOXoMn8Rbg* macroUsages;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* typeInstCache;
tySequence__qy6Iwdy00wN560qud54HTg* procInstCache;
tySequence__k67v9bwvvQDmS1ynyGGUbeQ* attachedOps;
tySequence__cLsClAAfd0MKkoBQVyvdvw* methodsPerType;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* enumToStringProcs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* emittedTypeInfo;
tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ backendFlags;
tySequence__q9bTuOB0JXh1iZ3CSGdRLbg* syms;
tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw* types;
tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ strings;
tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw numbers;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA cfg;
};
struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ {
tySequence__C3r8jsj9chA4sIlYfDN5aDw* data;
NI counter;
};
struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg {
tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg status;
NIM_BOOL symsInit;
NIM_BOOL typesInit;
NIM_BOOL loadedButAliveSetChanged;
tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag fromDisk;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* syms;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* types;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ iface;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ ifaceHidden;
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
NU32 Field0;
NimStringDesc* Field1;
};
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
NU32 Field0;
NI32 Field1;
};
struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ {
NU32 module;
NI32 item;
};
struct tyTuple__PsEhl3dzznmmJiLAuIXZOg {
NU32 Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA {
NU16 line;
NI16 col;
NU32 file;
};
struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA Field1;
};
struct tyTuple__Db8CrQifKGIsKc3w71w7Lw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ key;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* concreteTypes;
};
typedef NU8 tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ;
struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ {
tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
NI Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
typedef NU8 tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ;
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
typedef NU8 tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ;
struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA {
tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
NU32 name;
NI32 path;
};
struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA {
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
NU32 name;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typ;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
NI32 ast;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ guard;
NI bitsize;
NI alignment;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
NU32 externalName;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw locFlags;
tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA annex;
NI32 constraint;
};
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw {
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* types;
NI32 n;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeInst;
NI32 nonUniqueId;
};
struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg {
NI Field0;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* Field1;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* Field2;
};
struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ {
tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* data;
NI counter;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ {
NI32 thisModule;
NI32 lastFile;
NU32 lastLit;
tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ filenames;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* pendingTypes;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* pendingSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw typeMarker;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw symMarker;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
};
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
NI Field0;
NI32 Field1;
NU32 Field2;
};
typedef NU8 tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg;
typedef NU8 tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA;
struct tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ {
FILE* f;
tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA currentSection;
tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg err;
};
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
struct RootObj {
TNimType* m_type;
};
typedef NU8 tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA;
struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA {
  RootObj Sup;
NI counter;
tySequence__xv3aaFd3JCw8NbmALHiezQ* data;
tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA mode;
};
struct tyTuple__sPaDkVPSC0MkcoXCxPH9ccA {
NimStringDesc* Field0;
NimStringDesc* Field1;
NIM_BOOL Field2;
};
typedef NU8 tyArray__YtcvxHNKV4YiecPE9ap1mcA[20];
typedef NU8 tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
struct tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ {
NI lastModule;
NU32 lastLit;
NI32 lastFile;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
};
struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA {
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
NI32 operand;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeId_0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
};
struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInst;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg uniqueId;
};
struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg {
tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* path;
};
struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ {
  RootObj Sup;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* left;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* right;
NI L;
NimStringDesc* data;
};
struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg {
NI id;
NimStringDesc* s;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* next;
NI h;
};
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
NI Field0;
NI Field1;
};
typedef NU8 tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NimStringDesc* tyArray__sMpvt1sOxOJ3LFGulnbeMQ[4];
struct tyObject_RodIter__L6nv9cakjPARHk068AFo6ww {
tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ decoder;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* values;
NI i;
NI module;
};
struct tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* concreteTypes;
NI compilesId;
};
struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg {
NI32 module;
NI32 symId;
NI32 typeId_0;
NIM_BOOL sealed;
};
typedef NimStringDesc* tyArray__nHXaesL0DJZHyVS07ARPRA[1];
typedef NimStringDesc* tyArray__Re75IspeoxXy2oCZHwcRrA[2];
typedef NimStringDesc* tyArray__yt5VDPNtUGx9cBkOVakHwdQ[6];
typedef NimStringDesc* tyArray__ucDUDWdKfioXQrN9bCbG29bg[12];
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  TGenericSeq Sup;
  tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE];
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  TGenericSeq Sup;
  NU32 data[SEQ_DECL_SIZE];
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  TGenericSeq Sup;
  tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE];
};
struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw {
  TGenericSeq Sup;
  tyTuple__PsEhl3dzznmmJiLAuIXZOg data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg {
  TGenericSeq Sup;
  tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w data[SEQ_DECL_SIZE];
};
struct tySequence__oKtVqsc9bQVCNyrijELM4OQ {
  TGenericSeq Sup;
  tyTuple__Db8CrQifKGIsKc3w71w7Lw data[SEQ_DECL_SIZE];
};
struct tySequence__qy6Iwdy00wN560qud54HTg {
  TGenericSeq Sup;
  tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg data[SEQ_DECL_SIZE];
};
struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ {
  TGenericSeq Sup;
  tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ data[SEQ_DECL_SIZE];
};
struct tySequence__cLsClAAfd0MKkoBQVyvdvw {
  TGenericSeq Sup;
  tyTuple__FEYH9alRJhHD0uTKF2vnIqw data[SEQ_DECL_SIZE];
};
struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg {
  TGenericSeq Sup;
  tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA data[SEQ_DECL_SIZE];
};
struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw {
  TGenericSeq Sup;
  tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw data[SEQ_DECL_SIZE];
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  TGenericSeq Sup;
  NI64 data[SEQ_DECL_SIZE];
};
struct tySequence__lo3S1lKyiPLhGGB9cBawd6A {
  TGenericSeq Sup;
  tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ data[SEQ_DECL_SIZE];
};
struct tySequence__C3r8jsj9chA4sIlYfDN5aDw {
  TGenericSeq Sup;
  tyTuple__VUJ5Hjm4tKAResBsRHJvYg data[SEQ_DECL_SIZE];
};
struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ {
  TGenericSeq Sup;
  tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg data[SEQ_DECL_SIZE];
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  TGenericSeq Sup;
  tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
struct tySequence__ed0C0uAUZPhvw3RAc5hfYg {
  TGenericSeq Sup;
  tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* data[SEQ_DECL_SIZE];
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__4Murtwnm0Fyc7F9acrytEXw {
  TGenericSeq Sup;
  tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
struct tySequence__xv3aaFd3JCw8NbmALHiezQ {
  TGenericSeq Sup;
  tyTuple__sPaDkVPSC0MkcoXCxPH9ccA data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__PXIzfWocnrafGz5p3CP5LA)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__9bAGqSvkAaFL9bWjsEPslrFA)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__b89aLriiJnVTD186H6zNIgg)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__48JTohSgTy339bRxHzUD8KA)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__QnmOtn1Iv4LvxOXoMn8Rbg)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__oKtVqsc9bQVCNyrijELM4OQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__qy6Iwdy00wN560qud54HTg)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__k67v9bwvvQDmS1ynyGGUbeQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__cLsClAAfd0MKkoBQVyvdvw)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__q9bTuOB0JXh1iZ3CSGdRLbg)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__IHUFRsFxZNv7YydiUO2esQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__C3r8jsj9chA4sIlYfDN5aDw)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__9cnx3zXnWzeclW8Ko4oUgAQ)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, needsRecompile__icZic_8252)(tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, NI32 fileIdx, tySequence__48JTohSgTy339bRxHzUD8KA** cachedModules);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPath__msgs_548)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toRodFile__icZic_3146)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* f, NimStringDesc* ext);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, noschangeFileExt)(NimStringDesc* filename, NimStringDesc* ext);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, completeGeneratedFilePath__options_4242)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* f, NIM_BOOL createSubDir);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, mangleModuleName__modulepaths_32)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg, loadRodFile__icZic_3151)(NimStringDesc* filename, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, NIM_BOOL ignoreConfig);
N_LIB_PRIVATE N_NIMCALL(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ, open__icZrodfiles_295)(NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(void, loadHeader__icZrodfiles_138)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f);
N_LIB_PRIVATE N_NIMCALL(void, loadSection__icZrodfiles_256)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA expected);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZrodfiles_89)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NimStringDesc** s);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3158)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA* x);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_3184)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA* x);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, configIdentical__icZic_481)(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, definedSymbolsAsString__icZic_462)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config);
N_NIMCALL(NimStringDesc*, rawNewString)(NI cap);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(void, load__icZic_3222)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ* t);
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_3295)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__PXIzfWocnrafGz5p3CP5LA** s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, includesIdentical__icZic_2228)(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, hashFileCached__icZic_516)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getHash__msgs_574)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___stdZsha49_870)(tyArray__YtcvxHNKV4YiecPE9ap1mcA self);
N_LIB_PRIVATE N_NIMCALL(void, secureHashFile__stdZsha49_862)(NimStringDesc* filename, tyArray__YtcvxHNKV4YiecPE9ap1mcA Result);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void, setHash__msgs_567)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx, NimStringDesc* hash);
N_LIB_PRIVATE N_NIMCALL(NI32, toFileIndex__icZic_2162)(NU32 x, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config);
N_LIB_PRIVATE N_NIMCALL(NI32, fileInfoIdx__msgs_376)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename);
static N_INLINE(NimStringDesc**, X5BX5D___icZic_154)(tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ* t, NU32 litId);
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_3245)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__9bAGqSvkAaFL9bWjsEPslrFA** s);
N_LIB_PRIVATE N_NIMCALL(void, load__icZic_3353)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw* t);
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_3411)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__b89aLriiJnVTD186H6zNIgg** s);
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_3474)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw** s);
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_3537)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__48JTohSgTy339bRxHzUD8KA** s);
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_3599)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__QnmOtn1Iv4LvxOXoMn8Rbg** s);
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_3667)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__4Murtwnm0Fyc7F9acrytEXw** s);
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_3725)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__q9bTuOB0JXh1iZ3CSGdRLbg** s);
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_3784)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw** s);
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_4075)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__oKtVqsc9bQVCNyrijELM4OQ** s);
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_4134)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__qy6Iwdy00wN560qud54HTg** s);
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_4201)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__k67v9bwvvQDmS1ynyGGUbeQ** s);
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_4269)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__cLsClAAfd0MKkoBQVyvdvw** s);
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_3226)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__sM4lkSb7zS6F7OVMvW9cffQ** s);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_4345)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ* x);
N_LIB_PRIVATE N_NIMCALL(void, close__icZrodfiles_293)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f);
N_LIB_PRIVATE N_NIMCALL(void, setupLookupTables__icZic_6265)(tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, NI32 fileIdx, tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg* m);
N_LIB_PRIVATE N_NIMCALL(void, initTable__icZic_6271)(NI initialSize, tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ* Result);
N_LIB_PRIVATE N_NIMCALL(tySequence__lo3S1lKyiPLhGGB9cBawd6A**, mgetOrPut__icZic_6415)(tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ* t, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* key, tySequence__lo3S1lKyiPLhGGB9cBawd6A* val);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*, getIdent__idents_152)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* ic, NimStringDesc* identifier);
static N_INLINE(NimStringDesc**, X5BX5D___icZic_5604)(tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ* t, NU32 litId);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NOINLINE(void*, newObj)(TNimType* typ, NI size);
N_LIB_PRIVATE N_NIMCALL(void, splitFile__pathutils_27)(NimStringDesc* x, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5310)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5272)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5317)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5315)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5266)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw, newLineInfo__msgs_391)(NI32 fileInfoIdx, NI line, NI col);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getPackage__packages_7)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(void, genericShallowAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(void, loadError__icZic_3139)(tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg err, NimStringDesc* filename, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, loadToReplayNodes__icZic_8240)(tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, NI32 fileIdx, tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNode__ast_3289)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind);
static N_INLINE(NI, len__icZpacked95ast_302)(tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_4798)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, loadNodes__icZic_5535)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI thisModule, tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree, NI n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeIT__ast_3342)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw, translateLineInfo__icZic_5521)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI thisModule, tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA x);
N_LIB_PRIVATE N_NIMCALL(NI32, toFileIndexCached__icZic_5515)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* g, NI thisModule, NU32 f);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, loadType__icZic_5505)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI thisModule, tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___icZic_6144)(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ x, tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ y);
static N_INLINE(NI32, moduleIndex__icZic_5896)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI thisModule, tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, typeHeaderFromPacked__icZic_6184)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw* t, NI32 si, NI32 item);
N_LIB_PRIVATE N_NIMCALL(void, typeBodyFromPacked__icZic_6191)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw* t, NI32 si, NI32 item, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, loadSym__icZic_5510)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI thisModule, tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, symHeaderFromPacked__icZic_5902)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA* s, NI32 si, NI32 item);
N_LIB_PRIVATE N_NIMCALL(void, symBodyFromPacked__icZic_6061)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA* s, NI32 si, NI32 item, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, loadProcHeader__icZic_5854)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI thisModule, tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree, NI n);
static N_INLINE(void, addAllowNil__icZic_5833)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* son);
static N_INLINE(void, nextChild__icZpacked95ast_321)(tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree, NI* pos);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg*, loadLib__icZic_5984)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI32 si, NI32 item, tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA l);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, rope__ropes_109)(NimStringDesc* s);
static N_INLINE(NI64*, X5BX5D___icZic_5673)(tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw* t, NU32 litId);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
N_LIB_PRIVATE N_NIMCALL(tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ, sons2__icZpacked95ast_507)(tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree, NI n);
N_LIB_PRIVATE N_NIMCALL(void, transitionNoneToSym__ast_4386)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NI, span__icZpacked95ast_503)(tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree, NI pos);
static N_INLINE(NIM_BOOL, isAtom__icZpacked95ast_215)(tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree, NI pos);
N_LIB_PRIVATE N_NIMCALL(void, flush__icZic_2441)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ, storeType__icZic_2437)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m);
N_LIB_PRIVATE N_NIMCALL(NU32, toLitId__icZic_521)(NI32 x, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m);
N_LIB_PRIVATE N_NIMCALL(NU32, getOrDefault__icZic_592)(tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ t, NI32 key);
N_LIB_PRIVATE N_NIMCALL(NU32, getOrIncl__icZic_926)(tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ* t, NimStringDesc* v);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___icZic_1069)(tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ* t, NI32 key, NU32 val);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__astalgo_402)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
static N_INLINE(NI32, getNodeId__icZpacked95ast_588)(tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree);
N_LIB_PRIVATE N_NIMCALL(void, toPackedNode__icZic_2428)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg* ir, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA, toPackedInfo__icZic_2576)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw x, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ, storeTypeLater__icZic_2724)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m);
N_LIB_PRIVATE N_NIMCALL(void, addMissing__icZic_2662)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* p);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__astalgo_3489)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ, storeSymLater__icZic_2738)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m);
N_LIB_PRIVATE N_NIMCALL(void, addMissing__icZic_2597)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* p);
N_LIB_PRIVATE N_NIMCALL(void, addModuleRef__icZic_2917)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg* ir, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m);
N_LIB_PRIVATE N_NIMCALL(NU32, getOrIncl__icZic_2490)(tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw* t, NI64 v);
N_LIB_PRIVATE N_NIMCALL(NI, prepare__icZpacked95ast_252)(tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg* tree, tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags, tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeId_0, tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info);
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, patch__icZpacked95ast_287)(tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg* tree, NI pos);
static N_INLINE(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ, safeItemId__icZic_2581)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m);
N_LIB_PRIVATE N_NIMCALL(void, genericAssign)(void* dest, void* src, TNimType* mt);
static N_INLINE(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, pop__icZic_2447)(tySequence__vKogasEnJSPhbQmA8r4Y9aA** s);
N_LIB_PRIVATE N_NIMCALL(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ, storeSym__icZic_2433)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m);
N_LIB_PRIVATE N_NIMCALL(NU32, toLitId__icZic_2474)(NimStringDesc* x, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___ropes_250)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA, toPackedLib__icZic_2826)(tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* l, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m);
static N_INLINE(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, pop__icZic_2462)(tySequence__ed0C0uAUZPhvw3RAc5hfYg** s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ, create__icZrodfiles_290)(NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(void, storeHeader__icZrodfiles_109)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f);
N_LIB_PRIVATE N_NIMCALL(void, storeSection__icZrodfiles_207)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA s);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZrodfiles_64)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_4391)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA x);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_4408)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA x);
N_LIB_PRIVATE N_NIMCALL(void, store__icZic_4433)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ t);
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_4520)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__PXIzfWocnrafGz5p3CP5LA* s);
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_4470)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__9bAGqSvkAaFL9bWjsEPslrFA* s);
N_LIB_PRIVATE N_NIMCALL(void, store__icZic_4578)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw t);
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_4636)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__b89aLriiJnVTD186H6zNIgg* s);
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_4691)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw* s);
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_4746)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__48JTohSgTy339bRxHzUD8KA* s);
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_4809)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__QnmOtn1Iv4LvxOXoMn8Rbg* s);
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_4860)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__4Murtwnm0Fyc7F9acrytEXw* s);
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_4918)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__q9bTuOB0JXh1iZ3CSGdRLbg* s);
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_4968)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw* s);
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_5220)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__oKtVqsc9bQVCNyrijELM4OQ* s);
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_5271)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__qy6Iwdy00wN560qud54HTg* s);
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_5339)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__k67v9bwvvQDmS1ynyGGUbeQ* s);
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_5390)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__cLsClAAfd0MKkoBQVyvdvw* s);
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_4437)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySequence__sM4lkSb7zS6F7OVMvW9cffQ* s);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_5449)(tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ* f, tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ x);
N_LIB_PRIVATE N_NIMCALL(void, disable__icZic_458)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* e);
N_LIB_PRIVATE N_NIMCALL(void, storeError__icZic_4380)(tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg err, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(void, echoBinSafe)(NimStringDesc** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, nosremoveFile)(NimStringDesc* file);
N_LIB_PRIVATE N_NIMCALL(tySequence__lo3S1lKyiPLhGGB9cBawd6A*, getOrDefault__icZic_8581)(tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ t, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* key);
N_LIB_PRIVATE N_NIMCALL(void, newTreeFrom__icZpacked95ast_112)(tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg old, tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg* Result);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosisAbsolute)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(void, rememberConfig__icZic_466)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA pc);
N_LIB_PRIVATE N_NIMCALL(NI, len__icZic_8740)(tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ t);
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_31)(NI hcode);
N_LIB_PRIVATE N_NIMCALL(void, add__icZic_8922)(tySequence__lo3S1lKyiPLhGGB9cBawd6A** x, tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ* y, NI yLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newSymNode__ast_3707)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, loadProcBody__icZic_5883)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI thisModule, tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree, NI n);
N_LIB_PRIVATE N_NIMCALL(void, toPackedProcDef__icZic_3034)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg* ir, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m);
N_LIB_PRIVATE N_NIMCALL(tySequence__lo3S1lKyiPLhGGB9cBawd6A*, newSeq__icZic_3083)(NI len);
N_LIB_PRIVATE N_NIMCALL(void, genericSeqAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(void, toPackedGeneratedProcDef__icZic_3063)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* encoder, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m);
N_LIB_PRIVATE N_NIMCALL(void, toPackedNodeIgnoreProcDefs__icZic_3054)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* encoder, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m);
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefined__options_2292)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* symbol);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__systemZassertions_56)(NimStringDesc* msg);
N_LIB_PRIVATE N_NIMCALL(void, quit__system_7174)(NimStringDesc* errormsg, NI errorcode) __attribute__((noreturn));
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___systemZdollars_3)(NI x);
N_LIB_PRIVATE N_NIMCALL(NI, len__icZic_9616)(tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ t);
N_LIB_PRIVATE N_NIMCALL(NI, len__icZic_9669)(tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw t);
N_LIB_PRIVATE TNimType NTIloadedmodule__fihS6xbKhtLC0fhM28Cpeg_;
N_LIB_PRIVATE TNimType NTImodulestatus__K6X1Kd9cJ9a0hyG1Twv69bMNg_;
extern TNimType NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_;
N_LIB_PRIVATE TNimType NTIpackedmodule__Lx6uQ9baEALysaHmfFGXw9ag_;
extern TNimType NTIstring__77mFvmsOLKik79ci2hXkHEg_;
extern TNimType NTItsymflags__CvS9awV8iSOts9a8vqMf0pbQ_;
N_LIB_PRIVATE TNimType NTILlitid_stringT__0q9cmhneJEKnQERTpXXdz6Q_;
extern TNimType NTIuint5150__JrFyJbYm9b5I4hJ9cWDqvfYA_;
N_LIB_PRIVATE TNimType NTIseqLLlitid_stringTT__PXIzfWocnrafGz5p3CP5LA_;
N_LIB_PRIVATE TNimType NTIseqLlitidT__9bAGqSvkAaFL9bWjsEPslrFA_;
extern TNimType NTIpackedtree__om9aqqVmbmBPgd8MeBkGtqg_;
N_LIB_PRIVATE TNimType NTILlitid_int5150T__Izx9aRSX9a0diDXD84jOS9aMQ_;
extern TNimType NTIint5150__sVg18TP9cLifHyygRe9cro9aA_;
N_LIB_PRIVATE TNimType NTIseqLLlitid_int5150TT__b89aLriiJnVTD186H6zNIgg_;
N_LIB_PRIVATE TNimType NTILlitid_packeditemidT__PsEhl3dzznmmJiLAuIXZOg_;
extern TNimType NTIpackeditemid__QkYBSICiQaMI6SmH4FJVoQ_;
N_LIB_PRIVATE TNimType NTIseqLLlitid_packeditemidTT__wE9cZkGC9cv7Iz9ckZOIyaW9aw_;
N_LIB_PRIVATE TNimType NTIseqLint5150T__48JTohSgTy339bRxHzUD8KA_;
N_LIB_PRIVATE TNimType NTILpackeditemid_packedlineinfoT__Dg3ILQdzHFjrYRx6Xwbq3w_;
extern TNimType NTIpackedlineinfo__wqhF27DCtLcrB2XHUZKKiA_;
N_LIB_PRIVATE TNimType NTIseqLLpackeditemid_packedlineinfoTT__QnmOtn1Iv4LvxOXoMn8Rbg_;
N_LIB_PRIVATE TNimType NTILpackeditemid_packeditemidT__Db8CrQifKGIsKc3w71w7Lw_;
N_LIB_PRIVATE TNimType NTIseqLLpackeditemid_packeditemidTT__oKtVqsc9bQVCNyrijELM4OQ_;
extern TNimType NTIpackedinstantiation__wt9ao6lqcInu9aOmUoxgkWcg_;
N_LIB_PRIVATE TNimType NTIseqLpackedinstantiationT__qy6Iwdy00wN560qud54HTg_;
N_LIB_PRIVATE TNimType NTILttypeattachedop_packeditemid_packeditemidT__Q9cwWJO3ddVfos2xI7N9cHHQ_;
extern TNimType NTIttypeattachedop__0IDqFfYT9a3F5i6tmCmdORQ_;
N_LIB_PRIVATE TNimType NTIseqLLttypeattachedop_packeditemid_packeditemidTT__k67v9bwvvQDmS1ynyGGUbeQ_;
N_LIB_PRIVATE TNimType NTILpackeditemid_int_packeditemidT__FEYH9alRJhHD0uTKF2vnIqw_;
extern TNimType NTIint__rR5Bzr1D5krxoo1NcNyeMA_;
N_LIB_PRIVATE TNimType NTIseqLLpackeditemid_int_packeditemidTT__cLsClAAfd0MKkoBQVyvdvw_;
extern TNimType NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_;
N_LIB_PRIVATE TNimType NTImodulebackendflag__1OX8mHZmOJcGSH2EQV6eCQ_;
N_LIB_PRIVATE TNimType NTIsetLmodulebackendflagT__p8Pc9cQY1mbvJo9ccEZy9bYog_;
extern TNimType NTIpackedsym__fAjcBcJ2JPtzDDxyIN8WmA_;
N_LIB_PRIVATE TNimType NTIseqLpackedsymT__q9bTuOB0JXh1iZ3CSGdRLbg_;
extern TNimType NTIpackedtype__MvipqCfEd9b9bJbbBPwsUOiw_;
N_LIB_PRIVATE TNimType NTIseqLpackedtypeT__DPZr9aMyRppVlNZ9ajSyOZ9bw_;
N_LIB_PRIVATE TNimType NTIbitable__f1TRECC4Lgx6Suak6pB8oQ_;
N_LIB_PRIVATE TNimType NTIbitable__YFXXoy9ajAIwHK4kQgVvjcw_;
extern TNimType NTIbiggestint__Aav8dQoMlCFnZRxA0IhTHQ_;
N_LIB_PRIVATE TNimType NTIseqLbiggestintT__IHUFRsFxZNv7YydiUO2esQ_;
N_LIB_PRIVATE TNimType NTIpackedconfig__aqQhF9bElTH51s7bVamv3vA_;
extern TNimType NTItbackend__zoooocqvga73vZuhGAAy6A_;
extern TNimType NTItgcmode__yHeclYqeKaCEfMHNbcWn4w_;
extern TNimType NTItsystemcc__DqbWIQj9a2XvtXkztox3VFQ_;
extern TNimType NTItoptions__JyE8ULWMsetkCt18l86VRw_;
extern TNimType NTItglobaloptions__5mooI84kzWQJDnWciD7sQA_;
extern TNimType NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_;
extern TNimType NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_;
extern TNimType NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_;
N_LIB_PRIVATE TNimType NTItable__jSCM9c8LtAedYb1zTNR73sQ_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__VUJ5Hjm4tKAResBsRHJvYg_;
extern TNimType NTIpident__eFRAx6MW9aaEkYtj9aZffV0A_;
extern TNimType NTIseqLpackeditemidT__lo3S1lKyiPLhGGB9cBawd6A_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__C3r8jsj9chA4sIlYfDN5aDw_;
N_LIB_PRIVATE TNimType NTIpackedmodulegraph__JbK5aK9aVhc9cJZzQYg1wQlQ_;
N_LIB_PRIVATE TNimType NTIpackedencoder__ftUl9bxYRlbT5ToKkxHdbfQ_;
N_LIB_PRIVATE TNimType NTItable__7OytuYts9c9a3BX9aQNPGI0gQ_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__UvldbCB6B9ayi9bGYW7vJNLA_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__9cnx3zXnWzeclW8Ko4oUgAQ_;
extern TNimType NTIpackedset__THXDbzJSs2hcC9a33en2pdw_;
extern TNimType NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_;
STRING_LITERAL(TM__mJObP0PRzfMjXxDpaIgosg_25, "rod", 3);
STRING_LITERAL(TM__mJObP0PRzfMjXxDpaIgosg_26, "config", 6);
extern TNimType NTItsym__3r34mwqcVmg5JFNmiaVncw_;
extern NIM_CONST tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw unknownLineInfo__lineinfos_284;
STRING_LITERAL(TM__mJObP0PRzfMjXxDpaIgosg_28, "/home/runner/work/nightlies/nightlies/nim/compiler/ic/ic.nim", 60);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__mJObP0PRzfMjXxDpaIgosg_27 = {((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_28),
((NI) 544),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__mJObP0PRzfMjXxDpaIgosg_29 = {((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_28),
((NI) 546),
((NI) 14)}
;
STRING_LITERAL(TM__mJObP0PRzfMjXxDpaIgosg_30, " reason: ", 9);
extern TNimType NTIrodfileerror__1o7JP9bTXjyuYT9bCVtYI0pg_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__mJObP0PRzfMjXxDpaIgosg_31 = {((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_28),
((NI) 548),
((NI) 14)}
;
extern NIM_CONST tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ nilItemId__icZpacked95ast_14;
extern TNimType NTIptype__q1v0zzhoMWrhMLs6UEp1IA_;
extern TNimType NTIttype__kQDDJGUiaUAtO9c9b6LjZYjA_;
extern TNimType NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_;
extern TNimType NTIplib__cpB5Ba1r1YF5UAlBgbtl8g_;
static NIM_CONST tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA TM__mJObP0PRzfMjXxDpaIgosg_32 = {((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 164), 0, ((NI32) 1), {0, 0}, {0, 0, 0}}
;
extern TNimType NTIseqLpackednodeT__4Murtwnm0Fyc7F9acrytEXw_;
STRING_LITERAL(TM__mJObP0PRzfMjXxDpaIgosg_33, "Error: ", 7);
STRING_LITERAL(TM__mJObP0PRzfMjXxDpaIgosg_34, "; couldn\'t write to ", 20);
N_LIB_PRIVATE TNimType NTIpackeddecoder__KP7DLKztb9c2OnCFWxJiscQ_;
extern TNimType NTIidentcache__6ZZ9cf5acLVYxUxl0ehlA1g_;
extern TNimType NTIidgenerator__M4gwBCp6eTol0yFD6lAxTQ_;
STRING_LITERAL(TM__mJObP0PRzfMjXxDpaIgosg_36, "nimDebug", 8);
STRING_LITERAL(TM__mJObP0PRzfMjXxDpaIgosg_37, "options.nim(645, 14) `false` Error: could not load: ", 52);
STRING_LITERAL(TM__mJObP0PRzfMjXxDpaIgosg_38, "Error: could not load: ", 23);
STRING_LITERAL(TM__mJObP0PRzfMjXxDpaIgosg_40, "exports:", 8);
static NIM_CONST tyArray__nHXaesL0DJZHyVS07ARPRA TM__mJObP0PRzfMjXxDpaIgosg_39 = {((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_40)}
;
STRING_LITERAL(TM__mJObP0PRzfMjXxDpaIgosg_41, "  ", 2);
STRING_LITERAL(TM__mJObP0PRzfMjXxDpaIgosg_42, " local ID: ", 11);
STRING_LITERAL(TM__mJObP0PRzfMjXxDpaIgosg_44, "reexports:", 10);
static NIM_CONST tyArray__nHXaesL0DJZHyVS07ARPRA TM__mJObP0PRzfMjXxDpaIgosg_43 = {((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_44)}
;
STRING_LITERAL(TM__mJObP0PRzfMjXxDpaIgosg_45, "hidden: ", 8);
STRING_LITERAL(TM__mJObP0PRzfMjXxDpaIgosg_47, "all symbols", 11);
static NIM_CONST tyArray__nHXaesL0DJZHyVS07ARPRA TM__mJObP0PRzfMjXxDpaIgosg_46 = {((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_47)}
;
STRING_LITERAL(TM__mJObP0PRzfMjXxDpaIgosg_48, " kind ", 6);
extern TNimType NTItsymkind__sjiB9b9aO1FRPetW6gPYZbfw_;
STRING_LITERAL(TM__mJObP0PRzfMjXxDpaIgosg_49, "  <anon symbol\?> local ID: ", 27);
STRING_LITERAL(TM__mJObP0PRzfMjXxDpaIgosg_50, "symbols: ", 9);
STRING_LITERAL(TM__mJObP0PRzfMjXxDpaIgosg_51, " types: ", 8);
STRING_LITERAL(TM__mJObP0PRzfMjXxDpaIgosg_52, " top level nodes: ", 18);
STRING_LITERAL(TM__mJObP0PRzfMjXxDpaIgosg_53, " other nodes: ", 14);
STRING_LITERAL(TM__mJObP0PRzfMjXxDpaIgosg_54, " strings: ", 10);
STRING_LITERAL(TM__mJObP0PRzfMjXxDpaIgosg_55, " numbers: ", 10);
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5219;
static N_NIMCALL(void, Marker_tySequence__PXIzfWocnrafGz5p3CP5LA)(void* p, NI op) {
	tySequence__PXIzfWocnrafGz5p3CP5LA* a;
	NI T1_;
	a = (tySequence__PXIzfWocnrafGz5p3CP5LA*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field1, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__9bAGqSvkAaFL9bWjsEPslrFA)(void* p, NI op) {
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA* a;
	NI T1_;
	a = (tySequence__9bAGqSvkAaFL9bWjsEPslrFA*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__b89aLriiJnVTD186H6zNIgg)(void* p, NI op) {
	tySequence__b89aLriiJnVTD186H6zNIgg* a;
	NI T1_;
	a = (tySequence__b89aLriiJnVTD186H6zNIgg*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw)(void* p, NI op) {
	tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw* a;
	NI T1_;
	a = (tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__48JTohSgTy339bRxHzUD8KA)(void* p, NI op) {
	tySequence__48JTohSgTy339bRxHzUD8KA* a;
	NI T1_;
	a = (tySequence__48JTohSgTy339bRxHzUD8KA*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__QnmOtn1Iv4LvxOXoMn8Rbg)(void* p, NI op) {
	tySequence__QnmOtn1Iv4LvxOXoMn8Rbg* a;
	NI T1_;
	a = (tySequence__QnmOtn1Iv4LvxOXoMn8Rbg*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__oKtVqsc9bQVCNyrijELM4OQ)(void* p, NI op) {
	tySequence__oKtVqsc9bQVCNyrijELM4OQ* a;
	NI T1_;
	a = (tySequence__oKtVqsc9bQVCNyrijELM4OQ*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__qy6Iwdy00wN560qud54HTg)(void* p, NI op) {
	tySequence__qy6Iwdy00wN560qud54HTg* a;
	NI T1_;
	a = (tySequence__qy6Iwdy00wN560qud54HTg*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].concreteTypes, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__k67v9bwvvQDmS1ynyGGUbeQ)(void* p, NI op) {
	tySequence__k67v9bwvvQDmS1ynyGGUbeQ* a;
	NI T1_;
	a = (tySequence__k67v9bwvvQDmS1ynyGGUbeQ*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__cLsClAAfd0MKkoBQVyvdvw)(void* p, NI op) {
	tySequence__cLsClAAfd0MKkoBQVyvdvw* a;
	NI T1_;
	a = (tySequence__cLsClAAfd0MKkoBQVyvdvw*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__q9bTuOB0JXh1iZ3CSGdRLbg)(void* p, NI op) {
	tySequence__q9bTuOB0JXh1iZ3CSGdRLbg* a;
	NI T1_;
	a = (tySequence__q9bTuOB0JXh1iZ3CSGdRLbg*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw)(void* p, NI op) {
	tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw* a;
	NI T1_;
	a = (tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].types, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__IHUFRsFxZNv7YydiUO2esQ)(void* p, NI op) {
	tySequence__IHUFRsFxZNv7YydiUO2esQ* a;
	NI T1_;
	a = (tySequence__IHUFRsFxZNv7YydiUO2esQ*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__C3r8jsj9chA4sIlYfDN5aDw)(void* p, NI op) {
	tySequence__C3r8jsj9chA4sIlYfDN5aDw* a;
	NI T1_;
	a = (tySequence__C3r8jsj9chA4sIlYfDN5aDw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field1, op);
	nimGCvisit((void*)a->data[T1_].Field2, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ)(void* p, NI op) {
	tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* a;
	NI T1_;
	a = (tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].fromDisk.definedSymbols, op);
	nimGCvisit((void*)a->data[T1_].fromDisk.includes, op);
	nimGCvisit((void*)a->data[T1_].fromDisk.imports, op);
	nimGCvisit((void*)a->data[T1_].fromDisk.toReplay.nodes, op);
	nimGCvisit((void*)a->data[T1_].fromDisk.topLevel.nodes, op);
	nimGCvisit((void*)a->data[T1_].fromDisk.bodies.nodes, op);
	nimGCvisit((void*)a->data[T1_].fromDisk.exports, op);
	nimGCvisit((void*)a->data[T1_].fromDisk.hidden, op);
	nimGCvisit((void*)a->data[T1_].fromDisk.reexports, op);
	nimGCvisit((void*)a->data[T1_].fromDisk.compilerProcs, op);
	nimGCvisit((void*)a->data[T1_].fromDisk.converters, op);
	nimGCvisit((void*)a->data[T1_].fromDisk.methods, op);
	nimGCvisit((void*)a->data[T1_].fromDisk.trmacros, op);
	nimGCvisit((void*)a->data[T1_].fromDisk.pureEnums, op);
	nimGCvisit((void*)a->data[T1_].fromDisk.macroUsages, op);
	nimGCvisit((void*)a->data[T1_].fromDisk.typeInstCache, op);
	nimGCvisit((void*)a->data[T1_].fromDisk.procInstCache, op);
	nimGCvisit((void*)a->data[T1_].fromDisk.attachedOps, op);
	nimGCvisit((void*)a->data[T1_].fromDisk.methodsPerType, op);
	nimGCvisit((void*)a->data[T1_].fromDisk.enumToStringProcs, op);
	nimGCvisit((void*)a->data[T1_].fromDisk.emittedTypeInfo, op);
	nimGCvisit((void*)a->data[T1_].fromDisk.syms, op);
	nimGCvisit((void*)a->data[T1_].fromDisk.types, op);
	nimGCvisit((void*)a->data[T1_].fromDisk.strings.vals, op);
	nimGCvisit((void*)a->data[T1_].fromDisk.strings.keys, op);
	nimGCvisit((void*)a->data[T1_].fromDisk.numbers.vals, op);
	nimGCvisit((void*)a->data[T1_].fromDisk.numbers.keys, op);
	nimGCvisit((void*)a->data[T1_].syms, op);
	nimGCvisit((void*)a->data[T1_].types, op);
	nimGCvisit((void*)a->data[T1_].module, op);
	nimGCvisit((void*)a->data[T1_].iface.data, op);
	nimGCvisit((void*)a->data[T1_].ifaceHidden.data, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__9cnx3zXnWzeclW8Ko4oUgAQ)(void* p, NI op) {
	tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* a;
	NI T1_;
	a = (tySequence__9cnx3zXnWzeclW8Ko4oUgAQ*)p;
	T1_ = (NI)0;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toRodFile__icZic_3146)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* f, NimStringDesc* ext) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = mangleModuleName__modulepaths_32(conf, f);
	T2_ = NIM_NIL;
	T2_ = completeGeneratedFilePath__options_4242(conf, T1_, NIM_TRUE);
	result = noschangeFileExt(T2_, ext);
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, definedSymbolsAsString__icZic_462)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = rawNewString(((NI) 200));
	result = resizeString(result, 6);
appendString(result, ((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_26));
	{
		NimStringDesc* d;
		d = NIM_NIL;
		{
			NimStringDesc* key;
			NimStringDesc* val;
			key = NIM_NIL;
			val = NIM_NIL;
			{
				NI h;
				NI colontmp_;
				NI T4_;
				NI res;
				h = (NI)0;
				colontmp_ = (NI)0;
				T4_ = (((*(*config).symbols).data ? (*(*config).symbols).data->Sup.len : 0)-1);
				colontmp_ = T4_;
				res = ((NI) 0);
				{
					while (1) {
						if (!(res <= colontmp_)) goto LA6;
						h = res;
						{
							if (!(*(*config).symbols).data->data[h].Field2) goto LA9_;
							key = (*(*config).symbols).data->data[h].Field0;
							val = (*(*config).symbols).data->data[h].Field1;
							d = key;
							result = addChar(result, 32);
							result = resizeString(result, (d ? d->Sup.len : 0) + 0);
appendString(result, d);
						}
						LA9_: ;
						res += ((NI) 1);
					} LA6: ;
				}
			}
		}
	}
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, configIdentical__icZic_481)(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config) {
	NIM_BOOL result;
	NimStringDesc* T1_;
	NIM_BOOL T2_;
	NIM_BOOL T4_;
	NIM_BOOL T6_;
	NIM_BOOL T8_;
	NIM_BOOL T10_;
	result = (NIM_BOOL)0;
	T1_ = NIM_NIL;
	T1_ = definedSymbolsAsString__icZic_462(config);
	result = eqStrings((*m).definedSymbols, T1_);
	T2_ = (NIM_BOOL)0;
	T2_ = result;
	if (!(T2_)) goto LA3_;
	T2_ = ((*m).cfg.backend == (*config).backend);
	LA3_: ;
	result = T2_;
	T4_ = (NIM_BOOL)0;
	T4_ = result;
	if (!(T4_)) goto LA5_;
	T4_ = ((*m).cfg.selectedGC == (*config).selectedGC);
	LA5_: ;
	result = T4_;
	T6_ = (NIM_BOOL)0;
	T6_ = result;
	if (!(T6_)) goto LA7_;
	T6_ = ((*m).cfg.cCompiler == (*config).cCompiler);
	LA7_: ;
	result = T6_;
	T8_ = (NIM_BOOL)0;
	T8_ = result;
	if (!(T8_)) goto LA9_;
	T8_ = ((*m).cfg.options == (*config).options);
	LA9_: ;
	result = T8_;
	T10_ = (NIM_BOOL)0;
	T10_ = result;
	if (!(T10_)) goto LA11_;
	T10_ = ((*m).cfg.globalOptions == (*config).globalOptions);
	LA11_: ;
	result = T10_;
	return result;
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, hashFileCached__icZic_516)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = getHash__msgs_574(conf, fileIdx);
	{
		NimStringDesc* fullpath;
		tyArray__YtcvxHNKV4YiecPE9ap1mcA T5_;
		if (!((result ? result->Sup.len : 0) == ((NI) 0))) goto LA3_;
		fullpath = toFullPath__msgs_548(conf, fileIdx);
		nimZeroMem((void*)T5_, sizeof(tyArray__YtcvxHNKV4YiecPE9ap1mcA));
		secureHashFile__stdZsha49_862(fullpath, T5_);
		result = dollar___stdZsha49_870(T5_);
		setHash__msgs_567(conf, fileIdx, result);
	}
	LA3_: ;
	return result;
}
static N_INLINE(NimStringDesc**, X5BX5D___icZic_154)(tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ* t, NU32 litId) {
	NimStringDesc** result;
	NI idx;
	result = (NimStringDesc**)0;
	idx = (NI)(((NI) (litId)) - ((NI) 256));
	result = (&(*t).vals->data[idx]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI32, toFileIndex__icZic_2162)(NU32 x, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config) {
	NI32 result;
	NimStringDesc** T1_;
	result = (NI32)0;
	T1_ = (NimStringDesc**)0;
	T1_ = X5BX5D___icZic_154((&(*m).strings), x);
	result = fileInfoIdx__msgs_376(config, (*T1_));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, includesIdentical__icZic_2228)(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		tyTuple__0q9cmhneJEKnQERTpXXdz6Q* it;
		NI i;
		NI L;
		NI T2_;
		it = (tyTuple__0q9cmhneJEKnQERTpXXdz6Q*)0;
		i = ((NI) 0);
		T2_ = ((*m).includes ? (*m).includes->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				it = (&(*m).includes->data[i]);
				{
					NI32 T7_;
					NimStringDesc* T8_;
					T7_ = (NI32)0;
					T7_ = toFileIndex__icZic_2162((*it).Field0, (&(*m)), config);
					T8_ = NIM_NIL;
					T8_ = hashFileCached__icZic_516(config, T7_);
					if (!!(eqStrings(T8_, (*it).Field1))) goto LA9_;
					result = NIM_FALSE;
					goto BeforeRet_;
				}
				LA9_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
	result = NIM_TRUE;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg, loadRodFile__icZic_3151)(NimStringDesc* filename, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, NIM_BOOL ignoreConfig) {
	tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg result;
	tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ f;
	result = (tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg)0;
	f = open__icZrodfiles_295(filename);
	loadHeader__icZrodfiles_138((&f));
	loadSection__icZrodfiles_256((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 1));
	loadPrim__icZrodfiles_89((&f), (&(*m).definedSymbols));
	loadPrim__icZic_3158((&f), (&(*m).moduleFlags));
	loadPrim__icZic_3184((&f), (&(*m).cfg));
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NIM_BOOL T6_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = (f.err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0));
		if (!(T4_)) goto LA5_;
		T6_ = (NIM_BOOL)0;
		T6_ = configIdentical__icZic_481((&(*m)), config);
		T4_ = !(T6_);
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA7_;
		T3_ = !(ignoreConfig);
		LA7_: ;
		if (!T3_) goto LA8_;
		f.err = ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 6);
	}
	LA8_: ;
	loadSection__icZrodfiles_256((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 2));
	load__icZic_3222((&f), (&(*m).strings));
	loadSection__icZrodfiles_256((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 3));
	loadSeq__icZic_3295((&f), (&(*m).includes));
	{
		NIM_BOOL T12_;
		T12_ = (NIM_BOOL)0;
		T12_ = includesIdentical__icZic_2228(m, config);
		if (!!(T12_)) goto LA13_;
		f.err = ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 7);
	}
	LA13_: ;
	loadSection__icZrodfiles_256((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 4));
	loadSeq__icZic_3245((&f), (&(*m).imports));
	loadSection__icZrodfiles_256((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 5));
	load__icZic_3353((&f), (&(*m).numbers));
	loadSection__icZrodfiles_256((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 6));
	loadSeq__icZic_3411((&f), (&(*m).exports));
	loadSection__icZrodfiles_256((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 7));
	loadSeq__icZic_3411((&f), (&(*m).hidden));
	loadSection__icZrodfiles_256((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 8));
	loadSeq__icZic_3474((&f), (&(*m).reexports));
	loadSection__icZrodfiles_256((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 9));
	loadSeq__icZic_3411((&f), (&(*m).compilerProcs));
	loadSection__icZrodfiles_256((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 10));
	loadSeq__icZic_3537((&f), (&(*m).trmacros));
	loadSection__icZrodfiles_256((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 11));
	loadSeq__icZic_3537((&f), (&(*m).converters));
	loadSection__icZrodfiles_256((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 12));
	loadSeq__icZic_3537((&f), (&(*m).methods));
	loadSection__icZrodfiles_256((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 13));
	loadSeq__icZic_3537((&f), (&(*m).pureEnums));
	loadSection__icZrodfiles_256((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 14));
	loadSeq__icZic_3599((&f), (&(*m).macroUsages));
	loadSection__icZrodfiles_256((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 15));
	loadSeq__icZic_3667((&f), (&(*m).toReplay.nodes));
	loadSection__icZrodfiles_256((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 16));
	loadSeq__icZic_3667((&f), (&(*m).topLevel.nodes));
	loadSection__icZrodfiles_256((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 17));
	loadSeq__icZic_3667((&f), (&(*m).bodies.nodes));
	loadSection__icZrodfiles_256((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 18));
	loadSeq__icZic_3725((&f), (&(*m).syms));
	loadSection__icZrodfiles_256((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 19));
	loadSeq__icZic_3784((&f), (&(*m).types));
	loadSection__icZrodfiles_256((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 20));
	loadSeq__icZic_4075((&f), (&(*m).typeInstCache));
	loadSection__icZrodfiles_256((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 21));
	loadSeq__icZic_4134((&f), (&(*m).procInstCache));
	loadSection__icZrodfiles_256((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 22));
	loadSeq__icZic_4201((&f), (&(*m).attachedOps));
	loadSection__icZrodfiles_256((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 23));
	loadSeq__icZic_4269((&f), (&(*m).methodsPerType));
	loadSection__icZrodfiles_256((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 24));
	loadSeq__icZic_4075((&f), (&(*m).enumToStringProcs));
	loadSection__icZrodfiles_256((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 25));
	loadSeq__icZic_3226((&f), (&(*m).emittedTypeInfo));
	loadSection__icZrodfiles_256((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 26));
	loadPrim__icZic_4345((&f), (&(*m).backendFlags));
	close__icZrodfiles_293((&f));
	result = f.err;
	return result;
}
static N_INLINE(NimStringDesc**, X5BX5D___icZic_5604)(tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ* t, NU32 litId) {
	NimStringDesc** result;
	NI idx;
	result = (NimStringDesc**)0;
	idx = (NI)(((NI) (litId)) - ((NI) 256));
	result = (&(*t).vals->data[idx]);
	return result;
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5310)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5272)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5315)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5266((&gch__system_5219.zct), c);
}
static N_INLINE(void, decRef__system_5317)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5315(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5272(src);
		incRef__system_5310(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5272((*dest));
		decRef__system_5317(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(void, setupLookupTables__icZic_6265)(tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, NI32 fileIdx, tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg* m) {
	NimStringDesc* filename;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T38_;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T39_;
	initTable__icZic_6271(((NI) 32), (&(*m).iface));
	initTable__icZic_6271(((NI) 32), (&(*m).ifaceHidden));
	{
		tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ* e;
		NI i;
		NI L;
		NI T2_;
		e = (tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ*)0;
		i = ((NI) 0);
		T2_ = ((*m).fromDisk.exports ? (*m).fromDisk.exports->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				NU32 nameLitX60gensym246_;
				tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ e2X60gensym246_;
				NimStringDesc** T5_;
				tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T6_;
				tySequence__lo3S1lKyiPLhGGB9cBawd6A* T7_;
				tySequence__lo3S1lKyiPLhGGB9cBawd6A** T8_;
				NI T9_;
				NU32 nameLitX60gensym261_;
				tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ e2X60gensym261_;
				NimStringDesc** T10_;
				tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T11_;
				tySequence__lo3S1lKyiPLhGGB9cBawd6A* T12_;
				tySequence__lo3S1lKyiPLhGGB9cBawd6A** T13_;
				NI T14_;
				if (!(i < L)) goto LA4;
				e = (&(*m).fromDisk.exports->data[i]);
				nameLitX60gensym246_ = (*e).Field0;
				nimZeroMem((void*)(&e2X60gensym246_), sizeof(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ));
				e2X60gensym246_.module = ((NU32) 0);
				e2X60gensym246_.item = (*e).Field1;
				T5_ = (NimStringDesc**)0;
				T5_ = X5BX5D___icZic_5604((&(*m).fromDisk.strings), nameLitX60gensym246_);
				T6_ = NIM_NIL;
				T6_ = getIdent__idents_152(cache, (*T5_));
				T7_ = NIM_NIL;
				T7_ = NIM_NIL;
				T8_ = (tySequence__lo3S1lKyiPLhGGB9cBawd6A**)0;
				T8_ = mgetOrPut__icZic_6415((&(*m).iface), T6_, T7_);
				unsureAsgnRef((void**) (&(*T8_)), (tySequence__lo3S1lKyiPLhGGB9cBawd6A*) incrSeqV3((TGenericSeq*)((*T8_)), (&NTIseqLpackeditemidT__lo3S1lKyiPLhGGB9cBawd6A_)));
				T9_ = (*T8_)->Sup.len++;
				(*T8_)->data[T9_] = e2X60gensym246_;
				nameLitX60gensym261_ = (*e).Field0;
				nimZeroMem((void*)(&e2X60gensym261_), sizeof(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ));
				e2X60gensym261_.module = ((NU32) 0);
				e2X60gensym261_.item = (*e).Field1;
				T10_ = (NimStringDesc**)0;
				T10_ = X5BX5D___icZic_5604((&(*m).fromDisk.strings), nameLitX60gensym261_);
				T11_ = NIM_NIL;
				T11_ = getIdent__idents_152(cache, (*T10_));
				T12_ = NIM_NIL;
				T12_ = NIM_NIL;
				T13_ = (tySequence__lo3S1lKyiPLhGGB9cBawd6A**)0;
				T13_ = mgetOrPut__icZic_6415((&(*m).ifaceHidden), T11_, T12_);
				unsureAsgnRef((void**) (&(*T13_)), (tySequence__lo3S1lKyiPLhGGB9cBawd6A*) incrSeqV3((TGenericSeq*)((*T13_)), (&NTIseqLpackeditemidT__lo3S1lKyiPLhGGB9cBawd6A_)));
				T14_ = (*T13_)->Sup.len++;
				(*T13_)->data[T14_] = e2X60gensym261_;
				i += ((NI) 1);
			} LA4: ;
		}
	}
	{
		tyTuple__PsEhl3dzznmmJiLAuIXZOg* e_2;
		NI i_2;
		NI L_2;
		NI T16_;
		e_2 = (tyTuple__PsEhl3dzznmmJiLAuIXZOg*)0;
		i_2 = ((NI) 0);
		T16_ = ((*m).fromDisk.reexports ? (*m).fromDisk.reexports->Sup.len : 0);
		L_2 = T16_;
		{
			while (1) {
				NU32 nameLitX60gensym264_;
				tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ e2X60gensym264_;
				NimStringDesc** T19_;
				tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T20_;
				tySequence__lo3S1lKyiPLhGGB9cBawd6A* T21_;
				tySequence__lo3S1lKyiPLhGGB9cBawd6A** T22_;
				NI T23_;
				NU32 nameLitX60gensym265_;
				tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ e2X60gensym265_;
				NimStringDesc** T24_;
				tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T25_;
				tySequence__lo3S1lKyiPLhGGB9cBawd6A* T26_;
				tySequence__lo3S1lKyiPLhGGB9cBawd6A** T27_;
				NI T28_;
				if (!(i_2 < L_2)) goto LA18;
				e_2 = (&(*m).fromDisk.reexports->data[i_2]);
				nameLitX60gensym264_ = (*e_2).Field0;
				e2X60gensym264_ = (*e_2).Field1;
				T19_ = (NimStringDesc**)0;
				T19_ = X5BX5D___icZic_5604((&(*m).fromDisk.strings), nameLitX60gensym264_);
				T20_ = NIM_NIL;
				T20_ = getIdent__idents_152(cache, (*T19_));
				T21_ = NIM_NIL;
				T21_ = NIM_NIL;
				T22_ = (tySequence__lo3S1lKyiPLhGGB9cBawd6A**)0;
				T22_ = mgetOrPut__icZic_6415((&(*m).iface), T20_, T21_);
				unsureAsgnRef((void**) (&(*T22_)), (tySequence__lo3S1lKyiPLhGGB9cBawd6A*) incrSeqV3((TGenericSeq*)((*T22_)), (&NTIseqLpackeditemidT__lo3S1lKyiPLhGGB9cBawd6A_)));
				T23_ = (*T22_)->Sup.len++;
				(*T22_)->data[T23_] = e2X60gensym264_;
				nameLitX60gensym265_ = (*e_2).Field0;
				e2X60gensym265_ = (*e_2).Field1;
				T24_ = (NimStringDesc**)0;
				T24_ = X5BX5D___icZic_5604((&(*m).fromDisk.strings), nameLitX60gensym265_);
				T25_ = NIM_NIL;
				T25_ = getIdent__idents_152(cache, (*T24_));
				T26_ = NIM_NIL;
				T26_ = NIM_NIL;
				T27_ = (tySequence__lo3S1lKyiPLhGGB9cBawd6A**)0;
				T27_ = mgetOrPut__icZic_6415((&(*m).ifaceHidden), T25_, T26_);
				unsureAsgnRef((void**) (&(*T27_)), (tySequence__lo3S1lKyiPLhGGB9cBawd6A*) incrSeqV3((TGenericSeq*)((*T27_)), (&NTIseqLpackeditemidT__lo3S1lKyiPLhGGB9cBawd6A_)));
				T28_ = (*T27_)->Sup.len++;
				(*T27_)->data[T28_] = e2X60gensym265_;
				i_2 += ((NI) 1);
			} LA18: ;
		}
	}
	{
		tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ* e_3;
		NI i_3;
		NI L_3;
		NI T30_;
		e_3 = (tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ*)0;
		i_3 = ((NI) 0);
		T30_ = ((*m).fromDisk.hidden ? (*m).fromDisk.hidden->Sup.len : 0);
		L_3 = T30_;
		{
			while (1) {
				NU32 nameLitX60gensym266_;
				tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ e2X60gensym266_;
				NimStringDesc** T33_;
				tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T34_;
				tySequence__lo3S1lKyiPLhGGB9cBawd6A* T35_;
				tySequence__lo3S1lKyiPLhGGB9cBawd6A** T36_;
				NI T37_;
				if (!(i_3 < L_3)) goto LA32;
				e_3 = (&(*m).fromDisk.hidden->data[i_3]);
				nameLitX60gensym266_ = (*e_3).Field0;
				nimZeroMem((void*)(&e2X60gensym266_), sizeof(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ));
				e2X60gensym266_.module = ((NU32) 0);
				e2X60gensym266_.item = (*e_3).Field1;
				T33_ = (NimStringDesc**)0;
				T33_ = X5BX5D___icZic_5604((&(*m).fromDisk.strings), nameLitX60gensym266_);
				T34_ = NIM_NIL;
				T34_ = getIdent__idents_152(cache, (*T33_));
				T35_ = NIM_NIL;
				T35_ = NIM_NIL;
				T36_ = (tySequence__lo3S1lKyiPLhGGB9cBawd6A**)0;
				T36_ = mgetOrPut__icZic_6415((&(*m).ifaceHidden), T34_, T35_);
				unsureAsgnRef((void**) (&(*T36_)), (tySequence__lo3S1lKyiPLhGGB9cBawd6A*) incrSeqV3((TGenericSeq*)((*T36_)), (&NTIseqLpackeditemidT__lo3S1lKyiPLhGGB9cBawd6A_)));
				T37_ = (*T36_)->Sup.len++;
				(*T36_)->data[T37_] = e2X60gensym266_;
				i_3 += ((NI) 1);
			} LA32: ;
		}
	}
	filename = toFullPath__msgs_548(conf, fileIdx);
	T38_ = NIM_NIL;
	T38_ = (tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) newObj((&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_), sizeof(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw));
	(*T38_).Sup.Sup.m_type = (&NTItsym__3r34mwqcVmg5JFNmiaVncw_);
	(*T38_).kind = ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6);
	nimZeroMem((void*)(&(*T38_).Sup.itemId), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*T38_).Sup.itemId.module = fileIdx;
	(*T38_).Sup.itemId.item = ((NI32) 0);
	nimZeroMem((void*)(&T39_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	splitFile__pathutils_27(filename, (&T39_));
	asgnRef((void**) (&(*T38_).name), getIdent__idents_152(cache, T39_.Field1));
	(*T38_).info = newLineInfo__msgs_391(fileIdx, ((NI) 1), ((NI) 1));
	(*T38_).position = ((NI) (fileIdx));
	unsureAsgnRef((void**) (&(*m).module), T38_);
	asgnRef((void**) (&(*(*m).module).owner), getPackage__packages_7(conf, cache, fileIdx));
	(*(*m).module).flags = (*m).fromDisk.moduleFlags;
}
N_LIB_PRIVATE N_NIMCALL(void, loadError__icZic_3139)(tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg err, NimStringDesc* filename, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config) {
	switch (err) {
	case ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 2):
	{
		liMessage__msgs_1128(config, unknownLineInfo__lineinfos_284, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 17), filename, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), TM__mJObP0PRzfMjXxDpaIgosg_27, NIM_FALSE);
	}
	break;
	case ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 7):
	{
		liMessage__msgs_1128(config, unknownLineInfo__lineinfos_284, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 62), filename, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), TM__mJObP0PRzfMjXxDpaIgosg_29, NIM_FALSE);
	}
	break;
	default:
	{
		NimStringDesc* T4_;
		T4_ = NIM_NIL;
		T4_ = rawNewString((filename ? filename->Sup.len : 0) + (reprEnum((NI)err, (&NTIrodfileerror__1o7JP9bTXjyuYT9bCVtYI0pg_)) ? reprEnum((NI)err, (&NTIrodfileerror__1o7JP9bTXjyuYT9bCVtYI0pg_))->Sup.len : 0) + 9);
appendString(T4_, filename);
appendString(T4_, ((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_30));
appendString(T4_, reprEnum((NI)err, (&NTIrodfileerror__1o7JP9bTXjyuYT9bCVtYI0pg_)));
		liMessage__msgs_1128(config, unknownLineInfo__lineinfos_284, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 17), T4_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), TM__mJObP0PRzfMjXxDpaIgosg_31, NIM_FALSE);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, needsRecompile__icZic_8252)(tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, NI32 fileIdx, tySequence__48JTohSgTy339bRxHzUD8KA** cachedModules) {
	NIM_BOOL result;
	NI m;
	result = (NIM_BOOL)0;
	m = ((NI) (fileIdx));
	{
		NI T3_;
		T3_ = ((*g) ? (*g)->Sup.len : 0);
		if (!(T3_ <= m)) goto LA4_;
		unsureAsgnRef((void**) (&(*g)), (tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ*) setLengthSeqV2(((*g))?&((*g))->Sup:NIM_NIL, (&NTIpackedmodulegraph__JbK5aK9aVhc9cJZzQYg1wQlQ_), ((NI) ((NI)(m + ((NI) 1))))));
	}
	LA4_: ;
	switch ((*g)->data[m].status) {
	case ((tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg) 0):
	{
		NimStringDesc* fullpath;
		NimStringDesc* rod;
		tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg err;
		(*g)->data[m].status = ((tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg) 2);
		fullpath = toFullPath__msgs_548(conf, fileIdx);
		rod = toRodFile__icZic_3146(conf, fullpath, ((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_25));
		err = loadRodFile__icZic_3151(rod, (&(*g)->data[m].fromDisk), conf, NIM_FALSE);
		{
			if (!(err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0))) goto LA9_;
			result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 1))&63U)))!=0);
			{
				NU32* dep;
				tySequence__9bAGqSvkAaFL9bWjsEPslrFA* colontmp_;
				NI i;
				NI L;
				NI T12_;
				dep = (NU32*)0;
				colontmp_ = NIM_NIL;
				colontmp_ = (*g)->data[m].fromDisk.imports;
				i = ((NI) 0);
				T12_ = (colontmp_ ? colontmp_->Sup.len : 0);
				L = T12_;
				{
					while (1) {
						NI32 fid;
						if (!(i < L)) goto LA14;
						dep = (&colontmp_->data[i]);
						fid = toFileIndex__icZic_2162((*dep), (&(*g)->data[m].fromDisk), conf);
						{
							NIM_BOOL T17_;
							T17_ = (NIM_BOOL)0;
							T17_ = needsRecompile__icZic_8252(g, conf, cache, fid, cachedModules);
							if (!T17_) goto LA18_;
							result = NIM_TRUE;
						}
						LA18_: ;
						i += ((NI) 1);
					} LA14: ;
				}
			}
			{
				NI T24_;
				if (!!(result)) goto LA22_;
				setupLookupTables__icZic_6265(g, conf, cache, fileIdx, (&(*g)->data[m]));
				unsureAsgnRef((void**) (&(*cachedModules)), (tySequence__48JTohSgTy339bRxHzUD8KA*) incrSeqV3((TGenericSeq*)((*cachedModules)), (&NTIseqLint5150T__48JTohSgTy339bRxHzUD8KA_)));
				T24_ = (*cachedModules)->Sup.len++;
				(*cachedModules)->data[T24_] = fileIdx;
				(*g)->data[m].status = ((tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg) 3);
			}
			goto LA20_;
			LA22_: ;
			{
				tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg T26_;
				nimZeroMem((void*)(&T26_), sizeof(tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg));
				nimZeroMem((void*)(&T26_), sizeof(tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg));
				T26_.status = ((tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg) 4);
				T26_.module = (*g)->data[m].module;
				genericShallowAssign((void*)(&(*g)->data[m]), (void*)(&T26_), (&NTIloadedmodule__fihS6xbKhtLC0fhM28Cpeg_));
			}
			LA20_: ;
		}
		goto LA7_;
		LA9_: ;
		{
			loadError__icZic_3139(err, rod, conf);
			(*g)->data[m].status = ((tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg) 4);
			result = NIM_TRUE;
		}
		LA7_: ;
	}
	break;
	case ((tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg) 2):
	case ((tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg) 3):
	{
		result = NIM_FALSE;
	}
	break;
	case ((tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg) 4):
	case ((tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg) 1):
	case ((tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg) 5):
	{
		result = NIM_TRUE;
	}
	break;
	}
	return result;
}
static N_INLINE(NI, len__icZpacked95ast_302)(tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = (tree.nodes ? tree.nodes->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI32, toFileIndexCached__icZic_5515)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* g, NI thisModule, NU32 f) {
	NI32 result;
	result = (NI32)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*c).lastLit == f);
		if (!(T3_)) goto LA4_;
		T3_ = ((*c).lastModule == thisModule);
		LA4_: ;
		if (!T3_) goto LA5_;
		result = (*c).lastFile;
	}
	goto LA1_;
	LA5_: ;
	{
		result = toFileIndex__icZic_2162(f, (&g->data[thisModule].fromDisk), (*c).config);
		(*c).lastModule = thisModule;
		(*c).lastLit = f;
		(*c).lastFile = result;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw, translateLineInfo__icZic_5521)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI thisModule, tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA x) {
	tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw result;
	nimZeroMem((void*)(&result), sizeof(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw));
	nimZeroMem((void*)(&result), sizeof(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw));
	result.line = x.line;
	result.col = x.col;
	result.fileIndex = toFileIndexCached__icZic_5515(c, (*g), thisModule, x.file);
	return result;
}
static N_INLINE(NI32, moduleIndex__icZic_5896)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI thisModule, tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ s) {
	NI32 result;
	result = (NI32)0;
	{
		if (!(s.module == ((NU32) 0))) goto LA3_;
		result = ((NI32) (thisModule));
	}
	goto LA1_;
	LA3_: ;
	{
		result = toFileIndexCached__icZic_5515(c, (*g), thisModule, s.module);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, typeHeaderFromPacked__icZic_6184)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw* t, NI32 si, NI32 item) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) newObj((&NTIptype__q1v0zzhoMWrhMLs6UEp1IA_), sizeof(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA));
	(*T1_).Sup.Sup.m_type = (&NTIttype__kQDDJGUiaUAtO9c9b6LjZYjA_);
	nimZeroMem((void*)(&(*T1_).Sup.itemId), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*T1_).Sup.itemId.module = si;
	(*T1_).Sup.itemId.item = (*t).nonUniqueId;
	(*T1_).kind = (*t).kind;
	(*T1_).flags = (*t).flags;
	(*T1_).size = (*t).size;
	(*T1_).align = (*t).align;
	(*T1_).paddingAtEnd = (*t).paddingAtEnd;
	(*T1_).lockLevel = (*t).lockLevel;
	nimZeroMem((void*)(&(*T1_).uniqueId), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*T1_).uniqueId.module = si;
	(*T1_).uniqueId.item = item;
	(*T1_).callConv = (*t).callConv;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, symHeaderFromPacked__icZic_5902)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA* s, NI32 si, NI32 item) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T1_;
	NimStringDesc** T12_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) newObj((&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_), sizeof(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw));
	(*T1_).Sup.Sup.m_type = (&NTItsym__3r34mwqcVmg5JFNmiaVncw_);
	nimZeroMem((void*)(&(*T1_).Sup.itemId), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*T1_).Sup.itemId.module = si;
	(*T1_).Sup.itemId.item = item;
	(*T1_).kind = (*s).kind;
	(*T1_).magic = (*s).magic;
	(*T1_).flags = (*s).flags;
	(*T1_).info = translateLineInfo__icZic_5521(c, g, ((NI) (si)), (*s).info);
	(*T1_).options = (*s).options;
	{
		if (!((2097952 &((NU32)1<<((NU)((*s).kind)&31U)))!=0)) goto LA4_;
		(*T1_).position = ((NI) 0);
	}
	goto LA2_;
	LA4_: ;
	{
		(*T1_).position = (*s).position;
	}
	LA2_: ;
	{
		if (!((520192 &((NU32)1<<((NU)((*s).kind)&31U)))!=0)) goto LA9_;
		(*T1_).offset = ((NI) -1);
	}
	goto LA7_;
	LA9_: ;
	{
		(*T1_).offset = (*s).offset;
	}
	LA7_: ;
	T12_ = (NimStringDesc**)0;
	T12_ = X5BX5D___icZic_5604((&(*g)->data[si].fromDisk.strings), (*s).name);
	asgnRef((void**) (&(*T1_).name), getIdent__idents_152((*c).cache, (*T12_)));
	result = T1_;
	return result;
}
static N_INLINE(void, addAllowNil__icZic_5833)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* son) {
	NI T1_;
	asgnRef((void**) (&(*father)._kind_6.sons), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) incrSeqV3((TGenericSeq*)((*father)._kind_6.sons), (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_)));
	T1_ = (*father)._kind_6.sons->Sup.len++;
	asgnRef((void**) (&(*father)._kind_6.sons->data[T1_]), son);
}
static N_INLINE(void, nextChild__icZpacked95ast_321)(tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree, NI* pos) {
	{
		if (!(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23) < tree.nodes->data[(*pos)].kind)) goto LA3_;
		(*pos) += ((NI) (tree.nodes->data[(*pos)].operand));
	}
	goto LA1_;
	LA3_: ;
	{
		(*pos) += ((NI) 1);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, loadProcHeader__icZic_5854)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI thisModule, tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree, NI n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw k;
	tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw T1_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T2_;
	NI i;
	result = NIM_NIL;
	k = tree.nodes->data[n].kind;
	T1_ = translateLineInfo__icZic_5521(c, g, thisModule, tree.nodes->data[n].info);
	T2_ = NIM_NIL;
	T2_ = loadType__icZic_5505(c, g, thisModule, tree.nodes->data[n].typeId_0);
	result = newNodeIT__ast_3342(k, T1_, T2_);
	(*result).flags = tree.nodes->data[n].flags;
	i = ((NI) 0);
	{
		NI n0;
		NI pos;
		NI last;
		n0 = (NI)0;
		pos = n;
		last = (NI)(pos + ((NI) (tree.nodes->data[pos].operand)));
		pos += ((NI) 1);
		{
			while (1) {
				if (!(pos < last)) goto LA5;
				n0 = pos;
				{
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T10_;
					if (!!((i == ((NI) 6)))) goto LA8_;
					T10_ = NIM_NIL;
					T10_ = loadNodes__icZic_5535(c, g, thisModule, tree, n0);
					add__ast_4798(result, T10_);
				}
				goto LA6_;
				LA8_: ;
				{
					addAllowNil__icZic_5833(result, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
				}
				LA6_: ;
				i += ((NI) 1);
				nextChild__icZpacked95ast_321(tree, (&pos));
			} LA5: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg*, loadLib__icZic_5984)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI32 si, NI32 item, tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA l) {
	tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* result;
	result = NIM_NIL;
	{
		if (!(((NI) (l.name)) == ((NI) 0))) goto LA3_;
		result = ((tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg*) NIM_NIL);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* T6_;
		NimStringDesc** T7_;
		T6_ = NIM_NIL;
		T6_ = (tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg*) newObj((&NTIplib__cpB5Ba1r1YF5UAlBgbtl8g_), sizeof(tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg));
		(*T6_).generated = l.generated;
		(*T6_).isOverriden = l.isOverriden;
		(*T6_).kind = l.kind;
		T7_ = (NimStringDesc**)0;
		T7_ = X5BX5D___icZic_5604((&(*g)->data[si].fromDisk.strings), l.name);
		asgnRef((void**) (&(*T6_).name), rope__ropes_109((*T7_)));
		result = T6_;
		{
			if (!!((l.path == ((NI32) -1)))) goto LA10_;
			asgnRef((void**) (&(*result).path), loadNodes__icZic_5535(c, g, ((NI) (si)), (*g)->data[si].fromDisk.bodies, ((NI) (l.path))));
		}
		LA10_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, symBodyFromPacked__icZic_6061)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA* s, NI32 si, NI32 item, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result) {
	NimStringDesc* externalName;
	NimStringDesc** T22_;
	asgnRef((void**) (&(*result).typ), loadType__icZic_5505(c, g, ((NI) (si)), (*s).typ));
	{
		if (!!(((*s).constraint == ((NI32) -1)))) goto LA3_;
		asgnRef((void**) (&(*result).constraint), loadNodes__icZic_5535(c, g, ((NI) (si)), (*g)->data[si].fromDisk.bodies, ((NI) ((*s).constraint))));
	}
	LA3_: ;
	{
		if (!((126976 &((NU32)1<<((NU)((*result).kind)&31U)))!=0)) goto LA7_;
		{
			if (!!(((*s).ast == ((NI32) -1)))) goto LA11_;
			asgnRef((void**) (&(*result).ast), loadProcHeader__icZic_5854(c, g, ((NI) (si)), (*g)->data[si].fromDisk.bodies, ((NI) ((*s).ast))));
		}
		LA11_: ;
	}
	goto LA5_;
	LA7_: ;
	{
		{
			if (!!(((*s).ast == ((NI32) -1)))) goto LA16_;
			asgnRef((void**) (&(*result).ast), loadNodes__icZic_5535(c, g, ((NI) (si)), (*g)->data[si].fromDisk.bodies, ((NI) ((*s).ast))));
		}
		LA16_: ;
	}
	LA5_: ;
	asgnRef((void**) (&(*result).annex), loadLib__icZic_5984(c, g, si, item, (*s).annex));
	{
		if (!((2622208 &((NU32)1<<((NU)((*s).kind)&31U)))!=0)) goto LA20_;
		asgnRef((void**) (&(*result)._kind_2.guard), loadSym__icZic_5510(c, g, ((NI) (si)), (*s).guard));
		(*result)._kind_2.bitsize = (*s).bitsize;
		(*result)._kind_2.alignment = (*s).alignment;
	}
	LA20_: ;
	asgnRef((void**) (&(*result).owner), loadSym__icZic_5510(c, g, ((NI) (si)), (*s).owner));
	T22_ = (NimStringDesc**)0;
	T22_ = X5BX5D___icZic_5604((&(*g)->data[si].fromDisk.strings), (*s).externalName);
	externalName = (*T22_);
	{
		if (!!(((externalName ? externalName->Sup.len : 0) == 0))) goto LA25_;
		asgnRef((void**) (&(*result).loc.r), rope__ropes_109(externalName));
	}
	LA25_: ;
	(*result).loc.flags = (*s).locFlags;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, loadSym__icZic_5510)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI thisModule, tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ s) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = eqeq___icZic_6144(s, nilItemId__icZpacked95ast_14);
		if (!T3_) goto LA4_;
		result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
	}
	goto LA1_;
	LA4_: ;
	{
		NI32 si;
		si = moduleIndex__icZic_5896(c, g, thisModule, s);
		{
			NI T11_;
			if (!!((*g)->data[si].symsInit)) goto LA9_;
			(*g)->data[si].symsInit = NIM_TRUE;
			T11_ = ((*g)->data[si].fromDisk.syms ? (*g)->data[si].fromDisk.syms->Sup.len : 0);
			asgnRef((void**) (&(*g)->data[si].syms), (tySequence__ed0C0uAUZPhvw3RAc5hfYg*) setLengthSeqV2(((*g)->data[si].syms)?&((*g)->data[si].syms)->Sup:NIM_NIL, (&NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_), ((NI) (T11_))));
		}
		LA9_: ;
		{
			if (!((*g)->data[si].syms->data[s.item] == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA14_;
			{
				if (!!(((*g)->data[si].fromDisk.syms->data[s.item].kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6)))) goto LA18_;
				result = symHeaderFromPacked__icZic_5902(c, g, (&(*g)->data[si].fromDisk.syms->data[s.item]), si, s.item);
				asgnRef((void**) (&(*g)->data[si].syms->data[s.item]), result);
				symBodyFromPacked__icZic_6061(c, g, (&(*g)->data[si].fromDisk.syms->data[s.item]), si, s.item, result);
			}
			goto LA16_;
			LA18_: ;
			{
				result = (*g)->data[si].module;
			}
			LA16_: ;
		}
		goto LA12_;
		LA14_: ;
		{
			result = (*g)->data[si].syms->data[s.item];
		}
		LA12_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, typeBodyFromPacked__icZic_6191)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw* t, NI32 si, NI32 item, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result) {
	asgnRef((void**) (&(*result).sym), loadSym__icZic_5510(c, g, ((NI) (si)), (*t).sym));
	asgnRef((void**) (&(*result).owner), loadSym__icZic_5510(c, g, ((NI) (si)), (*t).owner));
	asgnRef((void**) (&(*result).typeInst), loadType__icZic_5505(c, g, ((NI) (si)), (*t).typeInst));
	{
		tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ* son;
		NI i;
		NI L;
		NI T2_;
		son = (tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ*)0;
		i = ((NI) 0);
		T2_ = ((*t).types ? (*t).types->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T5_;
				NI T6_;
				if (!(i < L)) goto LA4;
				son = (&(*t).types->data[i]);
				T5_ = NIM_NIL;
				T5_ = loadType__icZic_5505(c, g, ((NI) (si)), (*son));
				asgnRef((void**) (&(*result).sons), (tySequence__vKogasEnJSPhbQmA8r4Y9aA*) incrSeqV3((TGenericSeq*)((*result).sons), (&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_)));
				T6_ = (*result).sons->Sup.len++;
				asgnRef((void**) (&(*result).sons->data[T6_]), T5_);
				i += ((NI) 1);
			} LA4: ;
		}
	}
	{
		if (!!(((*t).n == ((NI32) -1)))) goto LA9_;
		asgnRef((void**) (&(*result).n), loadNodes__icZic_5535(c, g, ((NI) (si)), (*g)->data[si].fromDisk.bodies, ((NI) ((*t).n))));
	}
	LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, loadType__icZic_5505)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI thisModule, tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ t) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = eqeq___icZic_6144(t, nilItemId__icZpacked95ast_14);
		if (!T3_) goto LA4_;
		result = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL);
	}
	goto LA1_;
	LA4_: ;
	{
		NI32 si;
		si = moduleIndex__icZic_5896(c, g, thisModule, t);
		{
			NI T11_;
			if (!!((*g)->data[si].typesInit)) goto LA9_;
			(*g)->data[si].typesInit = NIM_TRUE;
			T11_ = ((*g)->data[si].fromDisk.types ? (*g)->data[si].fromDisk.types->Sup.len : 0);
			asgnRef((void**) (&(*g)->data[si].types), (tySequence__vKogasEnJSPhbQmA8r4Y9aA*) setLengthSeqV2(((*g)->data[si].types)?&((*g)->data[si].types)->Sup:NIM_NIL, (&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_), ((NI) (T11_))));
		}
		LA9_: ;
		{
			if (!((*g)->data[si].types->data[t.item] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA14_;
			result = typeHeaderFromPacked__icZic_6184(c, g, (&(*g)->data[si].fromDisk.types->data[t.item]), si, t.item);
			asgnRef((void**) (&(*g)->data[si].types->data[t.item]), result);
			typeBodyFromPacked__icZic_6191(c, g, (&(*g)->data[si].fromDisk.types->data[t.item]), si, t.item, result);
		}
		goto LA12_;
		LA14_: ;
		{
			result = (*g)->data[si].types->data[t.item];
		}
		LA12_: ;
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI64*, X5BX5D___icZic_5673)(tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw* t, NU32 litId) {
	NI64* result;
	NI idx;
	result = (NI64*)0;
	idx = (NI)(((NI) (litId)) - ((NI) 256));
	result = (&(*t).vals->data[idx]);
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5272(p);
	decRef__system_5317(T1_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, loadNodes__icZic_5535)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI thisModule, tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree, NI n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw k;
	tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw T5_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T6_;
{	result = NIM_NIL;
	k = tree.nodes->data[n].kind;
	{
		if (!(k == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 164))) goto LA3_;
		result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
		goto BeforeRet_;
	}
	LA3_: ;
	T5_ = translateLineInfo__icZic_5521(c, g, thisModule, tree.nodes->data[n].info);
	T6_ = NIM_NIL;
	T6_ = loadType__icZic_5505(c, g, thisModule, tree.nodes->data[n].typeId_0);
	result = newNodeIT__ast_3342(k, T5_, T6_);
	(*result).flags = tree.nodes->data[n].flags;
	switch (k) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 4):
	{
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	{
		NimStringDesc** T9_;
		T9_ = (NimStringDesc**)0;
		T9_ = X5BX5D___icZic_5604((&(*g)->data[thisModule].fromDisk.strings), ((NU32) (tree.nodes->data[n].operand)));
		asgnRef((void**) (&(*result)._kind_5.ident), getIdent__idents_152((*c).cache, (*T9_)));
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ T11_;
		nimZeroMem((void*)(&T11_), sizeof(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ));
		T11_.module = ((NU32) 0);
		T11_.item = tree.nodes->data[n].operand;
		asgnRef((void**) (&(*result)._kind_4.sym), loadSym__icZic_5510(c, g, thisModule, T11_));
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 9):
	{
		(*result)._kind_1.intVal = ((NI64) (tree.nodes->data[n].operand));
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 8):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 10) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 15):
	{
		NI64* T14_;
		T14_ = (NI64*)0;
		T14_ = X5BX5D___icZic_5673((&(*g)->data[thisModule].fromDisk.numbers), ((NU32) (tree.nodes->data[n].operand)));
		(*result)._kind_1.intVal = (*T14_);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22):
	{
		NimStringDesc** T16_;
		NimStringDesc* T17_;
		T16_ = (NimStringDesc**)0;
		T16_ = X5BX5D___icZic_5604((&(*g)->data[thisModule].fromDisk.strings), ((NU32) (tree.nodes->data[n].operand)));
		T17_ = NIM_NIL;
		T17_ = (*result)._kind_3.strVal; (*result)._kind_3.strVal = copyStringRC1((*T16_));
		if (T17_) nimGCunrefNoCycle(T17_);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 16) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 19):
	{
		union { NI64 source; NF dest; } LOC19;
		NI64* T20_;
		T20_ = (NI64*)0;
		T20_ = X5BX5D___icZic_5673((&(*g)->data[thisModule].fromDisk.numbers), ((NU32) (tree.nodes->data[n].operand)));
		LOC19.source = (*T20_);
		(*result)._kind_2.floatVal = LOC19.dest;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 162):
	{
		tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ T22_;
		NI n1;
		NI n2;
		tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ T23_;
		T22_ = sons2__icZpacked95ast_507(tree, n);
		n1 = T22_.Field0;
		n2 = T22_.Field1;
		transitionNoneToSym__ast_4386(result);
		nimZeroMem((void*)(&T23_), sizeof(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ));
		T23_.module = ((NU32) (tree.nodes->data[n1].operand));
		T23_.item = tree.nodes->data[n2].operand;
		asgnRef((void**) (&(*result)._kind_4.sym), loadSym__icZic_5510(c, g, thisModule, T23_));
	}
	break;
	default:
	{
		{
			NI n0;
			NI pos;
			NI last;
			n0 = (NI)0;
			pos = n;
			last = (NI)(pos + ((NI) (tree.nodes->data[pos].operand)));
			pos += ((NI) 1);
			{
				while (1) {
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T28_;
					if (!(pos < last)) goto LA27;
					n0 = pos;
					T28_ = NIM_NIL;
					T28_ = loadNodes__icZic_5535(c, g, thisModule, tree, n0);
					addAllowNil__icZic_5833(result, T28_);
					nextChild__icZpacked95ast_321(tree, (&pos));
				} LA27: ;
			}
		}
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isAtom__icZpacked95ast_215)(tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree, NI pos) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = (tree.nodes->data[pos].kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23));
	return result;
}
static N_INLINE(NI, span__icZpacked95ast_503)(tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree, NI pos) {
	NI result;
	result = (NI)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isAtom__icZpacked95ast_215(tree, pos);
		if (!T3_) goto LA4_;
		result = ((NI) 1);
	}
	goto LA1_;
	LA4_: ;
	{
		result = ((NI) (tree.nodes->data[pos].operand));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, loadToReplayNodes__icZic_8240)(tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, NI32 fileIdx, tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg* m) {
	asgnRef((void**) (&(*(*m).module).ast), newNode__ast_3289(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115)));
	{
		NI T3_;
		tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ decoder;
		T3_ = (NI)0;
		T3_ = len__icZpacked95ast_302((*m).fromDisk.toReplay);
		if (!(((NI) 0) < T3_)) goto LA4_;
		nimZeroMem((void*)(&decoder), sizeof(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ));
		nimZeroMem((void*)(&decoder), sizeof(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ));
		decoder.lastModule = ((NI) -1);
		decoder.lastLit = ((NU32) 0);
		decoder.lastFile = ((NI32) -1);
		decoder.config = conf;
		decoder.cache = cache;
		{
			NI p;
			NI p_2;
			p = (NI)0;
			p_2 = ((NI) 0);
			{
				while (1) {
					NI T9_;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T10_;
					NI s;
					T9_ = (NI)0;
					T9_ = len__icZpacked95ast_302((*m).fromDisk.toReplay);
					if (!(p_2 < T9_)) goto LA8;
					p = p_2;
					T10_ = NIM_NIL;
					T10_ = loadNodes__icZic_5535((&decoder), g, ((NI) (fileIdx)), (*m).fromDisk.toReplay, p);
					add__ast_4798((*(*m).module).ast, T10_);
					s = span__icZpacked95ast_503((*m).fromDisk.toReplay, p_2);
					p_2 += s;
				} LA8: ;
			}
		}
	}
	LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, moduleFromRodFile__icZic_8330)(tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, NI32 fileIdx, tySequence__48JTohSgTy339bRxHzUD8KA** cachedModules) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = needsRecompile__icZic_8252(g, conf, cache, fileIdx, cachedModules);
		if (!T3_) goto LA4_;
		result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
	}
	goto LA1_;
	LA4_: ;
	{
		result = (*g)->data[fileIdx].module;
	}
	LA1_: ;
	{
		NI32* m;
		NI i;
		NI L;
		NI T8_;
		m = (NI32*)0;
		i = ((NI) 0);
		T8_ = ((*cachedModules) ? (*cachedModules)->Sup.len : 0);
		L = T8_;
		{
			while (1) {
				if (!(i < L)) goto LA10;
				m = (&(*cachedModules)->data[i]);
				loadToReplayNodes__icZic_8240(g, conf, cache, (*m), (&(*g)->data[(*m)]));
				i += ((NI) 1);
			} LA10: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NU32, toLitId__icZic_521)(NI32 x, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m) {
	NU32 result;
	result = (NU32)0;
	{
		if (!(x == (*c).lastFile)) goto LA3_;
		result = (*c).lastLit;
	}
	goto LA1_;
	LA3_: ;
	{
		result = getOrDefault__icZic_592((*c).filenames, x);
		{
			NimStringDesc* p;
			if (!(result == ((NU32) 0))) goto LA8_;
			p = toFullPath__msgs_548((*c).config, x);
			result = getOrIncl__icZic_926((&(*m).strings), p);
			X5BX5Deq___icZic_1069((&(*c).filenames), x, result);
		}
		LA8_: ;
		(*c).lastFile = x;
		(*c).lastLit = result;
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI32, getNodeId__icZpacked95ast_588)(tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree) {
	NI32 result;
	NI T1_;
	result = (NI32)0;
	T1_ = (tree.nodes ? tree.nodes->Sup.len : 0);
	result = ((NI32) (T1_));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA, toPackedInfo__icZic_2576)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw x, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m) {
	tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA result;
	nimZeroMem((void*)(&result), sizeof(tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA));
	nimZeroMem((void*)(&result), sizeof(tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA));
	result.line = x.line;
	result.col = x.col;
	result.file = toLitId__icZic_521(x.fileIndex, c, m);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addMissing__icZic_2662)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* p) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !((p == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((*p).uniqueId.module == (*c).thisModule);
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			NIM_BOOL T9_;
			NI T12_;
			T9_ = (NIM_BOOL)0;
			T9_ = contains__astalgo_3489((&(*c).typeMarker), ((NI) ((*p).uniqueId.item)));
			if (!!(T9_)) goto LA10_;
			unsureAsgnRef((void**) (&(*c).pendingTypes), (tySequence__vKogasEnJSPhbQmA8r4Y9aA*) incrSeqV3((TGenericSeq*)((*c).pendingTypes), (&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_)));
			T12_ = (*c).pendingTypes->Sup.len++;
			asgnRef((void**) (&(*c).pendingTypes->data[T12_]), p);
		}
		LA10_: ;
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ, storeTypeLater__icZic_2724)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m) {
	tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ result;
{	nimZeroMem((void*)(&result), sizeof(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ));
	{
		if (!(t == 0)) goto LA3_;
		result = nilItemId__icZpacked95ast_14;
		goto BeforeRet_;
	}
	LA3_: ;
	nimZeroMem((void*)(&result), sizeof(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ));
	result.module = toLitId__icZic_521((*t).uniqueId.module, c, m);
	result.item = (*t).uniqueId.item;
	{
		if (!((*t).uniqueId.module == (*c).thisModule)) goto LA7_;
		addMissing__icZic_2662(c, t);
	}
	LA7_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addMissing__icZic_2597)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* p) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !((p == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((*p).Sup.itemId.module == (*c).thisModule);
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			NIM_BOOL T9_;
			T9_ = (NIM_BOOL)0;
			T9_ = contains__astalgo_3489((&(*c).symMarker), ((NI) ((*p).Sup.itemId.item)));
			if (!!(T9_)) goto LA10_;
			{
				NIM_BOOL T14_;
				NI T18_;
				T14_ = (NIM_BOOL)0;
				T14_ = (((*p).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 4))&63U)))!=0);
				if (!(T14_)) goto LA15_;
				T14_ = ((520192 &((NU32)1<<((NU)((*p).kind)&31U)))!=0);
				LA15_: ;
				if (!!(T14_)) goto LA16_;
				unsureAsgnRef((void**) (&(*c).pendingSyms), (tySequence__ed0C0uAUZPhvw3RAc5hfYg*) incrSeqV3((TGenericSeq*)((*c).pendingSyms), (&NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_)));
				T18_ = (*c).pendingSyms->Sup.len++;
				asgnRef((void**) (&(*c).pendingSyms->data[T18_]), p);
			}
			LA16_: ;
		}
		LA10_: ;
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ, storeSymLater__icZic_2738)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m) {
	tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ result;
{	nimZeroMem((void*)(&result), sizeof(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ));
	{
		if (!(s == 0)) goto LA3_;
		result = nilItemId__icZpacked95ast_14;
		goto BeforeRet_;
	}
	LA3_: ;
	nimZeroMem((void*)(&result), sizeof(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ));
	result.module = toLitId__icZic_521((*s).Sup.itemId.module, c, m);
	result.item = (*s).Sup.itemId.item;
	{
		if (!((*s).Sup.itemId.module == (*c).thisModule)) goto LA7_;
		addMissing__icZic_2597(c, s);
	}
	LA7_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addModuleRef__icZic_2917)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg* ir, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m) {
	tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
	tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA T1_;
	NI T2_;
	tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA T3_;
	NU32 T4_;
	NI T5_;
	tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA T6_;
	NI T7_;
	info = toPackedInfo__icZic_2576((*n).info, c, m);
	nimZeroMem((void*)(&T1_), sizeof(tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA));
	T1_.kind = ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 162);
	T1_.operand = ((NI32) 3);
	T1_.typeId_0 = storeTypeLater__icZic_2724((*n).typ, c, m);
	T1_.info = info;
	unsureAsgnRef((void**) (&(*ir).nodes), (tySequence__4Murtwnm0Fyc7F9acrytEXw*) incrSeqV3((TGenericSeq*)((*ir).nodes), (&NTIseqLpackednodeT__4Murtwnm0Fyc7F9acrytEXw_)));
	T2_ = (*ir).nodes->Sup.len++;
	(*ir).nodes->data[T2_] = T1_;
	nimZeroMem((void*)(&T3_), sizeof(tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA));
	T3_.kind = ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 9);
	T3_.info = info;
	T4_ = (NU32)0;
	T4_ = toLitId__icZic_521((*(*n)._kind_4.sym).Sup.itemId.module, c, m);
	T3_.operand = ((NI32) (T4_));
	unsureAsgnRef((void**) (&(*ir).nodes), (tySequence__4Murtwnm0Fyc7F9acrytEXw*) incrSeqV3((TGenericSeq*)((*ir).nodes), (&NTIseqLpackednodeT__4Murtwnm0Fyc7F9acrytEXw_)));
	T5_ = (*ir).nodes->Sup.len++;
	(*ir).nodes->data[T5_] = T3_;
	nimZeroMem((void*)(&T6_), sizeof(tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA));
	T6_.kind = ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 9);
	T6_.info = info;
	T6_.operand = (*(*n)._kind_4.sym).Sup.itemId.item;
	unsureAsgnRef((void**) (&(*ir).nodes), (tySequence__4Murtwnm0Fyc7F9acrytEXw*) incrSeqV3((TGenericSeq*)((*ir).nodes), (&NTIseqLpackednodeT__4Murtwnm0Fyc7F9acrytEXw_)));
	T7_ = (*ir).nodes->Sup.len++;
	(*ir).nodes->data[T7_] = T6_;
}
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, toPackedNode__icZic_2428)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg* ir, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m) {
	tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
{	{
		NI T5_;
		if (!(n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA3_;
		unsureAsgnRef((void**) (&(*ir).nodes), (tySequence__4Murtwnm0Fyc7F9acrytEXw*) incrSeqV3((TGenericSeq*)((*ir).nodes), (&NTIseqLpackednodeT__4Murtwnm0Fyc7F9acrytEXw_)));
		T5_ = (*ir).nodes->Sup.len++;
		(*ir).nodes->data[T5_] = TM__mJObP0PRzfMjXxDpaIgosg_32;
		goto BeforeRet_;
	}
	LA3_: ;
	info = toPackedInfo__icZic_2576((*n).info, c, m);
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 4):
	{
		tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA T7_;
		NI T8_;
		nimZeroMem((void*)(&T7_), sizeof(tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA));
		T7_.kind = (*n).kind;
		T7_.flags = (*n).flags;
		T7_.operand = ((NI32) 0);
		T7_.typeId_0 = storeTypeLater__icZic_2724((*n).typ, c, m);
		T7_.info = info;
		unsureAsgnRef((void**) (&(*ir).nodes), (tySequence__4Murtwnm0Fyc7F9acrytEXw*) incrSeqV3((TGenericSeq*)((*ir).nodes), (&NTIseqLpackednodeT__4Murtwnm0Fyc7F9acrytEXw_)));
		T8_ = (*ir).nodes->Sup.len++;
		(*ir).nodes->data[T8_] = T7_;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	{
		tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA T10_;
		NU32 T11_;
		NI T12_;
		nimZeroMem((void*)(&T10_), sizeof(tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA));
		T10_.kind = (*n).kind;
		T10_.flags = (*n).flags;
		T11_ = (NU32)0;
		T11_ = getOrIncl__icZic_926((&(*m).strings), (*(*n)._kind_5.ident).s);
		T10_.operand = ((NI32) (T11_));
		T10_.typeId_0 = storeTypeLater__icZic_2724((*n).typ, c, m);
		T10_.info = info;
		unsureAsgnRef((void**) (&(*ir).nodes), (tySequence__4Murtwnm0Fyc7F9acrytEXw*) incrSeqV3((TGenericSeq*)((*ir).nodes), (&NTIseqLpackednodeT__4Murtwnm0Fyc7F9acrytEXw_)));
		T12_ = (*ir).nodes->Sup.len++;
		(*ir).nodes->data[T12_] = T10_;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		{
			NI32 id;
			tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ T18_;
			tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA T19_;
			NI T20_;
			if (!((*(*n)._kind_4.sym).Sup.itemId.module == (*c).thisModule)) goto LA16_;
			T18_ = storeSymLater__icZic_2738((*n)._kind_4.sym, c, m);
			id = T18_.item;
			nimZeroMem((void*)(&T19_), sizeof(tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA));
			T19_.kind = ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3);
			T19_.flags = (*n).flags;
			T19_.operand = id;
			T19_.typeId_0 = storeTypeLater__icZic_2724((*n).typ, c, m);
			T19_.info = info;
			unsureAsgnRef((void**) (&(*ir).nodes), (tySequence__4Murtwnm0Fyc7F9acrytEXw*) incrSeqV3((TGenericSeq*)((*ir).nodes), (&NTIseqLpackednodeT__4Murtwnm0Fyc7F9acrytEXw_)));
			T20_ = (*ir).nodes->Sup.len++;
			(*ir).nodes->data[T20_] = T19_;
		}
		goto LA14_;
		LA16_: ;
		{
			addModuleRef__icZic_2917(n, ir, c, m);
		}
		LA14_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 9):
	{
		tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA T23_;
		NI T24_;
		nimZeroMem((void*)(&T23_), sizeof(tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA));
		T23_.kind = (*n).kind;
		T23_.flags = (*n).flags;
		T23_.operand = ((NI32) ((*n)._kind_1.intVal));
		T23_.typeId_0 = storeTypeLater__icZic_2724((*n).typ, c, m);
		T23_.info = info;
		unsureAsgnRef((void**) (&(*ir).nodes), (tySequence__4Murtwnm0Fyc7F9acrytEXw*) incrSeqV3((TGenericSeq*)((*ir).nodes), (&NTIseqLpackednodeT__4Murtwnm0Fyc7F9acrytEXw_)));
		T24_ = (*ir).nodes->Sup.len++;
		(*ir).nodes->data[T24_] = T23_;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 8):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 10) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 15):
	{
		tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA T26_;
		NU32 T27_;
		NI T28_;
		nimZeroMem((void*)(&T26_), sizeof(tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA));
		T26_.kind = (*n).kind;
		T26_.flags = (*n).flags;
		T27_ = (NU32)0;
		T27_ = getOrIncl__icZic_2490((&(*m).numbers), (*n)._kind_1.intVal);
		T26_.operand = ((NI32) (T27_));
		T26_.typeId_0 = storeTypeLater__icZic_2724((*n).typ, c, m);
		T26_.info = info;
		unsureAsgnRef((void**) (&(*ir).nodes), (tySequence__4Murtwnm0Fyc7F9acrytEXw*) incrSeqV3((TGenericSeq*)((*ir).nodes), (&NTIseqLpackednodeT__4Murtwnm0Fyc7F9acrytEXw_)));
		T28_ = (*ir).nodes->Sup.len++;
		(*ir).nodes->data[T28_] = T26_;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22):
	{
		tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA T30_;
		NU32 T31_;
		NI T32_;
		nimZeroMem((void*)(&T30_), sizeof(tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA));
		T30_.kind = (*n).kind;
		T30_.flags = (*n).flags;
		T31_ = (NU32)0;
		T31_ = getOrIncl__icZic_926((&(*m).strings), (*n)._kind_3.strVal);
		T30_.operand = ((NI32) (T31_));
		T30_.typeId_0 = storeTypeLater__icZic_2724((*n).typ, c, m);
		T30_.info = info;
		unsureAsgnRef((void**) (&(*ir).nodes), (tySequence__4Murtwnm0Fyc7F9acrytEXw*) incrSeqV3((TGenericSeq*)((*ir).nodes), (&NTIseqLpackednodeT__4Murtwnm0Fyc7F9acrytEXw_)));
		T32_ = (*ir).nodes->Sup.len++;
		(*ir).nodes->data[T32_] = T30_;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 16) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 19):
	{
		tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA T34_;
		union { NF source; NI64 dest; } LOC35;
		NU32 T36_;
		NI T37_;
		nimZeroMem((void*)(&T34_), sizeof(tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA));
		T34_.kind = (*n).kind;
		T34_.flags = (*n).flags;
		LOC35.source = (*n)._kind_2.floatVal;
		T36_ = (NU32)0;
		T36_ = getOrIncl__icZic_2490((&(*m).numbers), LOC35.dest);
		T34_.operand = ((NI32) (T36_));
		T34_.typeId_0 = storeTypeLater__icZic_2724((*n).typ, c, m);
		T34_.info = info;
		unsureAsgnRef((void**) (&(*ir).nodes), (tySequence__4Murtwnm0Fyc7F9acrytEXw*) incrSeqV3((TGenericSeq*)((*ir).nodes), (&NTIseqLpackednodeT__4Murtwnm0Fyc7F9acrytEXw_)));
		T37_ = (*ir).nodes->Sup.len++;
		(*ir).nodes->data[T37_] = T34_;
	}
	break;
	default:
	{
		NI patchPos;
		tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ T39_;
		T39_ = storeTypeLater__icZic_2724((*n).typ, c, m);
		patchPos = prepare__icZpacked95ast_252(ir, (*n).kind, (*n).flags, T39_, info);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA42;
					i = i_2;
					toPackedNode__icZic_2428((*n)._kind_6.sons->data[i], ir, c, m);
					i_2 += ((NI) 1);
				} LA42: ;
			}
		}
		patch__icZpacked95ast_287(ir, patchPos);
	}
	break;
	}
	}BeforeRet_: ;
}
static N_INLINE(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ, safeItemId__icZic_2581)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m) {
	tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ result;
	nimZeroMem((void*)(&result), sizeof(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (s == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = ((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 24));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = nilItemId__icZpacked95ast_14;
	}
	goto LA1_;
	LA5_: ;
	{
		nimZeroMem((void*)(&result), sizeof(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ));
		result.module = toLitId__icZic_521((*s).Sup.itemId.module, c, m);
		result.item = (*s).Sup.itemId.item;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ, storeType__icZic_2437)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m) {
	tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ result;
{	nimZeroMem((void*)(&result), sizeof(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ));
	{
		if (!(t == 0)) goto LA3_;
		result = nilItemId__icZpacked95ast_14;
		goto BeforeRet_;
	}
	LA3_: ;
	nimZeroMem((void*)(&result), sizeof(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ));
	result.module = toLitId__icZic_521((*t).uniqueId.module, c, m);
	result.item = (*t).uniqueId.item;
	{
		NIM_BOOL T7_;
		NIM_BOOL T9_;
		tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw p;
		NI32 nodeIdX60gensym98_;
		T7_ = (NIM_BOOL)0;
		T7_ = ((*t).uniqueId.module == (*c).thisModule);
		if (!(T7_)) goto LA8_;
		T9_ = (NIM_BOOL)0;
		T9_ = containsOrIncl__astalgo_402((&(*c).typeMarker), ((NI) ((*t).uniqueId.item)));
		T7_ = !(T9_);
		LA8_: ;
		if (!T7_) goto LA10_;
		{
			NI T14_;
			T14_ = ((*m).types ? (*m).types->Sup.len : 0);
			if (!(T14_ <= ((NI) ((*t).uniqueId.item)))) goto LA15_;
			unsureAsgnRef((void**) (&(*m).types), (tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw*) setLengthSeqV2(((*m).types)?&((*m).types)->Sup:NIM_NIL, (&NTIseqLpackedtypeT__DPZr9aMyRppVlNZ9ajSyOZ9bw_), ((NI) ((NI32)((*t).uniqueId.item + ((NI32) 1))))));
		}
		LA15_: ;
		nimZeroMem((void*)(&p), sizeof(tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw));
		nimZeroMem((void*)(&p), sizeof(tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw));
		p.kind = (*t).kind;
		p.flags = (*t).flags;
		p.callConv = (*t).callConv;
		p.size = (*t).size;
		p.align = (*t).align;
		p.nonUniqueId = (*t).Sup.itemId.item;
		p.paddingAtEnd = (*t).paddingAtEnd;
		p.lockLevel = (*t).lockLevel;
		nodeIdX60gensym98_ = (NI32)0;
		{
			if (!!(((*t).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA19_;
			nodeIdX60gensym98_ = getNodeId__icZpacked95ast_588((*m).bodies);
			toPackedNode__icZic_2428((*t).n, (&(*m).bodies), c, m);
		}
		goto LA17_;
		LA19_: ;
		{
			nodeIdX60gensym98_ = ((NI32) -1);
		}
		LA17_: ;
		p.n = nodeIdX60gensym98_;
		p.typeInst = storeType__icZic_2437((*t).typeInst, c, m);
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA** kid;
			NI i;
			NI L;
			NI T23_;
			kid = (tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA**)0;
			i = ((NI) 0);
			T23_ = ((*t).sons ? (*t).sons->Sup.len : 0);
			L = T23_;
			{
				while (1) {
					tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ T26_;
					NI T27_;
					if (!(i < L)) goto LA25;
					kid = &(*t).sons->data[i];
					T26_ = storeType__icZic_2437((*kid), c, m);
					p.types = (tySequence__lo3S1lKyiPLhGGB9cBawd6A*) incrSeqV3((TGenericSeq*)(p.types), (&NTIseqLpackeditemidT__lo3S1lKyiPLhGGB9cBawd6A_));
					T27_ = p.types->Sup.len++;
					p.types->data[T27_] = T26_;
					i += ((NI) 1);
				} LA25: ;
			}
		}
		addMissing__icZic_2597(c, (*t).sym);
		p.sym = safeItemId__icZic_2581((*t).sym, c, m);
		addMissing__icZic_2597(c, (*t).owner);
		p.owner = safeItemId__icZic_2581((*t).owner, c, m);
		genericAssign((void*)(&(*m).types->data[(*t).uniqueId.item]), (void*)(&p), (&NTIpackedtype__MvipqCfEd9b9bJbbBPwsUOiw_));
	}
	LA10_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, pop__icZic_2447)(tySequence__vKogasEnJSPhbQmA8r4Y9aA** s) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	NI L;
	NI T1_;
	result = NIM_NIL;
	T1_ = ((*s) ? (*s)->Sup.len : 0);
	L = (NI)(T1_ - ((NI) 1));
	result = (*s)->data[L];
	unsureAsgnRef((void**) (&(*s)), (tySequence__vKogasEnJSPhbQmA8r4Y9aA*) setLengthSeqV2(((*s))?&((*s))->Sup:NIM_NIL, (&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_), ((NI) (L))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NU32, toLitId__icZic_2474)(NimStringDesc* x, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m) {
	NU32 result;
	result = (NU32)0;
	result = getOrIncl__icZic_926((&(*m).strings), x);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA, toPackedLib__icZic_2826)(tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* l, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m) {
	tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA result;
	NimStringDesc* T5_;
	NI32 nodeIdX60gensym102_;
{	nimZeroMem((void*)(&result), sizeof(tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA));
	{
		if (!(l == 0)) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	result.kind = (*l).kind;
	result.generated = (*l).generated;
	result.isOverriden = (*l).isOverriden;
	T5_ = NIM_NIL;
	T5_ = dollar___ropes_250((*l).name);
	result.name = toLitId__icZic_2474(T5_, m);
	nodeIdX60gensym102_ = (NI32)0;
	{
		if (!!(((*l).path == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA8_;
		nodeIdX60gensym102_ = getNodeId__icZpacked95ast_588((*m).bodies);
		toPackedNode__icZic_2428((*l).path, (&(*m).bodies), c, m);
	}
	goto LA6_;
	LA8_: ;
	{
		nodeIdX60gensym102_ = ((NI32) -1);
	}
	LA6_: ;
	result.path = nodeIdX60gensym102_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ, storeSym__icZic_2433)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m) {
	tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ result;
{	nimZeroMem((void*)(&result), sizeof(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ));
	{
		if (!(s == 0)) goto LA3_;
		result = nilItemId__icZpacked95ast_14;
		goto BeforeRet_;
	}
	LA3_: ;
	nimZeroMem((void*)(&result), sizeof(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ));
	result.module = toLitId__icZic_521((*s).Sup.itemId.module, c, m);
	result.item = (*s).Sup.itemId.item;
	{
		NIM_BOOL T7_;
		NIM_BOOL T9_;
		tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA p;
		NI32 nodeIdX60gensym111_;
		NI32 nodeIdX60gensym113_;
		NimStringDesc* T31_;
		T7_ = (NIM_BOOL)0;
		T7_ = ((*s).Sup.itemId.module == (*c).thisModule);
		if (!(T7_)) goto LA8_;
		T9_ = (NIM_BOOL)0;
		T9_ = containsOrIncl__astalgo_402((&(*c).symMarker), ((NI) ((*s).Sup.itemId.item)));
		T7_ = !(T9_);
		LA8_: ;
		if (!T7_) goto LA10_;
		{
			NI T14_;
			T14_ = ((*m).syms ? (*m).syms->Sup.len : 0);
			if (!(T14_ <= ((NI) ((*s).Sup.itemId.item)))) goto LA15_;
			unsureAsgnRef((void**) (&(*m).syms), (tySequence__q9bTuOB0JXh1iZ3CSGdRLbg*) setLengthSeqV2(((*m).syms)?&((*m).syms)->Sup:NIM_NIL, (&NTIseqLpackedsymT__q9bTuOB0JXh1iZ3CSGdRLbg_), ((NI) ((NI32)((*s).Sup.itemId.item + ((NI32) 1))))));
		}
		LA15_: ;
		nimZeroMem((void*)(&p), sizeof(tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA));
		nimZeroMem((void*)(&p), sizeof(tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA));
		p.kind = (*s).kind;
		p.flags = (*s).flags;
		p.info = toPackedInfo__icZic_2576((*s).info, c, m);
		p.magic = (*s).magic;
		p.position = (*s).position;
		p.offset = (*s).offset;
		p.options = (*s).options;
		p.name = toLitId__icZic_2474((*(*s).name).s, m);
		nodeIdX60gensym111_ = (NI32)0;
		{
			if (!!(((*s).ast == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA19_;
			nodeIdX60gensym111_ = getNodeId__icZpacked95ast_588((*m).bodies);
			toPackedNode__icZic_2428((*s).ast, (&(*m).bodies), c, m);
		}
		goto LA17_;
		LA19_: ;
		{
			nodeIdX60gensym111_ = ((NI32) -1);
		}
		LA17_: ;
		p.ast = nodeIdX60gensym111_;
		nodeIdX60gensym113_ = (NI32)0;
		{
			if (!!(((*s).constraint == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA24_;
			nodeIdX60gensym113_ = getNodeId__icZpacked95ast_588((*m).bodies);
			toPackedNode__icZic_2428((*s).constraint, (&(*m).bodies), c, m);
		}
		goto LA22_;
		LA24_: ;
		{
			nodeIdX60gensym113_ = ((NI32) -1);
		}
		LA22_: ;
		p.constraint = nodeIdX60gensym113_;
		{
			if (!((2622208 &((NU32)1<<((NU)((*s).kind)&31U)))!=0)) goto LA29_;
			addMissing__icZic_2597(c, (*s)._kind_2.guard);
			p.guard = safeItemId__icZic_2581((*s)._kind_2.guard, c, m);
			p.bitsize = (*s)._kind_2.bitsize;
			p.alignment = (*s)._kind_2.alignment;
		}
		LA29_: ;
		T31_ = NIM_NIL;
		{
			if (!((*s).loc.r == 0)) goto LA34_;
			T31_ = ((NimStringDesc*) NIM_NIL);
		}
		goto LA32_;
		LA34_: ;
		{
			T31_ = dollar___ropes_250((*s).loc.r);
		}
		LA32_: ;
		p.externalName = toLitId__icZic_2474(T31_, m);
		p.locFlags = (*s).loc.flags;
		addMissing__icZic_2662(c, (*s).typ);
		p.typ = storeType__icZic_2437((*s).typ, c, m);
		addMissing__icZic_2597(c, (*s).owner);
		p.owner = safeItemId__icZic_2581((*s).owner, c, m);
		p.annex = toPackedLib__icZic_2826((*s).annex, c, m);
		(*m).syms->data[(*s).Sup.itemId.item] = p;
	}
	LA10_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, pop__icZic_2462)(tySequence__ed0C0uAUZPhvw3RAc5hfYg** s) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	NI L;
	NI T1_;
	result = NIM_NIL;
	T1_ = ((*s) ? (*s)->Sup.len : 0);
	L = (NI)(T1_ - ((NI) 1));
	result = (*s)->data[L];
	unsureAsgnRef((void**) (&(*s)), (tySequence__ed0C0uAUZPhvw3RAc5hfYg*) setLengthSeqV2(((*s))?&((*s))->Sup:NIM_NIL, (&NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_), ((NI) (L))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, flush__icZic_2441)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m) {
	{
		while (1) {
			{
				NI T5_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T8_;
				tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ T9_;
				T5_ = ((*c).pendingTypes ? (*c).pendingTypes->Sup.len : 0);
				if (!(((NI) 0) < T5_)) goto LA6_;
				T8_ = NIM_NIL;
				T8_ = pop__icZic_2447((&(*c).pendingTypes));
				T9_ = storeType__icZic_2437(T8_, c, m);
				(void)(T9_);
			}
			goto LA3_;
			LA6_: ;
			{
				NI T11_;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T14_;
				tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ T15_;
				T11_ = ((*c).pendingSyms ? (*c).pendingSyms->Sup.len : 0);
				if (!(((NI) 0) < T11_)) goto LA12_;
				T14_ = NIM_NIL;
				T14_ = pop__icZic_2462((&(*c).pendingSyms));
				T15_ = storeSym__icZic_2433(T14_, c, m);
				(void)(T15_);
			}
			goto LA3_;
			LA12_: ;
			{
				goto LA1;
			}
			LA3_: ;
		}
	} LA1: ;
}
N_LIB_PRIVATE N_NIMCALL(void, disable__icZic_458)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* e) {
	unsureAsgnRef((void**) (&(*e).config), ((tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) NIM_NIL));
}
N_LIB_PRIVATE N_NIMCALL(void, storeError__icZic_4380)(tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg err, NimStringDesc* filename) {
	tyArray__sMpvt1sOxOJ3LFGulnbeMQ T1_;
	nimZeroMem((void*)T1_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
	T1_[0] = copyString(((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_33));
	T1_[1] = reprEnum((NI)err, (&NTIrodfileerror__1o7JP9bTXjyuYT9bCVtYI0pg_));
	T1_[2] = copyString(((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_34));
	T1_[3] = copyString(filename);
	echoBinSafe(T1_, 4);
	nosremoveFile(filename);
}
N_LIB_PRIVATE N_NIMCALL(void, saveRodFile__icZic_4386)(NimStringDesc* filename, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* encoder, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m) {
	tyObject_RodFile__fVxxWpdMqDQj2Vdv19aO6UQ f;
	flush__icZic_2441(encoder, m);
	f = create__icZrodfiles_290(filename);
	storeHeader__icZrodfiles_109((&f));
	storeSection__icZrodfiles_207((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 1));
	storePrim__icZrodfiles_64((&f), (*m).definedSymbols);
	storePrim__icZic_4391((&f), (*m).moduleFlags);
	storePrim__icZic_4408((&f), (*m).cfg);
	storeSection__icZrodfiles_207((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 2));
	store__icZic_4433((&f), (*m).strings);
	storeSection__icZrodfiles_207((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 3));
	storeSeq__icZic_4520((&f), (*m).includes);
	storeSection__icZrodfiles_207((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 4));
	storeSeq__icZic_4470((&f), (*m).imports);
	storeSection__icZrodfiles_207((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 5));
	store__icZic_4578((&f), (*m).numbers);
	storeSection__icZrodfiles_207((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 6));
	storeSeq__icZic_4636((&f), (*m).exports);
	storeSection__icZrodfiles_207((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 7));
	storeSeq__icZic_4636((&f), (*m).hidden);
	storeSection__icZrodfiles_207((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 8));
	storeSeq__icZic_4691((&f), (*m).reexports);
	storeSection__icZrodfiles_207((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 9));
	storeSeq__icZic_4636((&f), (*m).compilerProcs);
	storeSection__icZrodfiles_207((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 10));
	storeSeq__icZic_4746((&f), (*m).trmacros);
	storeSection__icZrodfiles_207((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 11));
	storeSeq__icZic_4746((&f), (*m).converters);
	storeSection__icZrodfiles_207((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 12));
	storeSeq__icZic_4746((&f), (*m).methods);
	storeSection__icZrodfiles_207((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 13));
	storeSeq__icZic_4746((&f), (*m).pureEnums);
	storeSection__icZrodfiles_207((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 14));
	storeSeq__icZic_4809((&f), (*m).macroUsages);
	storeSection__icZrodfiles_207((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 15));
	storeSeq__icZic_4860((&f), (*m).toReplay.nodes);
	storeSection__icZrodfiles_207((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 16));
	storeSeq__icZic_4860((&f), (*m).topLevel.nodes);
	storeSection__icZrodfiles_207((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 17));
	storeSeq__icZic_4860((&f), (*m).bodies.nodes);
	storeSection__icZrodfiles_207((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 18));
	storeSeq__icZic_4918((&f), (*m).syms);
	storeSection__icZrodfiles_207((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 19));
	storeSeq__icZic_4968((&f), (*m).types);
	storeSection__icZrodfiles_207((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 20));
	storeSeq__icZic_5220((&f), (*m).typeInstCache);
	storeSection__icZrodfiles_207((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 21));
	storeSeq__icZic_5271((&f), (*m).procInstCache);
	storeSection__icZrodfiles_207((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 22));
	storeSeq__icZic_5339((&f), (*m).attachedOps);
	storeSection__icZrodfiles_207((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 23));
	storeSeq__icZic_5390((&f), (*m).methodsPerType);
	storeSection__icZrodfiles_207((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 24));
	storeSeq__icZic_5220((&f), (*m).enumToStringProcs);
	storeSection__icZrodfiles_207((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 25));
	storeSeq__icZic_4437((&f), (*m).emittedTypeInfo);
	storeSection__icZrodfiles_207((&f), ((tyEnum_RodSection__1qPF6pCFSjFrr79bX0V9c5OA) 26));
	storePrim__icZic_5449((&f), (*m).backendFlags);
	close__icZrodfiles_293((&f));
	disable__icZic_458(encoder);
	{
		if (!!((f.err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		storeError__icZic_4380(f.err, filename);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, simulateLoadedModule__icZic_8467)(tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* moduleSym, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m) {
	NI idx;
	idx = (*moduleSym).position;
	(*g)->data[idx].status = ((tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg) 3);
	setupLookupTables__icZic_6265(g, conf, cache, ((NI32) (idx)), (&(*g)->data[idx]));
	loadToReplayNodes__icZic_8240(g, conf, cache, ((NI32) (idx)), (&(*g)->data[idx]));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, translateId__icZic_8428)(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ id, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* g, NI thisModule, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config) {
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	{
		if (!(id.module == ((NU32) 0))) goto LA3_;
		nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
		result.module = ((NI32) (thisModule));
		result.item = id.item;
	}
	goto LA1_;
	LA3_: ;
	{
		nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
		result.module = toFileIndex__icZic_2162(id.module, (&g->data[thisModule].fromDisk), config);
		result.item = id.item;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, loadSymFromId__icZic_8413)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI module, tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ id) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	result = NIM_NIL;
	{
		NI T3_;
		T3_ = ((*g)->data[module].syms ? (*g)->data[module].syms->Sup.len : 0);
		if (!(((NI) (id.item)) < T3_)) goto LA4_;
		result = (*g)->data[module].syms->data[id.item];
	}
	goto LA1_;
	LA4_: ;
	{
		result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
	}
	LA1_: ;
	{
		tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ decoder;
		if (!(result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA9_;
		nimZeroMem((void*)(&decoder), sizeof(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ));
		nimZeroMem((void*)(&decoder), sizeof(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ));
		decoder.lastModule = ((NI) -1);
		decoder.lastLit = ((NU32) 0);
		decoder.lastFile = ((NI32) -1);
		decoder.config = config;
		decoder.cache = cache;
		result = loadSym__icZic_5510((&decoder), g, module, id);
	}
	LA9_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, interfaceSymbol__icZic_9091)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI32 module, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name, NIM_BOOL importHidden) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ decoder;
	tySequence__lo3S1lKyiPLhGGB9cBawd6A* values;
	tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ* retX60gensym301_;
	result = NIM_NIL;
	nimZeroMem((void*)(&decoder), sizeof(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ));
	nimZeroMem((void*)(&decoder), sizeof(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ));
	decoder.lastModule = ((NI) -1);
	decoder.lastLit = ((NU32) 0);
	decoder.lastFile = ((NI32) -1);
	decoder.config = config;
	decoder.cache = cache;
	retX60gensym301_ = (&(*g)->data[module].iface);
	{
		if (!importHidden) goto LA3_;
		retX60gensym301_ = (&(*g)->data[module].ifaceHidden);
	}
	LA3_: ;
	values = getOrDefault__icZic_8581((*retX60gensym301_), name);
	result = loadSym__icZic_5510((&decoder), g, ((NI) (module)), values->data[((NI) 0)]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rememberConfig__icZic_466)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA pc) {
	unsureAsgnRef((void**) (&(*m).definedSymbols), definedSymbolsAsString__icZic_462(config));
	(*m).cfg = pc;
}
N_LIB_PRIVATE N_NIMCALL(void, initEncoder__icZic_2270)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* moduleSym, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA pc) {
	NI32 thisNimFile;
	NimStringDesc* h;
	tyTuple__0q9cmhneJEKnQERTpXXdz6Q T11_;
	NI T12_;
	NimStringDesc* T13_;
	(*c).thisModule = (*moduleSym).Sup.itemId.module;
	unsureAsgnRef((void**) (&(*c).config), config);
	(*m).moduleFlags = (*moduleSym).flags;
	newTreeFrom__icZpacked95ast_112((*m).topLevel, (&(*m).bodies));
	newTreeFrom__icZpacked95ast_112((*m).topLevel, (&(*m).toReplay));
	(*c).lastFile = ((NI32) -10);
	thisNimFile = (*c).thisModule;
	h = getHash__msgs_574(config, thisNimFile);
	{
		NimStringDesc* fullpath;
		if (!((h ? h->Sup.len : 0) == ((NI) 0))) goto LA3_;
		fullpath = toFullPath__msgs_548(config, thisNimFile);
		{
			NIM_BOOL T7_;
			tyArray__YtcvxHNKV4YiecPE9ap1mcA T10_;
			T7_ = (NIM_BOOL)0;
			T7_ = nosisAbsolute(fullpath);
			if (!T7_) goto LA8_;
			nimZeroMem((void*)T10_, sizeof(tyArray__YtcvxHNKV4YiecPE9ap1mcA));
			secureHashFile__stdZsha49_862(fullpath, T10_);
			h = dollar___stdZsha49_870(T10_);
			setHash__msgs_567(config, thisNimFile, h);
		}
		LA8_: ;
	}
	LA3_: ;
	nimZeroMem((void*)(&T11_), sizeof(tyTuple__0q9cmhneJEKnQERTpXXdz6Q));
	T11_.Field0 = toLitId__icZic_521(thisNimFile, c, m);
	T11_.Field1 = copyString(h);
	unsureAsgnRef((void**) (&(*m).includes), (tySequence__PXIzfWocnrafGz5p3CP5LA*) incrSeqV3((TGenericSeq*)((*m).includes), (&NTIseqLLlitid_stringTT__PXIzfWocnrafGz5p3CP5LA_)));
	T12_ = (*m).includes->Sup.len++;
	(*m).includes->data[T12_].Field0 = T11_.Field0;
	T13_ = NIM_NIL;
	T13_ = (*m).includes->data[T12_].Field1; (*m).includes->data[T12_].Field1 = copyStringRC1(T11_.Field1);
	if (T13_) nimGCunrefNoCycle(T13_);
	rememberConfig__icZic_466(c, m, config, pc);
}
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_31)(NI hcode) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = !((hcode == ((NI) 0)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, initRodIterAllSyms__icZic_8670)(tyObject_RodIter__L6nv9cakjPARHk068AFo6ww* it, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI32 module, NIM_BOOL importHidden) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ T1_;
	result = NIM_NIL;
	nimZeroMem((void*)(&T1_), sizeof(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ));
	T1_.lastModule = ((NI) -1);
	T1_.lastLit = ((NU32) 0);
	T1_.lastFile = ((NI32) -1);
	T1_.config = config;
	T1_.cache = cache;
	genericShallowAssign((void*)(&(*it).decoder), (void*)(&T1_), (&NTIpackeddecoder__KP7DLKztb9c2OnCFWxJiscQ_));
	unsureAsgnRef((void**) (&(*it).values), NIM_NIL);
	(*it).module = ((NI) (module));
	{
		tySequence__lo3S1lKyiPLhGGB9cBawd6A** v;
		tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ colontmp_;
		tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ* retX60gensym292_;
		NI L;
		v = (tySequence__lo3S1lKyiPLhGGB9cBawd6A**)0;
		nimZeroMem((void*)(&colontmp_), sizeof(tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ));
		retX60gensym292_ = (&(*g)->data[module].iface);
		{
			if (!importHidden) goto LA5_;
			retX60gensym292_ = (&(*g)->data[module].ifaceHidden);
		}
		LA5_: ;
		colontmp_.data = (*retX60gensym292_).data;
		colontmp_.counter = (*retX60gensym292_).counter;
		L = len__icZic_8740(colontmp_);
		{
			NI h;
			NI colontmp__2;
			NI T8_;
			NI res;
			h = (NI)0;
			colontmp__2 = (NI)0;
			T8_ = ((colontmp_.data ? colontmp_.data->Sup.len : 0)-1);
			colontmp__2 = T8_;
			res = ((NI) 0);
			{
				while (1) {
					if (!(res <= colontmp__2)) goto LA10;
					h = res;
					{
						NIM_BOOL T13_;
						T13_ = (NIM_BOOL)0;
						T13_ = isFilled__pureZcollectionsZtables_31(colontmp_.data->data[h].Field0);
						if (!T13_) goto LA14_;
						v = (&colontmp_.data->data[h].Field2);
						add__icZic_8922((&(*it).values), ((*v)) ? ((*v)->data) : NIM_NIL, ((*v) ? (*v)->Sup.len : 0));
					}
					LA14_: ;
					res += ((NI) 1);
				} LA10: ;
			}
		}
	}
	(*it).i = ((NI) 0);
	{
		NI T18_;
		T18_ = ((*it).values ? (*it).values->Sup.len : 0);
		if (!((*it).i < T18_)) goto LA19_;
		result = loadSym__icZic_5510((&(*it).decoder), g, ((NI) (module)), (*it).values->data[(*it).i]);
		(*it).i += ((NI) 1);
	}
	LA19_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, nextRodIter__icZic_8980)(tyObject_RodIter__L6nv9cakjPARHk068AFo6ww* it, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	result = NIM_NIL;
	{
		NI T3_;
		T3_ = ((*it).values ? (*it).values->Sup.len : 0);
		if (!((*it).i < T3_)) goto LA4_;
		result = loadSym__icZic_5510((&(*it).decoder), g, (*it).module, (*it).values->data[(*it).i]);
		(*it).i += ((NI) 1);
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, loadTypeFromId__icZic_8398)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI module, tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ id) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	result = NIM_NIL;
	{
		NI T3_;
		T3_ = ((*g)->data[module].types ? (*g)->data[module].types->Sup.len : 0);
		if (!(((NI) (id.item)) < T3_)) goto LA4_;
		result = (*g)->data[module].types->data[id.item];
	}
	goto LA1_;
	LA4_: ;
	{
		result = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL);
	}
	LA1_: ;
	{
		tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ decoder;
		if (!(result == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA9_;
		nimZeroMem((void*)(&decoder), sizeof(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ));
		nimZeroMem((void*)(&decoder), sizeof(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ));
		decoder.lastModule = ((NI) -1);
		decoder.lastLit = ((NU32) 0);
		decoder.lastFile = ((NI32) -1);
		decoder.config = config;
		decoder.cache = cache;
		result = loadType__icZic_5505((&decoder), g, module, id);
	}
	LA9_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, storeTypeInst__icZic_3012)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* inst) {
	tyTuple__Db8CrQifKGIsKc3w71w7Lw T1_;
	NI T2_;
	T1_.Field0 = storeSymLater__icZic_2738(s, c, m);
	T1_.Field1 = storeTypeLater__icZic_2724(inst, c, m);
	unsureAsgnRef((void**) (&(*m).typeInstCache), (tySequence__oKtVqsc9bQVCNyrijELM4OQ*) incrSeqV3((TGenericSeq*)((*m).typeInstCache), (&NTIseqLLpackeditemid_packeditemidTT__oKtVqsc9bQVCNyrijELM4OQ_)));
	T2_ = (*m).typeInstCache->Sup.len++;
	(*m).typeInstCache->data[T2_] = T1_;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, initRodIter__icZic_8497)(tyObject_RodIter__L6nv9cakjPARHk068AFo6ww* it, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI32 module, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name, NIM_BOOL importHidden) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ T1_;
	tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ* retX60gensym289_;
	result = NIM_NIL;
	nimZeroMem((void*)(&T1_), sizeof(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ));
	T1_.lastModule = ((NI) -1);
	T1_.lastLit = ((NU32) 0);
	T1_.lastFile = ((NI32) -1);
	T1_.config = config;
	T1_.cache = cache;
	genericShallowAssign((void*)(&(*it).decoder), (void*)(&T1_), (&NTIpackeddecoder__KP7DLKztb9c2OnCFWxJiscQ_));
	retX60gensym289_ = (&(*g)->data[module].iface);
	{
		if (!importHidden) goto LA4_;
		retX60gensym289_ = (&(*g)->data[module].ifaceHidden);
	}
	LA4_: ;
	unsureAsgnRef((void**) (&(*it).values), getOrDefault__icZic_8581((*retX60gensym289_), name));
	(*it).i = ((NI) 0);
	(*it).module = ((NI) (module));
	{
		NI T8_;
		T8_ = ((*it).values ? (*it).values->Sup.len : 0);
		if (!((*it).i < T8_)) goto LA9_;
		result = loadSym__icZic_5510((&(*it).decoder), g, ((NI) (module)), (*it).values->data[(*it).i]);
		(*it).i += ((NI) 1);
	}
	LA9_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addExported__icZic_2332)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NU32 nameId;
	tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ T1_;
	NI T2_;
	nameId = getOrIncl__icZic_926((&(*m).strings), (*(*s).name).s);
	T1_.Field0 = nameId;
	T1_.Field1 = (*s).Sup.itemId.item;
	unsureAsgnRef((void**) (&(*m).exports), (tySequence__b89aLriiJnVTD186H6zNIgg*) incrSeqV3((TGenericSeq*)((*m).exports), (&NTIseqLLlitid_int5150TT__b89aLriiJnVTD186H6zNIgg_)));
	T2_ = (*m).exports->Sup.len++;
	(*m).exports->data[T2_] = T1_;
}
N_LIB_PRIVATE N_NIMCALL(void, addHidden__icZic_2308)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NU32 nameId;
	tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ T1_;
	NI T2_;
	nameId = getOrIncl__icZic_926((&(*m).strings), (*(*s).name).s);
	T1_.Field0 = nameId;
	T1_.Field1 = (*s).Sup.itemId.item;
	unsureAsgnRef((void**) (&(*m).hidden), (tySequence__b89aLriiJnVTD186H6zNIgg*) incrSeqV3((TGenericSeq*)((*m).hidden), (&NTIseqLLlitid_int5150TT__b89aLriiJnVTD186H6zNIgg_)));
	T2_ = (*m).hidden->Sup.len++;
	(*m).hidden->data[T2_] = T1_;
}
N_LIB_PRIVATE N_NIMCALL(void, storeExpansion__icZic_3134)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T1_;
	T1_ = NIM_NIL;
	T1_ = newSymNode__ast_3707(s, info);
	toPackedNode__icZic_2428(T1_, (&(*m).bodies), c, m);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, loadProcBody__icZic_5883)(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* c, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI thisModule, tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tree, NI n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	NI i;
	result = NIM_NIL;
	i = ((NI) 0);
	{
		NI n0;
		NI pos;
		NI last;
		n0 = (NI)0;
		pos = n;
		last = (NI)(pos + ((NI) (tree.nodes->data[pos].operand)));
		pos += ((NI) 1);
		{
			while (1) {
				if (!(pos < last)) goto LA3;
				n0 = pos;
				{
					if (!(i == ((NI) 6))) goto LA6_;
					result = loadNodes__icZic_5535(c, g, thisModule, tree, n0);
				}
				LA6_: ;
				i += ((NI) 1);
				nextChild__icZpacked95ast_321(tree, (&pos));
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, loadProcBody__icZic_8386)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	NI32 mId;
	tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ decoder;
	NI32 pos;
	result = NIM_NIL;
	mId = (*s).Sup.itemId.module;
	nimZeroMem((void*)(&decoder), sizeof(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ));
	nimZeroMem((void*)(&decoder), sizeof(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ));
	decoder.lastModule = ((NI) -1);
	decoder.lastLit = ((NU32) 0);
	decoder.lastFile = ((NI32) -1);
	decoder.config = config;
	decoder.cache = cache;
	pos = (*g)->data[mId].fromDisk.syms->data[(*s).Sup.itemId.item].ast;
	result = loadProcBody__icZic_5883((&decoder), g, ((NI) (mId)), (*g)->data[mId].fromDisk.bodies, ((NI) (pos)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI32, searchForCompilerproc__icZic_9189)(tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg* m, NimStringDesc* name) {
	NI32 result;
{	result = (NI32)0;
	{
		tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ* it;
		NI i;
		NI L;
		NI T2_;
		it = (tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ*)0;
		i = ((NI) 0);
		T2_ = ((*m).fromDisk.compilerProcs ? (*m).fromDisk.compilerProcs->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				it = (&(*m).fromDisk.compilerProcs->data[i]);
				{
					NimStringDesc** T7_;
					T7_ = (NimStringDesc**)0;
					T7_ = X5BX5D___icZic_154((&(*m).fromDisk.strings), (*it).Field0);
					if (!eqStrings((*T7_), name)) goto LA8_;
					result = (*it).Field1;
					goto BeforeRet_;
				}
				LA8_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
	result = ((NI32) -1);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, toPackedProcDef__icZic_3034)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg* ir, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m) {
	tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
	NI patchPos;
	tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ T1_;
	info = toPackedInfo__icZic_2576((*n).info, c, m);
	T1_ = storeTypeLater__icZic_2724((*n).typ, c, m);
	patchPos = prepare__icZpacked95ast_252(ir, (*n).kind, (*n).flags, T1_, info);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				{
					if (!!((i == ((NI) 6)))) goto LA7_;
					toPackedNode__icZic_2428((*n)._kind_6.sons->data[i], ir, c, m);
				}
				goto LA5_;
				LA7_: ;
				{
					tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA T10_;
					NI T11_;
					nimZeroMem((void*)(&T10_), sizeof(tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA));
					T10_.kind = ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1);
					T10_.flags = 0;
					T10_.operand = ((NI32) 0);
					T10_.typeId_0 = nilItemId__icZpacked95ast_14;
					T10_.info = info;
					unsureAsgnRef((void**) (&(*ir).nodes), (tySequence__4Murtwnm0Fyc7F9acrytEXw*) incrSeqV3((TGenericSeq*)((*ir).nodes), (&NTIseqLpackednodeT__4Murtwnm0Fyc7F9acrytEXw_)));
					T11_ = (*ir).nodes->Sup.len++;
					(*ir).nodes->data[T11_] = T10_;
				}
				LA5_: ;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	patch__icZpacked95ast_287(ir, patchPos);
}
N_LIB_PRIVATE N_NIMCALL(void, toPackedGeneratedProcDef__icZic_3063)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* encoder, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m) {
	toPackedProcDef__icZic_3034((*s).ast, (&(*m).topLevel), encoder, m);
}
N_LIB_PRIVATE N_NIMCALL(void, storeInstantiation__icZic_3074)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* i) {
	tySequence__lo3S1lKyiPLhGGB9cBawd6A* t;
	NI T1_;
	tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg T6_;
	NI T7_;
	T1_ = ((*i).concreteTypes ? (*i).concreteTypes->Sup.len : 0);
	t = newSeq__icZic_3083(((NI) (T1_)));
	{
		NI j;
		NI colontmp_;
		NI T3_;
		NI res;
		j = (NI)0;
		colontmp_ = (NI)0;
		T3_ = (((*i).concreteTypes ? (*i).concreteTypes->Sup.len : 0)-1);
		colontmp_ = T3_;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA5;
				j = res;
				t->data[j] = storeTypeLater__icZic_2724((*i).concreteTypes->data[j], c, m);
				res += ((NI) 1);
			} LA5: ;
		}
	}
	nimZeroMem((void*)(&T6_), sizeof(tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg));
	nimZeroMem((void*)(&T6_), sizeof(tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg));
	T6_.key = storeSymLater__icZic_2738(s, c, m);
	T6_.sym = storeSymLater__icZic_2738((*i).sym, c, m);
	genericSeqAssign((&T6_.concreteTypes), t, (&NTIseqLpackeditemidT__lo3S1lKyiPLhGGB9cBawd6A_));
	unsureAsgnRef((void**) (&(*m).procInstCache), (tySequence__qy6Iwdy00wN560qud54HTg*) incrSeqV3((TGenericSeq*)((*m).procInstCache), (&NTIseqLpackedinstantiationT__qy6Iwdy00wN560qud54HTg_)));
	T7_ = (*m).procInstCache->Sup.len++;
	(*m).procInstCache->data[T7_].key = T6_.key;
	(*m).procInstCache->data[T7_].sym = T6_.sym;
	genericSeqAssign((&(*m).procInstCache->data[T7_].concreteTypes), T6_.concreteTypes, (&NTIseqLpackeditemidT__lo3S1lKyiPLhGGB9cBawd6A_));
	toPackedGeneratedProcDef__icZic_3063((*i).sym, c, m);
}
N_LIB_PRIVATE N_NIMCALL(void, addPragmaComputation__icZic_3030)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	toPackedNode__icZic_2428(n, (&(*m).toReplay), c, m);
}
N_LIB_PRIVATE N_NIMCALL(void, addCompilerProc__icZic_2413)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NU32 nameId;
	tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ T1_;
	NI T2_;
	nameId = getOrIncl__icZic_926((&(*m).strings), (*(*s).name).s);
	T1_.Field0 = nameId;
	T1_.Field1 = (*s).Sup.itemId.item;
	unsureAsgnRef((void**) (&(*m).compilerProcs), (tySequence__b89aLriiJnVTD186H6zNIgg*) incrSeqV3((TGenericSeq*)((*m).compilerProcs), (&NTIseqLLlitid_int5150TT__b89aLriiJnVTD186H6zNIgg_)));
	T2_ = (*m).compilerProcs->Sup.len++;
	(*m).compilerProcs->data[T2_] = T1_;
}
N_LIB_PRIVATE N_NIMCALL(void, addTrmacro__icZic_2358)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NI T1_;
	unsureAsgnRef((void**) (&(*m).trmacros), (tySequence__48JTohSgTy339bRxHzUD8KA*) incrSeqV3((TGenericSeq*)((*m).trmacros), (&NTIseqLint5150T__48JTohSgTy339bRxHzUD8KA_)));
	T1_ = (*m).trmacros->Sup.len++;
	(*m).trmacros->data[T1_] = (*s).Sup.itemId.item;
}
N_LIB_PRIVATE N_NIMCALL(void, addPureEnum__icZic_2366)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NI T1_;
	unsureAsgnRef((void**) (&(*m).pureEnums), (tySequence__48JTohSgTy339bRxHzUD8KA*) incrSeqV3((TGenericSeq*)((*m).pureEnums), (&NTIseqLint5150T__48JTohSgTy339bRxHzUD8KA_)));
	T1_ = (*m).pureEnums->Sup.len++;
	(*m).pureEnums->data[T1_] = (*s).Sup.itemId.item;
}
N_LIB_PRIVATE N_NIMCALL(void, addConverter__icZic_2347)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NI T1_;
	unsureAsgnRef((void**) (&(*m).converters), (tySequence__48JTohSgTy339bRxHzUD8KA*) incrSeqV3((TGenericSeq*)((*m).converters), (&NTIseqLint5150T__48JTohSgTy339bRxHzUD8KA_)));
	T1_ = (*m).converters->Sup.len++;
	(*m).converters->data[T1_] = (*s).Sup.itemId.item;
}
N_LIB_PRIVATE N_NIMCALL(void, addImportFileDep__icZic_2300)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, NI32 f) {
	NU32 T1_;
	NI T2_;
	T1_ = (NU32)0;
	T1_ = toLitId__icZic_521(f, c, m);
	unsureAsgnRef((void**) (&(*m).imports), (tySequence__9bAGqSvkAaFL9bWjsEPslrFA*) incrSeqV3((TGenericSeq*)((*m).imports), (&NTIseqLlitidT__9bAGqSvkAaFL9bWjsEPslrFA_)));
	T2_ = (*m).imports->Sup.len++;
	(*m).imports->data[T2_] = T1_;
}
N_LIB_PRIVATE N_NIMCALL(void, addIncludeFileDep__icZic_2292)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, NI32 f) {
	tyTuple__0q9cmhneJEKnQERTpXXdz6Q T1_;
	NI T2_;
	NimStringDesc* T3_;
	nimZeroMem((void*)(&T1_), sizeof(tyTuple__0q9cmhneJEKnQERTpXXdz6Q));
	T1_.Field0 = toLitId__icZic_521(f, c, m);
	T1_.Field1 = hashFileCached__icZic_516((*c).config, f);
	unsureAsgnRef((void**) (&(*m).includes), (tySequence__PXIzfWocnrafGz5p3CP5LA*) incrSeqV3((TGenericSeq*)((*m).includes), (&NTIseqLLlitid_stringTT__PXIzfWocnrafGz5p3CP5LA_)));
	T2_ = (*m).includes->Sup.len++;
	(*m).includes->data[T2_].Field0 = T1_.Field0;
	T3_ = NIM_NIL;
	T3_ = (*m).includes->data[T2_].Field1; (*m).includes->data[T2_].Field1 = copyStringRC1(T1_.Field1);
	if (T3_) nimGCunrefNoCycle(T3_);
}
N_LIB_PRIVATE N_NIMCALL(void, addReexport__icZic_2389)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NU32 nameId;
	tyTuple__PsEhl3dzznmmJiLAuIXZOg T1_;
	tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ T2_;
	NI T3_;
	nameId = getOrIncl__icZic_926((&(*m).strings), (*(*s).name).s);
	T1_.Field0 = nameId;
	nimZeroMem((void*)(&T2_), sizeof(tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ));
	T2_.module = toLitId__icZic_521((*s).Sup.itemId.module, c, m);
	T2_.item = (*s).Sup.itemId.item;
	T1_.Field1 = T2_;
	unsureAsgnRef((void**) (&(*m).reexports), (tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw*) incrSeqV3((TGenericSeq*)((*m).reexports), (&NTIseqLLlitid_packeditemidTT__wE9cZkGC9cv7Iz9ckZOIyaW9aw_)));
	T3_ = (*m).reexports->Sup.len++;
	(*m).reexports->data[T3_] = T1_;
}
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__ast_3155(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, toPackedNodeIgnoreProcDefs__icZic_3054)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* encoder, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159):
	{
		toPackedProcDef__icZic_3034(n, (&(*m).topLevel), encoder, m);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
			it = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA6;
						i = i_2;
						it = (*n)._kind_6.sons->data[i];
						toPackedNodeIgnoreProcDefs__icZic_3054(it, encoder, m);
						i_2 += ((NI) 1);
					} LA6: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 116):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 117):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 118):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 119):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 120):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 121):
	{
	}
	break;
	default:
	{
		toPackedNode__icZic_2428(n, (&(*m).topLevel), encoder, m);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, toPackedNodeTopLevel__icZic_3059)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* encoder, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m) {
	toPackedNodeIgnoreProcDefs__icZic_3054(n, encoder, m);
	flush__icZic_2441(encoder, m);
}
N_LIB_PRIVATE N_NIMCALL(void, rememberStartupConfig__icZic_507)(tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA* dest, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config) {
	(*dest).backend = (*config).backend;
	(*dest).selectedGC = (*config).selectedGC;
	(*dest).cCompiler = (*config).cCompiler;
	(*dest).options = (*config).options;
	(*dest).globalOptions = (*config).globalOptions;
	(*dest).globalOptions &= ~(((NU64)1) << ((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 1)) & 63));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg*, idgenFromLoadedModule__icZic_9180)(tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg* m) {
	tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* result;
	tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* T1_;
	NI T2_;
	NI T3_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg*) newObj((&NTIidgenerator__M4gwBCp6eTol0yFD6lAxTQ_), sizeof(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg));
	(*T1_).module = (*(*m).module).Sup.itemId.module;
	T2_ = ((*m).fromDisk.syms ? (*m).fromDisk.syms->Sup.len : 0);
	(*T1_).symId = ((NI32) (T2_));
	T3_ = ((*m).fromDisk.types ? (*m).fromDisk.types->Sup.len : 0);
	(*T1_).typeId_0 = ((NI32) (T3_));
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initPackedDecoder__icZic_5841)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ* Result) {
	(*Result).lastModule = 0;
	(*Result).lastLit = 0;
	(*Result).lastFile = 0;
	unsureAsgnRef((void**)&(*Result).config, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).cache, NIM_NIL);
	(*Result).lastModule = ((NI) -1);
	(*Result).lastLit = ((NU32) 0);
	(*Result).lastFile = ((NI32) -1);
	unsureAsgnRef((void**) (&(*Result).config), config);
	unsureAsgnRef((void**) (&(*Result).cache), cache);
}
N_LIB_PRIVATE N_NIMCALL(void, rodViewer__icZic_9258)(NimStringDesc* rodfile, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache) {
	tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag m;
	tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg err;
	tyArray__nHXaesL0DJZHyVS07ARPRA T29_;
	NimStringDesc* T30_;
	NI T31_;
	NimStringDesc* T32_;
	tyArray__ucDUDWdKfioXQrN9bCbG29bg T51_;
	NI T52_;
	NI T53_;
	NI T54_;
	NI T55_;
	NI T56_;
	NI T57_;
	nimZeroMem((void*)(&m), sizeof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag));
	err = loadRodFile__icZic_3151(rodfile, (&m), config, NIM_TRUE);
	{
		if (!!((err == ((tyEnum_RodFileError__1o7JP9bTXjyuYT9bCVtYI0pg) 0)))) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = isDefined__options_2292(config, ((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_36));
			if (!T7_) goto LA8_;
			{
				NimStringDesc* T14_;
				if (!NIM_TRUE) goto LA12_;
				T14_ = NIM_NIL;
				T14_ = rawNewString((rodfile ? rodfile->Sup.len : 0) + (reprEnum((NI)err, (&NTIrodfileerror__1o7JP9bTXjyuYT9bCVtYI0pg_)) ? reprEnum((NI)err, (&NTIrodfileerror__1o7JP9bTXjyuYT9bCVtYI0pg_))->Sup.len : 0) + 61);
appendString(T14_, ((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_37));
appendString(T14_, rodfile);
appendString(T14_, ((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_30));
appendString(T14_, reprEnum((NI)err, (&NTIrodfileerror__1o7JP9bTXjyuYT9bCVtYI0pg_)));
				failedAssertImpl__systemZassertions_56(T14_);
			}
			LA12_: ;
		}
		goto LA5_;
		LA8_: ;
		{
			NimStringDesc* T16_;
			T16_ = NIM_NIL;
			T16_ = rawNewString((rodfile ? rodfile->Sup.len : 0) + (reprEnum((NI)err, (&NTIrodfileerror__1o7JP9bTXjyuYT9bCVtYI0pg_)) ? reprEnum((NI)err, (&NTIrodfileerror__1o7JP9bTXjyuYT9bCVtYI0pg_))->Sup.len : 0) + 32);
appendString(T16_, ((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_38));
appendString(T16_, rodfile);
appendString(T16_, ((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_30));
appendString(T16_, reprEnum((NI)err, (&NTIrodfileerror__1o7JP9bTXjyuYT9bCVtYI0pg_)));
			quit__system_7174(T16_, ((NI) 1));
		}
		LA5_: ;
	}
	LA3_: ;
	echoBinSafe(TM__mJObP0PRzfMjXxDpaIgosg_39, 1);
	{
		tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ* ex;
		NI i;
		NI L;
		NI T18_;
		ex = (tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ*)0;
		i = ((NI) 0);
		T18_ = (m.exports ? m.exports->Sup.len : 0);
		L = T18_;
		{
			while (1) {
				tyArray__sMpvt1sOxOJ3LFGulnbeMQ T21_;
				NimStringDesc** T22_;
				if (!(i < L)) goto LA20;
				ex = (&m.exports->data[i]);
				nimZeroMem((void*)T21_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
				T21_[0] = copyString(((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_41));
				T22_ = (NimStringDesc**)0;
				T22_ = X5BX5D___icZic_5604((&m.strings), (*ex).Field0);
				T21_[1] = copyString((*T22_));
				T21_[2] = copyString(((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_42));
				T21_[3] = dollar___systemZdollars_3(((NI) ((*ex).Field1)));
				echoBinSafe(T21_, 4);
				i += ((NI) 1);
			} LA20: ;
		}
	}
	echoBinSafe(TM__mJObP0PRzfMjXxDpaIgosg_43, 1);
	{
		tyTuple__PsEhl3dzznmmJiLAuIXZOg* ex_2;
		NI i_2;
		NI L_2;
		NI T24_;
		ex_2 = (tyTuple__PsEhl3dzznmmJiLAuIXZOg*)0;
		i_2 = ((NI) 0);
		T24_ = (m.reexports ? m.reexports->Sup.len : 0);
		L_2 = T24_;
		{
			while (1) {
				tyArray__Re75IspeoxXy2oCZHwcRrA T27_;
				NimStringDesc** T28_;
				if (!(i_2 < L_2)) goto LA26;
				ex_2 = (&m.reexports->data[i_2]);
				nimZeroMem((void*)T27_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T27_[0] = copyString(((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_41));
				T28_ = (NimStringDesc**)0;
				T28_ = X5BX5D___icZic_5604((&m.strings), (*ex_2).Field0);
				T27_[1] = copyString((*T28_));
				echoBinSafe(T27_, 2);
				i_2 += ((NI) 1);
			} LA26: ;
		}
	}
	nimZeroMem((void*)T29_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
	T30_ = NIM_NIL;
	T31_ = (m.hidden ? m.hidden->Sup.len : 0);
	T32_ = NIM_NIL;
	T32_ = dollar___systemZdollars_3(T31_);
	T30_ = rawNewString((T32_ ? T32_->Sup.len : 0) + 8);
appendString(T30_, ((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_45));
appendString(T30_, T32_);
	T29_[0] = T30_;
	echoBinSafe(T29_, 1);
	{
		tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ* ex_3;
		NI i_3;
		NI L_3;
		NI T34_;
		ex_3 = (tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ*)0;
		i_3 = ((NI) 0);
		T34_ = (m.hidden ? m.hidden->Sup.len : 0);
		L_3 = T34_;
		{
			while (1) {
				tyArray__sMpvt1sOxOJ3LFGulnbeMQ T37_;
				NimStringDesc** T38_;
				if (!(i_3 < L_3)) goto LA36;
				ex_3 = (&m.hidden->data[i_3]);
				nimZeroMem((void*)T37_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
				T37_[0] = copyString(((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_41));
				T38_ = (NimStringDesc**)0;
				T38_ = X5BX5D___icZic_5604((&m.strings), (*ex_3).Field0);
				T37_[1] = copyString((*T38_));
				T37_[2] = copyString(((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_42));
				T37_[3] = dollar___systemZdollars_3(((NI) ((*ex_3).Field1)));
				echoBinSafe(T37_, 4);
				i_3 += ((NI) 1);
			} LA36: ;
		}
	}
	echoBinSafe(TM__mJObP0PRzfMjXxDpaIgosg_46, 1);
	{
		NI i_4;
		NI colontmp_;
		NI T40_;
		NI res;
		i_4 = (NI)0;
		colontmp_ = (NI)0;
		T40_ = ((m.syms ? m.syms->Sup.len : 0)-1);
		colontmp_ = T40_;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA42;
				i_4 = res;
				{
					tyArray__yt5VDPNtUGx9cBkOVakHwdQ T47_;
					NimStringDesc** T48_;
					if (!!((m.syms->data[i_4].name == ((NU32) 0)))) goto LA45_;
					nimZeroMem((void*)T47_, sizeof(tyArray__yt5VDPNtUGx9cBkOVakHwdQ));
					T47_[0] = copyString(((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_41));
					T48_ = (NimStringDesc**)0;
					T48_ = X5BX5D___icZic_5604((&m.strings), m.syms->data[i_4].name);
					T47_[1] = copyString((*T48_));
					T47_[2] = copyString(((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_42));
					T47_[3] = dollar___systemZdollars_3(i_4);
					T47_[4] = copyString(((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_48));
					T47_[5] = reprEnum((NI)m.syms->data[i_4].kind, (&NTItsymkind__sjiB9b9aO1FRPetW6gPYZbfw_));
					echoBinSafe(T47_, 6);
				}
				goto LA43_;
				LA45_: ;
				{
					tyArray__sMpvt1sOxOJ3LFGulnbeMQ T50_;
					nimZeroMem((void*)T50_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
					T50_[0] = copyString(((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_49));
					T50_[1] = dollar___systemZdollars_3(i_4);
					T50_[2] = copyString(((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_48));
					T50_[3] = reprEnum((NI)m.syms->data[i_4].kind, (&NTItsymkind__sjiB9b9aO1FRPetW6gPYZbfw_));
					echoBinSafe(T50_, 4);
				}
				LA43_: ;
				res += ((NI) 1);
			} LA42: ;
		}
	}
	nimZeroMem((void*)T51_, sizeof(tyArray__ucDUDWdKfioXQrN9bCbG29bg));
	T51_[0] = copyString(((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_50));
	T52_ = (m.syms ? m.syms->Sup.len : 0);
	T51_[1] = dollar___systemZdollars_3(T52_);
	T51_[2] = copyString(((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_51));
	T53_ = (m.types ? m.types->Sup.len : 0);
	T51_[3] = dollar___systemZdollars_3(T53_);
	T51_[4] = copyString(((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_52));
	T54_ = (m.topLevel.nodes ? m.topLevel.nodes->Sup.len : 0);
	T51_[5] = dollar___systemZdollars_3(T54_);
	T51_[6] = copyString(((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_53));
	T55_ = (m.bodies.nodes ? m.bodies.nodes->Sup.len : 0);
	T51_[7] = dollar___systemZdollars_3(T55_);
	T51_[8] = copyString(((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_54));
	T56_ = (NI)0;
	T56_ = len__icZic_9616(m.strings);
	T51_[9] = dollar___systemZdollars_3(T56_);
	T51_[10] = copyString(((NimStringDesc*) &TM__mJObP0PRzfMjXxDpaIgosg_55));
	T57_ = (NI)0;
	T57_ = len__icZic_9669(m.numbers);
	T51_[11] = dollar___systemZdollars_3(T57_);
	echoBinSafe(T51_, 12);
}
N_LIB_PRIVATE N_NIMCALL(void, atmicatsicdotnim_DatInit000)(void) {
static TNimNode* TM__mJObP0PRzfMjXxDpaIgosg_2_10[10];
static TNimNode* TM__mJObP0PRzfMjXxDpaIgosg_3_6[6];
NI TM__mJObP0PRzfMjXxDpaIgosg_5;
static char* NIM_CONST TM__mJObP0PRzfMjXxDpaIgosg_4[6] = {
"undefined", 
"storing", 
"loading", 
"loaded", 
"outdated", 
"stored"};
static TNimNode* TM__mJObP0PRzfMjXxDpaIgosg_6_28[28];
static TNimNode* TM__mJObP0PRzfMjXxDpaIgosg_7_2[2];
static TNimNode* TM__mJObP0PRzfMjXxDpaIgosg_8_2[2];
static TNimNode* TM__mJObP0PRzfMjXxDpaIgosg_9_2[2];
static TNimNode* TM__mJObP0PRzfMjXxDpaIgosg_10_2[2];
static TNimNode* TM__mJObP0PRzfMjXxDpaIgosg_11_2[2];
static TNimNode* TM__mJObP0PRzfMjXxDpaIgosg_12_3[3];
static TNimNode* TM__mJObP0PRzfMjXxDpaIgosg_13_3[3];
static TNimNode* TM__mJObP0PRzfMjXxDpaIgosg_14_2[2];
NI TM__mJObP0PRzfMjXxDpaIgosg_16;
static char* NIM_CONST TM__mJObP0PRzfMjXxDpaIgosg_15[2] = {
"HasDatInitProc", 
"HasModuleInitProc"};
static TNimNode* TM__mJObP0PRzfMjXxDpaIgosg_17_2[2];
static TNimNode* TM__mJObP0PRzfMjXxDpaIgosg_18_2[2];
static TNimNode* TM__mJObP0PRzfMjXxDpaIgosg_19_5[5];
static TNimNode* TM__mJObP0PRzfMjXxDpaIgosg_20_2[2];
static TNimNode* TM__mJObP0PRzfMjXxDpaIgosg_21_3[3];
static TNimNode* TM__mJObP0PRzfMjXxDpaIgosg_22_9[9];
static TNimNode* TM__mJObP0PRzfMjXxDpaIgosg_23_2[2];
static TNimNode* TM__mJObP0PRzfMjXxDpaIgosg_24_3[3];
static TNimNode* TM__mJObP0PRzfMjXxDpaIgosg_35_5[5];
static TNimNode TM__mJObP0PRzfMjXxDpaIgosg_0[116];
NTIloadedmodule__fihS6xbKhtLC0fhM28Cpeg_.size = sizeof(tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg);
NTIloadedmodule__fihS6xbKhtLC0fhM28Cpeg_.align = NIM_ALIGNOF(tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg);
NTIloadedmodule__fihS6xbKhtLC0fhM28Cpeg_.kind = 18;
NTIloadedmodule__fihS6xbKhtLC0fhM28Cpeg_.base = 0;
NTIloadedmodule__fihS6xbKhtLC0fhM28Cpeg_.flags = 2;
TM__mJObP0PRzfMjXxDpaIgosg_2_10[0] = &TM__mJObP0PRzfMjXxDpaIgosg_0[1];
NTImodulestatus__K6X1Kd9cJ9a0hyG1Twv69bMNg_.size = sizeof(tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg);
NTImodulestatus__K6X1Kd9cJ9a0hyG1Twv69bMNg_.align = NIM_ALIGNOF(tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg);
NTImodulestatus__K6X1Kd9cJ9a0hyG1Twv69bMNg_.kind = 14;
NTImodulestatus__K6X1Kd9cJ9a0hyG1Twv69bMNg_.base = 0;
NTImodulestatus__K6X1Kd9cJ9a0hyG1Twv69bMNg_.flags = 3;
for (TM__mJObP0PRzfMjXxDpaIgosg_5 = 0; TM__mJObP0PRzfMjXxDpaIgosg_5 < 6; TM__mJObP0PRzfMjXxDpaIgosg_5++) {
TM__mJObP0PRzfMjXxDpaIgosg_0[TM__mJObP0PRzfMjXxDpaIgosg_5+2].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[TM__mJObP0PRzfMjXxDpaIgosg_5+2].offset = TM__mJObP0PRzfMjXxDpaIgosg_5;
TM__mJObP0PRzfMjXxDpaIgosg_0[TM__mJObP0PRzfMjXxDpaIgosg_5+2].name = TM__mJObP0PRzfMjXxDpaIgosg_4[TM__mJObP0PRzfMjXxDpaIgosg_5];
TM__mJObP0PRzfMjXxDpaIgosg_3_6[TM__mJObP0PRzfMjXxDpaIgosg_5] = &TM__mJObP0PRzfMjXxDpaIgosg_0[TM__mJObP0PRzfMjXxDpaIgosg_5+2];
}
TM__mJObP0PRzfMjXxDpaIgosg_0[8].len = 6; TM__mJObP0PRzfMjXxDpaIgosg_0[8].kind = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[8].sons = &TM__mJObP0PRzfMjXxDpaIgosg_3_6[0];
NTImodulestatus__K6X1Kd9cJ9a0hyG1Twv69bMNg_.node = &TM__mJObP0PRzfMjXxDpaIgosg_0[8];
TM__mJObP0PRzfMjXxDpaIgosg_0[1].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[1].offset = offsetof(tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg, status);
TM__mJObP0PRzfMjXxDpaIgosg_0[1].typ = (&NTImodulestatus__K6X1Kd9cJ9a0hyG1Twv69bMNg_);
TM__mJObP0PRzfMjXxDpaIgosg_0[1].name = "status";
TM__mJObP0PRzfMjXxDpaIgosg_2_10[1] = &TM__mJObP0PRzfMjXxDpaIgosg_0[9];
TM__mJObP0PRzfMjXxDpaIgosg_0[9].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[9].offset = offsetof(tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg, symsInit);
TM__mJObP0PRzfMjXxDpaIgosg_0[9].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__mJObP0PRzfMjXxDpaIgosg_0[9].name = "symsInit";
TM__mJObP0PRzfMjXxDpaIgosg_2_10[2] = &TM__mJObP0PRzfMjXxDpaIgosg_0[10];
TM__mJObP0PRzfMjXxDpaIgosg_0[10].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[10].offset = offsetof(tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg, typesInit);
TM__mJObP0PRzfMjXxDpaIgosg_0[10].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__mJObP0PRzfMjXxDpaIgosg_0[10].name = "typesInit";
TM__mJObP0PRzfMjXxDpaIgosg_2_10[3] = &TM__mJObP0PRzfMjXxDpaIgosg_0[11];
TM__mJObP0PRzfMjXxDpaIgosg_0[11].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[11].offset = offsetof(tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg, loadedButAliveSetChanged);
TM__mJObP0PRzfMjXxDpaIgosg_0[11].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__mJObP0PRzfMjXxDpaIgosg_0[11].name = "loadedButAliveSetChanged";
TM__mJObP0PRzfMjXxDpaIgosg_2_10[4] = &TM__mJObP0PRzfMjXxDpaIgosg_0[12];
NTIpackedmodule__Lx6uQ9baEALysaHmfFGXw9ag_.size = sizeof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag);
NTIpackedmodule__Lx6uQ9baEALysaHmfFGXw9ag_.align = NIM_ALIGNOF(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag);
NTIpackedmodule__Lx6uQ9baEALysaHmfFGXw9ag_.kind = 18;
NTIpackedmodule__Lx6uQ9baEALysaHmfFGXw9ag_.base = 0;
NTIpackedmodule__Lx6uQ9baEALysaHmfFGXw9ag_.flags = 2;
TM__mJObP0PRzfMjXxDpaIgosg_6_28[0] = &TM__mJObP0PRzfMjXxDpaIgosg_0[14];
TM__mJObP0PRzfMjXxDpaIgosg_0[14].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[14].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, definedSymbols);
TM__mJObP0PRzfMjXxDpaIgosg_0[14].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__mJObP0PRzfMjXxDpaIgosg_0[14].name = "definedSymbols";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[1] = &TM__mJObP0PRzfMjXxDpaIgosg_0[15];
TM__mJObP0PRzfMjXxDpaIgosg_0[15].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[15].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, moduleFlags);
TM__mJObP0PRzfMjXxDpaIgosg_0[15].typ = (&NTItsymflags__CvS9awV8iSOts9a8vqMf0pbQ_);
TM__mJObP0PRzfMjXxDpaIgosg_0[15].name = "moduleFlags";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[2] = &TM__mJObP0PRzfMjXxDpaIgosg_0[16];
NTILlitid_stringT__0q9cmhneJEKnQERTpXXdz6Q_.size = sizeof(tyTuple__0q9cmhneJEKnQERTpXXdz6Q);
NTILlitid_stringT__0q9cmhneJEKnQERTpXXdz6Q_.align = NIM_ALIGNOF(tyTuple__0q9cmhneJEKnQERTpXXdz6Q);
NTILlitid_stringT__0q9cmhneJEKnQERTpXXdz6Q_.kind = 18;
NTILlitid_stringT__0q9cmhneJEKnQERTpXXdz6Q_.base = 0;
NTILlitid_stringT__0q9cmhneJEKnQERTpXXdz6Q_.flags = 2;
TM__mJObP0PRzfMjXxDpaIgosg_7_2[0] = &TM__mJObP0PRzfMjXxDpaIgosg_0[18];
TM__mJObP0PRzfMjXxDpaIgosg_0[18].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[18].offset = offsetof(tyTuple__0q9cmhneJEKnQERTpXXdz6Q, Field0);
TM__mJObP0PRzfMjXxDpaIgosg_0[18].typ = (&NTIuint5150__JrFyJbYm9b5I4hJ9cWDqvfYA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[18].name = "Field0";
TM__mJObP0PRzfMjXxDpaIgosg_7_2[1] = &TM__mJObP0PRzfMjXxDpaIgosg_0[19];
TM__mJObP0PRzfMjXxDpaIgosg_0[19].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[19].offset = offsetof(tyTuple__0q9cmhneJEKnQERTpXXdz6Q, Field1);
TM__mJObP0PRzfMjXxDpaIgosg_0[19].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__mJObP0PRzfMjXxDpaIgosg_0[19].name = "Field1";
TM__mJObP0PRzfMjXxDpaIgosg_0[17].len = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[17].kind = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[17].sons = &TM__mJObP0PRzfMjXxDpaIgosg_7_2[0];
NTILlitid_stringT__0q9cmhneJEKnQERTpXXdz6Q_.node = &TM__mJObP0PRzfMjXxDpaIgosg_0[17];
NTIseqLLlitid_stringTT__PXIzfWocnrafGz5p3CP5LA_.size = sizeof(tySequence__PXIzfWocnrafGz5p3CP5LA*);
NTIseqLLlitid_stringTT__PXIzfWocnrafGz5p3CP5LA_.align = NIM_ALIGNOF(tySequence__PXIzfWocnrafGz5p3CP5LA*);
NTIseqLLlitid_stringTT__PXIzfWocnrafGz5p3CP5LA_.kind = 24;
NTIseqLLlitid_stringTT__PXIzfWocnrafGz5p3CP5LA_.base = (&NTILlitid_stringT__0q9cmhneJEKnQERTpXXdz6Q_);
NTIseqLLlitid_stringTT__PXIzfWocnrafGz5p3CP5LA_.flags = 2;
NTIseqLLlitid_stringTT__PXIzfWocnrafGz5p3CP5LA_.marker = Marker_tySequence__PXIzfWocnrafGz5p3CP5LA;
TM__mJObP0PRzfMjXxDpaIgosg_0[16].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[16].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, includes);
TM__mJObP0PRzfMjXxDpaIgosg_0[16].typ = (&NTIseqLLlitid_stringTT__PXIzfWocnrafGz5p3CP5LA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[16].name = "includes";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[3] = &TM__mJObP0PRzfMjXxDpaIgosg_0[20];
NTIseqLlitidT__9bAGqSvkAaFL9bWjsEPslrFA_.size = sizeof(tySequence__9bAGqSvkAaFL9bWjsEPslrFA*);
NTIseqLlitidT__9bAGqSvkAaFL9bWjsEPslrFA_.align = NIM_ALIGNOF(tySequence__9bAGqSvkAaFL9bWjsEPslrFA*);
NTIseqLlitidT__9bAGqSvkAaFL9bWjsEPslrFA_.kind = 24;
NTIseqLlitidT__9bAGqSvkAaFL9bWjsEPslrFA_.base = (&NTIuint5150__JrFyJbYm9b5I4hJ9cWDqvfYA_);
NTIseqLlitidT__9bAGqSvkAaFL9bWjsEPslrFA_.flags = 2;
NTIseqLlitidT__9bAGqSvkAaFL9bWjsEPslrFA_.marker = Marker_tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
TM__mJObP0PRzfMjXxDpaIgosg_0[20].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[20].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, imports);
TM__mJObP0PRzfMjXxDpaIgosg_0[20].typ = (&NTIseqLlitidT__9bAGqSvkAaFL9bWjsEPslrFA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[20].name = "imports";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[4] = &TM__mJObP0PRzfMjXxDpaIgosg_0[21];
TM__mJObP0PRzfMjXxDpaIgosg_0[21].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[21].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, toReplay);
TM__mJObP0PRzfMjXxDpaIgosg_0[21].typ = (&NTIpackedtree__om9aqqVmbmBPgd8MeBkGtqg_);
TM__mJObP0PRzfMjXxDpaIgosg_0[21].name = "toReplay";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[5] = &TM__mJObP0PRzfMjXxDpaIgosg_0[22];
TM__mJObP0PRzfMjXxDpaIgosg_0[22].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[22].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, topLevel);
TM__mJObP0PRzfMjXxDpaIgosg_0[22].typ = (&NTIpackedtree__om9aqqVmbmBPgd8MeBkGtqg_);
TM__mJObP0PRzfMjXxDpaIgosg_0[22].name = "topLevel";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[6] = &TM__mJObP0PRzfMjXxDpaIgosg_0[23];
TM__mJObP0PRzfMjXxDpaIgosg_0[23].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[23].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, bodies);
TM__mJObP0PRzfMjXxDpaIgosg_0[23].typ = (&NTIpackedtree__om9aqqVmbmBPgd8MeBkGtqg_);
TM__mJObP0PRzfMjXxDpaIgosg_0[23].name = "bodies";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[7] = &TM__mJObP0PRzfMjXxDpaIgosg_0[24];
NTILlitid_int5150T__Izx9aRSX9a0diDXD84jOS9aMQ_.size = sizeof(tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ);
NTILlitid_int5150T__Izx9aRSX9a0diDXD84jOS9aMQ_.align = NIM_ALIGNOF(tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ);
NTILlitid_int5150T__Izx9aRSX9a0diDXD84jOS9aMQ_.kind = 18;
NTILlitid_int5150T__Izx9aRSX9a0diDXD84jOS9aMQ_.base = 0;
NTILlitid_int5150T__Izx9aRSX9a0diDXD84jOS9aMQ_.flags = 3;
TM__mJObP0PRzfMjXxDpaIgosg_8_2[0] = &TM__mJObP0PRzfMjXxDpaIgosg_0[26];
TM__mJObP0PRzfMjXxDpaIgosg_0[26].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[26].offset = offsetof(tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ, Field0);
TM__mJObP0PRzfMjXxDpaIgosg_0[26].typ = (&NTIuint5150__JrFyJbYm9b5I4hJ9cWDqvfYA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[26].name = "Field0";
TM__mJObP0PRzfMjXxDpaIgosg_8_2[1] = &TM__mJObP0PRzfMjXxDpaIgosg_0[27];
TM__mJObP0PRzfMjXxDpaIgosg_0[27].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[27].offset = offsetof(tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ, Field1);
TM__mJObP0PRzfMjXxDpaIgosg_0[27].typ = (&NTIint5150__sVg18TP9cLifHyygRe9cro9aA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[27].name = "Field1";
TM__mJObP0PRzfMjXxDpaIgosg_0[25].len = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[25].kind = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[25].sons = &TM__mJObP0PRzfMjXxDpaIgosg_8_2[0];
NTILlitid_int5150T__Izx9aRSX9a0diDXD84jOS9aMQ_.node = &TM__mJObP0PRzfMjXxDpaIgosg_0[25];
NTIseqLLlitid_int5150TT__b89aLriiJnVTD186H6zNIgg_.size = sizeof(tySequence__b89aLriiJnVTD186H6zNIgg*);
NTIseqLLlitid_int5150TT__b89aLriiJnVTD186H6zNIgg_.align = NIM_ALIGNOF(tySequence__b89aLriiJnVTD186H6zNIgg*);
NTIseqLLlitid_int5150TT__b89aLriiJnVTD186H6zNIgg_.kind = 24;
NTIseqLLlitid_int5150TT__b89aLriiJnVTD186H6zNIgg_.base = (&NTILlitid_int5150T__Izx9aRSX9a0diDXD84jOS9aMQ_);
NTIseqLLlitid_int5150TT__b89aLriiJnVTD186H6zNIgg_.flags = 2;
NTIseqLLlitid_int5150TT__b89aLriiJnVTD186H6zNIgg_.marker = Marker_tySequence__b89aLriiJnVTD186H6zNIgg;
TM__mJObP0PRzfMjXxDpaIgosg_0[24].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[24].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, exports);
TM__mJObP0PRzfMjXxDpaIgosg_0[24].typ = (&NTIseqLLlitid_int5150TT__b89aLriiJnVTD186H6zNIgg_);
TM__mJObP0PRzfMjXxDpaIgosg_0[24].name = "exports";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[8] = &TM__mJObP0PRzfMjXxDpaIgosg_0[28];
TM__mJObP0PRzfMjXxDpaIgosg_0[28].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[28].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, hidden);
TM__mJObP0PRzfMjXxDpaIgosg_0[28].typ = (&NTIseqLLlitid_int5150TT__b89aLriiJnVTD186H6zNIgg_);
TM__mJObP0PRzfMjXxDpaIgosg_0[28].name = "hidden";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[9] = &TM__mJObP0PRzfMjXxDpaIgosg_0[29];
NTILlitid_packeditemidT__PsEhl3dzznmmJiLAuIXZOg_.size = sizeof(tyTuple__PsEhl3dzznmmJiLAuIXZOg);
NTILlitid_packeditemidT__PsEhl3dzznmmJiLAuIXZOg_.align = NIM_ALIGNOF(tyTuple__PsEhl3dzznmmJiLAuIXZOg);
NTILlitid_packeditemidT__PsEhl3dzznmmJiLAuIXZOg_.kind = 18;
NTILlitid_packeditemidT__PsEhl3dzznmmJiLAuIXZOg_.base = 0;
NTILlitid_packeditemidT__PsEhl3dzznmmJiLAuIXZOg_.flags = 3;
TM__mJObP0PRzfMjXxDpaIgosg_9_2[0] = &TM__mJObP0PRzfMjXxDpaIgosg_0[31];
TM__mJObP0PRzfMjXxDpaIgosg_0[31].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[31].offset = offsetof(tyTuple__PsEhl3dzznmmJiLAuIXZOg, Field0);
TM__mJObP0PRzfMjXxDpaIgosg_0[31].typ = (&NTIuint5150__JrFyJbYm9b5I4hJ9cWDqvfYA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[31].name = "Field0";
TM__mJObP0PRzfMjXxDpaIgosg_9_2[1] = &TM__mJObP0PRzfMjXxDpaIgosg_0[32];
TM__mJObP0PRzfMjXxDpaIgosg_0[32].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[32].offset = offsetof(tyTuple__PsEhl3dzznmmJiLAuIXZOg, Field1);
TM__mJObP0PRzfMjXxDpaIgosg_0[32].typ = (&NTIpackeditemid__QkYBSICiQaMI6SmH4FJVoQ_);
TM__mJObP0PRzfMjXxDpaIgosg_0[32].name = "Field1";
TM__mJObP0PRzfMjXxDpaIgosg_0[30].len = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[30].kind = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[30].sons = &TM__mJObP0PRzfMjXxDpaIgosg_9_2[0];
NTILlitid_packeditemidT__PsEhl3dzznmmJiLAuIXZOg_.node = &TM__mJObP0PRzfMjXxDpaIgosg_0[30];
NTIseqLLlitid_packeditemidTT__wE9cZkGC9cv7Iz9ckZOIyaW9aw_.size = sizeof(tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw*);
NTIseqLLlitid_packeditemidTT__wE9cZkGC9cv7Iz9ckZOIyaW9aw_.align = NIM_ALIGNOF(tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw*);
NTIseqLLlitid_packeditemidTT__wE9cZkGC9cv7Iz9ckZOIyaW9aw_.kind = 24;
NTIseqLLlitid_packeditemidTT__wE9cZkGC9cv7Iz9ckZOIyaW9aw_.base = (&NTILlitid_packeditemidT__PsEhl3dzznmmJiLAuIXZOg_);
NTIseqLLlitid_packeditemidTT__wE9cZkGC9cv7Iz9ckZOIyaW9aw_.flags = 2;
NTIseqLLlitid_packeditemidTT__wE9cZkGC9cv7Iz9ckZOIyaW9aw_.marker = Marker_tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw;
TM__mJObP0PRzfMjXxDpaIgosg_0[29].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[29].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, reexports);
TM__mJObP0PRzfMjXxDpaIgosg_0[29].typ = (&NTIseqLLlitid_packeditemidTT__wE9cZkGC9cv7Iz9ckZOIyaW9aw_);
TM__mJObP0PRzfMjXxDpaIgosg_0[29].name = "reexports";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[10] = &TM__mJObP0PRzfMjXxDpaIgosg_0[33];
TM__mJObP0PRzfMjXxDpaIgosg_0[33].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[33].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, compilerProcs);
TM__mJObP0PRzfMjXxDpaIgosg_0[33].typ = (&NTIseqLLlitid_int5150TT__b89aLriiJnVTD186H6zNIgg_);
TM__mJObP0PRzfMjXxDpaIgosg_0[33].name = "compilerProcs";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[11] = &TM__mJObP0PRzfMjXxDpaIgosg_0[34];
NTIseqLint5150T__48JTohSgTy339bRxHzUD8KA_.size = sizeof(tySequence__48JTohSgTy339bRxHzUD8KA*);
NTIseqLint5150T__48JTohSgTy339bRxHzUD8KA_.align = NIM_ALIGNOF(tySequence__48JTohSgTy339bRxHzUD8KA*);
NTIseqLint5150T__48JTohSgTy339bRxHzUD8KA_.kind = 24;
NTIseqLint5150T__48JTohSgTy339bRxHzUD8KA_.base = (&NTIint5150__sVg18TP9cLifHyygRe9cro9aA_);
NTIseqLint5150T__48JTohSgTy339bRxHzUD8KA_.flags = 2;
NTIseqLint5150T__48JTohSgTy339bRxHzUD8KA_.marker = Marker_tySequence__48JTohSgTy339bRxHzUD8KA;
TM__mJObP0PRzfMjXxDpaIgosg_0[34].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[34].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, converters);
TM__mJObP0PRzfMjXxDpaIgosg_0[34].typ = (&NTIseqLint5150T__48JTohSgTy339bRxHzUD8KA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[34].name = "converters";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[12] = &TM__mJObP0PRzfMjXxDpaIgosg_0[35];
TM__mJObP0PRzfMjXxDpaIgosg_0[35].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[35].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, methods);
TM__mJObP0PRzfMjXxDpaIgosg_0[35].typ = (&NTIseqLint5150T__48JTohSgTy339bRxHzUD8KA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[35].name = "methods";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[13] = &TM__mJObP0PRzfMjXxDpaIgosg_0[36];
TM__mJObP0PRzfMjXxDpaIgosg_0[36].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[36].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, trmacros);
TM__mJObP0PRzfMjXxDpaIgosg_0[36].typ = (&NTIseqLint5150T__48JTohSgTy339bRxHzUD8KA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[36].name = "trmacros";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[14] = &TM__mJObP0PRzfMjXxDpaIgosg_0[37];
TM__mJObP0PRzfMjXxDpaIgosg_0[37].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[37].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, pureEnums);
TM__mJObP0PRzfMjXxDpaIgosg_0[37].typ = (&NTIseqLint5150T__48JTohSgTy339bRxHzUD8KA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[37].name = "pureEnums";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[15] = &TM__mJObP0PRzfMjXxDpaIgosg_0[38];
NTILpackeditemid_packedlineinfoT__Dg3ILQdzHFjrYRx6Xwbq3w_.size = sizeof(tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w);
NTILpackeditemid_packedlineinfoT__Dg3ILQdzHFjrYRx6Xwbq3w_.align = NIM_ALIGNOF(tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w);
NTILpackeditemid_packedlineinfoT__Dg3ILQdzHFjrYRx6Xwbq3w_.kind = 18;
NTILpackeditemid_packedlineinfoT__Dg3ILQdzHFjrYRx6Xwbq3w_.base = 0;
NTILpackeditemid_packedlineinfoT__Dg3ILQdzHFjrYRx6Xwbq3w_.flags = 3;
TM__mJObP0PRzfMjXxDpaIgosg_10_2[0] = &TM__mJObP0PRzfMjXxDpaIgosg_0[40];
TM__mJObP0PRzfMjXxDpaIgosg_0[40].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[40].offset = offsetof(tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w, Field0);
TM__mJObP0PRzfMjXxDpaIgosg_0[40].typ = (&NTIpackeditemid__QkYBSICiQaMI6SmH4FJVoQ_);
TM__mJObP0PRzfMjXxDpaIgosg_0[40].name = "Field0";
TM__mJObP0PRzfMjXxDpaIgosg_10_2[1] = &TM__mJObP0PRzfMjXxDpaIgosg_0[41];
TM__mJObP0PRzfMjXxDpaIgosg_0[41].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[41].offset = offsetof(tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w, Field1);
TM__mJObP0PRzfMjXxDpaIgosg_0[41].typ = (&NTIpackedlineinfo__wqhF27DCtLcrB2XHUZKKiA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[41].name = "Field1";
TM__mJObP0PRzfMjXxDpaIgosg_0[39].len = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[39].kind = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[39].sons = &TM__mJObP0PRzfMjXxDpaIgosg_10_2[0];
NTILpackeditemid_packedlineinfoT__Dg3ILQdzHFjrYRx6Xwbq3w_.node = &TM__mJObP0PRzfMjXxDpaIgosg_0[39];
NTIseqLLpackeditemid_packedlineinfoTT__QnmOtn1Iv4LvxOXoMn8Rbg_.size = sizeof(tySequence__QnmOtn1Iv4LvxOXoMn8Rbg*);
NTIseqLLpackeditemid_packedlineinfoTT__QnmOtn1Iv4LvxOXoMn8Rbg_.align = NIM_ALIGNOF(tySequence__QnmOtn1Iv4LvxOXoMn8Rbg*);
NTIseqLLpackeditemid_packedlineinfoTT__QnmOtn1Iv4LvxOXoMn8Rbg_.kind = 24;
NTIseqLLpackeditemid_packedlineinfoTT__QnmOtn1Iv4LvxOXoMn8Rbg_.base = (&NTILpackeditemid_packedlineinfoT__Dg3ILQdzHFjrYRx6Xwbq3w_);
NTIseqLLpackeditemid_packedlineinfoTT__QnmOtn1Iv4LvxOXoMn8Rbg_.flags = 2;
NTIseqLLpackeditemid_packedlineinfoTT__QnmOtn1Iv4LvxOXoMn8Rbg_.marker = Marker_tySequence__QnmOtn1Iv4LvxOXoMn8Rbg;
TM__mJObP0PRzfMjXxDpaIgosg_0[38].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[38].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, macroUsages);
TM__mJObP0PRzfMjXxDpaIgosg_0[38].typ = (&NTIseqLLpackeditemid_packedlineinfoTT__QnmOtn1Iv4LvxOXoMn8Rbg_);
TM__mJObP0PRzfMjXxDpaIgosg_0[38].name = "macroUsages";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[16] = &TM__mJObP0PRzfMjXxDpaIgosg_0[42];
NTILpackeditemid_packeditemidT__Db8CrQifKGIsKc3w71w7Lw_.size = sizeof(tyTuple__Db8CrQifKGIsKc3w71w7Lw);
NTILpackeditemid_packeditemidT__Db8CrQifKGIsKc3w71w7Lw_.align = NIM_ALIGNOF(tyTuple__Db8CrQifKGIsKc3w71w7Lw);
NTILpackeditemid_packeditemidT__Db8CrQifKGIsKc3w71w7Lw_.kind = 18;
NTILpackeditemid_packeditemidT__Db8CrQifKGIsKc3w71w7Lw_.base = 0;
NTILpackeditemid_packeditemidT__Db8CrQifKGIsKc3w71w7Lw_.flags = 3;
TM__mJObP0PRzfMjXxDpaIgosg_11_2[0] = &TM__mJObP0PRzfMjXxDpaIgosg_0[44];
TM__mJObP0PRzfMjXxDpaIgosg_0[44].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[44].offset = offsetof(tyTuple__Db8CrQifKGIsKc3w71w7Lw, Field0);
TM__mJObP0PRzfMjXxDpaIgosg_0[44].typ = (&NTIpackeditemid__QkYBSICiQaMI6SmH4FJVoQ_);
TM__mJObP0PRzfMjXxDpaIgosg_0[44].name = "Field0";
TM__mJObP0PRzfMjXxDpaIgosg_11_2[1] = &TM__mJObP0PRzfMjXxDpaIgosg_0[45];
TM__mJObP0PRzfMjXxDpaIgosg_0[45].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[45].offset = offsetof(tyTuple__Db8CrQifKGIsKc3w71w7Lw, Field1);
TM__mJObP0PRzfMjXxDpaIgosg_0[45].typ = (&NTIpackeditemid__QkYBSICiQaMI6SmH4FJVoQ_);
TM__mJObP0PRzfMjXxDpaIgosg_0[45].name = "Field1";
TM__mJObP0PRzfMjXxDpaIgosg_0[43].len = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[43].kind = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[43].sons = &TM__mJObP0PRzfMjXxDpaIgosg_11_2[0];
NTILpackeditemid_packeditemidT__Db8CrQifKGIsKc3w71w7Lw_.node = &TM__mJObP0PRzfMjXxDpaIgosg_0[43];
NTIseqLLpackeditemid_packeditemidTT__oKtVqsc9bQVCNyrijELM4OQ_.size = sizeof(tySequence__oKtVqsc9bQVCNyrijELM4OQ*);
NTIseqLLpackeditemid_packeditemidTT__oKtVqsc9bQVCNyrijELM4OQ_.align = NIM_ALIGNOF(tySequence__oKtVqsc9bQVCNyrijELM4OQ*);
NTIseqLLpackeditemid_packeditemidTT__oKtVqsc9bQVCNyrijELM4OQ_.kind = 24;
NTIseqLLpackeditemid_packeditemidTT__oKtVqsc9bQVCNyrijELM4OQ_.base = (&NTILpackeditemid_packeditemidT__Db8CrQifKGIsKc3w71w7Lw_);
NTIseqLLpackeditemid_packeditemidTT__oKtVqsc9bQVCNyrijELM4OQ_.flags = 2;
NTIseqLLpackeditemid_packeditemidTT__oKtVqsc9bQVCNyrijELM4OQ_.marker = Marker_tySequence__oKtVqsc9bQVCNyrijELM4OQ;
TM__mJObP0PRzfMjXxDpaIgosg_0[42].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[42].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, typeInstCache);
TM__mJObP0PRzfMjXxDpaIgosg_0[42].typ = (&NTIseqLLpackeditemid_packeditemidTT__oKtVqsc9bQVCNyrijELM4OQ_);
TM__mJObP0PRzfMjXxDpaIgosg_0[42].name = "typeInstCache";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[17] = &TM__mJObP0PRzfMjXxDpaIgosg_0[46];
NTIseqLpackedinstantiationT__qy6Iwdy00wN560qud54HTg_.size = sizeof(tySequence__qy6Iwdy00wN560qud54HTg*);
NTIseqLpackedinstantiationT__qy6Iwdy00wN560qud54HTg_.align = NIM_ALIGNOF(tySequence__qy6Iwdy00wN560qud54HTg*);
NTIseqLpackedinstantiationT__qy6Iwdy00wN560qud54HTg_.kind = 24;
NTIseqLpackedinstantiationT__qy6Iwdy00wN560qud54HTg_.base = (&NTIpackedinstantiation__wt9ao6lqcInu9aOmUoxgkWcg_);
NTIseqLpackedinstantiationT__qy6Iwdy00wN560qud54HTg_.flags = 2;
NTIseqLpackedinstantiationT__qy6Iwdy00wN560qud54HTg_.marker = Marker_tySequence__qy6Iwdy00wN560qud54HTg;
TM__mJObP0PRzfMjXxDpaIgosg_0[46].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[46].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, procInstCache);
TM__mJObP0PRzfMjXxDpaIgosg_0[46].typ = (&NTIseqLpackedinstantiationT__qy6Iwdy00wN560qud54HTg_);
TM__mJObP0PRzfMjXxDpaIgosg_0[46].name = "procInstCache";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[18] = &TM__mJObP0PRzfMjXxDpaIgosg_0[47];
NTILttypeattachedop_packeditemid_packeditemidT__Q9cwWJO3ddVfos2xI7N9cHHQ_.size = sizeof(tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ);
NTILttypeattachedop_packeditemid_packeditemidT__Q9cwWJO3ddVfos2xI7N9cHHQ_.align = NIM_ALIGNOF(tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ);
NTILttypeattachedop_packeditemid_packeditemidT__Q9cwWJO3ddVfos2xI7N9cHHQ_.kind = 18;
NTILttypeattachedop_packeditemid_packeditemidT__Q9cwWJO3ddVfos2xI7N9cHHQ_.base = 0;
NTILttypeattachedop_packeditemid_packeditemidT__Q9cwWJO3ddVfos2xI7N9cHHQ_.flags = 3;
TM__mJObP0PRzfMjXxDpaIgosg_12_3[0] = &TM__mJObP0PRzfMjXxDpaIgosg_0[49];
TM__mJObP0PRzfMjXxDpaIgosg_0[49].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[49].offset = offsetof(tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ, Field0);
TM__mJObP0PRzfMjXxDpaIgosg_0[49].typ = (&NTIttypeattachedop__0IDqFfYT9a3F5i6tmCmdORQ_);
TM__mJObP0PRzfMjXxDpaIgosg_0[49].name = "Field0";
TM__mJObP0PRzfMjXxDpaIgosg_12_3[1] = &TM__mJObP0PRzfMjXxDpaIgosg_0[50];
TM__mJObP0PRzfMjXxDpaIgosg_0[50].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[50].offset = offsetof(tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ, Field1);
TM__mJObP0PRzfMjXxDpaIgosg_0[50].typ = (&NTIpackeditemid__QkYBSICiQaMI6SmH4FJVoQ_);
TM__mJObP0PRzfMjXxDpaIgosg_0[50].name = "Field1";
TM__mJObP0PRzfMjXxDpaIgosg_12_3[2] = &TM__mJObP0PRzfMjXxDpaIgosg_0[51];
TM__mJObP0PRzfMjXxDpaIgosg_0[51].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[51].offset = offsetof(tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ, Field2);
TM__mJObP0PRzfMjXxDpaIgosg_0[51].typ = (&NTIpackeditemid__QkYBSICiQaMI6SmH4FJVoQ_);
TM__mJObP0PRzfMjXxDpaIgosg_0[51].name = "Field2";
TM__mJObP0PRzfMjXxDpaIgosg_0[48].len = 3; TM__mJObP0PRzfMjXxDpaIgosg_0[48].kind = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[48].sons = &TM__mJObP0PRzfMjXxDpaIgosg_12_3[0];
NTILttypeattachedop_packeditemid_packeditemidT__Q9cwWJO3ddVfos2xI7N9cHHQ_.node = &TM__mJObP0PRzfMjXxDpaIgosg_0[48];
NTIseqLLttypeattachedop_packeditemid_packeditemidTT__k67v9bwvvQDmS1ynyGGUbeQ_.size = sizeof(tySequence__k67v9bwvvQDmS1ynyGGUbeQ*);
NTIseqLLttypeattachedop_packeditemid_packeditemidTT__k67v9bwvvQDmS1ynyGGUbeQ_.align = NIM_ALIGNOF(tySequence__k67v9bwvvQDmS1ynyGGUbeQ*);
NTIseqLLttypeattachedop_packeditemid_packeditemidTT__k67v9bwvvQDmS1ynyGGUbeQ_.kind = 24;
NTIseqLLttypeattachedop_packeditemid_packeditemidTT__k67v9bwvvQDmS1ynyGGUbeQ_.base = (&NTILttypeattachedop_packeditemid_packeditemidT__Q9cwWJO3ddVfos2xI7N9cHHQ_);
NTIseqLLttypeattachedop_packeditemid_packeditemidTT__k67v9bwvvQDmS1ynyGGUbeQ_.flags = 2;
NTIseqLLttypeattachedop_packeditemid_packeditemidTT__k67v9bwvvQDmS1ynyGGUbeQ_.marker = Marker_tySequence__k67v9bwvvQDmS1ynyGGUbeQ;
TM__mJObP0PRzfMjXxDpaIgosg_0[47].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[47].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, attachedOps);
TM__mJObP0PRzfMjXxDpaIgosg_0[47].typ = (&NTIseqLLttypeattachedop_packeditemid_packeditemidTT__k67v9bwvvQDmS1ynyGGUbeQ_);
TM__mJObP0PRzfMjXxDpaIgosg_0[47].name = "attachedOps";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[19] = &TM__mJObP0PRzfMjXxDpaIgosg_0[52];
NTILpackeditemid_int_packeditemidT__FEYH9alRJhHD0uTKF2vnIqw_.size = sizeof(tyTuple__FEYH9alRJhHD0uTKF2vnIqw);
NTILpackeditemid_int_packeditemidT__FEYH9alRJhHD0uTKF2vnIqw_.align = NIM_ALIGNOF(tyTuple__FEYH9alRJhHD0uTKF2vnIqw);
NTILpackeditemid_int_packeditemidT__FEYH9alRJhHD0uTKF2vnIqw_.kind = 18;
NTILpackeditemid_int_packeditemidT__FEYH9alRJhHD0uTKF2vnIqw_.base = 0;
NTILpackeditemid_int_packeditemidT__FEYH9alRJhHD0uTKF2vnIqw_.flags = 3;
TM__mJObP0PRzfMjXxDpaIgosg_13_3[0] = &TM__mJObP0PRzfMjXxDpaIgosg_0[54];
TM__mJObP0PRzfMjXxDpaIgosg_0[54].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[54].offset = offsetof(tyTuple__FEYH9alRJhHD0uTKF2vnIqw, Field0);
TM__mJObP0PRzfMjXxDpaIgosg_0[54].typ = (&NTIpackeditemid__QkYBSICiQaMI6SmH4FJVoQ_);
TM__mJObP0PRzfMjXxDpaIgosg_0[54].name = "Field0";
TM__mJObP0PRzfMjXxDpaIgosg_13_3[1] = &TM__mJObP0PRzfMjXxDpaIgosg_0[55];
TM__mJObP0PRzfMjXxDpaIgosg_0[55].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[55].offset = offsetof(tyTuple__FEYH9alRJhHD0uTKF2vnIqw, Field1);
TM__mJObP0PRzfMjXxDpaIgosg_0[55].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[55].name = "Field1";
TM__mJObP0PRzfMjXxDpaIgosg_13_3[2] = &TM__mJObP0PRzfMjXxDpaIgosg_0[56];
TM__mJObP0PRzfMjXxDpaIgosg_0[56].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[56].offset = offsetof(tyTuple__FEYH9alRJhHD0uTKF2vnIqw, Field2);
TM__mJObP0PRzfMjXxDpaIgosg_0[56].typ = (&NTIpackeditemid__QkYBSICiQaMI6SmH4FJVoQ_);
TM__mJObP0PRzfMjXxDpaIgosg_0[56].name = "Field2";
TM__mJObP0PRzfMjXxDpaIgosg_0[53].len = 3; TM__mJObP0PRzfMjXxDpaIgosg_0[53].kind = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[53].sons = &TM__mJObP0PRzfMjXxDpaIgosg_13_3[0];
NTILpackeditemid_int_packeditemidT__FEYH9alRJhHD0uTKF2vnIqw_.node = &TM__mJObP0PRzfMjXxDpaIgosg_0[53];
NTIseqLLpackeditemid_int_packeditemidTT__cLsClAAfd0MKkoBQVyvdvw_.size = sizeof(tySequence__cLsClAAfd0MKkoBQVyvdvw*);
NTIseqLLpackeditemid_int_packeditemidTT__cLsClAAfd0MKkoBQVyvdvw_.align = NIM_ALIGNOF(tySequence__cLsClAAfd0MKkoBQVyvdvw*);
NTIseqLLpackeditemid_int_packeditemidTT__cLsClAAfd0MKkoBQVyvdvw_.kind = 24;
NTIseqLLpackeditemid_int_packeditemidTT__cLsClAAfd0MKkoBQVyvdvw_.base = (&NTILpackeditemid_int_packeditemidT__FEYH9alRJhHD0uTKF2vnIqw_);
NTIseqLLpackeditemid_int_packeditemidTT__cLsClAAfd0MKkoBQVyvdvw_.flags = 2;
NTIseqLLpackeditemid_int_packeditemidTT__cLsClAAfd0MKkoBQVyvdvw_.marker = Marker_tySequence__cLsClAAfd0MKkoBQVyvdvw;
TM__mJObP0PRzfMjXxDpaIgosg_0[52].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[52].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, methodsPerType);
TM__mJObP0PRzfMjXxDpaIgosg_0[52].typ = (&NTIseqLLpackeditemid_int_packeditemidTT__cLsClAAfd0MKkoBQVyvdvw_);
TM__mJObP0PRzfMjXxDpaIgosg_0[52].name = "methodsPerType";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[20] = &TM__mJObP0PRzfMjXxDpaIgosg_0[57];
TM__mJObP0PRzfMjXxDpaIgosg_0[57].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[57].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, enumToStringProcs);
TM__mJObP0PRzfMjXxDpaIgosg_0[57].typ = (&NTIseqLLpackeditemid_packeditemidTT__oKtVqsc9bQVCNyrijELM4OQ_);
TM__mJObP0PRzfMjXxDpaIgosg_0[57].name = "enumToStringProcs";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[21] = &TM__mJObP0PRzfMjXxDpaIgosg_0[58];
TM__mJObP0PRzfMjXxDpaIgosg_0[58].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[58].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, emittedTypeInfo);
TM__mJObP0PRzfMjXxDpaIgosg_0[58].typ = (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__mJObP0PRzfMjXxDpaIgosg_0[58].name = "emittedTypeInfo";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[22] = &TM__mJObP0PRzfMjXxDpaIgosg_0[59];
NTImodulebackendflag__1OX8mHZmOJcGSH2EQV6eCQ_.size = sizeof(tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ);
NTImodulebackendflag__1OX8mHZmOJcGSH2EQV6eCQ_.align = NIM_ALIGNOF(tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ);
NTImodulebackendflag__1OX8mHZmOJcGSH2EQV6eCQ_.kind = 14;
NTImodulebackendflag__1OX8mHZmOJcGSH2EQV6eCQ_.base = 0;
NTImodulebackendflag__1OX8mHZmOJcGSH2EQV6eCQ_.flags = 3;
for (TM__mJObP0PRzfMjXxDpaIgosg_16 = 0; TM__mJObP0PRzfMjXxDpaIgosg_16 < 2; TM__mJObP0PRzfMjXxDpaIgosg_16++) {
TM__mJObP0PRzfMjXxDpaIgosg_0[TM__mJObP0PRzfMjXxDpaIgosg_16+60].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[TM__mJObP0PRzfMjXxDpaIgosg_16+60].offset = TM__mJObP0PRzfMjXxDpaIgosg_16;
TM__mJObP0PRzfMjXxDpaIgosg_0[TM__mJObP0PRzfMjXxDpaIgosg_16+60].name = TM__mJObP0PRzfMjXxDpaIgosg_15[TM__mJObP0PRzfMjXxDpaIgosg_16];
TM__mJObP0PRzfMjXxDpaIgosg_14_2[TM__mJObP0PRzfMjXxDpaIgosg_16] = &TM__mJObP0PRzfMjXxDpaIgosg_0[TM__mJObP0PRzfMjXxDpaIgosg_16+60];
}
TM__mJObP0PRzfMjXxDpaIgosg_0[62].len = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[62].kind = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[62].sons = &TM__mJObP0PRzfMjXxDpaIgosg_14_2[0];
NTImodulebackendflag__1OX8mHZmOJcGSH2EQV6eCQ_.node = &TM__mJObP0PRzfMjXxDpaIgosg_0[62];
NTIsetLmodulebackendflagT__p8Pc9cQY1mbvJo9ccEZy9bYog_.size = sizeof(tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ);
NTIsetLmodulebackendflagT__p8Pc9cQY1mbvJo9ccEZy9bYog_.align = NIM_ALIGNOF(tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ);
NTIsetLmodulebackendflagT__p8Pc9cQY1mbvJo9ccEZy9bYog_.kind = 19;
NTIsetLmodulebackendflagT__p8Pc9cQY1mbvJo9ccEZy9bYog_.base = (&NTImodulebackendflag__1OX8mHZmOJcGSH2EQV6eCQ_);
NTIsetLmodulebackendflagT__p8Pc9cQY1mbvJo9ccEZy9bYog_.flags = 3;
TM__mJObP0PRzfMjXxDpaIgosg_0[63].len = 0; TM__mJObP0PRzfMjXxDpaIgosg_0[63].kind = 0;
NTIsetLmodulebackendflagT__p8Pc9cQY1mbvJo9ccEZy9bYog_.node = &TM__mJObP0PRzfMjXxDpaIgosg_0[63];
TM__mJObP0PRzfMjXxDpaIgosg_0[59].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[59].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, backendFlags);
TM__mJObP0PRzfMjXxDpaIgosg_0[59].typ = (&NTIsetLmodulebackendflagT__p8Pc9cQY1mbvJo9ccEZy9bYog_);
TM__mJObP0PRzfMjXxDpaIgosg_0[59].name = "backendFlags";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[23] = &TM__mJObP0PRzfMjXxDpaIgosg_0[64];
NTIseqLpackedsymT__q9bTuOB0JXh1iZ3CSGdRLbg_.size = sizeof(tySequence__q9bTuOB0JXh1iZ3CSGdRLbg*);
NTIseqLpackedsymT__q9bTuOB0JXh1iZ3CSGdRLbg_.align = NIM_ALIGNOF(tySequence__q9bTuOB0JXh1iZ3CSGdRLbg*);
NTIseqLpackedsymT__q9bTuOB0JXh1iZ3CSGdRLbg_.kind = 24;
NTIseqLpackedsymT__q9bTuOB0JXh1iZ3CSGdRLbg_.base = (&NTIpackedsym__fAjcBcJ2JPtzDDxyIN8WmA_);
NTIseqLpackedsymT__q9bTuOB0JXh1iZ3CSGdRLbg_.flags = 2;
NTIseqLpackedsymT__q9bTuOB0JXh1iZ3CSGdRLbg_.marker = Marker_tySequence__q9bTuOB0JXh1iZ3CSGdRLbg;
TM__mJObP0PRzfMjXxDpaIgosg_0[64].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[64].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, syms);
TM__mJObP0PRzfMjXxDpaIgosg_0[64].typ = (&NTIseqLpackedsymT__q9bTuOB0JXh1iZ3CSGdRLbg_);
TM__mJObP0PRzfMjXxDpaIgosg_0[64].name = "syms";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[24] = &TM__mJObP0PRzfMjXxDpaIgosg_0[65];
NTIseqLpackedtypeT__DPZr9aMyRppVlNZ9ajSyOZ9bw_.size = sizeof(tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw*);
NTIseqLpackedtypeT__DPZr9aMyRppVlNZ9ajSyOZ9bw_.align = NIM_ALIGNOF(tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw*);
NTIseqLpackedtypeT__DPZr9aMyRppVlNZ9ajSyOZ9bw_.kind = 24;
NTIseqLpackedtypeT__DPZr9aMyRppVlNZ9ajSyOZ9bw_.base = (&NTIpackedtype__MvipqCfEd9b9bJbbBPwsUOiw_);
NTIseqLpackedtypeT__DPZr9aMyRppVlNZ9ajSyOZ9bw_.flags = 2;
NTIseqLpackedtypeT__DPZr9aMyRppVlNZ9ajSyOZ9bw_.marker = Marker_tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw;
TM__mJObP0PRzfMjXxDpaIgosg_0[65].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[65].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, types);
TM__mJObP0PRzfMjXxDpaIgosg_0[65].typ = (&NTIseqLpackedtypeT__DPZr9aMyRppVlNZ9ajSyOZ9bw_);
TM__mJObP0PRzfMjXxDpaIgosg_0[65].name = "types";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[25] = &TM__mJObP0PRzfMjXxDpaIgosg_0[66];
NTIbitable__f1TRECC4Lgx6Suak6pB8oQ_.size = sizeof(tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ);
NTIbitable__f1TRECC4Lgx6Suak6pB8oQ_.align = NIM_ALIGNOF(tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ);
NTIbitable__f1TRECC4Lgx6Suak6pB8oQ_.kind = 18;
NTIbitable__f1TRECC4Lgx6Suak6pB8oQ_.base = 0;
NTIbitable__f1TRECC4Lgx6Suak6pB8oQ_.flags = 2;
TM__mJObP0PRzfMjXxDpaIgosg_17_2[0] = &TM__mJObP0PRzfMjXxDpaIgosg_0[68];
TM__mJObP0PRzfMjXxDpaIgosg_0[68].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[68].offset = offsetof(tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ, vals);
TM__mJObP0PRzfMjXxDpaIgosg_0[68].typ = (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__mJObP0PRzfMjXxDpaIgosg_0[68].name = "vals";
TM__mJObP0PRzfMjXxDpaIgosg_17_2[1] = &TM__mJObP0PRzfMjXxDpaIgosg_0[69];
TM__mJObP0PRzfMjXxDpaIgosg_0[69].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[69].offset = offsetof(tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ, keys);
TM__mJObP0PRzfMjXxDpaIgosg_0[69].typ = (&NTIseqLlitidT__9bAGqSvkAaFL9bWjsEPslrFA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[69].name = "keys";
TM__mJObP0PRzfMjXxDpaIgosg_0[67].len = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[67].kind = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[67].sons = &TM__mJObP0PRzfMjXxDpaIgosg_17_2[0];
NTIbitable__f1TRECC4Lgx6Suak6pB8oQ_.node = &TM__mJObP0PRzfMjXxDpaIgosg_0[67];
TM__mJObP0PRzfMjXxDpaIgosg_0[66].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[66].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, strings);
TM__mJObP0PRzfMjXxDpaIgosg_0[66].typ = (&NTIbitable__f1TRECC4Lgx6Suak6pB8oQ_);
TM__mJObP0PRzfMjXxDpaIgosg_0[66].name = "strings";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[26] = &TM__mJObP0PRzfMjXxDpaIgosg_0[70];
NTIbitable__YFXXoy9ajAIwHK4kQgVvjcw_.size = sizeof(tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw);
NTIbitable__YFXXoy9ajAIwHK4kQgVvjcw_.align = NIM_ALIGNOF(tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw);
NTIbitable__YFXXoy9ajAIwHK4kQgVvjcw_.kind = 18;
NTIbitable__YFXXoy9ajAIwHK4kQgVvjcw_.base = 0;
NTIbitable__YFXXoy9ajAIwHK4kQgVvjcw_.flags = 2;
TM__mJObP0PRzfMjXxDpaIgosg_18_2[0] = &TM__mJObP0PRzfMjXxDpaIgosg_0[72];
NTIseqLbiggestintT__IHUFRsFxZNv7YydiUO2esQ_.size = sizeof(tySequence__IHUFRsFxZNv7YydiUO2esQ*);
NTIseqLbiggestintT__IHUFRsFxZNv7YydiUO2esQ_.align = NIM_ALIGNOF(tySequence__IHUFRsFxZNv7YydiUO2esQ*);
NTIseqLbiggestintT__IHUFRsFxZNv7YydiUO2esQ_.kind = 24;
NTIseqLbiggestintT__IHUFRsFxZNv7YydiUO2esQ_.base = (&NTIbiggestint__Aav8dQoMlCFnZRxA0IhTHQ_);
NTIseqLbiggestintT__IHUFRsFxZNv7YydiUO2esQ_.flags = 2;
NTIseqLbiggestintT__IHUFRsFxZNv7YydiUO2esQ_.marker = Marker_tySequence__IHUFRsFxZNv7YydiUO2esQ;
TM__mJObP0PRzfMjXxDpaIgosg_0[72].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[72].offset = offsetof(tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw, vals);
TM__mJObP0PRzfMjXxDpaIgosg_0[72].typ = (&NTIseqLbiggestintT__IHUFRsFxZNv7YydiUO2esQ_);
TM__mJObP0PRzfMjXxDpaIgosg_0[72].name = "vals";
TM__mJObP0PRzfMjXxDpaIgosg_18_2[1] = &TM__mJObP0PRzfMjXxDpaIgosg_0[73];
TM__mJObP0PRzfMjXxDpaIgosg_0[73].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[73].offset = offsetof(tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw, keys);
TM__mJObP0PRzfMjXxDpaIgosg_0[73].typ = (&NTIseqLlitidT__9bAGqSvkAaFL9bWjsEPslrFA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[73].name = "keys";
TM__mJObP0PRzfMjXxDpaIgosg_0[71].len = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[71].kind = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[71].sons = &TM__mJObP0PRzfMjXxDpaIgosg_18_2[0];
NTIbitable__YFXXoy9ajAIwHK4kQgVvjcw_.node = &TM__mJObP0PRzfMjXxDpaIgosg_0[71];
TM__mJObP0PRzfMjXxDpaIgosg_0[70].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[70].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, numbers);
TM__mJObP0PRzfMjXxDpaIgosg_0[70].typ = (&NTIbitable__YFXXoy9ajAIwHK4kQgVvjcw_);
TM__mJObP0PRzfMjXxDpaIgosg_0[70].name = "numbers";
TM__mJObP0PRzfMjXxDpaIgosg_6_28[27] = &TM__mJObP0PRzfMjXxDpaIgosg_0[74];
NTIpackedconfig__aqQhF9bElTH51s7bVamv3vA_.size = sizeof(tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA);
NTIpackedconfig__aqQhF9bElTH51s7bVamv3vA_.align = NIM_ALIGNOF(tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA);
NTIpackedconfig__aqQhF9bElTH51s7bVamv3vA_.kind = 18;
NTIpackedconfig__aqQhF9bElTH51s7bVamv3vA_.base = 0;
NTIpackedconfig__aqQhF9bElTH51s7bVamv3vA_.flags = 3;
TM__mJObP0PRzfMjXxDpaIgosg_19_5[0] = &TM__mJObP0PRzfMjXxDpaIgosg_0[76];
TM__mJObP0PRzfMjXxDpaIgosg_0[76].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[76].offset = offsetof(tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA, backend);
TM__mJObP0PRzfMjXxDpaIgosg_0[76].typ = (&NTItbackend__zoooocqvga73vZuhGAAy6A_);
TM__mJObP0PRzfMjXxDpaIgosg_0[76].name = "backend";
TM__mJObP0PRzfMjXxDpaIgosg_19_5[1] = &TM__mJObP0PRzfMjXxDpaIgosg_0[77];
TM__mJObP0PRzfMjXxDpaIgosg_0[77].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[77].offset = offsetof(tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA, selectedGC);
TM__mJObP0PRzfMjXxDpaIgosg_0[77].typ = (&NTItgcmode__yHeclYqeKaCEfMHNbcWn4w_);
TM__mJObP0PRzfMjXxDpaIgosg_0[77].name = "selectedGC";
TM__mJObP0PRzfMjXxDpaIgosg_19_5[2] = &TM__mJObP0PRzfMjXxDpaIgosg_0[78];
TM__mJObP0PRzfMjXxDpaIgosg_0[78].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[78].offset = offsetof(tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA, cCompiler);
TM__mJObP0PRzfMjXxDpaIgosg_0[78].typ = (&NTItsystemcc__DqbWIQj9a2XvtXkztox3VFQ_);
TM__mJObP0PRzfMjXxDpaIgosg_0[78].name = "cCompiler";
TM__mJObP0PRzfMjXxDpaIgosg_19_5[3] = &TM__mJObP0PRzfMjXxDpaIgosg_0[79];
TM__mJObP0PRzfMjXxDpaIgosg_0[79].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[79].offset = offsetof(tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA, options);
TM__mJObP0PRzfMjXxDpaIgosg_0[79].typ = (&NTItoptions__JyE8ULWMsetkCt18l86VRw_);
TM__mJObP0PRzfMjXxDpaIgosg_0[79].name = "options";
TM__mJObP0PRzfMjXxDpaIgosg_19_5[4] = &TM__mJObP0PRzfMjXxDpaIgosg_0[80];
TM__mJObP0PRzfMjXxDpaIgosg_0[80].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[80].offset = offsetof(tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA, globalOptions);
TM__mJObP0PRzfMjXxDpaIgosg_0[80].typ = (&NTItglobaloptions__5mooI84kzWQJDnWciD7sQA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[80].name = "globalOptions";
TM__mJObP0PRzfMjXxDpaIgosg_0[75].len = 5; TM__mJObP0PRzfMjXxDpaIgosg_0[75].kind = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[75].sons = &TM__mJObP0PRzfMjXxDpaIgosg_19_5[0];
NTIpackedconfig__aqQhF9bElTH51s7bVamv3vA_.node = &TM__mJObP0PRzfMjXxDpaIgosg_0[75];
TM__mJObP0PRzfMjXxDpaIgosg_0[74].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[74].offset = offsetof(tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag, cfg);
TM__mJObP0PRzfMjXxDpaIgosg_0[74].typ = (&NTIpackedconfig__aqQhF9bElTH51s7bVamv3vA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[74].name = "cfg";
TM__mJObP0PRzfMjXxDpaIgosg_0[13].len = 28; TM__mJObP0PRzfMjXxDpaIgosg_0[13].kind = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[13].sons = &TM__mJObP0PRzfMjXxDpaIgosg_6_28[0];
NTIpackedmodule__Lx6uQ9baEALysaHmfFGXw9ag_.node = &TM__mJObP0PRzfMjXxDpaIgosg_0[13];
TM__mJObP0PRzfMjXxDpaIgosg_0[12].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[12].offset = offsetof(tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg, fromDisk);
TM__mJObP0PRzfMjXxDpaIgosg_0[12].typ = (&NTIpackedmodule__Lx6uQ9baEALysaHmfFGXw9ag_);
TM__mJObP0PRzfMjXxDpaIgosg_0[12].name = "fromDisk";
TM__mJObP0PRzfMjXxDpaIgosg_2_10[5] = &TM__mJObP0PRzfMjXxDpaIgosg_0[81];
TM__mJObP0PRzfMjXxDpaIgosg_0[81].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[81].offset = offsetof(tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg, syms);
TM__mJObP0PRzfMjXxDpaIgosg_0[81].typ = (&NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_);
TM__mJObP0PRzfMjXxDpaIgosg_0[81].name = "syms";
TM__mJObP0PRzfMjXxDpaIgosg_2_10[6] = &TM__mJObP0PRzfMjXxDpaIgosg_0[82];
TM__mJObP0PRzfMjXxDpaIgosg_0[82].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[82].offset = offsetof(tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg, types);
TM__mJObP0PRzfMjXxDpaIgosg_0[82].typ = (&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[82].name = "types";
TM__mJObP0PRzfMjXxDpaIgosg_2_10[7] = &TM__mJObP0PRzfMjXxDpaIgosg_0[83];
TM__mJObP0PRzfMjXxDpaIgosg_0[83].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[83].offset = offsetof(tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg, module);
TM__mJObP0PRzfMjXxDpaIgosg_0[83].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__mJObP0PRzfMjXxDpaIgosg_0[83].name = "module";
TM__mJObP0PRzfMjXxDpaIgosg_2_10[8] = &TM__mJObP0PRzfMjXxDpaIgosg_0[84];
NTItable__jSCM9c8LtAedYb1zTNR73sQ_.size = sizeof(tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ);
NTItable__jSCM9c8LtAedYb1zTNR73sQ_.align = NIM_ALIGNOF(tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ);
NTItable__jSCM9c8LtAedYb1zTNR73sQ_.kind = 18;
NTItable__jSCM9c8LtAedYb1zTNR73sQ_.base = 0;
NTItable__jSCM9c8LtAedYb1zTNR73sQ_.flags = 2;
TM__mJObP0PRzfMjXxDpaIgosg_20_2[0] = &TM__mJObP0PRzfMjXxDpaIgosg_0[86];
NTIkeyvaluepair__VUJ5Hjm4tKAResBsRHJvYg_.size = sizeof(tyTuple__VUJ5Hjm4tKAResBsRHJvYg);
NTIkeyvaluepair__VUJ5Hjm4tKAResBsRHJvYg_.align = NIM_ALIGNOF(tyTuple__VUJ5Hjm4tKAResBsRHJvYg);
NTIkeyvaluepair__VUJ5Hjm4tKAResBsRHJvYg_.kind = 18;
NTIkeyvaluepair__VUJ5Hjm4tKAResBsRHJvYg_.base = 0;
NTIkeyvaluepair__VUJ5Hjm4tKAResBsRHJvYg_.flags = 2;
TM__mJObP0PRzfMjXxDpaIgosg_21_3[0] = &TM__mJObP0PRzfMjXxDpaIgosg_0[88];
TM__mJObP0PRzfMjXxDpaIgosg_0[88].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[88].offset = offsetof(tyTuple__VUJ5Hjm4tKAResBsRHJvYg, Field0);
TM__mJObP0PRzfMjXxDpaIgosg_0[88].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[88].name = "Field0";
TM__mJObP0PRzfMjXxDpaIgosg_21_3[1] = &TM__mJObP0PRzfMjXxDpaIgosg_0[89];
TM__mJObP0PRzfMjXxDpaIgosg_0[89].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[89].offset = offsetof(tyTuple__VUJ5Hjm4tKAResBsRHJvYg, Field1);
TM__mJObP0PRzfMjXxDpaIgosg_0[89].typ = (&NTIpident__eFRAx6MW9aaEkYtj9aZffV0A_);
TM__mJObP0PRzfMjXxDpaIgosg_0[89].name = "Field1";
TM__mJObP0PRzfMjXxDpaIgosg_21_3[2] = &TM__mJObP0PRzfMjXxDpaIgosg_0[90];
TM__mJObP0PRzfMjXxDpaIgosg_0[90].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[90].offset = offsetof(tyTuple__VUJ5Hjm4tKAResBsRHJvYg, Field2);
TM__mJObP0PRzfMjXxDpaIgosg_0[90].typ = (&NTIseqLpackeditemidT__lo3S1lKyiPLhGGB9cBawd6A_);
TM__mJObP0PRzfMjXxDpaIgosg_0[90].name = "Field2";
TM__mJObP0PRzfMjXxDpaIgosg_0[87].len = 3; TM__mJObP0PRzfMjXxDpaIgosg_0[87].kind = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[87].sons = &TM__mJObP0PRzfMjXxDpaIgosg_21_3[0];
NTIkeyvaluepair__VUJ5Hjm4tKAResBsRHJvYg_.node = &TM__mJObP0PRzfMjXxDpaIgosg_0[87];
NTIkeyvaluepairseq__C3r8jsj9chA4sIlYfDN5aDw_.size = sizeof(tySequence__C3r8jsj9chA4sIlYfDN5aDw*);
NTIkeyvaluepairseq__C3r8jsj9chA4sIlYfDN5aDw_.align = NIM_ALIGNOF(tySequence__C3r8jsj9chA4sIlYfDN5aDw*);
NTIkeyvaluepairseq__C3r8jsj9chA4sIlYfDN5aDw_.kind = 24;
NTIkeyvaluepairseq__C3r8jsj9chA4sIlYfDN5aDw_.base = (&NTIkeyvaluepair__VUJ5Hjm4tKAResBsRHJvYg_);
NTIkeyvaluepairseq__C3r8jsj9chA4sIlYfDN5aDw_.flags = 2;
NTIkeyvaluepairseq__C3r8jsj9chA4sIlYfDN5aDw_.marker = Marker_tySequence__C3r8jsj9chA4sIlYfDN5aDw;
TM__mJObP0PRzfMjXxDpaIgosg_0[86].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[86].offset = offsetof(tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ, data);
TM__mJObP0PRzfMjXxDpaIgosg_0[86].typ = (&NTIkeyvaluepairseq__C3r8jsj9chA4sIlYfDN5aDw_);
TM__mJObP0PRzfMjXxDpaIgosg_0[86].name = "data";
TM__mJObP0PRzfMjXxDpaIgosg_20_2[1] = &TM__mJObP0PRzfMjXxDpaIgosg_0[91];
TM__mJObP0PRzfMjXxDpaIgosg_0[91].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[91].offset = offsetof(tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ, counter);
TM__mJObP0PRzfMjXxDpaIgosg_0[91].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[91].name = "counter";
TM__mJObP0PRzfMjXxDpaIgosg_0[85].len = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[85].kind = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[85].sons = &TM__mJObP0PRzfMjXxDpaIgosg_20_2[0];
NTItable__jSCM9c8LtAedYb1zTNR73sQ_.node = &TM__mJObP0PRzfMjXxDpaIgosg_0[85];
TM__mJObP0PRzfMjXxDpaIgosg_0[84].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[84].offset = offsetof(tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg, iface);
TM__mJObP0PRzfMjXxDpaIgosg_0[84].typ = (&NTItable__jSCM9c8LtAedYb1zTNR73sQ_);
TM__mJObP0PRzfMjXxDpaIgosg_0[84].name = "iface";
TM__mJObP0PRzfMjXxDpaIgosg_2_10[9] = &TM__mJObP0PRzfMjXxDpaIgosg_0[92];
TM__mJObP0PRzfMjXxDpaIgosg_0[92].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[92].offset = offsetof(tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg, ifaceHidden);
TM__mJObP0PRzfMjXxDpaIgosg_0[92].typ = (&NTItable__jSCM9c8LtAedYb1zTNR73sQ_);
TM__mJObP0PRzfMjXxDpaIgosg_0[92].name = "ifaceHidden";
TM__mJObP0PRzfMjXxDpaIgosg_0[0].len = 10; TM__mJObP0PRzfMjXxDpaIgosg_0[0].kind = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[0].sons = &TM__mJObP0PRzfMjXxDpaIgosg_2_10[0];
NTIloadedmodule__fihS6xbKhtLC0fhM28Cpeg_.node = &TM__mJObP0PRzfMjXxDpaIgosg_0[0];
NTIpackedmodulegraph__JbK5aK9aVhc9cJZzQYg1wQlQ_.size = sizeof(tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ*);
NTIpackedmodulegraph__JbK5aK9aVhc9cJZzQYg1wQlQ_.align = NIM_ALIGNOF(tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ*);
NTIpackedmodulegraph__JbK5aK9aVhc9cJZzQYg1wQlQ_.kind = 24;
NTIpackedmodulegraph__JbK5aK9aVhc9cJZzQYg1wQlQ_.base = (&NTIloadedmodule__fihS6xbKhtLC0fhM28Cpeg_);
NTIpackedmodulegraph__JbK5aK9aVhc9cJZzQYg1wQlQ_.flags = 2;
NTIpackedmodulegraph__JbK5aK9aVhc9cJZzQYg1wQlQ_.marker = Marker_tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ;
NTIpackedencoder__ftUl9bxYRlbT5ToKkxHdbfQ_.size = sizeof(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ);
NTIpackedencoder__ftUl9bxYRlbT5ToKkxHdbfQ_.align = NIM_ALIGNOF(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ);
NTIpackedencoder__ftUl9bxYRlbT5ToKkxHdbfQ_.kind = 18;
NTIpackedencoder__ftUl9bxYRlbT5ToKkxHdbfQ_.base = 0;
NTIpackedencoder__ftUl9bxYRlbT5ToKkxHdbfQ_.flags = 2;
TM__mJObP0PRzfMjXxDpaIgosg_22_9[0] = &TM__mJObP0PRzfMjXxDpaIgosg_0[94];
TM__mJObP0PRzfMjXxDpaIgosg_0[94].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[94].offset = offsetof(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ, thisModule);
TM__mJObP0PRzfMjXxDpaIgosg_0[94].typ = (&NTIint5150__sVg18TP9cLifHyygRe9cro9aA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[94].name = "thisModule";
TM__mJObP0PRzfMjXxDpaIgosg_22_9[1] = &TM__mJObP0PRzfMjXxDpaIgosg_0[95];
TM__mJObP0PRzfMjXxDpaIgosg_0[95].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[95].offset = offsetof(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ, lastFile);
TM__mJObP0PRzfMjXxDpaIgosg_0[95].typ = (&NTIint5150__sVg18TP9cLifHyygRe9cro9aA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[95].name = "lastFile";
TM__mJObP0PRzfMjXxDpaIgosg_22_9[2] = &TM__mJObP0PRzfMjXxDpaIgosg_0[96];
TM__mJObP0PRzfMjXxDpaIgosg_0[96].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[96].offset = offsetof(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ, lastLit);
TM__mJObP0PRzfMjXxDpaIgosg_0[96].typ = (&NTIuint5150__JrFyJbYm9b5I4hJ9cWDqvfYA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[96].name = "lastLit";
TM__mJObP0PRzfMjXxDpaIgosg_22_9[3] = &TM__mJObP0PRzfMjXxDpaIgosg_0[97];
NTItable__7OytuYts9c9a3BX9aQNPGI0gQ_.size = sizeof(tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ);
NTItable__7OytuYts9c9a3BX9aQNPGI0gQ_.align = NIM_ALIGNOF(tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ);
NTItable__7OytuYts9c9a3BX9aQNPGI0gQ_.kind = 18;
NTItable__7OytuYts9c9a3BX9aQNPGI0gQ_.base = 0;
NTItable__7OytuYts9c9a3BX9aQNPGI0gQ_.flags = 2;
TM__mJObP0PRzfMjXxDpaIgosg_23_2[0] = &TM__mJObP0PRzfMjXxDpaIgosg_0[99];
NTIkeyvaluepair__UvldbCB6B9ayi9bGYW7vJNLA_.size = sizeof(tyTuple__UvldbCB6B9ayi9bGYW7vJNLA);
NTIkeyvaluepair__UvldbCB6B9ayi9bGYW7vJNLA_.align = NIM_ALIGNOF(tyTuple__UvldbCB6B9ayi9bGYW7vJNLA);
NTIkeyvaluepair__UvldbCB6B9ayi9bGYW7vJNLA_.kind = 18;
NTIkeyvaluepair__UvldbCB6B9ayi9bGYW7vJNLA_.base = 0;
NTIkeyvaluepair__UvldbCB6B9ayi9bGYW7vJNLA_.flags = 3;
TM__mJObP0PRzfMjXxDpaIgosg_24_3[0] = &TM__mJObP0PRzfMjXxDpaIgosg_0[101];
TM__mJObP0PRzfMjXxDpaIgosg_0[101].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[101].offset = offsetof(tyTuple__UvldbCB6B9ayi9bGYW7vJNLA, Field0);
TM__mJObP0PRzfMjXxDpaIgosg_0[101].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[101].name = "Field0";
TM__mJObP0PRzfMjXxDpaIgosg_24_3[1] = &TM__mJObP0PRzfMjXxDpaIgosg_0[102];
TM__mJObP0PRzfMjXxDpaIgosg_0[102].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[102].offset = offsetof(tyTuple__UvldbCB6B9ayi9bGYW7vJNLA, Field1);
TM__mJObP0PRzfMjXxDpaIgosg_0[102].typ = (&NTIint5150__sVg18TP9cLifHyygRe9cro9aA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[102].name = "Field1";
TM__mJObP0PRzfMjXxDpaIgosg_24_3[2] = &TM__mJObP0PRzfMjXxDpaIgosg_0[103];
TM__mJObP0PRzfMjXxDpaIgosg_0[103].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[103].offset = offsetof(tyTuple__UvldbCB6B9ayi9bGYW7vJNLA, Field2);
TM__mJObP0PRzfMjXxDpaIgosg_0[103].typ = (&NTIuint5150__JrFyJbYm9b5I4hJ9cWDqvfYA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[103].name = "Field2";
TM__mJObP0PRzfMjXxDpaIgosg_0[100].len = 3; TM__mJObP0PRzfMjXxDpaIgosg_0[100].kind = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[100].sons = &TM__mJObP0PRzfMjXxDpaIgosg_24_3[0];
NTIkeyvaluepair__UvldbCB6B9ayi9bGYW7vJNLA_.node = &TM__mJObP0PRzfMjXxDpaIgosg_0[100];
NTIkeyvaluepairseq__9cnx3zXnWzeclW8Ko4oUgAQ_.size = sizeof(tySequence__9cnx3zXnWzeclW8Ko4oUgAQ*);
NTIkeyvaluepairseq__9cnx3zXnWzeclW8Ko4oUgAQ_.align = NIM_ALIGNOF(tySequence__9cnx3zXnWzeclW8Ko4oUgAQ*);
NTIkeyvaluepairseq__9cnx3zXnWzeclW8Ko4oUgAQ_.kind = 24;
NTIkeyvaluepairseq__9cnx3zXnWzeclW8Ko4oUgAQ_.base = (&NTIkeyvaluepair__UvldbCB6B9ayi9bGYW7vJNLA_);
NTIkeyvaluepairseq__9cnx3zXnWzeclW8Ko4oUgAQ_.flags = 2;
NTIkeyvaluepairseq__9cnx3zXnWzeclW8Ko4oUgAQ_.marker = Marker_tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
TM__mJObP0PRzfMjXxDpaIgosg_0[99].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[99].offset = offsetof(tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ, data);
TM__mJObP0PRzfMjXxDpaIgosg_0[99].typ = (&NTIkeyvaluepairseq__9cnx3zXnWzeclW8Ko4oUgAQ_);
TM__mJObP0PRzfMjXxDpaIgosg_0[99].name = "data";
TM__mJObP0PRzfMjXxDpaIgosg_23_2[1] = &TM__mJObP0PRzfMjXxDpaIgosg_0[104];
TM__mJObP0PRzfMjXxDpaIgosg_0[104].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[104].offset = offsetof(tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ, counter);
TM__mJObP0PRzfMjXxDpaIgosg_0[104].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[104].name = "counter";
TM__mJObP0PRzfMjXxDpaIgosg_0[98].len = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[98].kind = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[98].sons = &TM__mJObP0PRzfMjXxDpaIgosg_23_2[0];
NTItable__7OytuYts9c9a3BX9aQNPGI0gQ_.node = &TM__mJObP0PRzfMjXxDpaIgosg_0[98];
TM__mJObP0PRzfMjXxDpaIgosg_0[97].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[97].offset = offsetof(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ, filenames);
TM__mJObP0PRzfMjXxDpaIgosg_0[97].typ = (&NTItable__7OytuYts9c9a3BX9aQNPGI0gQ_);
TM__mJObP0PRzfMjXxDpaIgosg_0[97].name = "filenames";
TM__mJObP0PRzfMjXxDpaIgosg_22_9[4] = &TM__mJObP0PRzfMjXxDpaIgosg_0[105];
TM__mJObP0PRzfMjXxDpaIgosg_0[105].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[105].offset = offsetof(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ, pendingTypes);
TM__mJObP0PRzfMjXxDpaIgosg_0[105].typ = (&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[105].name = "pendingTypes";
TM__mJObP0PRzfMjXxDpaIgosg_22_9[5] = &TM__mJObP0PRzfMjXxDpaIgosg_0[106];
TM__mJObP0PRzfMjXxDpaIgosg_0[106].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[106].offset = offsetof(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ, pendingSyms);
TM__mJObP0PRzfMjXxDpaIgosg_0[106].typ = (&NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_);
TM__mJObP0PRzfMjXxDpaIgosg_0[106].name = "pendingSyms";
TM__mJObP0PRzfMjXxDpaIgosg_22_9[6] = &TM__mJObP0PRzfMjXxDpaIgosg_0[107];
TM__mJObP0PRzfMjXxDpaIgosg_0[107].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[107].offset = offsetof(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ, typeMarker);
TM__mJObP0PRzfMjXxDpaIgosg_0[107].typ = (&NTIpackedset__THXDbzJSs2hcC9a33en2pdw_);
TM__mJObP0PRzfMjXxDpaIgosg_0[107].name = "typeMarker";
TM__mJObP0PRzfMjXxDpaIgosg_22_9[7] = &TM__mJObP0PRzfMjXxDpaIgosg_0[108];
TM__mJObP0PRzfMjXxDpaIgosg_0[108].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[108].offset = offsetof(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ, symMarker);
TM__mJObP0PRzfMjXxDpaIgosg_0[108].typ = (&NTIpackedset__THXDbzJSs2hcC9a33en2pdw_);
TM__mJObP0PRzfMjXxDpaIgosg_0[108].name = "symMarker";
TM__mJObP0PRzfMjXxDpaIgosg_22_9[8] = &TM__mJObP0PRzfMjXxDpaIgosg_0[109];
TM__mJObP0PRzfMjXxDpaIgosg_0[109].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[109].offset = offsetof(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ, config);
TM__mJObP0PRzfMjXxDpaIgosg_0[109].typ = (&NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[109].name = "config";
TM__mJObP0PRzfMjXxDpaIgosg_0[93].len = 9; TM__mJObP0PRzfMjXxDpaIgosg_0[93].kind = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[93].sons = &TM__mJObP0PRzfMjXxDpaIgosg_22_9[0];
NTIpackedencoder__ftUl9bxYRlbT5ToKkxHdbfQ_.node = &TM__mJObP0PRzfMjXxDpaIgosg_0[93];
NTIpackeddecoder__KP7DLKztb9c2OnCFWxJiscQ_.size = sizeof(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ);
NTIpackeddecoder__KP7DLKztb9c2OnCFWxJiscQ_.align = NIM_ALIGNOF(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ);
NTIpackeddecoder__KP7DLKztb9c2OnCFWxJiscQ_.kind = 18;
NTIpackeddecoder__KP7DLKztb9c2OnCFWxJiscQ_.base = 0;
NTIpackeddecoder__KP7DLKztb9c2OnCFWxJiscQ_.flags = 2;
TM__mJObP0PRzfMjXxDpaIgosg_35_5[0] = &TM__mJObP0PRzfMjXxDpaIgosg_0[111];
TM__mJObP0PRzfMjXxDpaIgosg_0[111].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[111].offset = offsetof(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ, lastModule);
TM__mJObP0PRzfMjXxDpaIgosg_0[111].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[111].name = "lastModule";
TM__mJObP0PRzfMjXxDpaIgosg_35_5[1] = &TM__mJObP0PRzfMjXxDpaIgosg_0[112];
TM__mJObP0PRzfMjXxDpaIgosg_0[112].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[112].offset = offsetof(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ, lastLit);
TM__mJObP0PRzfMjXxDpaIgosg_0[112].typ = (&NTIuint5150__JrFyJbYm9b5I4hJ9cWDqvfYA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[112].name = "lastLit";
TM__mJObP0PRzfMjXxDpaIgosg_35_5[2] = &TM__mJObP0PRzfMjXxDpaIgosg_0[113];
TM__mJObP0PRzfMjXxDpaIgosg_0[113].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[113].offset = offsetof(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ, lastFile);
TM__mJObP0PRzfMjXxDpaIgosg_0[113].typ = (&NTIint5150__sVg18TP9cLifHyygRe9cro9aA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[113].name = "lastFile";
TM__mJObP0PRzfMjXxDpaIgosg_35_5[3] = &TM__mJObP0PRzfMjXxDpaIgosg_0[114];
TM__mJObP0PRzfMjXxDpaIgosg_0[114].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[114].offset = offsetof(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ, config);
TM__mJObP0PRzfMjXxDpaIgosg_0[114].typ = (&NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_);
TM__mJObP0PRzfMjXxDpaIgosg_0[114].name = "config";
TM__mJObP0PRzfMjXxDpaIgosg_35_5[4] = &TM__mJObP0PRzfMjXxDpaIgosg_0[115];
TM__mJObP0PRzfMjXxDpaIgosg_0[115].kind = 1;
TM__mJObP0PRzfMjXxDpaIgosg_0[115].offset = offsetof(tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ, cache);
TM__mJObP0PRzfMjXxDpaIgosg_0[115].typ = (&NTIidentcache__6ZZ9cf5acLVYxUxl0ehlA1g_);
TM__mJObP0PRzfMjXxDpaIgosg_0[115].name = "cache";
TM__mJObP0PRzfMjXxDpaIgosg_0[110].len = 5; TM__mJObP0PRzfMjXxDpaIgosg_0[110].kind = 2; TM__mJObP0PRzfMjXxDpaIgosg_0[110].sons = &TM__mJObP0PRzfMjXxDpaIgosg_35_5[0];
NTIpackeddecoder__KP7DLKztb9c2OnCFWxJiscQ_.node = &TM__mJObP0PRzfMjXxDpaIgosg_0[110];
}

