/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 32

#include "nimbase.h"
#include <setjmp.h>
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw;
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ;
typedef struct tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA;
typedef struct tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA;
typedef struct tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw;
typedef struct tySequence__ed0C0uAUZPhvw3RAc5hfYg tySequence__ed0C0uAUZPhvw3RAc5hfYg;
typedef struct tySequence__vvBerF0axaNtu9aMA2gnsrA tySequence__vvBerF0axaNtu9aMA2gnsrA;
typedef struct tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ;
typedef struct tySequence__ZQPym9bf1jM5qaSn7LUXMKA tySequence__ZQPym9bf1jM5qaSn7LUXMKA;
typedef struct tySequence__9c3OY0aBmSBgwdsnBAPf4Ag tySequence__9c3OY0aBmSBgwdsnBAPf4Ag;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw;
typedef struct tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ;
typedef struct tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tySequence__Jhh6ks9carRtwV9aOuM8yMNw tySequence__Jhh6ks9carRtwV9aOuM8yMNw;
typedef struct tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw tySequence__Bis5AbpONWcIRrPyPJS8Yw;
typedef struct tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg;
typedef struct tySequence__E8pi9b5QNahsURYzXMjh3qw tySequence__E8pi9b5QNahsURYzXMjh3qw;
typedef struct tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg;
typedef struct tySequence__XDpbjnuseLNZDGLBQ2Qzow tySequence__XDpbjnuseLNZDGLBQ2Qzow;
typedef struct tyObject_Table__cBohObSCAwRxvYFXQHv2wA tyObject_Table__cBohObSCAwRxvYFXQHv2wA;
typedef struct tySequence__QqvaCqCpEE1QmQZbcZLi5A tySequence__QqvaCqCpEE1QmQZbcZLi5A;
typedef struct tySequence__RNhZxf20g9beyq5VBOGxhDg tySequence__RNhZxf20g9beyq5VBOGxhDg;
typedef struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ;
typedef struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ tySequence__lFbCtu5P2Kf7YDYtGjkxAQ;
typedef struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA;
typedef struct tySequence__ijtae5OneaLys0hN9alAicA tySequence__ijtae5OneaLys0hN9alAicA;
typedef struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w;
typedef struct tySequence__SerjNoUujW2dUouVBrJiCw tySequence__SerjNoUujW2dUouVBrJiCw;
typedef struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyObject_Table__r0v8BdcBPKhl73K8p2VMUA;
typedef struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g tySequence__K9agbtcb0qPZuSJFXB9cTe6g;
typedef struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg;
typedef struct tySequence__m88qdML9cQOuqGAQn6XWL1A tySequence__m88qdML9cQOuqGAQn6XWL1A;
typedef struct tyObject_Table__1hIWbTQWYT4BmhdESze57A tyObject_Table__1hIWbTQWYT4BmhdESze57A;
typedef struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ tySequence__naEbXEp9b9aiW1zXJorqf9cXQ;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA;
typedef struct tyObject_Table__imojfg883tkWsWJwyshGqQ tyObject_Table__imojfg883tkWsWJwyshGqQ;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg tyObject_Table__BCPh85PHtwxox9bv7NLFrlg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA;
typedef struct tySequence__KgiZ29chkJAD01p9aLRB32qw tySequence__KgiZ29chkJAD01p9aLRB32qw;
typedef struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A tyObject_Table__LM44poVdVEn4Mo4N4L8c3A;
typedef struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw tySequence__rkYRZrbHVYL3nhXlQW3K9bw;
typedef struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ tySequence__IRFEb1e9bxgbJLuB5xrdZsQ;
typedef struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ;
typedef struct tySequence__YmPd0eWfcTfrVYrthlXPYA tySequence__YmPd0eWfcTfrVYrthlXPYA;
typedef struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q;
typedef struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg tySequence__Hz5SYwQU29b9aFLt09blvVQPg;
typedef struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg tyObject_Table__R7JnJQEipxxOlJWXQz7jWg;
typedef struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ tySequence__3G9aA9cLXaPxuRxMKm3anacQ;
typedef struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q tySequence__bPFv6ypvvCX2A9a9al8utL2Q;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct tySequence__GR8qmV1kNRcoQ2g76VFy3A tySequence__GR8qmV1kNRcoQ2g76VFy3A;
typedef struct Exception Exception;
typedef struct tySequence__QbmGqFaLnb1IWWToREeaIA tySequence__QbmGqFaLnb1IWWToREeaIA;
typedef struct TSafePoint TSafePoint;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw;
typedef struct tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw;
typedef struct tyObject_Env_suggestdotnim_getTokenLenFromSource___JTQD63EOMNGYBEyDiI65hA tyObject_Env_suggestdotnim_getTokenLenFromSource___JTQD63EOMNGYBEyDiI65hA;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg;
typedef struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg;
typedef struct tySequence__4Murtwnm0Fyc7F9acrytEXw tySequence__4Murtwnm0Fyc7F9acrytEXw;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw;
typedef struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg tySequence__QnmOtn1Iv4LvxOXoMn8Rbg;
typedef struct tySequence__oKtVqsc9bQVCNyrijELM4OQ tySequence__oKtVqsc9bQVCNyrijELM4OQ;
typedef struct tySequence__qy6Iwdy00wN560qud54HTg tySequence__qy6Iwdy00wN560qud54HTg;
typedef struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ tySequence__k67v9bwvvQDmS1ynyGGUbeQ;
typedef struct tySequence__cLsClAAfd0MKkoBQVyvdvw tySequence__cLsClAAfd0MKkoBQVyvdvw;
typedef struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg tySequence__q9bTuOB0JXh1iZ3CSGdRLbg;
typedef struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw;
typedef struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ;
typedef struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ;
typedef struct tySequence__C3r8jsj9chA4sIlYfDN5aDw tySequence__C3r8jsj9chA4sIlYfDN5aDw;
typedef struct tyObject_RodIter__L6nv9cakjPARHk068AFo6ww tyObject_RodIter__L6nv9cakjPARHk068AFo6ww;
typedef struct tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ;
typedef struct tySequence__lo3S1lKyiPLhGGB9cBawd6A tySequence__lo3S1lKyiPLhGGB9cBawd6A;
typedef struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ;
typedef struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g tySequence__qeAsXh2i1GAL5Nl0g3OP8g;
typedef struct tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A;
typedef struct tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg;
typedef struct tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw;
typedef struct tyObject_MismatchInfo__7DZVQMEKp3NTauLRe48cLw tyObject_MismatchInfo__7DZVQMEKp3NTauLRe48cLw;
typedef struct tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyTuple__hwJj4UwOYfHl0hX52kYcPQ tyTuple__hwJj4UwOYfHl0hX52kYcPQ;
typedef struct tyObject_Env_sigmatchdotnim_matchUserTypeClass___J1TZ8yvjL0AcwEoyPAfoPQ tyObject_Env_sigmatchdotnim_matchUserTypeClass___J1TZ8yvjL0AcwEoyPAfoPQ;
typedef struct tySequence__r9afowSCR9cYl2NdMwuF5Jtg tySequence__r9afowSCR9cYl2NdMwuF5Jtg;
typedef struct tyTuple__7ojGQ7p3GL8CscnPtcFVrQ tyTuple__7ojGQ7p3GL8CscnPtcFVrQ;
typedef struct tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct tyObject_CandidateError__gFDKCwBunKZtG86yhpxUMQ tyObject_CandidateError__gFDKCwBunKZtG86yhpxUMQ;
typedef struct tySequence__LFzufdBEvfOUK6PWh0HUtQ tySequence__LFzufdBEvfOUK6PWh0HUtQ;
typedef struct tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q;
typedef struct tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA;
typedef struct tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w;
typedef struct tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA;
typedef struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ tyTuple__NAaJgGVgNmlGoqmiWxdOHQ;
typedef struct tyTuple__VbApVidEWCFLq9a29bPtaS7A tyTuple__VbApVidEWCFLq9a29bPtaS7A;
typedef struct tySequence__k7EQb9bN3Uhl608xoPGMRJA tySequence__k7EQb9bN3Uhl608xoPGMRJA;
typedef struct tyTuple__toqrUPSdp8zSxOdlxMJj9cA tyTuple__toqrUPSdp8zSxOdlxMJj9cA;
typedef struct tyTuple__EbsafWGli8bW2GRJQ9apsjA tyTuple__EbsafWGli8bW2GRJQ9apsjA;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
typedef struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ;
typedef struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg tyTuple__UluY8x0Nj6cp9b0o88wJ0lg;
typedef struct tySequence__dlD6tEGzYLLpKVq3XwuFlA tySequence__dlD6tEGzYLLpKVq3XwuFlA;
typedef struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ;
typedef struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg;
typedef struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ;
typedef struct tyTuple__rZZA0skon1OsHdiEvT8RZQ tyTuple__rZZA0skon1OsHdiEvT8RZQ;
typedef struct tySequence__6OFCSvqRaxyEgUqWtnZSlw tySequence__6OFCSvqRaxyEgUqWtnZSlw;
typedef struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q;
typedef struct tySequence__UnGSk9aaLosDroi2QDrlOfQ tySequence__UnGSk9aaLosDroi2QDrlOfQ;
typedef struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA tyTuple__q13Zt16VkCqu6Zg5jWqwHA;
typedef struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA tyTuple__aWN9bNzF9bubXNJV9ciomgpfA;
typedef struct tySequence__m4PVWjcAAjfxlwJxLkKn8A tySequence__m4PVWjcAAjfxlwJxLkKn8A;
typedef struct tyTuple__RWXAsQlFoGYyEQZp1G65sg tyTuple__RWXAsQlFoGYyEQZp1G65sg;
typedef struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg;
typedef struct tyTuple__RmGJuqOgEaHckHndh0LEsw tyTuple__RmGJuqOgEaHckHndh0LEsw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__J4cxakKjhKxTIJR9bojMmXw tyTuple__J4cxakKjhKxTIJR9bojMmXw;
typedef struct tySequence__i89c5kdtWKzK3OEiI81pkkw tySequence__i89c5kdtWKzK3OEiI81pkkw;
typedef struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A;
typedef struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ;
typedef struct tyTuple__a7QginWFapakKbWJBJ2vfA tyTuple__a7QginWFapakKbWJBJ2vfA;
typedef struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__kbX6x85REySUrk9auORL0vw tyTuple__kbX6x85REySUrk9auORL0vw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g;
typedef struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q;
typedef struct tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A;
typedef struct tyTuple__nF9cH4hinXgGEUwO4G2bshw tyTuple__nF9cH4hinXgGEUwO4G2bshw;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
typedef struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA;
typedef struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__PsEhl3dzznmmJiLAuIXZOg tyTuple__PsEhl3dzznmmJiLAuIXZOg;
typedef struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w;
typedef struct tyTuple__Db8CrQifKGIsKc3w71w7Lw tyTuple__Db8CrQifKGIsKc3w71w7Lw;
typedef struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg;
typedef struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ;
typedef struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw tyTuple__FEYH9alRJhHD0uTKF2vnIqw;
typedef struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA;
typedef struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA;
typedef struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw;
typedef struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg tyTuple__VUJ5Hjm4tKAResBsRHJvYg;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw {
  RootObj Sup;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__aaEwD7wUZoIxDUprFEbfMQ[38];
struct tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ {
NI counter;
tySequence__ZQPym9bf1jM5qaSn7LUXMKA* data;
};
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__q9caIJqxIEVMlKzDKc7PN3A) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* expectedType);
typedef NU32 tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__Kiet6YwcQwPvcQYHHEqqqQ) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* expectedType);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__PSlVV9bxpH9avY5YrjCD5uqA) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__8k9afYvvfaH1tjWAwlISb0A) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, void* ClE_0);
void* ClE_0;
} tyProc__9bnYcX9avusKBraL3FJXBwJw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__uojbiMfaKLMuGW9bbomtTBg) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
typedef NU32 tySet_tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__bqRyngJC8bSPcUqqn9bn73w) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nOrig, tySet_tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw filter, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags);
typedef N_NIMCALL_PTR(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, tyProc__F6LocU8y66ng5Ra4XoVWJA) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* prev);
typedef struct {
N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, void* ClE_0);
void* ClE_0;
} tyProc__Nc9aAsBDTkr61wP9a9cnds8Og;
typedef struct {
N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fn, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, void* ClE_0);
void* ClE_0;
} tyProc__z8FaSv6eEIc72FZ9c9cBcaGg;
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw {
NI counter;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* data;
};
typedef NU8 tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ;
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__9aa59awckKpa9areOQSBOwSeQ) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* dc, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ op, NI col);
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
struct tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ {
tySequence__Bis5AbpONWcIRrPyPJS8Yw* data;
NI counter;
};
struct tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg {
tySequence__E8pi9b5QNahsURYzXMjh3qw* data;
NI counter;
};
struct tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg {
tySequence__XDpbjnuseLNZDGLBQ2Qzow* data;
NI counter;
};
struct tyObject_Table__cBohObSCAwRxvYFXQHv2wA {
tySequence__QqvaCqCpEE1QmQZbcZLi5A* data;
NI counter;
};
struct tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw {
  tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw Sup;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* enforceVoidContext;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* voidType;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* currentScope;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* moduleScope;
tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA* imports;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* topLevelScope;
tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA* p;
tyArray__aaEwD7wUZoIxDUprFEbfMQ intTypeCache;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* nilTypeCache;
tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw* matchedConcept;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* friendModules;
NI instCounter;
NI* templInstCounter;
NI inGenericContext;
NI inStaticContext;
NI inUnrolledContext;
NI compilesContextId;
NI compilesContextIdGenerator;
NI inGenericInst;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* converters;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* patterns;
tySequence__vvBerF0axaNtu9aMA2gnsrA* optionStack;
tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ symMapping;
tySequence__9c3OY0aBmSBgwdsnBAPf4Ag* libs;
tyProc__q9caIJqxIEVMlKzDKc7PN3A semConstExpr;
tyProc__Kiet6YwcQwPvcQYHHEqqqQ semExpr;
tyProc__PSlVV9bxpH9avY5YrjCD5uqA semTryExpr;
tyProc__q9caIJqxIEVMlKzDKc7PN3A semTryConstExpr;
tyProc__8k9afYvvfaH1tjWAwlISb0A computeRequiresInit;
tyProc__9bnYcX9avusKBraL3FJXBwJw hasUnresolvedArgs;
tyProc__PSlVV9bxpH9avY5YrjCD5uqA semOperand;
tyProc__uojbiMfaKLMuGW9bbomtTBg semConstBoolExpr;
tyProc__bqRyngJC8bSPcUqqn9bn73w semOverloadedCall;
tyProc__F6LocU8y66ng5Ra4XoVWJA semTypeNode;
tyProc__Nc9aAsBDTkr61wP9a9cnds8Og semInferredLambda;
tyProc__z8FaSv6eEIc72FZ9c9cBcaGg semGenerateInstance;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw includedFiles;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw pureEnumFields;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw userPragmas;
tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ* evalContext;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw unknownIdents;
tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ* generics;
NI topStmts;
NI lastGenericIdx;
NI hloLoopDetector;
NI inParallelStmt;
tyProc__9aa59awckKpa9areOQSBOwSeQ instTypeBoundOp;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* selfName;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw signatures;
NimStringDesc* recursiveDep;
NIM_BOOL suggestionsMade;
NIM_BOOL isAmbiguous;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
NI inTypeContext;
NI inConceptDecl;
tySequence__Jhh6ks9carRtwV9aOuM8yMNw* unusedImports;
tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ exportIndirections;
tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg importModuleMap;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastTLineInfo;
tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg sideEffects;
NI inUncheckedAssignSection;
tyObject_Table__cBohObSCAwRxvYFXQHv2wA importModuleLookup;
};
struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA {
tySequence__ijtae5OneaLys0hN9alAicA* data;
NI counter;
};
struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w {
tySequence__SerjNoUujW2dUouVBrJiCw* data;
NI counter;
};
struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA {
tySequence__K9agbtcb0qPZuSJFXB9cTe6g* data;
NI counter;
};
typedef tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyArray__46hjIasL27aUz9c7kgtWooQ[5];
struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg {
tySequence__m88qdML9cQOuqGAQn6XWL1A* data;
NI counter;
};
struct tyObject_Table__1hIWbTQWYT4BmhdESze57A {
tySequence__naEbXEp9b9aiW1zXJorqf9cXQ* data;
NI counter;
};
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
};
struct tyObject_Table__imojfg883tkWsWJwyshGqQ {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA {
tySequence__KgiZ29chkJAD01p9aLRB32qw* data;
NI counter;
};
struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A {
tySequence__rkYRZrbHVYL3nhXlQW3K9bw* data;
NI counter;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg[65];
struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ {
tySequence__YmPd0eWfcTfrVYrthlXPYA* data;
NI counter;
};
struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__I6rzVhdiYtUh7jwWJQoeyw) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__EQOAUyRkp9c3eeiGlHvCThA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q {
tySequence__Hz5SYwQU29b9aFLt09blvVQPg* data;
NI counter;
};
struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg {
tySequence__3G9aA9cLXaPxuRxMKm3anacQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__1CO5eEh25fBKUWGagpikwg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
typedef N_NIMCALL_PTR(void, tyProc__VcUg5jOhttLagdxUmVN8Tg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__XOkru1xuh2bHzmkw1UYzLA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formal, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* actual);
struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opNot;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opContains;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLe;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLt;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAnd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opOr;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opIsNil;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opEq;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAdd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opSub;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opMul;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opDiv;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg {
tySequence__RNhZxf20g9beyq5VBOGxhDg* ifaces;
tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* packed_0;
tySequence__lFbCtu5P2Kf7YDYtGjkxAQ* encoders;
tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA typeInstCache;
tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w procInstCache;
tyArray__46hjIasL27aUz9c7kgtWooQ attachedOps;
tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg methodsPerType;
tyObject_Table__1hIWbTQWYT4BmhdESze57A enumToStringProcs;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw emittedTypeInfo;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA startupPackedConfig;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw deps;
tyObject_Table__imojfg883tkWsWJwyshGqQ importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__BCPh85PHtwxox9bv7NLFrlg inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* usageSym;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* owners;
tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA suggestSymbols;
tyObject_Table__LM44poVdVEn4Mo4N4L8c3A suggestErrors;
tySequence__IRFEb1e9bxgbJLuB5xrdZsQ* methods;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* systemModule;
tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg sysTypes;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw compilerprocs;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw exposed;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageTypes;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* emptyNode;
tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ canonTypes;
tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw symBodyHashes;
tyProc__I6rzVhdiYtUh7jwWJQoeyw importModuleCallback;
tyProc__EQOAUyRkp9c3eeiGlHvCThA includeFileCallback;
tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q cacheSeqs;
tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g cacheCounters;
tyObject_Table__R7JnJQEipxxOlJWXQz7jWg cacheTables;
tySequence__bPFv6ypvvCX2A9a9al8utL2Q* passes;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinition;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinitionResolveForward;
tyProc__1CO5eEh25fBKUWGagpikwg onUsage;
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* globalDestructors;
tyProc__VcUg5jOhttLagdxUmVN8Tg strongSemCheck;
tyProc__XOkru1xuh2bHzmkw1UYzLA compatibleProps;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg operators;
};
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__QbmGqFaLnb1IWWToREeaIA* trace;
Exception* up;
};
struct TSafePoint {
TSafePoint* prev;
NI status;
jmp_buf context;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ;
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
struct tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw {
NI h;
};
struct tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ {
NI depthLevel;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw symbols;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* parent;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* allowPrivateAccess;
};
struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg {
NI id;
NimStringDesc* s;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* next;
NI h;
};
struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg {
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg section;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* qualifiedPath;
NimStringDesc** name;
NimStringDesc* filePath;
NI line;
NI column;
NimStringDesc* doc;
NimStringDesc* forth;
NI quality;
NIM_BOOL isGlobal;
NIM_BOOL contextFits;
tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ prefix;
NU8 symkind;
NI scope;
NI localUsages;
NI globalUsages;
NI tokenLen;
NI version;
NU16 endLine;
NI endCol;
};
typedef NU8 tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU8 tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
struct tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw {
NI a;
NI b;
};
typedef NU8 tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg;
struct tyObject_Env_suggestdotnim_getTokenLenFromSource___JTQD63EOMNGYBEyDiI65hA {
  RootObj Sup;
NI colonstate_;
NimStringDesc* line1;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (NI col, void* ClE_0);
void* ClE_0;
} tyProc__cOOsXj9cY0bKt2oqNqLbhZw;
typedef N_CLOSURE_PTR(NIM_BOOL, TM__wjrA09aH0rT1R7zbrcCaROw_5) (NI col);
typedef N_CLOSURE_PTR(NIM_BOOL, TM__wjrA09aH0rT1R7zbrcCaROw_6) (NI col);
typedef N_CLOSURE_PTR(NIM_BOOL, TM__wjrA09aH0rT1R7zbrcCaROw_7) (NI col);
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInst;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg uniqueId;
};
typedef NU8 tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg[9];
typedef NU8 tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU8 tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg;
struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg {
tySequence__4Murtwnm0Fyc7F9acrytEXw* nodes;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ;
struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ {
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw {
tySequence__IHUFRsFxZNv7YydiUO2esQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag {
NimStringDesc* definedSymbols;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA moduleFlags;
tySequence__PXIzfWocnrafGz5p3CP5LA* includes;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* imports;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg toReplay;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg topLevel;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg bodies;
tySequence__b89aLriiJnVTD186H6zNIgg* exports;
tySequence__b89aLriiJnVTD186H6zNIgg* hidden;
tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw* reexports;
tySequence__b89aLriiJnVTD186H6zNIgg* compilerProcs;
tySequence__48JTohSgTy339bRxHzUD8KA* converters;
tySequence__48JTohSgTy339bRxHzUD8KA* methods;
tySequence__48JTohSgTy339bRxHzUD8KA* trmacros;
tySequence__48JTohSgTy339bRxHzUD8KA* pureEnums;
tySequence__QnmOtn1Iv4LvxOXoMn8Rbg* macroUsages;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* typeInstCache;
tySequence__qy6Iwdy00wN560qud54HTg* procInstCache;
tySequence__k67v9bwvvQDmS1ynyGGUbeQ* attachedOps;
tySequence__cLsClAAfd0MKkoBQVyvdvw* methodsPerType;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* enumToStringProcs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* emittedTypeInfo;
tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ backendFlags;
tySequence__q9bTuOB0JXh1iZ3CSGdRLbg* syms;
tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw* types;
tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ strings;
tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw numbers;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA cfg;
};
struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ {
tySequence__C3r8jsj9chA4sIlYfDN5aDw* data;
NI counter;
};
struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg {
tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg status;
NIM_BOOL symsInit;
NIM_BOOL typesInit;
NIM_BOOL loadedButAliveSetChanged;
tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag fromDisk;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* syms;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* types;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ iface;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ ifaceHidden;
};
struct tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ {
NI lastModule;
NU32 lastLit;
NI32 lastFile;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
};
struct tyObject_RodIter__L6nv9cakjPARHk068AFo6ww {
tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ decoder;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* values;
NI i;
NI module;
};
struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* converters;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* patterns;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* pureEnums;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interf;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interfHidden;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* uniqueName;
};
struct tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field0;
NI Field1;
NIM_BOOL Field2;
};
typedef NU8 tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ;
struct tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m;
tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ mode;
union{
struct {tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw imported;
} _mode_2;
struct {tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw exceptSet;
} _mode_3;
};
};
typedef NU8 tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg;
typedef NU8 tyEnum_MismatchKind__4mf6T2YBNEEtWBTWMSzL9bw;
struct tyObject_MismatchInfo__7DZVQMEKp3NTauLRe48cLw {
tyEnum_MismatchKind__4mf6T2YBNEEtWBTWMSzL9bw kind;
NI arg;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* formal;
};
struct tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw {
tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c;
NI exactMatches;
NI genericMatches;
NI subtypeMatches;
NI intConvMatches;
NI convMatches;
tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg state;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* callee;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* calleeSym;
NI calleeScope;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* call;
tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ bindings;
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
NIM_BOOL baseTypeMatch;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg fauxMatch;
NIM_BOOL genericConverter;
NIM_BOOL coerceDistincts;
NIM_BOOL typedescMatched;
NIM_BOOL isNoCall;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* inferredTypes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* diagnostics;
NI inheritancePenalty;
tyObject_MismatchInfo__7DZVQMEKp3NTauLRe48cLw firstMismatch;
NIM_BOOL diagnosticsEnabled;
};
typedef NU8 tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
typedef NU8 tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA;
typedef NU8 tySet_tyEnum_TTypeRelFlag__nkWaH9aZ1YawZFP9aSlbYFMw;
struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg {
NI32 module;
NI32 symId;
NI32 typeId_0;
NIM_BOOL sealed;
};
struct tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* candidateType;
tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw* prev;
NI depth;
};
typedef NU32 tyArray__FleBT9cC2nxhgiXmSYYnEKA[4];
struct tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ {
tyArray__FleBT9cC2nxhgiXmSYYnEKA udata;
};
typedef NU8 tyEnum_TTypeRelFlag__nkWaH9aZ1YawZFP9aSlbYFMw;
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_TTypeCmpFlag__IRq9bqtrf9ctEUyeRMyvWy4Q;
typedef NU8 tySet_tyEnum_ProcConvMismatch__8QUcKskIrkXqgfo6ArVV0Q;
struct tyTuple__hwJj4UwOYfHl0hX52kYcPQ {
tySet_tyEnum_ProcConvMismatch__8QUcKskIrkXqgfo6ArVV0Q Field0;
tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA Field1;
};
typedef NU8 tyEnum_EffectsCompat__Ua7UNlEurqcdZ8OG3EY7xA;
typedef NU8 tyEnum_SkippedPtr__ZfkN1Zg3tYB8pQTEnxqNcg;
struct tyObject_Env_sigmatchdotnim_matchUserTypeClass___J1TZ8yvjL0AcwEoyPAfoPQ {
  RootObj Sup;
NI colonstate_;
NimStringDesc* errorPrefix1;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeClass2;
tyProc__k2HFjxisIgDALbEUFojxaQ oldWriteHook3;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* diagnostics4;
};
struct tyTuple__7ojGQ7p3GL8CscnPtcFVrQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field0;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* Field1;
};
typedef N_CLOSURE_PTR(void, TM__wjrA09aH0rT1R7zbrcCaROw_40) (NimStringDesc* output);
typedef N_CLOSURE_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, TM__wjrA09aH0rT1R7zbrcCaROw_47) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
typedef N_CLOSURE_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, TM__wjrA09aH0rT1R7zbrcCaROw_48) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fn, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
typedef N_CLOSURE_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, TM__wjrA09aH0rT1R7zbrcCaROw_55) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
typedef N_CLOSURE_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, TM__wjrA09aH0rT1R7zbrcCaROw_56) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fn, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
typedef tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* tyArray__iegsN9bf6GqRiWprrJjTAoA[1];
typedef NU8 tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow;
typedef NU16 tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw;
typedef NimStringDesc* tyArray__24KAM9afIUgUaqBaEBB6r9bg[3];
typedef NU8 tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA;
struct tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field0;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field1;
};
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
NI Field0;
NI Field1;
};
typedef NU8 tyEnum_TNodeKind__jsmc0lvQl44MLrOvpRmgJQ;
typedef NI tyArray__HU7qaqKu9czJLT84iCBJnsA[2];
typedef NU8 tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NimStringDesc* tyArray__Re75IspeoxXy2oCZHwcRrA[2];
typedef struct {
N_NIMCALL_PTR(NI, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* x, tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* y, void* ClE_0);
void* ClE_0;
} tyProc__5ZzDzBBqlwfychCMx6jbDw;
typedef NU8 tyEnum_SortOrder__TcYjciSJ3jKUT4ygglumjg;
typedef N_CLOSURE_PTR(NI, TM__wjrA09aH0rT1R7zbrcCaROw_88) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* x, tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* y, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__wjrA09aH0rT1R7zbrcCaROw_89) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result);
typedef NU8 tyEnum_TCheckPointResult__1fIaGKvTluv8QtOC3X9afKQ;
struct tyObject_CandidateError__gFDKCwBunKZtG86yhpxUMQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
tyObject_MismatchInfo__7DZVQMEKp3NTauLRe48cLw firstMismatch;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* diagnostics;
NIM_BOOL enabled;
};
typedef NU16 tySet_tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA;
typedef NU8 tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef N_CLOSURE_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, TM__wjrA09aH0rT1R7zbrcCaROw_102) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fn, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
struct tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA {
tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* key;
RootObj* val;
};
struct tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* genericSym;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ {
NI Field0;
tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ Field1;
};
struct tyTuple__toqrUPSdp8zSxOdlxMJj9cA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
struct tyTuple__VbApVidEWCFLq9a29bPtaS7A {
NI Field0;
NI Field1;
tySequence__k7EQb9bN3Uhl608xoPGMRJA* Field2;
};
struct tyTuple__EbsafWGli8bW2GRJQ9apsjA {
NI Field0;
NI Field1;
tySequence__qwqHTkRvwhrRyENtudHQ7g* Field2;
};
struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ {
tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* data;
NI counter;
};
struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ {
NI32 thisModule;
NI32 lastFile;
NU32 lastLit;
tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ filenames;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* pendingTypes;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* pendingSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw typeMarker;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw symMarker;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
};
struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ {
NU32 module;
NI32 item;
};
struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg {
NI module;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ packed_0;
};
struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
};
struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__dlD6tEGzYLLpKVq3XwuFlA* Field2;
};
struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q {
NI module;
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg sym;
tySequence__UnGSk9aaLosDroi2QDrlOfQ* concreteTypes;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__rZZA0skon1OsHdiEvT8RZQ {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__6OFCSvqRaxyEgUqWtnZSlw* Field2;
};
struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field2;
};
struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
};
struct tyTuple__RWXAsQlFoGYyEQZp1G65sg {
NI Field0;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field1;
};
struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__m4PVWjcAAjfxlwJxLkKn8A* Field2;
};
struct tyTuple__RmGJuqOgEaHckHndh0LEsw {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field2;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
};
struct tyTuple__J4cxakKjhKxTIJR9bojMmXw {
NI Field0;
NI32 Field1;
tySequence__i89c5kdtWKzK3OEiI81pkkw* Field2;
};
struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ {
NI Field0;
NI32 Field1;
tySequence__GR8qmV1kNRcoQ2g76VFy3A* Field2;
};
struct tyTuple__a7QginWFapakKbWJBJ2vfA {
tySequence__ed0C0uAUZPhvw3RAc5hfYg* Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__kbX6x85REySUrk9auORL0vw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q {
tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A* root;
NI entries;
};
struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, tyProc__kqPx9c4py2HW6KcFMhNvxtg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__9c6qRjwy7Es8UkDTIUwAfFA) (tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__mv4BsRs5VEnhcxzV6pQU5w) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
struct tyTuple__nF9cH4hinXgGEUwO4G2bshw {
tyProc__kqPx9c4py2HW6KcFMhNvxtg Field0;
tyProc__9c6qRjwy7Es8UkDTIUwAfFA Field1;
tyProc__mv4BsRs5VEnhcxzV6pQU5w Field2;
NIM_BOOL Field3;
};
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA {
NCSTRING procname;
NI line;
NCSTRING filename;
};
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
NU32 Field0;
NimStringDesc* Field1;
};
struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA {
NU16 line;
NI16 col;
NU32 file;
};
struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA {
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
NI32 operand;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeId_0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
};
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
NU32 Field0;
NI32 Field1;
};
struct tyTuple__PsEhl3dzznmmJiLAuIXZOg {
NU32 Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA Field1;
};
struct tyTuple__Db8CrQifKGIsKc3w71w7Lw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ key;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* concreteTypes;
};
struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ {
tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
NI Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
typedef NU8 tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ;
struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA {
tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
NU32 name;
NI32 path;
};
struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA {
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
NU32 name;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typ;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
NI32 ast;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ guard;
NI bitsize;
NI alignment;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
NU32 externalName;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw locFlags;
tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA annex;
NI32 constraint;
};
struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw {
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* types;
NI32 n;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeInst;
NI32 nonUniqueId;
};
struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg {
NI Field0;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* Field1;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* Field2;
};
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
NI Field0;
NI32 Field1;
NU32 Field2;
};
struct tySequence__GR8qmV1kNRcoQ2g76VFy3A {
  TGenericSeq Sup;
  tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__ed0C0uAUZPhvw3RAc5hfYg {
  TGenericSeq Sup;
  tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
struct tySequence__r9afowSCR9cYl2NdMwuF5Jtg {
  TGenericSeq Sup;
  tyTuple__7ojGQ7p3GL8CscnPtcFVrQ data[SEQ_DECL_SIZE];
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__LFzufdBEvfOUK6PWh0HUtQ {
  TGenericSeq Sup;
  tyObject_CandidateError__gFDKCwBunKZtG86yhpxUMQ data[SEQ_DECL_SIZE];
};
struct tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA {
  TGenericSeq Sup;
  tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg data[SEQ_DECL_SIZE];
};
struct tySequence__vvBerF0axaNtu9aMA2gnsrA {
  TGenericSeq Sup;
  tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q* data[SEQ_DECL_SIZE];
};
struct tySequence__ZQPym9bf1jM5qaSn7LUXMKA {
  TGenericSeq Sup;
  tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA data[SEQ_DECL_SIZE];
};
struct tySequence__9c3OY0aBmSBgwdsnBAPf4Ag {
  TGenericSeq Sup;
  tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ {
  TGenericSeq Sup;
  tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w data[SEQ_DECL_SIZE];
};
struct tySequence__Jhh6ks9carRtwV9aOuM8yMNw {
  TGenericSeq Sup;
  tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg data[SEQ_DECL_SIZE];
};
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw {
  TGenericSeq Sup;
  tyTuple__NAaJgGVgNmlGoqmiWxdOHQ data[SEQ_DECL_SIZE];
};
struct tySequence__E8pi9b5QNahsURYzXMjh3qw {
  TGenericSeq Sup;
  tyTuple__47w2DboNEPf69aPgubZdd7Q data[SEQ_DECL_SIZE];
};
struct tySequence__k7EQb9bN3Uhl608xoPGMRJA {
  TGenericSeq Sup;
  tyTuple__toqrUPSdp8zSxOdlxMJj9cA data[SEQ_DECL_SIZE];
};
struct tySequence__XDpbjnuseLNZDGLBQ2Qzow {
  TGenericSeq Sup;
  tyTuple__VbApVidEWCFLq9a29bPtaS7A data[SEQ_DECL_SIZE];
};
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  TGenericSeq Sup;
  NI data[SEQ_DECL_SIZE];
};
struct tySequence__QqvaCqCpEE1QmQZbcZLi5A {
  TGenericSeq Sup;
  tyTuple__EbsafWGli8bW2GRJQ9apsjA data[SEQ_DECL_SIZE];
};
struct tySequence__RNhZxf20g9beyq5VBOGxhDg {
  TGenericSeq Sup;
  tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ data[SEQ_DECL_SIZE];
};
struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ {
  TGenericSeq Sup;
  tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg data[SEQ_DECL_SIZE];
};
struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ {
  TGenericSeq Sup;
  tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ data[SEQ_DECL_SIZE];
};
struct tySequence__dlD6tEGzYLLpKVq3XwuFlA {
  TGenericSeq Sup;
  tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ data[SEQ_DECL_SIZE];
};
struct tySequence__ijtae5OneaLys0hN9alAicA {
  TGenericSeq Sup;
  tyTuple__UluY8x0Nj6cp9b0o88wJ0lg data[SEQ_DECL_SIZE];
};
struct tySequence__6OFCSvqRaxyEgUqWtnZSlw {
  TGenericSeq Sup;
  tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q data[SEQ_DECL_SIZE];
};
struct tySequence__SerjNoUujW2dUouVBrJiCw {
  TGenericSeq Sup;
  tyTuple__rZZA0skon1OsHdiEvT8RZQ data[SEQ_DECL_SIZE];
};
struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g {
  TGenericSeq Sup;
  tyTuple__q13Zt16VkCqu6Zg5jWqwHA data[SEQ_DECL_SIZE];
};
struct tySequence__m4PVWjcAAjfxlwJxLkKn8A {
  TGenericSeq Sup;
  tyTuple__RWXAsQlFoGYyEQZp1G65sg data[SEQ_DECL_SIZE];
};
struct tySequence__m88qdML9cQOuqGAQn6XWL1A {
  TGenericSeq Sup;
  tyTuple__aWN9bNzF9bubXNJV9ciomgpfA data[SEQ_DECL_SIZE];
};
struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ {
  TGenericSeq Sup;
  tyTuple__RmGJuqOgEaHckHndh0LEsw data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__i89c5kdtWKzK3OEiI81pkkw {
  TGenericSeq Sup;
  tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A data[SEQ_DECL_SIZE];
};
struct tySequence__KgiZ29chkJAD01p9aLRB32qw {
  TGenericSeq Sup;
  tyTuple__J4cxakKjhKxTIJR9bojMmXw data[SEQ_DECL_SIZE];
};
struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw {
  TGenericSeq Sup;
  tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ data[SEQ_DECL_SIZE];
};
struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ {
  TGenericSeq Sup;
  tyTuple__a7QginWFapakKbWJBJ2vfA data[SEQ_DECL_SIZE];
};
struct tySequence__YmPd0eWfcTfrVYrthlXPYA {
  TGenericSeq Sup;
  tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg {
  TGenericSeq Sup;
  tyTuple__kbX6x85REySUrk9auORL0vw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ {
  TGenericSeq Sup;
  tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g data[SEQ_DECL_SIZE];
};
struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q {
  TGenericSeq Sup;
  tyTuple__nF9cH4hinXgGEUwO4G2bshw data[SEQ_DECL_SIZE];
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
struct tySequence__QbmGqFaLnb1IWWToREeaIA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA data[SEQ_DECL_SIZE];
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  TGenericSeq Sup;
  tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE];
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  TGenericSeq Sup;
  NU32 data[SEQ_DECL_SIZE];
};
struct tySequence__4Murtwnm0Fyc7F9acrytEXw {
  TGenericSeq Sup;
  tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA data[SEQ_DECL_SIZE];
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  TGenericSeq Sup;
  tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE];
};
struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw {
  TGenericSeq Sup;
  tyTuple__PsEhl3dzznmmJiLAuIXZOg data[SEQ_DECL_SIZE];
};
struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg {
  TGenericSeq Sup;
  tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w data[SEQ_DECL_SIZE];
};
struct tySequence__oKtVqsc9bQVCNyrijELM4OQ {
  TGenericSeq Sup;
  tyTuple__Db8CrQifKGIsKc3w71w7Lw data[SEQ_DECL_SIZE];
};
struct tySequence__qy6Iwdy00wN560qud54HTg {
  TGenericSeq Sup;
  tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg data[SEQ_DECL_SIZE];
};
struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ {
  TGenericSeq Sup;
  tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ data[SEQ_DECL_SIZE];
};
struct tySequence__cLsClAAfd0MKkoBQVyvdvw {
  TGenericSeq Sup;
  tyTuple__FEYH9alRJhHD0uTKF2vnIqw data[SEQ_DECL_SIZE];
};
struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg {
  TGenericSeq Sup;
  tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA data[SEQ_DECL_SIZE];
};
struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw {
  TGenericSeq Sup;
  tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw data[SEQ_DECL_SIZE];
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  TGenericSeq Sup;
  NI64 data[SEQ_DECL_SIZE];
};
struct tySequence__lo3S1lKyiPLhGGB9cBawd6A {
  TGenericSeq Sup;
  tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ data[SEQ_DECL_SIZE];
};
struct tySequence__C3r8jsj9chA4sIlYfDN5aDw {
  TGenericSeq Sup;
  tyTuple__VUJ5Hjm4tKAResBsRHJvYg data[SEQ_DECL_SIZE];
};
struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g {
  TGenericSeq Sup;
  tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg data[SEQ_DECL_SIZE];
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  TGenericSeq Sup;
  tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE];
};
struct tySequence__UnGSk9aaLosDroi2QDrlOfQ {
  TGenericSeq Sup;
  tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, exactEquals__msgs_1007)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw a, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw b);
N_LIB_PRIVATE N_NIMCALL(void, suggestExprNoCheck__sigmatch_6236)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, sugExpr__sigmatch_6203)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySequence__GR8qmV1kNRcoQ2g76VFy3A** outputs);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, safeSemExpr__sigmatch_6197)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(void, pushSafePoint)(TSafePoint* s);
static N_INLINE(void, popSafePoint)(void);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isObj)(TNimType* obj, TNimType* subclass);
static N_INLINE(Exception*, nimBorrowCurrentException)(void);
static N_INLINE(void, popCurrentException)(void);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5302)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5264)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5309)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5307)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5258)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(void, reraiseException)(void);
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, suggestFieldAccess__sigmatch_5259)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* field, tySequence__GR8qmV1kNRcoQ2g76VFy3A** outputs);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, initTabIter__astalgo_3770)(tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw* ti, tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tab);
static N_INLINE(NIM_BOOL, filterSym__sigmatch_4938)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* prefix, tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ* res);
N_LIB_PRIVATE N_NIMCALL(tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ, prefixMatch__sigmatch_4943)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ, prefixMatch__prefixmatches_10)(NimStringDesc* p, NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg*, symToSuggest__sigmatch_4569)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NIM_BOOL isLocal, tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg section, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NI quality, tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ prefix, NIM_BOOL inTypeContext, NI scope, NIM_BOOL useSuppliedInfo, NU16 endLine, NI endCol);
N_LIB_PRIVATE N_NOINLINE(void*, newObj)(TNimType* typ, NI size);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(NIM_BOOL, contains__pureZtimes_2292)(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw s, NI value);
static N_INLINE(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw, dotdot___pureZunicode_840)(NI a, NI b);
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, typeToString__types_50)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg prefer);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPath__msgs_548)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
static N_INLINE(NI, toLinenumber__msgs_619)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
static N_INLINE(NI, toColumn__msgs_622)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(NI, getTokenLenFromSource__sigmatch_4492)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* ident, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tyRef__2F9cu9at6fEkJGwU3CoFWY3A)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, sourceLine__msgs_1111)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw i);
N_LIB_PRIVATE N_CLOSURE(NIM_BOOL, isOpeningBacktick__sigmatch_4499)(NI col, void* ClE_0);
static N_INLINE(NI, skipUntil__pureZparseutils_148)(NimStringDesc* s, NIM_CHAR until, NI start);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreStyle)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NimStringDesc*, X5BX5D___pureZunicode_865)(NimStringDesc* s, tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw x);
N_NIMCALL(NimStringDesc*, mnewString)(NI len);
static N_INLINE(NIM_CHAR, X5BX5D___system_7321)(NimStringDesc* s, NI i);
N_LIB_PRIVATE N_NIMCALL(NI, identLen__linter_13)(NimStringDesc* line, NI start);
static N_INLINE(NI, parseWhile__pureZparseutils_226)(NimStringDesc* s, NimStringDesc** token, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw validChars, NI start);
N_LIB_PRIVATE N_NIMCALL(void, fastSubstr__pureZparseutils_170)(NimStringDesc* s, NimStringDesc** token, NI start, NI length);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(NI, getQuality__sigmatch_5031)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
static N_INLINE(NI, len__ast_3990)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, skipTypes__ast_3723)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kinds);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, elemType__types_263)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, nextIter__astalgo_3755)(tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw* ti, tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tab);
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_2722)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m);
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_2710)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI module);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, initRodIterAllSyms__icZic_8670)(tyObject_RodIter__L6nv9cakjPARHk068AFo6ww* it, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI32 module, NIM_BOOL importHidden);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, nextRodIter__icZic_8980)(tyObject_RodIter__L6nv9cakjPARHk068AFo6ww* it, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g);
N_LIB_PRIVATE N_NIMCALL(void, suggestEverything__sigmatch_5246)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* f, tySequence__GR8qmV1kNRcoQ2g76VFy3A** outputs);
N_LIB_PRIVATE N_NIMCALL(void, suggestSymList__sigmatch_5069)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* list, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* f, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tySequence__GR8qmV1kNRcoQ2g76VFy3A** outputs);
N_LIB_PRIVATE N_NIMCALL(void, suggestField__sigmatch_5055)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* f, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tySequence__GR8qmV1kNRcoQ2g76VFy3A** outputs);
static N_INLINE(NIM_BOOL, fieldVisible__sigmatch_4973)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* f);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getModule__astalgo_216)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, suggestObject__sigmatch_5089)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* f, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tySequence__GR8qmV1kNRcoQ2g76VFy3A** outputs);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, lastSon__ast_4833)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, suggestOperations__sigmatch_5223)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tySequence__GR8qmV1kNRcoQ2g76VFy3A** outputs);
static N_INLINE(NIM_BOOL, filterSymNoOpr__sigmatch_4964)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* prefix, tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ* res);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isKeyword__renderer_73)(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* i);
static N_INLINE(NIM_BOOL, typeFits__sigmatch_5182)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* firstArg);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, argtypeMatches__sigmatch_4322)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, NIM_BOOL fromHlo);
N_LIB_PRIVATE N_NIMCALL(void, newCandidate__sigmatch_195)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* ctx, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* callee, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* Result);
N_LIB_PRIVATE N_NIMCALL(void, initCandidate__sigmatch_116)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* ctx, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* callee);
static N_INLINE(void, initCandidateAux__sigmatch_94)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* ctx, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* callee);
N_LIB_PRIVATE N_NIMCALL(void, initIdTable__ast_4084)(tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, paramTypesMatch__sigmatch_3620)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* argOrig);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, paramTypesMatchAux__sigmatch_3296)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* argSemantized, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* argOrig);
N_LIB_PRIVATE N_NIMCALL(void, assignType__ast_3964)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* dest, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeIT__ast_3342)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, makeTypeFromExpr__semdata_834)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, newTypeS__semdata_763)(tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqRC1)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, copyTree__ast_4432)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* src);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA, typeRel__sigmatch_202)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* aOrig, tySet_tyEnum_TTypeRelFlag__nkWaH9aZ1YawZFP9aSlbYFMw flags);
static N_INLINE(void, put__sigmatch_120)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* key, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* val);
N_LIB_PRIVATE N_NIMCALL(void, idTablePut__astalgo_70)(tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ* t, tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* key, RootObj* val);
static N_INLINE(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, skipIntLit__magicsys_124)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* id);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, copyType__ast_4034)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg id, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner);
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextTypeId__ast_3122)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, lastSon__ast_3731)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n);
N_LIB_PRIVATE N_NIMCALL(RootObj*, idTableGet__astalgo_64)(tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ t, tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tryResolvingStaticExpr__sigmatch_1227)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL allowUnresolved);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, replaceTypesInBody__semtypinst_1024)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* p, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, NIM_BOOL allowMetaTypes);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, base__types_63)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(void, add__concepts_23)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* father, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, maybeSkipDistinct__sigmatch_1210)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* callee);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, shouldSkipDistinct__sigmatch_1199)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* rules, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* callIdent);
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NIM_BOOL, eqeq___idents_229)(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* a, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*, considerQuotedIdent__lookups_29)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* origin);
static N_INLINE(NIM_BOOL, sameEnumTypes__types_2152)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* b);
N_LIB_PRIVATE N_NOINLINE(tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA, typeRangeRel__sigmatch_981)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isOrdinalType__types_299)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, NIM_BOOL allowEnumWithHoles);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___int495056_425)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, firstOrd__types_1406)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, lastOrd__types_1530)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lteq___int495056_421)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b);
N_LIB_PRIVATE N_NIMCALL(NF, firstFloat__types_1505)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(NF, lastFloat__types_1644)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isConvertibleToRange__sigmatch_548)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a);
static N_INLINE(NIM_BOOL, isIntLit__types_186)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA, handleRange__sigmatch_476)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg min, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg max);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, getInt__ast_4593)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lteq___int495056_938)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, NI64 b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lteq___int495056_945)(NI64 a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA, handleFloatRange__sigmatch_596)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a);
static N_INLINE(NIM_BOOL, isFloatLit__types_201)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isCovariantPtr__sigmatch_1405)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA, inferStaticsInRange__sigmatch_1370)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* inferred, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* concrete);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___int495056_952)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, NI64 b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, lengthOrd__types_1717)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, minus___int495056_973)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, NI64 b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, plus___int495056_987)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, NI64 b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, inferStaticParam__sigmatch_1235)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lhs, NI64 rhs);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, newTypeWithSons__semdata_851)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind, tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newIntNode__ast_3711)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, NI64 intVal);
N_LIB_PRIVATE N_NIMCALL(NI64, toInt64__int495056_88)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ arg);
N_LIB_PRIVATE N_NIMCALL(void, failureToInferStaticParam__sigmatch_1361)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, findUnresolvedStatic__ast_4957)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, minus___int495056_637)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA, recordRel__sigmatch_806)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameType__types_1880)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* b, tySet_tyEnum_TTypeCmpFlag__IRq9bqtrf9ctEUyeRMyvWy4Q flags);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA, minRel__sigmatch_798)(tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA a, tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameObjectTypes__types_2103)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* b);
N_LIB_PRIVATE N_NIMCALL(NI, isObjectSubtype__sigmatch_656)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* fGenericOrigin);
N_LIB_PRIVATE N_NIMCALL(void, genericParamPut__sigmatch_622)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* last, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* fGenericOrigin);
static N_INLINE(NIM_BOOL, sameDistinctTypes__types_2148)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* b);
static N_INLINE(tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA, allowsNil__sigmatch_875)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA, procTypeRel__sigmatch_927)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA, procParamTypeRel__sigmatch_898)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isMetaType__ast_3474)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, generateTypeInstance__semtypinst_1086)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* p, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
static N_INLINE(NIM_BOOL, inconsistentVarTypes__sigmatch_882)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a);
N_LIB_PRIVATE N_NIMCALL(tyTuple__hwJj4UwOYfHl0hX52kYcPQ, getProcConvMismatch__types_3753)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA rel);
N_LIB_PRIVATE N_NIMCALL(tyEnum_EffectsCompat__Ua7UNlEurqcdZ8OG3EY7xA, compatibleEffects__types_3483)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formal, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* actual);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, skipGenericAlias__types_2275)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, prepareMetatypeForSigmatch__semtypinst_1100)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* p, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_1441)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, conceptMatch__concepts_538)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* concpt, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* arg, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ* bindings, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* invocation);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, skipToObject__sigmatch_703)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyEnum_SkippedPtr__ZfkN1Zg3tYB8pQTEnxqNcg* skipped);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isGenericSubtype__sigmatch_744)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, NI* d, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* fGenericOrigin);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, concreteType__sigmatch_443)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isEmptyContainer__types_3684)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, matchUserTypeClass__sigmatch_993)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ff, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a);
static N_NIMCALL(void, Marker_tyRef__LPNfKrTCyieb604nvY2VZA)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___renderer_2116)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ*, openScope__lookups_76)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, newSym__ast_3409)(tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw symKind, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg id, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options);
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextSymId__ast_3103)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, exactReplica__ast_4039)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(void*, newSeq)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, makeTypeDesc__concepts_49)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
static N_NIMCALL(void, Marker_tySequence__r9afowSCR9cYl2NdMwuF5Jtg)(void* p, NI op);
static N_INLINE(void, addDecl__lookups_1517)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
static N_INLINE(void, addDeclAt__lookups_1509)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(void, addDeclAt__lookups_995)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___sigmatch_1102)(NimStringDesc* s, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuReplaceStr)(NimStringDesc* s, NimStringDesc* sub, NimStringDesc* by);
N_LIB_PRIVATE N_NIMCALL(void, closeScope__lookups_108)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
N_LIB_PRIVATE N_NIMCALL(void, nimLeaveFinally)(void);
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_625)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_167)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(void, transitionGenericParamToType__ast_4391)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, exprStructuralEquivalent__trees_56)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b, NIM_BOOL strictSymEquality);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, makeStaticExpr__semdata_856)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, incMatches__sigmatch_3266)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m, tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA r, NI convMatch);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newSymNode__ast_3707)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, implicitConv__sigmatch_3095)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeI__ast_3320)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsGenericType__types_3406)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, getInstantiatedType__sigmatch_3081)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, errorType__semdata_1032)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_4798)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newProcNode__ast_3809)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* params, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* name, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pattern, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* genericParams, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pragmas, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* exceptions);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newTree__ast_3356)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** children, NI childrenLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, userConvMatch__sigmatch_3123)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, matchNodeKinds__parampatterns_505)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NIM_BOOL, isLValue__sigmatch_3118)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow, isAssignable__parampatterns_334)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL isUnsafeAddr);
N_LIB_PRIVATE N_NIMCALL(void, markUsed__sigmatch_85)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, warnAboutDeprecated__sigmatch_5454)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, extractPragma__sigmatch_5411)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__systemZassertions_56)(NimStringDesc* msg);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw, whichPragma__trees_244)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, userError__sigmatch_5487)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_629)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toMsgFilename__msgs_612)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, belongsToProjectPackage__packages_50)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(void, styleCheckUseImpl__linter_158)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, markOwnerModuleAsUsed__sigmatch_89)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(NI, getOrDefault__sigmatch_5637)(tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg t, NI key, NI default_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__sigmatch_5788)(tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ s, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ key);
N_LIB_PRIVATE N_NIMCALL(void, del__sigmatch_6088)(tySequence__Jhh6ks9carRtwV9aOuM8yMNw** x, NI i);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newSymNode__ast_3704)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
static N_INLINE(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newDeref__lowerings_11)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, localConvMatch__sigmatch_3209)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg);
N_LIB_PRIVATE N_NIMCALL(void, transitionSonsKind__ast_4347)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyEnum_TNodeKind__jsmc0lvQl44MLrOvpRmgJQ kind);
N_LIB_PRIVATE N_NIMCALL(void, copyCandidate__sigmatch_199)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* a, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* b);
N_LIB_PRIVATE N_NIMCALL(void, copyIdTable__ast_3589)(tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ* dest, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ src);
N_LIB_PRIVATE N_NIMCALL(void, genericAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(NI, cmpCandidates__sigmatch_358)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* a, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* b);
N_LIB_PRIVATE N_NIMCALL(NI, checkGeneric__sigmatch_207)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* a, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* b);
N_LIB_PRIVATE N_NIMCALL(NI, complexDisambiguation__sigmatch_336)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* b);
N_LIB_PRIVATE N_NIMCALL(NI, sumGeneric__sigmatch_261)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
static N_INLINE(NIM_BOOL, contains__sigmatch_4340)(NI* a, NI aLen_0, NI item);
static N_INLINE(NI, find__sigmatch_4345)(NI* a, NI aLen_0, NI item);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, copyNode__ast_4324)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* src);
N_LIB_PRIVATE N_NIMCALL(void, suggestCall__sigmatch_5153)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nOrig, tySequence__GR8qmV1kNRcoQ2g76VFy3A** outputs);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nameFits__sigmatch_5120)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, argsFit__sigmatch_5142)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* candidate, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nOrig);
N_LIB_PRIVATE N_NIMCALL(void, newCandidate__sigmatch_189)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* ctx, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* callee, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* binding, NI calleeScope, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* Result);
N_LIB_PRIVATE N_NIMCALL(void, initCandidate__sigmatch_124)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* ctx, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* callee, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* binding, NI calleeScope, NIM_BOOL diagnosticsEnabled);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, originatingModule__ast_4670)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, skipGenericOwner__ast_4659)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, partialMatch__sigmatch_4216)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nOrig, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m);
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(void, initPackedSet__pureZcollectionsZintsets_16)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(void, matchesAux__sigmatch_3825)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nOrig, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* marker);
N_LIB_PRIVATE N_NIMCALL(NI, findFirstArgBlock__sigmatch_3783)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, openShadowScope__lookups_1575)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
N_LIB_PRIVATE N_NIMCALL(void, incl__pureZcollectionsZintsets_55)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(void, setSon__sigmatch_3687)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, NI at, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* son);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, arrayConstr__sigmatch_3762)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, rawAddSon__ast_4276)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* father, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* son, NIM_BOOL propagateHasAsgn);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, makeRangeType__semdata_1069)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, NI64 first, NI64 last, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* intType);
N_LIB_PRIVATE N_NIMCALL(void, incrIndexType__sigmatch_3766)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(void, prepareNamedParam__sigmatch_3746)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newIdentNode__ast_3700)(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, mergeShadowScope__lookups_1579)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getNamedParamFromList__astalgo_293)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* list, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__astalgo_402)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, prepareOperand__sigmatch_3700)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formal, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a);
N_LIB_PRIVATE N_NIMCALL(void, considerGenSyms__semdata_437)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, arrayConstr__sigmatch_3758)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, addSonSkipIntLit__magicsys_136)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* father, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* son, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* id);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, prepareOperand__sigmatch_3737)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, getSysType__magicsys_60)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind);
N_LIB_PRIVATE N_NIMCALL(void, closeShadowScope__lookups_1577)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
N_LIB_PRIVATE N_NIMCALL(void, suggestVar__sigmatch_5168)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySequence__GR8qmV1kNRcoQ2g76VFy3A** outputs);
N_LIB_PRIVATE N_NIMCALL(void, produceOutput__sigmatch_4809)(tySequence__GR8qmV1kNRcoQ2g76VFy3A** a, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, sort__sigmatch_4818)(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg** a, NI aLen_0, tyProc__5ZzDzBBqlwfychCMx6jbDw cmp, tyEnum_SortOrder__TcYjciSJ3jKUT4ygglumjg order);
N_LIB_PRIVATE N_NIMCALL(NI, cmpSuggestions__sigmatch_4477)(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* a, tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* b);
N_LIB_PRIVATE N_NIMCALL(NI, cmp__system_1549)(NimStringDesc* x, NimStringDesc* y);
N_LIB_PRIVATE N_NIMCALL(void, suggestWriteln__msgs_431)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___sigmatch_4762)(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* suggest);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___options_4702)(tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___systemZdollars_3)(NI x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuJoinSep)(NimStringDesc** a, NI aLen_0, NimStringDesc* sep);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___systemZdollars_9)(NU64 x);
N_LIB_PRIVATE N_NIMCALL(void, suggestQuit__msgs_456)(void);
static N_NIMCALL(void, Marker_tySequence__LFzufdBEvfOUK6PWh0HUtQ)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderTree__renderer_46)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA renderFlags);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, argTypeToString__sigmatch_362)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg, tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg prefer);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatSingleElem)(NimStringDesc* formatstr, NimStringDesc* a);
N_LIB_PRIVATE N_NIMCALL(void, suggestExpr__sigmatch_6331)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw, newLineInfo__msgs_391)(NI32 fileInfoIdx, NI line, NI col);
extern TNimType NTIerecoverableerror__aRVEU9aWMU9b9a9baYZqUd3t9cA_;
extern TNimType NTIsuggest__vIaEYib9am0Aa2d8J2uMYdQ_;
extern TNimType NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_;
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__wjrA09aH0rT1R7zbrcCaROw_3 = {
0x00, 0x00, 0x00, 0x00, 0x72, 0xed, 0x00, 0xf4,
0x01, 0x00, 0x00, 0x58, 0x00, 0x00, 0x00, 0x58,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
extern TNimType NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_;
N_LIB_PRIVATE TNimType NTIobject__JTQD63EOMNGYBEyDiI65hA_;
extern TNimType NTIint__xHTZrq9aYs6boc9bCba0JbpQ_;
extern TNimType NTIstring__77mFvmsOLKik79ci2hXkHEg_;
N_LIB_PRIVATE TNimType NTIrefobject__2F9cu9at6fEkJGwU3CoFWY3A_;
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__wjrA09aH0rT1R7zbrcCaROw_8 = {
0x00, 0x00, 0x00, 0x00, 0x72, 0xef, 0x00, 0xf4,
0x01, 0x00, 0x00, 0x78, 0x00, 0x00, 0x00, 0x78,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_9, "=", 1);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__wjrA09aH0rT1R7zbrcCaROw_10 = {
0x10, 0x08, 0x80, 0x00, 0x00, 0xc0, 0x00, 0x00,
0x00}
;
extern TNimType NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__wjrA09aH0rT1R7zbrcCaROw_11 = {
0x10, 0x09, 0xe0, 0x00, 0x00, 0xe0, 0x00, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__wjrA09aH0rT1R7zbrcCaROw_12 = {
0x10, 0x09, 0xe0, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__wjrA09aH0rT1R7zbrcCaROw_13 = {
0x00, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
extern TNimType NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__wjrA09aH0rT1R7zbrcCaROw_14 = {
0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__wjrA09aH0rT1R7zbrcCaROw_15 = {
0x00, 0x00, 0x80, 0x00, 0x00, 0xc0, 0x00, 0x10,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__wjrA09aH0rT1R7zbrcCaROw_16 = {
0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
extern NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg abstractInst__ast_356;
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_17, "unknown", 7);
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_18, "cannot infer the value of the static param \'", 44);
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_19, "\'", 1);
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_21, "/home/runner/work/nightlies/nightlies/nim/compiler/sigmatch.nim", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wjrA09aH0rT1R7zbrcCaROw_20 = {((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_21),
((NI) 886),
((NI) 12)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__wjrA09aH0rT1R7zbrcCaROw_22 = {
0x00, 0x08, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__wjrA09aH0rT1R7zbrcCaROw_23 = {
0x00, 0x08, 0x10, 0x00, 0x00, 0x20, 0x00, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__wjrA09aH0rT1R7zbrcCaROw_24 = {
0x10, 0xa9, 0x00, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__wjrA09aH0rT1R7zbrcCaROw_25 = {
0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
extern NIM_CONST tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw unknownLineInfo__lineinfos_284;
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_26, "wrong instantiated type!", 24);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wjrA09aH0rT1R7zbrcCaROw_27 = {((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_21),
((NI) 1511),
((NI) 23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wjrA09aH0rT1R7zbrcCaROw_28 = {((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_21),
((NI) 1545),
((NI) 25)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__wjrA09aH0rT1R7zbrcCaROw_29 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__wjrA09aH0rT1R7zbrcCaROw_30 = {
0x10, 0x08, 0x10, 0x00, 0x00, 0x60, 0x08, 0x00,
0x00}
;
N_LIB_PRIVATE TNimType NTIobject__J1TZ8yvjL0AcwEoyPAfoPQ_;
extern TNimType NTIptype__q1v0zzhoMWrhMLs6UEp1IA_;
extern TNimType NTIprocLoutput58stringTLOclosureOT__k2HFjxisIgDALbEUFojxaQ_;
N_LIB_PRIVATE TNimType NTIrefobject__LPNfKrTCyieb604nvY2VZA_;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__wjrA09aH0rT1R7zbrcCaROw_32 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x00,
0x00}
;
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_33, " too nested for type matching", 29);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wjrA09aH0rT1R7zbrcCaROw_34 = {((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_21),
((NI) 670),
((NI) 16)}
;
N_LIB_PRIVATE TNimType NTILpsym_ptypeT__7ojGQ7p3GL8CscnPtcFVrQ_;
extern TNimType NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_;
N_LIB_PRIVATE TNimType NTIseqLLpsym_ptypeTT__r9afowSCR9cYl2NdMwuF5Jtg_;
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_37, ":", 1);
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_38, "Error:", 6);
static NIM_CONST tyProc__k2HFjxisIgDALbEUFojxaQ TM__wjrA09aH0rT1R7zbrcCaROw_39 = {NIM_NIL,NIM_NIL};
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_41, "(", 1);
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_42, ", ", 2);
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_43, ")", 1);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wjrA09aH0rT1R7zbrcCaROw_44 = {((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_21),
((NI) 1685),
((NI) 27)}
;
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_45, " unknown type kind ", 19);
extern TNimType NTIttypekind__b28l2MkhJpnFhatVrsrXpg_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wjrA09aH0rT1R7zbrcCaROw_46 = {((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_21),
((NI) 1858),
((NI) 18)}
;
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_49, "getInstantiatedType", 19);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wjrA09aH0rT1R7zbrcCaROw_50 = {((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_21),
((NI) 1885),
((NI) 17)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__wjrA09aH0rT1R7zbrcCaROw_51 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__wjrA09aH0rT1R7zbrcCaROw_52 = {
0x00, 0x00, 0x80, 0x00, 0x00, 0x40, 0x00, 0x00,
0x00}
;
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_53, "implicitConv", 12);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wjrA09aH0rT1R7zbrcCaROw_54 = {((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_21),
((NI) 1898),
((NI) 37)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__wjrA09aH0rT1R7zbrcCaROw_57 = {
0x10, 0xa8, 0x80, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_58, "suggest.nim(556, 12) `result == nil or result.kind == nkPragma` ", 64);
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_59, "enum \'", 6);
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_60, "\' which contains field \'", 24);
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_61, "; ", 2);
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_62, " is deprecated", 14);
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_64, "/home/runner/work/nightlies/nightlies/nim/compiler/suggest.nim", 62);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wjrA09aH0rT1R7zbrcCaROw_63 = {((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_64),
((NI) 568),
((NI) 15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wjrA09aH0rT1R7zbrcCaROw_65 = {((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_64),
((NI) 570),
((NI) 9)}
;
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_66, "$1usage of \'$2\' is an {.error.} defined at $3", 45);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wjrA09aH0rT1R7zbrcCaROw_67 = {((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_64),
((NI) 581),
((NI) 12)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wjrA09aH0rT1R7zbrcCaROw_68 = {((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_64),
((NI) 583),
((NI) 6)}
;
extern NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw Letters__linter_12;
N_LIB_PRIVATE TNimType NTItcandidate__9b35s9cLOLunJ2l2Vo3cQTlw_;
extern TNimType NTIpcontext__C5LQliQ3Detta8PpLynVjQ_;
extern TNimType NTIint__rR5Bzr1D5krxoo1NcNyeMA_;
N_LIB_PRIVATE TNimType NTItcandidatestate__OWU1uSiYyPkPf9adpdtClBg_;
extern TNimType NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_;
extern TNimType NTItidtable__Cs7vbulfMjKciTA2Uv9b6vQ_;
extern TNimType NTItmagic__3qAy6bDUDlF8Fc2RR6pF9ag_;
extern TNimType NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_;
N_LIB_PRIVATE TNimType NTImismatchinfo__7DZVQMEKp3NTauLRe48cLw_;
N_LIB_PRIVATE TNimType NTImismatchkind__4mf6T2YBNEEtWBTWMSzL9bw_;
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_77, "x.state is not csMatch", 22);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wjrA09aH0rT1R7zbrcCaROw_78 = {((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_21),
((NI) 2261),
((NI) 21)}
;
static NIM_CONST tyArray__HU7qaqKu9czJLT84iCBJnsA TM__wjrA09aH0rT1R7zbrcCaROw_79 = {((NI) 0),
((NI) 256)}
;
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_80, "sigmatch.nim(2403, 18) `n[a][0].kind == nkEmpty and n[a][1].kind in {nkBracket, nkArgList}` ", 92);
extern TNimType NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_;
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_81, "named parameter has to be an identifier", 39);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wjrA09aH0rT1R7zbrcCaROw_82 = {((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_21),
((NI) 2420),
((NI) 18)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__wjrA09aH0rT1R7zbrcCaROw_83 = {
0x00, 0x88, 0x80, 0x00, 0x00, 0x80, 0x00, 0x00,
0x00}
;
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_84, "matches", 7);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wjrA09aH0rT1R7zbrcCaROw_85 = {((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_21),
((NI) 2488),
((NI) 23)}
;
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_86, "cannot convert $1 to $2", 23);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wjrA09aH0rT1R7zbrcCaROw_87 = {((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_21),
((NI) 2540),
((NI) 22)}
;
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_90, "skGlobalVar", 11);
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_91, "skGlobalLet", 11);
extern TNimType NTItsymkind__sjiB9b9aO1FRPetW6gPYZbfw_;
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_92, ".", 1);
extern TNimType NTIprefixmatch__Y9cGLq2K6rNefjjqfIC9bauQ_;
N_LIB_PRIVATE TNimType NTIcandidateerror__gFDKCwBunKZtG86yhpxUMQ_;
N_LIB_PRIVATE TNimType NTIcandidateerrors__LFzufdBEvfOUK6PWh0HUtQ_;
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_94, ": ", 2);
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_95, " | ", 3);
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_96, "void", 4);
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_97, "The default parameter \'$1\' has incompatible type with the explicitly requested proc instantiation", 97);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wjrA09aH0rT1R7zbrcCaROw_98 = {((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_21),
((NI) 2602),
((NI) 20)}
;
STRING_LITERAL(TM__wjrA09aH0rT1R7zbrcCaROw_99, "cannot instantiate: \'", 21);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wjrA09aH0rT1R7zbrcCaROw_100 = {((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_21),
((NI) 2644),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wjrA09aH0rT1R7zbrcCaROw_101 = {((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_21),
((NI) 2653),
((NI) 14)}
;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern Exception* currException__system_2566;
extern Exception* currException__system_2566;
extern Exception* currException__system_2566;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5211;
static N_INLINE(void, pushSafePoint)(TSafePoint* s) {
	(*s).prev = excHandler__system_2565;
	excHandler__system_2565 = s;
}
static N_INLINE(void, popSafePoint)(void) {
	excHandler__system_2565 = (*excHandler__system_2565).prev;
}
static N_INLINE(Exception*, nimBorrowCurrentException)(void) {
	Exception* result;
	result = NIM_NIL;
	result = currException__system_2566;
	return result;
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5302)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5264)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5307)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5258((&gch__system_5211.zct), c);
}
static N_INLINE(void, decRef__system_5309)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5307(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5264(src);
		incRef__system_5302(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5264((*dest));
		decRef__system_5309(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, popCurrentException)(void) {
	asgnRef((void**) (&currException__system_2566), (*currException__system_2566).up);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, safeSemExpr__sigmatch_6197)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* volatile result;
	TSafePoint TM__wjrA09aH0rT1R7zbrcCaROw_2;
	result = NIM_NIL;
	pushSafePoint(&TM__wjrA09aH0rT1R7zbrcCaROw_2);
	TM__wjrA09aH0rT1R7zbrcCaROw_2.status = _setjmp(TM__wjrA09aH0rT1R7zbrcCaROw_2.context);
	if (TM__wjrA09aH0rT1R7zbrcCaROw_2.status == 0) {
	result = (*c).semExpr(c, n, 0, ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIerecoverableerror__aRVEU9aWMU9b9a9baYZqUd3t9cA_))) {
			TM__wjrA09aH0rT1R7zbrcCaROw_2.status = 0;
			result = (*(*c).graph).emptyNode;
			popCurrentException();
		}
	}
	if (TM__wjrA09aH0rT1R7zbrcCaROw_2.status != 0) reraiseException();
	return result;
}
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ, prefixMatch__sigmatch_4943)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ result;
	result = (tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	{
		result = prefixMatch__prefixmatches_10((*(*n)._kind_5.ident).s, (*(*s).name).s);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		result = prefixMatch__prefixmatches_10((*(*(*n)._kind_4.sym).name).s, (*(*s).name).s);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 57):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 56):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 53):
	{
		{
			NI T6_;
			T6_ = (NI)0;
			T6_ = len__ast_3155(n);
			if (!(((NI) 0) < T6_)) goto LA7_;
			result = prefixMatch__sigmatch_4943(s, (*n)._kind_6.sons->data[((NI) 0)]);
		}
		LA7_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	return result;
}
static N_INLINE(NIM_BOOL, filterSym__sigmatch_4938)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* prefix, tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ* res) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		if (!!(((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6)))) goto LA3_;
		{
			if (!!((prefix == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA7_;
			(*res) = prefixMatch__sigmatch_4943(s, prefix);
			result = !(((*res) == ((tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ) 0)));
		}
		goto LA5_;
		LA7_: ;
		{
			result = NIM_TRUE;
		}
		LA5_: ;
	}
	LA3_: ;
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5264(p);
	decRef__system_5309(T1_);
}
static N_INLINE(NIM_BOOL, contains__pureZtimes_2292)(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw s, NI value) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (s.a <= value);
	if (!(T1_)) goto LA2_;
	T1_ = (value <= s.b);
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw, dotdot___pureZunicode_840)(NI a, NI b) {
	tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw));
	result.a = a;
	result.b = b;
	return result;
}
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c) {
	(*dest).data[(*dest).Sup.len] = c;
	(*dest).data[(NI)((*dest).Sup.len + ((NI) 1))] = 0;
	(*dest).Sup.len += ((NI) 1);
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(NI, toLinenumber__msgs_619)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NI result;
	result = (NI)0;
	result = ((NI) (info.line));
	return result;
}
static N_INLINE(NI, toColumn__msgs_622)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NI result;
	result = (NI)0;
	result = ((NI) (info.col));
	return result;
}
static N_NIMCALL(void, Marker_tyRef__2F9cu9at6fEkJGwU3CoFWY3A)(void* p, NI op) {
	tyObject_Env_suggestdotnim_getTokenLenFromSource___JTQD63EOMNGYBEyDiI65hA* a;
	a = (tyObject_Env_suggestdotnim_getTokenLenFromSource___JTQD63EOMNGYBEyDiI65hA*)p;
	nimGCvisit((void*)(*a).line1, op);
}
N_LIB_PRIVATE N_CLOSURE(NIM_BOOL, isOpeningBacktick__sigmatch_4499)(NI col, void* ClE_0) {
	NIM_BOOL result;
	tyObject_Env_suggestdotnim_getTokenLenFromSource___JTQD63EOMNGYBEyDiI65hA* colonenvP_;
	result = (NIM_BOOL)0;
	colonenvP_ = (tyObject_Env_suggestdotnim_getTokenLenFromSource___JTQD63EOMNGYBEyDiI65hA*) ClE_0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((NI) 0) <= col);
		if (!(T3_)) goto LA4_;
		T3_ = (col < ((*colonenvP_).line1 ? (*colonenvP_).line1->Sup.len : 0));
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			tyProc__cOOsXj9cY0bKt2oqNqLbhZw T11_;
			NIM_BOOL T12_;
			if (!((NU8)((*colonenvP_).line1->data[col]) == (NU8)(96))) goto LA9_;
			nimZeroMem((void*)(&T11_), sizeof(tyProc__cOOsXj9cY0bKt2oqNqLbhZw));
			T11_.ClP_0 = isOpeningBacktick__sigmatch_4499; T11_.ClE_0 = colonenvP_;
			T12_ = (NIM_BOOL)0;
			T12_ = T11_.ClE_0? T11_.ClP_0((NI)(col - ((NI) 1)), T11_.ClE_0):((TM__wjrA09aH0rT1R7zbrcCaROw_5)(T11_.ClP_0))((NI)(col - ((NI) 1)));
			result = !(T12_);
		}
		goto LA7_;
		LA9_: ;
		{
			tyProc__cOOsXj9cY0bKt2oqNqLbhZw T14_;
			nimZeroMem((void*)(&T14_), sizeof(tyProc__cOOsXj9cY0bKt2oqNqLbhZw));
			T14_.ClP_0 = isOpeningBacktick__sigmatch_4499; T14_.ClE_0 = colonenvP_;
			result = T14_.ClE_0? T14_.ClP_0((NI)(col - ((NI) 1)), T14_.ClE_0):((TM__wjrA09aH0rT1R7zbrcCaROw_6)(T14_.ClP_0))((NI)(col - ((NI) 1)));
		}
		LA7_: ;
	}
	goto LA1_;
	LA5_: ;
	{
		result = NIM_FALSE;
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI, skipUntil__pureZparseutils_148)(NimStringDesc* s, NIM_CHAR until, NI start) {
	NI result;
	result = (NI)0;
	result = ((NI) 0);
	{
		while (1) {
			NIM_BOOL T3_;
			T3_ = (NIM_BOOL)0;
			T3_ = ((NI)(start + result) < (s ? s->Sup.len : 0));
			if (!(T3_)) goto LA4_;
			T3_ = !(((NU8)(s->data[(NI)(result + start)]) == (NU8)(until)));
			LA4_: ;
			if (!T3_) goto LA2;
			result += ((NI) 1);
		} LA2: ;
	}
	return result;
}
static N_INLINE(NimStringDesc*, X5BX5D___pureZunicode_865)(NimStringDesc* s, tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw x) {
	NimStringDesc* result;
	NI a;
	NI L;
	result = NIM_NIL;
	a = x.a;
	L = (NI)((NI)(x.b - a) + ((NI) 1));
	result = mnewString(((NI) (L)));
	{
		NI i;
		NI i_2;
		i = (NI)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < L)) goto LA3;
				i = i_2;
				result->data[i] = s->data[(NI)(i + a)];
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
static N_INLINE(NIM_CHAR, X5BX5D___system_7321)(NimStringDesc* s, NI i) {
	NIM_CHAR result;
	result = (NIM_CHAR)0;
	result = s->data[(NI)((s ? s->Sup.len : 0) - i)];
	return result;
}
static N_INLINE(NI, parseWhile__pureZparseutils_226)(NimStringDesc* s, NimStringDesc** token, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw validChars, NI start) {
	NI result;
	NI i;
	result = (NI)0;
	i = start;
	{
		while (1) {
			NIM_BOOL T3_;
			T3_ = (NIM_BOOL)0;
			T3_ = (i < (s ? s->Sup.len : 0));
			if (!(T3_)) goto LA4_;
			T3_ = ((validChars[(NU)(((NU8)(s->data[i])))>>3] &(1U<<((NU)(((NU8)(s->data[i])))&7U)))!=0);
			LA4_: ;
			if (!T3_) goto LA2;
			i += ((NI) 1);
		} LA2: ;
	}
	result = (NI)(i - start);
	fastSubstr__pureZparseutils_170(s, token, start, result);
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, getTokenLenFromSource__sigmatch_4492)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* ident, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NI result;
	tyObject_Env_suggestdotnim_getTokenLenFromSource___JTQD63EOMNGYBEyDiI65hA* colonenv_;
	NI column;
	result = (NI)0;
	colonenv_ = NIM_NIL;
	colonenv_ = (tyObject_Env_suggestdotnim_getTokenLenFromSource___JTQD63EOMNGYBEyDiI65hA*) newObj((&NTIrefobject__2F9cu9at6fEkJGwU3CoFWY3A_), sizeof(tyObject_Env_suggestdotnim_getTokenLenFromSource___JTQD63EOMNGYBEyDiI65hA));
	(*colonenv_).Sup.m_type = (&NTIobject__JTQD63EOMNGYBEyDiI65hA_);
	asgnRef((void**) (&(*colonenv_).line1), sourceLine__msgs_1111(conf, info));
	column = toColumn__msgs_622(info);
	{
		if (!(((*colonenv_).line1 ? (*colonenv_).line1->Sup.len : 0) < column)) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T6_;
		NIM_BOOL T7_;
		tyProc__cOOsXj9cY0bKt2oqNqLbhZw T10_;
		T6_ = (NIM_BOOL)0;
		T7_ = (NIM_BOOL)0;
		T7_ = (((NI) 0) < column);
		if (!(T7_)) goto LA8_;
		T7_ = ((NU8)((*colonenv_).line1->data[(NI)(column - ((NI) 1))]) == (NU8)(96));
		LA8_: ;
		T6_ = T7_;
		if (!(T6_)) goto LA9_;
		nimZeroMem((void*)(&T10_), sizeof(tyProc__cOOsXj9cY0bKt2oqNqLbhZw));
		T10_.ClP_0 = isOpeningBacktick__sigmatch_4499; T10_.ClE_0 = colonenv_;
		T6_ = T10_.ClE_0? T10_.ClP_0((NI)(column - ((NI) 1)), T10_.ClE_0):((TM__wjrA09aH0rT1R7zbrcCaROw_7)(T10_.ClP_0))((NI)(column - ((NI) 1)));
		LA9_: ;
		if (!T6_) goto LA11_;
		result = skipUntil__pureZparseutils_148((*colonenv_).line1, 96, column);
		{
			tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw T15_;
			NimStringDesc* T16_;
			NI T17_;
			T15_ = dotdot___pureZunicode_840(column, (NI)((NI)(column + result) - ((NI) 1)));
			T16_ = NIM_NIL;
			T16_ = X5BX5D___pureZunicode_865((*colonenv_).line1, T15_);
			T17_ = (NI)0;
			T17_ = nsuCmpIgnoreStyle(T16_, ident);
			if (!!((T17_ == ((NI) 0)))) goto LA18_;
			result = ((NI) 0);
		}
		LA18_: ;
	}
	goto LA1_;
	LA11_: ;
	{
		NIM_BOOL T21_;
		NIM_CHAR T23_;
		T21_ = (NIM_BOOL)0;
		T21_ = (((NU8)(ident->data[((NI) 0)])) >= ((NU8)(97)) && ((NU8)(ident->data[((NI) 0)])) <= ((NU8)(122)) || ((NU8)(ident->data[((NI) 0)])) >= ((NU8)(65)) && ((NU8)(ident->data[((NI) 0)])) <= ((NU8)(90)) || ((NU8)(ident->data[((NI) 0)])) >= ((NU8)(48)) && ((NU8)(ident->data[((NI) 0)])) <= ((NU8)(57)) || ((NU8)(ident->data[((NI) 0)])) >= ((NU8)(128)) && ((NU8)(ident->data[((NI) 0)])) <= ((NU8)(255)) || ((NU8)(ident->data[((NI) 0)])) == ((NU8)(95)));
		if (!(T21_)) goto LA22_;
		T23_ = (NIM_CHAR)0;
		T23_ = X5BX5D___system_7321(ident, ((NI) 1));
		T21_ = !(((NU8)(T23_) == (NU8)(61)));
		LA22_: ;
		if (!T21_) goto LA24_;
		result = identLen__linter_13((*colonenv_).line1, column);
		{
			tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw T28_;
			NimStringDesc* T29_;
			NI T30_;
			T28_ = dotdot___pureZunicode_840(column, (NI)((NI)(column + result) - ((NI) 1)));
			T29_ = NIM_NIL;
			T29_ = X5BX5D___pureZunicode_865((*colonenv_).line1, T28_);
			T30_ = (NI)0;
			T30_ = nsuCmpIgnoreStyle(T29_, ident);
			if (!!((T30_ == ((NI) 0)))) goto LA31_;
			result = ((NI) 0);
		}
		LA31_: ;
	}
	goto LA1_;
	LA24_: ;
	{
		NimStringDesc* sourceIdent;
		sourceIdent = NIM_NIL;
		result = parseWhile__pureZparseutils_226((*colonenv_).line1, (&sourceIdent), TM__wjrA09aH0rT1R7zbrcCaROw_8, column);
		{
			NIM_BOOL T36_;
			NIM_CHAR T37_;
			T36_ = (NIM_BOOL)0;
			T37_ = (NIM_CHAR)0;
			T37_ = X5BX5D___system_7321(ident, ((NI) 1));
			T36_ = ((NU8)(T37_) == (NU8)(61));
			if (!(T36_)) goto LA38_;
			T36_ = (((NU8)(ident->data[((NI) 0)])) >= ((NU8)(97)) && ((NU8)(ident->data[((NI) 0)])) <= ((NU8)(122)) || ((NU8)(ident->data[((NI) 0)])) >= ((NU8)(65)) && ((NU8)(ident->data[((NI) 0)])) <= ((NU8)(90)) || ((NU8)(ident->data[((NI) 0)])) >= ((NU8)(48)) && ((NU8)(ident->data[((NI) 0)])) <= ((NU8)(57)) || ((NU8)(ident->data[((NI) 0)])) >= ((NU8)(128)) && ((NU8)(ident->data[((NI) 0)])) <= ((NU8)(255)) || ((NU8)(ident->data[((NI) 0)])) == ((NU8)(95)));
			LA38_: ;
			if (!T36_) goto LA39_;
			{
				if (!!(eqStrings(sourceIdent, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_9)))) goto LA43_;
				result = ((NI) 0);
			}
			LA43_: ;
		}
		goto LA34_;
		LA39_: ;
		{
			NIM_BOOL T46_;
			tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw T48_;
			NimStringDesc* T49_;
			T46_ = (NIM_BOOL)0;
			T46_ = ((ident ? ident->Sup.len : 0) < (sourceIdent ? sourceIdent->Sup.len : 0));
			if (!(T46_)) goto LA47_;
			T48_ = dotdot___pureZunicode_840(((NI) 0), ((ident ? ident->Sup.len : 0)-1));
			T49_ = NIM_NIL;
			T49_ = X5BX5D___pureZunicode_865(sourceIdent, T48_);
			T46_ = eqStrings(T49_, ident);
			LA47_: ;
			if (!T46_) goto LA50_;
			result = (ident ? ident->Sup.len : 0);
		}
		goto LA34_;
		LA50_: ;
		{
			if (!!(eqStrings(sourceIdent, ident))) goto LA53_;
			result = ((NI) 0);
		}
		goto LA34_;
		LA53_: ;
		LA34_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg*, symToSuggest__sigmatch_4569)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NIM_BOOL isLocal, tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg section, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NI quality, tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ prefix, NIM_BOOL inTypeContext, NI scope, NIM_BOOL useSuppliedInfo, NU16 endLine, NI endCol) {
	tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result;
	result = NIM_NIL;
	result = (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg*) newObj((&NTIsuggest__vIaEYib9am0Aa2d8J2uMYdQ_), sizeof(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg));
	(*result).section = section;
	(*result).quality = quality;
	(*result).isGlobal = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 3))&63U)))!=0);
	(*result).prefix = prefix;
	(*result).contextFits = (inTypeContext == ((144 &((NU32)1<<((NU)((*s).kind)&31U)))!=0));
	(*result).scope = scope;
	(*result).name = (&(*(*s).name).s);
	(*result).symkind = ((NU8) ((*s).kind));
	{
		if (!!((((*(*g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 30))&63U)))!=0))) goto LA3_;
		if ((*result).qualifiedPath) { nimGCunrefNoCycle((*result).qualifiedPath); (*result).qualifiedPath = NIM_NIL; }
		{
			NIM_BOOL T7_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* ow;
			T7_ = (NIM_BOOL)0;
			T7_ = !(isLocal);
			if (!(T7_)) goto LA8_;
			T7_ = !(((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6)));
			LA8_: ;
			if (!T7_) goto LA9_;
			ow = (*s).owner;
			{
				NIM_BOOL T13_;
				NIM_BOOL T14_;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* ow2;
				NI T19_;
				NimStringDesc* T20_;
				T13_ = (NIM_BOOL)0;
				T14_ = (NIM_BOOL)0;
				T14_ = !((ow == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
				if (!(T14_)) goto LA15_;
				T14_ = !(((*ow).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6)));
				LA15_: ;
				T13_ = T14_;
				if (!(T13_)) goto LA16_;
				T13_ = !(((*ow).owner == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
				LA16_: ;
				if (!T13_) goto LA17_;
				ow2 = (*ow).owner;
				asgnRef((void**) (&(*result).qualifiedPath), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*result).qualifiedPath), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
				T19_ = (*result).qualifiedPath->Sup.len++;
				T20_ = NIM_NIL;
				T20_ = (*result).qualifiedPath->data[T19_]; (*result).qualifiedPath->data[T19_] = copyStringRC1((*(*ow2).name).s);
				if (T20_) nimGCunrefNoCycle(T20_);
			}
			LA17_: ;
			{
				NI T25_;
				NimStringDesc* T26_;
				if (!!((ow == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA23_;
				asgnRef((void**) (&(*result).qualifiedPath), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*result).qualifiedPath), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
				T25_ = (*result).qualifiedPath->Sup.len++;
				T26_ = NIM_NIL;
				T26_ = (*result).qualifiedPath->data[T25_]; (*result).qualifiedPath->data[T25_] = copyStringRC1((*(*ow).name).s);
				if (T26_) nimGCunrefNoCycle(T26_);
			}
			LA23_: ;
		}
		LA9_: ;
		{
			NIM_BOOL T29_;
			tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw T31_;
			NimStringDesc* T34_;
			NI T35_;
			NimStringDesc* T36_;
			T29_ = (NIM_BOOL)0;
			T29_ = ((TM__wjrA09aH0rT1R7zbrcCaROw_3[(NU)(((NU8)((*(*s).name).s->data[((NI) 0)])))>>3] &(1U<<((NU)(((NU8)((*(*s).name).s->data[((NI) 0)])))&7U)))!=0);
			if (T29_) goto LA30_;
			T31_ = dotdot___pureZunicode_840(((NI) 1), ((NI) 66));
			T29_ = contains__pureZtimes_2292(T31_, (*(*s).name).id);
			LA30_: ;
			if (!T29_) goto LA32_;
			T34_ = NIM_NIL;
			T34_ = rawNewString(((*(*s).name).s ? (*(*s).name).s->Sup.len : 0) + 2);
appendChar(T34_, 96);
appendString(T34_, (*(*s).name).s);
appendChar(T34_, 96);
			asgnRef((void**) (&(*result).qualifiedPath), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*result).qualifiedPath), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
			T35_ = (*result).qualifiedPath->Sup.len++;
			T36_ = NIM_NIL;
			T36_ = (*result).qualifiedPath->data[T35_]; (*result).qualifiedPath->data[T35_] = copyStringRC1(T34_);
			if (T36_) nimGCunrefNoCycle(T36_);
		}
		goto LA27_;
		LA32_: ;
		{
			NI T38_;
			NimStringDesc* T39_;
			asgnRef((void**) (&(*result).qualifiedPath), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*result).qualifiedPath), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
			T38_ = (*result).qualifiedPath->Sup.len++;
			T39_ = NIM_NIL;
			T39_ = (*result).qualifiedPath->data[T38_]; (*result).qualifiedPath->data[T38_] = copyStringRC1((*(*s).name).s);
			if (T39_) nimGCunrefNoCycle(T39_);
		}
		LA27_: ;
		{
			if (!!(((*s).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA42_;
			asgnRef((void**) (&(*result).forth), typeToString__types_50((*s).typ, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0)));
		}
		goto LA40_;
		LA42_: ;
		{
			asgnRef((void**) (&(*result).forth), ((NimStringDesc*) NIM_NIL));
		}
		LA40_: ;
	}
	LA3_: ;
	{
		NIM_BOOL T47_;
		NIM_BOOL T48_;
		NI T50_;
		T47_ = (NIM_BOOL)0;
		T48_ = (NIM_BOOL)0;
		T48_ = ((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6));
		if (!(T48_)) goto LA49_;
		T50_ = (NI)0;
		T50_ = len__ast_3155((*s).ast);
		T48_ = !((T50_ == ((NI) 0)));
		LA49_: ;
		T47_ = T48_;
		if (!(T47_)) goto LA51_;
		T47_ = !((section == ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 9)));
		LA51_: ;
		if (!T47_) goto LA52_;
		asgnRef((void**) (&(*result).filePath), toFullPath__msgs_548((*g).config, (*(*(*s).ast)._kind_6.sons->data[((NI) 0)]).info.fileIndex));
		(*result).line = ((NI) 1);
		(*result).column = ((NI) 0);
		(*result).tokenLen = ((NI) 0);
	}
	goto LA45_;
	LA52_: ;
	{
		tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw infox;
		{
			NIM_BOOL T57_;
			T57_ = (NIM_BOOL)0;
			T57_ = useSuppliedInfo;
			if (T57_) goto LA58_;
			T57_ = ((263696 &((NU32)1<<((NU)(section)&31U)))!=0);
			LA58_: ;
			if (!T57_) goto LA59_;
			infox = info;
		}
		goto LA55_;
		LA59_: ;
		{
			infox = (*s).info;
		}
		LA55_: ;
		asgnRef((void**) (&(*result).filePath), toFullPath__msgs_548((*g).config, infox.fileIndex));
		(*result).line = toLinenumber__msgs_619(infox);
		(*result).column = toColumn__msgs_622(infox);
		{
			if (!!((section == ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 9)))) goto LA64_;
			(*result).tokenLen = ((*(*s).name).s ? (*(*s).name).s->Sup.len : 0);
		}
		goto LA62_;
		LA64_: ;
		{
			(*result).tokenLen = getTokenLenFromSource__sigmatch_4492((*g).config, (*(*s).name).s, infox);
		}
		LA62_: ;
	}
	LA45_: ;
	(*result).version = (*(*g).config).suggestVersion;
	(*result).endLine = endLine;
	(*result).endCol = endCol;
	return result;
}
static N_INLINE(NI, len__ast_3990)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n).sons ? (*n).sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, getQuality__sigmatch_5031)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NI result;
	result = (NI)0;
	result = ((NI) 100);
	{
		NIM_BOOL T3_;
		NI T5_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* exp_1;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*s).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_3990((*s).typ);
		T3_ = (((NI) 1) < T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		exp_1 = skipTypes__ast_3723((*(*s).typ).sons->data[((NI) 1)], TM__wjrA09aH0rT1R7zbrcCaROw_10);
		{
			if (!((*exp_1).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48))) goto LA10_;
			exp_1 = elemType__types_263(exp_1);
		}
		LA10_: ;
		{
			if (!((*exp_1).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 6) || (*exp_1).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 7) || (*exp_1).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12) || (*exp_1).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 59))) goto LA14_;
			result = ((NI) 50);
		}
		LA14_: ;
	}
	LA6_: ;
	{
		if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 22))&63U)))!=0)) goto LA18_;
		result = ((NI) ((NI)(((NI) (result)) - ((NI) 5))));
	}
	LA18_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_2710)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI module) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = ((*g).packed_0 ? (*g).packed_0->Sup.len : 0);
	T1_ = (module < T2_);
	if (!(T1_)) goto LA3_;
	T1_ = ((*g).packed_0->data[module].status == ((tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg) 3));
	LA3_: ;
	result = T1_;
	return result;
}
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_2722)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = isCachedModule__modulegraphs_2710(g, (*m).position);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, suggestEverything__sigmatch_5246)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* f, tySequence__GR8qmV1kNRcoQ2g76VFy3A** outputs) {
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* it;
		NI scopeN;
		NIM_BOOL isLocal;
		NIM_BOOL isLocal_2;
		NI scopeN_2;
		it = NIM_NIL;
		scopeN = (NI)0;
		isLocal = (NIM_BOOL)0;
		isLocal_2 = NIM_TRUE;
		scopeN_2 = ((NI) 0);
		{
			tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope;
			tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* current;
			scope = NIM_NIL;
			current = (*c).currentScope;
			{
				while (1) {
					if (!!((current == ((tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ*) NIM_NIL)))) goto LA4;
					scope = current;
					{
						if (!(scope == (*c).topLevelScope)) goto LA7_;
						isLocal_2 = NIM_FALSE;
					}
					LA7_: ;
					scopeN_2 -= ((NI) 1);
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* item;
						tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw it_2;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
						item = NIM_NIL;
						nimZeroMem((void*)(&it_2), sizeof(tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw));
						s = initTabIter__astalgo_3770((&it_2), (*scope).symbols);
						{
							while (1) {
								tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A colontmp_;
								tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ pm;
								if (!!((s == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA11;
								item = s;
								nimZeroMem((void*)(&colontmp_), sizeof(tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A));
								colontmp_.Field0 = item;
								colontmp_.Field1 = scopeN_2;
								colontmp_.Field2 = isLocal_2;
								it = colontmp_.Field0;
								scopeN = colontmp_.Field1;
								isLocal = colontmp_.Field2;
								pm = (tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ)0;
								{
									NIM_BOOL T14_;
									NI T17_;
									tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* T18_;
									NI T19_;
									T14_ = (NIM_BOOL)0;
									T14_ = filterSym__sigmatch_4938(it, f, (&pm));
									if (!T14_) goto LA15_;
									T17_ = (NI)0;
									T17_ = getQuality__sigmatch_5031(it);
									T18_ = NIM_NIL;
									T18_ = symToSuggest__sigmatch_4569((*c).graph, it, isLocal, ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 1), (*n).info, T17_, pm, (((NI) 0) < (*c).inTypeContext), scopeN, NIM_FALSE, ((NU16) 0), ((NI) 0));
									unsureAsgnRef((void**) (&(*outputs)), (tySequence__GR8qmV1kNRcoQ2g76VFy3A*) incrSeqV3((TGenericSeq*)((*outputs)), (&NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_)));
									T19_ = (*outputs)->Sup.len++;
									asgnRef((void**) (&(*outputs)->data[T19_]), T18_);
								}
								LA15_: ;
								s = nextIter__astalgo_3755((&it_2), (*scope).symbols);
							} LA11: ;
						}
					}
					current = (*current).parent;
				} LA4: ;
			}
		}
		scopeN_2 -= ((NI) 1);
		isLocal_2 = NIM_FALSE;
		{
			tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg* im;
			NI i;
			NI L;
			NI T21_;
			im = (tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg*)0;
			i = ((NI) 0);
			T21_ = ((*c).imports ? (*c).imports->Sup.len : 0);
			L = T21_;
			{
				while (1) {
					if (!(i < L)) goto LA23;
					im = (&(*c).imports->data[i]);
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s_2;
						NIM_BOOL importHidden;
						s_2 = NIM_NIL;
						importHidden = (((*(*im).m).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 27))&31U)))!=0);
						{
							NIM_BOOL T27_;
							tyObject_RodIter__L6nv9cakjPARHk068AFo6ww rodIt;
							tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* r;
							T27_ = (NIM_BOOL)0;
							T27_ = isCachedModule__modulegraphs_2722((*c).graph, (*im).m);
							if (!T27_) goto LA28_;
							nimZeroMem((void*)(&rodIt), sizeof(tyObject_RodIter__L6nv9cakjPARHk068AFo6ww));
							r = initRodIterAllSyms__icZic_8670((&rodIt), (*(*c).graph).config, (*(*c).graph).cache, (&(*(*c).graph).packed_0), ((NI32) ((*(*im).m).position)), importHidden);
							{
								while (1) {
									tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A colontmp__2;
									tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ pm_2;
									if (!!((r == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA31;
									s_2 = r;
									nimZeroMem((void*)(&colontmp__2), sizeof(tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A));
									colontmp__2.Field0 = s_2;
									colontmp__2.Field1 = scopeN_2;
									colontmp__2.Field2 = isLocal_2;
									it = colontmp__2.Field0;
									scopeN = colontmp__2.Field1;
									isLocal = colontmp__2.Field2;
									pm_2 = (tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ)0;
									{
										NIM_BOOL T34_;
										NI T37_;
										tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* T38_;
										NI T39_;
										T34_ = (NIM_BOOL)0;
										T34_ = filterSym__sigmatch_4938(it, f, (&pm_2));
										if (!T34_) goto LA35_;
										T37_ = (NI)0;
										T37_ = getQuality__sigmatch_5031(it);
										T38_ = NIM_NIL;
										T38_ = symToSuggest__sigmatch_4569((*c).graph, it, isLocal, ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 1), (*n).info, T37_, pm_2, (((NI) 0) < (*c).inTypeContext), scopeN, NIM_FALSE, ((NU16) 0), ((NI) 0));
										unsureAsgnRef((void**) (&(*outputs)), (tySequence__GR8qmV1kNRcoQ2g76VFy3A*) incrSeqV3((TGenericSeq*)((*outputs)), (&NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_)));
										T39_ = (*outputs)->Sup.len++;
										asgnRef((void**) (&(*outputs)->data[T39_]), T38_);
									}
									LA35_: ;
									r = nextRodIter__icZic_8980((&rodIt), (&(*(*c).graph).packed_0));
								} LA31: ;
							}
						}
						goto LA25_;
						LA28_: ;
						{
							{
								tyObject_TSym__3r34mwqcVmg5JFNmiaVncw** s_3;
								tySequence__ed0C0uAUZPhvw3RAc5hfYg* colontmp__3;
								tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* retX60gensym17_;
								NI i_2;
								NI L_2;
								NI T46_;
								s_3 = (tyObject_TSym__3r34mwqcVmg5JFNmiaVncw**)0;
								colontmp__3 = NIM_NIL;
								retX60gensym17_ = (&(*(*c).graph).ifaces->data[(*(*im).m).position].interf);
								{
									if (!importHidden) goto LA44_;
									retX60gensym17_ = (&(*(*c).graph).ifaces->data[(*(*im).m).position].interfHidden);
								}
								LA44_: ;
								colontmp__3 = (*retX60gensym17_).data;
								i_2 = ((NI) 0);
								T46_ = (colontmp__3 ? colontmp__3->Sup.len : 0);
								L_2 = T46_;
								{
									while (1) {
										if (!(i_2 < L_2)) goto LA48;
										s_3 = &colontmp__3->data[i_2];
										{
											tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A colontmp__4;
											tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ pm_3;
											if (!!(((*s_3) == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA51_;
											s_2 = (*s_3);
											nimZeroMem((void*)(&colontmp__4), sizeof(tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A));
											colontmp__4.Field0 = s_2;
											colontmp__4.Field1 = scopeN_2;
											colontmp__4.Field2 = isLocal_2;
											it = colontmp__4.Field0;
											scopeN = colontmp__4.Field1;
											isLocal = colontmp__4.Field2;
											pm_3 = (tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ)0;
											{
												NIM_BOOL T55_;
												NI T58_;
												tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* T59_;
												NI T60_;
												T55_ = (NIM_BOOL)0;
												T55_ = filterSym__sigmatch_4938(it, f, (&pm_3));
												if (!T55_) goto LA56_;
												T58_ = (NI)0;
												T58_ = getQuality__sigmatch_5031(it);
												T59_ = NIM_NIL;
												T59_ = symToSuggest__sigmatch_4569((*c).graph, it, isLocal, ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 1), (*n).info, T58_, pm_3, (((NI) 0) < (*c).inTypeContext), scopeN, NIM_FALSE, ((NU16) 0), ((NI) 0));
												unsureAsgnRef((void**) (&(*outputs)), (tySequence__GR8qmV1kNRcoQ2g76VFy3A*) incrSeqV3((TGenericSeq*)((*outputs)), (&NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_)));
												T60_ = (*outputs)->Sup.len++;
												asgnRef((void**) (&(*outputs)->data[T60_]), T59_);
											}
											LA56_: ;
										}
										LA51_: ;
										i_2 += ((NI) 1);
									} LA48: ;
								}
							}
						}
						LA25_: ;
					}
					i += ((NI) 1);
				} LA23: ;
			}
		}
	}
}
static N_INLINE(NIM_BOOL, fieldVisible__sigmatch_4973)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* f) {
	NIM_BOOL result;
	NI fmoduleId;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym804_;
	NIM_BOOL T1_;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym806_;
{	result = (NIM_BOOL)0;
	xX60gensym804_ = getModule__astalgo_216(f);
	fmoduleId = (NI)((NI)((NU32)(((NI) ((*xX60gensym804_).Sup.itemId.module))) << (NU32)(((NI) 20))) + ((NI) ((*xX60gensym804_).Sup.itemId.item)));
	T1_ = (NIM_BOOL)0;
	T1_ = (((*f).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 1))&63U)))!=0);
	if (T1_) goto LA2_;
	xX60gensym806_ = (*c).module;
	T1_ = (fmoduleId == (NI)((NI)((NU32)(((NI) ((*xX60gensym806_).Sup.itemId.module))) << (NU32)(((NI) 20))) + ((NI) ((*xX60gensym806_).Sup.itemId.item))));
	LA2_: ;
	result = T1_;
	{
		if (!!(result)) goto LA5_;
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw** module;
			NI i;
			NI L;
			NI T8_;
			module = (tyObject_TSym__3r34mwqcVmg5JFNmiaVncw**)0;
			i = ((NI) 0);
			T8_ = ((*c).friendModules ? (*c).friendModules->Sup.len : 0);
			L = T8_;
			{
				while (1) {
					if (!(i < L)) goto LA10;
					module = &(*c).friendModules->data[i];
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym807_;
						xX60gensym807_ = (*module);
						if (!(fmoduleId == (NI)((NI)((NU32)(((NI) ((*xX60gensym807_).Sup.itemId.module))) << (NU32)(((NI) 20))) + ((NI) ((*xX60gensym807_).Sup.itemId.item))))) goto LA13_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA13_: ;
					i += ((NI) 1);
				} LA10: ;
			}
		}
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* symObj;
			if (!((*f).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19))) goto LA17_;
			symObj = (*f).owner;
			{
				if (!((*(*symObj).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22) || (*(*symObj).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21))) goto LA21_;
				symObj = (*(*(*symObj).typ).sons->data[((NI) 0)]).sym;
			}
			LA21_: ;
			{
				tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope;
				tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* current;
				scope = NIM_NIL;
				current = (*c).currentScope;
				{
					while (1) {
						if (!!((current == ((tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ*) NIM_NIL)))) goto LA25;
						scope = current;
						{
							tyObject_TSym__3r34mwqcVmg5JFNmiaVncw** sym;
							NI i_2;
							NI L_2;
							NI T27_;
							sym = (tyObject_TSym__3r34mwqcVmg5JFNmiaVncw**)0;
							i_2 = ((NI) 0);
							T27_ = ((*scope).allowPrivateAccess ? (*scope).allowPrivateAccess->Sup.len : 0);
							L_2 = T27_;
							{
								while (1) {
									if (!(i_2 < L_2)) goto LA29;
									sym = &(*scope).allowPrivateAccess->data[i_2];
									{
										tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym810_;
										tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym811_;
										xX60gensym810_ = symObj;
										xX60gensym811_ = (*sym);
										if (!((NI)((NI)((NU32)(((NI) ((*xX60gensym810_).Sup.itemId.module))) << (NU32)(((NI) 20))) + ((NI) ((*xX60gensym810_).Sup.itemId.item))) == (NI)((NI)((NU32)(((NI) ((*xX60gensym811_).Sup.itemId.module))) << (NU32)(((NI) 20))) + ((NI) ((*xX60gensym811_).Sup.itemId.item))))) goto LA32_;
										result = NIM_TRUE;
										goto BeforeRet_;
									}
									LA32_: ;
									i_2 += ((NI) 1);
								} LA29: ;
							}
						}
						current = (*current).parent;
					} LA25: ;
				}
			}
		}
		LA17_: ;
	}
	LA5_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, suggestField__sigmatch_5055)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* f, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tySequence__GR8qmV1kNRcoQ2g76VFy3A** outputs) {
	tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ pm;
	pm = (tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ)0;
	{
		NIM_BOOL T3_;
		NI T7_;
		tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* T8_;
		NI T9_;
		T3_ = (NIM_BOOL)0;
		T3_ = filterSym__sigmatch_4938(s, f, (&pm));
		if (!(T3_)) goto LA4_;
		T3_ = fieldVisible__sigmatch_4973(c, s);
		LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = (NI)0;
		T7_ = getQuality__sigmatch_5031(s);
		T8_ = NIM_NIL;
		T8_ = symToSuggest__sigmatch_4569((*c).graph, s, NIM_TRUE, ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 1), info, T7_, pm, (((NI) 0) < (*c).inTypeContext), ((NI) 0), NIM_FALSE, ((NU16) 0), ((NI) 0));
		unsureAsgnRef((void**) (&(*outputs)), (tySequence__GR8qmV1kNRcoQ2g76VFy3A*) incrSeqV3((TGenericSeq*)((*outputs)), (&NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_)));
		T9_ = (*outputs)->Sup.len++;
		asgnRef((void**) (&(*outputs)->data[T9_]), T8_);
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, suggestSymList__sigmatch_5069)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* list, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* f, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tySequence__GR8qmV1kNRcoQ2g76VFy3A** outputs) {
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(list);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					if (!((*(*list)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA6_;
					suggestField__sigmatch_5055(c, (*(*list)._kind_6.sons->data[i])._kind_4.sym, f, info, outputs);
				}
				LA6_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, suggestObject__sigmatch_5089)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* f, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tySequence__GR8qmV1kNRcoQ2g76VFy3A** outputs) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 138):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					suggestObject__sigmatch_5089(c, (*n)._kind_6.sons->data[i], f, info, outputs);
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 139):
	{
		{
			NI T8_;
			T8_ = (NI)0;
			T8_ = len__ast_3155(n);
			if (!(((NI) 0) < T8_)) goto LA9_;
			suggestObject__sigmatch_5089(c, (*n)._kind_6.sons->data[((NI) 0)], f, info, outputs);
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = len__ast_3155(n);
				i_4 = ((NI) 1);
				{
					while (1) {
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T14_;
						if (!(i_4 < colontmp__2)) goto LA13;
						i_3 = i_4;
						T14_ = NIM_NIL;
						T14_ = lastSon__ast_4833((*n)._kind_6.sons->data[i_3]);
						suggestObject__sigmatch_5089(c, T14_, f, info, outputs);
						i_4 += ((NI) 1);
					} LA13: ;
				}
			}
		}
		LA9_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		suggestField__sigmatch_5055(c, (*n)._kind_4.sym, f, info, outputs);
	}
	break;
	default:
	{
	}
	break;
	}
}
static N_INLINE(NIM_BOOL, filterSymNoOpr__sigmatch_4964)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* prefix, tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ* res) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NIM_BOOL T5_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = filterSym__sigmatch_4938(s, prefix, res);
	if (!(T2_)) goto LA3_;
	T2_ = (((NU8)((*(*s).name).s->data[((NI) 0)])) >= ((NU8)(97)) && ((NU8)((*(*s).name).s->data[((NI) 0)])) <= ((NU8)(122)) || ((NU8)((*(*s).name).s->data[((NI) 0)])) >= ((NU8)(65)) && ((NU8)((*(*s).name).s->data[((NI) 0)])) <= ((NU8)(90)) || ((NU8)((*(*s).name).s->data[((NI) 0)])) >= ((NU8)(48)) && ((NU8)((*(*s).name).s->data[((NI) 0)])) <= ((NU8)(57)) || ((NU8)((*(*s).name).s->data[((NI) 0)])) >= ((NU8)(128)) && ((NU8)((*(*s).name).s->data[((NI) 0)])) <= ((NU8)(255)));
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T5_ = (NIM_BOOL)0;
	T5_ = isKeyword__renderer_73((*s).name);
	T1_ = !(T5_);
	LA4_: ;
	result = T1_;
	return result;
}
static N_INLINE(void, initCandidateAux__sigmatch_94)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* ctx, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* callee) {
	tyObject_MismatchInfo__7DZVQMEKp3NTauLRe48cLw T1_;
	unsureAsgnRef((void**) (&(*c).c), ctx);
	(*c).exactMatches = ((NI) 0);
	(*c).subtypeMatches = ((NI) 0);
	(*c).convMatches = ((NI) 0);
	(*c).intConvMatches = ((NI) 0);
	(*c).genericMatches = ((NI) 0);
	(*c).state = ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 0);
	nimZeroMem((void*)(&T1_), sizeof(tyObject_MismatchInfo__7DZVQMEKp3NTauLRe48cLw));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_MismatchInfo__7DZVQMEKp3NTauLRe48cLw));
	(*c).firstMismatch.kind = T1_.kind;
	(*c).firstMismatch.arg = T1_.arg;
	unsureAsgnRef((void**) (&(*c).firstMismatch.formal), T1_.formal);
	unsureAsgnRef((void**) (&(*c).callee), callee);
	unsureAsgnRef((void**) (&(*c).call), ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
	(*c).baseTypeMatch = NIM_FALSE;
	(*c).genericConverter = NIM_FALSE;
	(*c).inheritancePenalty = ((NI) 0);
}
N_LIB_PRIVATE N_NIMCALL(void, initCandidate__sigmatch_116)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* ctx, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* callee) {
	initCandidateAux__sigmatch_94(ctx, c, callee);
	unsureAsgnRef((void**) (&(*c).calleeSym), ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
	initIdTable__ast_4084((&(*c).bindings));
}
N_LIB_PRIVATE N_NIMCALL(void, newCandidate__sigmatch_195)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* ctx, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* callee, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* Result) {
	unsureAsgnRef((void**)&(*Result).c, NIM_NIL);
	(*Result).exactMatches = 0;
	(*Result).genericMatches = 0;
	(*Result).subtypeMatches = 0;
	(*Result).intConvMatches = 0;
	(*Result).convMatches = 0;
	(*Result).state = 0;
	unsureAsgnRef((void**)&(*Result).callee, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).calleeSym, NIM_NIL);
	(*Result).calleeScope = 0;
	unsureAsgnRef((void**)&(*Result).call, NIM_NIL);
	(*Result).bindings.counter = 0;
	unsureAsgnRef((void**)&(*Result).bindings.data, NIM_NIL);
	(*Result).magic = 0;
	(*Result).baseTypeMatch = 0;
	(*Result).fauxMatch = 0;
	(*Result).genericConverter = 0;
	(*Result).coerceDistincts = 0;
	(*Result).typedescMatched = 0;
	(*Result).isNoCall = 0;
	unsureAsgnRef((void**)&(*Result).inferredTypes, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).diagnostics, NIM_NIL);
	(*Result).inheritancePenalty = 0;
	(*Result).firstMismatch.kind = 0;
	(*Result).firstMismatch.arg = 0;
	unsureAsgnRef((void**)&(*Result).firstMismatch.formal, NIM_NIL);
	(*Result).diagnosticsEnabled = 0;
	initCandidate__sigmatch_116(ctx, Result, callee);
}
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextTypeId__ast_3122)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x) {
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*x).typeId_0 += ((NI) 1);
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	result.module = (*x).module;
	result.item = (*x).typeId_0;
	return result;
}
static N_INLINE(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, skipIntLit__magicsys_124)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* id) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*t).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36));
		LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = nextTypeId__ast_3122(id);
		result = copyType__ast_4034(t, T7_, (*t).owner);
		asgnRef((void**) (&(*result).n), ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
	}
	goto LA1_;
	LA5_: ;
	{
		result = t;
	}
	LA1_: ;
	return result;
}
static N_INLINE(void, put__sigmatch_120)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* key, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* val) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1_;
	T1_ = NIM_NIL;
	T1_ = skipIntLit__magicsys_124(val, (*(*c).c).Sup.idgen);
	idTablePut__astalgo_70((&(*c).bindings), &key->Sup, &T1_->Sup.Sup);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tryResolvingStaticExpr__sigmatch_1227)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL allowUnresolved) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* instantiated;
	result = NIM_NIL;
	instantiated = replaceTypesInBody__semtypinst_1024((*c).c, (*c).bindings, n, ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL), allowUnresolved);
	result = (*(*c).c).semExpr((*c).c, instantiated, 0, ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
	return result;
}
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__ast_3155(n);
	}
	LA1_: ;
	return result;
}
static N_INLINE(NIM_BOOL, eqeq___idents_229)(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* a, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* b) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (a == 0);
		if (T3_) goto LA4_;
		T3_ = (b == 0);
		LA4_: ;
		if (!T3_) goto LA5_;
		result = (a == b);
	}
	goto LA1_;
	LA5_: ;
	{
		result = ((*a).id == (*b).id);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, shouldSkipDistinct__sigmatch_1199)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* rules, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* callIdent) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		if (!((*rules).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 130))) goto LA3_;
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* r;
			r = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(rules);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA8;
						i = i_2;
						r = (*rules)._kind_6.sons->data[i];
						{
							tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T11_;
							NIM_BOOL T12_;
							T11_ = NIM_NIL;
							T11_ = considerQuotedIdent__lookups_29((*m).c, r, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
							T12_ = (NIM_BOOL)0;
							T12_ = eqeq___idents_229(T11_, callIdent);
							if (!T12_) goto LA13_;
							result = NIM_TRUE;
							goto BeforeRet_;
						}
						LA13_: ;
						i_2 += ((NI) 1);
					} LA8: ;
				}
			}
		}
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	goto LA1_;
	LA3_: ;
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* r_2;
			r_2 = NIM_NIL;
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = safeLen__ast_3148(rules);
				i_4 = ((NI) 0);
				{
					while (1) {
						if (!(i_4 < colontmp__2)) goto LA19;
						i_3 = i_4;
						r_2 = (*rules)._kind_6.sons->data[i_3];
						{
							tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T22_;
							NIM_BOOL T23_;
							T22_ = NIM_NIL;
							T22_ = considerQuotedIdent__lookups_29((*m).c, r_2, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
							T23_ = (NIM_BOOL)0;
							T23_ = eqeq___idents_229(T22_, callIdent);
							if (!T23_) goto LA24_;
							result = NIM_FALSE;
							goto BeforeRet_;
						}
						LA24_: ;
						i_4 += ((NI) 1);
					} LA19: ;
				}
			}
		}
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, maybeSkipDistinct__sigmatch_1210)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* callee) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T5_ = !((t == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		if (!(T5_)) goto LA6_;
		T5_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 13));
		LA6_: ;
		T4_ = T5_;
		if (!(T4_)) goto LA7_;
		T4_ = !(((*t).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
		LA7_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA8_;
		T3_ = shouldSkipDistinct__sigmatch_1199(m, (*t).n, (*callee).name);
		LA8_: ;
		if (!T3_) goto LA9_;
		result = base__types_63(t);
	}
	goto LA1_;
	LA9_: ;
	{
		result = t;
	}
	LA1_: ;
	return result;
}
static N_INLINE(NIM_BOOL, sameEnumTypes__types_2152)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* b) {
	NIM_BOOL result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* xX60gensym302_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* xX60gensym303_;
	result = (NIM_BOOL)0;
	xX60gensym302_ = a;
	xX60gensym303_ = b;
	result = ((NI)((NI)((NU32)(((NI) ((*xX60gensym302_).Sup.itemId.module))) << (NU32)(((NI) 20))) + ((NI) ((*xX60gensym302_).Sup.itemId.item))) == (NI)((NI)((NU32)(((NI) ((*xX60gensym303_).Sup.itemId.module))) << (NU32)(((NI) 20))) + ((NI) ((*xX60gensym303_).Sup.itemId.item))));
	return result;
}
N_LIB_PRIVATE N_NOINLINE(tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA, typeRangeRel__sigmatch_981)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a) {
	tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA result;
	result = (tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isOrdinalType__types_299(f, NIM_FALSE);
		if (!T3_) goto LA4_;
		{
			NIM_BOOL T8_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T9_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T10_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T12_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T13_;
			T8_ = (NIM_BOOL)0;
			T9_ = firstOrd__types_1406(((tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) NIM_NIL), a);
			T10_ = firstOrd__types_1406(((tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) NIM_NIL), f);
			T8_ = eqeq___int495056_425(T9_, T10_);
			if (!(T8_)) goto LA11_;
			T12_ = lastOrd__types_1530(((tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) NIM_NIL), a);
			T13_ = lastOrd__types_1530(((tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) NIM_NIL), f);
			T8_ = eqeq___int495056_425(T12_, T13_);
			LA11_: ;
			if (!T8_) goto LA14_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10);
		}
		goto LA6_;
		LA14_: ;
		{
			NIM_BOOL T17_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T18_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T19_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T21_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T22_;
			T17_ = (NIM_BOOL)0;
			T18_ = firstOrd__types_1406(((tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) NIM_NIL), f);
			T19_ = firstOrd__types_1406(((tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) NIM_NIL), a);
			T17_ = lteq___int495056_421(T18_, T19_);
			if (!(T17_)) goto LA20_;
			T21_ = lastOrd__types_1530(((tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) NIM_NIL), a);
			T22_ = lastOrd__types_1530(((tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) NIM_NIL), f);
			T17_ = lteq___int495056_421(T21_, T22_);
			LA20_: ;
			if (!T17_) goto LA23_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
		}
		goto LA6_;
		LA23_: ;
		{
			NIM_BOOL T26_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T27_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T28_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T30_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T31_;
			T26_ = (NIM_BOOL)0;
			T27_ = firstOrd__types_1406(((tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) NIM_NIL), a);
			T28_ = lastOrd__types_1530(((tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) NIM_NIL), f);
			T26_ = lteq___int495056_421(T27_, T28_);
			if (!(T26_)) goto LA29_;
			T30_ = firstOrd__types_1406(((tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) NIM_NIL), f);
			T31_ = lastOrd__types_1530(((tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) NIM_NIL), a);
			T26_ = lteq___int495056_421(T30_, T31_);
			LA29_: ;
			if (!T26_) goto LA32_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
		}
		goto LA6_;
		LA32_: ;
		{
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
		}
		LA6_: ;
	}
	goto LA1_;
	LA4_: ;
	{
		{
			NIM_BOOL T38_;
			NF T39_;
			NF T40_;
			NF T42_;
			NF T43_;
			T38_ = (NIM_BOOL)0;
			T39_ = (NF)0;
			T39_ = firstFloat__types_1505(a);
			T40_ = (NF)0;
			T40_ = firstFloat__types_1505(f);
			T38_ = (T39_ == T40_);
			if (!(T38_)) goto LA41_;
			T42_ = (NF)0;
			T42_ = lastFloat__types_1644(a);
			T43_ = (NF)0;
			T43_ = lastFloat__types_1644(f);
			T38_ = (T42_ == T43_);
			LA41_: ;
			if (!T38_) goto LA44_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10);
		}
		goto LA36_;
		LA44_: ;
		{
			NIM_BOOL T47_;
			NF T48_;
			NF T49_;
			NF T51_;
			NF T52_;
			T47_ = (NIM_BOOL)0;
			T48_ = (NF)0;
			T48_ = firstFloat__types_1505(f);
			T49_ = (NF)0;
			T49_ = firstFloat__types_1505(a);
			T47_ = (T48_ <= T49_);
			if (!(T47_)) goto LA50_;
			T51_ = (NF)0;
			T51_ = lastFloat__types_1644(a);
			T52_ = (NF)0;
			T52_ = lastFloat__types_1644(f);
			T47_ = (T51_ <= T52_);
			LA50_: ;
			if (!T47_) goto LA53_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
		}
		goto LA36_;
		LA53_: ;
		{
			NIM_BOOL T56_;
			NF T57_;
			NF T58_;
			NF T60_;
			NF T61_;
			T56_ = (NIM_BOOL)0;
			T57_ = (NF)0;
			T57_ = firstFloat__types_1505(a);
			T58_ = (NF)0;
			T58_ = lastFloat__types_1644(f);
			T56_ = (T57_ <= T58_);
			if (!(T56_)) goto LA59_;
			T60_ = (NF)0;
			T60_ = firstFloat__types_1505(f);
			T61_ = (NF)0;
			T61_ = lastFloat__types_1644(a);
			T56_ = (T60_ <= T61_);
			LA59_: ;
			if (!T56_) goto LA62_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
		}
		goto LA36_;
		LA62_: ;
		{
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
		}
		LA36_: ;
	}
	LA1_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isIntLit__types_186)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31));
	if (!(T2_)) goto LA3_;
	T2_ = !(((*t).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = ((*(*t).n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6));
	LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isConvertibleToRange__sigmatch_548)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*f).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) && (*f).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35) || (*f).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40) && (*f).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44));
		if (!(T3_)) goto LA4_;
		T3_ = ((*a).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) && (*a).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35) || (*a).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40) && (*a).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44));
		LA4_: ;
		if (!T3_) goto LA5_;
		switch ((*f).kind) {
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 32):
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = isIntLit__types_186(a);
			if (T8_) goto LA9_;
			T8_ = ((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 32));
			LA9_: ;
			result = T8_;
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 33):
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = isIntLit__types_186(a);
			if (T11_) goto LA12_;
			T11_ = ((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 32) || (*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 33));
			LA12_: ;
			result = T11_;
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 34):
		{
			NIM_BOOL T14_;
			T14_ = (NIM_BOOL)0;
			T14_ = isIntLit__types_186(a);
			if (T14_) goto LA15_;
			T14_ = ((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 32) || (*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 33) || (*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 34));
			LA15_: ;
			result = T14_;
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31):
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40):
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44):
		{
			result = NIM_TRUE;
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35):
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = isIntLit__types_186(a);
			if (T18_) goto LA19_;
			T18_ = ((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 32) || (*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 33) || (*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 34) || (*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) || (*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35));
			LA19_: ;
			result = T18_;
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 41):
		{
			NIM_BOOL T21_;
			T21_ = (NIM_BOOL)0;
			T21_ = isIntLit__types_186(a);
			if (T21_) goto LA22_;
			T21_ = ((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 41));
			LA22_: ;
			result = T21_;
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 42):
		{
			NIM_BOOL T24_;
			T24_ = (NIM_BOOL)0;
			T24_ = isIntLit__types_186(a);
			if (T24_) goto LA25_;
			T24_ = ((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 41) || (*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 42));
			LA25_: ;
			result = T24_;
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 43):
		{
			NIM_BOOL T27_;
			T27_ = (NIM_BOOL)0;
			T27_ = isIntLit__types_186(a);
			if (T27_) goto LA28_;
			T27_ = ((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 41) || (*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 42) || (*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 43));
			LA28_: ;
			result = T27_;
		}
		break;
		default:
		{
			result = NIM_FALSE;
		}
		break;
		}
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T33_;
		if (!((*f).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36) && (*f).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 39))) goto LA31_;
		T33_ = (NIM_BOOL)0;
		T33_ = isIntLit__types_186(a);
		if (T33_) goto LA34_;
		T33_ = ((*a).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36) && (*a).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 39));
		LA34_: ;
		result = T33_;
	}
	goto LA1_;
	LA31_: ;
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA, handleRange__sigmatch_476)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg min, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg max) {
	tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA result;
	result = (tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA)0;
	{
		if (!((*a).kind == (*f).kind)) goto LA3_;
		result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ab;
		tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg k;
		ab = skipTypes__ast_3723(a, TM__wjrA09aH0rT1R7zbrcCaROw_16);
		k = (*ab).kind;
		{
			if (!(k == (*f).kind)) goto LA8_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 4);
		}
		goto LA6_;
		LA8_: ;
		{
			NIM_BOOL T11_;
			NIM_BOOL T12_;
			NIM_BOOL T13_;
			NIM_BOOL T14_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T18_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T19_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T21_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T22_;
			T11_ = (NIM_BOOL)0;
			T12_ = (NIM_BOOL)0;
			T13_ = (NIM_BOOL)0;
			T14_ = (NIM_BOOL)0;
			T14_ = (k == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31));
			if (!(T14_)) goto LA15_;
			T14_ = ((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 20) || (*f).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 32) && (*f).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35) || (*f).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40) && (*f).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44));
			LA15_: ;
			T13_ = T14_;
			if (!(T13_)) goto LA16_;
			T13_ = isIntLit__types_186(ab);
			LA16_: ;
			T12_ = T13_;
			if (!(T12_)) goto LA17_;
			T18_ = firstOrd__types_1406(((tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) NIM_NIL), f);
			T19_ = getInt__ast_4593((*ab).n);
			T12_ = lteq___int495056_421(T18_, T19_);
			LA17_: ;
			T11_ = T12_;
			if (!(T11_)) goto LA20_;
			T21_ = getInt__ast_4593((*ab).n);
			T22_ = lastOrd__types_1530(((tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) NIM_NIL), f);
			T11_ = lteq___int495056_421(T21_, T22_);
			LA20_: ;
			if (!T11_) goto LA23_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 9);
		}
		goto LA6_;
		LA23_: ;
		{
			NIM_BOOL T26_;
			T26_ = (NIM_BOOL)0;
			T26_ = ((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31));
			if (!(T26_)) goto LA27_;
			T26_ = (k >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 32) && k <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 34));
			LA27_: ;
			if (!T26_) goto LA28_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 2);
		}
		goto LA6_;
		LA28_: ;
		{
			NIM_BOOL T31_;
			T31_ = (NIM_BOOL)0;
			T31_ = ((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40));
			if (!(T31_)) goto LA32_;
			T31_ = (k >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 41) && k <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 43));
			LA32_: ;
			if (!T31_) goto LA33_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 2);
		}
		goto LA6_;
		LA33_: ;
		{
			NIM_BOOL T36_;
			T36_ = (NIM_BOOL)0;
			T36_ = (min <= k);
			if (!(T36_)) goto LA37_;
			T36_ = (k <= max);
			LA37_: ;
			if (!T36_) goto LA38_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
		}
		goto LA6_;
		LA38_: ;
		{
			NIM_BOOL T41_;
			NIM_BOOL T42_;
			NIM_BOOL T43_;
			NIM_BOOL T45_;
			NIM_BOOL T46_;
			NIM_BOOL T49_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T52_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T54_;
			T41_ = (NIM_BOOL)0;
			T42_ = (NIM_BOOL)0;
			T43_ = (NIM_BOOL)0;
			T43_ = ((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 20));
			if (!(T43_)) goto LA44_;
			T45_ = (NIM_BOOL)0;
			T46_ = (NIM_BOOL)0;
			T46_ = ((*f).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) && (*f).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35));
			if (!(T46_)) goto LA47_;
			T46_ = ((*(*a).sons->data[((NI) 0)]).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) && (*(*a).sons->data[((NI) 0)]).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35));
			LA47_: ;
			T45_ = T46_;
			if (T45_) goto LA48_;
			T49_ = (NIM_BOOL)0;
			T49_ = ((*f).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 41) && (*f).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 43));
			if (!(T49_)) goto LA50_;
			T49_ = ((*(*a).sons->data[((NI) 0)]).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 41) && (*(*a).sons->data[((NI) 0)]).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 43));
			LA50_: ;
			T45_ = T49_;
			LA48_: ;
			T43_ = T45_;
			LA44_: ;
			T42_ = T43_;
			if (!(T42_)) goto LA51_;
			T52_ = firstOrd__types_1406(((tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) NIM_NIL), f);
			T42_ = lteq___int495056_938(T52_, (*(*(*a).n)._kind_6.sons->data[((NI) 0)])._kind_1.intVal);
			LA51_: ;
			T41_ = T42_;
			if (!(T41_)) goto LA53_;
			T54_ = lastOrd__types_1530(((tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) NIM_NIL), f);
			T41_ = lteq___int495056_945((*(*(*a).n)._kind_6.sons->data[((NI) 1)])._kind_1.intVal, T54_);
			LA53_: ;
			if (!T41_) goto LA55_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
		}
		goto LA6_;
		LA55_: ;
		{
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
		}
		LA6_: ;
	}
	LA1_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isFloatLit__types_201)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36));
	if (!(T2_)) goto LA3_;
	T2_ = !(((*t).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = ((*(*t).n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 16));
	LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA, handleFloatRange__sigmatch_596)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a) {
	tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA result;
	result = (tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA)0;
	{
		if (!((*a).kind == (*f).kind)) goto LA3_;
		result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ab;
		tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg k;
		ab = skipTypes__ast_3723(a, TM__wjrA09aH0rT1R7zbrcCaROw_16);
		k = (*ab).kind;
		{
			if (!(k == (*f).kind)) goto LA8_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 4);
		}
		goto LA6_;
		LA8_: ;
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = isFloatLit__types_201(ab);
			if (!T11_) goto LA12_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 9);
		}
		goto LA6_;
		LA12_: ;
		{
			NIM_BOOL T15_;
			T15_ = (NIM_BOOL)0;
			T15_ = isIntLit__types_186(ab);
			if (!T15_) goto LA16_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
		}
		goto LA6_;
		LA16_: ;
		{
			NIM_BOOL T19_;
			T19_ = (NIM_BOOL)0;
			T19_ = (((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36) <= k);
			if (!(T19_)) goto LA20_;
			T19_ = (k <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 39));
			LA20_: ;
			if (!T19_) goto LA21_;
			{
				if (!((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 37))) goto LA25_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
			}
			goto LA23_;
			LA25_: ;
			{
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 2);
			}
			LA23_: ;
		}
		goto LA6_;
		LA21_: ;
		{
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
		}
		LA6_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isCovariantPtr__sigmatch_1405)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	switch ((*f).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45):
	{
		NIM_BOOL T2_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T3_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T5_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T6_;
		tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA T7_;
		T2_ = (NIM_BOOL)0;
		T3_ = NIM_NIL;
		T3_ = base__types_63(f);
		T2_ = !(((*T3_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21) || (*T3_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22) || (*T3_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*T3_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47) || (*T3_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45)));
		if (!(T2_)) goto LA4_;
		T5_ = NIM_NIL;
		T5_ = base__types_63(f);
		T6_ = NIM_NIL;
		T6_ = base__types_63(a);
		T7_ = (tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA)0;
		T7_ = typeRel__sigmatch_202(c, T5_, T6_, 2);
		T2_ = (T7_ == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 3));
		LA4_: ;
		result = T2_;
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* body;
		NIM_BOOL T9_;
		NIM_BOOL T10_;
		NIM_BOOL T11_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T12_;
		NI T14_;
		NIM_BOOL T17_;
		tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA T19_;
		body = base__types_63(f);
		T9_ = (NIM_BOOL)0;
		T10_ = (NIM_BOOL)0;
		T11_ = (NIM_BOOL)0;
		T12_ = NIM_NIL;
		T12_ = base__types_63(a);
		T11_ = (body == T12_);
		if (!(T11_)) goto LA13_;
		T14_ = (NI)0;
		T14_ = len__ast_3990(a);
		T11_ = (T14_ == ((NI) 3));
		LA13_: ;
		T10_ = T11_;
		if (!(T10_)) goto LA15_;
		T10_ = !((((*(*body).sons->data[((NI) 0)]).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 36))&63U)))!=0));
		LA15_: ;
		T9_ = T10_;
		if (!(T9_)) goto LA16_;
		T17_ = (NIM_BOOL)0;
		T17_ = !(((*(*f).sons->data[((NI) 1)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21) || (*(*f).sons->data[((NI) 1)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22) || (*(*f).sons->data[((NI) 1)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*(*f).sons->data[((NI) 1)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47) || (*(*f).sons->data[((NI) 1)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45)));
		if (!(T17_)) goto LA18_;
		T19_ = (tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA)0;
		T19_ = typeRel__sigmatch_202(c, (*f).sons->data[((NI) 1)], (*a).sons->data[((NI) 1)], 2);
		T17_ = (T19_ == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 3));
		LA18_: ;
		T9_ = T17_;
		LA16_: ;
		result = T9_;
		goto BeforeRet_;
	}
	break;
	default:
	{
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, inferStaticParam__sigmatch_1235)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lhs, NI64 rhs) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*lhs).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*lhs).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29) || (*lhs).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30) || (*lhs).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31) || (*lhs).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) || (*lhs).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28) || (*lhs).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*lhs)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		LA4_: ;
		if (!T3_) goto LA5_;
		switch ((*(*(*lhs)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic) {
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 46):
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 65):
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 29):
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 51):
		{
			{
				if (!((*(*lhs)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6))) goto LA10_;
				result = inferStaticParam__sigmatch_1235(c, (*lhs)._kind_6.sons->data[((NI) 2)], (NI64)(rhs - (*(*lhs)._kind_6.sons->data[((NI) 1)])._kind_1.intVal));
				goto BeforeRet_;
			}
			goto LA8_;
			LA10_: ;
			{
				if (!((*(*lhs)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6))) goto LA13_;
				result = inferStaticParam__sigmatch_1235(c, (*lhs)._kind_6.sons->data[((NI) 1)], (NI64)(rhs - (*(*lhs)._kind_6.sons->data[((NI) 2)])._kind_1.intVal));
				goto BeforeRet_;
			}
			goto LA8_;
			LA13_: ;
			LA8_: ;
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 30):
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 47):
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 66):
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 52):
		{
			{
				if (!((*(*lhs)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6))) goto LA18_;
				result = inferStaticParam__sigmatch_1235(c, (*lhs)._kind_6.sons->data[((NI) 2)], (NI64)((*(*lhs)._kind_6.sons->data[((NI) 1)])._kind_1.intVal - rhs));
				goto BeforeRet_;
			}
			goto LA16_;
			LA18_: ;
			{
				if (!((*(*lhs)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6))) goto LA21_;
				result = inferStaticParam__sigmatch_1235(c, (*lhs)._kind_6.sons->data[((NI) 1)], (NI64)(rhs + (*(*lhs)._kind_6.sons->data[((NI) 2)])._kind_1.intVal));
				goto BeforeRet_;
			}
			goto LA16_;
			LA21_: ;
			LA16_: ;
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 48):
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 67):
		{
			{
				if (!((*(*lhs)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6))) goto LA26_;
				{
					if (!((NI64)(rhs % (*(*lhs)._kind_6.sons->data[((NI) 1)])._kind_1.intVal) == IL64(0))) goto LA30_;
					result = inferStaticParam__sigmatch_1235(c, (*lhs)._kind_6.sons->data[((NI) 2)], (NI64)(rhs / (*(*lhs)._kind_6.sons->data[((NI) 1)])._kind_1.intVal));
					goto BeforeRet_;
				}
				LA30_: ;
			}
			goto LA24_;
			LA26_: ;
			{
				if (!((*(*lhs)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6))) goto LA33_;
				{
					if (!((NI64)(rhs % (*(*lhs)._kind_6.sons->data[((NI) 2)])._kind_1.intVal) == IL64(0))) goto LA37_;
					result = inferStaticParam__sigmatch_1235(c, (*lhs)._kind_6.sons->data[((NI) 1)], (NI64)(rhs / (*(*lhs)._kind_6.sons->data[((NI) 2)])._kind_1.intVal));
					goto BeforeRet_;
				}
				LA37_: ;
			}
			goto LA24_;
			LA33_: ;
			LA24_: ;
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 49):
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 68):
		{
			{
				if (!((*(*lhs)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6))) goto LA42_;
				{
					if (!((NI64)((*(*lhs)._kind_6.sons->data[((NI) 1)])._kind_1.intVal % rhs) == IL64(0))) goto LA46_;
					result = inferStaticParam__sigmatch_1235(c, (*lhs)._kind_6.sons->data[((NI) 2)], (NI64)((*(*lhs)._kind_6.sons->data[((NI) 1)])._kind_1.intVal / rhs));
					goto BeforeRet_;
				}
				LA46_: ;
			}
			goto LA40_;
			LA42_: ;
			{
				if (!((*(*lhs)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6))) goto LA49_;
				result = inferStaticParam__sigmatch_1235(c, (*lhs)._kind_6.sons->data[((NI) 1)], (NI64)((*(*lhs)._kind_6.sons->data[((NI) 2)])._kind_1.intVal * rhs));
				goto BeforeRet_;
			}
			goto LA40_;
			LA49_: ;
			LA40_: ;
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 58):
		{
			{
				if (!((*(*lhs)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6))) goto LA54_;
				result = inferStaticParam__sigmatch_1235(c, (*lhs)._kind_6.sons->data[((NI) 1)], (NI64)((NI64)(rhs) >> (NU64)((*(*lhs)._kind_6.sons->data[((NI) 2)])._kind_1.intVal)));
				goto BeforeRet_;
			}
			LA54_: ;
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 57):
		{
			{
				if (!((*(*lhs)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6))) goto LA59_;
				result = inferStaticParam__sigmatch_1235(c, (*lhs)._kind_6.sons->data[((NI) 1)], (NI64)((NU64)(rhs) << (NU64)((*(*lhs)._kind_6.sons->data[((NI) 2)])._kind_1.intVal)));
				goto BeforeRet_;
			}
			LA59_: ;
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 59):
		{
			{
				if (!((*(*lhs)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6))) goto LA64_;
				result = inferStaticParam__sigmatch_1235(c, (*lhs)._kind_6.sons->data[((NI) 1)], (NI64)((NI64)(rhs) >> (NU64)((*(*lhs)._kind_6.sons->data[((NI) 2)])._kind_1.intVal)));
				goto BeforeRet_;
			}
			LA64_: ;
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 93):
		{
			result = inferStaticParam__sigmatch_1235(c, (*lhs)._kind_6.sons->data[((NI) 1)], -(rhs));
			goto BeforeRet_;
		}
		break;
		case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 97):
		{
			result = inferStaticParam__sigmatch_1235(c, (*lhs)._kind_6.sons->data[((NI) 1)], rhs);
			goto BeforeRet_;
		}
		break;
		default:
		{
		}
		break;
		}
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T70_;
		NIM_BOOL T71_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* inferred;
		T70_ = (NIM_BOOL)0;
		T71_ = (NIM_BOOL)0;
		T71_ = ((*lhs).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		if (!(T71_)) goto LA72_;
		T71_ = ((*(*lhs).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60));
		LA72_: ;
		T70_ = T71_;
		if (!(T70_)) goto LA73_;
		T70_ = ((*(*lhs).typ).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
		LA73_: ;
		if (!T70_) goto LA74_;
		inferred = newTypeWithSons__semdata_851((*c).c, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60), (*(*lhs).typ).sons);
		asgnRef((void**) (&(*inferred).n), newIntNode__ast_3711(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6), rhs));
		put__sigmatch_120(c, (*lhs).typ, inferred);
		{
			if (!!(((*(*c).c).matchedConcept == ((tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw*) NIM_NIL)))) goto LA78_;
			asgnRef((void**) (&(*(*lhs).typ).n), (*inferred).n);
		}
		LA78_: ;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	goto LA1_;
	LA74_: ;
	LA1_: ;
	result = NIM_FALSE;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, failureToInferStaticParam__sigmatch_1361)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* staticParam;
	NimStringDesc* name;
	NimStringDesc* T6_;
	staticParam = findUnresolvedStatic__ast_4957(n);
	{
		if (!!((staticParam == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA3_;
		name = (*(*(*staticParam)._kind_4.sym).name).s;
	}
	goto LA1_;
	LA3_: ;
	{
		name = copyString(((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_17));
	}
	LA1_: ;
	T6_ = NIM_NIL;
	T6_ = rawNewString((name ? name->Sup.len : 0) + 45);
appendString(T6_, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_18));
appendString(T6_, name);
appendString(T6_, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_19));
	liMessage__msgs_1128(conf, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T6_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__wjrA09aH0rT1R7zbrcCaROw_20, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA, inferStaticsInRange__sigmatch_1370)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* inferred, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* concrete) {
	tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lowerBound;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* upperBound;
{	result = (tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA)0;
	lowerBound = tryResolvingStaticExpr__sigmatch_1227(c, (*(*inferred).n)._kind_6.sons->data[((NI) 0)], NIM_TRUE);
	upperBound = tryResolvingStaticExpr__sigmatch_1227(c, (*(*inferred).n)._kind_6.sons->data[((NI) 1)], NIM_TRUE);
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* expX60gensym222_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ rhsX60gensym222_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T16_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T17_;
		if (!((*lowerBound).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6))) goto LA3_;
		{
			if (!((*upperBound).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6))) goto LA7_;
			{
				tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T11_;
				NIM_BOOL T12_;
				T11_ = lengthOrd__types_1717((*(*(*c).c).graph).config, concrete);
				T12_ = (NIM_BOOL)0;
				T12_ = eqeq___int495056_952(T11_, (NI64)((NI64)((*upperBound)._kind_1.intVal - (*lowerBound)._kind_1.intVal) + IL64(1)));
				if (!T12_) goto LA13_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
				goto BeforeRet_;
			}
			goto LA9_;
			LA13_: ;
			{
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
				goto BeforeRet_;
			}
			LA9_: ;
		}
		LA7_: ;
		expX60gensym222_ = upperBound;
		T16_ = lengthOrd__types_1717((*(*(*c).c).graph).config, concrete);
		T17_ = plus___int495056_987(T16_, (*lowerBound)._kind_1.intVal);
		rhsX60gensym222_ = minus___int495056_973(T17_, IL64(1));
		{
			NI64 T20_;
			NIM_BOOL T21_;
			T20_ = (NI64)0;
			T20_ = toInt64__int495056_88(rhsX60gensym222_);
			T21_ = (NIM_BOOL)0;
			T21_ = inferStaticParam__sigmatch_1235(c, expX60gensym222_, T20_);
			if (!T21_) goto LA22_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
			goto BeforeRet_;
		}
		goto LA18_;
		LA22_: ;
		{
			failureToInferStaticParam__sigmatch_1361((*(*(*c).c).graph).config, expX60gensym222_);
		}
		LA18_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* expX60gensym225_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ rhsX60gensym225_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T28_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T29_;
		tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T30_;
		if (!((*upperBound).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6))) goto LA26_;
		expX60gensym225_ = lowerBound;
		T28_ = getInt__ast_4593(upperBound);
		T29_ = plus___int495056_987(T28_, IL64(1));
		T30_ = lengthOrd__types_1717((*(*(*c).c).graph).config, concrete);
		rhsX60gensym225_ = minus___int495056_637(T29_, T30_);
		{
			NI64 T33_;
			NIM_BOOL T34_;
			T33_ = (NI64)0;
			T33_ = toInt64__int495056_88(rhsX60gensym225_);
			T34_ = (NIM_BOOL)0;
			T34_ = inferStaticParam__sigmatch_1235(c, expX60gensym225_, T33_);
			if (!T34_) goto LA35_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
			goto BeforeRet_;
		}
		goto LA31_;
		LA35_: ;
		{
			failureToInferStaticParam__sigmatch_1361((*(*(*c).c).graph).config, expX60gensym225_);
		}
		LA31_: ;
	}
	goto LA1_;
	LA26_: ;
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA, minRel__sigmatch_798)(tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA a, tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA b) {
	tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA result;
	result = (tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA)0;
	{
		if (!(a <= b)) goto LA3_;
		result = a;
	}
	goto LA1_;
	LA3_: ;
	{
		result = b;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA, recordRel__sigmatch_806)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a) {
	tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA result;
{	result = (tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA)0;
	result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = sameType__types_1880(f, a, 0);
		if (!T3_) goto LA4_;
		result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10);
	}
	goto LA1_;
	LA4_: ;
	{
		NI T7_;
		NI T8_;
		NI firstField;
		T7_ = (NI)0;
		T7_ = len__ast_3990(a);
		T8_ = (NI)0;
		T8_ = len__ast_3990(f);
		if (!(T7_ == T8_)) goto LA9_;
		result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10);
		{
			if (!((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18))) goto LA13_;
			firstField = ((NI) 0);
		}
		goto LA11_;
		LA13_: ;
		{
			firstField = ((NI) 1);
		}
		LA11_: ;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3990(f);
			i_2 = firstField;
			{
				while (1) {
					tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA m;
					if (!(i_2 < colontmp_)) goto LA18;
					i = i_2;
					m = typeRel__sigmatch_202(c, (*f).sons->data[i], (*a).sons->data[i], 0);
					{
						if (!(m < ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 3))) goto LA21_;
						result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
						goto BeforeRet_;
					}
					LA21_: ;
					result = minRel__sigmatch_798(result, m);
					i_2 += ((NI) 1);
				} LA18: ;
			}
		}
		{
			NIM_BOOL T25_;
			T25_ = (NIM_BOOL)0;
			T25_ = !(((*f).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
			if (!(T25_)) goto LA26_;
			T25_ = !(((*a).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
			LA26_: ;
			if (!T25_) goto LA27_;
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = len__ast_3155((*f).n);
				i_4 = ((NI) 0);
				{
					while (1) {
						if (!(i_4 < colontmp__2)) goto LA31;
						i_3 = i_4;
						{
							if (!!(((*(*(*f).n)._kind_6.sons->data[i_3]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)))) goto LA34_;
							result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
							goto BeforeRet_;
						}
						goto LA32_;
						LA34_: ;
						{
							if (!!(((*(*(*a).n)._kind_6.sons->data[i_3]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)))) goto LA37_;
							result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
							goto BeforeRet_;
						}
						goto LA32_;
						LA37_: ;
						{
							tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* x;
							tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* y;
							x = (*(*(*f).n)._kind_6.sons->data[i_3])._kind_4.sym;
							y = (*(*(*a).n)._kind_6.sons->data[i_3])._kind_4.sym;
							{
								NIM_BOOL T42_;
								tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA T44_;
								T42_ = (NIM_BOOL)0;
								T42_ = ((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17));
								if (!(T42_)) goto LA43_;
								T44_ = (tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA)0;
								T44_ = typeRel__sigmatch_202(c, (*x).typ, (*y).typ, 0);
								T42_ = (T44_ < ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 3));
								LA43_: ;
								if (!T42_) goto LA45_;
								result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
								goto BeforeRet_;
							}
							LA45_: ;
							{
								if (!!(((*(*x).name).id == (*(*y).name).id))) goto LA49_;
								result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
								goto BeforeRet_;
							}
							LA49_: ;
						}
						LA32_: ;
						i_4 += ((NI) 1);
					} LA31: ;
				}
			}
		}
		LA27_: ;
	}
	goto LA1_;
	LA9_: ;
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genericParamPut__sigmatch_622)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* last, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* fGenericOrigin) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T7_;
		NI T8_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = !((fGenericOrigin == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		if (!(T4_)) goto LA5_;
		T4_ = ((*last).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11));
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA6_;
		T7_ = (NI)0;
		T7_ = len__ast_3990(last);
		T8_ = (NI)0;
		T8_ = len__ast_3990(fGenericOrigin);
		T3_ = ((NI)(T7_ - ((NI) 1)) == T8_);
		LA6_: ;
		if (!T3_) goto LA9_;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3990(fGenericOrigin);
			i_2 = ((NI) 1);
			{
				while (1) {
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* x;
					RootObj* T14_;
					if (!(i_2 < colontmp_)) goto LA13;
					i = i_2;
					T14_ = NIM_NIL;
					T14_ = idTableGet__astalgo_64((*c).bindings, (*((tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA**) (&((*fGenericOrigin).sons->data[i])))));
					x = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) (T14_));
					{
						if (!(x == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA17_;
						put__sigmatch_120(c, (*fGenericOrigin).sons->data[i], (*last).sons->data[i]);
					}
					LA17_: ;
					i_2 += ((NI) 1);
				} LA13: ;
			}
		}
	}
	LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, isObjectSubtype__sigmatch_656)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* fGenericOrigin) {
	NI result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	NI depth;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* last;
	result = (NI)0;
	t = a;
	depth = ((NI) 0);
	last = a;
	{
		while (1) {
			NIM_BOOL T3_;
			NIM_BOOL T5_;
			T3_ = (NIM_BOOL)0;
			T3_ = !((t == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
			if (!(T3_)) goto LA4_;
			T5_ = (NIM_BOOL)0;
			T5_ = sameObjectTypes__types_2103(f, t);
			T3_ = !(T5_);
			LA4_: ;
			if (!T3_) goto LA2;
			t = (*t).sons->data[((NI) 0)];
			{
				if (!(t == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA8_;
				goto LA1;
			}
			LA8_: ;
			last = t;
			t = skipTypes__ast_3723(t, TM__wjrA09aH0rT1R7zbrcCaROw_12);
			depth += ((NI) 1);
		} LA2: ;
	} LA1: ;
	{
		if (!!((t == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA12_;
		genericParamPut__sigmatch_622(c, last, fGenericOrigin);
		result = depth;
	}
	goto LA10_;
	LA12_: ;
	{
		result = ((NI) -1);
	}
	LA10_: ;
	return result;
}
static N_INLINE(NIM_BOOL, sameDistinctTypes__types_2148)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* b) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = sameObjectTypes__types_2103(a, b);
	return result;
}
static N_INLINE(tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA, allowsNil__sigmatch_875)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f) {
	tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA result;
	result = (tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA)0;
	{
		if (!!((((*f).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 17))&63U)))!=0))) goto LA3_;
		result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 3);
	}
	goto LA1_;
	LA3_: ;
	{
		result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
	}
	LA1_: ;
	return result;
}
static N_INLINE(NIM_BOOL, inconsistentVarTypes__sigmatch_882)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = !(((*f).kind == (*a).kind));
	if (!(T1_)) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47) || (*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46));
	if (T3_) goto LA4_;
	T3_ = ((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47) || (*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46));
	LA4_: ;
	T1_ = T3_;
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA, procParamTypeRel__sigmatch_898)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a) {
	tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f_2;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a_2;
{	result = (tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA)0;
	f_2 = f;
	a_2 = a;
	{
		NIM_BOOL T3_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* aResolved;
		RootObj* T6_;
		T3_ = (NIM_BOOL)0;
		T3_ = isMetaType__ast_3474(a_2);
		if (!T3_) goto LA4_;
		T6_ = NIM_NIL;
		T6_ = idTableGet__astalgo_64((*c).bindings, (*((tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA**) (&(a_2)))));
		aResolved = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) (T6_));
		{
			if (!!((aResolved == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA9_;
			a_2 = aResolved;
		}
		LA9_: ;
	}
	LA4_: ;
	{
		NIM_BOOL T13_;
		tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA reverseRel;
		T13_ = (NIM_BOOL)0;
		T13_ = isMetaType__ast_3474(a_2);
		if (!T13_) goto LA14_;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = isMetaType__ast_3474(f_2);
			if (!T18_) goto LA19_;
			{
				if (!!(((*c).call == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA23_;
				f_2 = generateTypeInstance__semtypinst_1086((*c).c, (*c).bindings, (*(*c).call).info, f_2);
			}
			goto LA21_;
			LA23_: ;
			{
				f_2 = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL);
			}
			LA21_: ;
			{
				NIM_BOOL T28_;
				T28_ = (NIM_BOOL)0;
				T28_ = (f_2 == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
				if (T28_) goto LA29_;
				T28_ = isMetaType__ast_3474(f_2);
				LA29_: ;
				if (!T28_) goto LA30_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 5);
				goto BeforeRet_;
			}
			LA30_: ;
		}
		LA19_: ;
		reverseRel = typeRel__sigmatch_202(c, a_2, f_2, 0);
		{
			if (!(((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8) <= reverseRel)) goto LA34_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 6);
		}
		LA34_: ;
	}
	goto LA11_;
	LA14_: ;
	{
		result = typeRel__sigmatch_202(c, f_2, a_2, 0);
	}
	LA11_: ;
	{
		NIM_BOOL T39_;
		T39_ = (NIM_BOOL)0;
		T39_ = (result <= ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 4));
		if (T39_) goto LA40_;
		T39_ = inconsistentVarTypes__sigmatch_882(f_2, a_2);
		LA40_: ;
		if (!T39_) goto LA41_;
		result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
	}
	LA41_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA, procTypeRel__sigmatch_927)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a) {
	tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA result;
{	result = (tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA)0;
	switch ((*a).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25):
	{
		tyTuple__hwJj4UwOYfHl0hX52kYcPQ T33_;
		{
			NI T4_;
			NI T5_;
			T4_ = (NI)0;
			T4_ = len__ast_3990(f);
			T5_ = (NI)0;
			T5_ = len__ast_3990(a);
			if (!!((T4_ == T5_))) goto LA6_;
			goto BeforeRet_;
		}
		LA6_: ;
		result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3990(f);
			i_2 = ((NI) 1);
			{
				while (1) {
					tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA T11_;
					if (!(i_2 < colontmp_)) goto LA10;
					i = i_2;
					T11_ = (tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA)0;
					T11_ = procParamTypeRel__sigmatch_898(c, (*f).sons->data[i], (*a).sons->data[i]);
					result = minRel__sigmatch_798(result, T11_);
					{
						if (!(result == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0))) goto LA14_;
						goto BeforeRet_;
					}
					LA14_: ;
					i_2 += ((NI) 1);
				} LA10: ;
			}
		}
		{
			if (!!(((*f).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA18_;
			{
				tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA T24_;
				if (!!(((*a).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA22_;
				T24_ = (tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA)0;
				T24_ = procParamTypeRel__sigmatch_898(c, (*f).sons->data[((NI) 0)], (*a).sons->data[((NI) 0)]);
				result = minRel__sigmatch_798(result, T24_);
				{
					if (!(result == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0))) goto LA27_;
					goto BeforeRet_;
				}
				LA27_: ;
			}
			goto LA20_;
			LA22_: ;
			{
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
				goto BeforeRet_;
			}
			LA20_: ;
		}
		goto LA16_;
		LA18_: ;
		{
			if (!!(((*a).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA31_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
			goto BeforeRet_;
		}
		goto LA16_;
		LA31_: ;
		LA16_: ;
		T33_ = getProcConvMismatch__types_3753((*(*(*c).c).graph).config, f, a, result);
		result = T33_.Field1;
		{
			tyEnum_EffectsCompat__Ua7UNlEurqcdZ8OG3EY7xA T36_;
			T36_ = (tyEnum_EffectsCompat__Ua7UNlEurqcdZ8OG3EY7xA)0;
			T36_ = compatibleEffects__types_3483(f, a);
			if (!!((T36_ == ((tyEnum_EffectsCompat__Ua7UNlEurqcdZ8OG3EY7xA) 0)))) goto LA37_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
			goto BeforeRet_;
		}
		LA37_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 5):
	{
		result = allowsNil__sigmatch_875(f);
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, skipToObject__sigmatch_703)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyEnum_SkippedPtr__ZfkN1Zg3tYB8pQTEnxqNcg* skipped) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* r;
	NI ptrs;
	result = NIM_NIL;
	r = t;
	ptrs = ((NI) 0);
	{
		while (1) {
			if (!!((r == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA2;
			switch ((*r).kind) {
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 9):
			{
				r = (*r).sons->data[((NI) 0)];
			}
			break;
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22):
			{
				ptrs += ((NI) 1);
				(*skipped) = ((tyEnum_SkippedPtr__ZfkN1Zg3tYB8pQTEnxqNcg) 1);
				r = lastSon__ast_3731(r);
			}
			break;
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21):
			{
				ptrs += ((NI) 1);
				(*skipped) = ((tyEnum_SkippedPtr__ZfkN1Zg3tYB8pQTEnxqNcg) 2);
				r = lastSon__ast_3731(r);
			}
			break;
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 10):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 4):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45):
			{
				r = lastSon__ast_3731(r);
			}
			break;
			default:
			{
				goto LA1;
			}
			break;
			}
		} LA2: ;
	} LA1: ;
	{
		NIM_BOOL T10_;
		T10_ = (NIM_BOOL)0;
		T10_ = ((*r).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17));
		if (!(T10_)) goto LA11_;
		T10_ = (ptrs <= ((NI) 1));
		LA11_: ;
		if (!T10_) goto LA12_;
		result = r;
	}
	LA12_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isGenericSubtype__sigmatch_744)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, NI* d, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* fGenericOrigin) {
	NIM_BOOL result;
	tyEnum_SkippedPtr__ZfkN1Zg3tYB8pQTEnxqNcg askip;
	tyEnum_SkippedPtr__ZfkN1Zg3tYB8pQTEnxqNcg fskip;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* r;
	NI depth;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* last;
{	result = (NIM_BOOL)0;
	askip = ((tyEnum_SkippedPtr__ZfkN1Zg3tYB8pQTEnxqNcg) 0);
	fskip = ((tyEnum_SkippedPtr__ZfkN1Zg3tYB8pQTEnxqNcg) 0);
	t = skipToObject__sigmatch_703(a, (&askip));
	r = skipToObject__sigmatch_703(f, (&fskip));
	{
		if (!(r == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA3_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	LA3_: ;
	depth = ((NI) 0);
	last = a;
	{
		while (1) {
			NIM_BOOL T7_;
			NIM_BOOL T8_;
			T7_ = (NIM_BOOL)0;
			T8_ = (NIM_BOOL)0;
			T8_ = !((t == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
			if (!(T8_)) goto LA9_;
			T8_ = !(((*r).sym == (*t).sym));
			LA9_: ;
			T7_ = T8_;
			if (!(T7_)) goto LA10_;
			T7_ = (askip == fskip);
			LA10_: ;
			if (!T7_) goto LA6;
			t = (*t).sons->data[((NI) 0)];
			{
				if (!(t == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA13_;
				goto LA5;
			}
			LA13_: ;
			last = t;
			t = skipToObject__sigmatch_703(t, (&askip));
			depth += ((NI) 1);
		} LA6: ;
	} LA5: ;
	{
		NIM_BOOL T17_;
		T17_ = (NIM_BOOL)0;
		T17_ = !((t == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		if (!(T17_)) goto LA18_;
		T17_ = (askip == fskip);
		LA18_: ;
		if (!T17_) goto LA19_;
		genericParamPut__sigmatch_622(c, last, fGenericOrigin);
		(*d) = depth;
		result = NIM_TRUE;
	}
	LA19_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, concreteType__sigmatch_443)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	result = NIM_NIL;
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8):
	{
		{
			if (!(*c).isNoCall) goto LA4_;
			result = t;
		}
		goto LA2_;
		LA4_: ;
		{
			result = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL);
		}
		LA2_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 19):
	{
		{
			if (!((*(*t).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 3))) goto LA10_;
			result = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL);
		}
		goto LA8_;
		LA10_: ;
		{
			result = t;
		}
		LA8_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 59):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 62):
	{
		result = t;
		{
			while (1) {
				RootObj* T16_;
				T16_ = NIM_NIL;
				T16_ = idTableGet__astalgo_64((*c).bindings, &t->Sup);
				result = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) (T16_));
				{
					if (!(result == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA19_;
					goto LA14;
				}
				LA19_: ;
				{
					if (!!(((*result).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12)))) goto LA23_;
					goto LA14;
				}
				LA23_: ;
			}
		} LA14: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 9):
	{
		result = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45):
	{
		{
			NIM_BOOL T29_;
			NIM_BOOL T30_;
			NI T32_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T34_;
			T29_ = (NIM_BOOL)0;
			T30_ = (NIM_BOOL)0;
			T30_ = !((f == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
			if (!(T30_)) goto LA31_;
			T32_ = (NI)0;
			T32_ = len__ast_3990(f);
			T30_ = (((NI) 0) < T32_);
			LA31_: ;
			T29_ = T30_;
			if (!(T29_)) goto LA33_;
			T34_ = NIM_NIL;
			T34_ = skipTypes__ast_3723((*f).sons->data[((NI) 0)], TM__wjrA09aH0rT1R7zbrcCaROw_29);
			T29_ = ((*T34_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25));
			LA33_: ;
			if (!T29_) goto LA35_;
			result = lastSon__ast_3731(t);
		}
		goto LA27_;
		LA35_: ;
		{
			result = t;
		}
		LA27_: ;
	}
	break;
	default:
	{
		result = t;
	}
	break;
	}
	return result;
}
static N_NIMCALL(void, Marker_tyRef__LPNfKrTCyieb604nvY2VZA)(void* p, NI op) {
	tyObject_Env_sigmatchdotnim_matchUserTypeClass___J1TZ8yvjL0AcwEoyPAfoPQ* a;
	a = (tyObject_Env_sigmatchdotnim_matchUserTypeClass___J1TZ8yvjL0AcwEoyPAfoPQ*)p;
	nimGCvisit((void*)(*a).errorPrefix1, op);
	nimGCvisit((void*)(*a).typeClass2, op);
	nimGCvisit((void*)(*a).oldWriteHook3.ClE_0, op);
	nimGCvisit((void*)(*a).diagnostics4, op);
}
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextSymId__ast_3103)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x) {
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*x).symId += ((NI) 1);
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	result.module = (*x).module;
	result.item = (*x).symId;
	return result;
}
static N_NIMCALL(void, Marker_tySequence__r9afowSCR9cYl2NdMwuF5Jtg)(void* p, NI op) {
	tySequence__r9afowSCR9cYl2NdMwuF5Jtg* a;
	NI T1_;
	a = (tySequence__r9afowSCR9cYl2NdMwuF5Jtg*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field0, op);
	nimGCvisit((void*)a->data[T1_].Field1, op);
	}
}
static N_INLINE(void, addDeclAt__lookups_1509)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	addDeclAt__lookups_995(c, scope, sym, (*sym).info);
}
static N_INLINE(void, addDecl__lookups_1517)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	addDeclAt__lookups_1509(c, (*c).currentScope, sym);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___sigmatch_1102)(NimStringDesc* s, void* ClE_0) {
	tyObject_Env_sigmatchdotnim_matchUserTypeClass___J1TZ8yvjL0AcwEoyPAfoPQ* colonenvP_;
	NimStringDesc* msg;
	NI T10_;
	NimStringDesc* T11_;
	colonenvP_ = (tyObject_Env_sigmatchdotnim_matchUserTypeClass___J1TZ8yvjL0AcwEoyPAfoPQ*) ClE_0;
	{
		NimStringDesc* T5_;
		if (!(((*colonenvP_).errorPrefix1 ? (*colonenvP_).errorPrefix1->Sup.len : 0) == ((NI) 0))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = rawNewString(((*(*(*(*colonenvP_).typeClass2).sym).name).s ? (*(*(*(*colonenvP_).typeClass2).sym).name).s->Sup.len : 0) + 1);
appendString(T5_, (*(*(*(*colonenvP_).typeClass2).sym).name).s);
appendString(T5_, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_37));
		asgnRef((void**) (&(*colonenvP_).errorPrefix1), T5_);
	}
	LA3_: ;
	msg = nsuReplaceStr(s, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_38), (*colonenvP_).errorPrefix1);
	{
		if (!!(((*colonenvP_).oldWriteHook3.ClP_0 == TM__wjrA09aH0rT1R7zbrcCaROw_39.ClP_0 && (*colonenvP_).oldWriteHook3.ClE_0 == TM__wjrA09aH0rT1R7zbrcCaROw_39.ClE_0))) goto LA8_;
		(*colonenvP_).oldWriteHook3.ClE_0? (*colonenvP_).oldWriteHook3.ClP_0(msg, (*colonenvP_).oldWriteHook3.ClE_0):((TM__wjrA09aH0rT1R7zbrcCaROw_40)((*colonenvP_).oldWriteHook3.ClP_0))(msg);
	}
	LA8_: ;
	asgnRef((void**) (&(*colonenvP_).diagnostics4), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*colonenvP_).diagnostics4), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
	T10_ = (*colonenvP_).diagnostics4->Sup.len++;
	T11_ = NIM_NIL;
	T11_ = (*colonenvP_).diagnostics4->data[T10_]; (*colonenvP_).diagnostics4->data[T10_] = copyStringRC1(msg);
	if (T11_) nimGCunrefNoCycle(T11_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, matchUserTypeClass__sigmatch_993)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ff, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_Env_sigmatchdotnim_matchUserTypeClass___J1TZ8yvjL0AcwEoyPAfoPQ* colonenv_;
	tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body;
	tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw matchedConceptContext;
	tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw* prevMatchedConcept;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* prevCandidateType;
	tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* T11_;
	TSafePoint TM__wjrA09aH0rT1R7zbrcCaROw_35;
	tySequence__r9afowSCR9cYl2NdMwuF5Jtg* typeParams;
	tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags;
	NIM_BOOL collectDiagnostics;
	NIM_BOOL T56_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* checkedBody;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T63_;
{	result = NIM_NIL;
	colonenv_ = NIM_NIL;
	colonenv_ = (tyObject_Env_sigmatchdotnim_matchUserTypeClass___J1TZ8yvjL0AcwEoyPAfoPQ*) newObj((&NTIrefobject__LPNfKrTCyieb604nvY2VZA_), sizeof(tyObject_Env_sigmatchdotnim_matchUserTypeClass___J1TZ8yvjL0AcwEoyPAfoPQ));
	(*colonenv_).Sup.m_type = (&NTIobject__J1TZ8yvjL0AcwEoyPAfoPQ_);
	c = (*m).c;
	asgnRef((void**) (&(*colonenv_).typeClass2), skipTypes__ast_3723(ff, TM__wjrA09aH0rT1R7zbrcCaROw_32));
	body = (*(*(*colonenv_).typeClass2).n)._kind_6.sons->data[((NI) 3)];
	nimZeroMem((void*)(&matchedConceptContext), sizeof(tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw));
	prevMatchedConcept = (*c).matchedConcept;
	prevCandidateType = (*(*(*colonenv_).typeClass2).sons->data[((NI) 0)]).sons->data[((NI) 0)];
	{
		if (!!((prevMatchedConcept == ((tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw*) NIM_NIL)))) goto LA3_;
		matchedConceptContext.prev = prevMatchedConcept;
		matchedConceptContext.depth = (NI)((*prevMatchedConcept).depth + ((NI) 1));
		{
			NimStringDesc* T9_;
			NimStringDesc* T10_;
			if (!(((NI) 4) < (*prevMatchedConcept).depth)) goto LA7_;
			T9_ = NIM_NIL;
			T10_ = NIM_NIL;
			T10_ = dollar___renderer_2116(body);
			T9_ = rawNewString((T10_ ? T10_->Sup.len : 0) + 29);
appendString(T9_, T10_);
appendString(T9_, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_33));
			liMessage__msgs_1128((*(*(*m).c).graph).config, (*body).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T9_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__wjrA09aH0rT1R7zbrcCaROw_34, NIM_FALSE);
			result = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL);
			goto BeforeRet_;
		}
		LA7_: ;
	}
	LA3_: ;
	T11_ = NIM_NIL;
	T11_ = openScope__lookups_76(c);
	matchedConceptContext.candidateType = a;
	asgnRef((void**) (&(*(*(*colonenv_).typeClass2).sons->data[((NI) 0)]).sons->data[((NI) 0)]), a);
	(*c).matchedConcept = (&matchedConceptContext);
	pushSafePoint(&TM__wjrA09aH0rT1R7zbrcCaROw_35);
	TM__wjrA09aH0rT1R7zbrcCaROw_35.status = _setjmp(TM__wjrA09aH0rT1R7zbrcCaROw_35.context);
	if (TM__wjrA09aH0rT1R7zbrcCaROw_35.status == 0) {
	typeParams = NIM_NIL;
	{
		if (!((*ff).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 53))) goto LA14_;
		{
			NI i;
			NI colontmp_;
			NI T17_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			T17_ = (NI)0;
			T17_ = len__ast_3990(ff);
			colontmp_ = (NI)(T17_ - ((NI) 1));
			i_2 = ((NI) 1);
			{
				while (1) {
					tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* typeParamName;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T20_;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* param;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* alreadyBound;
					RootObj* T21_;
					if (!(i_2 < colontmp_)) goto LA19;
					i = i_2;
					T20_ = NIM_NIL;
					T20_ = base__types_63(ff);
					typeParamName = (*(*(*T20_).sons->data[(NI)(i - ((NI) 1))]).sym).name;
					typ = (*ff).sons->data[i];
					param = NIM_NIL;
					T21_ = NIM_NIL;
					T21_ = idTableGet__astalgo_64((*m).bindings, (*((tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA**) (&(typ)))));
					alreadyBound = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) (T21_));
					{
						if (!!((alreadyBound == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA24_;
						typ = alreadyBound;
					}
					LA24_: ;
					{
						tyTuple__7ojGQ7p3GL8CscnPtcFVrQ T54_;
						NI T55_;
						{
							tyTuple__7ojGQ7p3GL8CscnPtcFVrQ* prev;
							NI i_3;
							NI L;
							NI T28_;
							prev = (tyTuple__7ojGQ7p3GL8CscnPtcFVrQ*)0;
							i_3 = ((NI) 0);
							T28_ = (typeParams ? typeParams->Sup.len : 0);
							L = T28_;
							{
								while (1) {
									if (!(i_3 < L)) goto LA30;
									prev = (&typeParams->data[i_3]);
									{
										tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* xX60gensym159_;
										tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* xX60gensym160_;
										tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T35_;
										xX60gensym159_ = (*prev).Field1;
										xX60gensym160_ = typ;
										if (!((NI)((NI)((NU32)(((NI) ((*xX60gensym159_).Sup.itemId.module))) << (NU32)(((NI) 20))) + ((NI) ((*xX60gensym159_).Sup.itemId.item))) == (NI)((NI)((NU32)(((NI) ((*xX60gensym160_).Sup.itemId.module))) << (NU32)(((NI) 20))) + ((NI) ((*xX60gensym160_).Sup.itemId.item))))) goto LA33_;
										T35_ = nextSymId__ast_3103((*c).Sup.idgen);
										param = newSym__ast_3409((*(*prev).Field0).kind, typeParamName, T35_, (*(*colonenv_).typeClass2).sym, (*(*(*colonenv_).typeClass2).sym).info, 0);
										asgnRef((void**) (&(*param).typ), (*(*prev).Field0).typ);
										goto LA26;
									}
									LA33_: ;
									i_3 += ((NI) 1);
								} LA30: ;
							}
						}
						switch ((*typ).kind) {
						case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60):
						{
							tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T37_;
							T37_ = nextSymId__ast_3103((*c).Sup.idgen);
							param = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 10), typeParamName, T37_, (*(*colonenv_).typeClass2).sym, (*(*(*colonenv_).typeClass2).sym).info, 0);
							asgnRef((void**) (&(*param).typ), exactReplica__ast_4039(typ));
							{
								if (!((*typ).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA40_;
								(*(*param).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 27)) & 63);
							}
							goto LA38_;
							LA40_: ;
							{
								asgnRef((void**) (&(*param).ast), (*typ).n);
							}
							LA38_: ;
						}
						break;
						case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 61):
						{
							tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T44_;
							T44_ = nextSymId__ast_3103((*c).Sup.idgen);
							param = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8), typeParamName, T44_, (*(*colonenv_).typeClass2).sym, (*(*(*colonenv_).typeClass2).sym).info, 0);
							asgnRef((void**) (&(*param).typ), exactReplica__ast_4039(typ));
						}
						break;
						default:
						{
							tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T46_;
							T46_ = nextSymId__ast_3103((*c).Sup.idgen);
							param = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 7), typeParamName, T46_, (*(*colonenv_).typeClass2).sym, (*(*(*colonenv_).typeClass2).sym).info, 0);
							{
								NIM_BOOL T49_;
								tySequence__vKogasEnJSPhbQmA8r4Y9aA* T52_;
								T49_ = (NIM_BOOL)0;
								T49_ = isMetaType__ast_3474(typ);
								if (!T49_) goto LA50_;
								T52_ = NIM_NIL;
								T52_ = (tySequence__vKogasEnJSPhbQmA8r4Y9aA*) newSeq((&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_), 1);
								asgnRef((void**) (&T52_->data[0]), typ);
								asgnRef((void**) (&(*param).typ), newTypeWithSons__semdata_851(c, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 55), T52_));
							}
							goto LA47_;
							LA50_: ;
							{
								asgnRef((void**) (&(*param).typ), makeTypeDesc__concepts_49(c, typ));
							}
							LA47_: ;
						}
						break;
						}
						nimZeroMem((void*)(&T54_), sizeof(tyTuple__7ojGQ7p3GL8CscnPtcFVrQ));
						T54_.Field0 = param;
						T54_.Field1 = typ;
						typeParams = (tySequence__r9afowSCR9cYl2NdMwuF5Jtg*) incrSeqV3((TGenericSeq*)(typeParams), (&NTIseqLLpsym_ptypeTT__r9afowSCR9cYl2NdMwuF5Jtg_));
						T55_ = typeParams->Sup.len++;
						asgnRef((void**) (&typeParams->data[T55_].Field0), T54_.Field0);
						asgnRef((void**) (&typeParams->data[T55_].Field1), T54_.Field1);
					} LA26: ;
					addDecl__lookups_1517(c, param);
					i_2 += ((NI) 1);
				} LA19: ;
			}
		}
	}
	LA14_: ;
	nimZeroMem((void*)(&(*colonenv_).oldWriteHook3), sizeof(tyProc__k2HFjxisIgDALbEUFojxaQ));
	asgnRef((void**) (&(*colonenv_).diagnostics4), NIM_NIL);
	asgnRef((void**) (&(*colonenv_).errorPrefix1), NIM_NIL);
	flags = 0;
	T56_ = (NIM_BOOL)0;
	T56_ = (*m).diagnosticsEnabled;
	if (T56_) goto LA57_;
	T56_ = (((*(*(*colonenv_).typeClass2).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 23))&63U)))!=0);
	LA57_: ;
	collectDiagnostics = T56_;
	{
		tyProc__k2HFjxisIgDALbEUFojxaQ T62_;
		if (!collectDiagnostics) goto LA60_;
		asgnRef((void**) (&(*colonenv_).oldWriteHook3.ClE_0), (*(*(*(*m).c).graph).config).writelnHook.ClE_0);
		(*colonenv_).oldWriteHook3.ClP_0 = (*(*(*(*m).c).graph).config).writelnHook.ClP_0;
		if ((*colonenv_).diagnostics4) { nimGCunrefNoCycle((*colonenv_).diagnostics4); (*colonenv_).diagnostics4 = NIM_NIL; }
		flags = 1024;
		nimZeroMem((void*)(&T62_), sizeof(tyProc__k2HFjxisIgDALbEUFojxaQ));
		T62_.ClP_0 = colonanonymous___sigmatch_1102; T62_.ClE_0 = colonenv_;
		asgnRef((void**) (&(*(*(*(*m).c).graph).config).writelnHook.ClE_0), T62_.ClE_0);
		(*(*(*(*m).c).graph).config).writelnHook.ClP_0 = T62_.ClP_0;
	}
	LA60_: ;
	T63_ = NIM_NIL;
	T63_ = copyTree__ast_4432(body);
	checkedBody = (*c).semTryExpr(c, T63_, flags);
	{
		if (!collectDiagnostics) goto LA66_;
		asgnRef((void**) (&(*(*(*(*m).c).graph).config).writelnHook.ClE_0), (*colonenv_).oldWriteHook3.ClE_0);
		(*(*(*(*m).c).graph).config).writelnHook.ClP_0 = (*colonenv_).oldWriteHook3.ClP_0;
		{
			NimStringDesc** msg;
			NI i_4;
			NI L_2;
			NI T69_;
			msg = (NimStringDesc**)0;
			i_4 = ((NI) 0);
			T69_ = ((*colonenv_).diagnostics4 ? (*colonenv_).diagnostics4->Sup.len : 0);
			L_2 = T69_;
			{
				while (1) {
					NI T72_;
					NimStringDesc* T73_;
					if (!(i_4 < L_2)) goto LA71;
					msg = (&(*colonenv_).diagnostics4->data[i_4]);
					unsureAsgnRef((void**) (&(*m).diagnostics), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*m).diagnostics), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
					T72_ = (*m).diagnostics->Sup.len++;
					T73_ = NIM_NIL;
					T73_ = (*m).diagnostics->data[T72_]; (*m).diagnostics->data[T72_] = copyStringRC1((*msg));
					if (T73_) nimGCunrefNoCycle(T73_);
					(*m).diagnosticsEnabled = NIM_TRUE;
					i_4 += ((NI) 1);
				} LA71: ;
			}
		}
	}
	LA66_: ;
	{
		if (!(checkedBody == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA76_;
		result = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL);
		popSafePoint();
		(*c).matchedConcept = prevMatchedConcept;
		asgnRef((void**) (&(*(*(*colonenv_).typeClass2).sons->data[((NI) 0)]).sons->data[((NI) 0)]), prevCandidateType);
		closeScope__lookups_108(c);
		goto BeforeRet_;
	}
	LA76_: ;
	{
		tyTuple__7ojGQ7p3GL8CscnPtcFVrQ* p;
		NI i_5;
		NI L_3;
		NI T79_;
		p = (tyTuple__7ojGQ7p3GL8CscnPtcFVrQ*)0;
		i_5 = ((NI) 0);
		T79_ = (typeParams ? typeParams->Sup.len : 0);
		L_3 = T79_;
		{
			while (1) {
				if (!(i_5 < L_3)) goto LA81;
				p = (&typeParams->data[i_5]);
				put__sigmatch_120(m, (*p).Field1, (*(*p).Field0).typ);
				i_5 += ((NI) 1);
			} LA81: ;
		}
	}
	{
		if (!((*ff).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 53))) goto LA84_;
		result = generateTypeInstance__semtypinst_1086(c, (*m).bindings, (*(*(*colonenv_).typeClass2).sym).info, ff);
	}
	goto LA82_;
	LA84_: ;
	{
		result = exactReplica__ast_4039(ff);
	}
	LA82_: ;
	asgnRef((void**) (&(*result).n), checkedBody);
	popSafePoint();
	}
	else {
		popSafePoint();
	}
	{
		(*c).matchedConcept = prevMatchedConcept;
		asgnRef((void**) (&(*(*(*colonenv_).typeClass2).sons->data[((NI) 0)]).sons->data[((NI) 0)]), prevCandidateType);
		closeScope__lookups_108(c);
		if (TM__wjrA09aH0rT1R7zbrcCaROw_35.status != 0) nimLeaveFinally();
	}
	if (TM__wjrA09aH0rT1R7zbrcCaROw_35.status != 0) reraiseException();
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x) {
	addInt__stdZprivateZdigitsutils_167(result, ((NI64) (x)));
}
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_625)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = resizeString(result, (info.Field0 ? info.Field0->Sup.len : 0) + 0);
appendString(result, info.Field0);
	{
		if (!(((NI) 0) < info.Field1)) goto LA3_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_41));
		addInt__stdZprivateZdigitsutils_189((&result), info.Field1);
		{
			if (!(((NI) 0) < (NI)(info.Field2 + ((NI) 1)))) goto LA7_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_42));
			addInt__stdZprivateZdigitsutils_189((&result), (NI)(info.Field2 + ((NI) 1)));
		}
		LA7_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_43));
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA, typeRel__sigmatch_202)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* aOrig, tySet_tyEnum_TTypeRelFlag__nkWaH9aZ1YawZFP9aSlbYFMw flags) {
	tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA result;
	NIM_BOOL useTypeLoweringRuleInTypeClass;
	NIM_BOOL T9_;
	NIM_BOOL T10_;
	NIM_BOOL T11_;
	NIM_BOOL T12_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* aOrig_2;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T55_;
{	result = (tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA)0;
	result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
	{
		if (!((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 6))) goto LA3_;
		{
			if (!!((aOrig == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA7_;
			put__sigmatch_120(c, f, aOrig);
		}
		LA7_: ;
		result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
		goto BeforeRet_;
	}
	LA3_: ;
	T9_ = (NIM_BOOL)0;
	T10_ = (NIM_BOOL)0;
	T11_ = (NIM_BOOL)0;
	T12_ = (NIM_BOOL)0;
	T12_ = !(((*(*c).c).matchedConcept == ((tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw*) NIM_NIL)));
	if (!(T12_)) goto LA13_;
	T12_ = !((*c).isNoCall);
	LA13_: ;
	T11_ = T12_;
	if (!(T11_)) goto LA14_;
	T11_ = !(((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8)));
	LA14_: ;
	T10_ = T11_;
	if (!(T10_)) goto LA15_;
	T10_ = !((((*aOrig).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 29))&63U)))!=0));
	LA15_: ;
	T9_ = T10_;
	if (!(T9_)) goto LA16_;
	T9_ = !((((*aOrig).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 28))&63U)))!=0));
	LA16_: ;
	useTypeLoweringRuleInTypeClass = T9_;
	{
		if (!useTypeLoweringRuleInTypeClass) goto LA19_;
		aOrig_2 = skipTypes__ast_3723(aOrig, TM__wjrA09aH0rT1R7zbrcCaROw_14);
	}
	goto LA17_;
	LA19_: ;
	{
		aOrig_2 = aOrig;
	}
	LA17_: ;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* prev;
		if (!((*aOrig_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 55))) goto LA24_;
		{
			NI T28_;
			T28_ = ((*aOrig_2).sons ? (*aOrig_2).sons->Sup.len : 0);
			if (!(((NI) 1) < T28_)) goto LA29_;
			prev = lastSon__ast_3731(aOrig_2);
		}
		goto LA26_;
		LA29_: ;
		{
			prev = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL);
		}
		LA26_: ;
		{
			if (!!((prev == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA34_;
			result = typeRel__sigmatch_202(c, f, prev, flags);
			goto BeforeRet_;
		}
		goto LA32_;
		LA34_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* candidate;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T49_;
			candidate = f;
			switch ((*f).kind) {
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12):
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* prev_2;
				RootObj* T38_;
				T38_ = NIM_NIL;
				T38_ = idTableGet__astalgo_64((*c).bindings, &f->Sup);
				prev_2 = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) (T38_));
				{
					if (!!((prev_2 == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA41_;
					candidate = prev_2;
				}
				LA41_: ;
			}
			break;
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 61):
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* computedType;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T44_;
				T44_ = NIM_NIL;
				T44_ = tryResolvingStaticExpr__sigmatch_1227(c, (*f).n, NIM_FALSE);
				computedType = (*T44_).typ;
				switch ((*computedType).kind) {
				case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8):
				{
					candidate = base__types_63(computedType);
				}
				break;
				case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60):
				{
					candidate = computedType;
				}
				break;
				default:
				{
				}
				break;
				}
			}
			break;
			default:
			{
			}
			break;
			}
			T49_ = NIM_NIL;
			T49_ = base__types_63(aOrig_2);
			result = typeRel__sigmatch_202(c, T49_, candidate, flags);
			{
				NI T54_;
				if (!!((result == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0)))) goto LA52_;
				unsureAsgnRef((void**) (&(*c).inferredTypes), (tySequence__vKogasEnJSPhbQmA8r4Y9aA*) incrSeqV3((TGenericSeq*)((*c).inferredTypes), (&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_)));
				T54_ = (*c).inferredTypes->Sup.len++;
				asgnRef((void**) (&(*c).inferredTypes->data[T54_]), aOrig_2);
				add__concepts_23(aOrig_2, candidate);
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10);
			}
			LA52_: ;
			goto BeforeRet_;
		}
		LA32_: ;
	}
	LA24_: ;
	T55_ = NIM_NIL;
	T55_ = skipTypes__ast_3723(aOrig_2, TM__wjrA09aH0rT1R7zbrcCaROw_15);
	a = maybeSkipDistinct__sigmatch_1210((&(*c)), T55_, (*c).calleeSym);
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T60_;
		if (!((*aOrig_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 4) || (*aOrig_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46))) goto LA58_;
		T60_ = NIM_NIL;
		T60_ = lastSon__ast_3731(aOrig_2);
		result = typeRel__sigmatch_202(c, f, T60_, flags);
		goto BeforeRet_;
	}
	LA58_: ;
	{
		NIM_BOOL T63_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T65_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T68_;
		T63_ = (NIM_BOOL)0;
		T63_ = ((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11));
		if (!(T63_)) goto LA64_;
		T65_ = NIM_NIL;
		T65_ = skipTypes__ast_3723(f, TM__wjrA09aH0rT1R7zbrcCaROw_15);
		T63_ = !(((*T65_).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 9) && (*T65_).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12) || (*T65_).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 51) && (*T65_).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 54) || (*T65_).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 56) && (*T65_).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 59)));
		LA64_: ;
		if (!T63_) goto LA66_;
		T68_ = NIM_NIL;
		T68_ = lastSon__ast_3731(a);
		result = typeRel__sigmatch_202(c, f, T68_, flags);
		goto BeforeRet_;
	}
	LA66_: ;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T73_;
		if (!(((*a).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 10))&63U)))!=0)) goto LA71_;
		T73_ = NIM_NIL;
		T73_ = lastSon__ast_3731(a);
		result = typeRel__sigmatch_202(c, f, T73_, flags);
		goto BeforeRet_;
	}
	LA71_: ;
	switch ((*a).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 57):
	{
		(*c).typedescMatched = NIM_TRUE;
		result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA** branch;
			NI i;
			NI L;
			NI T76_;
			branch = (tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA**)0;
			i = ((NI) 0);
			T76_ = ((*a).sons ? (*a).sons->Sup.len : 0);
			L = T76_;
			{
				while (1) {
					tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA x;
					if (!(i < L)) goto LA78;
					branch = &(*a).sons->data[i];
					x = typeRel__sigmatch_202(c, f, (*branch), (flags | 1));
					{
						if (!(x == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0))) goto LA81_;
						result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
						goto BeforeRet_;
					}
					LA81_: ;
					{
						if (!(x < result)) goto LA85_;
						result = x;
					}
					LA85_: ;
					i += ((NI) 1);
				} LA78: ;
			}
		}
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 56):
	{
		(*c).typedescMatched = NIM_TRUE;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA** branch_2;
			NI i_2;
			NI L_2;
			NI T89_;
			branch_2 = (tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA**)0;
			i_2 = ((NI) 0);
			T89_ = ((*a).sons ? (*a).sons->Sup.len : 0);
			L_2 = T89_;
			{
				while (1) {
					tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA x_2;
					if (!(i_2 < L_2)) goto LA91;
					branch_2 = &(*a).sons->data[i_2];
					x_2 = typeRel__sigmatch_202(c, f, (*branch_2), (flags | 1));
					{
						if (!!((x_2 == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0)))) goto LA94_;
						{
							if (!(((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8) <= x_2)) goto LA98_;
							result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
						}
						goto LA96_;
						LA98_: ;
						{
							result = x_2;
						}
						LA96_: ;
						goto BeforeRet_;
					}
					LA94_: ;
					i_2 += ((NI) 1);
				} LA91: ;
			}
		}
		result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 64):
	{
		{
			if (!!(((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 64)))) goto LA104_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
			goto BeforeRet_;
		}
		LA104_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 58):
	{
		switch ((*f).kind) {
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 58):
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T108_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T109_;
			T108_ = NIM_NIL;
			T108_ = lastSon__ast_3731(a);
			T109_ = NIM_NIL;
			T109_ = lastSon__ast_3731(f);
			result = typeRel__sigmatch_202(c, T108_, T109_, flags);
			goto BeforeRet_;
		}
		break;
		default:
		{
			{
				if (!((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 59))) goto LA113_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
			}
			goto LA111_;
			LA113_: ;
			{
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
			}
			LA111_: ;
			goto BeforeRet_;
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 59):
	{
		{
			if (!((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 59))) goto LA119_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
			goto BeforeRet_;
		}
		goto LA117_;
		LA119_: ;
		{
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
			goto BeforeRet_;
		}
		LA117_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 52):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 53):
	{
		{
			NIM_BOOL T125_;
			tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA x_3;
			T125_ = (NIM_BOOL)0;
			T125_ = !(((*(*c).c).matchedConcept == ((tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw*) NIM_NIL)));
			if (!(T125_)) goto LA126_;
			T125_ = ((*(*(*c).c).matchedConcept).depth <= ((NI) 4));
			LA126_: ;
			if (!T125_) goto LA127_;
			(*(*(*c).c).matchedConcept).depth += ((NI) 1);
			x_3 = typeRel__sigmatch_202(c, a, f, (flags | 1));
			{
				if (!(((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8) <= x_3)) goto LA131_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
				goto BeforeRet_;
			}
			LA131_: ;
		}
		LA127_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	switch ((*f).kind) {
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14):
	{
		{
			NIM_BOOL T137_;
			T137_ = (NIM_BOOL)0;
			T137_ = ((*a).kind == (*f).kind);
			if (!(T137_)) goto LA138_;
			T137_ = sameEnumTypes__types_2152(f, a);
			LA138_: ;
			if (!T137_) goto LA139_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10);
		}
		goto LA135_;
		LA139_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T142_;
			NIM_BOOL T143_;
			T142_ = NIM_NIL;
			T142_ = skipTypes__ast_3723(a, TM__wjrA09aH0rT1R7zbrcCaROw_16);
			T143_ = (NIM_BOOL)0;
			T143_ = sameEnumTypes__types_2152(f, T142_);
			if (!T143_) goto LA144_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 3);
		}
		goto LA135_;
		LA144_: ;
		LA135_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2):
	{
		{
			if (!((*a).kind == (*f).kind)) goto LA149_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10);
		}
		goto LA147_;
		LA149_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T152_;
			T152_ = NIM_NIL;
			T152_ = skipTypes__ast_3723(a, TM__wjrA09aH0rT1R7zbrcCaROw_16);
			if (!((*T152_).kind == (*f).kind)) goto LA153_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 3);
		}
		goto LA147_;
		LA153_: ;
		LA147_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 20):
	{
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T165_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T166_;
			if (!((*a).kind == (*f).kind)) goto LA158_;
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T162_;
				T162_ = NIM_NIL;
				T162_ = base__types_63(f);
				if (!((*T162_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 0))) goto LA163_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
				goto BeforeRet_;
			}
			LA163_: ;
			T165_ = NIM_NIL;
			T165_ = base__types_63(f);
			T166_ = NIM_NIL;
			T166_ = base__types_63(a);
			result = typeRel__sigmatch_202(c, T165_, T166_, flags);
			{
				if (!!(((257 &((NU16)1<<((NU)(result)&15U)))!=0))) goto LA169_;
				{
					NI i_3;
					NI res;
					i_3 = (NI)0;
					res = ((NI) 0);
					{
						while (1) {
							if (!(res <= ((NI) 1))) goto LA173;
							i_3 = res;
							{
								if (!((*(*(*f).n)._kind_6.sons->data[i_3]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 62))) goto LA176_;
								asgnRef((void**) (&(*(*f).n)._kind_6.sons->data[i_3]), tryResolvingStaticExpr__sigmatch_1227(c, (*(*f).n)._kind_6.sons->data[i_3], NIM_FALSE));
							}
							LA176_: ;
							res += ((NI) 1);
						} LA173: ;
					}
				}
				result = typeRangeRel__sigmatch_981(f, a);
			}
			LA169_: ;
		}
		goto LA156_;
		LA158_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f_2;
			f_2 = skipTypes__ast_3723(f, TM__wjrA09aH0rT1R7zbrcCaROw_16);
			{
				NIM_BOOL T181_;
				NIM_BOOL T183_;
				T181_ = (NIM_BOOL)0;
				T181_ = ((*f_2).kind == (*a).kind);
				if (!(T181_)) goto LA182_;
				T183_ = (NIM_BOOL)0;
				T183_ = !(((*f_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14)));
				if (T183_) goto LA184_;
				T183_ = sameEnumTypes__types_2152(f_2, a);
				LA184_: ;
				T181_ = T183_;
				LA182_: ;
				if (!T181_) goto LA185_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 2);
			}
			goto LA179_;
			LA185_: ;
			{
				NIM_BOOL T188_;
				T188_ = (NIM_BOOL)0;
				T188_ = isConvertibleToRange__sigmatch_548(f_2, a);
				if (!T188_) goto LA189_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
			}
			goto LA179_;
			LA189_: ;
			LA179_: ;
		}
		LA156_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31):
	{
		result = handleRange__sigmatch_476(f, a, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 32), ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 34));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 32):
	{
		result = handleRange__sigmatch_476(f, a, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 32), ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 32));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 33):
	{
		result = handleRange__sigmatch_476(f, a, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 32), ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 33));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 34):
	{
		result = handleRange__sigmatch_476(f, a, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 32), ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 34));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35):
	{
		result = handleRange__sigmatch_476(f, a, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31), ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40):
	{
		result = handleRange__sigmatch_476(f, a, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 41), ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 43));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 41):
	{
		result = handleRange__sigmatch_476(f, a, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 41), ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 41));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 42):
	{
		result = handleRange__sigmatch_476(f, a, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 41), ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 42));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 43):
	{
		result = handleRange__sigmatch_476(f, a, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 41), ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 43));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44):
	{
		result = handleRange__sigmatch_476(f, a, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40), ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44));
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36):
	{
		result = handleFloatRange__sigmatch_596(f, a);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 37):
	{
		result = handleFloatRange__sigmatch_596(f, a);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 38):
	{
		result = handleFloatRange__sigmatch_596(f, a);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 39):
	{
		result = handleFloatRange__sigmatch_596(f, a);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47):
	{
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T210_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T211_;
			if (!((*aOrig_2).kind == (*f).kind)) goto LA208_;
			T210_ = NIM_NIL;
			T210_ = base__types_63(f);
			T211_ = NIM_NIL;
			T211_ = base__types_63(aOrig_2);
			result = typeRel__sigmatch_202(c, T210_, T211_, flags);
		}
		goto LA206_;
		LA208_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T213_;
			T213_ = NIM_NIL;
			T213_ = base__types_63(f);
			result = typeRel__sigmatch_202(c, T213_, aOrig_2, (flags | 2));
		}
		LA206_: ;
		{
			NIM_BOOL T216_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T218_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T219_;
			T216_ = (NIM_BOOL)0;
			T216_ = (result <= ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 4));
			if (!(T216_)) goto LA217_;
			T218_ = NIM_NIL;
			T218_ = lastSon__ast_3731(f);
			T219_ = NIM_NIL;
			T219_ = skipTypes__ast_3723(T218_, abstractInst__ast_356);
			T216_ = ((*T219_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22) || (*T219_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21) || (*T219_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*T219_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47) || (*T219_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45));
			LA217_: ;
			if (!T216_) goto LA220_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
		}
		LA220_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
	{
		switch ((*a).kind) {
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* fRange;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* aRange;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ff;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* aa;
			fRange = (*f).sons->data[((NI) 0)];
			aRange = (*a).sons->data[((NI) 0)];
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* prev_3;
				RootObj* T228_;
				if (!((*fRange).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12))) goto LA226_;
				T228_ = NIM_NIL;
				T228_ = idTableGet__astalgo_64((*c).bindings, (*((tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA**) (&(fRange)))));
				prev_3 = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) (T228_));
				{
					if (!(prev_3 == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA231_;
					put__sigmatch_120(c, fRange, (*a).sons->data[((NI) 0)]);
					fRange = a;
				}
				goto LA229_;
				LA231_: ;
				{
					fRange = prev_3;
				}
				LA229_: ;
			}
			LA226_: ;
			ff = skipTypes__ast_3723((*f).sons->data[((NI) 1)], TM__wjrA09aH0rT1R7zbrcCaROw_14);
			aa = (*a).sons->data[((NI) 1)];
			{
				NIM_BOOL T236_;
				T236_ = (NIM_BOOL)0;
				T236_ = !(((*(*f).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12)));
				if (!(T236_)) goto LA237_;
				T236_ = ((*aa).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 3));
				LA237_: ;
				if (!T236_) goto LA238_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
			}
			goto LA234_;
			LA238_: ;
			{
				result = typeRel__sigmatch_202(c, ff, aa, flags);
			}
			LA234_: ;
			{
				if (!(result < ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8))) goto LA243_;
				{
					NIM_BOOL T247_;
					NIM_BOOL T248_;
					NIM_BOOL T249_;
					T247_ = (NIM_BOOL)0;
					T248_ = (NIM_BOOL)0;
					T249_ = (NIM_BOOL)0;
					T249_ = NIM_FALSE;
					if (!(T249_)) goto LA250_;
					T249_ = !(((flags &((NU8)1<<((NU)(((tyEnum_TTypeRelFlag__nkWaH9aZ1YawZFP9aSlbYFMw) 1))&7U)))!=0));
					LA250_: ;
					T248_ = T249_;
					if (!(T248_)) goto LA251_;
					T248_ = ((*ff).kind == (*aa).kind);
					LA251_: ;
					T247_ = T248_;
					if (!(T247_)) goto LA252_;
					T247_ = isCovariantPtr__sigmatch_1405(c, ff, aa);
					LA252_: ;
					if (!T247_) goto LA253_;
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 3);
				}
				goto LA245_;
				LA253_: ;
				{
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
					goto BeforeRet_;
				}
				LA245_: ;
			}
			LA243_: ;
			{
				if (!(((*fRange).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 9))&63U)))!=0)) goto LA258_;
				result = inferStaticsInRange__sigmatch_1370(c, fRange, a);
				goto BeforeRet_;
			}
			goto LA256_;
			LA258_: ;
			{
				NIM_BOOL T261_;
				T261_ = (NIM_BOOL)0;
				T261_ = !(((*(*c).c).matchedConcept == ((tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw*) NIM_NIL)));
				if (!(T261_)) goto LA262_;
				T261_ = (((*aRange).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 9))&63U)))!=0);
				LA262_: ;
				if (!T261_) goto LA263_;
				result = inferStaticsInRange__sigmatch_1370(c, aRange, f);
				goto BeforeRet_;
			}
			goto LA256_;
			LA263_: ;
			{
				{
					tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T268_;
					tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T269_;
					NIM_BOOL T270_;
					T268_ = lengthOrd__types_1717((*(*(*c).c).graph).config, fRange);
					T269_ = lengthOrd__types_1717((*(*(*c).c).graph).config, aRange);
					T270_ = (NIM_BOOL)0;
					T270_ = eqeq___int495056_425(T268_, T269_);
					if (!!(T270_)) goto LA271_;
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
				}
				LA271_: ;
			}
			LA256_: ;
		}
		break;
		default:
		{
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 49):
	{
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T279_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T280_;
			if (!((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 49))) goto LA277_;
			T279_ = NIM_NIL;
			T279_ = base__types_63(f);
			T280_ = NIM_NIL;
			T280_ = base__types_63(a);
			result = typeRel__sigmatch_202(c, T279_, T280_, flags);
			{
				if (!(result < ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8))) goto LA283_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
			}
			LA283_: ;
		}
		goto LA275_;
		LA277_: ;
		{
		}
		LA275_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48):
	{
		{
			if (!((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48))) goto LA289_;
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T295_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T296_;
				if (!(((*a).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 0))&63U)))!=0)) goto LA293_;
				T295_ = NIM_NIL;
				T295_ = base__types_63(f);
				T296_ = NIM_NIL;
				T296_ = lastSon__ast_3731(a);
				result = typeRel__sigmatch_202(c, T295_, T296_, flags);
				goto BeforeRet_;
			}
			LA293_: ;
			{
				if (!((*(*f).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 7))) goto LA299_;
				goto BeforeRet_;
			}
			LA299_: ;
		}
		LA289_: ;
		switch ((*a).kind) {
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27):
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48):
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T302_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T303_;
			T302_ = NIM_NIL;
			T302_ = base__types_63(f);
			T303_ = NIM_NIL;
			T303_ = base__types_63(a);
			result = typeRel__sigmatch_202(c, T302_, T303_, flags);
			{
				if (!(result < ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8))) goto LA306_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
			}
			LA306_: ;
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ffX60gensym291_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* aaX60gensym291_;
			tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA baseRelX60gensym291_;
			{
				NIM_BOOL T311_;
				T311_ = (NIM_BOOL)0;
				T311_ = !(((*(*f).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12)));
				if (!(T311_)) goto LA312_;
				T311_ = ((*(*a).sons->data[((NI) 1)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 3));
				LA312_: ;
				if (!T311_) goto LA313_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 3);
				goto BeforeRet_;
			}
			LA313_: ;
			ffX60gensym291_ = base__types_63(f);
			aaX60gensym291_ = (*a).sons->data[((NI) 1)];
			baseRelX60gensym291_ = typeRel__sigmatch_202(c, ffX60gensym291_, aaX60gensym291_, flags);
			{
				if (!(((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8) <= baseRelX60gensym291_)) goto LA317_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
			}
			goto LA315_;
			LA317_: ;
			{
				NIM_BOOL T320_;
				NIM_BOOL T321_;
				NIM_BOOL T322_;
				T320_ = (NIM_BOOL)0;
				T321_ = (NIM_BOOL)0;
				T322_ = (NIM_BOOL)0;
				T322_ = NIM_FALSE;
				if (!(T322_)) goto LA323_;
				T322_ = !(((flags &((NU8)1<<((NU)(((tyEnum_TTypeRelFlag__nkWaH9aZ1YawZFP9aSlbYFMw) 1))&7U)))!=0));
				LA323_: ;
				T321_ = T322_;
				if (!(T321_)) goto LA324_;
				T321_ = ((*ffX60gensym291_).kind == (*aaX60gensym291_).kind);
				LA324_: ;
				T320_ = T321_;
				if (!(T320_)) goto LA325_;
				T320_ = isCovariantPtr__sigmatch_1405(c, ffX60gensym291_, aaX60gensym291_);
				LA325_: ;
				if (!T320_) goto LA326_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
			}
			goto LA315_;
			LA326_: ;
			LA315_: ;
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ffX60gensym298_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* aaX60gensym298_;
			tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA baseRelX60gensym298_;
			{
				NIM_BOOL T331_;
				T331_ = (NIM_BOOL)0;
				T331_ = !(((*(*f).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12)));
				if (!(T331_)) goto LA332_;
				T331_ = ((*(*a).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 3));
				LA332_: ;
				if (!T331_) goto LA333_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
				goto BeforeRet_;
			}
			LA333_: ;
			ffX60gensym298_ = base__types_63(f);
			aaX60gensym298_ = (*a).sons->data[((NI) 0)];
			baseRelX60gensym298_ = typeRel__sigmatch_202(c, ffX60gensym298_, aaX60gensym298_, flags);
			{
				if (!(((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8) <= baseRelX60gensym298_)) goto LA337_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
			}
			goto LA335_;
			LA337_: ;
			{
				NIM_BOOL T340_;
				NIM_BOOL T341_;
				NIM_BOOL T342_;
				T340_ = (NIM_BOOL)0;
				T341_ = (NIM_BOOL)0;
				T342_ = (NIM_BOOL)0;
				T342_ = NIM_FALSE;
				if (!(T342_)) goto LA343_;
				T342_ = !(((flags &((NU8)1<<((NU)(((tyEnum_TTypeRelFlag__nkWaH9aZ1YawZFP9aSlbYFMw) 1))&7U)))!=0));
				LA343_: ;
				T341_ = T342_;
				if (!(T341_)) goto LA344_;
				T341_ = ((*ffX60gensym298_).kind == (*aaX60gensym298_).kind);
				LA344_: ;
				T340_ = T341_;
				if (!(T340_)) goto LA345_;
				T340_ = isCovariantPtr__sigmatch_1405(c, ffX60gensym298_, aaX60gensym298_);
				LA345_: ;
				if (!T340_) goto LA346_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
			}
			goto LA335_;
			LA346_: ;
			LA335_: ;
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
		{
			{
				if (!((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27))) goto LA351_;
				{
					if (!((*(*f).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2))) goto LA355_;
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
				}
				goto LA353_;
				LA355_: ;
				{
					NIM_BOOL T358_;
					NIM_BOOL T359_;
					NI T361_;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T363_;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T364_;
					tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA T365_;
					T358_ = (NIM_BOOL)0;
					T359_ = (NIM_BOOL)0;
					T359_ = ((*(*f).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12));
					if (!(T359_)) goto LA360_;
					T361_ = (NI)0;
					T361_ = len__ast_3990(a);
					T359_ = (((NI) 0) < T361_);
					LA360_: ;
					T358_ = T359_;
					if (!(T358_)) goto LA362_;
					T363_ = NIM_NIL;
					T363_ = base__types_63(f);
					T364_ = NIM_NIL;
					T364_ = base__types_63(a);
					T365_ = (tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA)0;
					T365_ = typeRel__sigmatch_202(c, T363_, T364_, flags);
					T358_ = (((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8) <= T365_);
					LA362_: ;
					if (!T358_) goto LA366_;
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
				}
				goto LA353_;
				LA366_: ;
				LA353_: ;
			}
			LA351_: ;
		}
		break;
		default:
		{
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
	{
		switch ((*a).kind) {
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
		{
			{
				NIM_BOOL T373_;
				T373_ = (NIM_BOOL)0;
				T373_ = !(((*(*f).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12)));
				if (!(T373_)) goto LA374_;
				T373_ = ((*(*a).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 3));
				LA374_: ;
				if (!T373_) goto LA375_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 3);
			}
			goto LA371_;
			LA375_: ;
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ff_2;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* aa_2;
				ff_2 = (*f).sons->data[((NI) 0)];
				aa_2 = (*a).sons->data[((NI) 0)];
				result = typeRel__sigmatch_202(c, ff_2, aa_2, flags);
				{
					if (!(result < ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8))) goto LA380_;
					{
						NIM_BOOL T384_;
						NIM_BOOL T385_;
						NIM_BOOL T386_;
						T384_ = (NIM_BOOL)0;
						T385_ = (NIM_BOOL)0;
						T386_ = (NIM_BOOL)0;
						T386_ = NIM_FALSE;
						if (!(T386_)) goto LA387_;
						T386_ = !(((flags &((NU8)1<<((NU)(((tyEnum_TTypeRelFlag__nkWaH9aZ1YawZFP9aSlbYFMw) 1))&7U)))!=0));
						LA387_: ;
						T385_ = T386_;
						if (!(T385_)) goto LA388_;
						T385_ = ((*ff_2).kind == (*aa_2).kind);
						LA388_: ;
						T384_ = T385_;
						if (!(T384_)) goto LA389_;
						T384_ = isCovariantPtr__sigmatch_1405(c, ff_2, aa_2);
						LA389_: ;
						if (!T384_) goto LA390_;
						result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 3);
					}
					goto LA382_;
					LA390_: ;
					{
						result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
					}
					LA382_: ;
				}
				goto LA378_;
				LA380_: ;
				{
					NIM_BOOL T394_;
					T394_ = (NIM_BOOL)0;
					T394_ = (((*f).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 17))&63U)))!=0);
					if (!(T394_)) goto LA395_;
					T394_ = !((((*a).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 17))&63U)))!=0));
					LA395_: ;
					if (!T394_) goto LA396_;
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
				}
				goto LA378_;
				LA396_: ;
				LA378_: ;
			}
			LA371_: ;
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 5):
		{
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
		}
		break;
		default:
		{
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 15):
	{
		{
			NIM_BOOL T403_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* x_4;
			T403_ = (NIM_BOOL)0;
			T403_ = isOrdinalType__types_299(a, (((*(*(*(*c).c).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 47))&63U)))!=0));
			if (!T403_) goto LA404_;
			{
				if (!((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 15))) goto LA408_;
				x_4 = (*a).sons->data[((NI) 0)];
			}
			goto LA406_;
			LA408_: ;
			{
				x_4 = a;
			}
			LA406_: ;
			{
				if (!((*(*f).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 0))) goto LA413_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
			}
			goto LA411_;
			LA413_: ;
			{
				result = typeRel__sigmatch_202(c, (*f).sons->data[((NI) 0)], x_4, flags);
				{
					if (!(result < ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8))) goto LA418_;
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
				}
				LA418_: ;
			}
			LA411_: ;
		}
		goto LA401_;
		LA404_: ;
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12))) goto LA421_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
		}
		goto LA401_;
		LA421_: ;
		LA401_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 30):
	{
		result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 5):
	{
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45))) goto LA427_;
			a = skipTypes__ast_3723(a, TM__wjrA09aH0rT1R7zbrcCaROw_22);
		}
		LA427_: ;
		{
			if (!((*a).kind == (*f).kind)) goto LA431_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10);
		}
		LA431_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18):
	{
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18))) goto LA436_;
			result = recordRel__sigmatch_806(c, f, a);
		}
		LA436_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17):
	{
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17))) goto LA441_;
			{
				NIM_BOOL T445_;
				T445_ = (NIM_BOOL)0;
				T445_ = sameObjectTypes__types_2103(f, a);
				if (!T445_) goto LA446_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10);
			}
			goto LA443_;
			LA446_: ;
			{
				NI depth;
				depth = isObjectSubtype__sigmatch_656(c, a, f, ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
				{
					if (!(((NI) 0) < depth)) goto LA451_;
					(*c).inheritancePenalty += depth;
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 3);
				}
				LA451_: ;
			}
			LA443_: ;
		}
		LA441_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 13):
	{
		a = skipTypes__ast_3723(a, TM__wjrA09aH0rT1R7zbrcCaROw_23);
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 13))) goto LA456_;
			{
				NIM_BOOL T460_;
				T460_ = (NIM_BOOL)0;
				T460_ = sameDistinctTypes__types_2148(f, a);
				if (!T460_) goto LA461_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10);
			}
			goto LA458_;
			LA461_: ;
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T466_;
				if (!(*c).coerceDistincts) goto LA464_;
				T466_ = NIM_NIL;
				T466_ = base__types_63(f);
				result = typeRel__sigmatch_202(c, T466_, a, flags);
			}
			goto LA458_;
			LA464_: ;
			LA458_: ;
		}
		goto LA454_;
		LA456_: ;
		{
			NIM_BOOL T468_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T470_;
			T468_ = (NIM_BOOL)0;
			T468_ = ((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 5));
			if (!(T468_)) goto LA469_;
			T470_ = NIM_NIL;
			T470_ = base__types_63(f);
			T468_ = ((*T470_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 26) || (*T470_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29) || (*T470_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22) || (*T470_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21) || (*T470_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25) || (*T470_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 50));
			LA469_: ;
			if (!T468_) goto LA471_;
			result = allowsNil__sigmatch_875(f);
		}
		goto LA454_;
		LA471_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T476_;
			if (!(*c).coerceDistincts) goto LA474_;
			T476_ = NIM_NIL;
			T476_ = base__types_63(f);
			result = typeRel__sigmatch_202(c, T476_, a, flags);
		}
		goto LA454_;
		LA474_: ;
		LA454_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 19):
	{
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 19))) goto LA480_;
			{
				NIM_BOOL T484_;
				T484_ = (NIM_BOOL)0;
				T484_ = !(((*(*f).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12)));
				if (!(T484_)) goto LA485_;
				T484_ = ((*(*a).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 3));
				LA485_: ;
				if (!T484_) goto LA486_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 3);
			}
			goto LA482_;
			LA486_: ;
			{
				result = typeRel__sigmatch_202(c, (*f).sons->data[((NI) 0)], (*a).sons->data[((NI) 0)], flags);
				{
					if (!(result < ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8))) goto LA491_;
					{
						if (!(result <= ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1))) goto LA495_;
						result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
					}
					goto LA493_;
					LA495_: ;
					{
						if (!!((((*a).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 43))&63U)))!=0))) goto LA498_;
						result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
					}
					goto LA493_;
					LA498_: ;
					LA493_: ;
				}
				LA491_: ;
			}
			LA482_: ;
		}
		LA480_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22):
	{
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45))) goto LA503_;
			a = skipTypes__ast_3723(a, TM__wjrA09aH0rT1R7zbrcCaROw_22);
		}
		LA503_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T524_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T525_;
			if (!((*a).kind == (*f).kind)) goto LA507_;
			{
				NI T511_;
				NI T512_;
				T511_ = (NI)0;
				T511_ = len__ast_3990(a);
				T512_ = (NI)0;
				T512_ = len__ast_3990(f);
				if (!(T511_ < T512_)) goto LA513_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
				goto BeforeRet_;
			}
			LA513_: ;
			{
				NI i_4;
				NI colontmp_;
				NI T516_;
				NI i_5;
				i_4 = (NI)0;
				colontmp_ = (NI)0;
				T516_ = (NI)0;
				T516_ = len__ast_3990(f);
				colontmp_ = (NI)(T516_ - ((NI) 1));
				i_5 = ((NI) 0);
				{
					while (1) {
						if (!(i_5 < colontmp_)) goto LA518;
						i_4 = i_5;
						{
							tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA T521_;
							T521_ = (tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA)0;
							T521_ = typeRel__sigmatch_202(c, (*f).sons->data[i_4], (*a).sons->data[i_4], flags);
							if (!(T521_ == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0))) goto LA522_;
							result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
							goto BeforeRet_;
						}
						LA522_: ;
						i_5 += ((NI) 1);
					} LA518: ;
				}
			}
			T524_ = NIM_NIL;
			T524_ = lastSon__ast_3731(f);
			T525_ = NIM_NIL;
			T525_ = lastSon__ast_3731(a);
			result = typeRel__sigmatch_202(c, T524_, T525_, (flags | 2));
			{
				NIM_BOOL T528_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T530_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T531_;
				T528_ = (NIM_BOOL)0;
				T528_ = (result <= ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 4));
				if (!(T528_)) goto LA529_;
				T530_ = NIM_NIL;
				T530_ = lastSon__ast_3731(f);
				T531_ = NIM_NIL;
				T531_ = skipTypes__ast_3723(T530_, abstractInst__ast_356);
				T528_ = ((*T531_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22) || (*T531_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21) || (*T531_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*T531_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47) || (*T531_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45));
				LA529_: ;
				if (!T528_) goto LA532_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
			}
			LA532_: ;
			{
				if (!(result <= ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 2))) goto LA536_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
			}
			goto LA534_;
			LA536_: ;
			{
				NIM_BOOL T539_;
				T539_ = (NIM_BOOL)0;
				T539_ = (((*f).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 17))&63U)))!=0);
				if (!(T539_)) goto LA540_;
				T539_ = !((((*a).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 17))&63U)))!=0));
				LA540_: ;
				if (!T539_) goto LA541_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
			}
			goto LA534_;
			LA541_: ;
			LA534_: ;
		}
		goto LA505_;
		LA507_: ;
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 5))) goto LA544_;
			result = allowsNil__sigmatch_875(f);
		}
		goto LA505_;
		LA544_: ;
		{
		}
		LA505_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25):
	{
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45))) goto LA550_;
			a = skipTypes__ast_3723(a, TM__wjrA09aH0rT1R7zbrcCaROw_22);
		}
		LA550_: ;
		result = procTypeRel__sigmatch_927(c, f, a);
		{
			NIM_BOOL T554_;
			NIM_BOOL T555_;
			T554_ = (NIM_BOOL)0;
			T555_ = (NIM_BOOL)0;
			T555_ = !((result == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0)));
			if (!(T555_)) goto LA556_;
			T555_ = (((*f).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 17))&63U)))!=0);
			LA556_: ;
			T554_ = T555_;
			if (!(T554_)) goto LA557_;
			T554_ = !((((*a).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 17))&63U)))!=0));
			LA557_: ;
			if (!T554_) goto LA558_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
		}
		LA558_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45):
	{
		switch ((*a).kind) {
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45):
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T562_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T563_;
			T562_ = NIM_NIL;
			T562_ = lastSon__ast_3731(f);
			T563_ = NIM_NIL;
			T563_ = lastSon__ast_3731(a);
			result = typeRel__sigmatch_202(c, T562_, T563_, flags);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 5):
		{
			result = allowsNil__sigmatch_875(f);
		}
		break;
		default:
		{
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 26):
	{
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45))) goto LA569_;
			a = skipTypes__ast_3723(a, TM__wjrA09aH0rT1R7zbrcCaROw_22);
		}
		LA569_: ;
		switch ((*a).kind) {
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 26):
		{
			{
				NIM_BOOL T574_;
				T574_ = (NIM_BOOL)0;
				T574_ = (((*f).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 17))&63U)))!=0);
				if (!(T574_)) goto LA575_;
				T574_ = !((((*a).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 17))&63U)))!=0));
				LA575_: ;
				if (!T574_) goto LA576_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
			}
			goto LA572_;
			LA576_: ;
			{
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10);
			}
			LA572_: ;
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 5):
		{
			result = allowsNil__sigmatch_875(f);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25):
		{
			{
				if (!!(((*a).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9)))) goto LA583_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
			}
			LA583_: ;
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21):
		{
			{
				NI T588_;
				T588_ = (NI)0;
				T588_ = len__ast_3990(a);
				if (!(T588_ == ((NI) 1))) goto LA589_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
			}
			LA589_: ;
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29):
		{
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
		}
		break;
		default:
		{
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
	{
		switch ((*a).kind) {
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
		{
			{
				NIM_BOOL T597_;
				T597_ = (NIM_BOOL)0;
				T597_ = (((*f).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 17))&63U)))!=0);
				if (!(T597_)) goto LA598_;
				T597_ = !((((*a).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 17))&63U)))!=0));
				LA598_: ;
				if (!T597_) goto LA599_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
			}
			goto LA595_;
			LA599_: ;
			{
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10);
			}
			LA595_: ;
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 5):
		{
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
		}
		break;
		default:
		{
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29):
	{
		switch ((*a).kind) {
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29):
		{
			{
				NIM_BOOL T608_;
				T608_ = (NIM_BOOL)0;
				T608_ = (((*f).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 17))&63U)))!=0);
				if (!(T608_)) goto LA609_;
				T608_ = !((((*a).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 17))&63U)))!=0));
				LA609_: ;
				if (!T608_) goto LA610_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
			}
			goto LA606_;
			LA610_: ;
			{
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10);
			}
			LA606_: ;
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 5):
		{
			result = allowsNil__sigmatch_875(f);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
		{
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21):
		{
			{
				NI T618_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* pointsTo;
				T618_ = (NI)0;
				T618_ = len__ast_3990(a);
				if (!(T618_ == ((NI) 1))) goto LA619_;
				pointsTo = skipTypes__ast_3723((*a).sons->data[((NI) 0)], TM__wjrA09aH0rT1R7zbrcCaROw_24);
				{
					if (!((*pointsTo).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2))) goto LA623_;
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
				}
				goto LA621_;
				LA623_: ;
				{
					NIM_BOOL T626_;
					T626_ = (NIM_BOOL)0;
					T626_ = ((*pointsTo).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 49));
					if (!(T626_)) goto LA627_;
					T626_ = ((*(*pointsTo).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2));
					LA627_: ;
					if (!T626_) goto LA628_;
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
				}
				goto LA621_;
				LA628_: ;
				{
					NIM_BOOL T631_;
					NIM_BOOL T632_;
					NIM_BOOL T633_;
					tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T635_;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T637_;
					T631_ = (NIM_BOOL)0;
					T632_ = (NIM_BOOL)0;
					T633_ = (NIM_BOOL)0;
					T633_ = ((*pointsTo).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16));
					if (!(T633_)) goto LA634_;
					T635_ = firstOrd__types_1406(((tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) NIM_NIL), (*pointsTo).sons->data[((NI) 0)]);
					T633_ = eqeq___int495056_952(T635_, IL64(0));
					LA634_: ;
					T632_ = T633_;
					if (!(T632_)) goto LA636_;
					T637_ = NIM_NIL;
					T637_ = skipTypes__ast_3723((*pointsTo).sons->data[((NI) 0)], TM__wjrA09aH0rT1R7zbrcCaROw_16);
					T632_ = ((*T637_).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) && (*T637_).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35));
					LA636_: ;
					T631_ = T632_;
					if (!(T631_)) goto LA638_;
					T631_ = ((*(*pointsTo).sons->data[((NI) 1)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2));
					LA638_: ;
					if (!T631_) goto LA639_;
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1);
				}
				goto LA621_;
				LA639_: ;
				LA621_: ;
			}
			LA619_: ;
		}
		break;
		default:
		{
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 3):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 63):
	{
		{
			if (!((*a).kind == (*f).kind)) goto LA645_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10);
		}
		LA645_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 4):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T648_;
		T648_ = NIM_NIL;
		T648_ = lastSon__ast_3731(f);
		result = typeRel__sigmatch_202(c, T648_, a, flags);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 64):
	{
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 64))) goto LA652_;
			{
				NI T656_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T659_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T660_;
				T656_ = (NI)0;
				T656_ = len__ast_3990(f);
				if (!(T656_ == ((NI) 1))) goto LA657_;
				T659_ = NIM_NIL;
				T659_ = lastSon__ast_3731(f);
				T660_ = NIM_NIL;
				T660_ = lastSon__ast_3731(a);
				result = typeRel__sigmatch_202(c, T659_, T660_, flags);
			}
			goto LA654_;
			LA657_: ;
			{
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
			}
			LA654_: ;
		}
		goto LA650_;
		LA652_: ;
		{
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
		}
		LA650_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* prev_4;
		RootObj* T664_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* origF;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f_3;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* roota;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* rootf;
		T664_ = NIM_NIL;
		T664_ = idTableGet__astalgo_64((*c).bindings, &f->Sup);
		prev_4 = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) (T664_));
		origF = f;
		{
			if (!(prev_4 == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA667_;
			f_3 = f;
		}
		goto LA665_;
		LA667_: ;
		{
			f_3 = prev_4;
		}
		LA665_: ;
		roota = skipGenericAlias__types_2275(a);
		rootf = skipGenericAlias__types_2275(f_3);
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11))) goto LA672_;
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T676_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T677_;
				tySet_tyEnum_TTypeRelFlag__nkWaH9aZ1YawZFP9aSlbYFMw nextFlags;
				NIM_BOOL hasCovariance;
				T676_ = NIM_NIL;
				T676_ = base__types_63(roota);
				T677_ = NIM_NIL;
				T677_ = base__types_63(rootf);
				if (!(T676_ == T677_)) goto LA678_;
				nextFlags = (flags | 2);
				hasCovariance = NIM_FALSE;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10);
				{
					NI i_6;
					NI colontmp__2;
					NI T681_;
					NI i_7;
					i_6 = (NI)0;
					colontmp__2 = (NI)0;
					T681_ = (NI)0;
					T681_ = len__ast_3990(rootf);
					colontmp__2 = (NI)(T681_ - ((NI) 1));
					i_7 = ((NI) 1);
					{
						while (1) {
							if (!(i_7 < colontmp__2)) goto LA683;
							i_6 = i_7;
							{
								tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ff_3;
								tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* aa_3;
								tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA res_2;
								ff_3 = (*rootf).sons->data[i_6];
								aa_3 = (*roota).sons->data[i_6];
								res_2 = typeRel__sigmatch_202(c, ff_3, aa_3, nextFlags);
								{
									NIM_BOOL T687_;
									T687_ = (NIM_BOOL)0;
									T687_ = !((res_2 == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0)));
									if (!(T687_)) goto LA688_;
									T687_ = !((res_2 == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10)));
									LA688_: ;
									if (!T687_) goto LA689_;
									result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
								}
								LA689_: ;
								{
									if (!!(((1280 &((NU16)1<<((NU)(res_2)&15U)))!=0))) goto LA693_;
									{
										NIM_BOOL T697_;
										tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw paramFlags;
										tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T701_;
										T697_ = (NIM_BOOL)0;
										T697_ = !(((flags &((NU8)1<<((NU)(((tyEnum_TTypeRelFlag__nkWaH9aZ1YawZFP9aSlbYFMw) 1))&7U)))!=0));
										if (!(T697_)) goto LA698_;
										T697_ = ((*ff_3).kind == (*aa_3).kind);
										LA698_: ;
										if (!T697_) goto LA699_;
										T701_ = NIM_NIL;
										T701_ = base__types_63(rootf);
										paramFlags = (*(*T701_).sons->data[(NI)(i_6 - ((NI) 1))]).flags;
										{
											if (!((paramFlags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 35))&63U)))!=0)) goto LA704_;
											{
												if (!((paramFlags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 36))&63U)))!=0)) goto LA708_;
												hasCovariance = isCovariantPtr__sigmatch_1405(c, ff_3, aa_3);
											}
											goto LA706_;
											LA708_: ;
											{
												NIM_BOOL T711_;
												T711_ = (NIM_BOOL)0;
												T711_ = !(((*ff_3).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22) || (*ff_3).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21)));
												if (!(T711_)) goto LA712_;
												T711_ = (res_2 == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 3));
												LA712_: ;
												hasCovariance = T711_;
											}
											LA706_: ;
										}
										goto LA702_;
										LA704_: ;
										{
											NIM_BOOL T714_;
											tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA T716_;
											T714_ = (NIM_BOOL)0;
											T714_ = ((paramFlags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 37))&63U)))!=0);
											if (!(T714_)) goto LA715_;
											T716_ = (tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA)0;
											T716_ = typeRel__sigmatch_202(c, aa_3, ff_3, flags);
											T714_ = (T716_ == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 3));
											LA715_: ;
											hasCovariance = T714_;
										}
										LA702_: ;
										{
											if (!hasCovariance) goto LA719_;
											goto LA684;
										}
										LA719_: ;
									}
									LA699_: ;
									result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
									goto BeforeRet_;
								}
								LA693_: ;
							} LA684: ;
							i_7 += ((NI) 1);
						} LA683: ;
					}
				}
				{
					if (!(prev_4 == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA723_;
					put__sigmatch_120(c, f_3, a);
				}
				LA723_: ;
			}
			goto LA674_;
			LA678_: ;
			{
				tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg fKind;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T726_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* aAsObject;
				T726_ = NIM_NIL;
				T726_ = lastSon__ast_3731(rootf);
				fKind = (*T726_).kind;
				{
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T731_;
					if (!(fKind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 56) || fKind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 57))) goto LA729_;
					T731_ = NIM_NIL;
					T731_ = lastSon__ast_3731(f_3);
					result = typeRel__sigmatch_202(c, T731_, a, flags);
					{
						if (!!((result == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0)))) goto LA734_;
						put__sigmatch_120(c, f_3, a);
					}
					LA734_: ;
					goto BeforeRet_;
				}
				LA729_: ;
				aAsObject = lastSon__ast_3731(roota);
				{
					if (!(fKind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22) || fKind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21))) goto LA738_;
					{
						if (!((*aAsObject).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17))) goto LA742_;
						result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
						goto BeforeRet_;
					}
					goto LA740_;
					LA742_: ;
					{
						if (!((*aAsObject).kind == fKind)) goto LA745_;
						aAsObject = base__types_63(aAsObject);
					}
					goto LA740_;
					LA745_: ;
					LA740_: ;
				}
				LA738_: ;
				{
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* baseType;
					if (!((*aAsObject).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17))) goto LA749_;
					baseType = base__types_63(aAsObject);
					{
						tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA ret;
						if (!!((baseType == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA753_;
						(*c).inheritancePenalty += ((NI) 1);
						ret = typeRel__sigmatch_202(c, f_3, baseType, flags);
						{
							if (!((1280 &((NU16)1<<((NU)(ret)&15U)))!=0)) goto LA757_;
							result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 3);
						}
						goto LA755_;
						LA757_: ;
						{
							result = ret;
						}
						LA755_: ;
						goto BeforeRet_;
					}
					LA753_: ;
				}
				LA749_: ;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
			}
			LA674_: ;
		}
		goto LA670_;
		LA672_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T761_;
			T761_ = NIM_NIL;
			T761_ = lastSon__ast_3731(origF);
			result = typeRel__sigmatch_202(c, T761_, a, flags);
			{
				NIM_BOOL T764_;
				T764_ = (NIM_BOOL)0;
				T764_ = !((result == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0)));
				if (!(T764_)) goto LA765_;
				T764_ = !(((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 5)));
				LA765_: ;
				if (!T764_) goto LA766_;
				put__sigmatch_120(c, f_3, a);
			}
			LA766_: ;
		}
		LA670_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 10):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* prevX60gensym373_;
		RootObj* T769_;
		T769_ = NIM_NIL;
		T769_ = idTableGet__astalgo_64((*c).bindings, &f->Sup);
		prevX60gensym373_ = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) (T769_));
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ff_4;
			if (!(prevX60gensym373_ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA772_;
			{
				NIM_BOOL T776_;
				NIM_BOOL T778_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T780_;
				T776_ = (NIM_BOOL)0;
				T776_ = (a == f);
				if (T776_) goto LA777_;
				T778_ = (NIM_BOOL)0;
				T778_ = ((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11));
				if (!(T778_)) goto LA779_;
				T780_ = NIM_NIL;
				T780_ = skipGenericAlias__types_2275(a);
				T778_ = ((*T780_).sons->data[((NI) 0)] == f);
				LA779_: ;
				T776_ = T778_;
				LA777_: ;
				if (!T776_) goto LA781_;
				{
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* boundX60gensym375_;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T787_;
					if (!!(((flags &((NU8)1<<((NU)(((tyEnum_TTypeRelFlag__nkWaH9aZ1YawZFP9aSlbYFMw) 0))&7U)))!=0))) goto LA785_;
					T787_ = NIM_NIL;
					T787_ = skipTypes__ast_3723(aOrig_2, TM__wjrA09aH0rT1R7zbrcCaROw_16);
					boundX60gensym375_ = skipIntLit__magicsys_124(T787_, (*(*c).c).Sup.idgen);
					put__sigmatch_120(c, f, boundX60gensym375_);
				}
				LA785_: ;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
				goto BeforeRet_;
			}
			LA781_: ;
			ff_4 = lastSon__ast_3731(f);
			{
				if (!!((ff_4 == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA790_;
				result = typeRel__sigmatch_202(c, ff_4, a, flags);
			}
			LA790_: ;
		}
		goto LA770_;
		LA772_: ;
		{
			result = typeRel__sigmatch_202(c, prevX60gensym373_, a, flags);
			goto BeforeRet_;
		}
		LA770_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 9):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* x_5;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* concpt;
		NIM_BOOL preventHack;
		x_5 = skipGenericAlias__types_2275(a);
		concpt = skipTypes__ast_3723((*f).sons->data[((NI) 0)], TM__wjrA09aH0rT1R7zbrcCaROw_25);
		preventHack = ((*concpt).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 62));
		{
			NIM_BOOL T796_;
			T796_ = (NIM_BOOL)0;
			T796_ = ((*x_5).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45));
			if (!(T796_)) goto LA797_;
			T796_ = !(((*(*f).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45)));
			LA797_: ;
			if (!T796_) goto LA798_;
			preventHack = NIM_TRUE;
			x_5 = lastSon__ast_3731(x_5);
		}
		LA798_: ;
		{
			NIM_BOOL T802_;
			NIM_BOOL T803_;
			NIM_BOOL T804_;
			NIM_BOOL T805_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* inst;
			T802_ = (NIM_BOOL)0;
			T803_ = (NIM_BOOL)0;
			T804_ = (NIM_BOOL)0;
			T805_ = (NIM_BOOL)0;
			T805_ = ((*x_5).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11) || (*x_5).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16));
			if (!(T805_)) goto LA806_;
			T805_ = !(((*c).calleeSym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
			LA806_: ;
			T804_ = T805_;
			if (!(T804_)) goto LA807_;
			T804_ = ((12288 &((NU32)1<<((NU)((*(*c).calleeSym).kind)&31U)))!=0);
			LA807_: ;
			T803_ = T804_;
			if (!(T803_)) goto LA808_;
			T803_ = !(((*c).call == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
			LA808_: ;
			T802_ = T803_;
			if (!(T802_)) goto LA809_;
			T802_ = !(preventHack);
			LA809_: ;
			if (!T802_) goto LA810_;
			inst = prepareMetatypeForSigmatch__semtypinst_1100((*c).c, (*c).bindings, (*(*c).call).info, f);
			result = typeRel__sigmatch_202(c, inst, a, flags);
			goto BeforeRet_;
		}
		LA810_: ;
		{
			if (!((*x_5).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 9))) goto LA814_;
			{
				if (!((*f).sons->data[((NI) 0)] == (*x_5).sons->data[((NI) 0)])) goto LA818_;
				{
					NI i_8;
					NI colontmp__3;
					NI i_9;
					i_8 = (NI)0;
					colontmp__3 = (NI)0;
					colontmp__3 = len__ast_3990(f);
					i_9 = ((NI) 1);
					{
						while (1) {
							tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA tr;
							if (!(i_9 < colontmp__3)) goto LA822;
							i_8 = i_9;
							tr = typeRel__sigmatch_202(c, (*f).sons->data[i_8], (*x_5).sons->data[i_8], flags);
							{
								if (!(tr <= ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 3))) goto LA825_;
								goto BeforeRet_;
							}
							LA825_: ;
							i_9 += ((NI) 1);
						} LA822: ;
					}
				}
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
			}
			LA818_: ;
		}
		goto LA812_;
		LA814_: ;
		{
			NIM_BOOL T828_;
			NIM_BOOL T829_;
			NI T832_;
			NI T833_;
			T828_ = (NIM_BOOL)0;
			T829_ = (NIM_BOOL)0;
			T829_ = ((*x_5).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11));
			if (!(T829_)) goto LA830_;
			T829_ = ((*f).sons->data[((NI) 0)] == (*x_5).sons->data[((NI) 0)]);
			LA830_: ;
			T828_ = T829_;
			if (!(T828_)) goto LA831_;
			T832_ = (NI)0;
			T832_ = len__ast_3990(x_5);
			T833_ = (NI)0;
			T833_ = len__ast_3990(f);
			T828_ = ((NI)(T832_ - ((NI) 1)) == T833_);
			LA831_: ;
			if (!T828_) goto LA834_;
			{
				NI i_10;
				NI colontmp__4;
				NI i_11;
				i_10 = (NI)0;
				colontmp__4 = (NI)0;
				colontmp__4 = len__ast_3990(f);
				i_11 = ((NI) 1);
				{
					while (1) {
						if (!(i_11 < colontmp__4)) goto LA838;
						i_10 = i_11;
						{
							if (!((*(*x_5).sons->data[i_10]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12))) goto LA841_;
							internalErrorImpl__msgs_1441((*(*(*c).c).graph).config, unknownLineInfo__lineinfos_284, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_26), TM__wjrA09aH0rT1R7zbrcCaROw_27);
						}
						goto LA839_;
						LA841_: ;
						{
							tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA T844_;
							T844_ = (tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA)0;
							T844_ = typeRel__sigmatch_202(c, (*f).sons->data[i_10], (*x_5).sons->data[i_10], flags);
							if (!(T844_ <= ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 3))) goto LA845_;
							{
								if (!!(((*(*f).sons->data[i_10]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8)))) goto LA849_;
								goto BeforeRet_;
							}
							LA849_: ;
						}
						goto LA839_;
						LA845_: ;
						LA839_: ;
						i_11 += ((NI) 1);
					} LA838: ;
				}
			}
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
		}
		goto LA812_;
		LA834_: ;
		{
			NIM_BOOL T852_;
			T852_ = (NIM_BOOL)0;
			T852_ = ((*x_5).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11));
			if (!(T852_)) goto LA853_;
			T852_ = ((*concpt).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 62));
			LA853_: ;
			if (!T852_) goto LA854_;
			{
				NIM_BOOL T858_;
				T858_ = (NIM_BOOL)0;
				T858_ = conceptMatch__concepts_538((*c).c, concpt, x_5, (&(*c).bindings), f);
				if (!T858_) goto LA859_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
			}
			goto LA856_;
			LA859_: ;
			{
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
			}
			LA856_: ;
		}
		goto LA812_;
		LA854_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* genericBody;
			tyEnum_SkippedPtr__ZfkN1Zg3tYB8pQTEnxqNcg askip;
			tyEnum_SkippedPtr__ZfkN1Zg3tYB8pQTEnxqNcg fskip;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* aobj;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* fobj;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T863_;
			NI depth_2;
			genericBody = (*f).sons->data[((NI) 0)];
			askip = ((tyEnum_SkippedPtr__ZfkN1Zg3tYB8pQTEnxqNcg) 0);
			fskip = ((tyEnum_SkippedPtr__ZfkN1Zg3tYB8pQTEnxqNcg) 0);
			aobj = skipToObject__sigmatch_703(x_5, (&askip));
			T863_ = NIM_NIL;
			T863_ = lastSon__ast_3731(genericBody);
			fobj = skipToObject__sigmatch_703(T863_, (&fskip));
			depth_2 = ((NI) -1);
			{
				NIM_BOOL T866_;
				NIM_BOOL T867_;
				T866_ = (NIM_BOOL)0;
				T867_ = (NIM_BOOL)0;
				T867_ = !((fobj == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
				if (!(T867_)) goto LA868_;
				T867_ = !((aobj == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
				LA868_: ;
				T866_ = T867_;
				if (!(T866_)) goto LA869_;
				T866_ = (askip == fskip);
				LA869_: ;
				if (!T866_) goto LA870_;
				depth_2 = isObjectSubtype__sigmatch_656(c, aobj, fobj, f);
			}
			LA870_: ;
			result = typeRel__sigmatch_202(c, genericBody, x_5, flags);
			{
				if (!!((result == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0)))) goto LA874_;
				{
					NI i_12;
					NI colontmp__5;
					NI i_13;
					i_12 = (NI)0;
					colontmp__5 = (NI)0;
					colontmp__5 = len__ast_3990(f);
					i_13 = ((NI) 1);
					{
						while (1) {
							tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* x_6;
							RootObj* T879_;
							if (!(i_13 < colontmp__5)) goto LA878;
							i_12 = i_13;
							T879_ = NIM_NIL;
							T879_ = idTableGet__astalgo_64((*c).bindings, (*((tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA**) (&((*genericBody).sons->data[(NI)(i_12 - ((NI) 1))])))));
							x_6 = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) (T879_));
							{
								if (!(x_6 == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA882_;
							}
							goto LA880_;
							LA882_: ;
							{
								if (!((*x_6).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 9) || (*x_6).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12))) goto LA885_;
								internalErrorImpl__msgs_1441((*(*(*c).c).graph).config, unknownLineInfo__lineinfos_284, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_26), TM__wjrA09aH0rT1R7zbrcCaROw_28);
							}
							goto LA880_;
							LA885_: ;
							{
								tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* key;
								tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* old;
								RootObj* T888_;
								key = (*f).sons->data[i_12];
								T888_ = NIM_NIL;
								T888_ = idTableGet__astalgo_64((*c).bindings, &key->Sup);
								old = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) (T888_));
								{
									if (!(old == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA891_;
									put__sigmatch_120(c, key, x_6);
								}
								goto LA889_;
								LA891_: ;
								{
									tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA T894_;
									T894_ = (tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA)0;
									T894_ = typeRel__sigmatch_202(c, old, x_6, (flags | 1));
									if (!(T894_ == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0))) goto LA895_;
									result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
									goto BeforeRet_;
								}
								goto LA889_;
								LA895_: ;
								LA889_: ;
							}
							LA880_: ;
							i_13 += ((NI) 1);
						} LA878: ;
					}
				}
			}
			LA874_: ;
			{
				NIM_BOOL genericSubtype;
				if (!(result == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0))) goto LA899_;
				genericSubtype = isGenericSubtype__sigmatch_744(c, x_5, f, (&depth_2), f);
				{
					NIM_BOOL T903_;
					NIM_BOOL T904_;
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym409_;
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym410_;
					T903_ = (NIM_BOOL)0;
					T904_ = (NIM_BOOL)0;
					T904_ = genericSubtype;
					if (!(T904_)) goto LA905_;
					xX60gensym409_ = (*aobj).sym;
					xX60gensym410_ = (*fobj).sym;
					T904_ = !(((NI)((NI)((NU32)(((NI) ((*xX60gensym409_).Sup.itemId.module))) << (NU32)(((NI) 20))) + ((NI) ((*xX60gensym409_).Sup.itemId.item))) == (NI)((NI)((NU32)(((NI) ((*xX60gensym410_).Sup.itemId.module))) << (NU32)(((NI) 20))) + ((NI) ((*xX60gensym410_).Sup.itemId.item)))));
					LA905_: ;
					T903_ = !(T904_);
					if (!(T903_)) goto LA906_;
					T903_ = !(((*aOrig_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 10)));
					LA906_: ;
					if (!T903_) goto LA907_;
					depth_2 = ((NI) -1);
				}
				LA907_: ;
			}
			LA899_: ;
			{
				if (!(((NI) 0) <= depth_2)) goto LA911_;
				(*c).inheritancePenalty += depth_2;
				{
					if (!(depth_2 == ((NI) 0))) goto LA915_;
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
				}
				goto LA913_;
				LA915_: ;
				{
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 3);
				}
				LA913_: ;
			}
			LA911_: ;
		}
		LA812_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 56):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* prevX60gensym413_;
		RootObj* T919_;
		T919_ = NIM_NIL;
		T919_ = idTableGet__astalgo_64((*c).bindings, &f->Sup);
		prevX60gensym413_ = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) (T919_));
		{
			if (!(prevX60gensym413_ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA922_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10);
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA** branch_3;
				NI i_14;
				NI L_3;
				NI T925_;
				branch_3 = (tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA**)0;
				i_14 = ((NI) 0);
				T925_ = ((*f).sons ? (*f).sons->Sup.len : 0);
				L_3 = T925_;
				{
					while (1) {
						tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA x_7;
						if (!(i_14 < L_3)) goto LA927;
						branch_3 = &(*f).sons->data[i_14];
						x_7 = typeRel__sigmatch_202(c, (*branch_3), aOrig_2, flags);
						{
							if (!(x_7 < ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 3))) goto LA930_;
							result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
							goto BeforeRet_;
						}
						LA930_: ;
						{
							if (!(x_7 < result)) goto LA934_;
							result = x_7;
						}
						LA934_: ;
						i_14 += ((NI) 1);
					} LA927: ;
				}
			}
			{
				if (!(((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8) < result)) goto LA938_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
			}
			LA938_: ;
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* boundX60gensym415_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T944_;
				if (!!(((flags &((NU8)1<<((NU)(((tyEnum_TTypeRelFlag__nkWaH9aZ1YawZFP9aSlbYFMw) 0))&7U)))!=0))) goto LA942_;
				T944_ = NIM_NIL;
				T944_ = skipTypes__ast_3723(aOrig_2, TM__wjrA09aH0rT1R7zbrcCaROw_16);
				boundX60gensym415_ = skipIntLit__magicsys_124(T944_, (*(*c).c).Sup.idgen);
				put__sigmatch_120(c, f, boundX60gensym415_);
			}
			LA942_: ;
			goto BeforeRet_;
		}
		goto LA920_;
		LA922_: ;
		{
			result = typeRel__sigmatch_202(c, prevX60gensym413_, a, flags);
			goto BeforeRet_;
		}
		LA920_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 57):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* prevX60gensym418_;
		RootObj* T947_;
		T947_ = NIM_NIL;
		T947_ = idTableGet__astalgo_64((*c).bindings, &f->Sup);
		prevX60gensym418_ = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) (T947_));
		{
			NI oldInheritancePenalty;
			NI maxInheritance;
			if (!(prevX60gensym418_ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA950_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
			oldInheritancePenalty = (*c).inheritancePenalty;
			maxInheritance = ((NI) 0);
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA** branch_4;
				NI i_15;
				NI L_4;
				NI T953_;
				branch_4 = (tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA**)0;
				i_15 = ((NI) 0);
				T953_ = ((*f).sons ? (*f).sons->Sup.len : 0);
				L_4 = T953_;
				{
					while (1) {
						tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA x_8;
						if (!(i_15 < L_4)) goto LA955;
						branch_4 = &(*f).sons->data[i_15];
						(*c).inheritancePenalty = ((NI) 0);
						x_8 = typeRel__sigmatch_202(c, (*branch_4), aOrig_2, flags);
						maxInheritance = ((maxInheritance >= (*c).inheritancePenalty) ? maxInheritance : (*c).inheritancePenalty);
						{
							if (!(result < x_8)) goto LA958_;
							result = x_8;
						}
						LA958_: ;
						i_15 += ((NI) 1);
					} LA955: ;
				}
			}
			{
				if (!(((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 2) <= result)) goto LA962_;
				{
					if (!(((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8) < result)) goto LA966_;
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
				}
				LA966_: ;
				{
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* boundX60gensym422_;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T972_;
					if (!!(((flags &((NU8)1<<((NU)(((tyEnum_TTypeRelFlag__nkWaH9aZ1YawZFP9aSlbYFMw) 0))&7U)))!=0))) goto LA970_;
					T972_ = NIM_NIL;
					T972_ = skipTypes__ast_3723(aOrig_2, TM__wjrA09aH0rT1R7zbrcCaROw_16);
					boundX60gensym422_ = skipIntLit__magicsys_124(T972_, (*(*c).c).Sup.idgen);
					put__sigmatch_120(c, f, boundX60gensym422_);
				}
				LA970_: ;
				goto BeforeRet_;
			}
			goto LA960_;
			LA962_: ;
			{
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
			}
			LA960_: ;
			(*c).inheritancePenalty = (NI)(oldInheritancePenalty + maxInheritance);
		}
		goto LA948_;
		LA950_: ;
		{
			result = typeRel__sigmatch_202(c, prevX60gensym418_, a, flags);
			goto BeforeRet_;
		}
		LA948_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 58):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* prevX60gensym425_;
		RootObj* T976_;
		T976_ = NIM_NIL;
		T976_ = idTableGet__astalgo_64((*c).bindings, &f->Sup);
		prevX60gensym425_ = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) (T976_));
		{
			if (!(prevX60gensym425_ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA979_;
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA** branch_5;
				NI i_16;
				NI L_5;
				NI T982_;
				branch_5 = (tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA**)0;
				i_16 = ((NI) 0);
				T982_ = ((*f).sons ? (*f).sons->Sup.len : 0);
				L_5 = T982_;
				{
					while (1) {
						if (!(i_16 < L_5)) goto LA984;
						branch_5 = &(*f).sons->data[i_16];
						{
							tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA T987_;
							T987_ = (tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA)0;
							T987_ = typeRel__sigmatch_202(c, (*branch_5), aOrig_2, flags);
							if (!!((T987_ == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0)))) goto LA988_;
							result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
							goto BeforeRet_;
						}
						LA988_: ;
						i_16 += ((NI) 1);
					} LA984: ;
				}
			}
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* boundX60gensym427_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T994_;
				if (!!(((flags &((NU8)1<<((NU)(((tyEnum_TTypeRelFlag__nkWaH9aZ1YawZFP9aSlbYFMw) 0))&7U)))!=0))) goto LA992_;
				T994_ = NIM_NIL;
				T994_ = skipTypes__ast_3723(aOrig_2, TM__wjrA09aH0rT1R7zbrcCaROw_16);
				boundX60gensym427_ = skipIntLit__magicsys_124(T994_, (*(*c).c).Sup.idgen);
				put__sigmatch_120(c, f, boundX60gensym427_);
			}
			LA992_: ;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
			goto BeforeRet_;
		}
		goto LA977_;
		LA979_: ;
		{
			result = typeRel__sigmatch_202(c, prevX60gensym425_, a, flags);
			goto BeforeRet_;
		}
		LA977_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 59):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* prevX60gensym430_;
		RootObj* T997_;
		T997_ = NIM_NIL;
		T997_ = idTableGet__astalgo_64((*c).bindings, &f->Sup);
		prevX60gensym430_ = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) (T997_));
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* concrete;
			if (!(prevX60gensym430_ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA1000_;
			concrete = concreteType__sigmatch_443((&(*c)), a, ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
			{
				NIM_BOOL T1004_;
				T1004_ = (NIM_BOOL)0;
				T1004_ = !((concrete == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
				if (!(T1004_)) goto LA1005_;
				T1004_ = !(((flags &((NU8)1<<((NU)(((tyEnum_TTypeRelFlag__nkWaH9aZ1YawZFP9aSlbYFMw) 0))&7U)))!=0));
				LA1005_: ;
				if (!T1004_) goto LA1006_;
				put__sigmatch_120(c, f, concrete);
			}
			LA1006_: ;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
			goto BeforeRet_;
		}
		goto LA998_;
		LA1000_: ;
		{
			result = typeRel__sigmatch_202(c, prevX60gensym430_, a, flags);
			goto BeforeRet_;
		}
		LA998_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 51):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* prevX60gensym434_;
		RootObj* T1010_;
		T1010_ = NIM_NIL;
		T1010_ = idTableGet__astalgo_64((*c).bindings, &f->Sup);
		prevX60gensym434_ = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) (T1010_));
		{
			tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg targetKind;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* effectiveArgType;
			NIM_BOOL typeClassMatches;
			NIM_BOOL T1015_;
			NIM_BOOL T1017_;
			if (!(prevX60gensym434_ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA1013_;
			targetKind = (*(*f).sons->data[((NI) 0)]).kind;
			effectiveArgType = skipTypes__ast_3723(a, TM__wjrA09aH0rT1R7zbrcCaROw_30);
			T1015_ = (NIM_BOOL)0;
			T1015_ = (targetKind == (*effectiveArgType).kind);
			if (!(T1015_)) goto LA1016_;
			T1017_ = (NIM_BOOL)0;
			T1017_ = isEmptyContainer__types_3684(effectiveArgType);
			T1015_ = !(T1017_);
			LA1016_: ;
			typeClassMatches = T1015_;
			{
				NIM_BOOL T1020_;
				NIM_BOOL T1022_;
				T1020_ = (NIM_BOOL)0;
				T1020_ = typeClassMatches;
				if (T1020_) goto LA1021_;
				T1022_ = (NIM_BOOL)0;
				T1022_ = (targetKind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25) || targetKind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 26));
				if (!(T1022_)) goto LA1023_;
				T1022_ = ((*effectiveArgType).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 5));
				LA1023_: ;
				T1020_ = T1022_;
				LA1021_: ;
				if (!T1020_) goto LA1024_;
				put__sigmatch_120(c, f, a);
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
				goto BeforeRet_;
			}
			goto LA1018_;
			LA1024_: ;
			{
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
				goto BeforeRet_;
			}
			LA1018_: ;
		}
		goto LA1011_;
		LA1013_: ;
		{
			result = typeRel__sigmatch_202(c, prevX60gensym434_, a, flags);
			goto BeforeRet_;
		}
		LA1011_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 53):
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 52):
	{
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1033_;
			if (!(((*f).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 10))&63U)))!=0)) goto LA1031_;
			T1033_ = NIM_NIL;
			T1033_ = lastSon__ast_3731(f);
			result = typeRel__sigmatch_202(c, T1033_, a, flags);
		}
		goto LA1029_;
		LA1031_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* prevX60gensym439_;
			RootObj* T1035_;
			T1035_ = NIM_NIL;
			T1035_ = idTableGet__astalgo_64((*c).bindings, &f->Sup);
			prevX60gensym439_ = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) (T1035_));
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* matched;
				if (!(prevX60gensym439_ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA1038_;
				{
					if (!(aOrig_2 == f)) goto LA1042_;
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10);
					goto BeforeRet_;
				}
				LA1042_: ;
				matched = matchUserTypeClass__sigmatch_993(c, f, aOrig_2);
				{
					if (!!((matched == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA1046_;
					add__concepts_23(matched, a);
					(*matched).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 10)) & 63);
					{
						if (!!(((flags &((NU8)1<<((NU)(((tyEnum_TTypeRelFlag__nkWaH9aZ1YawZFP9aSlbYFMw) 0))&7U)))!=0))) goto LA1050_;
						put__sigmatch_120(c, f, matched);
					}
					LA1050_: ;
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
				}
				goto LA1044_;
				LA1046_: ;
				{
					NIM_BOOL T1053_;
					NI T1054_;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1056_;
					T1053_ = (NIM_BOOL)0;
					T1054_ = (NI)0;
					T1054_ = len__ast_3990(a);
					T1053_ = (((NI) 0) < T1054_);
					if (!(T1053_)) goto LA1055_;
					T1056_ = NIM_NIL;
					T1056_ = lastSon__ast_3731(a);
					T1053_ = (T1056_ == f);
					LA1055_: ;
					if (!T1053_) goto LA1057_;
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
				}
				goto LA1044_;
				LA1057_: ;
				{
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
				}
				LA1044_: ;
			}
			goto LA1036_;
			LA1038_: ;
			{
				result = typeRel__sigmatch_202(c, prevX60gensym439_, a, flags);
				goto BeforeRet_;
			}
			LA1036_: ;
		}
		LA1029_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 62):
	{
		{
			NIM_BOOL T1064_;
			T1064_ = (NIM_BOOL)0;
			T1064_ = conceptMatch__concepts_538((*c).c, f, a, (&(*c).bindings), ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
			if (!T1064_) goto LA1065_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
		}
		goto LA1062_;
		LA1065_: ;
		{
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
		}
		LA1062_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 54):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* prevX60gensym445_;
		RootObj* T1069_;
		T1069_ = NIM_NIL;
		T1069_ = idTableGet__astalgo_64((*c).bindings, &f->Sup);
		prevX60gensym445_ = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) (T1069_));
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* roota_2;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* rootf_2;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1074_;
			if (!(prevX60gensym445_ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA1072_;
			roota_2 = skipGenericAlias__types_2275(a);
			T1074_ = NIM_NIL;
			T1074_ = lastSon__ast_3731(f);
			rootf_2 = skipGenericAlias__types_2275(T1074_);
			{
				NIM_BOOL T1077_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1079_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1080_;
				T1077_ = (NIM_BOOL)0;
				T1077_ = ((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11));
				if (!(T1077_)) goto LA1078_;
				T1079_ = NIM_NIL;
				T1079_ = base__types_63(roota_2);
				T1080_ = NIM_NIL;
				T1080_ = base__types_63(rootf_2);
				T1077_ = (T1079_ == T1080_);
				LA1078_: ;
				if (!T1077_) goto LA1081_;
				{
					NI i_17;
					NI colontmp__6;
					NI T1084_;
					NI i_18;
					i_17 = (NI)0;
					colontmp__6 = (NI)0;
					T1084_ = (NI)0;
					T1084_ = len__ast_3990(rootf_2);
					colontmp__6 = (NI)(T1084_ - ((NI) 1));
					i_18 = ((NI) 1);
					{
						while (1) {
							tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ff_5;
							tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* aa_4;
							if (!(i_18 < colontmp__6)) goto LA1086;
							i_17 = i_18;
							ff_5 = (*rootf_2).sons->data[i_17];
							aa_4 = (*roota_2).sons->data[i_17];
							result = typeRel__sigmatch_202(c, ff_5, aa_4, flags);
							{
								if (!(result == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0))) goto LA1089_;
								goto BeforeRet_;
							}
							LA1089_: ;
							{
								NIM_BOOL T1093_;
								T1093_ = (NIM_BOOL)0;
								T1093_ = ((*ff_5).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 20));
								if (!(T1093_)) goto LA1094_;
								T1093_ = !((result == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10)));
								LA1094_: ;
								if (!T1093_) goto LA1095_;
								result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
								goto BeforeRet_;
							}
							LA1095_: ;
							i_18 += ((NI) 1);
						} LA1086: ;
					}
				}
			}
			goto LA1075_;
			LA1081_: ;
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1098_;
				T1098_ = NIM_NIL;
				T1098_ = lastSon__ast_3731(rootf_2);
				result = typeRel__sigmatch_202(c, T1098_, a, flags);
			}
			LA1075_: ;
			{
				if (!!((result == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0)))) goto LA1101_;
				put__sigmatch_120(c, f, a);
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
			}
			LA1101_: ;
		}
		goto LA1070_;
		LA1072_: ;
		{
			result = typeRel__sigmatch_202(c, prevX60gensym445_, a, flags);
			goto BeforeRet_;
		}
		LA1070_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12):
	{
		NIM_BOOL doBindGP;
		NIM_BOOL T1105_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* x_9;
		RootObj* T1107_;
		T1105_ = (NIM_BOOL)0;
		T1105_ = !(((flags &((NU8)1<<((NU)(((tyEnum_TTypeRelFlag__nkWaH9aZ1YawZFP9aSlbYFMw) 0))&7U)))!=0));
		if (T1105_) goto LA1106_;
		T1105_ = ((flags &((NU8)1<<((NU)(((tyEnum_TTypeRelFlag__nkWaH9aZ1YawZFP9aSlbYFMw) 2))&7U)))!=0);
		LA1106_: ;
		doBindGP = T1105_;
		T1107_ = NIM_NIL;
		T1107_ = idTableGet__astalgo_64((*c).bindings, &f->Sup);
		x_9 = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) (T1107_));
		{
			if (!(x_9 == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA1110_;
			{
				NIM_BOOL T1114_;
				T1114_ = (NIM_BOOL)0;
				T1114_ = ((*(*c).callee).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 10));
				if (!(T1114_)) goto LA1115_;
				T1114_ = !((*c).typedescMatched);
				LA1115_: ;
				if (!T1114_) goto LA1116_;
				{
					if (!(((*a).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 30))&63U)))!=0)) goto LA1120_;
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
				}
				goto LA1118_;
				LA1120_: ;
				{
					if (!((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8))) goto LA1123_;
					{
						NI T1127_;
						T1127_ = (NI)0;
						T1127_ = len__ast_3990(f);
						if (!(T1127_ == ((NI) 0))) goto LA1128_;
						result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
					}
					goto LA1125_;
					LA1128_: ;
					{
						tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* aa_5;
						tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1145_;
						{
							NI T1133_;
							NimStringDesc* argX60gensym455_;
							T1133_ = (NI)0;
							T1133_ = len__ast_3990(a);
							if (!!((((NI) 0) < T1133_))) goto LA1134_;
							argX60gensym455_ = toFileLineCol__msgs_625(TM__wjrA09aH0rT1R7zbrcCaROw_44);
							internalErrorImpl__msgs_1441((*(*(*c).c).graph).config, unknownLineInfo__lineinfos_284, argX60gensym455_, TM__wjrA09aH0rT1R7zbrcCaROw_44);
						}
						LA1134_: ;
						(*c).typedescMatched = NIM_TRUE;
						aa_5 = a;
						{
							while (1) {
								NIM_BOOL T1138_;
								NI T1140_;
								T1138_ = (NIM_BOOL)0;
								T1138_ = ((*aa_5).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8) || (*aa_5).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12));
								if (!(T1138_)) goto LA1139_;
								T1140_ = (NI)0;
								T1140_ = len__ast_3990(aa_5);
								T1138_ = (((NI) 0) < T1140_);
								LA1139_: ;
								if (!T1138_) goto LA1137;
								aa_5 = lastSon__ast_3731(aa_5);
							} LA1137: ;
						}
						{
							if (!((*aa_5).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12) || (*aa_5).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 51) && (*aa_5).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 54) || (*aa_5).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 56) && (*aa_5).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 59))) goto LA1143_;
							result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
							goto BeforeRet_;
						}
						LA1143_: ;
						T1145_ = NIM_NIL;
						T1145_ = base__types_63(f);
						result = typeRel__sigmatch_202(c, T1145_, aa_5, flags);
						{
							if (!(((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8) < result)) goto LA1148_;
							result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
						}
						LA1148_: ;
					}
					LA1125_: ;
				}
				goto LA1118_;
				LA1123_: ;
				{
					if (!(*c).isNoCall) goto LA1151_;
					{
						tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* concrete_2;
						if (!doBindGP) goto LA1155_;
						concrete_2 = concreteType__sigmatch_443((&(*c)), a, f);
						{
							if (!(concrete_2 == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA1159_;
							result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
							goto BeforeRet_;
						}
						LA1159_: ;
						put__sigmatch_120(c, f, concrete_2);
					}
					LA1155_: ;
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
				}
				goto LA1118_;
				LA1151_: ;
				{
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
				}
				LA1118_: ;
			}
			goto LA1112_;
			LA1116_: ;
			{
				{
					NIM_BOOL T1165_;
					NI T1166_;
					NI oldInheritancePenalty_2;
					T1165_ = (NIM_BOOL)0;
					T1166_ = (NI)0;
					T1166_ = len__ast_3990(f);
					T1165_ = (((NI) 0) < T1166_);
					if (!(T1165_)) goto LA1167_;
					T1165_ = !(((*(*f).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 0)));
					LA1167_: ;
					if (!T1165_) goto LA1168_;
					oldInheritancePenalty_2 = (*c).inheritancePenalty;
					result = typeRel__sigmatch_202(c, (*f).sons->data[((NI) 0)], a, (flags | 5));
					{
						NIM_BOOL T1172_;
						tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* concrete_3;
						T1172_ = (NIM_BOOL)0;
						T1172_ = doBindGP;
						if (!(T1172_)) goto LA1173_;
						T1172_ = !(((257 &((NU16)1<<((NU)(result)&15U)))!=0));
						LA1173_: ;
						if (!T1172_) goto LA1174_;
						concrete_3 = concreteType__sigmatch_443((&(*c)), a, f);
						{
							if (!(concrete_3 == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA1178_;
							result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
							goto BeforeRet_;
						}
						LA1178_: ;
						put__sigmatch_120(c, f, concrete_3);
					}
					LA1174_: ;
					{
						if (!((1032 &((NU16)1<<((NU)(result)&15U)))!=0)) goto LA1182_;
						(*c).inheritancePenalty = (NI)((NI)(oldInheritancePenalty_2 - (*c).inheritancePenalty) - (NI)(((NI) 100) * (result == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10))));
						result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
					}
					LA1182_: ;
				}
				goto LA1163_;
				LA1168_: ;
				{
					if (!((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8))) goto LA1185_;
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
				}
				goto LA1163_;
				LA1185_: ;
				{
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
				}
				LA1163_: ;
			}
			LA1112_: ;
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* concrete_4;
				if (!(result == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8))) goto LA1190_;
				concrete_4 = a;
				{
					if (!(((*a).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 30))&63U)))!=0)) goto LA1194_;
					transitionGenericParamToType__ast_4391((*a).sym);
					(*a).flags &= ~(((NU64)1) << ((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 30)) & 63));
				}
				goto LA1192_;
				LA1194_: ;
				{
					concrete_4 = concreteType__sigmatch_443((&(*c)), a, f);
					{
						if (!(concrete_4 == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA1199_;
						result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
						goto BeforeRet_;
					}
					LA1199_: ;
				}
				LA1192_: ;
				{
					if (!doBindGP) goto LA1203_;
					put__sigmatch_120(c, f, concrete_4);
				}
				LA1203_: ;
			}
			goto LA1188_;
			LA1190_: ;
			{
				if (!(((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8) < result)) goto LA1206_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
			}
			goto LA1188_;
			LA1206_: ;
			LA1188_: ;
		}
		goto LA1108_;
		LA1110_: ;
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 3))) goto LA1209_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
		}
		goto LA1108_;
		LA1209_: ;
		{
			if (!((*x_9).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12))) goto LA1212_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
		}
		goto LA1108_;
		LA1212_: ;
		{
			result = typeRel__sigmatch_202(c, x_9, a, flags);
			{
				if (!(((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8) < result)) goto LA1217_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
			}
			LA1217_: ;
		}
		LA1108_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* prev_5;
		RootObj* T1220_;
		T1220_ = NIM_NIL;
		T1220_ = idTableGet__astalgo_64((*c).bindings, &f->Sup);
		prev_5 = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) (T1220_));
		{
			if (!(prev_5 == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA1223_;
			{
				if (!((*aOrig_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60))) goto LA1227_;
				{
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1231_;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1234_;
					T1231_ = NIM_NIL;
					T1231_ = base__types_63(f);
					if (!!(((*T1231_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 0) || (*T1231_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12)))) goto LA1232_;
					T1234_ = NIM_NIL;
					T1234_ = base__types_63(f);
					result = typeRel__sigmatch_202(c, T1234_, a, flags);
					{
						NIM_BOOL T1237_;
						T1237_ = (NIM_BOOL)0;
						T1237_ = !((result == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0)));
						if (!(T1237_)) goto LA1238_;
						T1237_ = !(((*f).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
						LA1238_: ;
						if (!T1237_) goto LA1239_;
						{
							NIM_BOOL T1243_;
							T1243_ = (NIM_BOOL)0;
							T1243_ = exprStructuralEquivalent__trees_56((*f).n, (*aOrig_2).n, NIM_FALSE);
							if (!!(T1243_)) goto LA1244_;
							result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
						}
						LA1244_: ;
					}
					LA1239_: ;
				}
				goto LA1229_;
				LA1232_: ;
				{
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1247_;
					T1247_ = NIM_NIL;
					T1247_ = base__types_63(f);
					if (!((*T1247_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12))) goto LA1248_;
					{
						tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1252_;
						NI T1253_;
						tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1256_;
						tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1257_;
						T1252_ = NIM_NIL;
						T1252_ = base__types_63(f);
						T1253_ = (NI)0;
						T1253_ = len__ast_3990(T1252_);
						if (!(((NI) 0) < T1253_)) goto LA1254_;
						T1256_ = NIM_NIL;
						T1256_ = base__types_63(f);
						T1257_ = NIM_NIL;
						T1257_ = lastSon__ast_3731(T1256_);
						result = typeRel__sigmatch_202(c, T1257_, a, flags);
					}
					goto LA1250_;
					LA1254_: ;
					{
						{
							if (!(((*f).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 25))&63U)))!=0)) goto LA1261_;
							result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
						}
						goto LA1259_;
						LA1261_: ;
						{
							tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1264_;
							T1264_ = NIM_NIL;
							T1264_ = base__types_63(f);
							result = typeRel__sigmatch_202(c, T1264_, a, flags);
						}
						LA1259_: ;
					}
					LA1250_: ;
				}
				goto LA1229_;
				LA1248_: ;
				{
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
				}
				LA1229_: ;
				{
					if (!!((result == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0)))) goto LA1268_;
					put__sigmatch_120(c, f, aOrig_2);
				}
				LA1268_: ;
			}
			goto LA1225_;
			LA1227_: ;
			{
				NIM_BOOL T1271_;
				T1271_ = (NIM_BOOL)0;
				T1271_ = !(((*aOrig_2).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
				if (!(T1271_)) goto LA1272_;
				T1271_ = !(((*(*aOrig_2).n).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
				LA1272_: ;
				if (!T1271_) goto LA1273_;
				{
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1277_;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1280_;
					T1277_ = NIM_NIL;
					T1277_ = base__types_63(f);
					if (!!(((*T1277_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 0)))) goto LA1278_;
					T1280_ = NIM_NIL;
					T1280_ = lastSon__ast_3731(f);
					result = typeRel__sigmatch_202(c, T1280_, (*(*aOrig_2).n).typ, flags);
				}
				goto LA1275_;
				LA1278_: ;
				{
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
				}
				LA1275_: ;
				{
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* boundType;
					tySequence__vKogasEnJSPhbQmA8r4Y9aA* T1286_;
					if (!!((result == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0)))) goto LA1284_;
					T1286_ = NIM_NIL;
					T1286_ = (tySequence__vKogasEnJSPhbQmA8r4Y9aA*) newSeq((&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_), 1);
					asgnRef((void**) (&T1286_->data[0]), (*(*aOrig_2).n).typ);
					boundType = newTypeWithSons__semdata_851((*c).c, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60), T1286_);
					asgnRef((void**) (&(*boundType).n), (*aOrig_2).n);
					put__sigmatch_120(c, f, boundType);
				}
				LA1284_: ;
			}
			goto LA1225_;
			LA1273_: ;
			{
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
			}
			LA1225_: ;
		}
		goto LA1221_;
		LA1223_: ;
		{
			if (!((*prev_5).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60))) goto LA1289_;
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1295_;
				if (!((*aOrig_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60))) goto LA1293_;
				T1295_ = NIM_NIL;
				T1295_ = lastSon__ast_3731(prev_5);
				result = typeRel__sigmatch_202(c, T1295_, a, flags);
				{
					NIM_BOOL T1298_;
					T1298_ = (NIM_BOOL)0;
					T1298_ = !((result == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0)));
					if (!(T1298_)) goto LA1299_;
					T1298_ = !(((*prev_5).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
					LA1299_: ;
					if (!T1298_) goto LA1300_;
					{
						NIM_BOOL T1304_;
						T1304_ = (NIM_BOOL)0;
						T1304_ = exprStructuralEquivalent__trees_56((*prev_5).n, (*aOrig_2).n, NIM_FALSE);
						if (!!(T1304_)) goto LA1305_;
						result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
					}
					LA1305_: ;
				}
				LA1300_: ;
			}
			goto LA1291_;
			LA1293_: ;
			{
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
			}
			LA1291_: ;
		}
		goto LA1221_;
		LA1289_: ;
		{
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
		}
		LA1221_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 55):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* prev_6;
		{
			NI T1312_;
			T1312_ = ((*f).sons ? (*f).sons->Sup.len : 0);
			if (!(((NI) 1) < T1312_)) goto LA1313_;
			prev_6 = lastSon__ast_3731(f);
		}
		goto LA1310_;
		LA1313_: ;
		{
			prev_6 = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL);
		}
		LA1310_: ;
		{
			if (!!((prev_6 == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA1318_;
			result = typeRel__sigmatch_202(c, prev_6, a, flags);
		}
		goto LA1316_;
		LA1318_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1321_;
			T1321_ = NIM_NIL;
			T1321_ = base__types_63(f);
			result = typeRel__sigmatch_202(c, T1321_, a, flags);
			{
				NI T1326_;
				if (!!((result == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0)))) goto LA1324_;
				unsureAsgnRef((void**) (&(*c).inferredTypes), (tySequence__vKogasEnJSPhbQmA8r4Y9aA*) incrSeqV3((TGenericSeq*)((*c).inferredTypes), (&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_)));
				T1326_ = (*c).inferredTypes->Sup.len++;
				asgnRef((void**) (&(*c).inferredTypes->data[T1326_]), f);
				add__concepts_23(f, a);
			}
			LA1324_: ;
		}
		LA1316_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* prev_7;
		RootObj* T1328_;
		T1328_ = NIM_NIL;
		T1328_ = idTableGet__astalgo_64((*c).bindings, &f->Sup);
		prev_7 = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) (T1328_));
		{
			if (!(prev_7 == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA1331_;
			{
				if (!!(((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8)))) goto LA1335_;
				{
					NIM_BOOL T1339_;
					T1339_ = (NIM_BOOL)0;
					T1339_ = ((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12));
					if (!(T1339_)) goto LA1340_;
					T1339_ = (((*a).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 30))&63U)))!=0);
					LA1340_: ;
					if (!T1339_) goto LA1341_;
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
				}
				goto LA1337_;
				LA1341_: ;
				{
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
				}
				LA1337_: ;
			}
			goto LA1333_;
			LA1335_: ;
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1345_;
				T1345_ = NIM_NIL;
				T1345_ = base__types_63(f);
				if (!((*T1345_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 0))) goto LA1346_;
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
			}
			goto LA1333_;
			LA1346_: ;
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1349_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1350_;
				T1349_ = NIM_NIL;
				T1349_ = base__types_63(f);
				T1350_ = NIM_NIL;
				T1350_ = base__types_63(a);
				result = typeRel__sigmatch_202(c, T1349_, T1350_, flags);
			}
			LA1333_: ;
			{
				if (!!((result == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0)))) goto LA1353_;
				put__sigmatch_120(c, f, a);
			}
			LA1353_: ;
		}
		goto LA1329_;
		LA1331_: ;
		{
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1360_;
				if (!(((*f).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 9))&63U)))!=0)) goto LA1358_;
				T1360_ = NIM_NIL;
				T1360_ = base__types_63(prev_7);
				result = typeRel__sigmatch_202(c, T1360_, a, flags);
			}
			goto LA1356_;
			LA1358_: ;
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1364_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1365_;
				if (!((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8))) goto LA1362_;
				T1364_ = NIM_NIL;
				T1364_ = base__types_63(prev_7);
				T1365_ = NIM_NIL;
				T1365_ = base__types_63(a);
				result = typeRel__sigmatch_202(c, T1364_, T1365_, flags);
			}
			goto LA1356_;
			LA1362_: ;
			{
				result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
			}
			LA1356_: ;
		}
		LA1329_: ;
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 7):
	{
		{
			if (!!((aOrig_2 == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA1370_;
			put__sigmatch_120(c, f, aOrig_2);
		}
		LA1370_: ;
		result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 50):
	{
		result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10);
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 61):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* reevaluated;
		{
			NIM_BOOL T1376_;
			T1376_ = (NIM_BOOL)0;
			T1376_ = ((*f).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
			if (T1376_) goto LA1377_;
			T1376_ = ((*(*f).n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1));
			LA1377_: ;
			if (!T1376_) goto LA1378_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8);
			goto BeforeRet_;
		}
		LA1378_: ;
		reevaluated = tryResolvingStaticExpr__sigmatch_1227(c, (*f).n, NIM_FALSE);
		switch ((*(*reevaluated).typ).kind) {
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8):
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1381_;
			T1381_ = NIM_NIL;
			T1381_ = base__types_63((*reevaluated).typ);
			result = typeRel__sigmatch_202(c, a, T1381_, flags);
		}
		break;
		case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60):
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1383_;
			T1383_ = NIM_NIL;
			T1383_ = base__types_63((*reevaluated).typ);
			result = typeRel__sigmatch_202(c, a, T1383_, flags);
			{
				NIM_BOOL T1386_;
				T1386_ = (NIM_BOOL)0;
				T1386_ = !((result == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0)));
				if (!(T1386_)) goto LA1387_;
				T1386_ = !(((*(*reevaluated).typ).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
				LA1387_: ;
				if (!T1386_) goto LA1388_;
				{
					NIM_BOOL T1392_;
					T1392_ = (NIM_BOOL)0;
					T1392_ = exprStructuralEquivalent__trees_56((*aOrig_2).n, (*(*reevaluated).typ).n, NIM_FALSE);
					if (!!(T1392_)) goto LA1393_;
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
				}
				LA1393_: ;
			}
			LA1388_: ;
		}
		break;
		default:
		{
			result = typeRel__sigmatch_202(c, a, (*reevaluated).typ, flags);
			{
				NIM_BOOL T1398_;
				T1398_ = (NIM_BOOL)0;
				T1398_ = !((result == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0)));
				if (!(T1398_)) goto LA1399_;
				T1398_ = !(((*(*reevaluated).typ).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
				LA1399_: ;
				if (!T1398_) goto LA1400_;
				{
					NIM_BOOL T1404_;
					T1404_ = (NIM_BOOL)0;
					T1404_ = exprStructuralEquivalent__trees_56((*aOrig_2).n, (*(*reevaluated).typ).n, NIM_FALSE);
					if (!!(T1404_)) goto LA1405_;
					result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0);
				}
				LA1405_: ;
			}
			LA1400_: ;
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 0):
	{
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 0))) goto LA1410_;
			result = ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10);
		}
		LA1410_: ;
	}
	break;
	default:
	{
		NimStringDesc* T1413_;
		T1413_ = NIM_NIL;
		T1413_ = rawNewString((reprEnum((NI)(*f).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)) ? reprEnum((NI)(*f).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_))->Sup.len : 0) + 19);
appendString(T1413_, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_45));
appendString(T1413_, reprEnum((NI)(*f).kind, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)));
		internalErrorImpl__msgs_1441((*(*(*c).c).graph).config, unknownLineInfo__lineinfos_284, T1413_, TM__wjrA09aH0rT1R7zbrcCaROw_46);
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, incMatches__sigmatch_3266)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m, tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA r, NI convMatch) {
	switch (r) {
	case ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1):
	case ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 2):
	{
		(*m).convMatches += convMatch;
	}
	break;
	case ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 3):
	case ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 4):
	{
		(*m).subtypeMatches += ((NI) 1);
	}
	break;
	case ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8):
	case ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 6):
	case ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 5):
	{
		(*m).genericMatches += ((NI) 1);
	}
	break;
	case ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 9):
	{
		(*m).intConvMatches += ((NI) 256);
	}
	break;
	case ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 7):
	{
		(*m).convMatches += ((NI) 1);
	}
	break;
	case ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10):
	{
		(*m).exactMatches += ((NI) 1);
	}
	break;
	case ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0):
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, getInstantiatedType__sigmatch_3081)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	RootObj* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = idTableGet__astalgo_64((*m).bindings, &f->Sup);
	result = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) (T1_));
	{
		if (!(result == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA4_;
		result = generateTypeInstance__semtypinst_1086(c, (*m).bindings, (*arg).info, f);
	}
	LA4_: ;
	{
		if (!(result == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA8_;
		internalErrorImpl__msgs_1441((*(*c).graph).config, (*arg).info, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_49), TM__wjrA09aH0rT1R7zbrcCaROw_50);
		result = errorType__semdata_1032(c);
	}
	LA8_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, implicitConv__sigmatch_3095)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = newNodeI__ast_3320(kind, (*arg).info);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = containsGenericType__types_3406(f);
		if (!T3_) goto LA4_;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T10_;
			if (!!(!(((*m).fauxMatch == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 0))))) goto LA8_;
			T10_ = NIM_NIL;
			T10_ = getInstantiatedType__sigmatch_3081(c, arg, m, f);
			asgnRef((void**) (&(*result).typ), skipTypes__ast_3723(T10_, TM__wjrA09aH0rT1R7zbrcCaROw_51));
		}
		goto LA6_;
		LA8_: ;
		{
			asgnRef((void**) (&(*result).typ), errorType__semdata_1032(c));
		}
		LA6_: ;
	}
	goto LA1_;
	LA4_: ;
	{
		asgnRef((void**) (&(*result).typ), skipTypes__ast_3723(f, TM__wjrA09aH0rT1R7zbrcCaROw_52));
	}
	LA1_: ;
	{
		if (!((*result).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA15_;
		internalErrorImpl__msgs_1441((*(*c).graph).config, (*arg).info, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_53), TM__wjrA09aH0rT1R7zbrcCaROw_54);
	}
	LA15_: ;
	add__ast_4798(result, (*(*c).graph).emptyNode);
	add__ast_4798(result, arg);
	return result;
}
static N_INLINE(NIM_BOOL, isLValue__sigmatch_3118)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow aa;
	result = (NIM_BOOL)0;
	aa = isAssignable__parampatterns_334(((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL), n, NIM_FALSE);
	switch (aa) {
	case ((tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow) 1):
	case ((tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow) 2):
	case ((tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow) 5):
	{
		result = NIM_TRUE;
	}
	break;
	case ((tyEnum_TAssignableResult__QCmMYhJezk585e39ahToCow) 3):
	{
		result = (((NI) 0) < (*c).inUncheckedAssignSection);
	}
	break;
	default:
	{
		result = NIM_FALSE;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, extractPragma__sigmatch_5411)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	{
		if (!((520192 &((NU32)1<<((NU)((*s).kind)&31U)))!=0)) goto LA3_;
		result = (*(*s).ast)._kind_6.sons->data[((NI) 4)];
	}
	goto LA1_;
	LA3_: ;
	{
		if (!((896 &((NU32)1<<((NU)((*s).kind)&31U)))!=0)) goto LA6_;
		{
			NIM_BOOL T10_;
			NI T12_;
			T10_ = (NIM_BOOL)0;
			T10_ = !(((*s).ast == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
			if (!(T10_)) goto LA11_;
			T12_ = (NI)0;
			T12_ = len__ast_3155((*s).ast);
			T10_ = (((NI) 0) < T12_);
			LA11_: ;
			if (!T10_) goto LA13_;
			{
				NIM_BOOL T17_;
				NI T19_;
				T17_ = (NIM_BOOL)0;
				T17_ = ((*(*(*s).ast)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 43));
				if (!(T17_)) goto LA18_;
				T19_ = (NI)0;
				T19_ = len__ast_3155((*(*s).ast)._kind_6.sons->data[((NI) 0)]);
				T17_ = (((NI) 1) < T19_);
				LA18_: ;
				if (!T17_) goto LA20_;
				result = (*(*(*s).ast)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)];
			}
			LA20_: ;
		}
		LA13_: ;
	}
	goto LA1_;
	LA6_: ;
	LA1_: ;
	{
		NIM_BOOL T24_;
		T24_ = (NIM_BOOL)0;
		T24_ = (result == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
		if (T24_) goto LA25_;
		T24_ = ((*result).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 90));
		LA25_: ;
		if (!!(T24_)) goto LA26_;
		failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_58));
	}
	LA26_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, warnAboutDeprecated__sigmatch_5454)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pragmaNode;
	NimStringDesc* name;
	NimStringDesc* T33_;
{	pragmaNode = NIM_NIL;
	{
		if (!((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 20))) goto LA3_;
		pragmaNode = extractPragma__sigmatch_5411((*s).owner);
	}
	goto LA1_;
	LA3_: ;
	{
		pragmaNode = extractPragma__sigmatch_5411(s);
	}
	LA1_: ;
	{
		NIM_BOOL T8_;
		NimStringDesc* T12_;
		T8_ = (NIM_BOOL)0;
		T8_ = ((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 20));
		if (!(T8_)) goto LA9_;
		T8_ = !((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 22))&63U)))!=0));
		LA9_: ;
		if (!T8_) goto LA10_;
		T12_ = NIM_NIL;
		T12_ = rawNewString(((*(*(*s).owner).name).s ? (*(*(*s).owner).name).s->Sup.len : 0) + ((*(*s).name).s ? (*(*s).name).s->Sup.len : 0) + 31);
appendString(T12_, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_59));
appendString(T12_, (*(*(*s).owner).name).s);
appendString(T12_, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_60));
appendString(T12_, (*(*s).name).s);
appendString(T12_, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_19));
		name = T12_;
	}
	goto LA6_;
	LA10_: ;
	{
		name = (*(*s).name).s;
	}
	LA6_: ;
	{
		if (!!((pragmaNode == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA16_;
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
			it = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(pragmaNode);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA21;
						i = i_2;
						it = (*pragmaNode)._kind_6.sons->data[i];
						{
							NIM_BOOL T24_;
							NIM_BOOL T25_;
							tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw T26_;
							NI T28_;
							NimStringDesc* T32_;
							T24_ = (NIM_BOOL)0;
							T25_ = (NIM_BOOL)0;
							T26_ = (tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw)0;
							T26_ = whichPragma__trees_244(it);
							T25_ = (T26_ == ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 138));
							if (!(T25_)) goto LA27_;
							T28_ = (NI)0;
							T28_ = safeLen__ast_3148(it);
							T25_ = (T28_ == ((NI) 2));
							LA27_: ;
							T24_ = T25_;
							if (!(T24_)) goto LA29_;
							T24_ = ((*(*it)._kind_6.sons->data[((NI) 1)]).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) && (*(*it)._kind_6.sons->data[((NI) 1)]).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22));
							LA29_: ;
							if (!T24_) goto LA30_;
							T32_ = NIM_NIL;
							T32_ = rawNewString(((*(*it)._kind_6.sons->data[((NI) 1)])._kind_3.strVal ? (*(*it)._kind_6.sons->data[((NI) 1)])._kind_3.strVal->Sup.len : 0) + (name ? name->Sup.len : 0) + 16);
appendString(T32_, (*(*it)._kind_6.sons->data[((NI) 1)])._kind_3.strVal);
appendString(T32_, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_61));
appendString(T32_, name);
appendString(T32_, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_62));
							liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 21), T32_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__wjrA09aH0rT1R7zbrcCaROw_63, NIM_FALSE);
							goto BeforeRet_;
						}
						LA30_: ;
						i_2 += ((NI) 1);
					} LA21: ;
				}
			}
		}
	}
	LA16_: ;
	T33_ = NIM_NIL;
	T33_ = rawNewString((name ? name->Sup.len : 0) + 14);
appendString(T33_, name);
appendString(T33_, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_62));
	liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 21), T33_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__wjrA09aH0rT1R7zbrcCaROw_65, NIM_FALSE);
	}BeforeRet_: ;
}
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_629)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = toMsgFilename__msgs_612(conf, info.fileIndex);
	result = resizeString(result, (T1_ ? T1_->Sup.len : 0) + 0);
appendString(result, T1_);
	{
		if (!(((NI) 0) < ((NI) (info.line)))) goto LA4_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_41));
		addInt__stdZprivateZdigitsutils_189((&result), ((NI) (info.line)));
		{
			if (!(((NI) 0) < (NI)(((NI) (info.col)) + ((NI) 1)))) goto LA8_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_42));
			addInt__stdZprivateZdigitsutils_189((&result), (NI)(((NI) (info.col)) + ((NI) 1)));
		}
		LA8_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_43));
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, userError__sigmatch_5487)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pragmaNode;
	tyArray__24KAM9afIUgUaqBaEBB6r9bg T22_;
	NimStringDesc* T23_;
{	pragmaNode = extractPragma__sigmatch_5411(s);
	{
		if (!!((pragmaNode == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA3_;
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
			it = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(pragmaNode);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA8;
						i = i_2;
						it = (*pragmaNode)._kind_6.sons->data[i];
						{
							NIM_BOOL T11_;
							NIM_BOOL T12_;
							tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw T13_;
							NI T15_;
							tyArray__24KAM9afIUgUaqBaEBB6r9bg T19_;
							NimStringDesc* T20_;
							NimStringDesc* T21_;
							T11_ = (NIM_BOOL)0;
							T12_ = (NIM_BOOL)0;
							T13_ = (tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw)0;
							T13_ = whichPragma__trees_244(it);
							T12_ = (T13_ == ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 122));
							if (!(T12_)) goto LA14_;
							T15_ = (NI)0;
							T15_ = safeLen__ast_3148(it);
							T12_ = (T15_ == ((NI) 2));
							LA14_: ;
							T11_ = T12_;
							if (!(T11_)) goto LA16_;
							T11_ = ((*(*it)._kind_6.sons->data[((NI) 1)]).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) && (*(*it)._kind_6.sons->data[((NI) 1)]).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22));
							LA16_: ;
							if (!T11_) goto LA17_;
							nimZeroMem((void*)T19_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
							T20_ = NIM_NIL;
							T20_ = rawNewString(((*(*it)._kind_6.sons->data[((NI) 1)])._kind_3.strVal ? (*(*it)._kind_6.sons->data[((NI) 1)])._kind_3.strVal->Sup.len : 0) + 2);
appendString(T20_, (*(*it)._kind_6.sons->data[((NI) 1)])._kind_3.strVal);
appendString(T20_, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_61));
							T19_[0] = T20_;
							T19_[1] = copyString((*(*s).name).s);
							T19_[2] = toFileLineCol__msgs_629(conf, (*(*s).ast).info);
							T21_ = NIM_NIL;
							T21_ = nsuFormatOpenArray(((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_66), T19_, 3);
							liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T21_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__wjrA09aH0rT1R7zbrcCaROw_67, NIM_FALSE);
							goto BeforeRet_;
						}
						LA17_: ;
						i_2 += ((NI) 1);
					} LA8: ;
				}
			}
		}
	}
	LA3_: ;
	nimZeroMem((void*)T22_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
	T22_[0] = ((NimStringDesc*) NIM_NIL);
	T22_[1] = copyString((*(*s).name).s);
	T22_[2] = toFileLineCol__msgs_629(conf, (*(*s).ast).info);
	T23_ = NIM_NIL;
	T23_ = nsuFormatOpenArray(((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_66), T22_, 3);
	liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T23_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__wjrA09aH0rT1R7zbrcCaROw_68, NIM_FALSE);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, markOwnerModuleAsUsed__sigmatch_89)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
	module = s;
	{
		while (1) {
			NIM_BOOL T3_;
			T3_ = (NIM_BOOL)0;
			T3_ = !((module == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
			if (!(T3_)) goto LA4_;
			T3_ = !(((*module).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6)));
			LA4_: ;
			if (!T3_) goto LA2;
			module = (*module).owner;
		} LA2: ;
	}
	{
		NIM_BOOL T7_;
		NI i;
		T7_ = (NIM_BOOL)0;
		T7_ = !((module == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
		if (!(T7_)) goto LA8_;
		T7_ = !((module == (*c).module));
		LA8_: ;
		if (!T7_) goto LA9_;
		i = ((NI) 0);
		{
			while (1) {
				NI T13_;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* candidate;
				T13_ = (((*c).unusedImports ? (*c).unusedImports->Sup.len : 0)-1);
				if (!(i <= T13_)) goto LA12;
				candidate = (*c).unusedImports->data[i].Field0;
				{
					NIM_BOOL T16_;
					NIM_BOOL T17_;
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym898_;
					NI T19_;
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym901_;
					tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ T21_;
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym902_;
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym903_;
					T16_ = (NIM_BOOL)0;
					T17_ = (NIM_BOOL)0;
					T17_ = (candidate == module);
					if (T17_) goto LA18_;
					xX60gensym898_ = candidate;
					T19_ = (NI)0;
					T19_ = getOrDefault__sigmatch_5637((*c).importModuleMap, (NI)((NI)((NU32)(((NI) ((*xX60gensym898_).Sup.itemId.module))) << (NU32)(((NI) 20))) + ((NI) ((*xX60gensym898_).Sup.itemId.item))), ((NI) (-2147483647 -1)));
					xX60gensym901_ = module;
					T17_ = (T19_ == (NI)((NI)((NU32)(((NI) ((*xX60gensym901_).Sup.itemId.module))) << (NU32)(((NI) 20))) + ((NI) ((*xX60gensym901_).Sup.itemId.item))));
					LA18_: ;
					T16_ = T17_;
					if (T16_) goto LA20_;
					xX60gensym902_ = candidate;
					T21_.Field0 = (NI)((NI)((NU32)(((NI) ((*xX60gensym902_).Sup.itemId.module))) << (NU32)(((NI) 20))) + ((NI) ((*xX60gensym902_).Sup.itemId.item)));
					xX60gensym903_ = s;
					T21_.Field1 = (NI)((NI)((NU32)(((NI) ((*xX60gensym903_).Sup.itemId.module))) << (NU32)(((NI) 20))) + ((NI) ((*xX60gensym903_).Sup.itemId.item)));
					T16_ = contains__sigmatch_5788((*c).exportIndirections, T21_);
					LA20_: ;
					if (!T16_) goto LA22_;
					del__sigmatch_6088((&(*c).unusedImports), ((NI) (i)));
				}
				goto LA14_;
				LA22_: ;
				{
					i += ((NI) 1);
				}
				LA14_: ;
			} LA12: ;
		}
	}
	LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, markUsed__sigmatch_85)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf;
	conf = (*(*c).graph).config;
	(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 0)) & 63);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 20));
		if (!(T3_)) goto LA4_;
		T3_ = !(((*s).owner == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
		LA4_: ;
		if (!T3_) goto LA5_;
		(*(*s).owner).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 0)) & 63);
		{
			if (!(((*(*s).owner).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 22))&63U)))!=0)) goto LA9_;
			warnAboutDeprecated__sigmatch_5454(conf, info, s);
		}
		LA9_: ;
	}
	LA5_: ;
	{
		if (!!(((20971520 & (*s).flags) == 0))) goto LA13_;
		{
			if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 22))&63U)))!=0)) goto LA17_;
			{
				NIM_BOOL T21_;
				T21_ = (NIM_BOOL)0;
				T21_ = ((*c).lastTLineInfo.line == info.line);
				if (!(T21_)) goto LA22_;
				T21_ = ((*c).lastTLineInfo.col == info.col);
				LA22_: ;
				if (!!(T21_)) goto LA23_;
				warnAboutDeprecated__sigmatch_5454(conf, info, s);
				(*c).lastTLineInfo = info;
			}
			LA23_: ;
		}
		LA17_: ;
		{
			if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 24))&63U)))!=0)) goto LA27_;
			userError__sigmatch_5487(conf, info, s);
		}
		LA27_: ;
	}
	LA13_: ;
	{
		NIM_BOOL T31_;
		NIM_BOOL T32_;
		NIM_BOOL T33_;
		NIM_BOOL T34_;
		NIM_BOOL T35_;
		T31_ = (NIM_BOOL)0;
		T32_ = (NIM_BOOL)0;
		T33_ = (NIM_BOOL)0;
		T34_ = (NIM_BOOL)0;
		T35_ = (NIM_BOOL)0;
		T35_ = !(((49152 & (*(*(*c).graph).config).globalOptions) == 0));
		if (!(T35_)) goto LA36_;
		T35_ = (((*(*(*c).graph).config).notes[(NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 91)- 17))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 91)- 17))&7U)))!=0);
		LA36_: ;
		T34_ = T35_;
		if (!(T34_)) goto LA37_;
		T34_ = belongsToProjectPackage__packages_50((*(*c).graph).config, s);
		LA37_: ;
		T33_ = T34_;
		if (!(T33_)) goto LA38_;
		T33_ = !(((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 5)));
		LA38_: ;
		T32_ = T33_;
		if (!(T32_)) goto LA39_;
		T32_ = ((Letters__linter_12[(NU)(((NU8)((*(*s).name).s->data[((NI) 0)])))>>3] &(1U<<((NU)(((NU8)((*(*s).name).s->data[((NI) 0)])))&7U)))!=0);
		LA39_: ;
		T31_ = T32_;
		if (!(T31_)) goto LA40_;
		T31_ = !((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 34))&63U)))!=0));
		LA40_: ;
		if (!T31_) goto LA41_;
		styleCheckUseImpl__linter_158((*(*c).graph).config, info, s);
	}
	LA41_: ;
	markOwnerModuleAsUsed__sigmatch_89(c, s);
}
static N_INLINE(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newDeref__lowerings_11)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = newNodeIT__ast_3342(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65), (*n).info, (*(*n).typ).sons->data[((NI) 0)]);
	add__ast_4798(result, n);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, userConvMatch__sigmatch_3123)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
{	result = NIM_NIL;
	result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = ((*c).converters ? (*c).converters->Sup.len : 0);
		colontmp_ = T2_;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				{
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* src;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* dest;
					tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA srca;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
					NIM_BOOL destIsGeneric;
					tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA fdest;
					src = (*(*(*c).converters->data[i]).typ).sons->data[((NI) 1)];
					dest = (*(*(*c).converters->data[i]).typ).sons->data[((NI) 0)];
					srca = typeRel__sigmatch_202(m, src, a, 0);
					{
						if (!!(((1288 &((NU16)1<<((NU)(srca)&15U)))!=0))) goto LA8_;
						goto LA5;
					}
					LA8_: ;
					constraint = (*(*(*(*(*(*c).converters->data[i]).typ).n)._kind_6.sons->data[((NI) 1)])._kind_4.sym).constraint;
					{
						NIM_BOOL T12_;
						NIM_BOOL T14_;
						T12_ = (NIM_BOOL)0;
						T12_ = !((constraint == 0));
						if (!(T12_)) goto LA13_;
						T14_ = (NIM_BOOL)0;
						T14_ = matchNodeKinds__parampatterns_505(constraint, arg);
						T12_ = !(T14_);
						LA13_: ;
						if (!T12_) goto LA15_;
						goto LA5;
					}
					LA15_: ;
					{
						NIM_BOOL T19_;
						NIM_BOOL T21_;
						T19_ = (NIM_BOOL)0;
						T19_ = ((*src).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*src).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47));
						if (!(T19_)) goto LA20_;
						T21_ = (NIM_BOOL)0;
						T21_ = isLValue__sigmatch_3118(c, arg);
						T19_ = !(T21_);
						LA20_: ;
						if (!T19_) goto LA22_;
						goto LA5;
					}
					LA22_: ;
					destIsGeneric = containsGenericType__types_3406(dest);
					{
						if (!destIsGeneric) goto LA26_;
						dest = generateTypeInstance__semtypinst_1086(c, (*m).bindings, (*arg).info, dest);
					}
					LA26_: ;
					fdest = typeRel__sigmatch_202(m, f, dest, 0);
					{
						NIM_BOOL T30_;
						NIM_BOOL T32_;
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* s;
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* param;
						T30_ = (NIM_BOOL)0;
						T30_ = ((1280 &((NU16)1<<((NU)(fdest)&15U)))!=0);
						if (!(T30_)) goto LA31_;
						T32_ = (NIM_BOOL)0;
						T32_ = ((*dest).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47));
						if (!(T32_)) goto LA33_;
						T32_ = ((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23));
						LA33_: ;
						T30_ = !(T32_);
						LA31_: ;
						if (!T30_) goto LA34_;
						markUsed__sigmatch_85(c, (*arg).info, (*c).converters->data[i]);
						s = newSymNode__ast_3704((*c).converters->data[i]);
						asgnRef((void**) (&(*s).typ), (*(*c).converters->data[i]).typ);
						(*s).info = (*arg).info;
						result = newNodeIT__ast_3342(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32), (*arg).info, dest);
						add__ast_4798(result, s);
						param = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
						{
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T40_;
							if (!(srca == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 3))) goto LA38_;
							T40_ = NIM_NIL;
							T40_ = copyTree__ast_4432(arg);
							param = implicitConv__sigmatch_3095(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59), src, T40_, (&(*m)), c);
						}
						goto LA36_;
						LA38_: ;
						{
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T44_;
							if (!((*src).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23))) goto LA42_;
							param = newNodeIT__ast_3342(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64), (*arg).info, (*(*s).typ).sons->data[((NI) 1)]);
							T44_ = NIM_NIL;
							T44_ = copyTree__ast_4432(arg);
							add__ast_4798(param, T44_);
						}
						goto LA36_;
						LA42_: ;
						{
							param = copyTree__ast_4432(arg);
						}
						LA36_: ;
						add__ast_4798(result, param);
						{
							if (!((*dest).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*dest).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47))) goto LA48_;
							(*dest).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 20)) & 63);
							result = newDeref__lowerings_11(result);
						}
						LA48_: ;
						(*m).convMatches += ((NI) 1);
						{
							NIM_BOOL T54_;
							if (!!((*m).genericConverter)) goto LA52_;
							T54_ = (NIM_BOOL)0;
							T54_ = (srca == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8));
							if (T54_) goto LA55_;
							T54_ = destIsGeneric;
							LA55_: ;
							(*m).genericConverter = T54_;
						}
						LA52_: ;
						goto BeforeRet_;
					}
					LA34_: ;
				} LA5: ;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, localConvMatch__sigmatch_3209)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* call;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T11_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T12_;
{	result = NIM_NIL;
	{
		if (!((*arg).typ == 0)) goto LA3_;
		result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = (f == (*arg).typ);
		if (!(T7_)) goto LA8_;
		T7_ = ((*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58));
		LA8_: ;
		if (!T7_) goto LA9_;
		result = arg;
		goto BeforeRet_;
	}
	LA9_: ;
	call = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27), (*arg).info);
	T11_ = NIM_NIL;
	T11_ = copyTree__ast_4432((*f).n);
	add__ast_4798(call, T11_);
	T12_ = NIM_NIL;
	T12_ = copyTree__ast_4432(arg);
	add__ast_4798(call, T12_);
	result = (*c).semTryExpr(c, call, 131072);
	{
		tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA r;
		if (!!((result == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA15_;
		{
			if (!((*result).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA19_;
			result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
			goto BeforeRet_;
		}
		LA19_: ;
		result = (*c).semExpr(c, call, 0, ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
		r = typeRel__sigmatch_202(m, (*f).sons->data[((NI) 0)], (*result).typ, 0);
		{
			if (!(r < ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8))) goto LA23_;
			result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
			goto BeforeRet_;
		}
		LA23_: ;
		{
			if (!((*result).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27))) goto LA27_;
			transitionSonsKind__ast_4347(result, ((tyEnum_TNodeKind__jsmc0lvQl44MLrOvpRmgJQ) 32));
		}
		LA27_: ;
		(*m).convMatches += ((NI) 1);
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T33_;
			if (!(r == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8))) goto LA31_;
			T33_ = NIM_NIL;
			T33_ = base__types_63(f);
			asgnRef((void**) (&(*result).typ), getInstantiatedType__sigmatch_3081(c, arg, (&(*m)), T33_));
		}
		LA31_: ;
		(*m).baseTypeMatch = NIM_TRUE;
	}
	LA15_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, paramTypesMatchAux__sigmatch_3296)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* argSemantized, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* argOrig) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* fMaybeStatic;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a_2;
	tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c;
	NI oldInheritancePenalty;
	tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA r;
	NI bothMetaCounter;
	NI lastBindingsLength;
{	result = NIM_NIL;
	fMaybeStatic = skipTypes__ast_3723(f, TM__wjrA09aH0rT1R7zbrcCaROw_13);
	arg = argSemantized;
	a_2 = a;
	c = (*m).c;
	{
		if (!(((*fMaybeStatic).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 24))&63U)))!=0)) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = ((*a_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12));
			if (!(T7_)) goto LA8_;
			T7_ = (((*a_2).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 30))&63U)))!=0);
			LA8_: ;
			if (!T7_) goto LA9_;
			assignType__ast_3964(a_2, f);
			result = argSemantized;
			goto BeforeRet_;
		}
		LA9_: ;
		{
			if (!((*a_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60))) goto LA13_;
			{
				NIM_BOOL T17_;
				NIM_BOOL T18_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T23_;
				T17_ = (NIM_BOOL)0;
				T18_ = (NIM_BOOL)0;
				T18_ = ((*(*m).callee).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 10));
				if (!(T18_)) goto LA19_;
				T18_ = ((*a_2).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
				LA19_: ;
				T17_ = T18_;
				if (!(T17_)) goto LA20_;
				T17_ = !((((*a_2).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 25))&63U)))!=0));
				LA20_: ;
				if (!T17_) goto LA21_;
				T23_ = NIM_NIL;
				T23_ = makeTypeFromExpr__semdata_834(c, arg);
				result = newNodeIT__ast_3342(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 4), (*argOrig).info, T23_);
				goto BeforeRet_;
			}
			LA21_: ;
		}
		goto LA11_;
		LA13_: ;
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* evaluated;
			evaluated = (*c).semTryConstExpr(c, arg, ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
				if (!!((evaluated == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA27_;
				typ = newTypeS__semdata_763(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60), c);
				if ((*typ).sons) { nimGCunrefNoCycle((*typ).sons); (*typ).sons = NIM_NIL; }
				(*typ).sons = (tySequence__vKogasEnJSPhbQmA8r4Y9aA*) newSeqRC1((&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_), 1);
				asgnRef((void**) (&(*typ).sons->data[0]), (*evaluated).typ);
				asgnRef((void**) (&(*typ).n), evaluated);
				arg = copyTree__ast_4432(arg);
				asgnRef((void**) (&(*arg).typ), typ);
				a_2 = typ;
			}
			goto LA25_;
			LA27_: ;
			{
				{
					if (!((*(*m).callee).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 10))) goto LA32_;
					{
						NIM_BOOL T36_;
						tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T38_;
						tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA T39_;
						T36_ = (NIM_BOOL)0;
						T36_ = ((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60));
						if (!(T36_)) goto LA37_;
						T38_ = NIM_NIL;
						T38_ = base__types_63(f);
						T39_ = (tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA)0;
						T39_ = typeRel__sigmatch_202(m, T38_, a_2, 0);
						T36_ = !((T39_ == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0)));
						LA37_: ;
						if (!T36_) goto LA40_;
						result = makeStaticExpr__semdata_856((*m).c, arg);
						(*(*result).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 9)) & 63);
						asgnRef((void**) (&(*(*result).typ).n), arg);
						goto BeforeRet_;
					}
					LA40_: ;
				}
				LA32_: ;
			}
			LA25_: ;
		}
		LA11_: ;
	}
	LA3_: ;
	oldInheritancePenalty = (*m).inheritancePenalty;
	r = typeRel__sigmatch_202(m, f, a_2, 0);
	{
		NIM_BOOL T44_;
		NIM_BOOL T45_;
		T44_ = (NIM_BOOL)0;
		T45_ = (NIM_BOOL)0;
		T45_ = !((r == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0)));
		if (!(T45_)) goto LA46_;
		T45_ = !(((*m).calleeSym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
		LA46_: ;
		T44_ = T45_;
		if (!(T44_)) goto LA47_;
		T44_ = ((393216 &((NU32)1<<((NU)((*(*m).calleeSym).kind)&31U)))!=0);
		LA47_: ;
		if (!T44_) goto LA48_;
		incMatches__sigmatch_3266(m, r, ((NI) 1));
		{
			if (!((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 7))) goto LA52_;
			result = arg;
			goto BeforeRet_;
		}
		goto LA50_;
		LA52_: ;
		{
			if (!((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8))) goto LA55_;
			result = arg;
			goto BeforeRet_;
		}
		goto LA50_;
		LA55_: ;
		{
			NIM_BOOL T58_;
			T58_ = (NIM_BOOL)0;
			T58_ = ((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60));
			if (!(T58_)) goto LA59_;
			T58_ = !(((*(*arg).typ).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
			LA59_: ;
			if (!T58_) goto LA60_;
			result = (*(*arg).typ).n;
			goto BeforeRet_;
		}
		goto LA50_;
		LA60_: ;
		{
			result = argSemantized;
			goto BeforeRet_;
		}
		LA50_: ;
	}
	LA48_: ;
	bothMetaCounter = ((NI) 0);
	lastBindingsLength = ((NI) -1);
	{
		while (1) {
			NIM_BOOL T65_;
			NIM_BOOL T66_;
			T65_ = (NIM_BOOL)0;
			T66_ = (NIM_BOOL)0;
			T66_ = (r == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 5));
			if (!(T66_)) goto LA67_;
			T66_ = !((lastBindingsLength == (*m).bindings.counter));
			LA67_: ;
			T65_ = T66_;
			if (!(T65_)) goto LA68_;
			T65_ = (bothMetaCounter < ((NI) 100));
			LA68_: ;
			if (!T65_) goto LA64;
			lastBindingsLength = (*m).bindings.counter;
			bothMetaCounter += ((NI) 1);
			{
				if (!((*arg).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 51) && (*arg).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 52) || (*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79) || (*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84) || (*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159))) goto LA71_;
				result = (*c).semInferredLambda.ClE_0? (*c).semInferredLambda.ClP_0(c, (*m).bindings, arg, (*c).semInferredLambda.ClE_0):((TM__wjrA09aH0rT1R7zbrcCaROw_47)((*c).semInferredLambda.ClP_0))(c, (*m).bindings, arg);
			}
			goto LA69_;
			LA71_: ;
			{
				if (!!(((*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)))) goto LA74_;
				result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
				goto BeforeRet_;
			}
			goto LA69_;
			LA74_: ;
			{
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* inferred;
				inferred = (*c).semGenerateInstance.ClE_0? (*c).semGenerateInstance.ClP_0(c, (*arg)._kind_4.sym, (*m).bindings, (*arg).info, (*c).semGenerateInstance.ClE_0):((TM__wjrA09aH0rT1R7zbrcCaROw_48)((*c).semGenerateInstance.ClP_0))(c, (*arg)._kind_4.sym, (*m).bindings, (*arg).info);
				result = newSymNode__ast_3707(inferred, (*arg).info);
			}
			LA69_: ;
			(*m).convMatches += ((NI) 1);
			arg = result;
			r = typeRel__sigmatch_202(m, f, (*arg).typ, 0);
		} LA64: ;
	}
	switch (r) {
	case ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 1):
	{
		(*m).convMatches += ((NI) 1);
		result = implicitConv__sigmatch_3095(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58), f, arg, (&(*m)), c);
	}
	break;
	case ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 2):
	{
		(*m).intConvMatches += ((NI) 1);
		result = implicitConv__sigmatch_3095(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58), f, arg, (&(*m)), c);
	}
	break;
	case ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 3):
	{
		(*m).subtypeMatches += ((NI) 1);
		{
			if (!((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8))) goto LA82_;
			result = arg;
		}
		goto LA80_;
		LA82_: ;
		{
			result = implicitConv__sigmatch_3095(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59), f, arg, (&(*m)), c);
		}
		LA80_: ;
	}
	break;
	case ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 4):
	{
		(*m).subtypeMatches += ((NI) 1);
		{
			if (!((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23))) goto LA88_;
			result = arg;
		}
		goto LA86_;
		LA88_: ;
		{
			result = implicitConv__sigmatch_3095(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58), f, arg, (&(*m)), c);
		}
		LA86_: ;
	}
	break;
	case ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 6):
	case ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 7):
	{
		{
			if (!((*arg).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 51) && (*arg).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 52) || (*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79) || (*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84) || (*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159))) goto LA94_;
			result = (*c).semInferredLambda.ClE_0? (*c).semInferredLambda.ClP_0(c, (*m).bindings, arg, (*c).semInferredLambda.ClE_0):((TM__wjrA09aH0rT1R7zbrcCaROw_55)((*c).semInferredLambda.ClP_0))(c, (*m).bindings, arg);
		}
		goto LA92_;
		LA94_: ;
		{
			if (!!(((*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)))) goto LA97_;
			result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
			goto BeforeRet_;
		}
		goto LA92_;
		LA97_: ;
		{
			if (!((393216 &((NU32)1<<((NU)((*(*arg)._kind_4.sym).kind)&31U)))!=0)) goto LA100_;
			result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
			goto BeforeRet_;
		}
		goto LA92_;
		LA100_: ;
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* inferred_2;
			{
				if (!((*(*arg)._kind_4.sym).ast == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA105_;
				result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
				goto BeforeRet_;
			}
			LA105_: ;
			inferred_2 = (*c).semGenerateInstance.ClE_0? (*c).semGenerateInstance.ClP_0(c, (*arg)._kind_4.sym, (*m).bindings, (*arg).info, (*c).semGenerateInstance.ClE_0):((TM__wjrA09aH0rT1R7zbrcCaROw_56)((*c).semGenerateInstance.ClP_0))(c, (*arg)._kind_4.sym, (*m).bindings, (*arg).info);
			result = newSymNode__ast_3707(inferred_2, (*arg).info);
		}
		LA92_: ;
		{
			if (!(r == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 7))) goto LA109_;
			(*m).convMatches += ((NI) 1);
			result = implicitConv__sigmatch_3095(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58), f, result, (&(*m)), c);
		}
		goto LA107_;
		LA109_: ;
		{
			(*m).genericMatches += ((NI) 1);
		}
		LA107_: ;
	}
	break;
	case ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8):
	{
		(*m).genericMatches += ((NI) 1);
		{
			if (!((*arg).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA115_;
			result = arg;
		}
		goto LA113_;
		LA115_: ;
		{
			NIM_BOOL T118_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T119_;
			T118_ = (NIM_BOOL)0;
			T119_ = NIM_NIL;
			T119_ = skipTypes__ast_3723((*arg).typ, TM__wjrA09aH0rT1R7zbrcCaROw_57);
			T118_ = ((*T119_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18));
			if (T118_) goto LA120_;
			T118_ = (oldInheritancePenalty < (*m).inheritancePenalty);
			LA120_: ;
			if (!T118_) goto LA121_;
			result = implicitConv__sigmatch_3095(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59), f, arg, (&(*m)), c);
		}
		goto LA113_;
		LA121_: ;
		{
			NIM_BOOL T124_;
			T124_ = (NIM_BOOL)0;
			T124_ = isEmptyContainer__types_3684((*arg).typ);
			if (!T124_) goto LA125_;
			result = copyTree__ast_4432(arg);
			asgnRef((void**) (&(*result).typ), getInstantiatedType__sigmatch_3081(c, arg, (&(*m)), f));
		}
		goto LA113_;
		LA125_: ;
		{
			result = arg;
		}
		LA113_: ;
	}
	break;
	case ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 5):
	{
		result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
	}
	break;
	case ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 9):
	{
		(*m).intConvMatches += ((NI) 256);
		result = implicitConv__sigmatch_3095(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58), f, arg, (&(*m)), c);
	}
	break;
	case ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ff;
		(*m).exactMatches += ((NI) 1);
		result = arg;
		ff = skipTypes__ast_3723(f, TM__wjrA09aH0rT1R7zbrcCaROw_57);
		{
			NIM_BOOL T133_;
			NIM_BOOL T135_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T137_;
			T133_ = (NIM_BOOL)0;
			T133_ = ((*ff).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18));
			if (T133_) goto LA134_;
			T135_ = (NIM_BOOL)0;
			T135_ = !(((*arg).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
			if (!(T135_)) goto LA136_;
			T137_ = NIM_NIL;
			T137_ = skipTypes__ast_3723((*arg).typ, TM__wjrA09aH0rT1R7zbrcCaROw_57);
			T135_ = ((*T137_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18));
			LA136_: ;
			T133_ = T135_;
			LA134_: ;
			if (!T133_) goto LA138_;
			result = implicitConv__sigmatch_3095(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59), f, arg, (&(*m)), c);
		}
		LA138_: ;
	}
	break;
	case ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0):
	{
		{
			if (!((*a_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 50) || (*a_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 61))) goto LA143_;
			(*m).genericMatches += ((NI) 1);
			(*m).fauxMatch = (*a_2).kind;
			result = arg;
			goto BeforeRet_;
		}
		goto LA141_;
		LA143_: ;
		{
			NIM_BOOL T146_;
			NIM_BOOL T147_;
			NIM_BOOL T149_;
			NIM_BOOL T150_;
			NIM_BOOL T151_;
			NI T153_;
			NIM_BOOL T156_;
			tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* p;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lifted;
			tyArray__iegsN9bf6GqRiWprrJjTAoA T161_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T162_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T163_;
			T146_ = (NIM_BOOL)0;
			T147_ = (NIM_BOOL)0;
			T147_ = ((*a_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 63));
			if (!(T147_)) goto LA148_;
			T149_ = (NIM_BOOL)0;
			T150_ = (NIM_BOOL)0;
			T151_ = (NIM_BOOL)0;
			T151_ = ((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25));
			if (!(T151_)) goto LA152_;
			T153_ = (NI)0;
			T153_ = len__ast_3990(f);
			T151_ = (T153_ == ((NI) 1));
			LA152_: ;
			T150_ = T151_;
			if (!(T150_)) goto LA154_;
			T150_ = ((*f).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
			LA154_: ;
			T149_ = T150_;
			if (T149_) goto LA155_;
			T156_ = (NIM_BOOL)0;
			T156_ = ((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 51));
			if (!(T156_)) goto LA157_;
			T156_ = ((*(*f).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25));
			LA157_: ;
			T149_ = T156_;
			LA155_: ;
			T147_ = T149_;
			LA148_: ;
			T146_ = T147_;
			if (!(T146_)) goto LA158_;
			T146_ = ((*argOrig).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115));
			LA158_: ;
			if (!T146_) goto LA159_;
			p = (*c).graph;
			nimZeroMem((void*)T161_, sizeof(tyArray__iegsN9bf6GqRiWprrJjTAoA));
			T161_[0] = (*p).emptyNode;
			T162_ = NIM_NIL;
			T162_ = newTree__ast_3356(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 76), T161_, 1);
			T163_ = NIM_NIL;
			T163_ = newProcNode__ast_3809(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 52), (*argOrig).info, argOrig, T162_, (*p).emptyNode, (*p).emptyNode, (*p).emptyNode, (*p).emptyNode, (*p).emptyNode);
			lifted = (*c).semExpr(c, T163_, 0, ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
			{
				if (!((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 51))) goto LA166_;
				(*m).genericMatches += ((NI) 1);
				put__sigmatch_120(m, f, (*lifted).typ);
			}
			LA166_: ;
			(*m).convMatches += ((NI) 1);
			result = implicitConv__sigmatch_3095(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58), f, lifted, (&(*m)), c);
			goto BeforeRet_;
		}
		goto LA141_;
		LA159_: ;
		LA141_: ;
		result = userConvMatch__sigmatch_3123(c, m, f, a_2, arg);
		{
			NIM_BOOL T170_;
			T170_ = (NIM_BOOL)0;
			T170_ = (result == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
			if (!(T170_)) goto LA171_;
			T170_ = ((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48));
			LA171_: ;
			if (!T170_) goto LA172_;
			{
				if (!!(((*f).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA176_;
				result = localConvMatch__sigmatch_3209(c, m, f, a_2, arg);
			}
			goto LA174_;
			LA176_: ;
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T179_;
				T179_ = NIM_NIL;
				T179_ = base__types_63(f);
				r = typeRel__sigmatch_202(m, T179_, a_2, 0);
				switch (r) {
				case ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8):
				{
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T181_;
					(*m).convMatches += ((NI) 1);
					result = copyTree__ast_4432(arg);
					T181_ = NIM_NIL;
					T181_ = base__types_63(f);
					asgnRef((void**) (&(*result).typ), getInstantiatedType__sigmatch_3081(c, arg, (&(*m)), T181_));
					(*m).baseTypeMatch = NIM_TRUE;
				}
				break;
				case ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 9):
				{
					(*m).intConvMatches += ((NI) 256);
					result = implicitConv__sigmatch_3095(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58), (*f).sons->data[((NI) 0)], arg, (&(*m)), c);
					(*m).baseTypeMatch = NIM_TRUE;
				}
				break;
				case ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 10):
				{
					(*m).convMatches += ((NI) 1);
					result = copyTree__ast_4432(arg);
					(*m).baseTypeMatch = NIM_TRUE;
				}
				break;
				case ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 3):
				{
					(*m).subtypeMatches += ((NI) 1);
					{
						tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T187_;
						T187_ = NIM_NIL;
						T187_ = base__types_63(f);
						if (!((*T187_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8))) goto LA188_;
						result = arg;
					}
					goto LA185_;
					LA188_: ;
					{
						tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T191_;
						T191_ = NIM_NIL;
						T191_ = base__types_63(f);
						result = implicitConv__sigmatch_3095(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59), T191_, arg, (&(*m)), c);
					}
					LA185_: ;
					(*m).baseTypeMatch = NIM_TRUE;
				}
				break;
				default:
				{
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T193_;
					T193_ = NIM_NIL;
					T193_ = base__types_63(f);
					result = userConvMatch__sigmatch_3123(c, m, T193_, a_2, arg);
					{
						if (!!((result == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA196_;
						(*m).baseTypeMatch = NIM_TRUE;
					}
					LA196_: ;
				}
				break;
				}
			}
			LA174_: ;
		}
		LA172_: ;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, copyCandidate__sigmatch_199)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* a, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* b) {
	unsureAsgnRef((void**) (&(*a).c), (*b).c);
	(*a).exactMatches = (*b).exactMatches;
	(*a).subtypeMatches = (*b).subtypeMatches;
	(*a).convMatches = (*b).convMatches;
	(*a).intConvMatches = (*b).intConvMatches;
	(*a).genericMatches = (*b).genericMatches;
	(*a).state = (*b).state;
	unsureAsgnRef((void**) (&(*a).callee), (*b).callee);
	unsureAsgnRef((void**) (&(*a).calleeSym), (*b).calleeSym);
	unsureAsgnRef((void**) (&(*a).call), copyTree__ast_4432((*b).call));
	(*a).baseTypeMatch = (*b).baseTypeMatch;
	copyIdTable__ast_3589((&(*a).bindings), (*b).bindings);
}
N_LIB_PRIVATE N_NIMCALL(NI, checkGeneric__sigmatch_207)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* a, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* b) {
	NI result;
	tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* aa;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* bb;
	NI winner;
{	result = (NI)0;
	c = (*a).c;
	aa = (*a).callee;
	bb = (*b).callee;
	winner = ((NI) 0);
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI T3_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (NI)0;
		T2_ = len__ast_3990(aa);
		T3_ = (NI)0;
		T3_ = len__ast_3990(bb);
		colontmp_ = ((T2_ <= T3_) ? T2_ : T3_);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw ma;
				tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA tra;
				tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw mb;
				tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA trb;
				if (!(i_2 < colontmp_)) goto LA5;
				i = i_2;
				nimZeroMem((void*)(&ma), sizeof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw));
				newCandidate__sigmatch_195(c, (*bb).sons->data[i], (&ma));
				tra = typeRel__sigmatch_202((&ma), (*bb).sons->data[i], (*aa).sons->data[i], 1);
				nimZeroMem((void*)(&mb), sizeof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw));
				newCandidate__sigmatch_195(c, (*aa).sons->data[i], (&mb));
				trb = typeRel__sigmatch_202((&mb), (*aa).sons->data[i], (*bb).sons->data[i], 1);
				{
					NIM_BOOL T8_;
					T8_ = (NIM_BOOL)0;
					T8_ = (tra == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8));
					if (!(T8_)) goto LA9_;
					T8_ = (trb == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0));
					LA9_: ;
					if (!T8_) goto LA10_;
					{
						if (!(winner == ((NI) -1))) goto LA14_;
						result = ((NI) 0);
						goto BeforeRet_;
					}
					LA14_: ;
					winner = ((NI) 1);
				}
				LA10_: ;
				{
					NIM_BOOL T18_;
					T18_ = (NIM_BOOL)0;
					T18_ = (trb == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 8));
					if (!(T18_)) goto LA19_;
					T18_ = (tra == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0));
					LA19_: ;
					if (!T18_) goto LA20_;
					{
						if (!(winner == ((NI) 1))) goto LA24_;
						result = ((NI) 0);
						goto BeforeRet_;
					}
					LA24_: ;
					winner = ((NI) -1);
				}
				LA20_: ;
				i_2 += ((NI) 1);
			} LA5: ;
		}
	}
	result = winner;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, sumGeneric__sigmatch_261)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	NI result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t_2;
	NI isvar;
{	result = (NI)0;
	t_2 = t;
	isvar = ((NI) 1);
	{
		while (1) {
			switch ((*t_2).kind) {
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 13):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 49):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 19):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 20):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 10):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45):
			{
				t_2 = lastSon__ast_3731(t_2);
				result += ((NI) 1);
			}
			break;
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 57):
			{
				NI maxBranch;
				maxBranch = ((NI) 0);
				{
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA** branch;
					NI i;
					NI L;
					NI T6_;
					branch = (tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA**)0;
					i = ((NI) 0);
					T6_ = ((*t_2).sons ? (*t_2).sons->Sup.len : 0);
					L = T6_;
					{
						while (1) {
							NI branchSum;
							if (!(i < L)) goto LA8;
							branch = &(*t_2).sons->data[i];
							branchSum = sumGeneric__sigmatch_261((*branch));
							{
								if (!(maxBranch < branchSum)) goto LA11_;
								maxBranch = branchSum;
							}
							LA11_: ;
							i += ((NI) 1);
						} LA8: ;
					}
				}
				result += maxBranch;
				goto LA1;
			}
			break;
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23):
			{
				t_2 = (*t_2).sons->data[((NI) 0)];
				result += ((NI) 1);
				isvar += ((NI) 1);
			}
			break;
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8):
			{
				t_2 = lastSon__ast_3731(t_2);
				{
					if (!((*t_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 3))) goto LA17_;
					goto LA1;
				}
				LA17_: ;
				result += ((NI) 1);
			}
			break;
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 9):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 56):
			{
				result += ((*t_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 9) || (*t_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 56));
				{
					NI i_2;
					NI colontmp_;
					NI i_3;
					i_2 = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = len__ast_3990(t_2);
					i_3 = ((NI) 0);
					{
						while (1) {
							if (!(i_3 < colontmp_)) goto LA22;
							i_2 = i_3;
							{
								NI T27_;
								if (!!(((*t_2).sons->data[i_2] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA25_;
								T27_ = (NI)0;
								T27_ = sumGeneric__sigmatch_261((*t_2).sons->data[i_2]);
								result += T27_;
							}
							LA25_: ;
							i_3 += ((NI) 1);
						} LA22: ;
					}
				}
				goto LA1;
			}
			break;
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60):
			{
				NI T29_;
				T29_ = (NI)0;
				T29_ = sumGeneric__sigmatch_261((*t_2).sons->data[((NI) 0)]);
				result = (NI)(T29_ + ((NI) 1));
				goto BeforeRet_;
			}
			break;
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 6):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 7):
			{
				goto LA1;
			}
			break;
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 4):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46):
			{
				t_2 = lastSon__ast_3731(t_2);
			}
			break;
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 26):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 39):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40) ... ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44):
			case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 54):
			{
				result = isvar;
				goto BeforeRet_;
			}
			break;
			default:
			{
				result = ((NI) 0);
				goto BeforeRet_;
			}
			break;
			}
		}
	} LA1: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, complexDisambiguation__sigmatch_336)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* b) {
	NI result;
	NI winner;
{	result = (NI)0;
	winner = ((NI) 0);
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI T3_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (NI)0;
		T2_ = len__ast_3990(a);
		T3_ = (NI)0;
		T3_ = len__ast_3990(b);
		colontmp_ = ((T2_ <= T3_) ? T2_ : T3_);
		i_2 = ((NI) 1);
		{
			while (1) {
				NI x;
				NI y;
				if (!(i_2 < colontmp_)) goto LA5;
				i = i_2;
				x = sumGeneric__sigmatch_261((*a).sons->data[i]);
				y = sumGeneric__sigmatch_261((*b).sons->data[i]);
				{
					if (!!((x == y))) goto LA8_;
					{
						if (!(winner == ((NI) 0))) goto LA12_;
						{
							if (!(y < x)) goto LA16_;
							winner = ((NI) 1);
						}
						goto LA14_;
						LA16_: ;
						{
							winner = ((NI) -1);
						}
						LA14_: ;
					}
					goto LA10_;
					LA12_: ;
					{
						if (!(y < x)) goto LA20_;
						{
							if (!!((winner == ((NI) 1)))) goto LA24_;
							result = ((NI) 0);
							goto BeforeRet_;
						}
						LA24_: ;
					}
					goto LA10_;
					LA20_: ;
					{
						{
							if (!!((winner == ((NI) -1)))) goto LA29_;
							result = ((NI) 0);
							goto BeforeRet_;
						}
						LA29_: ;
					}
					LA10_: ;
				}
				LA8_: ;
				i_2 += ((NI) 1);
			} LA5: ;
		}
	}
	result = winner;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, cmpCandidates__sigmatch_358)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* a, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* b) {
	NI result;
{	result = (NI)0;
	result = (NI)((*a).exactMatches - (*b).exactMatches);
	{
		if (!!((result == ((NI) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	result = (NI)((*a).genericMatches - (*b).genericMatches);
	{
		if (!!((result == ((NI) 0)))) goto LA7_;
		goto BeforeRet_;
	}
	LA7_: ;
	result = (NI)((*a).subtypeMatches - (*b).subtypeMatches);
	{
		if (!!((result == ((NI) 0)))) goto LA11_;
		goto BeforeRet_;
	}
	LA11_: ;
	result = (NI)((*a).intConvMatches - (*b).intConvMatches);
	{
		if (!!((result == ((NI) 0)))) goto LA15_;
		goto BeforeRet_;
	}
	LA15_: ;
	result = (NI)((*a).convMatches - (*b).convMatches);
	{
		if (!!((result == ((NI) 0)))) goto LA19_;
		goto BeforeRet_;
	}
	LA19_: ;
	result = (NI)((*b).inheritancePenalty - (*a).inheritancePenalty);
	{
		if (!!((result == ((NI) 0)))) goto LA23_;
		goto BeforeRet_;
	}
	LA23_: ;
	result = checkGeneric__sigmatch_207(a, b);
	{
		if (!!((result == ((NI) 0)))) goto LA27_;
		goto BeforeRet_;
	}
	LA27_: ;
	result = complexDisambiguation__sigmatch_336((*a).callee, (*b).callee);
	{
		if (!!((result == ((NI) 0)))) goto LA31_;
		goto BeforeRet_;
	}
	LA31_: ;
	result = (NI)((*a).calleeScope - (*b).calleeScope);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, paramTypesMatch__sigmatch_3620)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* argOrig) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (arg == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = !(((*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 56) || (*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 57)));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = paramTypesMatchAux__sigmatch_3296(m, f, a, arg, argOrig);
	}
	goto LA1_;
	LA5_: ;
	{
		tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c;
		tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw x;
		tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw T8_;
		tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw y;
		tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw T9_;
		tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw z;
		tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw T10_;
		NI best;
		c = (*m).c;
		nimZeroMem((void*)(&x), sizeof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw));
		nimZeroMem((void*)(&T8_), sizeof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw));
		newCandidate__sigmatch_195(c, (*m).callee, (&T8_));
		nimCopyMem((void*)(&x), (NIM_CONST void*)(&T8_), sizeof(x));
		nimZeroMem((void*)(&y), sizeof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw));
		nimZeroMem((void*)(&T9_), sizeof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw));
		newCandidate__sigmatch_195(c, (*m).callee, (&T9_));
		nimCopyMem((void*)(&y), (NIM_CONST void*)(&T9_), sizeof(y));
		nimZeroMem((void*)(&z), sizeof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw));
		nimZeroMem((void*)(&T10_), sizeof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw));
		newCandidate__sigmatch_195(c, (*m).callee, (&T10_));
		nimCopyMem((void*)(&z), (NIM_CONST void*)(&T10_), sizeof(z));
		x.calleeSym = (*m).calleeSym;
		y.calleeSym = (*m).calleeSym;
		z.calleeSym = (*m).calleeSym;
		best = ((NI) -1);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(arg);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA13;
					i = i_2;
					{
						{
							tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA r;
							if (!((1568768 &((NU32)1<<((NU)((*(*(*arg)._kind_6.sons->data[i])._kind_4.sym).kind)&31U)))!=0)) goto LA17_;
							copyCandidate__sigmatch_199((&z), (&(*m)));
							z.callee = (*(*arg)._kind_6.sons->data[i]).typ;
							{
								if (!(((*z.callee).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 9))&63U)))!=0)) goto LA21_;
								goto LA14;
							}
							LA21_: ;
							z.calleeSym = (*(*arg)._kind_6.sons->data[i])._kind_4.sym;
							r = typeRel__sigmatch_202((&z), f, (*(*arg)._kind_6.sons->data[i]).typ, 0);
							incMatches__sigmatch_3266((&z), r, ((NI) 2));
							{
								if (!!((r == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0)))) goto LA25_;
								z.state = ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 1);
								switch (x.state) {
								case ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 0):
								case ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 2):
								{
									genericAssign((void*)(&x), (void*)(&z), (&NTItcandidate__9b35s9cLOLunJ2l2Vo3cQTlw_));
									best = i;
								}
								break;
								case ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 1):
								{
									NI cmp;
									cmp = cmpCandidates__sigmatch_358((&x), (&z));
									{
										if (!(cmp < ((NI) 0))) goto LA31_;
										best = i;
										genericAssign((void*)(&x), (void*)(&z), (&NTItcandidate__9b35s9cLOLunJ2l2Vo3cQTlw_));
									}
									goto LA29_;
									LA31_: ;
									{
										if (!(cmp == ((NI) 0))) goto LA34_;
										genericAssign((void*)(&y), (void*)(&z), (&NTItcandidate__9b35s9cLOLunJ2l2Vo3cQTlw_));
									}
									goto LA29_;
									LA34_: ;
									LA29_: ;
								}
								break;
								}
							}
							LA25_: ;
						}
						LA17_: ;
					} LA14: ;
					i_2 += ((NI) 1);
				} LA13: ;
			}
		}
		{
			if (!(x.state == ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 0))) goto LA38_;
			result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
		}
		goto LA36_;
		LA38_: ;
		{
			NIM_BOOL T41_;
			NI T43_;
			T41_ = (NIM_BOOL)0;
			T41_ = (y.state == ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 1));
			if (!(T41_)) goto LA42_;
			T43_ = (NI)0;
			T43_ = cmpCandidates__sigmatch_358((&x), (&y));
			T41_ = (T43_ == ((NI) 0));
			LA42_: ;
			if (!T41_) goto LA44_;
			{
				if (!!((x.state == ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 1)))) goto LA48_;
				internalErrorImpl__msgs_1441((*(*(*m).c).graph).config, (*arg).info, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_77), TM__wjrA09aH0rT1R7zbrcCaROw_78);
			}
			LA48_: ;
			{
				if (!((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 6) || (*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 7))) goto LA52_;
				result = arg;
			}
			goto LA50_;
			LA52_: ;
			{
				result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
			}
			LA50_: ;
		}
		goto LA36_;
		LA44_: ;
		{
			markUsed__sigmatch_85((*m).c, (*arg).info, (*(*arg)._kind_6.sons->data[best])._kind_4.sym);
			result = paramTypesMatchAux__sigmatch_3296(m, f, (*(*arg)._kind_6.sons->data[best]).typ, (*arg)._kind_6.sons->data[best], argOrig);
		}
		LA36_: ;
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI, find__sigmatch_4345)(NI* a, NI aLen_0, NI item) {
	NI result;
{	result = (NI)0;
	result = ((NI) 0);
	{
		NI* i;
		NI i_2;
		i = (NI*)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < aLen_0)) goto LA3;
				i = (&a[i_2]);
				{
					if (!((*i) == item)) goto LA6_;
					goto BeforeRet_;
				}
				LA6_: ;
				result += ((NI) 1);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__sigmatch_4340)(NI* a, NI aLen_0, NI item) {
	NIM_BOOL result;
	NI T1_;
{	result = (NIM_BOOL)0;
	T1_ = (NI)0;
	T1_ = find__sigmatch_4345(a, aLen_0, item);
	result = (((NI) 0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, argtypeMatches__sigmatch_4322)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, NIM_BOOL fromHlo) {
	NIM_BOOL result;
	tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw m;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* res;
	result = (NIM_BOOL)0;
	nimZeroMem((void*)(&m), sizeof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw));
	newCandidate__sigmatch_195(c, f, (&m));
	res = paramTypesMatch__sigmatch_3620((&m), f, a, (*(*c).graph).emptyNode, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
	{
		if (!!(fromHlo)) goto LA3_;
		result = !((res == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T6_;
		NIM_BOOL T7_;
		T6_ = (NIM_BOOL)0;
		T7_ = (NIM_BOOL)0;
		T7_ = !((res == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
		if (!(T7_)) goto LA8_;
		T7_ = (m.convMatches == ((NI) 0));
		LA8_: ;
		T6_ = T7_;
		if (!(T6_)) goto LA9_;
		T6_ = contains__sigmatch_4340(TM__wjrA09aH0rT1R7zbrcCaROw_79, 2, m.intConvMatches);
		LA9_: ;
		result = T6_;
	}
	LA1_: ;
	return result;
}
static N_INLINE(NIM_BOOL, typeFits__sigmatch_5182)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* firstArg) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T6_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = !(((*s).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		if (!(T4_)) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__ast_3990((*s).typ);
		T4_ = (((NI) 1) < T6_);
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA7_;
		T3_ = !(((*(*s).typ).sons->data[((NI) 1)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		LA7_: ;
		if (!T3_) goto LA8_;
		m = getModule__astalgo_216(s);
		{
			NIM_BOOL T12_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* exp_1;
			T12_ = (NIM_BOOL)0;
			T12_ = !((m == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
			if (!(T12_)) goto LA13_;
			T12_ = (((*m).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 15))&63U)))!=0);
			LA13_: ;
			if (!T12_) goto LA14_;
			{
				if (!((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 7))) goto LA18_;
				goto BeforeRet_;
			}
			LA18_: ;
			exp_1 = skipTypes__ast_3723((*(*s).typ).sons->data[((NI) 1)], TM__wjrA09aH0rT1R7zbrcCaROw_10);
			{
				if (!((*exp_1).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48))) goto LA22_;
				exp_1 = elemType__types_263(exp_1);
			}
			LA22_: ;
			{
				if (!((*exp_1).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 6) || (*exp_1).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 7) || (*exp_1).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12) || (*exp_1).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 59))) goto LA26_;
				goto BeforeRet_;
			}
			LA26_: ;
		}
		LA14_: ;
		result = argtypeMatches__sigmatch_4322(c, (*(*s).typ).sons->data[((NI) 1)], firstArg, NIM_FALSE);
	}
	LA8_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, suggestOperations__sigmatch_5223)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tySequence__GR8qmV1kNRcoQ2g76VFy3A** outputs) {
	tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
	info = (*n).info;
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* item;
		NI scopeN;
		NIM_BOOL isLocal;
		NIM_BOOL isLocal_2;
		NI scopeN_2;
		item = NIM_NIL;
		scopeN = (NI)0;
		isLocal = (NIM_BOOL)0;
		isLocal_2 = NIM_TRUE;
		scopeN_2 = ((NI) 0);
		{
			tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope;
			tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* current;
			scope = NIM_NIL;
			current = (*c).currentScope;
			{
				while (1) {
					if (!!((current == ((tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ*) NIM_NIL)))) goto LA4;
					scope = current;
					{
						if (!(scope == (*c).topLevelScope)) goto LA7_;
						isLocal_2 = NIM_FALSE;
					}
					LA7_: ;
					scopeN_2 -= ((NI) 1);
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* item_2;
						tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw it;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
						item_2 = NIM_NIL;
						nimZeroMem((void*)(&it), sizeof(tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw));
						s = initTabIter__astalgo_3770((&it), (*scope).symbols);
						{
							while (1) {
								tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A colontmp_;
								tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* it_2;
								tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ pm;
								if (!!((s == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA11;
								item_2 = s;
								nimZeroMem((void*)(&colontmp_), sizeof(tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A));
								colontmp_.Field0 = item_2;
								colontmp_.Field1 = scopeN_2;
								colontmp_.Field2 = isLocal_2;
								item = colontmp_.Field0;
								scopeN = colontmp_.Field1;
								isLocal = colontmp_.Field2;
								it_2 = item;
								pm = (tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ)0;
								{
									NIM_BOOL T14_;
									NI T18_;
									tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* T19_;
									NI T20_;
									T14_ = (NIM_BOOL)0;
									T14_ = filterSymNoOpr__sigmatch_4964(it_2, f, (&pm));
									if (!(T14_)) goto LA15_;
									T14_ = typeFits__sigmatch_5182(c, it_2, typ);
									LA15_: ;
									if (!T14_) goto LA16_;
									T18_ = (NI)0;
									T18_ = getQuality__sigmatch_5031(it_2);
									T19_ = NIM_NIL;
									T19_ = symToSuggest__sigmatch_4569((*c).graph, it_2, isLocal, ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 1), info, T18_, pm, (((NI) 0) < (*c).inTypeContext), scopeN, NIM_FALSE, ((NU16) 0), ((NI) 0));
									unsureAsgnRef((void**) (&(*outputs)), (tySequence__GR8qmV1kNRcoQ2g76VFy3A*) incrSeqV3((TGenericSeq*)((*outputs)), (&NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_)));
									T20_ = (*outputs)->Sup.len++;
									asgnRef((void**) (&(*outputs)->data[T20_]), T19_);
								}
								LA16_: ;
								s = nextIter__astalgo_3755((&it), (*scope).symbols);
							} LA11: ;
						}
					}
					current = (*current).parent;
				} LA4: ;
			}
		}
		scopeN_2 -= ((NI) 1);
		isLocal_2 = NIM_FALSE;
		{
			tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg* im;
			NI i;
			NI L;
			NI T22_;
			im = (tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg*)0;
			i = ((NI) 0);
			T22_ = ((*c).imports ? (*c).imports->Sup.len : 0);
			L = T22_;
			{
				while (1) {
					if (!(i < L)) goto LA24;
					im = (&(*c).imports->data[i]);
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s_2;
						NIM_BOOL importHidden;
						s_2 = NIM_NIL;
						importHidden = (((*(*im).m).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 27))&31U)))!=0);
						{
							NIM_BOOL T28_;
							tyObject_RodIter__L6nv9cakjPARHk068AFo6ww rodIt;
							tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* r;
							T28_ = (NIM_BOOL)0;
							T28_ = isCachedModule__modulegraphs_2722((*c).graph, (*im).m);
							if (!T28_) goto LA29_;
							nimZeroMem((void*)(&rodIt), sizeof(tyObject_RodIter__L6nv9cakjPARHk068AFo6ww));
							r = initRodIterAllSyms__icZic_8670((&rodIt), (*(*c).graph).config, (*(*c).graph).cache, (&(*(*c).graph).packed_0), ((NI32) ((*(*im).m).position)), importHidden);
							{
								while (1) {
									tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A colontmp__2;
									tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* it_3;
									tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ pm_2;
									if (!!((r == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA32;
									s_2 = r;
									nimZeroMem((void*)(&colontmp__2), sizeof(tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A));
									colontmp__2.Field0 = s_2;
									colontmp__2.Field1 = scopeN_2;
									colontmp__2.Field2 = isLocal_2;
									item = colontmp__2.Field0;
									scopeN = colontmp__2.Field1;
									isLocal = colontmp__2.Field2;
									it_3 = item;
									pm_2 = (tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ)0;
									{
										NIM_BOOL T35_;
										NI T39_;
										tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* T40_;
										NI T41_;
										T35_ = (NIM_BOOL)0;
										T35_ = filterSymNoOpr__sigmatch_4964(it_3, f, (&pm_2));
										if (!(T35_)) goto LA36_;
										T35_ = typeFits__sigmatch_5182(c, it_3, typ);
										LA36_: ;
										if (!T35_) goto LA37_;
										T39_ = (NI)0;
										T39_ = getQuality__sigmatch_5031(it_3);
										T40_ = NIM_NIL;
										T40_ = symToSuggest__sigmatch_4569((*c).graph, it_3, isLocal, ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 1), info, T39_, pm_2, (((NI) 0) < (*c).inTypeContext), scopeN, NIM_FALSE, ((NU16) 0), ((NI) 0));
										unsureAsgnRef((void**) (&(*outputs)), (tySequence__GR8qmV1kNRcoQ2g76VFy3A*) incrSeqV3((TGenericSeq*)((*outputs)), (&NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_)));
										T41_ = (*outputs)->Sup.len++;
										asgnRef((void**) (&(*outputs)->data[T41_]), T40_);
									}
									LA37_: ;
									r = nextRodIter__icZic_8980((&rodIt), (&(*(*c).graph).packed_0));
								} LA32: ;
							}
						}
						goto LA26_;
						LA29_: ;
						{
							{
								tyObject_TSym__3r34mwqcVmg5JFNmiaVncw** s_3;
								tySequence__ed0C0uAUZPhvw3RAc5hfYg* colontmp__3;
								tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* retX60gensym17_;
								NI i_2;
								NI L_2;
								NI T48_;
								s_3 = (tyObject_TSym__3r34mwqcVmg5JFNmiaVncw**)0;
								colontmp__3 = NIM_NIL;
								retX60gensym17_ = (&(*(*c).graph).ifaces->data[(*(*im).m).position].interf);
								{
									if (!importHidden) goto LA46_;
									retX60gensym17_ = (&(*(*c).graph).ifaces->data[(*(*im).m).position].interfHidden);
								}
								LA46_: ;
								colontmp__3 = (*retX60gensym17_).data;
								i_2 = ((NI) 0);
								T48_ = (colontmp__3 ? colontmp__3->Sup.len : 0);
								L_2 = T48_;
								{
									while (1) {
										if (!(i_2 < L_2)) goto LA50;
										s_3 = &colontmp__3->data[i_2];
										{
											tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A colontmp__4;
											tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* it_4;
											tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ pm_3;
											if (!!(((*s_3) == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA53_;
											s_2 = (*s_3);
											nimZeroMem((void*)(&colontmp__4), sizeof(tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A));
											colontmp__4.Field0 = s_2;
											colontmp__4.Field1 = scopeN_2;
											colontmp__4.Field2 = isLocal_2;
											item = colontmp__4.Field0;
											scopeN = colontmp__4.Field1;
											isLocal = colontmp__4.Field2;
											it_4 = item;
											pm_3 = (tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ)0;
											{
												NIM_BOOL T57_;
												NI T61_;
												tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* T62_;
												NI T63_;
												T57_ = (NIM_BOOL)0;
												T57_ = filterSymNoOpr__sigmatch_4964(it_4, f, (&pm_3));
												if (!(T57_)) goto LA58_;
												T57_ = typeFits__sigmatch_5182(c, it_4, typ);
												LA58_: ;
												if (!T57_) goto LA59_;
												T61_ = (NI)0;
												T61_ = getQuality__sigmatch_5031(it_4);
												T62_ = NIM_NIL;
												T62_ = symToSuggest__sigmatch_4569((*c).graph, it_4, isLocal, ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 1), info, T61_, pm_3, (((NI) 0) < (*c).inTypeContext), scopeN, NIM_FALSE, ((NU16) 0), ((NI) 0));
												unsureAsgnRef((void**) (&(*outputs)), (tySequence__GR8qmV1kNRcoQ2g76VFy3A*) incrSeqV3((TGenericSeq*)((*outputs)), (&NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_)));
												T63_ = (*outputs)->Sup.len++;
												asgnRef((void**) (&(*outputs)->data[T63_]), T62_);
											}
											LA59_: ;
										}
										LA53_: ;
										i_2 += ((NI) 1);
									} LA50: ;
								}
							}
						}
						LA26_: ;
					}
					i += ((NI) 1);
				} LA24: ;
			}
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, suggestFieldAccess__sigmatch_5259)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* field, tySequence__GR8qmV1kNRcoQ2g76VFy3A** outputs) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
	tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ pm;
	typ = (*n).typ;
	pm = (tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ)0;
	{
		if (!(typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
			if (!(T7_)) goto LA8_;
			T7_ = ((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6));
			LA8_: ;
			if (!T7_) goto LA9_;
			{
				if (!((*n)._kind_4.sym == (*c).module)) goto LA13_;
				{
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* it;
					tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw it_2;
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
					it = NIM_NIL;
					nimZeroMem((void*)(&it_2), sizeof(tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw));
					s = initTabIter__astalgo_3770((&it_2), (*(*c).topLevelScope).symbols);
					{
						while (1) {
							if (!!((s == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA17;
							it = s;
							{
								NIM_BOOL T20_;
								NI T23_;
								tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* T24_;
								NI T25_;
								T20_ = (NIM_BOOL)0;
								T20_ = filterSym__sigmatch_4938(it, field, (&pm));
								if (!T20_) goto LA21_;
								T23_ = (NI)0;
								T23_ = getQuality__sigmatch_5031(it);
								T24_ = NIM_NIL;
								T24_ = symToSuggest__sigmatch_4569((*c).graph, it, NIM_FALSE, ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 1), (*n).info, T23_, pm, (((NI) 0) < (*c).inTypeContext), ((NI) -99), NIM_FALSE, ((NU16) 0), ((NI) 0));
								unsureAsgnRef((void**) (&(*outputs)), (tySequence__GR8qmV1kNRcoQ2g76VFy3A*) incrSeqV3((TGenericSeq*)((*outputs)), (&NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_)));
								T25_ = (*outputs)->Sup.len++;
								asgnRef((void**) (&(*outputs)->data[T25_]), T24_);
							}
							LA21_: ;
							s = nextIter__astalgo_3755((&it_2), (*(*c).topLevelScope).symbols);
						} LA17: ;
					}
				}
			}
			goto LA11_;
			LA13_: ;
			{
				{
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* it_3;
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* colontmp_;
					NIM_BOOL importHidden;
					it_3 = NIM_NIL;
					colontmp_ = NIM_NIL;
					colontmp_ = (*n)._kind_4.sym;
					importHidden = (((*colontmp_).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 27))&31U)))!=0);
					{
						NIM_BOOL T30_;
						tyObject_RodIter__L6nv9cakjPARHk068AFo6ww rodIt;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* r;
						T30_ = (NIM_BOOL)0;
						T30_ = isCachedModule__modulegraphs_2722((*c).graph, colontmp_);
						if (!T30_) goto LA31_;
						nimZeroMem((void*)(&rodIt), sizeof(tyObject_RodIter__L6nv9cakjPARHk068AFo6ww));
						r = initRodIterAllSyms__icZic_8670((&rodIt), (*(*c).graph).config, (*(*c).graph).cache, (&(*(*c).graph).packed_0), ((NI32) ((*colontmp_).position)), importHidden);
						{
							while (1) {
								if (!!((r == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA34;
								it_3 = r;
								{
									NIM_BOOL T37_;
									NI T40_;
									tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* T41_;
									NI T42_;
									T37_ = (NIM_BOOL)0;
									T37_ = filterSym__sigmatch_4938(it_3, field, (&pm));
									if (!T37_) goto LA38_;
									T40_ = (NI)0;
									T40_ = getQuality__sigmatch_5031(it_3);
									T41_ = NIM_NIL;
									T41_ = symToSuggest__sigmatch_4569((*c).graph, it_3, NIM_FALSE, ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 1), (*n).info, T40_, pm, (((NI) 0) < (*c).inTypeContext), ((NI) -99), NIM_FALSE, ((NU16) 0), ((NI) 0));
									unsureAsgnRef((void**) (&(*outputs)), (tySequence__GR8qmV1kNRcoQ2g76VFy3A*) incrSeqV3((TGenericSeq*)((*outputs)), (&NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_)));
									T42_ = (*outputs)->Sup.len++;
									asgnRef((void**) (&(*outputs)->data[T42_]), T41_);
								}
								LA38_: ;
								r = nextRodIter__icZic_8980((&rodIt), (&(*(*c).graph).packed_0));
							} LA34: ;
						}
					}
					goto LA28_;
					LA31_: ;
					{
						{
							tyObject_TSym__3r34mwqcVmg5JFNmiaVncw** s_2;
							tySequence__ed0C0uAUZPhvw3RAc5hfYg* colontmp__2;
							tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* retX60gensym17_;
							NI i;
							NI L;
							NI T49_;
							s_2 = (tyObject_TSym__3r34mwqcVmg5JFNmiaVncw**)0;
							colontmp__2 = NIM_NIL;
							retX60gensym17_ = (&(*(*c).graph).ifaces->data[(*colontmp_).position].interf);
							{
								if (!importHidden) goto LA47_;
								retX60gensym17_ = (&(*(*c).graph).ifaces->data[(*colontmp_).position].interfHidden);
							}
							LA47_: ;
							colontmp__2 = (*retX60gensym17_).data;
							i = ((NI) 0);
							T49_ = (colontmp__2 ? colontmp__2->Sup.len : 0);
							L = T49_;
							{
								while (1) {
									if (!(i < L)) goto LA51;
									s_2 = &colontmp__2->data[i];
									{
										if (!!(((*s_2) == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA54_;
										it_3 = (*s_2);
										{
											NIM_BOOL T58_;
											NI T61_;
											tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* T62_;
											NI T63_;
											T58_ = (NIM_BOOL)0;
											T58_ = filterSym__sigmatch_4938(it_3, field, (&pm));
											if (!T58_) goto LA59_;
											T61_ = (NI)0;
											T61_ = getQuality__sigmatch_5031(it_3);
											T62_ = NIM_NIL;
											T62_ = symToSuggest__sigmatch_4569((*c).graph, it_3, NIM_FALSE, ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 1), (*n).info, T61_, pm, (((NI) 0) < (*c).inTypeContext), ((NI) -99), NIM_FALSE, ((NU16) 0), ((NI) 0));
											unsureAsgnRef((void**) (&(*outputs)), (tySequence__GR8qmV1kNRcoQ2g76VFy3A*) incrSeqV3((TGenericSeq*)((*outputs)), (&NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_)));
											T63_ = (*outputs)->Sup.len++;
											asgnRef((void**) (&(*outputs)->data[T63_]), T62_);
										}
										LA59_: ;
									}
									LA54_: ;
									i += ((NI) 1);
								} LA51: ;
							}
						}
					}
					LA28_: ;
				}
			}
			LA11_: ;
		}
		goto LA5_;
		LA9_: ;
		{
			suggestEverything__sigmatch_5246(c, n, field, outputs);
		}
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* orig;
		orig = typ;
		typ = skipTypes__ast_3723(orig, TM__wjrA09aH0rT1R7zbrcCaROw_11);
		{
			NIM_BOOL T68_;
			NIM_BOOL T69_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
			T68_ = (NIM_BOOL)0;
			T69_ = (NIM_BOOL)0;
			T69_ = ((*typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14));
			if (!(T69_)) goto LA70_;
			T69_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
			LA70_: ;
			T68_ = T69_;
			if (!(T68_)) goto LA71_;
			T68_ = ((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 7));
			LA71_: ;
			if (!T68_) goto LA72_;
			t = typ;
			{
				while (1) {
					if (!!((t == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA75;
					suggestSymList__sigmatch_5069(c, (*t).n, field, (*n).info, outputs);
					t = (*t).sons->data[((NI) 0)];
				} LA75: ;
			}
		}
		goto LA66_;
		LA72_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t_2;
			if (!((*typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17))) goto LA77_;
			t_2 = typ;
			{
				while (1) {
					suggestObject__sigmatch_5089(c, (*t_2).n, field, (*n).info, outputs);
					{
						if (!((*t_2).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA83_;
						goto LA79;
					}
					LA83_: ;
					t_2 = skipTypes__ast_3723((*t_2).sons->data[((NI) 0)], TM__wjrA09aH0rT1R7zbrcCaROw_12);
				}
			} LA79: ;
		}
		goto LA66_;
		LA77_: ;
		{
			NIM_BOOL T86_;
			T86_ = (NIM_BOOL)0;
			T86_ = ((*typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18));
			if (!(T86_)) goto LA87_;
			T86_ = !(((*typ).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
			LA87_: ;
			if (!T86_) goto LA88_;
			suggestSymList__sigmatch_5069(c, (*typ).n, field, (*n).info, outputs);
		}
		goto LA66_;
		LA88_: ;
		LA66_: ;
		suggestOperations__sigmatch_5223(c, n, field, orig, outputs);
		{
			if (!!((typ == orig))) goto LA92_;
			suggestOperations__sigmatch_5223(c, n, field, typ, outputs);
		}
		LA92_: ;
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, sugExpr__sigmatch_6203)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySequence__GR8qmV1kNRcoQ2g76VFy3A** outputs) {
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* obj;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* prefix;
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45))) goto LA3_;
		obj = safeSemExpr__sigmatch_6197(c, (*n)._kind_6.sons->data[((NI) 0)]);
		{
			NIM_BOOL T7_;
			NIM_BOOL T8_;
			NI T9_;
			T7_ = (NIM_BOOL)0;
			T8_ = (NIM_BOOL)0;
			T9_ = (NI)0;
			T9_ = len__ast_3155(n);
			T8_ = (T9_ == ((NI) 2));
			if (!(T8_)) goto LA10_;
			T8_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).info.line == (*(*n)._kind_6.sons->data[((NI) 0)]).info.line);
			LA10_: ;
			T7_ = T8_;
			if (!(T7_)) goto LA11_;
			T7_ = !((*(*(*c).graph).config).m.trackPosAttached);
			LA11_: ;
			if (!T7_) goto LA12_;
			prefix = (*n)._kind_6.sons->data[((NI) 1)];
		}
		goto LA5_;
		LA12_: ;
		{
			prefix = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
		}
		LA5_: ;
		suggestFieldAccess__sigmatch_5259(c, obj, prefix, outputs);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* prefix_2;
		tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2))) goto LA16_;
		{
			if (!(*(*(*c).graph).config).m.trackPosAttached) goto LA20_;
			prefix_2 = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
		}
		goto LA18_;
		LA20_: ;
		{
			prefix_2 = n;
		}
		LA18_: ;
		info = (*n).info;
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* item;
			NI scopeN;
			NIM_BOOL isLocal;
			NIM_BOOL isLocal_2;
			NI scopeN_2;
			item = NIM_NIL;
			scopeN = (NI)0;
			isLocal = (NIM_BOOL)0;
			isLocal_2 = NIM_TRUE;
			scopeN_2 = ((NI) 0);
			{
				tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope;
				tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* current;
				scope = NIM_NIL;
				current = (*c).currentScope;
				{
					while (1) {
						if (!!((current == ((tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ*) NIM_NIL)))) goto LA26;
						scope = current;
						{
							if (!(scope == (*c).topLevelScope)) goto LA29_;
							isLocal_2 = NIM_FALSE;
						}
						LA29_: ;
						scopeN_2 -= ((NI) 1);
						{
							tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* item_2;
							tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw it;
							tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
							item_2 = NIM_NIL;
							nimZeroMem((void*)(&it), sizeof(tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw));
							s = initTabIter__astalgo_3770((&it), (*scope).symbols);
							{
								while (1) {
									tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A colontmp_;
									tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* it_2;
									tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ pm;
									if (!!((s == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA33;
									item_2 = s;
									nimZeroMem((void*)(&colontmp_), sizeof(tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A));
									colontmp_.Field0 = item_2;
									colontmp_.Field1 = scopeN_2;
									colontmp_.Field2 = isLocal_2;
									item = colontmp_.Field0;
									scopeN = colontmp_.Field1;
									isLocal = colontmp_.Field2;
									it_2 = item;
									pm = (tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ)0;
									{
										NIM_BOOL T36_;
										NI T39_;
										tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* T40_;
										NI T41_;
										T36_ = (NIM_BOOL)0;
										T36_ = filterSym__sigmatch_4938(it_2, prefix_2, (&pm));
										if (!T36_) goto LA37_;
										T39_ = (NI)0;
										T39_ = getQuality__sigmatch_5031(it_2);
										T40_ = NIM_NIL;
										T40_ = symToSuggest__sigmatch_4569((*c).graph, it_2, isLocal, ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 1), info, T39_, pm, (((NI) 0) < (*c).inTypeContext), scopeN, NIM_FALSE, ((NU16) 0), ((NI) 0));
										unsureAsgnRef((void**) (&(*outputs)), (tySequence__GR8qmV1kNRcoQ2g76VFy3A*) incrSeqV3((TGenericSeq*)((*outputs)), (&NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_)));
										T41_ = (*outputs)->Sup.len++;
										asgnRef((void**) (&(*outputs)->data[T41_]), T40_);
									}
									LA37_: ;
									s = nextIter__astalgo_3755((&it), (*scope).symbols);
								} LA33: ;
							}
						}
						current = (*current).parent;
					} LA26: ;
				}
			}
			scopeN_2 -= ((NI) 1);
			isLocal_2 = NIM_FALSE;
			{
				tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg* im;
				NI i;
				NI L;
				NI T43_;
				im = (tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg*)0;
				i = ((NI) 0);
				T43_ = ((*c).imports ? (*c).imports->Sup.len : 0);
				L = T43_;
				{
					while (1) {
						if (!(i < L)) goto LA45;
						im = (&(*c).imports->data[i]);
						{
							tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s_2;
							NIM_BOOL importHidden;
							s_2 = NIM_NIL;
							importHidden = (((*(*im).m).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 27))&31U)))!=0);
							{
								NIM_BOOL T49_;
								tyObject_RodIter__L6nv9cakjPARHk068AFo6ww rodIt;
								tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* r;
								T49_ = (NIM_BOOL)0;
								T49_ = isCachedModule__modulegraphs_2722((*c).graph, (*im).m);
								if (!T49_) goto LA50_;
								nimZeroMem((void*)(&rodIt), sizeof(tyObject_RodIter__L6nv9cakjPARHk068AFo6ww));
								r = initRodIterAllSyms__icZic_8670((&rodIt), (*(*c).graph).config, (*(*c).graph).cache, (&(*(*c).graph).packed_0), ((NI32) ((*(*im).m).position)), importHidden);
								{
									while (1) {
										tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A colontmp__2;
										tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* it_3;
										tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ pm_2;
										if (!!((r == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA53;
										s_2 = r;
										nimZeroMem((void*)(&colontmp__2), sizeof(tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A));
										colontmp__2.Field0 = s_2;
										colontmp__2.Field1 = scopeN_2;
										colontmp__2.Field2 = isLocal_2;
										item = colontmp__2.Field0;
										scopeN = colontmp__2.Field1;
										isLocal = colontmp__2.Field2;
										it_3 = item;
										pm_2 = (tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ)0;
										{
											NIM_BOOL T56_;
											NI T59_;
											tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* T60_;
											NI T61_;
											T56_ = (NIM_BOOL)0;
											T56_ = filterSym__sigmatch_4938(it_3, prefix_2, (&pm_2));
											if (!T56_) goto LA57_;
											T59_ = (NI)0;
											T59_ = getQuality__sigmatch_5031(it_3);
											T60_ = NIM_NIL;
											T60_ = symToSuggest__sigmatch_4569((*c).graph, it_3, isLocal, ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 1), info, T59_, pm_2, (((NI) 0) < (*c).inTypeContext), scopeN, NIM_FALSE, ((NU16) 0), ((NI) 0));
											unsureAsgnRef((void**) (&(*outputs)), (tySequence__GR8qmV1kNRcoQ2g76VFy3A*) incrSeqV3((TGenericSeq*)((*outputs)), (&NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_)));
											T61_ = (*outputs)->Sup.len++;
											asgnRef((void**) (&(*outputs)->data[T61_]), T60_);
										}
										LA57_: ;
										r = nextRodIter__icZic_8980((&rodIt), (&(*(*c).graph).packed_0));
									} LA53: ;
								}
							}
							goto LA47_;
							LA50_: ;
							{
								{
									tyObject_TSym__3r34mwqcVmg5JFNmiaVncw** s_3;
									tySequence__ed0C0uAUZPhvw3RAc5hfYg* colontmp__3;
									tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* retX60gensym17_;
									NI i_2;
									NI L_2;
									NI T68_;
									s_3 = (tyObject_TSym__3r34mwqcVmg5JFNmiaVncw**)0;
									colontmp__3 = NIM_NIL;
									retX60gensym17_ = (&(*(*c).graph).ifaces->data[(*(*im).m).position].interf);
									{
										if (!importHidden) goto LA66_;
										retX60gensym17_ = (&(*(*c).graph).ifaces->data[(*(*im).m).position].interfHidden);
									}
									LA66_: ;
									colontmp__3 = (*retX60gensym17_).data;
									i_2 = ((NI) 0);
									T68_ = (colontmp__3 ? colontmp__3->Sup.len : 0);
									L_2 = T68_;
									{
										while (1) {
											if (!(i_2 < L_2)) goto LA70;
											s_3 = &colontmp__3->data[i_2];
											{
												tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A colontmp__4;
												tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* it_4;
												tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ pm_3;
												if (!!(((*s_3) == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA73_;
												s_2 = (*s_3);
												nimZeroMem((void*)(&colontmp__4), sizeof(tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A));
												colontmp__4.Field0 = s_2;
												colontmp__4.Field1 = scopeN_2;
												colontmp__4.Field2 = isLocal_2;
												item = colontmp__4.Field0;
												scopeN = colontmp__4.Field1;
												isLocal = colontmp__4.Field2;
												it_4 = item;
												pm_3 = (tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ)0;
												{
													NIM_BOOL T77_;
													NI T80_;
													tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* T81_;
													NI T82_;
													T77_ = (NIM_BOOL)0;
													T77_ = filterSym__sigmatch_4938(it_4, prefix_2, (&pm_3));
													if (!T77_) goto LA78_;
													T80_ = (NI)0;
													T80_ = getQuality__sigmatch_5031(it_4);
													T81_ = NIM_NIL;
													T81_ = symToSuggest__sigmatch_4569((*c).graph, it_4, isLocal, ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 1), info, T80_, pm_3, (((NI) 0) < (*c).inTypeContext), scopeN, NIM_FALSE, ((NU16) 0), ((NI) 0));
													unsureAsgnRef((void**) (&(*outputs)), (tySequence__GR8qmV1kNRcoQ2g76VFy3A*) incrSeqV3((TGenericSeq*)((*outputs)), (&NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_)));
													T82_ = (*outputs)->Sup.len++;
													asgnRef((void**) (&(*outputs)->data[T82_]), T81_);
												}
												LA78_: ;
											}
											LA73_: ;
											i_2 += ((NI) 1);
										} LA70: ;
									}
								}
							}
							LA47_: ;
						}
						i += ((NI) 1);
					} LA45: ;
				}
			}
		}
	}
	goto LA1_;
	LA16_: ;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* prefix_3;
		{
			if (!(*(*(*c).graph).config).m.trackPosAttached) goto LA86_;
			prefix_3 = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
		}
		goto LA84_;
		LA86_: ;
		{
			prefix_3 = n;
		}
		LA84_: ;
		suggestEverything__sigmatch_5246(c, n, prefix_3, outputs);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nameFits__sigmatch_5120)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* op;
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* opr;
{	result = (NIM_BOOL)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32))) goto LA3_;
		op = (*n)._kind_6.sons->data[((NI) 0)];
	}
	goto LA1_;
	LA3_: ;
	{
		op = n;
	}
	LA1_: ;
	{
		if (!((*op).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 57) || (*op).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 56))) goto LA8_;
		op = (*op)._kind_6.sons->data[((NI) 0)];
	}
	LA8_: ;
	{
		if (!((*op).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45))) goto LA12_;
		op = (*op)._kind_6.sons->data[((NI) 1)];
	}
	LA12_: ;
	opr = NIM_NIL;
	switch ((*op).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		opr = (*(*op)._kind_4.sym).name;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	{
		opr = (*op)._kind_5.ident;
	}
	break;
	default:
	{
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	break;
	}
	result = ((*opr).id == (*(*s).name).id);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initCandidate__sigmatch_124)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* ctx, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* callee, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* binding, NI calleeScope, NIM_BOOL diagnosticsEnabled) {
	initCandidateAux__sigmatch_94(ctx, c, (*callee).typ);
	unsureAsgnRef((void**) (&(*c).calleeSym), callee);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((520192 &((NU32)1<<((NU)((*callee).kind)&31U)))!=0);
		if (!(T3_)) goto LA4_;
		T3_ = (calleeScope == ((NI) -1));
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T9_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
			T9_ = NIM_NIL;
			T9_ = originatingModule__ast_4670(callee);
			if (!(T9_ == (*ctx).module)) goto LA10_;
			(*c).calleeScope = ((NI) 2);
			owner = callee;
			{
				while (1) {
					owner = skipGenericOwner__ast_4659(owner);
					{
						if (!((*owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6))) goto LA16_;
						goto LA12;
					}
					LA16_: ;
					(*c).calleeScope += ((NI) 1);
				}
			} LA12: ;
		}
		goto LA7_;
		LA10_: ;
		{
			(*c).calleeScope = ((NI) 1);
		}
		LA7_: ;
	}
	goto LA1_;
	LA5_: ;
	{
		(*c).calleeScope = calleeScope;
	}
	LA1_: ;
	unsureAsgnRef((void**) (&(*c).diagnostics), NIM_NIL);
	(*c).diagnosticsEnabled = diagnosticsEnabled;
	(*c).magic = (*(*c).calleeSym).magic;
	initIdTable__ast_4084((&(*c).bindings));
	{
		NIM_BOOL T22_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* typeParams;
		T22_ = (NIM_BOOL)0;
		T22_ = !((binding == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
		if (!(T22_)) goto LA23_;
		T22_ = ((520192 &((NU32)1<<((NU)((*callee).kind)&31U)))!=0);
		LA23_: ;
		if (!T22_) goto LA24_;
		typeParams = (*(*callee).ast)._kind_6.sons->data[((NI) 2)];
		{
			NI i;
			NI colontmp_;
			NI T27_;
			NI T28_;
			NI res;
			i = (NI)0;
			colontmp_ = (NI)0;
			T27_ = (NI)0;
			T27_ = len__ast_3155(typeParams);
			T28_ = (NI)0;
			T28_ = len__ast_3155(binding);
			colontmp_ = ((T27_ <= (NI)(T28_ - ((NI) 1))) ? T27_ : (NI)(T28_ - ((NI) 1)));
			res = ((NI) 1);
			{
				while (1) {
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formalTypeParam;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* bound;
					if (!(res <= colontmp_)) goto LA30;
					i = res;
					formalTypeParam = (*(*typeParams)._kind_6.sons->data[(NI)(i - ((NI) 1))]).typ;
					bound = (*(*binding)._kind_6.sons->data[i]).typ;
					{
						if (!!((bound == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA33_;
						{
							if (!((*formalTypeParam).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8))) goto LA37_;
							{
								if (!!(((*bound).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8)))) goto LA41_;
								bound = makeTypeDesc__concepts_49(ctx, bound);
							}
							LA41_: ;
						}
						goto LA35_;
						LA37_: ;
						{
							bound = skipTypes__ast_3723(bound, TM__wjrA09aH0rT1R7zbrcCaROw_14);
						}
						LA35_: ;
						put__sigmatch_120(c, formalTypeParam, bound);
					}
					LA33_: ;
					res += ((NI) 1);
				} LA30: ;
			}
		}
	}
	LA24_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newCandidate__sigmatch_189)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* ctx, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* callee, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* binding, NI calleeScope, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* Result) {
	unsureAsgnRef((void**)&(*Result).c, NIM_NIL);
	(*Result).exactMatches = 0;
	(*Result).genericMatches = 0;
	(*Result).subtypeMatches = 0;
	(*Result).intConvMatches = 0;
	(*Result).convMatches = 0;
	(*Result).state = 0;
	unsureAsgnRef((void**)&(*Result).callee, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).calleeSym, NIM_NIL);
	(*Result).calleeScope = 0;
	unsureAsgnRef((void**)&(*Result).call, NIM_NIL);
	(*Result).bindings.counter = 0;
	unsureAsgnRef((void**)&(*Result).bindings.data, NIM_NIL);
	(*Result).magic = 0;
	(*Result).baseTypeMatch = 0;
	(*Result).fauxMatch = 0;
	(*Result).genericConverter = 0;
	(*Result).coerceDistincts = 0;
	(*Result).typedescMatched = 0;
	(*Result).isNoCall = 0;
	unsureAsgnRef((void**)&(*Result).inferredTypes, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).diagnostics, NIM_NIL);
	(*Result).inheritancePenalty = 0;
	(*Result).firstMismatch.kind = 0;
	(*Result).firstMismatch.arg = 0;
	unsureAsgnRef((void**)&(*Result).firstMismatch.formal, NIM_NIL);
	(*Result).diagnosticsEnabled = 0;
	initCandidate__sigmatch_124(ctx, Result, callee, binding, calleeScope, NIM_FALSE);
}
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result) {
	initPackedSet__pureZcollectionsZintsets_16(Result);
}
N_LIB_PRIVATE N_NIMCALL(NI, findFirstArgBlock__sigmatch_3783)(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	result = ((NI) 2147483647);
	{
		NI a2;
		NI colontmp_;
		NI T2_;
		NI res;
		a2 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (NI)0;
		T2_ = len__ast_3155(n);
		colontmp_ = (NI)(T2_ - ((NI) 1));
		res = colontmp_;
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* formalLast;
				NI T9_;
				NI T10_;
				if (!(((NI) 0) <= res)) goto LA4;
				a2 = res;
				{
					if (!!(((*(*n)._kind_6.sons->data[a2]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115)))) goto LA7_;
					goto LA1;
				}
				LA7_: ;
				T9_ = (NI)0;
				T9_ = len__ast_3155((*(*m).callee).n);
				T10_ = (NI)0;
				T10_ = len__ast_3155(n);
				formalLast = (*(*(*m).callee).n)._kind_6.sons->data[(NI)(T9_ - (NI)(T10_ - a2))];
				{
					NIM_BOOL T13_;
					NIM_BOOL T14_;
					T13_ = (NIM_BOOL)0;
					T14_ = (NIM_BOOL)0;
					T14_ = ((*formalLast).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
					if (!(T14_)) goto LA15_;
					T14_ = ((*(*formalLast)._kind_4.sym).ast == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
					LA15_: ;
					T13_ = T14_;
					if (!(T13_)) goto LA16_;
					T13_ = !(((*(*(*formalLast)._kind_4.sym).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 63) || (*(*(*formalLast)._kind_4.sym).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48)));
					LA16_: ;
					if (!T13_) goto LA17_;
					result = a2;
				}
				goto LA11_;
				LA17_: ;
				{
					goto LA1;
				}
				LA11_: ;
				res -= ((NI) 1);
			} LA4: ;
		}
	} LA1: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setSon__sigmatch_3687)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, NI at, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* son) {
	NI oldLen;
	oldLen = len__ast_3155(father);
	{
		if (!(oldLen <= at)) goto LA3_;
		asgnRef((void**) (&(*father)._kind_6.sons), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) setLengthSeqV2(((*father)._kind_6.sons)?&((*father)._kind_6.sons)->Sup:NIM_NIL, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) ((NI)(at + ((NI) 1))))));
	}
	LA3_: ;
	asgnRef((void**) (&(*father)._kind_6.sons->data[at]), son);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, arrayConstr__sigmatch_3762)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T2_;
	result = NIM_NIL;
	result = newTypeS__semdata_763(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16), c);
	T1_ = NIM_NIL;
	T1_ = makeRangeType__semdata_1069(c, IL64(0), IL64(-1), info, ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
	rawAddSon__ast_4276(result, T1_, NIM_TRUE);
	T2_ = NIM_NIL;
	T2_ = newTypeS__semdata_763(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 3), c);
	rawAddSon__ast_4276(result, T2_, NIM_TRUE);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, incrIndexType__sigmatch_3766)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	(*(*(*(*t).sons->data[((NI) 0)]).n)._kind_6.sons->data[((NI) 1)])._kind_1.intVal += ((NI) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, prepareNamedParam__sigmatch_3746)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c) {
	{
		tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
		tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T5_;
		if (!!(((*(*a)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2)))) goto LA3_;
		info = (*(*a)._kind_6.sons->data[((NI) 0)]).info;
		T5_ = NIM_NIL;
		T5_ = considerQuotedIdent__lookups_29(c, (*a)._kind_6.sons->data[((NI) 0)], ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
		asgnRef((void**) (&(*a)._kind_6.sons->data[((NI) 0)]), newIdentNode__ast_3700(T5_, info));
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, prepareOperand__sigmatch_3700)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formal, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*formal).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 6));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_3990(formal);
		T3_ = !((T5_ == ((NI) 1)));
		LA4_: ;
		if (!T3_) goto LA6_;
		result = a;
	}
	goto LA1_;
	LA6_: ;
	{
		if (!((*a).typ == 0)) goto LA9_;
		{
			tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags;
			if (!((*formal).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 64))) goto LA13_;
			flags = 774;
			result = (*c).semOperand(c, a, flags);
		}
		goto LA11_;
		LA13_: ;
		{
			tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags_2;
			flags_2 = 768;
			result = (*c).semOperand(c, a, flags_2);
		}
		LA11_: ;
	}
	goto LA1_;
	LA9_: ;
	{
		result = a;
		considerGenSyms__semdata_437(c, result);
		{
			NIM_BOOL T19_;
			NIM_BOOL T20_;
			T19_ = (NIM_BOOL)0;
			T20_ = (NIM_BOOL)0;
			T20_ = !(((*result).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65)));
			if (!(T20_)) goto LA21_;
			T20_ = ((*(*result).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*(*result).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47));
			LA21_: ;
			T19_ = T20_;
			if (!(T19_)) goto LA22_;
			T19_ = ((*c).matchedConcept == ((tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw*) NIM_NIL));
			LA22_: ;
			if (!T19_) goto LA23_;
			result = newDeref__lowerings_11(result);
		}
		LA23_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, arrayConstr__sigmatch_3758)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T2_;
	result = NIM_NIL;
	result = newTypeS__semdata_763(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16), c);
	T1_ = NIM_NIL;
	T1_ = makeRangeType__semdata_1069(c, IL64(0), IL64(0), (*n).info, ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
	rawAddSon__ast_4276(result, T1_, NIM_TRUE);
	T2_ = NIM_NIL;
	T2_ = skipTypes__ast_3723((*n).typ, TM__wjrA09aH0rT1R7zbrcCaROw_83);
	addSonSkipIntLit__magicsys_136(result, T2_, (*c).Sup.idgen);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, prepareOperand__sigmatch_3737)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	{
		if (!((*a).typ == 0)) goto LA3_;
		result = (*c).semOperand(c, a, 512);
	}
	goto LA1_;
	LA3_: ;
	{
		result = a;
		considerGenSyms__semdata_437(c, result);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, matchesAux__sigmatch_3825)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nOrig, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* marker) {
	tyObject_MismatchInfo__7DZVQMEKp3NTauLRe48cLw T1_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T2_;
	NI a;
	NI f;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg;
	NI formalLen;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* formal;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* container;
	NI firstArgBlock;
{	(*m).state = ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 1);
	nimZeroMem((void*)(&T1_), sizeof(tyObject_MismatchInfo__7DZVQMEKp3NTauLRe48cLw));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_MismatchInfo__7DZVQMEKp3NTauLRe48cLw));
	(*m).firstMismatch.kind = T1_.kind;
	(*m).firstMismatch.arg = T1_.arg;
	unsureAsgnRef((void**) (&(*m).firstMismatch.formal), T1_.formal);
	T2_ = NIM_NIL;
	T2_ = base__types_63((*m).callee);
	unsureAsgnRef((void**) (&(*m).call), newNodeIT__ast_3342((*n).kind, (*n).info, T2_));
	add__ast_4798((*m).call, (*n)._kind_6.sons->data[((NI) 0)]);
	a = ((NI) 1);
	{
		if (!!(((*(*m).callee).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 10)))) goto LA5_;
		f = ((NI) 1);
	}
	goto LA3_;
	LA5_: ;
	{
		f = ((NI) 0);
	}
	LA3_: ;
	arg = NIM_NIL;
	formalLen = len__ast_3155((*(*m).callee).n);
	{
		if (!(((NI) 1) < formalLen)) goto LA10_;
		formal = (*(*(*(*m).callee).n)._kind_6.sons->data[((NI) 1)])._kind_4.sym;
	}
	goto LA8_;
	LA10_: ;
	{
		formal = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
	}
	LA8_: ;
	container = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
	firstArgBlock = findFirstArgBlock__sigmatch_3783(m, n);
	{
		while (1) {
			NI T15_;
			T15_ = (NI)0;
			T15_ = len__ast_3155(n);
			if (!(a < T15_)) goto LA14;
			openShadowScope__lookups_1575(c);
			{
				NIM_BOOL T18_;
				NIM_BOOL T19_;
				NIM_BOOL T22_;
				T18_ = (NIM_BOOL)0;
				T19_ = (NIM_BOOL)0;
				T19_ = ((NI)(formalLen - ((NI) 1)) <= a);
				if (!(T19_)) goto LA20_;
				T19_ = (f < formalLen);
				LA20_: ;
				T18_ = T19_;
				if (!(T18_)) goto LA21_;
				T22_ = (NIM_BOOL)0;
				T22_ = ((*(*(*(*(*m).callee).n)._kind_6.sons->data[f]).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48));
				if (!(T22_)) goto LA23_;
				T22_ = ((*(*(*(*(*(*m).callee).n)._kind_6.sons->data[f]).typ).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 6));
				LA23_: ;
				T18_ = T22_;
				LA21_: ;
				if (!T18_) goto LA24_;
				formal = (*(*(*(*m).callee).n)._kind_6.sons->data[f])._kind_4.sym;
				incl__pureZcollectionsZintsets_55(marker, (*formal).position);
				{
					if (!((*(*n)._kind_6.sons->data[a]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58))) goto LA28_;
					{
						NIM_BOOL T32_;
						T32_ = (NIM_BOOL)0;
						T32_ = ((*(*(*n)._kind_6.sons->data[a])._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1));
						if (!(T32_)) goto LA33_;
						T32_ = ((*(*(*n)._kind_6.sons->data[a])._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41) || (*(*(*n)._kind_6.sons->data[a])._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152));
						LA33_: ;
						if (!!(T32_)) goto LA34_;
						failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_80));
					}
					LA34_: ;
					setSon__sigmatch_3687((*m).call, (NI)((*formal).position + ((NI) 1)), (*(*n)._kind_6.sons->data[a])._kind_6.sons->data[((NI) 1)]);
				}
				goto LA26_;
				LA28_: ;
				{
					{
						tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T41_;
						if (!(container == 0)) goto LA39_;
						T41_ = NIM_NIL;
						T41_ = arrayConstr__sigmatch_3762(c, (*n).info);
						container = newNodeIT__ast_3342(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152), (*(*n)._kind_6.sons->data[a]).info, T41_);
						setSon__sigmatch_3687((*m).call, (NI)((*formal).position + ((NI) 1)), container);
					}
					goto LA37_;
					LA39_: ;
					{
						incrIndexType__sigmatch_3766((*container).typ);
					}
					LA37_: ;
					add__ast_4798(container, (*n)._kind_6.sons->data[a]);
				}
				LA26_: ;
			}
			goto LA16_;
			LA24_: ;
			{
				if (!((*(*n)._kind_6.sons->data[a]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 33))) goto LA44_;
				(*m).firstMismatch.kind = ((tyEnum_MismatchKind__4mf6T2YBNEEtWBTWMSzL9bw) 2);
				prepareNamedParam__sigmatch_3746((*n)._kind_6.sons->data[a], c);
				{
					if (!!(((*(*(*n)._kind_6.sons->data[a])._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2)))) goto LA48_;
					liMessage__msgs_1128((*(*c).graph).config, (*(*n)._kind_6.sons->data[a]).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_81), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__wjrA09aH0rT1R7zbrcCaROw_82, NIM_FALSE);
					mergeShadowScope__lookups_1579(c);
					(*m).state = ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 2);
					(*m).firstMismatch.arg = a;
					unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
					goto BeforeRet_;
				}
				LA48_: ;
				formal = getNamedParamFromList__astalgo_293((*(*m).callee).n, (*(*(*n)._kind_6.sons->data[a])._kind_6.sons->data[((NI) 0)])._kind_5.ident);
				{
					if (!(formal == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA52_;
					mergeShadowScope__lookups_1579(c);
					(*m).state = ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 2);
					(*m).firstMismatch.arg = a;
					unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
					goto BeforeRet_;
				}
				LA52_: ;
				{
					NIM_BOOL T56_;
					T56_ = (NIM_BOOL)0;
					T56_ = containsOrIncl__astalgo_402(marker, (*formal).position);
					if (!T56_) goto LA57_;
					(*m).firstMismatch.kind = ((tyEnum_MismatchKind__4mf6T2YBNEEtWBTWMSzL9bw) 1);
					mergeShadowScope__lookups_1579(c);
					(*m).state = ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 2);
					(*m).firstMismatch.arg = a;
					unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
					goto BeforeRet_;
				}
				LA57_: ;
				(*m).baseTypeMatch = NIM_FALSE;
				(*m).typedescMatched = NIM_FALSE;
				asgnRef((void**) (&(*(*n)._kind_6.sons->data[a])._kind_6.sons->data[((NI) 1)]), prepareOperand__sigmatch_3700(c, (*formal).typ, (*(*n)._kind_6.sons->data[a])._kind_6.sons->data[((NI) 1)]));
				asgnRef((void**) (&(*(*n)._kind_6.sons->data[a]).typ), (*(*(*n)._kind_6.sons->data[a])._kind_6.sons->data[((NI) 1)]).typ);
				arg = paramTypesMatch__sigmatch_3620(m, (*formal).typ, (*(*n)._kind_6.sons->data[a]).typ, (*(*n)._kind_6.sons->data[a])._kind_6.sons->data[((NI) 1)], (*(*n)._kind_6.sons->data[a])._kind_6.sons->data[((NI) 1)]);
				(*m).firstMismatch.kind = ((tyEnum_MismatchKind__4mf6T2YBNEEtWBTWMSzL9bw) 3);
				{
					if (!(arg == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA61_;
					mergeShadowScope__lookups_1579(c);
					(*m).state = ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 2);
					(*m).firstMismatch.arg = a;
					unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
					goto BeforeRet_;
				}
				LA61_: ;
				{
					if (!!(((*formal).constraint == 0))) goto LA65_;
					{
						NIM_BOOL T69_;
						T69_ = (NIM_BOOL)0;
						T69_ = matchNodeKinds__parampatterns_505((*formal).constraint, (*(*n)._kind_6.sons->data[a])._kind_6.sons->data[((NI) 1)]);
						if (!T69_) goto LA70_;
						(*m).genericMatches += ((NI) 100);
					}
					goto LA67_;
					LA70_: ;
					{
						mergeShadowScope__lookups_1579(c);
						(*m).state = ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 2);
						(*m).firstMismatch.arg = a;
						unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
						goto BeforeRet_;
					}
					LA67_: ;
				}
				LA65_: ;
				{
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* argConverter;
					if (!((*(*formal).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23))) goto LA75_;
					{
						if (!((*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65))) goto LA79_;
						argConverter = (*arg)._kind_6.sons->data[((NI) 0)];
					}
					goto LA77_;
					LA79_: ;
					{
						argConverter = arg;
					}
					LA77_: ;
					{
						if (!((*argConverter).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32))) goto LA84_;
						{
							if (!!(((*(*argConverter).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23)))) goto LA88_;
							(*m).firstMismatch.kind = ((tyEnum_MismatchKind__4mf6T2YBNEEtWBTWMSzL9bw) 4);
							mergeShadowScope__lookups_1579(c);
							(*m).state = ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 2);
							(*m).firstMismatch.arg = a;
							unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
							goto BeforeRet_;
						}
						LA88_: ;
					}
					goto LA82_;
					LA84_: ;
					{
						NIM_BOOL T91_;
						T91_ = (NIM_BOOL)0;
						T91_ = isLValue__sigmatch_3118(c, (*(*n)._kind_6.sons->data[a])._kind_6.sons->data[((NI) 1)]);
						if (!!(T91_)) goto LA92_;
						(*m).firstMismatch.kind = ((tyEnum_MismatchKind__4mf6T2YBNEEtWBTWMSzL9bw) 4);
						mergeShadowScope__lookups_1579(c);
						(*m).state = ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 2);
						(*m).firstMismatch.arg = a;
						unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
						goto BeforeRet_;
					}
					goto LA82_;
					LA92_: ;
					LA82_: ;
				}
				LA75_: ;
				{
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T98_;
					if (!(*m).baseTypeMatch) goto LA96_;
					T98_ = NIM_NIL;
					T98_ = arrayConstr__sigmatch_3758(c, arg);
					container = newNodeIT__ast_3342(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41), (*(*n)._kind_6.sons->data[a]).info, T98_);
					add__ast_4798(container, arg);
					setSon__sigmatch_3687((*m).call, (NI)((*formal).position + ((NI) 1)), container);
					{
						if (!!((f == (NI)(formalLen - ((NI) 1))))) goto LA101_;
						container = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
					}
					LA101_: ;
				}
				goto LA94_;
				LA96_: ;
				{
					setSon__sigmatch_3687((*m).call, (NI)((*formal).position + ((NI) 1)), arg);
				}
				LA94_: ;
				f += ((NI) 1);
			}
			goto LA16_;
			LA44_: ;
			{
				{
					if (!(formalLen <= f)) goto LA107_;
					{
						if (!(((*(*m).callee).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 0))&63U)))!=0)) goto LA111_;
						asgnRef((void**) (&(*n)._kind_6.sons->data[a]), prepareOperand__sigmatch_3737(c, (*n)._kind_6.sons->data[a]));
						{
							tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T115_;
							tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T118_;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T119_;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T120_;
							T115_ = NIM_NIL;
							T115_ = skipTypes__ast_3723((*(*n)._kind_6.sons->data[a]).typ, TM__wjrA09aH0rT1R7zbrcCaROw_57);
							if (!((*T115_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28))) goto LA116_;
							T118_ = NIM_NIL;
							T118_ = getSysType__magicsys_60((*c).graph, (*(*n)._kind_6.sons->data[a]).info, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29));
							T119_ = NIM_NIL;
							T119_ = copyTree__ast_4432((*n)._kind_6.sons->data[a]);
							T120_ = NIM_NIL;
							T120_ = implicitConv__sigmatch_3095(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58), T118_, T119_, (&(*m)), c);
							add__ast_4798((*m).call, T120_);
						}
						goto LA113_;
						LA116_: ;
						{
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T122_;
							T122_ = NIM_NIL;
							T122_ = copyTree__ast_4432((*n)._kind_6.sons->data[a]);
							add__ast_4798((*m).call, T122_);
						}
						LA113_: ;
					}
					goto LA109_;
					LA111_: ;
					{
						NIM_BOOL T124_;
						T124_ = (NIM_BOOL)0;
						T124_ = !((formal == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
						if (!(T124_)) goto LA125_;
						T124_ = ((*(*formal).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48));
						LA125_: ;
						if (!T124_) goto LA126_;
						(*m).firstMismatch.kind = ((tyEnum_MismatchKind__4mf6T2YBNEEtWBTWMSzL9bw) 3);
						(*m).baseTypeMatch = NIM_FALSE;
						(*m).typedescMatched = NIM_FALSE;
						incl__pureZcollectionsZintsets_55(marker, (*formal).position);
						asgnRef((void**) (&(*n)._kind_6.sons->data[a]), prepareOperand__sigmatch_3700(c, (*formal).typ, (*n)._kind_6.sons->data[a]));
						arg = paramTypesMatch__sigmatch_3620(m, (*formal).typ, (*(*n)._kind_6.sons->data[a]).typ, (*n)._kind_6.sons->data[a], (*nOrig)._kind_6.sons->data[a]);
						{
							NIM_BOOL T130_;
							NIM_BOOL T131_;
							T130_ = (NIM_BOOL)0;
							T131_ = (NIM_BOOL)0;
							T131_ = !((arg == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
							if (!(T131_)) goto LA132_;
							T131_ = (*m).baseTypeMatch;
							LA132_: ;
							T130_ = T131_;
							if (!(T130_)) goto LA133_;
							T130_ = !((container == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
							LA133_: ;
							if (!T130_) goto LA134_;
							add__ast_4798(container, arg);
							incrIndexType__sigmatch_3766((*container).typ);
							{
								if (!!(((*formal).constraint == 0))) goto LA138_;
								{
									NIM_BOOL T142_;
									T142_ = (NIM_BOOL)0;
									T142_ = matchNodeKinds__parampatterns_505((*formal).constraint, (*n)._kind_6.sons->data[a]);
									if (!T142_) goto LA143_;
									(*m).genericMatches += ((NI) 100);
								}
								goto LA140_;
								LA143_: ;
								{
									mergeShadowScope__lookups_1579(c);
									(*m).state = ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 2);
									(*m).firstMismatch.arg = a;
									unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
									goto BeforeRet_;
								}
								LA140_: ;
							}
							LA138_: ;
							{
								tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* argConverter_2;
								if (!((*(*formal).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23))) goto LA148_;
								{
									if (!((*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65))) goto LA152_;
									argConverter_2 = (*arg)._kind_6.sons->data[((NI) 0)];
								}
								goto LA150_;
								LA152_: ;
								{
									argConverter_2 = arg;
								}
								LA150_: ;
								{
									if (!((*argConverter_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32))) goto LA157_;
									{
										if (!!(((*(*argConverter_2).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23)))) goto LA161_;
										(*m).firstMismatch.kind = ((tyEnum_MismatchKind__4mf6T2YBNEEtWBTWMSzL9bw) 4);
										mergeShadowScope__lookups_1579(c);
										(*m).state = ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 2);
										(*m).firstMismatch.arg = a;
										unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
										goto BeforeRet_;
									}
									LA161_: ;
								}
								goto LA155_;
								LA157_: ;
								{
									NIM_BOOL T164_;
									T164_ = (NIM_BOOL)0;
									T164_ = isLValue__sigmatch_3118(c, (*n)._kind_6.sons->data[a]);
									if (!!(T164_)) goto LA165_;
									(*m).firstMismatch.kind = ((tyEnum_MismatchKind__4mf6T2YBNEEtWBTWMSzL9bw) 4);
									mergeShadowScope__lookups_1579(c);
									(*m).state = ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 2);
									(*m).firstMismatch.arg = a;
									unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
									goto BeforeRet_;
								}
								goto LA155_;
								LA165_: ;
								LA155_: ;
							}
							LA148_: ;
						}
						goto LA128_;
						LA134_: ;
						{
							mergeShadowScope__lookups_1579(c);
							(*m).state = ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 2);
							(*m).firstMismatch.arg = a;
							unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
							goto BeforeRet_;
						}
						LA128_: ;
					}
					goto LA109_;
					LA126_: ;
					{
						(*m).firstMismatch.kind = ((tyEnum_MismatchKind__4mf6T2YBNEEtWBTWMSzL9bw) 6);
						mergeShadowScope__lookups_1579(c);
						(*m).state = ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 2);
						(*m).firstMismatch.arg = a;
						unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
						goto BeforeRet_;
					}
					LA109_: ;
				}
				goto LA105_;
				LA107_: ;
				{
					{
						if (!!(((*(*(*(*m).callee).n)._kind_6.sons->data[f]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)))) goto LA172_;
						internalErrorImpl__msgs_1441((*(*c).graph).config, (*(*n)._kind_6.sons->data[a]).info, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_84), TM__wjrA09aH0rT1R7zbrcCaROw_85);
						mergeShadowScope__lookups_1579(c);
						(*m).state = ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 2);
						(*m).firstMismatch.arg = a;
						unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
						goto BeforeRet_;
					}
					LA172_: ;
					{
						NIM_BOOL T176_;
						NI T180_;
						NI T181_;
						T176_ = (NIM_BOOL)0;
						T176_ = (((*c).features &((NU32)1<<((NU)(((tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw) 18))&31U)))!=0);
						if (!(T176_)) goto LA177_;
						T176_ = (firstArgBlock <= a);
						LA177_: ;
						if (!T176_) goto LA178_;
						T180_ = (NI)0;
						T180_ = len__ast_3155((*(*m).callee).n);
						T181_ = (NI)0;
						T181_ = len__ast_3155(n);
						f = ((f >= (NI)(T180_ - (NI)(T181_ - a))) ? f : (NI)(T180_ - (NI)(T181_ - a)));
					}
					LA178_: ;
					formal = (*(*(*(*m).callee).n)._kind_6.sons->data[f])._kind_4.sym;
					(*m).firstMismatch.kind = ((tyEnum_MismatchKind__4mf6T2YBNEEtWBTWMSzL9bw) 3);
					{
						NIM_BOOL T184_;
						T184_ = (NIM_BOOL)0;
						T184_ = containsOrIncl__astalgo_402(marker, (*formal).position);
						if (!(T184_)) goto LA185_;
						T184_ = (container == 0);
						LA185_: ;
						if (!T184_) goto LA186_;
						(*m).firstMismatch.kind = ((tyEnum_MismatchKind__4mf6T2YBNEEtWBTWMSzL9bw) 7);
						mergeShadowScope__lookups_1579(c);
						(*m).state = ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 2);
						(*m).firstMismatch.arg = a;
						unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
						goto BeforeRet_;
					}
					LA186_: ;
					{
						NIM_BOOL T190_;
						T190_ = (NIM_BOOL)0;
						T190_ = ((*(*formal).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48));
						if (!(T190_)) goto LA191_;
						T190_ = ((*(*(*formal).typ).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 6));
						LA191_: ;
						if (!T190_) goto LA192_;
						{
							tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T198_;
							if (!(container == 0)) goto LA196_;
							T198_ = NIM_NIL;
							T198_ = arrayConstr__sigmatch_3762(c, (*n).info);
							container = newNodeIT__ast_3342(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152), (*(*n)._kind_6.sons->data[a]).info, T198_);
							setSon__sigmatch_3687((*m).call, (NI)((*formal).position + ((NI) 1)), container);
						}
						goto LA194_;
						LA196_: ;
						{
							incrIndexType__sigmatch_3766((*container).typ);
						}
						LA194_: ;
						add__ast_4798(container, (*n)._kind_6.sons->data[a]);
					}
					goto LA188_;
					LA192_: ;
					{
						(*m).baseTypeMatch = NIM_FALSE;
						(*m).typedescMatched = NIM_FALSE;
						asgnRef((void**) (&(*n)._kind_6.sons->data[a]), prepareOperand__sigmatch_3700(c, (*formal).typ, (*n)._kind_6.sons->data[a]));
						arg = paramTypesMatch__sigmatch_3620(m, (*formal).typ, (*(*n)._kind_6.sons->data[a]).typ, (*n)._kind_6.sons->data[a], (*nOrig)._kind_6.sons->data[a]);
						{
							if (!(arg == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA203_;
							mergeShadowScope__lookups_1579(c);
							(*m).state = ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 2);
							(*m).firstMismatch.arg = a;
							unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
							goto BeforeRet_;
						}
						LA203_: ;
						{
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T215_;
							NI T216_;
							if (!(*m).baseTypeMatch) goto LA207_;
							{
								tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T213_;
								if (!(container == 0)) goto LA211_;
								T213_ = NIM_NIL;
								T213_ = arrayConstr__sigmatch_3758(c, arg);
								container = newNodeIT__ast_3342(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41), (*(*n)._kind_6.sons->data[a]).info, T213_);
								(*(*container).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 0)) & 63);
							}
							goto LA209_;
							LA211_: ;
							{
								incrIndexType__sigmatch_3766((*container).typ);
							}
							LA209_: ;
							add__ast_4798(container, arg);
							T215_ = NIM_NIL;
							T215_ = implicitConv__sigmatch_3095(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58), (*formal).typ, container, (&(*m)), c);
							setSon__sigmatch_3687((*m).call, (NI)((*formal).position + ((NI) 1)), T215_);
							T216_ = (NI)0;
							T216_ = len__ast_3155(n);
							f = ((f >= (NI)((NI)((NI)(formalLen - T216_) + a) + ((NI) 1))) ? f : (NI)((NI)((NI)(formalLen - T216_) + a) + ((NI) 1)));
						}
						goto LA205_;
						LA207_: ;
						{
							NIM_BOOL T218_;
							T218_ = (NIM_BOOL)0;
							T218_ = !(((*(*formal).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48)));
							if (T218_) goto LA219_;
							T218_ = (container == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
							LA219_: ;
							if (!T218_) goto LA220_;
							setSon__sigmatch_3687((*m).call, (NI)((*formal).position + ((NI) 1)), arg);
							f += ((NI) 1);
							container = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
						}
						goto LA205_;
						LA220_: ;
						{
							tyArray__Re75IspeoxXy2oCZHwcRrA T223_;
							NimStringDesc* T224_;
							nimZeroMem((void*)T223_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
							T223_[0] = typeToString__types_50((*(*n)._kind_6.sons->data[a]).typ, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
							T223_[1] = typeToString__types_50((*formal).typ, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
							T224_ = NIM_NIL;
							T224_ = nsuFormatOpenArray(((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_86), T223_, 2);
							liMessage__msgs_1128((*(*c).graph).config, (*(*n)._kind_6.sons->data[a]).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T224_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__wjrA09aH0rT1R7zbrcCaROw_87, NIM_FALSE);
							mergeShadowScope__lookups_1579(c);
							(*m).state = ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 2);
							(*m).firstMismatch.arg = a;
							unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
							goto BeforeRet_;
						}
						LA205_: ;
					}
					LA188_: ;
					{
						if (!!(((*formal).constraint == 0))) goto LA227_;
						{
							NIM_BOOL T231_;
							T231_ = (NIM_BOOL)0;
							T231_ = matchNodeKinds__parampatterns_505((*formal).constraint, (*n)._kind_6.sons->data[a]);
							if (!T231_) goto LA232_;
							(*m).genericMatches += ((NI) 100);
						}
						goto LA229_;
						LA232_: ;
						{
							mergeShadowScope__lookups_1579(c);
							(*m).state = ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 2);
							(*m).firstMismatch.arg = a;
							unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
							goto BeforeRet_;
						}
						LA229_: ;
					}
					LA227_: ;
					{
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* argConverter_3;
						if (!((*(*formal).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23))) goto LA237_;
						{
							if (!((*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65))) goto LA241_;
							argConverter_3 = (*arg)._kind_6.sons->data[((NI) 0)];
						}
						goto LA239_;
						LA241_: ;
						{
							argConverter_3 = arg;
						}
						LA239_: ;
						{
							if (!((*argConverter_3).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32))) goto LA246_;
							{
								if (!!(((*(*argConverter_3).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23)))) goto LA250_;
								(*m).firstMismatch.kind = ((tyEnum_MismatchKind__4mf6T2YBNEEtWBTWMSzL9bw) 4);
								mergeShadowScope__lookups_1579(c);
								(*m).state = ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 2);
								(*m).firstMismatch.arg = a;
								unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
								goto BeforeRet_;
							}
							LA250_: ;
						}
						goto LA244_;
						LA246_: ;
						{
							NIM_BOOL T253_;
							T253_ = (NIM_BOOL)0;
							T253_ = isLValue__sigmatch_3118(c, (*n)._kind_6.sons->data[a]);
							if (!!(T253_)) goto LA254_;
							(*m).firstMismatch.kind = ((tyEnum_MismatchKind__4mf6T2YBNEEtWBTWMSzL9bw) 4);
							mergeShadowScope__lookups_1579(c);
							(*m).state = ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 2);
							(*m).firstMismatch.arg = a;
							unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
							goto BeforeRet_;
						}
						goto LA244_;
						LA254_: ;
						LA244_: ;
					}
					LA237_: ;
				}
				LA105_: ;
			}
			LA16_: ;
			{
				NIM_BOOL T258_;
				NIM_BOOL T260_;
				T258_ = (NIM_BOOL)0;
				T258_ = ((*m).state == ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 1));
				if (!(T258_)) goto LA259_;
				T260_ = (NIM_BOOL)0;
				T260_ = !(((*m).calleeSym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
				if (!(T260_)) goto LA261_;
				T260_ = ((393216 &((NU32)1<<((NU)((*(*m).calleeSym).kind)&31U)))!=0);
				LA261_: ;
				T258_ = !(T260_);
				LA259_: ;
				if (!T258_) goto LA262_;
				mergeShadowScope__lookups_1579(c);
			}
			goto LA256_;
			LA262_: ;
			{
				closeShadowScope__lookups_1577(c);
			}
			LA256_: ;
			a += ((NI) 1);
		} LA14: ;
	}
	(*m).firstMismatch.arg = a;
	unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, partialMatch__sigmatch_4216)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nOrig, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m) {
	tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw marker;
	nimZeroMem((void*)(&marker), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
	initIntSet__pureZcollectionsZintsets_238((&marker));
	matchesAux__sigmatch_3825(c, n, nOrig, m, (&marker));
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, argsFit__sigmatch_5142)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* candidate, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nOrig) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	switch ((*candidate).kind) {
	case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6):
	case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 12) ... ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 18):
	case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 20):
	{
		tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw m;
		nimZeroMem((void*)(&m), sizeof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw));
		newCandidate__sigmatch_189(c, candidate, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), ((NI) -1), (&m));
		partialMatch__sigmatch_4216(c, n, nOrig, (&m));
		result = !((m.state == ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 2)));
	}
	break;
	default:
	{
		result = NIM_FALSE;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, suggestCall__sigmatch_5153)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nOrig, tySequence__GR8qmV1kNRcoQ2g76VFy3A** outputs) {
	tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
	info = (*n).info;
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* item;
		NI scopeN;
		NIM_BOOL isLocal;
		NIM_BOOL isLocal_2;
		NI scopeN_2;
		item = NIM_NIL;
		scopeN = (NI)0;
		isLocal = (NIM_BOOL)0;
		isLocal_2 = NIM_TRUE;
		scopeN_2 = ((NI) 0);
		{
			tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope;
			tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* current;
			scope = NIM_NIL;
			current = (*c).currentScope;
			{
				while (1) {
					if (!!((current == ((tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ*) NIM_NIL)))) goto LA4;
					scope = current;
					{
						if (!(scope == (*c).topLevelScope)) goto LA7_;
						isLocal_2 = NIM_FALSE;
					}
					LA7_: ;
					scopeN_2 -= ((NI) 1);
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* item_2;
						tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw it;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
						item_2 = NIM_NIL;
						nimZeroMem((void*)(&it), sizeof(tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw));
						s = initTabIter__astalgo_3770((&it), (*scope).symbols);
						{
							while (1) {
								tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A colontmp_;
								tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* it_2;
								tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ pm;
								if (!!((s == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA11;
								item_2 = s;
								nimZeroMem((void*)(&colontmp_), sizeof(tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A));
								colontmp_.Field0 = item_2;
								colontmp_.Field1 = scopeN_2;
								colontmp_.Field2 = isLocal_2;
								item = colontmp_.Field0;
								scopeN = colontmp_.Field1;
								isLocal = colontmp_.Field2;
								it_2 = item;
								pm = (tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ)0;
								{
									NIM_BOOL T14_;
									NIM_BOOL T15_;
									NI T20_;
									tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* T21_;
									NI T22_;
									T14_ = (NIM_BOOL)0;
									T15_ = (NIM_BOOL)0;
									T15_ = filterSym__sigmatch_4938(it_2, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), (&pm));
									if (!(T15_)) goto LA16_;
									T15_ = nameFits__sigmatch_5120(c, it_2, n);
									LA16_: ;
									T14_ = T15_;
									if (!(T14_)) goto LA17_;
									T14_ = argsFit__sigmatch_5142(c, it_2, n, nOrig);
									LA17_: ;
									if (!T14_) goto LA18_;
									T20_ = (NI)0;
									T20_ = getQuality__sigmatch_5031(it_2);
									T21_ = NIM_NIL;
									T21_ = symToSuggest__sigmatch_4569((*c).graph, it_2, isLocal, ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 2), info, T20_, pm, (((NI) 0) < (*c).inTypeContext), scopeN, NIM_FALSE, ((NU16) 0), ((NI) 0));
									unsureAsgnRef((void**) (&(*outputs)), (tySequence__GR8qmV1kNRcoQ2g76VFy3A*) incrSeqV3((TGenericSeq*)((*outputs)), (&NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_)));
									T22_ = (*outputs)->Sup.len++;
									asgnRef((void**) (&(*outputs)->data[T22_]), T21_);
								}
								LA18_: ;
								s = nextIter__astalgo_3755((&it), (*scope).symbols);
							} LA11: ;
						}
					}
					current = (*current).parent;
				} LA4: ;
			}
		}
		scopeN_2 -= ((NI) 1);
		isLocal_2 = NIM_FALSE;
		{
			tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg* im;
			NI i;
			NI L;
			NI T24_;
			im = (tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg*)0;
			i = ((NI) 0);
			T24_ = ((*c).imports ? (*c).imports->Sup.len : 0);
			L = T24_;
			{
				while (1) {
					if (!(i < L)) goto LA26;
					im = (&(*c).imports->data[i]);
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s_2;
						NIM_BOOL importHidden;
						s_2 = NIM_NIL;
						importHidden = (((*(*im).m).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 27))&31U)))!=0);
						{
							NIM_BOOL T30_;
							tyObject_RodIter__L6nv9cakjPARHk068AFo6ww rodIt;
							tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* r;
							T30_ = (NIM_BOOL)0;
							T30_ = isCachedModule__modulegraphs_2722((*c).graph, (*im).m);
							if (!T30_) goto LA31_;
							nimZeroMem((void*)(&rodIt), sizeof(tyObject_RodIter__L6nv9cakjPARHk068AFo6ww));
							r = initRodIterAllSyms__icZic_8670((&rodIt), (*(*c).graph).config, (*(*c).graph).cache, (&(*(*c).graph).packed_0), ((NI32) ((*(*im).m).position)), importHidden);
							{
								while (1) {
									tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A colontmp__2;
									tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* it_3;
									tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ pm_2;
									if (!!((r == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA34;
									s_2 = r;
									nimZeroMem((void*)(&colontmp__2), sizeof(tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A));
									colontmp__2.Field0 = s_2;
									colontmp__2.Field1 = scopeN_2;
									colontmp__2.Field2 = isLocal_2;
									item = colontmp__2.Field0;
									scopeN = colontmp__2.Field1;
									isLocal = colontmp__2.Field2;
									it_3 = item;
									pm_2 = (tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ)0;
									{
										NIM_BOOL T37_;
										NIM_BOOL T38_;
										NI T43_;
										tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* T44_;
										NI T45_;
										T37_ = (NIM_BOOL)0;
										T38_ = (NIM_BOOL)0;
										T38_ = filterSym__sigmatch_4938(it_3, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), (&pm_2));
										if (!(T38_)) goto LA39_;
										T38_ = nameFits__sigmatch_5120(c, it_3, n);
										LA39_: ;
										T37_ = T38_;
										if (!(T37_)) goto LA40_;
										T37_ = argsFit__sigmatch_5142(c, it_3, n, nOrig);
										LA40_: ;
										if (!T37_) goto LA41_;
										T43_ = (NI)0;
										T43_ = getQuality__sigmatch_5031(it_3);
										T44_ = NIM_NIL;
										T44_ = symToSuggest__sigmatch_4569((*c).graph, it_3, isLocal, ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 2), info, T43_, pm_2, (((NI) 0) < (*c).inTypeContext), scopeN, NIM_FALSE, ((NU16) 0), ((NI) 0));
										unsureAsgnRef((void**) (&(*outputs)), (tySequence__GR8qmV1kNRcoQ2g76VFy3A*) incrSeqV3((TGenericSeq*)((*outputs)), (&NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_)));
										T45_ = (*outputs)->Sup.len++;
										asgnRef((void**) (&(*outputs)->data[T45_]), T44_);
									}
									LA41_: ;
									r = nextRodIter__icZic_8980((&rodIt), (&(*(*c).graph).packed_0));
								} LA34: ;
							}
						}
						goto LA28_;
						LA31_: ;
						{
							{
								tyObject_TSym__3r34mwqcVmg5JFNmiaVncw** s_3;
								tySequence__ed0C0uAUZPhvw3RAc5hfYg* colontmp__3;
								tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* retX60gensym17_;
								NI i_2;
								NI L_2;
								NI T52_;
								s_3 = (tyObject_TSym__3r34mwqcVmg5JFNmiaVncw**)0;
								colontmp__3 = NIM_NIL;
								retX60gensym17_ = (&(*(*c).graph).ifaces->data[(*(*im).m).position].interf);
								{
									if (!importHidden) goto LA50_;
									retX60gensym17_ = (&(*(*c).graph).ifaces->data[(*(*im).m).position].interfHidden);
								}
								LA50_: ;
								colontmp__3 = (*retX60gensym17_).data;
								i_2 = ((NI) 0);
								T52_ = (colontmp__3 ? colontmp__3->Sup.len : 0);
								L_2 = T52_;
								{
									while (1) {
										if (!(i_2 < L_2)) goto LA54;
										s_3 = &colontmp__3->data[i_2];
										{
											tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A colontmp__4;
											tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* it_4;
											tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ pm_3;
											if (!!(((*s_3) == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA57_;
											s_2 = (*s_3);
											nimZeroMem((void*)(&colontmp__4), sizeof(tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A));
											colontmp__4.Field0 = s_2;
											colontmp__4.Field1 = scopeN_2;
											colontmp__4.Field2 = isLocal_2;
											item = colontmp__4.Field0;
											scopeN = colontmp__4.Field1;
											isLocal = colontmp__4.Field2;
											it_4 = item;
											pm_3 = (tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ)0;
											{
												NIM_BOOL T61_;
												NIM_BOOL T62_;
												NI T67_;
												tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* T68_;
												NI T69_;
												T61_ = (NIM_BOOL)0;
												T62_ = (NIM_BOOL)0;
												T62_ = filterSym__sigmatch_4938(it_4, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), (&pm_3));
												if (!(T62_)) goto LA63_;
												T62_ = nameFits__sigmatch_5120(c, it_4, n);
												LA63_: ;
												T61_ = T62_;
												if (!(T61_)) goto LA64_;
												T61_ = argsFit__sigmatch_5142(c, it_4, n, nOrig);
												LA64_: ;
												if (!T61_) goto LA65_;
												T67_ = (NI)0;
												T67_ = getQuality__sigmatch_5031(it_4);
												T68_ = NIM_NIL;
												T68_ = symToSuggest__sigmatch_4569((*c).graph, it_4, isLocal, ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 2), info, T67_, pm_3, (((NI) 0) < (*c).inTypeContext), scopeN, NIM_FALSE, ((NU16) 0), ((NI) 0));
												unsureAsgnRef((void**) (&(*outputs)), (tySequence__GR8qmV1kNRcoQ2g76VFy3A*) incrSeqV3((TGenericSeq*)((*outputs)), (&NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_)));
												T69_ = (*outputs)->Sup.len++;
												asgnRef((void**) (&(*outputs)->data[T69_]), T68_);
											}
											LA65_: ;
										}
										LA57_: ;
										i_2 += ((NI) 1);
									} LA54: ;
								}
							}
						}
						LA28_: ;
					}
					i += ((NI) 1);
				} LA26: ;
			}
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, suggestVar__sigmatch_5168)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySequence__GR8qmV1kNRcoQ2g76VFy3A** outputs) {
	tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
	info = (*n).info;
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* item;
		NI scopeN;
		NIM_BOOL isLocal;
		NIM_BOOL isLocal_2;
		NI scopeN_2;
		item = NIM_NIL;
		scopeN = (NI)0;
		isLocal = (NIM_BOOL)0;
		isLocal_2 = NIM_TRUE;
		scopeN_2 = ((NI) 0);
		{
			tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope;
			tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* current;
			scope = NIM_NIL;
			current = (*c).currentScope;
			{
				while (1) {
					if (!!((current == ((tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ*) NIM_NIL)))) goto LA4;
					scope = current;
					{
						if (!(scope == (*c).topLevelScope)) goto LA7_;
						isLocal_2 = NIM_FALSE;
					}
					LA7_: ;
					scopeN_2 -= ((NI) 1);
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* item_2;
						tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw it;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
						item_2 = NIM_NIL;
						nimZeroMem((void*)(&it), sizeof(tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw));
						s = initTabIter__astalgo_3770((&it), (*scope).symbols);
						{
							while (1) {
								tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A colontmp_;
								tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* it_2;
								tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ pm;
								if (!!((s == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA11;
								item_2 = s;
								nimZeroMem((void*)(&colontmp_), sizeof(tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A));
								colontmp_.Field0 = item_2;
								colontmp_.Field1 = scopeN_2;
								colontmp_.Field2 = isLocal_2;
								item = colontmp_.Field0;
								scopeN = colontmp_.Field1;
								isLocal = colontmp_.Field2;
								it_2 = item;
								pm = (tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ)0;
								{
									NIM_BOOL T14_;
									NI T17_;
									tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* T18_;
									NI T19_;
									T14_ = (NIM_BOOL)0;
									T14_ = nameFits__sigmatch_5120(c, it_2, n);
									if (!T14_) goto LA15_;
									T17_ = (NI)0;
									T17_ = getQuality__sigmatch_5031(it_2);
									T18_ = NIM_NIL;
									T18_ = symToSuggest__sigmatch_4569((*c).graph, it_2, isLocal, ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 2), info, T17_, pm, (((NI) 0) < (*c).inTypeContext), scopeN, NIM_FALSE, ((NU16) 0), ((NI) 0));
									unsureAsgnRef((void**) (&(*outputs)), (tySequence__GR8qmV1kNRcoQ2g76VFy3A*) incrSeqV3((TGenericSeq*)((*outputs)), (&NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_)));
									T19_ = (*outputs)->Sup.len++;
									asgnRef((void**) (&(*outputs)->data[T19_]), T18_);
								}
								LA15_: ;
								s = nextIter__astalgo_3755((&it), (*scope).symbols);
							} LA11: ;
						}
					}
					current = (*current).parent;
				} LA4: ;
			}
		}
		scopeN_2 -= ((NI) 1);
		isLocal_2 = NIM_FALSE;
		{
			tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg* im;
			NI i;
			NI L;
			NI T21_;
			im = (tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg*)0;
			i = ((NI) 0);
			T21_ = ((*c).imports ? (*c).imports->Sup.len : 0);
			L = T21_;
			{
				while (1) {
					if (!(i < L)) goto LA23;
					im = (&(*c).imports->data[i]);
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s_2;
						NIM_BOOL importHidden;
						s_2 = NIM_NIL;
						importHidden = (((*(*im).m).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 27))&31U)))!=0);
						{
							NIM_BOOL T27_;
							tyObject_RodIter__L6nv9cakjPARHk068AFo6ww rodIt;
							tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* r;
							T27_ = (NIM_BOOL)0;
							T27_ = isCachedModule__modulegraphs_2722((*c).graph, (*im).m);
							if (!T27_) goto LA28_;
							nimZeroMem((void*)(&rodIt), sizeof(tyObject_RodIter__L6nv9cakjPARHk068AFo6ww));
							r = initRodIterAllSyms__icZic_8670((&rodIt), (*(*c).graph).config, (*(*c).graph).cache, (&(*(*c).graph).packed_0), ((NI32) ((*(*im).m).position)), importHidden);
							{
								while (1) {
									tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A colontmp__2;
									tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* it_3;
									tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ pm_2;
									if (!!((r == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA31;
									s_2 = r;
									nimZeroMem((void*)(&colontmp__2), sizeof(tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A));
									colontmp__2.Field0 = s_2;
									colontmp__2.Field1 = scopeN_2;
									colontmp__2.Field2 = isLocal_2;
									item = colontmp__2.Field0;
									scopeN = colontmp__2.Field1;
									isLocal = colontmp__2.Field2;
									it_3 = item;
									pm_2 = (tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ)0;
									{
										NIM_BOOL T34_;
										NI T37_;
										tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* T38_;
										NI T39_;
										T34_ = (NIM_BOOL)0;
										T34_ = nameFits__sigmatch_5120(c, it_3, n);
										if (!T34_) goto LA35_;
										T37_ = (NI)0;
										T37_ = getQuality__sigmatch_5031(it_3);
										T38_ = NIM_NIL;
										T38_ = symToSuggest__sigmatch_4569((*c).graph, it_3, isLocal, ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 2), info, T37_, pm_2, (((NI) 0) < (*c).inTypeContext), scopeN, NIM_FALSE, ((NU16) 0), ((NI) 0));
										unsureAsgnRef((void**) (&(*outputs)), (tySequence__GR8qmV1kNRcoQ2g76VFy3A*) incrSeqV3((TGenericSeq*)((*outputs)), (&NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_)));
										T39_ = (*outputs)->Sup.len++;
										asgnRef((void**) (&(*outputs)->data[T39_]), T38_);
									}
									LA35_: ;
									r = nextRodIter__icZic_8980((&rodIt), (&(*(*c).graph).packed_0));
								} LA31: ;
							}
						}
						goto LA25_;
						LA28_: ;
						{
							{
								tyObject_TSym__3r34mwqcVmg5JFNmiaVncw** s_3;
								tySequence__ed0C0uAUZPhvw3RAc5hfYg* colontmp__3;
								tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* retX60gensym17_;
								NI i_2;
								NI L_2;
								NI T46_;
								s_3 = (tyObject_TSym__3r34mwqcVmg5JFNmiaVncw**)0;
								colontmp__3 = NIM_NIL;
								retX60gensym17_ = (&(*(*c).graph).ifaces->data[(*(*im).m).position].interf);
								{
									if (!importHidden) goto LA44_;
									retX60gensym17_ = (&(*(*c).graph).ifaces->data[(*(*im).m).position].interfHidden);
								}
								LA44_: ;
								colontmp__3 = (*retX60gensym17_).data;
								i_2 = ((NI) 0);
								T46_ = (colontmp__3 ? colontmp__3->Sup.len : 0);
								L_2 = T46_;
								{
									while (1) {
										if (!(i_2 < L_2)) goto LA48;
										s_3 = &colontmp__3->data[i_2];
										{
											tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A colontmp__4;
											tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* it_4;
											tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ pm_3;
											if (!!(((*s_3) == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA51_;
											s_2 = (*s_3);
											nimZeroMem((void*)(&colontmp__4), sizeof(tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A));
											colontmp__4.Field0 = s_2;
											colontmp__4.Field1 = scopeN_2;
											colontmp__4.Field2 = isLocal_2;
											item = colontmp__4.Field0;
											scopeN = colontmp__4.Field1;
											isLocal = colontmp__4.Field2;
											it_4 = item;
											pm_3 = (tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ)0;
											{
												NIM_BOOL T55_;
												NI T58_;
												tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* T59_;
												NI T60_;
												T55_ = (NIM_BOOL)0;
												T55_ = nameFits__sigmatch_5120(c, it_4, n);
												if (!T55_) goto LA56_;
												T58_ = (NI)0;
												T58_ = getQuality__sigmatch_5031(it_4);
												T59_ = NIM_NIL;
												T59_ = symToSuggest__sigmatch_4569((*c).graph, it_4, isLocal, ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 2), info, T58_, pm_3, (((NI) 0) < (*c).inTypeContext), scopeN, NIM_FALSE, ((NU16) 0), ((NI) 0));
												unsureAsgnRef((void**) (&(*outputs)), (tySequence__GR8qmV1kNRcoQ2g76VFy3A*) incrSeqV3((TGenericSeq*)((*outputs)), (&NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_)));
												T60_ = (*outputs)->Sup.len++;
												asgnRef((void**) (&(*outputs)->data[T60_]), T59_);
											}
											LA56_: ;
										}
										LA51_: ;
										i_2 += ((NI) 1);
									} LA48: ;
								}
							}
						}
						LA25_: ;
					}
					i += ((NI) 1);
				} LA23: ;
			}
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(NI, cmpSuggestions__sigmatch_4477)(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* a, tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* b) {
	NI result;
{	result = (NI)0;
	result = (NI)(((NI) ((*b).prefix)) - ((NI) ((*a).prefix)));
	{
		if (!!((result == ((NI) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	result = (NI)(((NI) ((*b).contextFits)) - ((NI) ((*a).contextFits)));
	{
		if (!!((result == ((NI) 0)))) goto LA7_;
		goto BeforeRet_;
	}
	LA7_: ;
	result = (NI)((*b).scope - (*a).scope);
	{
		if (!!((result == ((NI) 0)))) goto LA11_;
		goto BeforeRet_;
	}
	LA11_: ;
	result = (NI)(((NI) ((*b).quality)) - ((NI) ((*a).quality)));
	{
		if (!!((result == ((NI) 0)))) goto LA15_;
		goto BeforeRet_;
	}
	LA15_: ;
	result = (NI)((*b).localUsages - (*a).localUsages);
	{
		if (!!((result == ((NI) 0)))) goto LA19_;
		goto BeforeRet_;
	}
	LA19_: ;
	result = (NI)((*b).globalUsages - (*a).globalUsages);
	{
		if (!!((result == ((NI) 0)))) goto LA23_;
		goto BeforeRet_;
	}
	LA23_: ;
	result = cmp__system_1549((*(*a).name), (*(*b).name));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___sigmatch_4762)(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* suggest) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = dollar___options_4702((*suggest).section);
	result = addChar(result, 9);
	{
		NimStringDesc* T17_;
		NimStringDesc* T18_;
		NimStringDesc* T19_;
		if (!((*suggest).section == ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 9))) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = (((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) ((*suggest).symkind)) == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8));
			if (!(T7_)) goto LA8_;
			T7_ = (*suggest).isGlobal;
			LA8_: ;
			if (!T7_) goto LA9_;
			result = resizeString(result, 11);
appendString(result, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_90));
		}
		goto LA5_;
		LA9_: ;
		{
			NIM_BOOL T12_;
			T12_ = (NIM_BOOL)0;
			T12_ = (((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) ((*suggest).symkind)) == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 9));
			if (!(T12_)) goto LA13_;
			T12_ = (*suggest).isGlobal;
			LA13_: ;
			if (!T12_) goto LA14_;
			result = resizeString(result, 11);
appendString(result, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_91));
		}
		goto LA5_;
		LA14_: ;
		{
			result = resizeString(result, (reprEnum((NI)((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) ((*suggest).symkind)), (&NTItsymkind__sjiB9b9aO1FRPetW6gPYZbfw_)) ? reprEnum((NI)((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) ((*suggest).symkind)), (&NTItsymkind__sjiB9b9aO1FRPetW6gPYZbfw_))->Sup.len : 0) + 0);
appendString(result, reprEnum((NI)((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) ((*suggest).symkind)), (&NTItsymkind__sjiB9b9aO1FRPetW6gPYZbfw_)));
		}
		LA5_: ;
		result = addChar(result, 9);
		T17_ = NIM_NIL;
		T17_ = dollar___systemZdollars_3((*suggest).line);
		result = resizeString(result, (T17_ ? T17_->Sup.len : 0) + 0);
appendString(result, T17_);
		result = addChar(result, 9);
		T18_ = NIM_NIL;
		T18_ = dollar___systemZdollars_3((*suggest).column);
		result = resizeString(result, (T18_ ? T18_->Sup.len : 0) + 0);
appendString(result, T18_);
		result = addChar(result, 9);
		T19_ = NIM_NIL;
		T19_ = dollar___systemZdollars_3((*suggest).tokenLen);
		result = resizeString(result, (T19_ ? T19_->Sup.len : 0) + 0);
appendString(result, T19_);
	}
	goto LA1_;
	LA3_: ;
	{
		NimStringDesc* T27_;
		NimStringDesc* T28_;
		result = resizeString(result, (reprEnum((NI)((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) ((*suggest).symkind)), (&NTItsymkind__sjiB9b9aO1FRPetW6gPYZbfw_)) ? reprEnum((NI)((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) ((*suggest).symkind)), (&NTItsymkind__sjiB9b9aO1FRPetW6gPYZbfw_))->Sup.len : 0) + 0);
appendString(result, reprEnum((NI)((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) ((*suggest).symkind)), (&NTItsymkind__sjiB9b9aO1FRPetW6gPYZbfw_)));
		result = addChar(result, 9);
		{
			NI T23_;
			NimStringDesc* T26_;
			T23_ = ((*suggest).qualifiedPath ? (*suggest).qualifiedPath->Sup.len : 0);
			if (!!((T23_ == ((NI) 0)))) goto LA24_;
			T26_ = NIM_NIL;
			T26_ = nsuJoinSep(((*suggest).qualifiedPath) ? ((*suggest).qualifiedPath->data) : NIM_NIL, ((*suggest).qualifiedPath ? (*suggest).qualifiedPath->Sup.len : 0), ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_92));
			result = resizeString(result, (T26_ ? T26_->Sup.len : 0) + 0);
appendString(result, T26_);
		}
		LA24_: ;
		result = addChar(result, 9);
		result = resizeString(result, ((*suggest).forth ? (*suggest).forth->Sup.len : 0) + 0);
appendString(result, (*suggest).forth);
		result = addChar(result, 9);
		result = resizeString(result, ((*suggest).filePath ? (*suggest).filePath->Sup.len : 0) + 0);
appendString(result, (*suggest).filePath);
		result = addChar(result, 9);
		T27_ = NIM_NIL;
		T27_ = dollar___systemZdollars_3((*suggest).line);
		result = resizeString(result, (T27_ ? T27_->Sup.len : 0) + 0);
appendString(result, T27_);
		result = addChar(result, 9);
		T28_ = NIM_NIL;
		T28_ = dollar___systemZdollars_3((*suggest).column);
		result = resizeString(result, (T28_ ? T28_->Sup.len : 0) + 0);
appendString(result, T28_);
		result = addChar(result, 9);
		{
			NimStringDesc* T33_;
			if (!((*suggest).version == ((NI) 0) || (*suggest).version == ((NI) 3))) goto LA31_;
			result = addChar(result, 9);
			T33_ = NIM_NIL;
			T33_ = dollar___systemZdollars_3(((NI) ((*suggest).quality)));
			result = resizeString(result, (T33_ ? T33_->Sup.len : 0) + 0);
appendString(result, T33_);
			{
				if (!((*suggest).section == ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 1))) goto LA36_;
				result = addChar(result, 9);
				result = resizeString(result, (reprEnum((NI)(*suggest).prefix, (&NTIprefixmatch__Y9cGLq2K6rNefjjqfIC9bauQ_)) ? reprEnum((NI)(*suggest).prefix, (&NTIprefixmatch__Y9cGLq2K6rNefjjqfIC9bauQ_))->Sup.len : 0) + 0);
appendString(result, reprEnum((NI)(*suggest).prefix, (&NTIprefixmatch__Y9cGLq2K6rNefjjqfIC9bauQ_)));
			}
			LA36_: ;
		}
		LA31_: ;
	}
	LA1_: ;
	{
		NIM_BOOL T40_;
		NimStringDesc* T44_;
		NimStringDesc* T45_;
		T40_ = (NIM_BOOL)0;
		T40_ = ((*suggest).version == ((NI) 3));
		if (!(T40_)) goto LA41_;
		T40_ = ((525312 &((NU32)1<<((NU)((*suggest).section)&31U)))!=0);
		LA41_: ;
		if (!T40_) goto LA42_;
		result = addChar(result, 9);
		T44_ = NIM_NIL;
		T44_ = dollar___systemZdollars_9(((NU64) ((*suggest).endLine)));
		result = resizeString(result, (T44_ ? T44_->Sup.len : 0) + 0);
appendString(result, T44_);
		result = addChar(result, 9);
		T45_ = NIM_NIL;
		T45_ = dollar___systemZdollars_3((*suggest).endCol);
		result = resizeString(result, (T45_ ? T45_->Sup.len : 0) + 0);
appendString(result, T45_);
	}
	LA42_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, produceOutput__sigmatch_4809)(tySequence__GR8qmV1kNRcoQ2g76VFy3A** a, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	{
		tyProc__5ZzDzBBqlwfychCMx6jbDw T5_;
		if (!((6 &((NU32)1<<((NU)((*conf).ideCmd)&31U)))!=0)) goto LA3_;
		nimZeroMem((void*)(&T5_), sizeof(tyProc__5ZzDzBBqlwfychCMx6jbDw));
		T5_.ClP_0 = ((TM__wjrA09aH0rT1R7zbrcCaROw_88) (cmpSuggestions__sigmatch_4477)); T5_.ClE_0 = NIM_NIL;
		sort__sigmatch_4818((*a) ? ((*a)->data) : NIM_NIL, ((*a) ? (*a)->Sup.len : 0), T5_, ((tyEnum_SortOrder__TcYjciSJ3jKUT4ygglumjg) 1));
	}
	LA3_: ;
	{
		NI T8_;
		T8_ = ((*a) ? (*a)->Sup.len : 0);
		if (!((*conf).suggestMaxResults < T8_)) goto LA9_;
		unsureAsgnRef((void**) (&(*a)), (tySequence__GR8qmV1kNRcoQ2g76VFy3A*) setLengthSeqV2(((*a))?&((*a))->Sup:NIM_NIL, (&NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_), ((NI) ((*conf).suggestMaxResults))));
	}
	LA9_: ;
	{
		if (!!(((*conf).suggestionResultHook.ClP_0 == 0))) goto LA13_;
		{
			tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg** s;
			NI i;
			NI L;
			NI T16_;
			s = (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg**)0;
			i = ((NI) 0);
			T16_ = ((*a) ? (*a)->Sup.len : 0);
			L = T16_;
			{
				while (1) {
					if (!(i < L)) goto LA18;
					s = &(*a)->data[i];
					(*conf).suggestionResultHook.ClE_0? (*conf).suggestionResultHook.ClP_0((*s), (*conf).suggestionResultHook.ClE_0):((TM__wjrA09aH0rT1R7zbrcCaROw_89)((*conf).suggestionResultHook.ClP_0))((*s));
					i += ((NI) 1);
				} LA18: ;
			}
		}
	}
	goto LA11_;
	LA13_: ;
	{
		{
			tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg** s_2;
			NI i_2;
			NI L_2;
			NI T21_;
			s_2 = (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg**)0;
			i_2 = ((NI) 0);
			T21_ = ((*a) ? (*a)->Sup.len : 0);
			L_2 = T21_;
			{
				while (1) {
					NimStringDesc* T24_;
					if (!(i_2 < L_2)) goto LA23;
					s_2 = &(*a)->data[i_2];
					T24_ = NIM_NIL;
					T24_ = dollar___sigmatch_4762((*s_2));
					suggestWriteln__msgs_431(conf, T24_);
					i_2 += ((NI) 1);
				} LA23: ;
			}
		}
	}
	LA11_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, suggestExprNoCheck__sigmatch_6236)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tySequence__GR8qmV1kNRcoQ2g76VFy3A* outputs;
{	{
		if (!(((NI) 0) < (*c).compilesContextId)) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	(*c).compilesContextId += ((NI) 1);
	outputs = NIM_NIL;
	{
		if (!((*(*(*c).graph).config).ideCmd == ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 1))) goto LA7_;
		sugExpr__sigmatch_6203(c, n, (&outputs));
	}
	goto LA5_;
	LA7_: ;
	{
		if (!((*(*(*c).graph).config).ideCmd == ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 2))) goto LA10_;
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x;
			if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32))) goto LA14_;
			a = copyNode__ast_4324(n);
			x = safeSemExpr__sigmatch_6197(c, (*n)._kind_6.sons->data[((NI) 0)]);
			{
				NIM_BOOL T18_;
				T18_ = (NIM_BOOL)0;
				T18_ = ((*x).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1));
				if (T18_) goto LA19_;
				T18_ = ((*x).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
				LA19_: ;
				if (!T18_) goto LA20_;
				x = (*n)._kind_6.sons->data[((NI) 0)];
			}
			LA20_: ;
			add__ast_4798(a, x);
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_3155(n);
				i_2 = ((NI) 1);
				{
					while (1) {
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x_2;
						if (!(i_2 < colontmp_)) goto LA24;
						i = i_2;
						x_2 = safeSemExpr__sigmatch_6197(c, (*n)._kind_6.sons->data[i]);
						{
							NIM_BOOL T27_;
							T27_ = (NIM_BOOL)0;
							T27_ = ((*x_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1));
							if (T27_) goto LA28_;
							T27_ = ((*x_2).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
							LA28_: ;
							if (!T27_) goto LA29_;
							goto LA22;
						}
						LA29_: ;
						add__ast_4798(a, x_2);
						i_2 += ((NI) 1);
					} LA24: ;
				}
			} LA22: ;
			suggestCall__sigmatch_5153(c, a, n, (&outputs));
		}
		goto LA12_;
		LA14_: ;
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x_3;
			if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 53) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 57) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 56))) goto LA32_;
			x_3 = safeSemExpr__sigmatch_6197(c, n);
			{
				NIM_BOOL T36_;
				T36_ = (NIM_BOOL)0;
				T36_ = ((*x_3).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1));
				if (T36_) goto LA37_;
				T36_ = ((*x_3).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
				LA37_: ;
				if (!T36_) goto LA38_;
				x_3 = n;
			}
			LA38_: ;
			suggestVar__sigmatch_5168(c, x_3, (&outputs));
		}
		goto LA12_;
		LA32_: ;
		LA12_: ;
	}
	goto LA5_;
	LA10_: ;
	LA5_: ;
	(*c).compilesContextId -= ((NI) 1);
	{
		NIM_BOOL T42_;
		NI T43_;
		T42_ = (NIM_BOOL)0;
		T43_ = (outputs ? outputs->Sup.len : 0);
		T42_ = (((NI) 0) < T43_);
		if (!(T42_)) goto LA44_;
		T42_ = ((14 &((NU32)1<<((NU)((*(*(*c).graph).config).ideCmd)&31U)))!=0);
		LA44_: ;
		if (!T42_) goto LA45_;
		produceOutput__sigmatch_4809((&outputs), (*(*c).graph).config);
		suggestQuit__msgs_456();
	}
	LA45_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, suggestExpr__sigmatch_6331)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = exactEquals__msgs_1007((*(*(*c).graph).config).m.trackPos, (*n).info);
		if (!T3_) goto LA4_;
		suggestExprNoCheck__sigmatch_6236(c, n);
	}
	LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCheckPointResult__1fIaGKvTluv8QtOC3X9afKQ, inCheckpoint__sigmatch_5341)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw current, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos) {
	tyEnum_TCheckPointResult__1fIaGKvTluv8QtOC3X9afKQ result;
{	result = (tyEnum_TCheckPointResult__1fIaGKvTluv8QtOC3X9afKQ)0;
	{
		if (!(current.fileIndex == trackPos.fileIndex)) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = (current.line == trackPos.line);
			if (!(T7_)) goto LA8_;
			T7_ = (((NI16)(current.col - trackPos.col) > 0? ((NI16)(current.col - trackPos.col)) : -((NI16)(current.col - trackPos.col))) < ((NI16) 4));
			LA8_: ;
			if (!T7_) goto LA9_;
			result = ((tyEnum_TCheckPointResult__1fIaGKvTluv8QtOC3X9afKQ) 2);
			goto BeforeRet_;
		}
		LA9_: ;
		{
			if (!((NU16)(trackPos.line) <= (NU16)(current.line))) goto LA13_;
			result = ((tyEnum_TCheckPointResult__1fIaGKvTluv8QtOC3X9afKQ) 1);
			goto BeforeRet_;
		}
		LA13_: ;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, semFinishOperands__sigmatch_4203)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				asgnRef((void**) (&(*n)._kind_6.sons->data[i]), prepareOperand__sigmatch_3737(c, (*n)._kind_6.sons->data[i]));
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
static N_NIMCALL(void, Marker_tySequence__LFzufdBEvfOUK6PWh0HUtQ)(void* p, NI op) {
	tySequence__LFzufdBEvfOUK6PWh0HUtQ* a;
	NI T1_;
	a = (tySequence__LFzufdBEvfOUK6PWh0HUtQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].sym, op);
	nimGCvisit((void*)a->data[T1_].firstMismatch.formal, op);
	nimGCvisit((void*)a->data[T1_].diagnostics, op);
	}
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, argTypeToString__sigmatch_362)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg, tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg prefer) {
	NimStringDesc* result;
	result = NIM_NIL;
	{
		if (!((*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 56) || (*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 57))) goto LA3_;
		result = typeToString__types_50((*(*arg)._kind_6.sons->data[((NI) 0)]).typ, prefer);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(arg);
			i_2 = ((NI) 1);
			{
				while (1) {
					NimStringDesc* T8_;
					if (!(i_2 < colontmp_)) goto LA7;
					i = i_2;
					result = resizeString(result, 3);
appendString(result, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_95));
					T8_ = NIM_NIL;
					T8_ = typeToString__types_50((*(*arg)._kind_6.sons->data[i]).typ, prefer);
					result = resizeString(result, (T8_ ? T8_->Sup.len : 0) + 0);
appendString(result, T8_);
					i_2 += ((NI) 1);
				} LA7: ;
			}
		}
	}
	goto LA1_;
	LA3_: ;
	{
		if (!((*arg).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA10_;
		result = copyString(((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_96));
	}
	goto LA1_;
	LA10_: ;
	{
		result = typeToString__types_50((*arg).typ, prefer);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, describeArgs__sigmatch_384)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI startIdx, tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg prefer) {
	NimStringDesc* result;
{	result = NIM_NIL;
	result = ((NimStringDesc*) NIM_NIL);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(n);
		i_2 = startIdx;
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg;
				NimStringDesc* T28_;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				arg = (*n)._kind_6.sons->data[i];
				{
					NimStringDesc* T8_;
					if (!((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 33))) goto LA6_;
					T8_ = NIM_NIL;
					T8_ = renderTree__renderer_46((*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)], 0);
					result = resizeString(result, (T8_ ? T8_->Sup.len : 0) + 0);
appendString(result, T8_);
					result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_94));
					{
						NIM_BOOL T11_;
						T11_ = (NIM_BOOL)0;
						T11_ = ((*arg).typ == 0);
						if (!(T11_)) goto LA12_;
						T11_ = !(((*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115) || (*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 52)));
						LA12_: ;
						if (!T11_) goto LA13_;
						arg = (*c).semOperand(c, (*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 1)], 0);
						asgnRef((void**) (&(*(*n)._kind_6.sons->data[i]).typ), (*arg).typ);
						asgnRef((void**) (&(*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 1)]), arg);
					}
					LA13_: ;
				}
				goto LA4_;
				LA6_: ;
				{
					{
						NIM_BOOL T18_;
						T18_ = (NIM_BOOL)0;
						T18_ = ((*arg).typ == 0);
						if (!(T18_)) goto LA19_;
						T18_ = !(((*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115) || (*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 52) || (*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 88) || (*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 85) || (*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 86) || (*arg).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 87)));
						LA19_: ;
						if (!T18_) goto LA20_;
						arg = (*c).semOperand(c, (*n)._kind_6.sons->data[i], 0);
						asgnRef((void**) (&(*n)._kind_6.sons->data[i]), arg);
					}
					LA20_: ;
				}
				LA4_: ;
				{
					NIM_BOOL T24_;
					T24_ = (NIM_BOOL)0;
					T24_ = !(((*arg).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
					if (!(T24_)) goto LA25_;
					T24_ = ((*(*arg).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 50));
					LA25_: ;
					if (!T24_) goto LA26_;
					goto BeforeRet_;
				}
				LA26_: ;
				T28_ = NIM_NIL;
				T28_ = argTypeToString__sigmatch_362(arg, prefer);
				result = resizeString(result, (T28_ ? T28_->Sup.len : 0) + 0);
appendString(result, T28_);
				{
					NI T31_;
					T31_ = (NI)0;
					T31_ = len__ast_3155(n);
					if (!!((i == (NI)(T31_ - ((NI) 1))))) goto LA32_;
					result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_42));
				}
				LA32_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, matches__sigmatch_4222)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nOrig, tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw* m) {
	tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw marker;
{	{
		if (!((*m).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 5) || (*m).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 6))) goto LA3_;
		(*m).state = ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 1);
		unsureAsgnRef((void**) (&(*m).call), n);
		goto BeforeRet_;
	}
	LA3_: ;
	nimZeroMem((void*)(&marker), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
	initIntSet__pureZcollectionsZintsets_238((&marker));
	matchesAux__sigmatch_3825(c, n, nOrig, m, (&marker));
	{
		if (!((*m).state == ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 2))) goto LA7_;
		goto BeforeRet_;
	}
	LA7_: ;
	{
		NI f;
		NI colontmp_;
		NI i;
		f = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155((*(*m).callee).n);
		i = ((NI) 1);
		{
			while (1) {
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* formal;
				if (!(i < colontmp_)) goto LA11;
				f = i;
				formal = (*(*(*(*m).callee).n)._kind_6.sons->data[f])._kind_4.sym;
				{
					NIM_BOOL T14_;
					T14_ = (NIM_BOOL)0;
					T14_ = containsOrIncl__astalgo_402((&marker), (*formal).position);
					if (!!(T14_)) goto LA15_;
					{
						if (!((*formal).ast == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA19_;
						{
							tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw cnKind;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* container;
							tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T32_;
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T33_;
							if (!((*(*formal).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48))) goto LA23_;
							{
								NIM_BOOL T27_;
								T27_ = (NIM_BOOL)0;
								T27_ = ((*(*formal).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48));
								if (!(T27_)) goto LA28_;
								T27_ = ((*(*(*formal).typ).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 6));
								LA28_: ;
								if (!T27_) goto LA29_;
								cnKind = ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152);
							}
							goto LA25_;
							LA29_: ;
							{
								cnKind = ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41);
							}
							LA25_: ;
							T32_ = NIM_NIL;
							T32_ = arrayConstr__sigmatch_3762(c, (*n).info);
							container = newNodeIT__ast_3342(cnKind, (*n).info, T32_);
							T33_ = NIM_NIL;
							T33_ = implicitConv__sigmatch_3095(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58), (*formal).typ, container, (&(*m)), c);
							setSon__sigmatch_3687((*m).call, (NI)((*formal).position + ((NI) 1)), T33_);
						}
						goto LA21_;
						LA23_: ;
						{
							(*m).state = ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 2);
							(*m).firstMismatch.kind = ((tyEnum_MismatchKind__4mf6T2YBNEEtWBTWMSzL9bw) 5);
							unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
							goto LA9;
						}
						LA21_: ;
					}
					goto LA17_;
					LA19_: ;
					{
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* defaultValue;
						{
							NimStringDesc* T40_;
							if (!((*(*formal).ast).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1))) goto LA38_;
							T40_ = NIM_NIL;
							T40_ = nsuFormatSingleElem(((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_97), (*(*formal).name).s);
							liMessage__msgs_1128((*(*c).graph).config, (*(*m).call).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T40_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__wjrA09aH0rT1R7zbrcCaROw_98, NIM_FALSE);
						}
						LA38_: ;
						{
							if (!(((*(*formal).ast).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg) 19))&31U)))!=0)) goto LA43_;
							(*(*m).call).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg) 19)) & 31);
						}
						LA43_: ;
						defaultValue = copyTree__ast_4432((*formal).ast);
						{
							if (!((*defaultValue).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA47_;
							defaultValue = implicitConv__sigmatch_3095(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58), (*formal).typ, defaultValue, (&(*m)), c);
						}
						LA47_: ;
						{
							tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* existing;
							RootObj* T53_;
							if (!!(((100663296 & (*(*formal).typ).flags) == 0))) goto LA51_;
							T53_ = NIM_NIL;
							T53_ = idTableGet__astalgo_64((*m).bindings, (*((tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA**) (&((*formal).typ)))));
							existing = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) (T53_));
							{
								NIM_BOOL T56_;
								T56_ = (NIM_BOOL)0;
								T56_ = (existing == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
								if (T56_) goto LA57_;
								T56_ = ((*existing).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8));
								LA57_: ;
								if (!T56_) goto LA58_;
								put__sigmatch_120(m, (*formal).typ, (*defaultValue).typ);
							}
							LA58_: ;
						}
						LA51_: ;
						(*defaultValue).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg) 18)) & 31);
						setSon__sigmatch_3687((*m).call, (NI)((*formal).position + ((NI) 1)), defaultValue);
					}
					LA17_: ;
				}
				LA15_: ;
				i += ((NI) 1);
			} LA11: ;
		}
	} LA9: ;
	{
		if (!((*m).state == ((tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg) 2))) goto LA62_;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA** t;
			NI i_2;
			NI L;
			NI T65_;
			t = (tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA**)0;
			i_2 = ((NI) 0);
			T65_ = ((*m).inferredTypes ? (*m).inferredTypes->Sup.len : 0);
			L = T65_;
			{
				while (1) {
					if (!(i_2 < L)) goto LA67;
					t = &(*m).inferredTypes->data[i_2];
					{
						NI T70_;
						T70_ = (NI)0;
						T70_ = len__ast_3990((*t));
						if (!(((NI) 1) < T70_)) goto LA71_;
						asgnRef((void**) (&(*(*t)).sons), (tySequence__vKogasEnJSPhbQmA8r4Y9aA*) setLengthSeqV2(((*(*t)).sons)?&((*(*t)).sons)->Sup:NIM_NIL, (&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_), ((NI) 1)));
					}
					LA71_: ;
					i_2 += ((NI) 1);
				} LA67: ;
			}
		}
	}
	LA62_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA, cmpTypes__sigmatch_3075)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a) {
	tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA result;
	tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw m;
	result = (tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA)0;
	nimZeroMem((void*)(&m), sizeof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw));
	newCandidate__sigmatch_195(c, f, (&m));
	result = typeRel__sigmatch_202((&m), f, a, 0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, suggestStmt__sigmatch_6347)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	suggestExpr__sigmatch_6331(c, n);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, instTypeBoundOp__sigmatch_4368)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* dc, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ op, NI col) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw m;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* f;
{	result = NIM_NIL;
	nimZeroMem((void*)(&m), sizeof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw));
	newCandidate__sigmatch_195(c, (*dc).typ, (&m));
	{
		NI T3_;
		NimStringDesc* T6_;
		T3_ = (NI)0;
		T3_ = len__ast_3990((*dc).typ);
		if (!(T3_ <= col)) goto LA4_;
		T6_ = NIM_NIL;
		T6_ = rawNewString(((*(*dc).name).s ? (*(*dc).name).s->Sup.len : 0) + 22);
appendString(T6_, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_99));
appendString(T6_, (*(*dc).name).s);
appendString(T6_, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_19));
		liMessage__msgs_1128((*(*c).graph).config, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T6_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__wjrA09aH0rT1R7zbrcCaROw_100, NIM_FALSE);
		result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
		goto BeforeRet_;
	}
	LA4_: ;
	f = (*(*dc).typ).sons->data[col];
	{
		if (!(op == ((tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ) 4))) goto LA9_;
		{
			if (!((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22) || (*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21))) goto LA13_;
			f = lastSon__ast_3731(f);
		}
		LA13_: ;
	}
	goto LA7_;
	LA9_: ;
	{
		{
			if (!((*f).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23))) goto LA18_;
			f = lastSon__ast_3731(f);
		}
		LA18_: ;
	}
	LA7_: ;
	{
		tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA T22_;
		NimStringDesc* T25_;
		T22_ = (tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA)0;
		T22_ = typeRel__sigmatch_202((&m), f, t, 0);
		if (!(T22_ == ((tyEnum_TTypeRelation__owa1t43Zclf9bnqhI7konMA) 0))) goto LA23_;
		T25_ = NIM_NIL;
		T25_ = rawNewString(((*(*dc).name).s ? (*(*dc).name).s->Sup.len : 0) + 22);
appendString(T25_, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_99));
appendString(T25_, (*(*dc).name).s);
appendString(T25_, ((NimStringDesc*) &TM__wjrA09aH0rT1R7zbrcCaROw_19));
		liMessage__msgs_1128((*(*c).graph).config, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T25_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__wjrA09aH0rT1R7zbrcCaROw_101, NIM_FALSE);
	}
	goto LA20_;
	LA23_: ;
	{
		result = (*c).semGenerateInstance.ClE_0? (*c).semGenerateInstance.ClP_0(c, dc, m.bindings, info, (*c).semGenerateInstance.ClE_0):((TM__wjrA09aH0rT1R7zbrcCaROw_102)((*c).semGenerateInstance.ClP_0))(c, dc, m.bindings, info);
		{
			if (!(op == ((tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ) 4))) goto LA29_;
		}
		LA29_: ;
	}
	LA20_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, suggestSentinel__sigmatch_6362)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c) {
	tySequence__GR8qmV1kNRcoQ2g76VFy3A* outputs;
{	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*(*(*c).graph).config).ideCmd == ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 1)));
		if (T3_) goto LA4_;
		T3_ = !(((*(*c).module).position == ((NI) ((*(*(*c).graph).config).m.trackPos.fileIndex))));
		LA4_: ;
		if (!T3_) goto LA5_;
		goto BeforeRet_;
	}
	LA5_: ;
	{
		if (!(((NI) 0) < (*c).compilesContextId)) goto LA9_;
		goto BeforeRet_;
	}
	LA9_: ;
	(*c).compilesContextId += ((NI) 1);
	outputs = NIM_NIL;
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* it;
		NI scopeN;
		NIM_BOOL isLocal;
		NIM_BOOL isLocal_2;
		NI scopeN_2;
		it = NIM_NIL;
		scopeN = (NI)0;
		isLocal = (NIM_BOOL)0;
		isLocal_2 = NIM_TRUE;
		scopeN_2 = ((NI) 0);
		{
			tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope;
			tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* current;
			scope = NIM_NIL;
			current = (*c).currentScope;
			{
				while (1) {
					if (!!((current == ((tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ*) NIM_NIL)))) goto LA14;
					scope = current;
					{
						if (!(scope == (*c).topLevelScope)) goto LA17_;
						isLocal_2 = NIM_FALSE;
					}
					LA17_: ;
					scopeN_2 -= ((NI) 1);
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* item;
						tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw it_2;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
						item = NIM_NIL;
						nimZeroMem((void*)(&it_2), sizeof(tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw));
						s = initTabIter__astalgo_3770((&it_2), (*scope).symbols);
						{
							while (1) {
								tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A colontmp_;
								tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ pm;
								if (!!((s == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA21;
								item = s;
								nimZeroMem((void*)(&colontmp_), sizeof(tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A));
								colontmp_.Field0 = item;
								colontmp_.Field1 = scopeN_2;
								colontmp_.Field2 = isLocal_2;
								it = colontmp_.Field0;
								scopeN = colontmp_.Field1;
								isLocal = colontmp_.Field2;
								pm = (tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ)0;
								{
									NIM_BOOL T24_;
									tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw T27_;
									NI T28_;
									tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* T29_;
									NI T30_;
									T24_ = (NIM_BOOL)0;
									T24_ = filterSymNoOpr__sigmatch_4964(it, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), (&pm));
									if (!T24_) goto LA25_;
									T27_ = newLineInfo__msgs_391((*(*(*c).graph).config).m.trackPos.fileIndex, ((NI) 0), ((NI) -1));
									T28_ = (NI)0;
									T28_ = getQuality__sigmatch_5031(it);
									T29_ = NIM_NIL;
									T29_ = symToSuggest__sigmatch_4569((*c).graph, it, isLocal, ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 1), T27_, T28_, ((tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ) 0), NIM_FALSE, scopeN, NIM_FALSE, ((NU16) 0), ((NI) 0));
									outputs = (tySequence__GR8qmV1kNRcoQ2g76VFy3A*) incrSeqV3((TGenericSeq*)(outputs), (&NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_));
									T30_ = outputs->Sup.len++;
									asgnRef((void**) (&outputs->data[T30_]), T29_);
								}
								LA25_: ;
								s = nextIter__astalgo_3755((&it_2), (*scope).symbols);
							} LA21: ;
						}
					}
					current = (*current).parent;
				} LA14: ;
			}
		}
		scopeN_2 -= ((NI) 1);
		isLocal_2 = NIM_FALSE;
		{
			tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg* im;
			NI i;
			NI L;
			NI T32_;
			im = (tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg*)0;
			i = ((NI) 0);
			T32_ = ((*c).imports ? (*c).imports->Sup.len : 0);
			L = T32_;
			{
				while (1) {
					if (!(i < L)) goto LA34;
					im = (&(*c).imports->data[i]);
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s_2;
						NIM_BOOL importHidden;
						s_2 = NIM_NIL;
						importHidden = (((*(*im).m).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 27))&31U)))!=0);
						{
							NIM_BOOL T38_;
							tyObject_RodIter__L6nv9cakjPARHk068AFo6ww rodIt;
							tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* r;
							T38_ = (NIM_BOOL)0;
							T38_ = isCachedModule__modulegraphs_2722((*c).graph, (*im).m);
							if (!T38_) goto LA39_;
							nimZeroMem((void*)(&rodIt), sizeof(tyObject_RodIter__L6nv9cakjPARHk068AFo6ww));
							r = initRodIterAllSyms__icZic_8670((&rodIt), (*(*c).graph).config, (*(*c).graph).cache, (&(*(*c).graph).packed_0), ((NI32) ((*(*im).m).position)), importHidden);
							{
								while (1) {
									tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A colontmp__2;
									tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ pm_2;
									if (!!((r == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA42;
									s_2 = r;
									nimZeroMem((void*)(&colontmp__2), sizeof(tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A));
									colontmp__2.Field0 = s_2;
									colontmp__2.Field1 = scopeN_2;
									colontmp__2.Field2 = isLocal_2;
									it = colontmp__2.Field0;
									scopeN = colontmp__2.Field1;
									isLocal = colontmp__2.Field2;
									pm_2 = (tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ)0;
									{
										NIM_BOOL T45_;
										tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw T48_;
										NI T49_;
										tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* T50_;
										NI T51_;
										T45_ = (NIM_BOOL)0;
										T45_ = filterSymNoOpr__sigmatch_4964(it, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), (&pm_2));
										if (!T45_) goto LA46_;
										T48_ = newLineInfo__msgs_391((*(*(*c).graph).config).m.trackPos.fileIndex, ((NI) 0), ((NI) -1));
										T49_ = (NI)0;
										T49_ = getQuality__sigmatch_5031(it);
										T50_ = NIM_NIL;
										T50_ = symToSuggest__sigmatch_4569((*c).graph, it, isLocal, ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 1), T48_, T49_, ((tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ) 0), NIM_FALSE, scopeN, NIM_FALSE, ((NU16) 0), ((NI) 0));
										outputs = (tySequence__GR8qmV1kNRcoQ2g76VFy3A*) incrSeqV3((TGenericSeq*)(outputs), (&NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_));
										T51_ = outputs->Sup.len++;
										asgnRef((void**) (&outputs->data[T51_]), T50_);
									}
									LA46_: ;
									r = nextRodIter__icZic_8980((&rodIt), (&(*(*c).graph).packed_0));
								} LA42: ;
							}
						}
						goto LA36_;
						LA39_: ;
						{
							{
								tyObject_TSym__3r34mwqcVmg5JFNmiaVncw** s_3;
								tySequence__ed0C0uAUZPhvw3RAc5hfYg* colontmp__3;
								tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* retX60gensym17_;
								NI i_2;
								NI L_2;
								NI T58_;
								s_3 = (tyObject_TSym__3r34mwqcVmg5JFNmiaVncw**)0;
								colontmp__3 = NIM_NIL;
								retX60gensym17_ = (&(*(*c).graph).ifaces->data[(*(*im).m).position].interf);
								{
									if (!importHidden) goto LA56_;
									retX60gensym17_ = (&(*(*c).graph).ifaces->data[(*(*im).m).position].interfHidden);
								}
								LA56_: ;
								colontmp__3 = (*retX60gensym17_).data;
								i_2 = ((NI) 0);
								T58_ = (colontmp__3 ? colontmp__3->Sup.len : 0);
								L_2 = T58_;
								{
									while (1) {
										if (!(i_2 < L_2)) goto LA60;
										s_3 = &colontmp__3->data[i_2];
										{
											tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A colontmp__4;
											tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ pm_3;
											if (!!(((*s_3) == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA63_;
											s_2 = (*s_3);
											nimZeroMem((void*)(&colontmp__4), sizeof(tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A));
											colontmp__4.Field0 = s_2;
											colontmp__4.Field1 = scopeN_2;
											colontmp__4.Field2 = isLocal_2;
											it = colontmp__4.Field0;
											scopeN = colontmp__4.Field1;
											isLocal = colontmp__4.Field2;
											pm_3 = (tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ)0;
											{
												NIM_BOOL T67_;
												tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw T70_;
												NI T71_;
												tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* T72_;
												NI T73_;
												T67_ = (NIM_BOOL)0;
												T67_ = filterSymNoOpr__sigmatch_4964(it, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL), (&pm_3));
												if (!T67_) goto LA68_;
												T70_ = newLineInfo__msgs_391((*(*(*c).graph).config).m.trackPos.fileIndex, ((NI) 0), ((NI) -1));
												T71_ = (NI)0;
												T71_ = getQuality__sigmatch_5031(it);
												T72_ = NIM_NIL;
												T72_ = symToSuggest__sigmatch_4569((*c).graph, it, isLocal, ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 1), T70_, T71_, ((tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ) 0), NIM_FALSE, scopeN, NIM_FALSE, ((NU16) 0), ((NI) 0));
												outputs = (tySequence__GR8qmV1kNRcoQ2g76VFy3A*) incrSeqV3((TGenericSeq*)(outputs), (&NTIseqLsuggestT__GR8qmV1kNRcoQ2g76VFy3A_));
												T73_ = outputs->Sup.len++;
												asgnRef((void**) (&outputs->data[T73_]), T72_);
											}
											LA68_: ;
										}
										LA63_: ;
										i_2 += ((NI) 1);
									} LA60: ;
								}
							}
						}
						LA36_: ;
					}
					i += ((NI) 1);
				} LA34: ;
			}
		}
	}
	(*c).compilesContextId -= ((NI) 1);
	produceOutput__sigmatch_4809((&outputs), (*(*c).graph).config);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, atmsigmatchdotnim_DatInit000)(void) {
static TNimNode* TM__wjrA09aH0rT1R7zbrcCaROw_4_2[2];
static TNimNode* TM__wjrA09aH0rT1R7zbrcCaROw_31_5[5];
static TNimNode* TM__wjrA09aH0rT1R7zbrcCaROw_36_2[2];
static TNimNode* TM__wjrA09aH0rT1R7zbrcCaROw_69_24[24];
static TNimNode* TM__wjrA09aH0rT1R7zbrcCaROw_70_3[3];
NI TM__wjrA09aH0rT1R7zbrcCaROw_72;
static char* NIM_CONST TM__wjrA09aH0rT1R7zbrcCaROw_71[3] = {
"csEmpty", 
"csMatch", 
"csNoMatch"};
static TNimNode* TM__wjrA09aH0rT1R7zbrcCaROw_73_3[3];
static TNimNode* TM__wjrA09aH0rT1R7zbrcCaROw_74_8[8];
NI TM__wjrA09aH0rT1R7zbrcCaROw_76;
static char* NIM_CONST TM__wjrA09aH0rT1R7zbrcCaROw_75[8] = {
"kUnknown", 
"kAlreadyGiven", 
"kUnknownNamedParam", 
"kTypeMismatch", 
"kVarNeeded", 
"kMissingParam", 
"kExtraArg", 
"kPositionalAlreadyGiven"};
static TNimNode* TM__wjrA09aH0rT1R7zbrcCaROw_93_4[4];
static TNimNode TM__wjrA09aH0rT1R7zbrcCaROw_0[59];
NTIobject__JTQD63EOMNGYBEyDiI65hA_.size = sizeof(tyObject_Env_suggestdotnim_getTokenLenFromSource___JTQD63EOMNGYBEyDiI65hA);
NTIobject__JTQD63EOMNGYBEyDiI65hA_.align = NIM_ALIGNOF(tyObject_Env_suggestdotnim_getTokenLenFromSource___JTQD63EOMNGYBEyDiI65hA);
NTIobject__JTQD63EOMNGYBEyDiI65hA_.kind = 17;
NTIobject__JTQD63EOMNGYBEyDiI65hA_.base = (&NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_);
TM__wjrA09aH0rT1R7zbrcCaROw_4_2[0] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[1];
TM__wjrA09aH0rT1R7zbrcCaROw_0[1].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[1].offset = offsetof(tyObject_Env_suggestdotnim_getTokenLenFromSource___JTQD63EOMNGYBEyDiI65hA, colonstate_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[1].typ = (&NTIint__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[1].name = ":state";
TM__wjrA09aH0rT1R7zbrcCaROw_4_2[1] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[2];
TM__wjrA09aH0rT1R7zbrcCaROw_0[2].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[2].offset = offsetof(tyObject_Env_suggestdotnim_getTokenLenFromSource___JTQD63EOMNGYBEyDiI65hA, line1);
TM__wjrA09aH0rT1R7zbrcCaROw_0[2].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[2].name = "line1";
TM__wjrA09aH0rT1R7zbrcCaROw_0[0].len = 2; TM__wjrA09aH0rT1R7zbrcCaROw_0[0].kind = 2; TM__wjrA09aH0rT1R7zbrcCaROw_0[0].sons = &TM__wjrA09aH0rT1R7zbrcCaROw_4_2[0];
NTIobject__JTQD63EOMNGYBEyDiI65hA_.node = &TM__wjrA09aH0rT1R7zbrcCaROw_0[0];
NTIrefobject__2F9cu9at6fEkJGwU3CoFWY3A_.size = sizeof(tyObject_Env_suggestdotnim_getTokenLenFromSource___JTQD63EOMNGYBEyDiI65hA*);
NTIrefobject__2F9cu9at6fEkJGwU3CoFWY3A_.align = NIM_ALIGNOF(tyObject_Env_suggestdotnim_getTokenLenFromSource___JTQD63EOMNGYBEyDiI65hA*);
NTIrefobject__2F9cu9at6fEkJGwU3CoFWY3A_.kind = 22;
NTIrefobject__2F9cu9at6fEkJGwU3CoFWY3A_.base = (&NTIobject__JTQD63EOMNGYBEyDiI65hA_);
NTIrefobject__2F9cu9at6fEkJGwU3CoFWY3A_.marker = Marker_tyRef__2F9cu9at6fEkJGwU3CoFWY3A;
NTIobject__J1TZ8yvjL0AcwEoyPAfoPQ_.size = sizeof(tyObject_Env_sigmatchdotnim_matchUserTypeClass___J1TZ8yvjL0AcwEoyPAfoPQ);
NTIobject__J1TZ8yvjL0AcwEoyPAfoPQ_.align = NIM_ALIGNOF(tyObject_Env_sigmatchdotnim_matchUserTypeClass___J1TZ8yvjL0AcwEoyPAfoPQ);
NTIobject__J1TZ8yvjL0AcwEoyPAfoPQ_.kind = 17;
NTIobject__J1TZ8yvjL0AcwEoyPAfoPQ_.base = (&NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_);
TM__wjrA09aH0rT1R7zbrcCaROw_31_5[0] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[4];
TM__wjrA09aH0rT1R7zbrcCaROw_0[4].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[4].offset = offsetof(tyObject_Env_sigmatchdotnim_matchUserTypeClass___J1TZ8yvjL0AcwEoyPAfoPQ, colonstate_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[4].typ = (&NTIint__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[4].name = ":state";
TM__wjrA09aH0rT1R7zbrcCaROw_31_5[1] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[5];
TM__wjrA09aH0rT1R7zbrcCaROw_0[5].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[5].offset = offsetof(tyObject_Env_sigmatchdotnim_matchUserTypeClass___J1TZ8yvjL0AcwEoyPAfoPQ, errorPrefix1);
TM__wjrA09aH0rT1R7zbrcCaROw_0[5].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[5].name = "errorPrefix1";
TM__wjrA09aH0rT1R7zbrcCaROw_31_5[2] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[6];
TM__wjrA09aH0rT1R7zbrcCaROw_0[6].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[6].offset = offsetof(tyObject_Env_sigmatchdotnim_matchUserTypeClass___J1TZ8yvjL0AcwEoyPAfoPQ, typeClass2);
TM__wjrA09aH0rT1R7zbrcCaROw_0[6].typ = (&NTIptype__q1v0zzhoMWrhMLs6UEp1IA_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[6].name = "typeClass2";
TM__wjrA09aH0rT1R7zbrcCaROw_31_5[3] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[7];
TM__wjrA09aH0rT1R7zbrcCaROw_0[7].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[7].offset = offsetof(tyObject_Env_sigmatchdotnim_matchUserTypeClass___J1TZ8yvjL0AcwEoyPAfoPQ, oldWriteHook3);
TM__wjrA09aH0rT1R7zbrcCaROw_0[7].typ = (&NTIprocLoutput58stringTLOclosureOT__k2HFjxisIgDALbEUFojxaQ_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[7].name = "oldWriteHook3";
TM__wjrA09aH0rT1R7zbrcCaROw_31_5[4] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[8];
TM__wjrA09aH0rT1R7zbrcCaROw_0[8].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[8].offset = offsetof(tyObject_Env_sigmatchdotnim_matchUserTypeClass___J1TZ8yvjL0AcwEoyPAfoPQ, diagnostics4);
TM__wjrA09aH0rT1R7zbrcCaROw_0[8].typ = (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[8].name = "diagnostics4";
TM__wjrA09aH0rT1R7zbrcCaROw_0[3].len = 5; TM__wjrA09aH0rT1R7zbrcCaROw_0[3].kind = 2; TM__wjrA09aH0rT1R7zbrcCaROw_0[3].sons = &TM__wjrA09aH0rT1R7zbrcCaROw_31_5[0];
NTIobject__J1TZ8yvjL0AcwEoyPAfoPQ_.node = &TM__wjrA09aH0rT1R7zbrcCaROw_0[3];
NTIrefobject__LPNfKrTCyieb604nvY2VZA_.size = sizeof(tyObject_Env_sigmatchdotnim_matchUserTypeClass___J1TZ8yvjL0AcwEoyPAfoPQ*);
NTIrefobject__LPNfKrTCyieb604nvY2VZA_.align = NIM_ALIGNOF(tyObject_Env_sigmatchdotnim_matchUserTypeClass___J1TZ8yvjL0AcwEoyPAfoPQ*);
NTIrefobject__LPNfKrTCyieb604nvY2VZA_.kind = 22;
NTIrefobject__LPNfKrTCyieb604nvY2VZA_.base = (&NTIobject__J1TZ8yvjL0AcwEoyPAfoPQ_);
NTIrefobject__LPNfKrTCyieb604nvY2VZA_.marker = Marker_tyRef__LPNfKrTCyieb604nvY2VZA;
NTILpsym_ptypeT__7ojGQ7p3GL8CscnPtcFVrQ_.size = sizeof(tyTuple__7ojGQ7p3GL8CscnPtcFVrQ);
NTILpsym_ptypeT__7ojGQ7p3GL8CscnPtcFVrQ_.align = NIM_ALIGNOF(tyTuple__7ojGQ7p3GL8CscnPtcFVrQ);
NTILpsym_ptypeT__7ojGQ7p3GL8CscnPtcFVrQ_.kind = 18;
NTILpsym_ptypeT__7ojGQ7p3GL8CscnPtcFVrQ_.base = 0;
NTILpsym_ptypeT__7ojGQ7p3GL8CscnPtcFVrQ_.flags = 2;
TM__wjrA09aH0rT1R7zbrcCaROw_36_2[0] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[10];
TM__wjrA09aH0rT1R7zbrcCaROw_0[10].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[10].offset = offsetof(tyTuple__7ojGQ7p3GL8CscnPtcFVrQ, Field0);
TM__wjrA09aH0rT1R7zbrcCaROw_0[10].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[10].name = "Field0";
TM__wjrA09aH0rT1R7zbrcCaROw_36_2[1] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[11];
TM__wjrA09aH0rT1R7zbrcCaROw_0[11].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[11].offset = offsetof(tyTuple__7ojGQ7p3GL8CscnPtcFVrQ, Field1);
TM__wjrA09aH0rT1R7zbrcCaROw_0[11].typ = (&NTIptype__q1v0zzhoMWrhMLs6UEp1IA_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[11].name = "Field1";
TM__wjrA09aH0rT1R7zbrcCaROw_0[9].len = 2; TM__wjrA09aH0rT1R7zbrcCaROw_0[9].kind = 2; TM__wjrA09aH0rT1R7zbrcCaROw_0[9].sons = &TM__wjrA09aH0rT1R7zbrcCaROw_36_2[0];
NTILpsym_ptypeT__7ojGQ7p3GL8CscnPtcFVrQ_.node = &TM__wjrA09aH0rT1R7zbrcCaROw_0[9];
NTIseqLLpsym_ptypeTT__r9afowSCR9cYl2NdMwuF5Jtg_.size = sizeof(tySequence__r9afowSCR9cYl2NdMwuF5Jtg*);
NTIseqLLpsym_ptypeTT__r9afowSCR9cYl2NdMwuF5Jtg_.align = NIM_ALIGNOF(tySequence__r9afowSCR9cYl2NdMwuF5Jtg*);
NTIseqLLpsym_ptypeTT__r9afowSCR9cYl2NdMwuF5Jtg_.kind = 24;
NTIseqLLpsym_ptypeTT__r9afowSCR9cYl2NdMwuF5Jtg_.base = (&NTILpsym_ptypeT__7ojGQ7p3GL8CscnPtcFVrQ_);
NTIseqLLpsym_ptypeTT__r9afowSCR9cYl2NdMwuF5Jtg_.flags = 2;
NTIseqLLpsym_ptypeTT__r9afowSCR9cYl2NdMwuF5Jtg_.marker = Marker_tySequence__r9afowSCR9cYl2NdMwuF5Jtg;
NTItcandidate__9b35s9cLOLunJ2l2Vo3cQTlw_.size = sizeof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw);
NTItcandidate__9b35s9cLOLunJ2l2Vo3cQTlw_.align = NIM_ALIGNOF(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw);
NTItcandidate__9b35s9cLOLunJ2l2Vo3cQTlw_.kind = 18;
NTItcandidate__9b35s9cLOLunJ2l2Vo3cQTlw_.base = 0;
TM__wjrA09aH0rT1R7zbrcCaROw_69_24[0] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[13];
TM__wjrA09aH0rT1R7zbrcCaROw_0[13].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[13].offset = offsetof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw, c);
TM__wjrA09aH0rT1R7zbrcCaROw_0[13].typ = (&NTIpcontext__C5LQliQ3Detta8PpLynVjQ_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[13].name = "c";
TM__wjrA09aH0rT1R7zbrcCaROw_69_24[1] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[14];
TM__wjrA09aH0rT1R7zbrcCaROw_0[14].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[14].offset = offsetof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw, exactMatches);
TM__wjrA09aH0rT1R7zbrcCaROw_0[14].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[14].name = "exactMatches";
TM__wjrA09aH0rT1R7zbrcCaROw_69_24[2] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[15];
TM__wjrA09aH0rT1R7zbrcCaROw_0[15].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[15].offset = offsetof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw, genericMatches);
TM__wjrA09aH0rT1R7zbrcCaROw_0[15].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[15].name = "genericMatches";
TM__wjrA09aH0rT1R7zbrcCaROw_69_24[3] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[16];
TM__wjrA09aH0rT1R7zbrcCaROw_0[16].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[16].offset = offsetof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw, subtypeMatches);
TM__wjrA09aH0rT1R7zbrcCaROw_0[16].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[16].name = "subtypeMatches";
TM__wjrA09aH0rT1R7zbrcCaROw_69_24[4] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[17];
TM__wjrA09aH0rT1R7zbrcCaROw_0[17].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[17].offset = offsetof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw, intConvMatches);
TM__wjrA09aH0rT1R7zbrcCaROw_0[17].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[17].name = "intConvMatches";
TM__wjrA09aH0rT1R7zbrcCaROw_69_24[5] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[18];
TM__wjrA09aH0rT1R7zbrcCaROw_0[18].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[18].offset = offsetof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw, convMatches);
TM__wjrA09aH0rT1R7zbrcCaROw_0[18].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[18].name = "convMatches";
TM__wjrA09aH0rT1R7zbrcCaROw_69_24[6] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[19];
NTItcandidatestate__OWU1uSiYyPkPf9adpdtClBg_.size = sizeof(tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg);
NTItcandidatestate__OWU1uSiYyPkPf9adpdtClBg_.align = NIM_ALIGNOF(tyEnum_TCandidateState__OWU1uSiYyPkPf9adpdtClBg);
NTItcandidatestate__OWU1uSiYyPkPf9adpdtClBg_.kind = 14;
NTItcandidatestate__OWU1uSiYyPkPf9adpdtClBg_.base = 0;
NTItcandidatestate__OWU1uSiYyPkPf9adpdtClBg_.flags = 3;
for (TM__wjrA09aH0rT1R7zbrcCaROw_72 = 0; TM__wjrA09aH0rT1R7zbrcCaROw_72 < 3; TM__wjrA09aH0rT1R7zbrcCaROw_72++) {
TM__wjrA09aH0rT1R7zbrcCaROw_0[TM__wjrA09aH0rT1R7zbrcCaROw_72+20].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[TM__wjrA09aH0rT1R7zbrcCaROw_72+20].offset = TM__wjrA09aH0rT1R7zbrcCaROw_72;
TM__wjrA09aH0rT1R7zbrcCaROw_0[TM__wjrA09aH0rT1R7zbrcCaROw_72+20].name = TM__wjrA09aH0rT1R7zbrcCaROw_71[TM__wjrA09aH0rT1R7zbrcCaROw_72];
TM__wjrA09aH0rT1R7zbrcCaROw_70_3[TM__wjrA09aH0rT1R7zbrcCaROw_72] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[TM__wjrA09aH0rT1R7zbrcCaROw_72+20];
}
TM__wjrA09aH0rT1R7zbrcCaROw_0[23].len = 3; TM__wjrA09aH0rT1R7zbrcCaROw_0[23].kind = 2; TM__wjrA09aH0rT1R7zbrcCaROw_0[23].sons = &TM__wjrA09aH0rT1R7zbrcCaROw_70_3[0];
NTItcandidatestate__OWU1uSiYyPkPf9adpdtClBg_.node = &TM__wjrA09aH0rT1R7zbrcCaROw_0[23];
TM__wjrA09aH0rT1R7zbrcCaROw_0[19].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[19].offset = offsetof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw, state);
TM__wjrA09aH0rT1R7zbrcCaROw_0[19].typ = (&NTItcandidatestate__OWU1uSiYyPkPf9adpdtClBg_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[19].name = "state";
TM__wjrA09aH0rT1R7zbrcCaROw_69_24[7] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[24];
TM__wjrA09aH0rT1R7zbrcCaROw_0[24].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[24].offset = offsetof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw, callee);
TM__wjrA09aH0rT1R7zbrcCaROw_0[24].typ = (&NTIptype__q1v0zzhoMWrhMLs6UEp1IA_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[24].name = "callee";
TM__wjrA09aH0rT1R7zbrcCaROw_69_24[8] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[25];
TM__wjrA09aH0rT1R7zbrcCaROw_0[25].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[25].offset = offsetof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw, calleeSym);
TM__wjrA09aH0rT1R7zbrcCaROw_0[25].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[25].name = "calleeSym";
TM__wjrA09aH0rT1R7zbrcCaROw_69_24[9] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[26];
TM__wjrA09aH0rT1R7zbrcCaROw_0[26].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[26].offset = offsetof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw, calleeScope);
TM__wjrA09aH0rT1R7zbrcCaROw_0[26].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[26].name = "calleeScope";
TM__wjrA09aH0rT1R7zbrcCaROw_69_24[10] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[27];
TM__wjrA09aH0rT1R7zbrcCaROw_0[27].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[27].offset = offsetof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw, call);
TM__wjrA09aH0rT1R7zbrcCaROw_0[27].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[27].name = "call";
TM__wjrA09aH0rT1R7zbrcCaROw_69_24[11] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[28];
TM__wjrA09aH0rT1R7zbrcCaROw_0[28].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[28].offset = offsetof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw, bindings);
TM__wjrA09aH0rT1R7zbrcCaROw_0[28].typ = (&NTItidtable__Cs7vbulfMjKciTA2Uv9b6vQ_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[28].name = "bindings";
TM__wjrA09aH0rT1R7zbrcCaROw_69_24[12] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[29];
TM__wjrA09aH0rT1R7zbrcCaROw_0[29].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[29].offset = offsetof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw, magic);
TM__wjrA09aH0rT1R7zbrcCaROw_0[29].typ = (&NTItmagic__3qAy6bDUDlF8Fc2RR6pF9ag_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[29].name = "magic";
TM__wjrA09aH0rT1R7zbrcCaROw_69_24[13] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[30];
TM__wjrA09aH0rT1R7zbrcCaROw_0[30].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[30].offset = offsetof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw, baseTypeMatch);
TM__wjrA09aH0rT1R7zbrcCaROw_0[30].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[30].name = "baseTypeMatch";
TM__wjrA09aH0rT1R7zbrcCaROw_69_24[14] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[31];
TM__wjrA09aH0rT1R7zbrcCaROw_0[31].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[31].offset = offsetof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw, fauxMatch);
TM__wjrA09aH0rT1R7zbrcCaROw_0[31].typ = (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[31].name = "fauxMatch";
TM__wjrA09aH0rT1R7zbrcCaROw_69_24[15] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[32];
TM__wjrA09aH0rT1R7zbrcCaROw_0[32].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[32].offset = offsetof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw, genericConverter);
TM__wjrA09aH0rT1R7zbrcCaROw_0[32].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[32].name = "genericConverter";
TM__wjrA09aH0rT1R7zbrcCaROw_69_24[16] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[33];
TM__wjrA09aH0rT1R7zbrcCaROw_0[33].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[33].offset = offsetof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw, coerceDistincts);
TM__wjrA09aH0rT1R7zbrcCaROw_0[33].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[33].name = "coerceDistincts";
TM__wjrA09aH0rT1R7zbrcCaROw_69_24[17] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[34];
TM__wjrA09aH0rT1R7zbrcCaROw_0[34].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[34].offset = offsetof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw, typedescMatched);
TM__wjrA09aH0rT1R7zbrcCaROw_0[34].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[34].name = "typedescMatched";
TM__wjrA09aH0rT1R7zbrcCaROw_69_24[18] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[35];
TM__wjrA09aH0rT1R7zbrcCaROw_0[35].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[35].offset = offsetof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw, isNoCall);
TM__wjrA09aH0rT1R7zbrcCaROw_0[35].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[35].name = "isNoCall";
TM__wjrA09aH0rT1R7zbrcCaROw_69_24[19] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[36];
TM__wjrA09aH0rT1R7zbrcCaROw_0[36].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[36].offset = offsetof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw, inferredTypes);
TM__wjrA09aH0rT1R7zbrcCaROw_0[36].typ = (&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[36].name = "inferredTypes";
TM__wjrA09aH0rT1R7zbrcCaROw_69_24[20] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[37];
TM__wjrA09aH0rT1R7zbrcCaROw_0[37].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[37].offset = offsetof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw, diagnostics);
TM__wjrA09aH0rT1R7zbrcCaROw_0[37].typ = (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[37].name = "diagnostics";
TM__wjrA09aH0rT1R7zbrcCaROw_69_24[21] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[38];
TM__wjrA09aH0rT1R7zbrcCaROw_0[38].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[38].offset = offsetof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw, inheritancePenalty);
TM__wjrA09aH0rT1R7zbrcCaROw_0[38].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[38].name = "inheritancePenalty";
TM__wjrA09aH0rT1R7zbrcCaROw_69_24[22] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[39];
NTImismatchinfo__7DZVQMEKp3NTauLRe48cLw_.size = sizeof(tyObject_MismatchInfo__7DZVQMEKp3NTauLRe48cLw);
NTImismatchinfo__7DZVQMEKp3NTauLRe48cLw_.align = NIM_ALIGNOF(tyObject_MismatchInfo__7DZVQMEKp3NTauLRe48cLw);
NTImismatchinfo__7DZVQMEKp3NTauLRe48cLw_.kind = 18;
NTImismatchinfo__7DZVQMEKp3NTauLRe48cLw_.base = 0;
NTImismatchinfo__7DZVQMEKp3NTauLRe48cLw_.flags = 2;
TM__wjrA09aH0rT1R7zbrcCaROw_73_3[0] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[41];
NTImismatchkind__4mf6T2YBNEEtWBTWMSzL9bw_.size = sizeof(tyEnum_MismatchKind__4mf6T2YBNEEtWBTWMSzL9bw);
NTImismatchkind__4mf6T2YBNEEtWBTWMSzL9bw_.align = NIM_ALIGNOF(tyEnum_MismatchKind__4mf6T2YBNEEtWBTWMSzL9bw);
NTImismatchkind__4mf6T2YBNEEtWBTWMSzL9bw_.kind = 14;
NTImismatchkind__4mf6T2YBNEEtWBTWMSzL9bw_.base = 0;
NTImismatchkind__4mf6T2YBNEEtWBTWMSzL9bw_.flags = 3;
for (TM__wjrA09aH0rT1R7zbrcCaROw_76 = 0; TM__wjrA09aH0rT1R7zbrcCaROw_76 < 8; TM__wjrA09aH0rT1R7zbrcCaROw_76++) {
TM__wjrA09aH0rT1R7zbrcCaROw_0[TM__wjrA09aH0rT1R7zbrcCaROw_76+42].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[TM__wjrA09aH0rT1R7zbrcCaROw_76+42].offset = TM__wjrA09aH0rT1R7zbrcCaROw_76;
TM__wjrA09aH0rT1R7zbrcCaROw_0[TM__wjrA09aH0rT1R7zbrcCaROw_76+42].name = TM__wjrA09aH0rT1R7zbrcCaROw_75[TM__wjrA09aH0rT1R7zbrcCaROw_76];
TM__wjrA09aH0rT1R7zbrcCaROw_74_8[TM__wjrA09aH0rT1R7zbrcCaROw_76] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[TM__wjrA09aH0rT1R7zbrcCaROw_76+42];
}
TM__wjrA09aH0rT1R7zbrcCaROw_0[50].len = 8; TM__wjrA09aH0rT1R7zbrcCaROw_0[50].kind = 2; TM__wjrA09aH0rT1R7zbrcCaROw_0[50].sons = &TM__wjrA09aH0rT1R7zbrcCaROw_74_8[0];
NTImismatchkind__4mf6T2YBNEEtWBTWMSzL9bw_.node = &TM__wjrA09aH0rT1R7zbrcCaROw_0[50];
TM__wjrA09aH0rT1R7zbrcCaROw_0[41].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[41].offset = offsetof(tyObject_MismatchInfo__7DZVQMEKp3NTauLRe48cLw, kind);
TM__wjrA09aH0rT1R7zbrcCaROw_0[41].typ = (&NTImismatchkind__4mf6T2YBNEEtWBTWMSzL9bw_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[41].name = "kind";
TM__wjrA09aH0rT1R7zbrcCaROw_73_3[1] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[51];
TM__wjrA09aH0rT1R7zbrcCaROw_0[51].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[51].offset = offsetof(tyObject_MismatchInfo__7DZVQMEKp3NTauLRe48cLw, arg);
TM__wjrA09aH0rT1R7zbrcCaROw_0[51].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[51].name = "arg";
TM__wjrA09aH0rT1R7zbrcCaROw_73_3[2] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[52];
TM__wjrA09aH0rT1R7zbrcCaROw_0[52].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[52].offset = offsetof(tyObject_MismatchInfo__7DZVQMEKp3NTauLRe48cLw, formal);
TM__wjrA09aH0rT1R7zbrcCaROw_0[52].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[52].name = "formal";
TM__wjrA09aH0rT1R7zbrcCaROw_0[40].len = 3; TM__wjrA09aH0rT1R7zbrcCaROw_0[40].kind = 2; TM__wjrA09aH0rT1R7zbrcCaROw_0[40].sons = &TM__wjrA09aH0rT1R7zbrcCaROw_73_3[0];
NTImismatchinfo__7DZVQMEKp3NTauLRe48cLw_.node = &TM__wjrA09aH0rT1R7zbrcCaROw_0[40];
TM__wjrA09aH0rT1R7zbrcCaROw_0[39].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[39].offset = offsetof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw, firstMismatch);
TM__wjrA09aH0rT1R7zbrcCaROw_0[39].typ = (&NTImismatchinfo__7DZVQMEKp3NTauLRe48cLw_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[39].name = "firstMismatch";
TM__wjrA09aH0rT1R7zbrcCaROw_69_24[23] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[53];
TM__wjrA09aH0rT1R7zbrcCaROw_0[53].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[53].offset = offsetof(tyObject_TCandidate__9b35s9cLOLunJ2l2Vo3cQTlw, diagnosticsEnabled);
TM__wjrA09aH0rT1R7zbrcCaROw_0[53].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[53].name = "diagnosticsEnabled";
TM__wjrA09aH0rT1R7zbrcCaROw_0[12].len = 24; TM__wjrA09aH0rT1R7zbrcCaROw_0[12].kind = 2; TM__wjrA09aH0rT1R7zbrcCaROw_0[12].sons = &TM__wjrA09aH0rT1R7zbrcCaROw_69_24[0];
NTItcandidate__9b35s9cLOLunJ2l2Vo3cQTlw_.node = &TM__wjrA09aH0rT1R7zbrcCaROw_0[12];
NTIcandidateerror__gFDKCwBunKZtG86yhpxUMQ_.size = sizeof(tyObject_CandidateError__gFDKCwBunKZtG86yhpxUMQ);
NTIcandidateerror__gFDKCwBunKZtG86yhpxUMQ_.align = NIM_ALIGNOF(tyObject_CandidateError__gFDKCwBunKZtG86yhpxUMQ);
NTIcandidateerror__gFDKCwBunKZtG86yhpxUMQ_.kind = 18;
NTIcandidateerror__gFDKCwBunKZtG86yhpxUMQ_.base = 0;
NTIcandidateerror__gFDKCwBunKZtG86yhpxUMQ_.flags = 2;
TM__wjrA09aH0rT1R7zbrcCaROw_93_4[0] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[55];
TM__wjrA09aH0rT1R7zbrcCaROw_0[55].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[55].offset = offsetof(tyObject_CandidateError__gFDKCwBunKZtG86yhpxUMQ, sym);
TM__wjrA09aH0rT1R7zbrcCaROw_0[55].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[55].name = "sym";
TM__wjrA09aH0rT1R7zbrcCaROw_93_4[1] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[56];
TM__wjrA09aH0rT1R7zbrcCaROw_0[56].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[56].offset = offsetof(tyObject_CandidateError__gFDKCwBunKZtG86yhpxUMQ, firstMismatch);
TM__wjrA09aH0rT1R7zbrcCaROw_0[56].typ = (&NTImismatchinfo__7DZVQMEKp3NTauLRe48cLw_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[56].name = "firstMismatch";
TM__wjrA09aH0rT1R7zbrcCaROw_93_4[2] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[57];
TM__wjrA09aH0rT1R7zbrcCaROw_0[57].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[57].offset = offsetof(tyObject_CandidateError__gFDKCwBunKZtG86yhpxUMQ, diagnostics);
TM__wjrA09aH0rT1R7zbrcCaROw_0[57].typ = (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[57].name = "diagnostics";
TM__wjrA09aH0rT1R7zbrcCaROw_93_4[3] = &TM__wjrA09aH0rT1R7zbrcCaROw_0[58];
TM__wjrA09aH0rT1R7zbrcCaROw_0[58].kind = 1;
TM__wjrA09aH0rT1R7zbrcCaROw_0[58].offset = offsetof(tyObject_CandidateError__gFDKCwBunKZtG86yhpxUMQ, enabled);
TM__wjrA09aH0rT1R7zbrcCaROw_0[58].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__wjrA09aH0rT1R7zbrcCaROw_0[58].name = "enabled";
TM__wjrA09aH0rT1R7zbrcCaROw_0[54].len = 4; TM__wjrA09aH0rT1R7zbrcCaROw_0[54].kind = 2; TM__wjrA09aH0rT1R7zbrcCaROw_0[54].sons = &TM__wjrA09aH0rT1R7zbrcCaROw_93_4[0];
NTIcandidateerror__gFDKCwBunKZtG86yhpxUMQ_.node = &TM__wjrA09aH0rT1R7zbrcCaROw_0[54];
NTIcandidateerrors__LFzufdBEvfOUK6PWh0HUtQ_.size = sizeof(tySequence__LFzufdBEvfOUK6PWh0HUtQ*);
NTIcandidateerrors__LFzufdBEvfOUK6PWh0HUtQ_.align = NIM_ALIGNOF(tySequence__LFzufdBEvfOUK6PWh0HUtQ*);
NTIcandidateerrors__LFzufdBEvfOUK6PWh0HUtQ_.kind = 24;
NTIcandidateerrors__LFzufdBEvfOUK6PWh0HUtQ_.base = (&NTIcandidateerror__gFDKCwBunKZtG86yhpxUMQ_);
NTIcandidateerrors__LFzufdBEvfOUK6PWh0HUtQ_.flags = 2;
NTIcandidateerrors__LFzufdBEvfOUK6PWh0HUtQ_.marker = Marker_tySequence__LFzufdBEvfOUK6PWh0HUtQ;
}

