/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64
#define NIM_EmulateOverflowChecks

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw;
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ;
typedef struct tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA;
typedef struct tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA;
typedef struct tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw;
typedef struct tySequence__ed0C0uAUZPhvw3RAc5hfYg tySequence__ed0C0uAUZPhvw3RAc5hfYg;
typedef struct tySequence__vvBerF0axaNtu9aMA2gnsrA tySequence__vvBerF0axaNtu9aMA2gnsrA;
typedef struct tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ;
typedef struct tySequence__ZQPym9bf1jM5qaSn7LUXMKA tySequence__ZQPym9bf1jM5qaSn7LUXMKA;
typedef struct tySequence__9c3OY0aBmSBgwdsnBAPf4Ag tySequence__9c3OY0aBmSBgwdsnBAPf4Ag;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw;
typedef struct tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ;
typedef struct tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg;
typedef struct tySequence__Jhh6ks9carRtwV9aOuM8yMNw tySequence__Jhh6ks9carRtwV9aOuM8yMNw;
typedef struct tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw tySequence__Bis5AbpONWcIRrPyPJS8Yw;
typedef struct tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg;
typedef struct tySequence__E8pi9b5QNahsURYzXMjh3qw tySequence__E8pi9b5QNahsURYzXMjh3qw;
typedef struct tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg;
typedef struct tySequence__XDpbjnuseLNZDGLBQ2Qzow tySequence__XDpbjnuseLNZDGLBQ2Qzow;
typedef struct tyObject_Table__cBohObSCAwRxvYFXQHv2wA tyObject_Table__cBohObSCAwRxvYFXQHv2wA;
typedef struct tySequence__QqvaCqCpEE1QmQZbcZLi5A tySequence__QqvaCqCpEE1QmQZbcZLi5A;
typedef struct tySequence__RNhZxf20g9beyq5VBOGxhDg tySequence__RNhZxf20g9beyq5VBOGxhDg;
typedef struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ;
typedef struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ tySequence__lFbCtu5P2Kf7YDYtGjkxAQ;
typedef struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA;
typedef struct tySequence__ijtae5OneaLys0hN9alAicA tySequence__ijtae5OneaLys0hN9alAicA;
typedef struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w;
typedef struct tySequence__SerjNoUujW2dUouVBrJiCw tySequence__SerjNoUujW2dUouVBrJiCw;
typedef struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyObject_Table__r0v8BdcBPKhl73K8p2VMUA;
typedef struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g tySequence__K9agbtcb0qPZuSJFXB9cTe6g;
typedef struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg;
typedef struct tySequence__m88qdML9cQOuqGAQn6XWL1A tySequence__m88qdML9cQOuqGAQn6XWL1A;
typedef struct tyObject_Table__1hIWbTQWYT4BmhdESze57A tyObject_Table__1hIWbTQWYT4BmhdESze57A;
typedef struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ tySequence__naEbXEp9b9aiW1zXJorqf9cXQ;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA;
typedef struct tyObject_Table__imojfg883tkWsWJwyshGqQ tyObject_Table__imojfg883tkWsWJwyshGqQ;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg tyObject_Table__BCPh85PHtwxox9bv7NLFrlg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA;
typedef struct tySequence__KgiZ29chkJAD01p9aLRB32qw tySequence__KgiZ29chkJAD01p9aLRB32qw;
typedef struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A tyObject_Table__LM44poVdVEn4Mo4N4L8c3A;
typedef struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw tySequence__rkYRZrbHVYL3nhXlQW3K9bw;
typedef struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ tySequence__IRFEb1e9bxgbJLuB5xrdZsQ;
typedef struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ;
typedef struct tySequence__YmPd0eWfcTfrVYrthlXPYA tySequence__YmPd0eWfcTfrVYrthlXPYA;
typedef struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q;
typedef struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg tySequence__Hz5SYwQU29b9aFLt09blvVQPg;
typedef struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg tyObject_Table__R7JnJQEipxxOlJWXQz7jWg;
typedef struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ tySequence__3G9aA9cLXaPxuRxMKm3anacQ;
typedef struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q tySequence__bPFv6ypvvCX2A9a9al8utL2Q;
typedef struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg;
typedef struct tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg;
typedef struct tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A;
typedef struct tyObject_RodIter__L6nv9cakjPARHk068AFo6ww tyObject_RodIter__L6nv9cakjPARHk068AFo6ww;
typedef struct tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ;
typedef struct tySequence__lo3S1lKyiPLhGGB9cBawd6A tySequence__lo3S1lKyiPLhGGB9cBawd6A;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw;
typedef struct tySequence__EK3kb9a029axOL6ZINxWj1hw tySequence__EK3kb9a029axOL6ZINxWj1hw;
typedef struct tyTuple__Ztb9b8BdGY9bQ5Qd69ajoC2fQ tyTuple__Ztb9b8BdGY9bQ5Qd69ajoC2fQ;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ;
typedef struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g tySequence__qeAsXh2i1GAL5Nl0g3OP8g;
typedef struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ;
typedef struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag;
typedef struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg;
typedef struct tySequence__4Murtwnm0Fyc7F9acrytEXw tySequence__4Murtwnm0Fyc7F9acrytEXw;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw;
typedef struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg tySequence__QnmOtn1Iv4LvxOXoMn8Rbg;
typedef struct tySequence__oKtVqsc9bQVCNyrijELM4OQ tySequence__oKtVqsc9bQVCNyrijELM4OQ;
typedef struct tySequence__qy6Iwdy00wN560qud54HTg tySequence__qy6Iwdy00wN560qud54HTg;
typedef struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ tySequence__k67v9bwvvQDmS1ynyGGUbeQ;
typedef struct tySequence__cLsClAAfd0MKkoBQVyvdvw tySequence__cLsClAAfd0MKkoBQVyvdvw;
typedef struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg tySequence__q9bTuOB0JXh1iZ3CSGdRLbg;
typedef struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw;
typedef struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ;
typedef struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ;
typedef struct tySequence__C3r8jsj9chA4sIlYfDN5aDw tySequence__C3r8jsj9chA4sIlYfDN5aDw;
typedef struct tyObject_HeapQueue__MBC6eEbMfekVnGqjI07yVg tyObject_HeapQueue__MBC6eEbMfekVnGqjI07yVg;
typedef struct tySequence__wDFGR0GrXEVcAPtPuTlVAA tySequence__wDFGR0GrXEVcAPtPuTlVAA;
typedef struct tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A;
typedef struct tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA;
typedef struct tyTuple__kuMQ1fbjJlHtwKTmBGAe6g tyTuple__kuMQ1fbjJlHtwKTmBGAe6g;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
typedef struct tyObject_TOverloadIter__CvTtbgSac6VxMVCfhzIzkg tyObject_TOverloadIter__CvTtbgSac6VxMVCfhzIzkg;
typedef struct tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q;
typedef struct tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA;
typedef struct tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w;
typedef struct tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA;
typedef struct tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg;
typedef struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ tyTuple__NAaJgGVgNmlGoqmiWxdOHQ;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct tyTuple__VbApVidEWCFLq9a29bPtaS7A tyTuple__VbApVidEWCFLq9a29bPtaS7A;
typedef struct tySequence__k7EQb9bN3Uhl608xoPGMRJA tySequence__k7EQb9bN3Uhl608xoPGMRJA;
typedef struct tyTuple__toqrUPSdp8zSxOdlxMJj9cA tyTuple__toqrUPSdp8zSxOdlxMJj9cA;
typedef struct tyTuple__EbsafWGli8bW2GRJQ9apsjA tyTuple__EbsafWGli8bW2GRJQ9apsjA;
typedef struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg tyTuple__UluY8x0Nj6cp9b0o88wJ0lg;
typedef struct tySequence__dlD6tEGzYLLpKVq3XwuFlA tySequence__dlD6tEGzYLLpKVq3XwuFlA;
typedef struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ;
typedef struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg;
typedef struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ;
typedef struct tyTuple__rZZA0skon1OsHdiEvT8RZQ tyTuple__rZZA0skon1OsHdiEvT8RZQ;
typedef struct tySequence__6OFCSvqRaxyEgUqWtnZSlw tySequence__6OFCSvqRaxyEgUqWtnZSlw;
typedef struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q;
typedef struct tySequence__UnGSk9aaLosDroi2QDrlOfQ tySequence__UnGSk9aaLosDroi2QDrlOfQ;
typedef struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA tyTuple__q13Zt16VkCqu6Zg5jWqwHA;
typedef struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA tyTuple__aWN9bNzF9bubXNJV9ciomgpfA;
typedef struct tySequence__m4PVWjcAAjfxlwJxLkKn8A tySequence__m4PVWjcAAjfxlwJxLkKn8A;
typedef struct tyTuple__RWXAsQlFoGYyEQZp1G65sg tyTuple__RWXAsQlFoGYyEQZp1G65sg;
typedef struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg;
typedef struct tyTuple__RmGJuqOgEaHckHndh0LEsw tyTuple__RmGJuqOgEaHckHndh0LEsw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__J4cxakKjhKxTIJR9bojMmXw tyTuple__J4cxakKjhKxTIJR9bojMmXw;
typedef struct tySequence__i89c5kdtWKzK3OEiI81pkkw tySequence__i89c5kdtWKzK3OEiI81pkkw;
typedef struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A;
typedef struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ;
typedef struct tySequence__GR8qmV1kNRcoQ2g76VFy3A tySequence__GR8qmV1kNRcoQ2g76VFy3A;
typedef struct tyTuple__a7QginWFapakKbWJBJ2vfA tyTuple__a7QginWFapakKbWJBJ2vfA;
typedef struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__kbX6x85REySUrk9auORL0vw tyTuple__kbX6x85REySUrk9auORL0vw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g;
typedef struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q;
typedef struct tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A;
typedef struct tyTuple__nF9cH4hinXgGEUwO4G2bshw tyTuple__nF9cH4hinXgGEUwO4G2bshw;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA;
typedef struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__PsEhl3dzznmmJiLAuIXZOg tyTuple__PsEhl3dzznmmJiLAuIXZOg;
typedef struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w;
typedef struct tyTuple__Db8CrQifKGIsKc3w71w7Lw tyTuple__Db8CrQifKGIsKc3w71w7Lw;
typedef struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg;
typedef struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ;
typedef struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw tyTuple__FEYH9alRJhHD0uTKF2vnIqw;
typedef struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA;
typedef struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA;
typedef struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw;
typedef struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg tyTuple__VUJ5Hjm4tKAResBsRHJvYg;
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg {
NI id;
NimStringDesc* s;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* next;
NI h;
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
typedef NU16 tySet_tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA;
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw {
  RootObj Sup;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__aaEwD7wUZoIxDUprFEbfMQ[38];
struct tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ {
NI counter;
tySequence__ZQPym9bf1jM5qaSn7LUXMKA* data;
};
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__q9caIJqxIEVMlKzDKc7PN3A) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* expectedType);
typedef NU32 tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__Kiet6YwcQwPvcQYHHEqqqQ) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* expectedType);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__PSlVV9bxpH9avY5YrjCD5uqA) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__8k9afYvvfaH1tjWAwlISb0A) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, void* ClE_0);
void* ClE_0;
} tyProc__9bnYcX9avusKBraL3FJXBwJw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__uojbiMfaKLMuGW9bbomtTBg) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
typedef NU32 tySet_tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__bqRyngJC8bSPcUqqn9bn73w) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nOrig, tySet_tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw filter, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags);
typedef N_NIMCALL_PTR(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, tyProc__F6LocU8y66ng5Ra4XoVWJA) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* prev);
typedef struct {
N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, void* ClE_0);
void* ClE_0;
} tyProc__Nc9aAsBDTkr61wP9a9cnds8Og;
typedef struct {
N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fn, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, void* ClE_0);
void* ClE_0;
} tyProc__z8FaSv6eEIc72FZ9c9cBcaGg;
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw {
NI counter;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* data;
};
typedef NU8 tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ;
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__9aa59awckKpa9areOQSBOwSeQ) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* dc, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ op, NI col);
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
struct tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ {
tySequence__Bis5AbpONWcIRrPyPJS8Yw* data;
NI counter;
};
struct tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg {
tySequence__E8pi9b5QNahsURYzXMjh3qw* data;
NI counter;
};
struct tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg {
tySequence__XDpbjnuseLNZDGLBQ2Qzow* data;
NI counter;
};
struct tyObject_Table__cBohObSCAwRxvYFXQHv2wA {
tySequence__QqvaCqCpEE1QmQZbcZLi5A* data;
NI counter;
};
struct tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw {
  tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw Sup;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* enforceVoidContext;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* voidType;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* currentScope;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* moduleScope;
tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA* imports;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* topLevelScope;
tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA* p;
tyArray__aaEwD7wUZoIxDUprFEbfMQ intTypeCache;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* nilTypeCache;
tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw* matchedConcept;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* friendModules;
NI instCounter;
NI* templInstCounter;
NI inGenericContext;
NI inStaticContext;
NI inUnrolledContext;
NI compilesContextId;
NI compilesContextIdGenerator;
NI inGenericInst;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* converters;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* patterns;
tySequence__vvBerF0axaNtu9aMA2gnsrA* optionStack;
tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ symMapping;
tySequence__9c3OY0aBmSBgwdsnBAPf4Ag* libs;
tyProc__q9caIJqxIEVMlKzDKc7PN3A semConstExpr;
tyProc__Kiet6YwcQwPvcQYHHEqqqQ semExpr;
tyProc__PSlVV9bxpH9avY5YrjCD5uqA semTryExpr;
tyProc__q9caIJqxIEVMlKzDKc7PN3A semTryConstExpr;
tyProc__8k9afYvvfaH1tjWAwlISb0A computeRequiresInit;
tyProc__9bnYcX9avusKBraL3FJXBwJw hasUnresolvedArgs;
tyProc__PSlVV9bxpH9avY5YrjCD5uqA semOperand;
tyProc__uojbiMfaKLMuGW9bbomtTBg semConstBoolExpr;
tyProc__bqRyngJC8bSPcUqqn9bn73w semOverloadedCall;
tyProc__F6LocU8y66ng5Ra4XoVWJA semTypeNode;
tyProc__Nc9aAsBDTkr61wP9a9cnds8Og semInferredLambda;
tyProc__z8FaSv6eEIc72FZ9c9cBcaGg semGenerateInstance;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw includedFiles;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw pureEnumFields;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw userPragmas;
tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ* evalContext;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw unknownIdents;
tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ* generics;
NI topStmts;
NI lastGenericIdx;
NI hloLoopDetector;
NI inParallelStmt;
tyProc__9aa59awckKpa9areOQSBOwSeQ instTypeBoundOp;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* selfName;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw signatures;
NimStringDesc* recursiveDep;
NIM_BOOL suggestionsMade;
NIM_BOOL isAmbiguous;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
NI inTypeContext;
NI inConceptDecl;
tySequence__Jhh6ks9carRtwV9aOuM8yMNw* unusedImports;
tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ exportIndirections;
tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg importModuleMap;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastTLineInfo;
tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg sideEffects;
NI inUncheckedAssignSection;
tyObject_Table__cBohObSCAwRxvYFXQHv2wA importModuleLookup;
};
struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA {
tySequence__ijtae5OneaLys0hN9alAicA* data;
NI counter;
};
struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w {
tySequence__SerjNoUujW2dUouVBrJiCw* data;
NI counter;
};
struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA {
tySequence__K9agbtcb0qPZuSJFXB9cTe6g* data;
NI counter;
};
typedef tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyArray__46hjIasL27aUz9c7kgtWooQ[5];
struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg {
tySequence__m88qdML9cQOuqGAQn6XWL1A* data;
NI counter;
};
struct tyObject_Table__1hIWbTQWYT4BmhdESze57A {
tySequence__naEbXEp9b9aiW1zXJorqf9cXQ* data;
NI counter;
};
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
};
struct tyObject_Table__imojfg883tkWsWJwyshGqQ {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA {
tySequence__KgiZ29chkJAD01p9aLRB32qw* data;
NI counter;
};
struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A {
tySequence__rkYRZrbHVYL3nhXlQW3K9bw* data;
NI counter;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg[65];
struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ {
tySequence__YmPd0eWfcTfrVYrthlXPYA* data;
NI counter;
};
struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__I6rzVhdiYtUh7jwWJQoeyw) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__EQOAUyRkp9c3eeiGlHvCThA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q {
tySequence__Hz5SYwQU29b9aFLt09blvVQPg* data;
NI counter;
};
struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg {
tySequence__3G9aA9cLXaPxuRxMKm3anacQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__1CO5eEh25fBKUWGagpikwg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
typedef N_NIMCALL_PTR(void, tyProc__VcUg5jOhttLagdxUmVN8Tg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__XOkru1xuh2bHzmkw1UYzLA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formal, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* actual);
struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opNot;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opContains;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLe;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLt;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAnd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opOr;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opIsNil;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opEq;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAdd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opSub;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opMul;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opDiv;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg {
tySequence__RNhZxf20g9beyq5VBOGxhDg* ifaces;
tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* packed_0;
tySequence__lFbCtu5P2Kf7YDYtGjkxAQ* encoders;
tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA typeInstCache;
tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w procInstCache;
tyArray__46hjIasL27aUz9c7kgtWooQ attachedOps;
tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg methodsPerType;
tyObject_Table__1hIWbTQWYT4BmhdESze57A enumToStringProcs;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw emittedTypeInfo;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA startupPackedConfig;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw deps;
tyObject_Table__imojfg883tkWsWJwyshGqQ importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__BCPh85PHtwxox9bv7NLFrlg inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* usageSym;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* owners;
tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA suggestSymbols;
tyObject_Table__LM44poVdVEn4Mo4N4L8c3A suggestErrors;
tySequence__IRFEb1e9bxgbJLuB5xrdZsQ* methods;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* systemModule;
tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg sysTypes;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw compilerprocs;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw exposed;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageTypes;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* emptyNode;
tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ canonTypes;
tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw symBodyHashes;
tyProc__I6rzVhdiYtUh7jwWJQoeyw importModuleCallback;
tyProc__EQOAUyRkp9c3eeiGlHvCThA includeFileCallback;
tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q cacheSeqs;
tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g cacheCounters;
tyObject_Table__R7JnJQEipxxOlJWXQz7jWg cacheTables;
tySequence__bPFv6ypvvCX2A9a9al8utL2Q* passes;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinition;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinitionResolveForward;
tyProc__1CO5eEh25fBKUWGagpikwg onUsage;
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* globalDestructors;
tyProc__VcUg5jOhttLagdxUmVN8Tg strongSemCheck;
tyProc__XOkru1xuh2bHzmkw1UYzLA compatibleProps;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg operators;
};
struct tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ {
NI depthLevel;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw symbols;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* parent;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* allowPrivateAccess;
};
struct tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g {
NI h;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ;
struct tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m;
tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ mode;
union{
struct {tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw imported;
} _mode_2;
struct {tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw exceptSet;
} _mode_3;
};
};
struct tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ {
NI lastModule;
NU32 lastLit;
NI32 lastFile;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
};
struct tyObject_RodIter__L6nv9cakjPARHk068AFo6ww {
tyObject_PackedDecoder__KP7DLKztb9c2OnCFWxJiscQ decoder;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* values;
NI i;
NI module;
};
struct tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A {
NIM_BOOL fromRod;
NI modIndex;
tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g ti;
tyObject_RodIter__L6nv9cakjPARHk068AFo6ww rodIt;
NIM_BOOL importHidden;
};
typedef NimStringDesc* tyArray__Re75IspeoxXy2oCZHwcRrA[2];
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
struct tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw {
NI h;
};
struct tyTuple__Ztb9b8BdGY9bQ5Qd69ajoC2fQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field0;
NimStringDesc* Field1;
};
typedef NU8 tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU8 tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg;
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInst;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg uniqueId;
};
typedef NU8 tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
typedef struct {
N_NIMCALL_PTR(NI, ClP_0) (tyTuple__Ztb9b8BdGY9bQ5Qd69ajoC2fQ x, tyTuple__Ztb9b8BdGY9bQ5Qd69ajoC2fQ y, void* ClE_0);
void* ClE_0;
} tyProc__u9cu9aE0U3KrPDmkcU8DWlOw;
typedef NU8 tyEnum_SortOrder__TcYjciSJ3jKUT4ygglumjg;
typedef N_CLOSURE_PTR(NI, TM__lKFMSIMkJc3WyNochLWXNg_20) (tyTuple__Ztb9b8BdGY9bQ5Qd69ajoC2fQ x, tyTuple__Ztb9b8BdGY9bQ5Qd69ajoC2fQ y, void* ClE_0);
struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* converters;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* patterns;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* pureEnums;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interf;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interfHidden;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* uniqueName;
};
struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ {
tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* data;
NI counter;
};
struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ {
NI32 thisModule;
NI32 lastFile;
NU32 lastLit;
tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ filenames;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* pendingTypes;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* pendingSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw typeMarker;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw symMarker;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
};
typedef NU8 tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg;
struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg {
tySequence__4Murtwnm0Fyc7F9acrytEXw* nodes;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ;
struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ {
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw {
tySequence__IHUFRsFxZNv7YydiUO2esQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag {
NimStringDesc* definedSymbols;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA moduleFlags;
tySequence__PXIzfWocnrafGz5p3CP5LA* includes;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* imports;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg toReplay;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg topLevel;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg bodies;
tySequence__b89aLriiJnVTD186H6zNIgg* exports;
tySequence__b89aLriiJnVTD186H6zNIgg* hidden;
tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw* reexports;
tySequence__b89aLriiJnVTD186H6zNIgg* compilerProcs;
tySequence__48JTohSgTy339bRxHzUD8KA* converters;
tySequence__48JTohSgTy339bRxHzUD8KA* methods;
tySequence__48JTohSgTy339bRxHzUD8KA* trmacros;
tySequence__48JTohSgTy339bRxHzUD8KA* pureEnums;
tySequence__QnmOtn1Iv4LvxOXoMn8Rbg* macroUsages;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* typeInstCache;
tySequence__qy6Iwdy00wN560qud54HTg* procInstCache;
tySequence__k67v9bwvvQDmS1ynyGGUbeQ* attachedOps;
tySequence__cLsClAAfd0MKkoBQVyvdvw* methodsPerType;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* enumToStringProcs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* emittedTypeInfo;
tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ backendFlags;
tySequence__q9bTuOB0JXh1iZ3CSGdRLbg* syms;
tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw* types;
tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ strings;
tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw numbers;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA cfg;
};
struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ {
tySequence__C3r8jsj9chA4sIlYfDN5aDw* data;
NI counter;
};
struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg {
tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg status;
NIM_BOOL symsInit;
NIM_BOOL typesInit;
NIM_BOOL loadedButAliveSetChanged;
tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag fromDisk;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* syms;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* types;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ iface;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ ifaceHidden;
};
typedef NU8 tySet_tyEnum_TLookupFlag__ns0lQuhi2aWBQ9bXAfDCqaA;
typedef NU8 tyEnum_TLookupFlag__ns0lQuhi2aWBQ9bXAfDCqaA;
typedef NU8 tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
struct tyObject_HeapQueue__MBC6eEbMfekVnGqjI07yVg {
tySequence__wDFGR0GrXEVcAPtPuTlVAA* data;
};
struct tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field0;
NI Field1;
NIM_BOOL Field2;
};
typedef NimStringDesc* tyArray__24KAM9afIUgUaqBaEBB6r9bg[3];
struct tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA {
NI dist;
NI depth;
NimStringDesc* msg;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
};
struct tyTuple__kuMQ1fbjJlHtwKTmBGAe6g {
NI Field0;
NI Field1;
NimStringDesc* Field2;
};
typedef NU8 tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg {
NI32 module;
NI32 symId;
NI32 typeId_0;
NIM_BOOL sealed;
};
typedef NU8 tyEnum_TOverloadIterMode__XQIFODuBaxbYxvlbAsr1Ng;
struct tyObject_TOverloadIter__CvTtbgSac6VxMVCfhzIzkg {
tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g it;
tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A mit;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m;
tyEnum_TOverloadIterMode__XQIFODuBaxbYxvlbAsr1Ng mode;
NI symChoiceIndex;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* currentScope;
NI importIdx;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw marked;
};
struct tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA {
tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* key;
RootObj* val;
};
struct tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* genericSym;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field0;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field1;
};
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
NI Field0;
NI Field1;
};
struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ {
NI Field0;
tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ Field1;
};
struct tyTuple__toqrUPSdp8zSxOdlxMJj9cA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
struct tyTuple__VbApVidEWCFLq9a29bPtaS7A {
NI Field0;
NI Field1;
tySequence__k7EQb9bN3Uhl608xoPGMRJA* Field2;
};
struct tyTuple__EbsafWGli8bW2GRJQ9apsjA {
NI Field0;
NI Field1;
tySequence__qwqHTkRvwhrRyENtudHQ7g* Field2;
};
struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ {
NU32 module;
NI32 item;
};
struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg {
NI module;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ packed_0;
};
struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
};
struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__dlD6tEGzYLLpKVq3XwuFlA* Field2;
};
struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q {
NI module;
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg sym;
tySequence__UnGSk9aaLosDroi2QDrlOfQ* concreteTypes;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__rZZA0skon1OsHdiEvT8RZQ {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__6OFCSvqRaxyEgUqWtnZSlw* Field2;
};
struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field2;
};
struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
};
struct tyTuple__RWXAsQlFoGYyEQZp1G65sg {
NI Field0;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field1;
};
struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__m4PVWjcAAjfxlwJxLkKn8A* Field2;
};
struct tyTuple__RmGJuqOgEaHckHndh0LEsw {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field2;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
};
struct tyTuple__J4cxakKjhKxTIJR9bojMmXw {
NI Field0;
NI32 Field1;
tySequence__i89c5kdtWKzK3OEiI81pkkw* Field2;
};
struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ {
NI Field0;
NI32 Field1;
tySequence__GR8qmV1kNRcoQ2g76VFy3A* Field2;
};
struct tyTuple__a7QginWFapakKbWJBJ2vfA {
tySequence__ed0C0uAUZPhvw3RAc5hfYg* Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__kbX6x85REySUrk9auORL0vw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q {
tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A* root;
NI entries;
};
struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, tyProc__kqPx9c4py2HW6KcFMhNvxtg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__9c6qRjwy7Es8UkDTIUwAfFA) (tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__mv4BsRs5VEnhcxzV6pQU5w) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
struct tyTuple__nF9cH4hinXgGEUwO4G2bshw {
tyProc__kqPx9c4py2HW6KcFMhNvxtg Field0;
tyProc__9c6qRjwy7Es8UkDTIUwAfFA Field1;
tyProc__mv4BsRs5VEnhcxzV6pQU5w Field2;
NIM_BOOL Field3;
};
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
NI Field0;
NI32 Field1;
NU32 Field2;
};
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
NU32 Field0;
NimStringDesc* Field1;
};
struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA {
NU16 line;
NI16 col;
NU32 file;
};
struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA {
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
NI32 operand;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeId_0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
};
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
NU32 Field0;
NI32 Field1;
};
struct tyTuple__PsEhl3dzznmmJiLAuIXZOg {
NU32 Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA Field1;
};
struct tyTuple__Db8CrQifKGIsKc3w71w7Lw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ key;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* concreteTypes;
};
struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ {
tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
NI Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
typedef NU8 tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ;
struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA {
tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
NU32 name;
NI32 path;
};
struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA {
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
NU32 name;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typ;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
NI32 ast;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ guard;
NI bitsize;
NI alignment;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
NU32 externalName;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw locFlags;
tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA annex;
NI32 constraint;
};
struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw {
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* types;
NI32 n;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeInst;
NI32 nonUniqueId;
};
struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg {
NI Field0;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* Field1;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* Field2;
};
struct tySequence__ed0C0uAUZPhvw3RAc5hfYg {
  TGenericSeq Sup;
  tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* data[SEQ_DECL_SIZE];
};
struct tySequence__EK3kb9a029axOL6ZINxWj1hw {
  TGenericSeq Sup;
  tyTuple__Ztb9b8BdGY9bQ5Qd69ajoC2fQ data[SEQ_DECL_SIZE];
};
struct tySequence__wDFGR0GrXEVcAPtPuTlVAA {
  TGenericSeq Sup;
  tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA data[SEQ_DECL_SIZE];
};
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  TGenericSeq Sup;
  NI data[SEQ_DECL_SIZE];
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA {
  TGenericSeq Sup;
  tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg data[SEQ_DECL_SIZE];
};
struct tySequence__vvBerF0axaNtu9aMA2gnsrA {
  TGenericSeq Sup;
  tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q* data[SEQ_DECL_SIZE];
};
struct tySequence__ZQPym9bf1jM5qaSn7LUXMKA {
  TGenericSeq Sup;
  tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA data[SEQ_DECL_SIZE];
};
struct tySequence__9c3OY0aBmSBgwdsnBAPf4Ag {
  TGenericSeq Sup;
  tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ {
  TGenericSeq Sup;
  tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w data[SEQ_DECL_SIZE];
};
struct tySequence__Jhh6ks9carRtwV9aOuM8yMNw {
  TGenericSeq Sup;
  tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg data[SEQ_DECL_SIZE];
};
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw {
  TGenericSeq Sup;
  tyTuple__NAaJgGVgNmlGoqmiWxdOHQ data[SEQ_DECL_SIZE];
};
struct tySequence__E8pi9b5QNahsURYzXMjh3qw {
  TGenericSeq Sup;
  tyTuple__47w2DboNEPf69aPgubZdd7Q data[SEQ_DECL_SIZE];
};
struct tySequence__k7EQb9bN3Uhl608xoPGMRJA {
  TGenericSeq Sup;
  tyTuple__toqrUPSdp8zSxOdlxMJj9cA data[SEQ_DECL_SIZE];
};
struct tySequence__XDpbjnuseLNZDGLBQ2Qzow {
  TGenericSeq Sup;
  tyTuple__VbApVidEWCFLq9a29bPtaS7A data[SEQ_DECL_SIZE];
};
struct tySequence__QqvaCqCpEE1QmQZbcZLi5A {
  TGenericSeq Sup;
  tyTuple__EbsafWGli8bW2GRJQ9apsjA data[SEQ_DECL_SIZE];
};
struct tySequence__RNhZxf20g9beyq5VBOGxhDg {
  TGenericSeq Sup;
  tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ data[SEQ_DECL_SIZE];
};
struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ {
  TGenericSeq Sup;
  tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg data[SEQ_DECL_SIZE];
};
struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ {
  TGenericSeq Sup;
  tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ data[SEQ_DECL_SIZE];
};
struct tySequence__dlD6tEGzYLLpKVq3XwuFlA {
  TGenericSeq Sup;
  tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ data[SEQ_DECL_SIZE];
};
struct tySequence__ijtae5OneaLys0hN9alAicA {
  TGenericSeq Sup;
  tyTuple__UluY8x0Nj6cp9b0o88wJ0lg data[SEQ_DECL_SIZE];
};
struct tySequence__6OFCSvqRaxyEgUqWtnZSlw {
  TGenericSeq Sup;
  tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q data[SEQ_DECL_SIZE];
};
struct tySequence__SerjNoUujW2dUouVBrJiCw {
  TGenericSeq Sup;
  tyTuple__rZZA0skon1OsHdiEvT8RZQ data[SEQ_DECL_SIZE];
};
struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g {
  TGenericSeq Sup;
  tyTuple__q13Zt16VkCqu6Zg5jWqwHA data[SEQ_DECL_SIZE];
};
struct tySequence__m4PVWjcAAjfxlwJxLkKn8A {
  TGenericSeq Sup;
  tyTuple__RWXAsQlFoGYyEQZp1G65sg data[SEQ_DECL_SIZE];
};
struct tySequence__m88qdML9cQOuqGAQn6XWL1A {
  TGenericSeq Sup;
  tyTuple__aWN9bNzF9bubXNJV9ciomgpfA data[SEQ_DECL_SIZE];
};
struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ {
  TGenericSeq Sup;
  tyTuple__RmGJuqOgEaHckHndh0LEsw data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__i89c5kdtWKzK3OEiI81pkkw {
  TGenericSeq Sup;
  tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A data[SEQ_DECL_SIZE];
};
struct tySequence__KgiZ29chkJAD01p9aLRB32qw {
  TGenericSeq Sup;
  tyTuple__J4cxakKjhKxTIJR9bojMmXw data[SEQ_DECL_SIZE];
};
struct tySequence__GR8qmV1kNRcoQ2g76VFy3A {
  TGenericSeq Sup;
  tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* data[SEQ_DECL_SIZE];
};
struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw {
  TGenericSeq Sup;
  tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ data[SEQ_DECL_SIZE];
};
struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ {
  TGenericSeq Sup;
  tyTuple__a7QginWFapakKbWJBJ2vfA data[SEQ_DECL_SIZE];
};
struct tySequence__YmPd0eWfcTfrVYrthlXPYA {
  TGenericSeq Sup;
  tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg {
  TGenericSeq Sup;
  tyTuple__kbX6x85REySUrk9auORL0vw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ {
  TGenericSeq Sup;
  tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g data[SEQ_DECL_SIZE];
};
struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q {
  TGenericSeq Sup;
  tyTuple__nF9cH4hinXgGEUwO4G2bshw data[SEQ_DECL_SIZE];
};
struct tySequence__lo3S1lKyiPLhGGB9cBawd6A {
  TGenericSeq Sup;
  tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ data[SEQ_DECL_SIZE];
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g {
  TGenericSeq Sup;
  tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg data[SEQ_DECL_SIZE];
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  TGenericSeq Sup;
  tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE];
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  TGenericSeq Sup;
  tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE];
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  TGenericSeq Sup;
  NU32 data[SEQ_DECL_SIZE];
};
struct tySequence__4Murtwnm0Fyc7F9acrytEXw {
  TGenericSeq Sup;
  tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA data[SEQ_DECL_SIZE];
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  TGenericSeq Sup;
  tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE];
};
struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw {
  TGenericSeq Sup;
  tyTuple__PsEhl3dzznmmJiLAuIXZOg data[SEQ_DECL_SIZE];
};
struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg {
  TGenericSeq Sup;
  tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w data[SEQ_DECL_SIZE];
};
struct tySequence__oKtVqsc9bQVCNyrijELM4OQ {
  TGenericSeq Sup;
  tyTuple__Db8CrQifKGIsKc3w71w7Lw data[SEQ_DECL_SIZE];
};
struct tySequence__qy6Iwdy00wN560qud54HTg {
  TGenericSeq Sup;
  tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg data[SEQ_DECL_SIZE];
};
struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ {
  TGenericSeq Sup;
  tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ data[SEQ_DECL_SIZE];
};
struct tySequence__cLsClAAfd0MKkoBQVyvdvw {
  TGenericSeq Sup;
  tyTuple__FEYH9alRJhHD0uTKF2vnIqw data[SEQ_DECL_SIZE];
};
struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg {
  TGenericSeq Sup;
  tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA data[SEQ_DECL_SIZE];
};
struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw {
  TGenericSeq Sup;
  tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw data[SEQ_DECL_SIZE];
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  TGenericSeq Sup;
  NI64 data[SEQ_DECL_SIZE];
};
struct tySequence__C3r8jsj9chA4sIlYfDN5aDw {
  TGenericSeq Sup;
  tyTuple__VUJ5Hjm4tKAResBsRHJvYg data[SEQ_DECL_SIZE];
};
struct tySequence__UnGSk9aaLosDroi2QDrlOfQ {
  TGenericSeq Sup;
  tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg data[SEQ_DECL_SIZE];
};
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, noidentError__lookups_20)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* origin);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderTree__renderer_46)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA renderFlags);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*, getIdent__idents_152)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* ic, NimStringDesc* identifier);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*, considerQuotedIdent__lookups_29)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* origin);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, initIdentIter__astalgo_3420)(tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g* ti, tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tab, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* s);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5340)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5302)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5347)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5345)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5296)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, nextIdentIter__astalgo_3401)(tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g* ti, tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tab);
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(void, initPackedSet__pureZcollectionsZintsets_16)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, initIdentIter__lookups_158)(tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A* ti, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* marked, tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg* im, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, initModuleIter__modulegraphs_2748)(tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A* mi, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__astalgo_3489)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__astalgo_402)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, nextModuleIter__modulegraphs_2783)(tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A* mi, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, nextIdentIter__lookups_278)(tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A* ti, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* marked, tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg* im, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NOINLINE(void*, newObj)(TNimType* typ, NI size);
N_LIB_PRIVATE N_NIMCALL(void, newStrTable__ast_4082)(tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* Result);
static N_INLINE(NI, scopeDepth__semdata_320)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, addUniqueSym__lookups_72)(tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, strTableInclReportConflict__astalgo_3335)(tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* t, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* n, NIM_BOOL onConflictKeepOld);
N_LIB_PRIVATE N_NIMCALL(NI*, X5BX5D___lookups_1101)(tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg* t, NI key);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___msgs_634)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, wrongRedefinition__lookups_985)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw conflictsWith, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ note);
N_LIB_PRIVATE N_NIMCALL(void, ensureNoMissingOrUnusedSymbols__lookups_17)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, initTabIter__astalgo_3770)(tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw* ti, tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tab);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatSingleElem)(NimStringDesc* formatstr, NimStringDesc* a);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getSymRepr__lookups_728)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NIM_BOOL getDeclarationPath);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getProcHeader__types_222)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg prefer, NIM_BOOL getDeclarationPath);
N_LIB_PRIVATE N_NIMCALL(void, addDeclaredLoc__astmsgs_17)(NimStringDesc** result, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_629)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toMsgFilename__msgs_612)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_167)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__EK3kb9a029axOL6ZINxWj1hw)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, nextIter__astalgo_3755)(tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw* ti, tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tab);
N_LIB_PRIVATE N_NIMCALL(tySequence__EK3kb9a029axOL6ZINxWj1hw*, sorted__lookups_830)(tyTuple__Ztb9b8BdGY9bQ5Qd69ajoC2fQ* a, NI aLen_0, tyProc__u9cu9aE0U3KrPDmkcU8DWlOw cmp, tyEnum_SortOrder__TcYjciSJ3jKUT4ygglumjg order);
N_LIB_PRIVATE N_NIMCALL(NI, colonanonymous___lookups_791)(tyTuple__Ztb9b8BdGY9bQ5Qd69ajoC2fQ xX60gensym68_, tyTuple__Ztb9b8BdGY9bQ5Qd69ajoC2fQ yX60gensym68_);
N_LIB_PRIVATE N_NIMCALL(NI, cmp__system_1549)(NimStringDesc* x, NimStringDesc* y);
N_LIB_PRIVATE N_NIMCALL(void, rawCloseScope__lookups_106)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
N_LIB_PRIVATE N_NIMCALL(void, addInterfaceOverloadableSymAt__lookups_1571)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(void, addOverloadableSymAt__lookups_1554)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fn);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_1441)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, strTableGet__astalgo_3383)(tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw t, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name);
N_LIB_PRIVATE N_NIMCALL(void, strTableAdd__astalgo_3325)(tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* t, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* n);
static N_INLINE(NIM_BOOL, isShadowScope__lookups_142)(tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* s);
N_LIB_PRIVATE N_NIMCALL(void, addInterfaceDeclAux__lookups_1524)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(void, exportSym__semdata_740)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
static N_INLINE(NIM_BOOL, isTopLevelInsideDeclaration__semdata_1124)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(void, addHidden__icZic_2308)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
static N_INLINE(void, addInterfaceDecl__lookups_1551)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(void, addInterfaceDeclAt__lookups_1547)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
static N_INLINE(void, addDeclAt__lookups_1509)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(void, addDeclAt__lookups_995)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, skipAlias__lookups_125)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, replaceDeprecated__nimfixZprettybase_47)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* oldSym, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* newSym);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, searchInScopes__lookups_603)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* s, NIM_BOOL* ambiguous);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, someSymFromImportTable__lookups_561)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name, NIM_BOOL* ambiguous);
N_LIB_PRIVATE N_NIMCALL(tySequence__ed0C0uAUZPhvw3RAc5hfYg*, searchInScopesFilterBy__lookups_644)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* s, tySet_tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw filter);
N_LIB_PRIVATE N_NIMCALL(void, errorUseQualifier__lookups_2521)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tySequence__ed0C0uAUZPhvw3RAc5hfYg* candidates, NimStringDesc* prefix);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, typeToString__types_50)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg prefer);
N_LIB_PRIVATE N_NIMCALL(tySequence__ed0C0uAUZPhvw3RAc5hfYg*, allPureEnumFields__lookups_495)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, errorUndeclaredIdentifierHint__lookups_2570)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident);
static N_INLINE(NIM_BOOL, mustFixSpelling__lookups_1621)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
N_LIB_PRIVATE N_NIMCALL(void, fixSpelling__lookups_1624)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident, NimStringDesc** result);
N_LIB_PRIVATE N_NIMCALL(void, initHeapQueue__lookups_1629)(tyObject_HeapQueue__MBC6eEbMfekVnGqjI07yVg* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimIdentNormalize__pureZstrutils_105)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NI, editDistance__stdZeditdistance_2)(NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___systemZdollars_3)(NI x);
N_LIB_PRIVATE N_NIMCALL(void, push__lookups_1642)(tyObject_HeapQueue__MBC6eEbMfekVnGqjI07yVg* heap, tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA* item);
static N_NIMCALL(void, Marker_tySequence__wDFGR0GrXEVcAPtPuTlVAA)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___lookups_1600)(tyTuple__kuMQ1fbjJlHtwKTmBGAe6g x, tyTuple__kuMQ1fbjJlHtwKTmBGAe6g y);
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_2722)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m);
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_2710)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI module);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, initRodIterAllSyms__icZic_8670)(tyObject_RodIter__L6nv9cakjPARHk068AFo6ww* it, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, NI32 module, NIM_BOOL importHidden);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, nextRodIter__icZic_8980)(tyObject_RodIter__L6nv9cakjPARHk068AFo6ww* it, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g);
static N_INLINE(NI, len__lookups_1696)(tyObject_HeapQueue__MBC6eEbMfekVnGqjI07yVg heap);
static N_INLINE(tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA*, X5BX5D___lookups_1764)(tyObject_HeapQueue__MBC6eEbMfekVnGqjI07yVg* heap, NI i);
N_LIB_PRIVATE N_NIMCALL(void, pop__lookups_2054)(tyObject_HeapQueue__MBC6eEbMfekVnGqjI07yVg* heap, tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA* Result);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(void, errorUndeclaredIdentifier__lookups_2564)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* name, NimStringDesc* extra);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, errorSym__lookups_686)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, newSym__ast_3409)(tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw symKind, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg id, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options);
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextSymId__ast_3103)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getCurrOwner__semdata_327)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, errorType__semdata_1032)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, errorUseQualifier__lookups_2494)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NIM_BOOL* amb);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, qualifiedLookUp__lookups_2598)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TLookupFlag__ns0lQuhi2aWBQ9bXAfDCqaA flags);
static N_INLINE(NIM_BOOL, eqeq___idents_229)(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* a, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* b);
N_LIB_PRIVATE N_NIMCALL(tySequence__qwqHTkRvwhrRyENtudHQ7g*, getOrDefault__lookups_2769)(tyObject_Table__cBohObSCAwRxvYFXQHv2wA t, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, someSym__modulegraphs_2849)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name);
N_LIB_PRIVATE N_NIMCALL(void, incl__pureZcollectionsZintsets_55)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, nextOverloadIterImports__lookups_3224)(tyObject_TOverloadIter__CvTtbgSac6VxMVCfhzIzkg* o, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, firstIdentExcluding__astalgo_3747)(tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g* ti, tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tab, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* s, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* excluding);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, symChoiceExtension__lookups_3251)(tyObject_TOverloadIter__CvTtbgSac6VxMVCfhzIzkg* o, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, nextIdentExcluding__astalgo_3425)(tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g* ti, tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tab, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* excluding);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, initOverloadIter__lookups_3120)(tyObject_TOverloadIter__CvTtbgSac6VxMVCfhzIzkg* o, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, nextOverloadIter__lookups_3274)(tyObject_TOverloadIter__CvTtbgSac6VxMVCfhzIzkg* o, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tySequence__ed0C0uAUZPhvw3RAc5hfYg*, newSeq__lookups_2544)(NI len);
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_2, "in expression \'", 15);
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_3, "\': ", 3);
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_4, "identifier expected, but found \'", 32);
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_5, "\'", 1);
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_7, "/home/runner/work/nightlies/nightlies/nim/compiler/lookups.nim", 62);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__lKFMSIMkJc3WyNochLWXNg_6 = {((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_7),
((NI) 23),
((NI) 12)}
;
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_8, "<Error>", 7);
extern TNimType NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_;
extern TNimType NTIpscope__1WBIpqNgZhwC9bV4356CRhQ_;
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_9, "duplicate import of \'$1\'; previous import here: $2", 50);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__lKFMSIMkJc3WyNochLWXNg_10 = {((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_7),
((NI) 320),
((NI) 18)}
;
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_11, "redefinition of \'$1\'; previous declaration here: $2", 51);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__lKFMSIMkJc3WyNochLWXNg_12 = {((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_7),
((NI) 305),
((NI) 14)}
;
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_13, "implementation of \'$1\' expected", 31);
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_14, "\'$1\'", 4);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__lKFMSIMkJc3WyNochLWXNg_15 = {((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_7),
((NI) 287),
((NI) 18)}
;
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_16, "(", 1);
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_17, ", ", 2);
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_18, ")", 1);
N_LIB_PRIVATE TNimType NTItupleLsym58psym_key58stringT__Ztb9b8BdGY9bQ5Qd69ajoC2fQ_;
extern TNimType NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_;
extern TNimType NTIstring__77mFvmsOLKik79ci2hXkHEg_;
N_LIB_PRIVATE TNimType NTIseqLtupleLsym58psym_key58stringTT__EK3kb9a029axOL6ZINxWj1hw_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__lKFMSIMkJc3WyNochLWXNg_21 = {((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_7),
((NI) 299),
((NI) 11)}
;
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_22, "addOverloadableSymAt", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__lKFMSIMkJc3WyNochLWXNg_23 = {((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_7),
((NI) 366),
((NI) 17)}
;
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_24, "addInterfaceDeclAux", 19);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__lKFMSIMkJc3WyNochLWXNg_25 = {((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_7),
((NI) 345),
((NI) 23)}
;
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_26, "use ", 4);
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_27, " instead; ", 10);
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_28, " is deprecated", 14);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__lKFMSIMkJc3WyNochLWXNg_29 = {((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_7),
((NI) 101),
((NI) 13)}
;
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_30, "ambiguous identifier: \'", 23);
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_31, " -- $1 the following:\012", 22);
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_32, "\012", 1);
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_33, "  ", 2);
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_34, ".", 1);
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_35, ": ", 2);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__lKFMSIMkJc3WyNochLWXNg_36 = {((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_7),
((NI) 505),
((NI) 12)}
;
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_37, "use one of", 10);
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_38, "\012 ($1, $2): \'$3\'", 16);
N_LIB_PRIVATE TNimType NTIspellcandidate__ZxujMy1bsXT9c9b7Yfb24WoA_;
extern TNimType NTIint__rR5Bzr1D5krxoo1NcNyeMA_;
N_LIB_PRIVATE TNimType NTIseqLspellcandidateT__wDFGR0GrXEVcAPtPuTlVAA_;
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_40, "\012candidates (edit distance, scope distance); see \'--spellSuggest\': ", 67);
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_41, "undeclared identifier: \'", 24);
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_42, "\012This might be caused by a recursive module dependency:\012", 56);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__lKFMSIMkJc3WyNochLWXNg_43 = {((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_7),
((NI) 521),
((NI) 12)}
;
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_44, "err:", 4);
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_45, " -- use one of the following:\012", 30);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__lKFMSIMkJc3WyNochLWXNg_46 = {((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_7),
((NI) 487),
((NI) 14)}
;
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_47, "identifier expected, but got: ", 30);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__lKFMSIMkJc3WyNochLWXNg_48 = {((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_7),
((NI) 609),
((NI) 18)}
;
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_49, "lookUp", 6);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__lKFMSIMkJc3WyNochLWXNg_50 = {((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_7),
((NI) 543),
((NI) 17)}
;
STRING_LITERAL(TM__lKFMSIMkJc3WyNochLWXNg_51, "you need a helper proc to disambiguate", 38);
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5249;
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, noidentError__lookups_20)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* origin) {
	NimStringDesc* m;
	NimStringDesc* T7_;
	NimStringDesc* T8_;
	m = ((NimStringDesc*) NIM_NIL);
	{
		NimStringDesc* T5_;
		NimStringDesc* T6_;
		if (!!((origin == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA3_;
		T5_ = NIM_NIL;
		T6_ = NIM_NIL;
		T6_ = renderTree__renderer_46(origin, 0);
		T5_ = rawNewString((T6_ ? T6_->Sup.len : 0) + 18);
appendString(T5_, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_2));
appendString(T5_, T6_);
appendString(T5_, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_3));
		m = resizeString(m, (T5_ ? T5_->Sup.len : 0) + 0);
appendString(m, T5_);
	}
	LA3_: ;
	T7_ = NIM_NIL;
	T8_ = NIM_NIL;
	T8_ = renderTree__renderer_46(n, 0);
	T7_ = rawNewString((T8_ ? T8_->Sup.len : 0) + 33);
appendString(T7_, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_4));
appendString(T7_, T8_);
appendString(T7_, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_5));
	m = resizeString(m, (T7_ ? T7_->Sup.len : 0) + 0);
appendString(m, T7_);
	liMessage__msgs_1128(conf, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), m, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__lKFMSIMkJc3WyNochLWXNg_6, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*, considerQuotedIdent__lookups_29)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* origin) {
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* result;
	result = NIM_NIL;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	{
		result = (*n)._kind_5.ident;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		result = (*(*n)._kind_4.sym).name;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 53):
	{
		NI T4_;
		T4_ = (NI)0;
		T4_ = len__ast_3155(n);
		switch (T4_) {
		case ((NI) 0):
		{
			noidentError__lookups_20((*(*c).graph).config, n, origin);
			result = getIdent__idents_152((*c).cache, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_8));
		}
		break;
		case ((NI) 1):
		{
			result = considerQuotedIdent__lookups_29(c, (*n)._kind_6.sons->data[((NI) 0)], origin);
		}
		break;
		default:
		{
			NimStringDesc* id;
			id = ((NimStringDesc*) NIM_NIL);
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_3155(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x;
						if (!(i_2 < colontmp_)) goto LA10;
						i = i_2;
						x = (*n)._kind_6.sons->data[i];
						switch ((*x).kind) {
						case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
						{
							id = resizeString(id, ((*(*x)._kind_5.ident).s ? (*(*x)._kind_5.ident).s->Sup.len : 0) + 0);
appendString(id, (*(*x)._kind_5.ident).s);
						}
						break;
						case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
						{
							id = resizeString(id, ((*(*(*x)._kind_4.sym).name).s ? (*(*(*x)._kind_4.sym).name).s->Sup.len : 0) + 0);
appendString(id, (*(*(*x)._kind_4.sym).name).s);
						}
						break;
						case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 56) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 57):
						{
							{
								if (!((*(*x)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA16_;
								id = resizeString(id, ((*(*(*(*x)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).s ? (*(*(*(*x)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).s->Sup.len : 0) + 0);
appendString(id, (*(*(*(*x)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).s);
							}
							goto LA14_;
							LA16_: ;
							{
								noidentError__lookups_20((*(*c).graph).config, n, origin);
								result = getIdent__idents_152((*c).cache, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_8));
							}
							LA14_: ;
						}
						break;
						case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 15):
						case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22):
						{
							NimStringDesc* T20_;
							T20_ = NIM_NIL;
							T20_ = renderTree__renderer_46(x, 0);
							id = resizeString(id, (T20_ ? T20_->Sup.len : 0) + 0);
appendString(id, T20_);
						}
						break;
						default:
						{
							noidentError__lookups_20((*(*c).graph).config, n, origin);
							result = getIdent__idents_152((*c).cache, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_8));
						}
						break;
						}
						i_2 += ((NI) 1);
					} LA10: ;
				}
			}
			result = getIdent__idents_152((*c).cache, id);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 57):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 56):
	{
		{
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA25_;
			result = (*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name;
		}
		goto LA23_;
		LA25_: ;
		{
			noidentError__lookups_20((*(*c).graph).config, n, origin);
			result = getIdent__idents_152((*c).cache, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_8));
		}
		LA23_: ;
	}
	break;
	default:
	{
		noidentError__lookups_20((*(*c).graph).config, n, origin);
		result = getIdent__idents_152((*c).cache, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_8));
	}
	break;
	}
	return result;
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5340)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5302)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5345)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5296((&gch__system_5249.zct), c);
}
static N_INLINE(void, decRef__system_5347)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5345(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5302(src);
		incRef__system_5340(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5302((*dest));
		decRef__system_5347(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result) {
	initPackedSet__pureZcollectionsZintsets_16(Result);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, initIdentIter__lookups_158)(tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A* ti, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* marked, tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg* im, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
{	result = NIM_NIL;
	result = initModuleIter__modulegraphs_2748(ti, g, (*im).m, name);
	{
		while (1) {
			NIM_BOOL b;
			if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA2;
			switch ((*im).mode) {
			case ((tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ) 0):
			{
				b = NIM_TRUE;
			}
			break;
			case ((tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ) 1):
			{
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym26_;
				xX60gensym26_ = result;
				b = contains__astalgo_3489((&(*im)._mode_2.imported), (NI)((NI)((NU64)(((NI) ((*xX60gensym26_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym26_).Sup.itemId.item))));
			}
			break;
			case ((tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ) 2):
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = contains__astalgo_3489((&(*im)._mode_3.exceptSet), (*name).id);
				b = !(T6_);
			}
			break;
			}
			{
				NIM_BOOL T9_;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym28_;
				NIM_BOOL T11_;
				T9_ = (NIM_BOOL)0;
				T9_ = b;
				if (!(T9_)) goto LA10_;
				xX60gensym28_ = result;
				T11_ = (NIM_BOOL)0;
				T11_ = containsOrIncl__astalgo_402(marked, (NI)((NI)((NU64)(((NI) ((*xX60gensym28_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym28_).Sup.itemId.item))));
				T9_ = !(T11_);
				LA10_: ;
				if (!T9_) goto LA12_;
				goto BeforeRet_;
			}
			LA12_: ;
			result = nextModuleIter__modulegraphs_2783(ti, g);
		} LA2: ;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, nextIdentIter__lookups_278)(tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A* ti, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* marked, tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg* im, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
{	result = NIM_NIL;
	{
		while (1) {
			result = nextModuleIter__modulegraphs_2783(ti, g);
			{
				if (!(result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA5_;
				result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
				goto BeforeRet_;
			}
			LA5_: ;
			switch ((*im).mode) {
			case ((tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ) 0):
			{
				{
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym29_;
					NIM_BOOL T10_;
					xX60gensym29_ = result;
					T10_ = (NIM_BOOL)0;
					T10_ = containsOrIncl__astalgo_402(marked, (NI)((NI)((NU64)(((NI) ((*xX60gensym29_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym29_).Sup.itemId.item))));
					if (!!(T10_)) goto LA11_;
					goto BeforeRet_;
				}
				LA11_: ;
			}
			break;
			case ((tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ) 1):
			{
				{
					NIM_BOOL T16_;
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym31_;
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym32_;
					NIM_BOOL T18_;
					T16_ = (NIM_BOOL)0;
					xX60gensym31_ = result;
					T16_ = contains__astalgo_3489((&(*im)._mode_2.imported), (NI)((NI)((NU64)(((NI) ((*xX60gensym31_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym31_).Sup.itemId.item))));
					if (!(T16_)) goto LA17_;
					xX60gensym32_ = result;
					T18_ = (NIM_BOOL)0;
					T18_ = containsOrIncl__astalgo_402(marked, (NI)((NI)((NU64)(((NI) ((*xX60gensym32_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym32_).Sup.itemId.item))));
					T16_ = !(T18_);
					LA17_: ;
					if (!T16_) goto LA19_;
					goto BeforeRet_;
				}
				LA19_: ;
			}
			break;
			case ((tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ) 2):
			{
				{
					NIM_BOOL T24_;
					NIM_BOOL T25_;
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym34_;
					NIM_BOOL T27_;
					T24_ = (NIM_BOOL)0;
					T25_ = (NIM_BOOL)0;
					T25_ = contains__astalgo_3489((&(*im)._mode_3.exceptSet), (*(*result).name).id);
					T24_ = !(T25_);
					if (!(T24_)) goto LA26_;
					xX60gensym34_ = result;
					T27_ = (NIM_BOOL)0;
					T27_ = containsOrIncl__astalgo_402(marked, (NI)((NI)((NU64)(((NI) ((*xX60gensym34_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym34_).Sup.itemId.item))));
					T24_ = !(T27_);
					LA26_: ;
					if (!T24_) goto LA28_;
					goto BeforeRet_;
				}
				LA28_: ;
			}
			break;
			}
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__ed0C0uAUZPhvw3RAc5hfYg*, searchInScopesFilterBy__lookups_644)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* s, tySet_tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw filter) {
	tySequence__ed0C0uAUZPhvw3RAc5hfYg* result;
	result = NIM_NIL;
	result = NIM_NIL;
	{
		{
			tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope;
			tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* current;
			scope = NIM_NIL;
			current = (*c).currentScope;
			{
				while (1) {
					tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g ti;
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* candidate;
					if (!!((current == ((tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ*) NIM_NIL)))) goto LA4;
					scope = current;
					nimZeroMem((void*)(&ti), sizeof(tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g));
					candidate = initIdentIter__astalgo_3420((&ti), (*scope).symbols, s);
					{
						while (1) {
							if (!!((candidate == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA6;
							{
								NI T11_;
								if (!((filter &((NU32)1<<((NU)((*candidate).kind)&31U)))!=0)) goto LA9_;
								result = (tySequence__ed0C0uAUZPhvw3RAc5hfYg*) incrSeqV3((TGenericSeq*)(result), (&NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_));
								T11_ = result->Sup.len++;
								asgnRef((void**) (&result->data[T11_]), candidate);
								goto LA1;
							}
							LA9_: ;
							candidate = nextIdentIter__astalgo_3401((&ti), (*scope).symbols);
						} LA6: ;
					}
					current = (*current).parent;
				} LA4: ;
			}
		}
	} LA1: ;
	{
		NI T14_;
		tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw marked;
		T14_ = (result ? result->Sup.len : 0);
		if (!(T14_ == ((NI) 0))) goto LA15_;
		nimZeroMem((void*)(&marked), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
		initIntSet__pureZcollectionsZintsets_238((&marked));
		{
			tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg* im;
			NI i;
			NI L;
			NI T18_;
			im = (tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg*)0;
			i = ((NI) 0);
			T18_ = ((*c).imports ? (*c).imports->Sup.len : 0);
			L = T18_;
			{
				while (1) {
					if (!(i < L)) goto LA20;
					im = (&(*c).imports->data[i]);
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s_2;
						tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A ti_2;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* candidate_2;
						s_2 = NIM_NIL;
						nimZeroMem((void*)(&ti_2), sizeof(tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A));
						candidate_2 = initIdentIter__lookups_158((&ti_2), (&marked), (&(*im)), s, (*c).graph);
						{
							while (1) {
								if (!!((candidate_2 == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA23;
								s_2 = candidate_2;
								{
									NI T28_;
									if (!((filter &((NU32)1<<((NU)((*s_2).kind)&31U)))!=0)) goto LA26_;
									result = (tySequence__ed0C0uAUZPhvw3RAc5hfYg*) incrSeqV3((TGenericSeq*)(result), (&NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_));
									T28_ = result->Sup.len++;
									asgnRef((void**) (&result->data[T28_]), s_2);
								}
								LA26_: ;
								candidate_2 = nextIdentIter__lookups_278((&ti_2), (&marked), (&(*im)), (*c).graph);
							} LA23: ;
						}
					}
					i += ((NI) 1);
				} LA20: ;
			}
		}
	}
	LA15_: ;
	return result;
}
static N_INLINE(NI, scopeDepth__semdata_320)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c) {
	NI result;
	result = (NI)0;
	{
		if (!!(((*c).currentScope == ((tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ*) NIM_NIL)))) goto LA3_;
		result = (*(*c).currentScope).depthLevel;
	}
	goto LA1_;
	LA3_: ;
	{
		result = ((NI) 0);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ*, openScope__lookups_76)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c) {
	tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* result;
	tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* T1_;
	NI T2_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ*) newObj((&NTIpscope__1WBIpqNgZhwC9bV4356CRhQ_), sizeof(tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ));
	asgnRef((void**) (&(*T1_).parent), (*c).currentScope);
	newStrTable__ast_4082((&(*T1_).symbols));
	T2_ = (NI)0;
	T2_ = scopeDepth__semdata_320(c);
	(*T1_).depthLevel = (NI)(T2_ + ((NI) 1));
	result = T1_;
	asgnRef((void**) (&(*c).currentScope), result);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, addUniqueSym__lookups_72)(tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	result = NIM_NIL;
	result = strTableInclReportConflict__astalgo_3335((&(*scope).symbols), s, NIM_FALSE);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, wrongRedefinition__lookups_985)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw conflictsWith, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ note) {
	{
		tyArray__Re75IspeoxXy2oCZHwcRrA T5_;
		NimStringDesc* T6_;
		if (!!(((*(*(*c).graph).config).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 24)))) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
		T5_[0] = copyString(s);
		T5_[1] = dollar___msgs_634((*(*c).graph).config, conflictsWith);
		T6_ = NIM_NIL;
		T6_ = nsuFormatOpenArray(((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_11), T5_, 2);
		liMessage__msgs_1128((*(*c).graph).config, info, note, T6_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__lKFMSIMkJc3WyNochLWXNg_12, NIM_FALSE);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addDeclAt__lookups_995)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* conflict;
	conflict = addUniqueSym__lookups_72(scope, sym);
	{
		if (!!((conflict == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = ((*sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6));
			if (!(T7_)) goto LA8_;
			T7_ = ((*conflict).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6));
			LA8_: ;
			if (!T7_) goto LA9_;
			{
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym83_;
				NI* T13_;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym86_;
				NI* T14_;
				tyArray__Re75IspeoxXy2oCZHwcRrA T17_;
				NimStringDesc* T18_;
				xX60gensym83_ = sym;
				T13_ = (NI*)0;
				T13_ = X5BX5D___lookups_1101((&(*c).importModuleMap), (NI)((NI)((NU64)(((NI) ((*xX60gensym83_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym83_).Sup.itemId.item))));
				xX60gensym86_ = conflict;
				T14_ = (NI*)0;
				T14_ = X5BX5D___lookups_1101((&(*c).importModuleMap), (NI)((NI)((NU64)(((NI) ((*xX60gensym86_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym86_).Sup.itemId.item))));
				if (!((*T13_) == (*T14_))) goto LA15_;
				nimZeroMem((void*)T17_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T17_[0] = copyString((*(*sym).name).s);
				T17_[1] = dollar___msgs_634((*(*c).graph).config, (*conflict).info);
				T18_ = NIM_NIL;
				T18_ = nsuFormatOpenArray(((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_9), T17_, 2);
				liMessage__msgs_1128((*(*c).graph).config, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 77), T18_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__lKFMSIMkJc3WyNochLWXNg_10, NIM_FALSE);
			}
			LA15_: ;
		}
		goto LA5_;
		LA9_: ;
		{
			wrongRedefinition__lookups_985(c, info, (*(*sym).name).s, (*conflict).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15));
		}
		LA5_: ;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getSymRepr__lookups_728)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NIM_BOOL getDeclarationPath) {
	NimStringDesc* result;
	result = NIM_NIL;
	switch ((*s).kind) {
	case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 12) ... ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 18):
	case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 7):
	{
		result = getProcHeader__types_222(conf, s, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0), getDeclarationPath);
	}
	break;
	default:
	{
		result = nsuFormatSingleElem(((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_14), (*(*s).name).s);
		{
			if (!getDeclarationPath) goto LA5_;
			addDeclaredLoc__astmsgs_17((&result), conf, s);
		}
		LA5_: ;
	}
	break;
	}
	return result;
}
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x) {
	addInt__stdZprivateZdigitsutils_167(result, ((NI64) (x)));
}
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_629)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = toMsgFilename__msgs_612(conf, info.fileIndex);
	result = resizeString(result, (T1_ ? T1_->Sup.len : 0) + 0);
appendString(result, T1_);
	{
		if (!(((NI) 0) < ((NI) (info.line)))) goto LA4_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_16));
		addInt__stdZprivateZdigitsutils_189((&result), ((NI) (info.line)));
		{
			if (!(((NI) 0) < (NI)(((NI) (info.col)) + ((NI) 1)))) goto LA8_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_17));
			addInt__stdZprivateZdigitsutils_189((&result), (NI)(((NI) (info.col)) + ((NI) 1)));
		}
		LA8_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_18));
	}
	LA4_: ;
	return result;
}
static N_NIMCALL(void, Marker_tySequence__EK3kb9a029axOL6ZINxWj1hw)(void* p, NI op) {
	tySequence__EK3kb9a029axOL6ZINxWj1hw* a;
	NI T1_;
	a = (tySequence__EK3kb9a029axOL6ZINxWj1hw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field0, op);
	nimGCvisit((void*)a->data[T1_].Field1, op);
	}
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5302(p);
	decRef__system_5347(T1_);
}
N_LIB_PRIVATE N_NIMCALL(NI, colonanonymous___lookups_791)(tyTuple__Ztb9b8BdGY9bQ5Qd69ajoC2fQ xX60gensym68_, tyTuple__Ztb9b8BdGY9bQ5Qd69ajoC2fQ yX60gensym68_) {
	NI result;
	tyTuple__Ztb9b8BdGY9bQ5Qd69ajoC2fQ it;
	NimStringDesc* aX60gensym68_;
	NimStringDesc* bX60gensym68_;
	result = (NI)0;
	nimZeroMem((void*)(&it), sizeof(tyTuple__Ztb9b8BdGY9bQ5Qd69ajoC2fQ));
	it.Field0 = xX60gensym68_.Field0;
	it.Field1 = copyString(xX60gensym68_.Field1);
	aX60gensym68_ = it.Field1;
	it.Field0 = yX60gensym68_.Field0;
	it.Field1 = copyString(yX60gensym68_.Field1);
	bX60gensym68_ = it.Field1;
	result = cmp__system_1549(aX60gensym68_, bX60gensym68_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, ensureNoMissingOrUnusedSymbols__lookups_17)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope) {
	tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw it;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
	NI missingImpls;
	tySequence__EK3kb9a029axOL6ZINxWj1hw* unusedSyms;
	nimZeroMem((void*)(&it), sizeof(tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw));
	s = initTabIter__astalgo_3770((&it), (*scope).symbols);
	missingImpls = ((NI) 0);
	unusedSyms = NIM_NIL;
	{
		while (1) {
			if (!!((s == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA2;
			{
				NIM_BOOL T5_;
				T5_ = (NIM_BOOL)0;
				T5_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 4))&63U)))!=0);
				if (!(T5_)) goto LA6_;
				T5_ = !(((192 &((NU32)1<<((NU)((*s).kind)&31U)))!=0));
				LA6_: ;
				if (!T5_) goto LA7_;
				{
					NimStringDesc* T13_;
					NimStringDesc* T14_;
					if (!(missingImpls == ((NI) 0))) goto LA11_;
					T13_ = NIM_NIL;
					T13_ = getSymRepr__lookups_728((*(*c).graph).config, s, NIM_FALSE);
					T14_ = NIM_NIL;
					T14_ = nsuFormatSingleElem(((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_13), T13_);
					liMessage__msgs_1128((*(*c).graph).config, (*s).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T14_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__lKFMSIMkJc3WyNochLWXNg_15, NIM_FALSE);
				}
				LA11_: ;
				missingImpls += ((NI) 1);
			}
			goto LA3_;
			LA7_: ;
			{
				if (!((3 & (*s).flags) == 0)) goto LA16_;
				{
					if (!!(((3162137 &((NU32)1<<((NU)((*s).kind)&31U)))!=0))) goto LA20_;
					{
						NIM_BOOL T24_;
						NIM_BOOL T25_;
						tyTuple__Ztb9b8BdGY9bQ5Qd69ajoC2fQ T30_;
						NI T31_;
						NimStringDesc* T32_;
						T24_ = (NIM_BOOL)0;
						T25_ = (NIM_BOOL)0;
						T25_ = !(((*s).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
						if (!(T25_)) goto LA26_;
						T25_ = !((((*(*s).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 26))&63U)))!=0));
						LA26_: ;
						T24_ = T25_;
						if (!(T24_)) goto LA27_;
						T24_ = !(((*(*s).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 12)));
						LA27_: ;
						if (!T24_) goto LA28_;
						nimZeroMem((void*)(&T30_), sizeof(tyTuple__Ztb9b8BdGY9bQ5Qd69ajoC2fQ));
						T30_.Field0 = s;
						T30_.Field1 = toFileLineCol__msgs_629((*(*c).graph).config, (*s).info);
						unusedSyms = (tySequence__EK3kb9a029axOL6ZINxWj1hw*) incrSeqV3((TGenericSeq*)(unusedSyms), (&NTIseqLtupleLsym58psym_key58stringTT__EK3kb9a029axOL6ZINxWj1hw_));
						T31_ = unusedSyms->Sup.len++;
						asgnRef((void**) (&unusedSyms->data[T31_].Field0), T30_.Field0);
						T32_ = NIM_NIL;
						T32_ = unusedSyms->data[T31_].Field1; unusedSyms->data[T31_].Field1 = copyStringRC1(T30_.Field1);
						if (T32_) nimGCunrefNoCycle(T32_);
					}
					LA28_: ;
				}
				LA20_: ;
			}
			goto LA3_;
			LA16_: ;
			LA3_: ;
			s = nextIter__astalgo_3755((&it), (*scope).symbols);
		} LA2: ;
	}
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw** s_2;
		NimStringDesc** _;
		tySequence__EK3kb9a029axOL6ZINxWj1hw* colontmp_;
		tySequence__EK3kb9a029axOL6ZINxWj1hw* resultX60gensym68_;
		tyProc__u9cu9aE0U3KrPDmkcU8DWlOw T34_;
		NI i;
		NI L;
		NI T35_;
		s_2 = (tyObject_TSym__3r34mwqcVmg5JFNmiaVncw**)0;
		_ = (NimStringDesc**)0;
		colontmp_ = NIM_NIL;
		nimZeroMem((void*)(&T34_), sizeof(tyProc__u9cu9aE0U3KrPDmkcU8DWlOw));
		T34_.ClP_0 = ((TM__lKFMSIMkJc3WyNochLWXNg_20) (colonanonymous___lookups_791)); T34_.ClE_0 = NIM_NIL;
		resultX60gensym68_ = sorted__lookups_830((unusedSyms) ? (unusedSyms->data) : NIM_NIL, (unusedSyms ? unusedSyms->Sup.len : 0), T34_, ((tyEnum_SortOrder__TcYjciSJ3jKUT4ygglumjg) 1));
		colontmp_ = resultX60gensym68_;
		i = ((NI) 0);
		T35_ = (colontmp_ ? colontmp_->Sup.len : 0);
		L = T35_;
		{
			while (1) {
				if (!(i < L)) goto LA37;
				s_2 = &colontmp_->data[i].Field0;
				_ = (&colontmp_->data[i].Field1);
				liMessage__msgs_1128((*(*c).graph).config, (*(*s_2)).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 76), (*(*(*s_2)).name).s, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__lKFMSIMkJc3WyNochLWXNg_21, NIM_FALSE);
				i += ((NI) 1);
			} LA37: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, rawCloseScope__lookups_106)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c) {
	asgnRef((void**) (&(*c).currentScope), (*(*c).currentScope).parent);
}
N_LIB_PRIVATE N_NIMCALL(void, closeScope__lookups_108)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c) {
	ensureNoMissingOrUnusedSymbols__lookups_17(c, (*c).currentScope);
	rawCloseScope__lookups_106(c);
}
N_LIB_PRIVATE N_NIMCALL(void, openShadowScope__lookups_1575)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c) {
	tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* T1_;
	T1_ = NIM_NIL;
	T1_ = (tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ*) newObj((&NTIpscope__1WBIpqNgZhwC9bV4356CRhQ_), sizeof(tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ));
	asgnRef((void**) (&(*T1_).parent), (*c).currentScope);
	newStrTable__ast_4082((&(*T1_).symbols));
	(*T1_).depthLevel = scopeDepth__semdata_320(c);
	asgnRef((void**) (&(*c).currentScope), T1_);
}
N_LIB_PRIVATE N_NIMCALL(void, addOverloadableSymAt__lookups_1554)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fn) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* check;
{	{
		if (!!(((1568832 &((NU32)1<<((NU)((*fn).kind)&31U)))!=0))) goto LA3_;
		internalErrorImpl__msgs_1441((*(*c).graph).config, (*fn).info, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_22), TM__lKFMSIMkJc3WyNochLWXNg_23);
		goto BeforeRet_;
	}
	LA3_: ;
	check = strTableGet__astalgo_3383((*scope).symbols, (*fn).name);
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = !((check == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
		if (!(T7_)) goto LA8_;
		T7_ = !(((1568832 &((NU32)1<<((NU)((*check).kind)&31U)))!=0));
		LA8_: ;
		if (!T7_) goto LA9_;
		wrongRedefinition__lookups_985(c, (*fn).info, (*(*fn).name).s, (*check).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15));
	}
	goto LA5_;
	LA9_: ;
	{
		strTableAdd__astalgo_3325((&(*scope).symbols), fn);
	}
	LA5_: ;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isShadowScope__lookups_142)(tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* s) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = !(((*s).parent == ((tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ*) NIM_NIL)));
	if (!(T1_)) goto LA2_;
	T1_ = ((*(*s).parent).depthLevel == (*s).depthLevel);
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(NIM_BOOL, isTopLevelInsideDeclaration__semdata_1124)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((*(*c).currentScope).depthLevel <= (NI)(((NI) 2) + ((520192 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addInterfaceDeclAux__lookups_1524)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	{
		if (!(((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 1))&63U)))!=0)) goto LA3_;
		{
			if (!!(((*c).module == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA7_;
			exportSym__semdata_740(c, sym);
		}
		goto LA5_;
		LA7_: ;
		{
			internalErrorImpl__msgs_1441((*(*c).graph).config, (*sym).info, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_24), TM__lKFMSIMkJc3WyNochLWXNg_25);
		}
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T11_;
		NIM_BOOL T12_;
		T11_ = (NIM_BOOL)0;
		T12_ = (NIM_BOOL)0;
		T12_ = ((43513728 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0);
		if (!(T12_)) goto LA13_;
		T12_ = !(((*c).module == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
		LA13_: ;
		T11_ = T12_;
		if (!(T11_)) goto LA14_;
		T11_ = isTopLevelInsideDeclaration__semdata_1124(c, sym);
		LA14_: ;
		if (!T11_) goto LA15_;
		strTableAdd__astalgo_3325((&(*(*c).graph).ifaces->data[(*(*c).module).position].interfHidden), sym);
		{
			if (!!(((*(*(*c).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0)))) goto LA19_;
			addHidden__icZic_2308((&(*(*c).graph).encoders->data[(*(*c).module).position]), (&(*(*c).graph).packed_0->data[(*(*c).module).position].fromDisk), sym);
		}
		LA19_: ;
	}
	goto LA1_;
	LA15_: ;
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addInterfaceOverloadableSymAt__lookups_1571)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	addOverloadableSymAt__lookups_1554(c, scope, sym);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isShadowScope__lookups_142(scope);
		if (!!(T3_)) goto LA4_;
		addInterfaceDeclAux__lookups_1524(c, sym);
	}
	LA4_: ;
}
static N_INLINE(void, addDeclAt__lookups_1509)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	addDeclAt__lookups_995(c, scope, sym, (*sym).info);
}
N_LIB_PRIVATE N_NIMCALL(void, addInterfaceDeclAt__lookups_1547)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	addDeclAt__lookups_1509(c, scope, sym);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isShadowScope__lookups_142(scope);
		if (!!(T3_)) goto LA4_;
		addInterfaceDeclAux__lookups_1524(c, sym);
	}
	LA4_: ;
}
static N_INLINE(void, addInterfaceDecl__lookups_1551)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	addInterfaceDeclAt__lookups_1547(c, (*c).currentScope, sym);
}
N_LIB_PRIVATE N_NIMCALL(void, mergeShadowScope__lookups_1579)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c) {
	tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* shadowScope;
	shadowScope = (*c).currentScope;
	rawCloseScope__lookups_106(c);
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
		tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw it;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
		sym = NIM_NIL;
		nimZeroMem((void*)(&it), sizeof(tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw));
		s = initTabIter__astalgo_3770((&it), (*shadowScope).symbols);
		{
			while (1) {
				if (!!((s == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA3;
				sym = s;
				{
					if (!((1568832 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0)) goto LA6_;
					addInterfaceOverloadableSymAt__lookups_1571(c, (*c).currentScope, sym);
				}
				goto LA4_;
				LA6_: ;
				{
					addInterfaceDecl__lookups_1551(c, sym);
				}
				LA4_: ;
				s = nextIter__astalgo_3755((&it), (*shadowScope).symbols);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, closeShadowScope__lookups_1577)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c) {
	rawCloseScope__lookups_106(c);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, skipAlias__lookups_125)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (s == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = !(((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 25)));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = s;
	}
	goto LA1_;
	LA5_: ;
	{
		result = (*s).owner;
		{
			if (!((*conf).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 27))) goto LA10_;
			replaceDeprecated__nimfixZprettybase_47(conf, (*n).info, s, result);
		}
		goto LA8_;
		LA10_: ;
		{
			NimStringDesc* T13_;
			T13_ = NIM_NIL;
			T13_ = rawNewString(((*(*result).name).s ? (*(*result).name).s->Sup.len : 0) + ((*(*s).name).s ? (*(*s).name).s->Sup.len : 0) + 28);
appendString(T13_, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_26));
appendString(T13_, (*(*result).name).s);
appendString(T13_, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_27));
appendString(T13_, (*(*s).name).s);
appendString(T13_, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_28));
			liMessage__msgs_1128(conf, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 21), T13_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__lKFMSIMkJc3WyNochLWXNg_29, NIM_FALSE);
		}
		LA8_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, someSymFromImportTable__lookups_561)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name, NIM_BOOL* ambiguous) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw marked;
	tySet_tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw symSet;
	result = NIM_NIL;
	nimZeroMem((void*)(&marked), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
	initIntSet__pureZcollectionsZintsets_238((&marked));
	symSet = 1568832;
	{
		if (!!((((*c).features &((NU32)1<<((NU)(((tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw) 15))&31U)))!=0))) goto LA3_;
		symSet &= ~(((NU32)1) << ((((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 20)) & 31));
	}
	LA3_: ;
	result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
	{
		{
			tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg* im;
			NI i;
			NI L;
			NI T7_;
			im = (tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg*)0;
			i = ((NI) 0);
			T7_ = ((*c).imports ? (*c).imports->Sup.len : 0);
			L = T7_;
			{
				while (1) {
					if (!(i < L)) goto LA9;
					im = (&(*c).imports->data[i]);
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
						tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A ti;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* candidate;
						s = NIM_NIL;
						nimZeroMem((void*)(&ti), sizeof(tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A));
						candidate = initIdentIter__lookups_158((&ti), (&marked), (&(*im)), name, (*c).graph);
						{
							while (1) {
								if (!!((candidate == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA12;
								s = candidate;
								{
									if (!(result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA15_;
									result = s;
								}
								goto LA13_;
								LA15_: ;
								{
									NIM_BOOL T18_;
									T18_ = (NIM_BOOL)0;
									T18_ = !(((symSet &((NU32)1<<((NU)((*s).kind)&31U)))!=0));
									if (T18_) goto LA19_;
									T18_ = !(((symSet &((NU32)1<<((NU)((*result).kind)&31U)))!=0));
									LA19_: ;
									if (!T18_) goto LA20_;
									(*ambiguous) = NIM_TRUE;
									goto LA5;
								}
								goto LA13_;
								LA20_: ;
								LA13_: ;
								candidate = nextIdentIter__lookups_278((&ti), (&marked), (&(*im)), (*c).graph);
							} LA12: ;
						}
					}
					i += ((NI) 1);
				} LA9: ;
			}
		}
	} LA5: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, searchInScopes__lookups_603)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* s, NIM_BOOL* ambiguous) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
{	result = NIM_NIL;
	{
		tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope;
		tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* current;
		scope = NIM_NIL;
		current = (*c).currentScope;
		{
			while (1) {
				if (!!((current == ((tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ*) NIM_NIL)))) goto LA3;
				scope = current;
				result = strTableGet__astalgo_3383((*scope).symbols, s);
				{
					if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA6_;
					goto BeforeRet_;
				}
				LA6_: ;
				current = (*current).parent;
			} LA3: ;
		}
	}
	result = someSymFromImportTable__lookups_561(c, s, ambiguous);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, errorUseQualifier__lookups_2521)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tySequence__ed0C0uAUZPhvw3RAc5hfYg* candidates, NimStringDesc* prefix) {
	NimStringDesc* err;
	NimStringDesc* T1_;
	NI i;
	T1_ = NIM_NIL;
	T1_ = rawNewString(((*(*candidates->data[((NI) 0)]).name).s ? (*(*candidates->data[((NI) 0)]).name).s->Sup.len : 0) + 24);
appendString(T1_, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_30));
appendString(T1_, (*(*candidates->data[((NI) 0)]).name).s);
appendString(T1_, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_5));
	err = T1_;
	i = ((NI) 0);
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw** candidate;
		NI i_2;
		NI L;
		NI T3_;
		candidate = (tyObject_TSym__3r34mwqcVmg5JFNmiaVncw**)0;
		i_2 = ((NI) 0);
		T3_ = (candidates ? candidates->Sup.len : 0);
		L = T3_;
		{
			while (1) {
				NimStringDesc* T12_;
				NimStringDesc* T13_;
				NimStringDesc* T14_;
				if (!(i_2 < L)) goto LA5;
				candidate = &candidates->data[i_2];
				{
					NimStringDesc* T10_;
					if (!(i == ((NI) 0))) goto LA8_;
					T10_ = NIM_NIL;
					T10_ = nsuFormatSingleElem(((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_31), prefix);
					err = resizeString(err, (T10_ ? T10_->Sup.len : 0) + 0);
appendString(err, T10_);
				}
				goto LA6_;
				LA8_: ;
				{
					err = resizeString(err, 1);
appendString(err, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_32));
				}
				LA6_: ;
				T12_ = NIM_NIL;
				T12_ = rawNewString(((*(*(*(*candidate)).owner).name).s ? (*(*(*(*candidate)).owner).name).s->Sup.len : 0) + ((*(*(*candidate)).name).s ? (*(*(*candidate)).name).s->Sup.len : 0) + 3);
appendString(T12_, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_33));
appendString(T12_, (*(*(*(*candidate)).owner).name).s);
appendString(T12_, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_34));
appendString(T12_, (*(*(*candidate)).name).s);
				err = resizeString(err, (T12_ ? T12_->Sup.len : 0) + 0);
appendString(err, T12_);
				T13_ = NIM_NIL;
				T14_ = NIM_NIL;
				T14_ = typeToString__types_50((*(*candidate)).typ, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
				T13_ = rawNewString((T14_ ? T14_->Sup.len : 0) + 2);
appendString(T13_, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_35));
appendString(T13_, T14_);
				err = resizeString(err, (T13_ ? T13_->Sup.len : 0) + 0);
appendString(err, T13_);
				i += ((NI) 1);
				i_2 += ((NI) 1);
			} LA5: ;
		}
	}
	liMessage__msgs_1128((*(*c).graph).config, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), err, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__lKFMSIMkJc3WyNochLWXNg_36, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__ed0C0uAUZPhvw3RAc5hfYg*, allPureEnumFields__lookups_495)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name) {
	tySequence__ed0C0uAUZPhvw3RAc5hfYg* result;
	tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g ti;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* res;
	result = NIM_NIL;
	nimZeroMem((void*)(&ti), sizeof(tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g));
	result = NIM_NIL;
	res = initIdentIter__astalgo_3420((&ti), (*c).pureEnumFields, name);
	{
		while (1) {
			NI T3_;
			if (!!((res == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA2;
			result = (tySequence__ed0C0uAUZPhvw3RAc5hfYg*) incrSeqV3((TGenericSeq*)(result), (&NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_));
			T3_ = result->Sup.len++;
			asgnRef((void**) (&result->data[T3_]), res);
			res = nextIdentIter__astalgo_3401((&ti), (*c).pureEnumFields);
		} LA2: ;
	}
	return result;
}
static N_INLINE(NIM_BOOL, mustFixSpelling__lookups_1621)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = !(((*(*(*c).graph).config).spellSuggestMax == ((NI) 0)));
	if (!(T1_)) goto LA2_;
	T1_ = ((*c).compilesContextId == ((NI) 0));
	LA2_: ;
	result = T1_;
	return result;
}
static N_NIMCALL(void, Marker_tySequence__wDFGR0GrXEVcAPtPuTlVAA)(void* p, NI op) {
	tySequence__wDFGR0GrXEVcAPtPuTlVAA* a;
	NI T1_;
	a = (tySequence__wDFGR0GrXEVcAPtPuTlVAA*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].msg, op);
	nimGCvisit((void*)a->data[T1_].sym, op);
	}
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___lookups_1596)(tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA* a, tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA* b) {
	NIM_BOOL result;
	tyTuple__kuMQ1fbjJlHtwKTmBGAe6g T1_;
	tyTuple__kuMQ1fbjJlHtwKTmBGAe6g T2_;
	result = (NIM_BOOL)0;
	nimZeroMem((void*)(&T1_), sizeof(tyTuple__kuMQ1fbjJlHtwKTmBGAe6g));
	T1_.Field0 = (*a).dist;
	T1_.Field1 = (*a).depth;
	T1_.Field2 = copyString((*a).msg);
	nimZeroMem((void*)(&T2_), sizeof(tyTuple__kuMQ1fbjJlHtwKTmBGAe6g));
	T2_.Field0 = (*b).dist;
	T2_.Field1 = (*b).depth;
	T2_.Field2 = copyString((*b).msg);
	result = lt___lookups_1600(T1_, T2_);
	return result;
}
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_2710)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NI module) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = ((*g).packed_0 ? (*g).packed_0->Sup.len : 0);
	T1_ = (module < T2_);
	if (!(T1_)) goto LA3_;
	T1_ = ((*g).packed_0->data[module].status == ((tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg) 3));
	LA3_: ;
	result = T1_;
	return result;
}
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_2722)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = isCachedModule__modulegraphs_2710(g, (*m).position);
	return result;
}
static N_INLINE(NI, len__lookups_1696)(tyObject_HeapQueue__MBC6eEbMfekVnGqjI07yVg heap) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = (heap.data ? heap.data->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA*, X5BX5D___lookups_1764)(tyObject_HeapQueue__MBC6eEbMfekVnGqjI07yVg* heap, NI i) {
	tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA* result;
	result = (tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA*)0;
	result = (&(*heap).data->data[i]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, fixSpelling__lookups_1624)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident, NimStringDesc** result) {
	tyObject_HeapQueue__MBC6eEbMfekVnGqjI07yVg list;
	NimStringDesc* name0;
	tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA e0;
	tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA* T54_;
	NI count;
{	nimZeroMem((void*)(&list), sizeof(tyObject_HeapQueue__MBC6eEbMfekVnGqjI07yVg));
	initHeapQueue__lookups_1629((&list));
	name0 = nimIdentNormalize__pureZstrutils_105((*ident).s);
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
		NI depth;
		NIM_BOOL isLocal;
		NIM_BOOL isLocal_2;
		NI scopeN;
		sym = NIM_NIL;
		depth = (NI)0;
		isLocal = (NIM_BOOL)0;
		isLocal_2 = NIM_TRUE;
		scopeN = ((NI) 0);
		{
			tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope;
			tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* current;
			scope = NIM_NIL;
			current = (*c).currentScope;
			{
				while (1) {
					if (!!((current == ((tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ*) NIM_NIL)))) goto LA4;
					scope = current;
					{
						if (!(scope == (*c).topLevelScope)) goto LA7_;
						isLocal_2 = NIM_FALSE;
					}
					LA7_: ;
					scopeN -= ((NI) 1);
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* item;
						tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw it;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
						item = NIM_NIL;
						nimZeroMem((void*)(&it), sizeof(tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw));
						s = initTabIter__astalgo_3770((&it), (*scope).symbols);
						{
							while (1) {
								tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A colontmp_;
								NI depth_2;
								NI dist;
								NimStringDesc* T12_;
								NimStringDesc* msg;
								tyArray__24KAM9afIUgUaqBaEBB6r9bg T13_;
								NimStringDesc* T14_;
								tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA T15_;
								if (!!((s == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA11;
								item = s;
								nimZeroMem((void*)(&colontmp_), sizeof(tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A));
								colontmp_.Field0 = item;
								colontmp_.Field1 = scopeN;
								colontmp_.Field2 = isLocal_2;
								sym = colontmp_.Field0;
								depth = colontmp_.Field1;
								isLocal = colontmp_.Field2;
								depth_2 = (NI)(((NI64)-(depth)) - ((NI) 1));
								T12_ = NIM_NIL;
								T12_ = nimIdentNormalize__pureZstrutils_105((*(*sym).name).s);
								dist = editDistance__stdZeditdistance_2(name0, T12_);
								msg = NIM_NIL;
								nimZeroMem((void*)T13_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
								T13_[0] = dollar___systemZdollars_3(dist);
								T13_[1] = dollar___systemZdollars_3(depth_2);
								T13_[2] = copyString((*(*sym).name).s);
								T14_ = NIM_NIL;
								T14_ = nsuFormatOpenArray(((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_38), T13_, 3);
								msg = resizeString(msg, (T14_ ? T14_->Sup.len : 0) + 0);
appendString(msg, T14_);
								addDeclaredLoc__astmsgs_17((&msg), (*(*c).graph).config, sym);
								nimZeroMem((void*)(&T15_), sizeof(tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA));
								nimZeroMem((void*)(&T15_), sizeof(tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA));
								T15_.dist = dist;
								T15_.depth = depth_2;
								T15_.msg = copyString(msg);
								T15_.sym = sym;
								push__lookups_1642((&list), (&T15_));
								s = nextIter__astalgo_3755((&it), (*scope).symbols);
							} LA11: ;
						}
					}
					current = (*current).parent;
				} LA4: ;
			}
		}
		scopeN -= ((NI) 1);
		isLocal_2 = NIM_FALSE;
		{
			tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg* im;
			NI i;
			NI L;
			NI T17_;
			im = (tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg*)0;
			i = ((NI) 0);
			T17_ = ((*c).imports ? (*c).imports->Sup.len : 0);
			L = T17_;
			{
				while (1) {
					if (!(i < L)) goto LA19;
					im = (&(*c).imports->data[i]);
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s_2;
						NIM_BOOL importHidden;
						s_2 = NIM_NIL;
						importHidden = (((*(*im).m).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 27))&31U)))!=0);
						{
							NIM_BOOL T23_;
							tyObject_RodIter__L6nv9cakjPARHk068AFo6ww rodIt;
							tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* r;
							T23_ = (NIM_BOOL)0;
							T23_ = isCachedModule__modulegraphs_2722((*c).graph, (*im).m);
							if (!T23_) goto LA24_;
							nimZeroMem((void*)(&rodIt), sizeof(tyObject_RodIter__L6nv9cakjPARHk068AFo6ww));
							r = initRodIterAllSyms__icZic_8670((&rodIt), (*(*c).graph).config, (*(*c).graph).cache, (&(*(*c).graph).packed_0), ((NI32) ((*(*im).m).position)), importHidden);
							{
								while (1) {
									tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A colontmp__2;
									NI depth_3;
									NI dist_2;
									NimStringDesc* T28_;
									NimStringDesc* msg_2;
									tyArray__24KAM9afIUgUaqBaEBB6r9bg T29_;
									NimStringDesc* T30_;
									tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA T31_;
									if (!!((r == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA27;
									s_2 = r;
									nimZeroMem((void*)(&colontmp__2), sizeof(tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A));
									colontmp__2.Field0 = s_2;
									colontmp__2.Field1 = scopeN;
									colontmp__2.Field2 = isLocal_2;
									sym = colontmp__2.Field0;
									depth = colontmp__2.Field1;
									isLocal = colontmp__2.Field2;
									depth_3 = (NI)(((NI64)-(depth)) - ((NI) 1));
									T28_ = NIM_NIL;
									T28_ = nimIdentNormalize__pureZstrutils_105((*(*sym).name).s);
									dist_2 = editDistance__stdZeditdistance_2(name0, T28_);
									msg_2 = NIM_NIL;
									nimZeroMem((void*)T29_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
									T29_[0] = dollar___systemZdollars_3(dist_2);
									T29_[1] = dollar___systemZdollars_3(depth_3);
									T29_[2] = copyString((*(*sym).name).s);
									T30_ = NIM_NIL;
									T30_ = nsuFormatOpenArray(((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_38), T29_, 3);
									msg_2 = resizeString(msg_2, (T30_ ? T30_->Sup.len : 0) + 0);
appendString(msg_2, T30_);
									addDeclaredLoc__astmsgs_17((&msg_2), (*(*c).graph).config, sym);
									nimZeroMem((void*)(&T31_), sizeof(tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA));
									nimZeroMem((void*)(&T31_), sizeof(tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA));
									T31_.dist = dist_2;
									T31_.depth = depth_3;
									T31_.msg = copyString(msg_2);
									T31_.sym = sym;
									push__lookups_1642((&list), (&T31_));
									r = nextRodIter__icZic_8980((&rodIt), (&(*(*c).graph).packed_0));
								} LA27: ;
							}
						}
						goto LA21_;
						LA24_: ;
						{
							{
								tyObject_TSym__3r34mwqcVmg5JFNmiaVncw** s_3;
								tySequence__ed0C0uAUZPhvw3RAc5hfYg* colontmp__3;
								tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* retX60gensym17_;
								NI i_2;
								NI L_2;
								NI T38_;
								s_3 = (tyObject_TSym__3r34mwqcVmg5JFNmiaVncw**)0;
								colontmp__3 = NIM_NIL;
								retX60gensym17_ = (&(*(*c).graph).ifaces->data[(*(*im).m).position].interf);
								{
									if (!importHidden) goto LA36_;
									retX60gensym17_ = (&(*(*c).graph).ifaces->data[(*(*im).m).position].interfHidden);
								}
								LA36_: ;
								colontmp__3 = (*retX60gensym17_).data;
								i_2 = ((NI) 0);
								T38_ = (colontmp__3 ? colontmp__3->Sup.len : 0);
								L_2 = T38_;
								{
									while (1) {
										if (!(i_2 < L_2)) goto LA40;
										s_3 = &colontmp__3->data[i_2];
										{
											tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A colontmp__4;
											NI depth_4;
											NI dist_3;
											NimStringDesc* T45_;
											NimStringDesc* msg_3;
											tyArray__24KAM9afIUgUaqBaEBB6r9bg T46_;
											NimStringDesc* T47_;
											tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA T48_;
											if (!!(((*s_3) == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA43_;
											s_2 = (*s_3);
											nimZeroMem((void*)(&colontmp__4), sizeof(tyTuple__Fa3eAsA5r9cNEvaYHmNpj2A));
											colontmp__4.Field0 = s_2;
											colontmp__4.Field1 = scopeN;
											colontmp__4.Field2 = isLocal_2;
											sym = colontmp__4.Field0;
											depth = colontmp__4.Field1;
											isLocal = colontmp__4.Field2;
											depth_4 = (NI)(((NI64)-(depth)) - ((NI) 1));
											T45_ = NIM_NIL;
											T45_ = nimIdentNormalize__pureZstrutils_105((*(*sym).name).s);
											dist_3 = editDistance__stdZeditdistance_2(name0, T45_);
											msg_3 = NIM_NIL;
											nimZeroMem((void*)T46_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
											T46_[0] = dollar___systemZdollars_3(dist_3);
											T46_[1] = dollar___systemZdollars_3(depth_4);
											T46_[2] = copyString((*(*sym).name).s);
											T47_ = NIM_NIL;
											T47_ = nsuFormatOpenArray(((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_38), T46_, 3);
											msg_3 = resizeString(msg_3, (T47_ ? T47_->Sup.len : 0) + 0);
appendString(msg_3, T47_);
											addDeclaredLoc__astmsgs_17((&msg_3), (*(*c).graph).config, sym);
											nimZeroMem((void*)(&T48_), sizeof(tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA));
											nimZeroMem((void*)(&T48_), sizeof(tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA));
											T48_.dist = dist_3;
											T48_.depth = depth_4;
											T48_.msg = copyString(msg_3);
											T48_.sym = sym;
											push__lookups_1642((&list), (&T48_));
										}
										LA43_: ;
										i_2 += ((NI) 1);
									} LA40: ;
								}
							}
						}
						LA21_: ;
					}
					i += ((NI) 1);
				} LA19: ;
			}
		}
	}
	{
		NI T51_;
		T51_ = (NI)0;
		T51_ = len__lookups_1696(list);
		if (!(T51_ == ((NI) 0))) goto LA52_;
		goto BeforeRet_;
	}
	LA52_: ;
	nimZeroMem((void*)(&e0), sizeof(tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA));
	T54_ = (tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA*)0;
	T54_ = X5BX5D___lookups_1764((&list), ((NI) 0));
	e0.dist = (*T54_).dist;
	e0.depth = (*T54_).depth;
	e0.msg = (*T54_).msg;
	e0.sym = (*T54_).sym;
	count = ((NI) 0);
	{
		while (1) {
			tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA e;
			{
				NI T59_;
				T59_ = (NI)0;
				T59_ = len__lookups_1696(list);
				if (!(T59_ == ((NI) 0))) goto LA60_;
				goto LA55;
			}
			LA60_: ;
			nimZeroMem((void*)(&e), sizeof(tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA));
			pop__lookups_2054((&list), (&e));
			{
				if (!((*(*(*c).graph).config).spellSuggestMax == ((NI) -1))) goto LA64_;
				{
					NIM_BOOL T68_;
					NIM_BOOL T70_;
					T68_ = (NIM_BOOL)0;
					T68_ = (e0.dist < e.dist);
					if (T68_) goto LA69_;
					T70_ = (NIM_BOOL)0;
					T70_ = ((name0 ? name0->Sup.len : 0) <= ((NI) 2));
					if (!(T70_)) goto LA71_;
					T70_ = (((NI) 4) <= count);
					LA71_: ;
					T68_ = T70_;
					LA69_: ;
					if (!T68_) goto LA72_;
					goto LA55;
				}
				LA72_: ;
			}
			goto LA62_;
			LA64_: ;
			{
				if (!((*(*(*c).graph).config).spellSuggestMax <= count)) goto LA75_;
				goto LA55;
			}
			goto LA62_;
			LA75_: ;
			LA62_: ;
			{
				if (!(count == ((NI) 0))) goto LA79_;
				unsureAsgnRef((void**) (&(*result)), resizeString((*result), 67));
appendString((*result), ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_40));
			}
			LA79_: ;
			unsureAsgnRef((void**) (&(*result)), resizeString((*result), (e.msg ? e.msg->Sup.len : 0) + 0));
appendString((*result), e.msg);
			count += ((NI) 1);
		}
	} LA55: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, errorUndeclaredIdentifier__lookups_2564)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* name, NimStringDesc* extra) {
	NimStringDesc* err;
	NimStringDesc* T1_;
	T1_ = NIM_NIL;
	T1_ = rawNewString((name ? name->Sup.len : 0) + (extra ? extra->Sup.len : 0) + 25);
appendString(T1_, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_41));
appendString(T1_, name);
appendString(T1_, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_5));
appendString(T1_, extra);
	err = T1_;
	{
		if (!(((NI) 0) < ((*c).recursiveDep ? (*c).recursiveDep->Sup.len : 0))) goto LA4_;
		err = resizeString(err, 56);
appendString(err, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_42));
		err = resizeString(err, ((*c).recursiveDep ? (*c).recursiveDep->Sup.len : 0) + 0);
appendString(err, (*c).recursiveDep);
		asgnRef((void**) (&(*c).recursiveDep), ((NimStringDesc*) NIM_NIL));
	}
	LA4_: ;
	liMessage__msgs_1128((*(*c).graph).config, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), err, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__lKFMSIMkJc3WyNochLWXNg_43, NIM_FALSE);
}
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextSymId__ast_3103)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x) {
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*x).symId += ((NI) 1);
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	result.module = (*x).module;
	result.item = (*x).symId;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, errorSym__lookups_686)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* m;
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T12_;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T13_;
	result = NIM_NIL;
	m = n;
	{
		if (!((*m).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45))) goto LA3_;
		m = (*m)._kind_6.sons->data[((NI) 1)];
	}
	LA3_: ;
	{
		if (!((*m).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2) || (*m).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3) || (*m).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 53))) goto LA7_;
		ident = considerQuotedIdent__lookups_29(c, m, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
	}
	goto LA5_;
	LA7_: ;
	{
		NimStringDesc* T10_;
		NimStringDesc* T11_;
		T10_ = NIM_NIL;
		T11_ = NIM_NIL;
		T11_ = renderTree__renderer_46(m, 0);
		T10_ = rawNewString((T11_ ? T11_->Sup.len : 0) + 4);
appendString(T10_, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_44));
appendString(T10_, T11_);
		ident = getIdent__idents_152((*c).cache, T10_);
	}
	LA5_: ;
	T12_ = nextSymId__ast_3103((*c).Sup.idgen);
	T13_ = NIM_NIL;
	T13_ = getCurrOwner__semdata_327(c);
	result = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 0), ident, T12_, T13_, (*n).info, 0);
	asgnRef((void**) (&(*result).typ), errorType__semdata_1032(c));
	(*result).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 34)) & 63);
	{
		NIM_BOOL T16_;
		T16_ = (NIM_BOOL)0;
		T16_ = !(((*(*(*c).graph).config).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 24)));
		if (!(T16_)) goto LA17_;
		T16_ = ((*c).compilesContextId == ((NI) 0));
		LA17_: ;
		if (!T16_) goto LA18_;
		strTableAdd__astalgo_3325((&(*(*c).moduleScope).symbols), result);
	}
	LA18_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, errorUndeclaredIdentifierHint__lookups_2570)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	NimStringDesc* extra;
	result = NIM_NIL;
	extra = ((NimStringDesc*) NIM_NIL);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = mustFixSpelling__lookups_1621(c);
		if (!T3_) goto LA4_;
		fixSpelling__lookups_1624(c, n, ident, (&extra));
	}
	LA4_: ;
	errorUndeclaredIdentifier__lookups_2564(c, (*n).info, (*ident).s, extra);
	result = errorSym__lookups_686(c, n);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, errorUseQualifier__lookups_2494)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NIM_BOOL* amb) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	NimStringDesc* err;
	NimStringDesc* T1_;
	NI i;
	NI ignoredModules;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = rawNewString(((*(*s).name).s ? (*(*s).name).s->Sup.len : 0) + 24);
appendString(T1_, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_30));
appendString(T1_, (*(*s).name).s);
appendString(T1_, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_5));
	err = T1_;
	i = ((NI) 0);
	ignoredModules = ((NI) 0);
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* candidate;
		tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw marked;
		candidate = NIM_NIL;
		nimZeroMem((void*)(&marked), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
		initIntSet__pureZcollectionsZintsets_238((&marked));
		{
			tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg* im;
			NI i_2;
			NI L;
			NI T4_;
			im = (tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg*)0;
			i_2 = ((NI) 0);
			T4_ = ((*c).imports ? (*c).imports->Sup.len : 0);
			L = T4_;
			{
				while (1) {
					if (!(i_2 < L)) goto LA6;
					im = (&(*c).imports->data[i_2]);
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s_2;
						tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A ti;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* candidate_2;
						s_2 = NIM_NIL;
						nimZeroMem((void*)(&ti), sizeof(tyObject_ModuleIter__ao1RRyFrHTmNImyTejOq7A));
						candidate_2 = initIdentIter__lookups_158((&ti), (&marked), (&(*im)), (*s).name, (*c).graph);
						{
							while (1) {
								NimStringDesc* T15_;
								NimStringDesc* T16_;
								NimStringDesc* T17_;
								if (!!((candidate_2 == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA9;
								s_2 = candidate_2;
								candidate = s_2;
								{
									if (!(i == ((NI) 0))) goto LA12_;
									err = resizeString(err, 30);
appendString(err, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_45));
								}
								goto LA10_;
								LA12_: ;
								{
									err = resizeString(err, 1);
appendString(err, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_32));
								}
								LA10_: ;
								T15_ = NIM_NIL;
								T15_ = rawNewString(((*(*(*candidate).owner).name).s ? (*(*(*candidate).owner).name).s->Sup.len : 0) + ((*(*candidate).name).s ? (*(*candidate).name).s->Sup.len : 0) + 3);
appendString(T15_, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_33));
appendString(T15_, (*(*(*candidate).owner).name).s);
appendString(T15_, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_34));
appendString(T15_, (*(*candidate).name).s);
								err = resizeString(err, (T15_ ? T15_->Sup.len : 0) + 0);
appendString(err, T15_);
								T16_ = NIM_NIL;
								T17_ = NIM_NIL;
								T17_ = typeToString__types_50((*candidate).typ, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
								T16_ = rawNewString((T17_ ? T17_->Sup.len : 0) + 2);
appendString(T16_, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_35));
appendString(T16_, T17_);
								err = resizeString(err, (T16_ ? T16_->Sup.len : 0) + 0);
appendString(err, T16_);
								{
									if (!((*candidate).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6))) goto LA20_;
									ignoredModules += ((NI) 1);
								}
								goto LA18_;
								LA20_: ;
								{
									result = candidate;
								}
								LA18_: ;
								i += ((NI) 1);
								candidate_2 = nextIdentIter__lookups_278((&ti), (&marked), (&(*im)), (*c).graph);
							} LA9: ;
						}
					}
					i_2 += ((NI) 1);
				} LA6: ;
			}
		}
	}
	{
		if (!!((ignoredModules == (NI)(i - ((NI) 1))))) goto LA25_;
		liMessage__msgs_1128((*(*c).graph).config, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), err, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__lKFMSIMkJc3WyNochLWXNg_46, NIM_FALSE);
		result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
	}
	goto LA23_;
	LA25_: ;
	{
		(*amb) = NIM_FALSE;
	}
	LA23_: ;
	return result;
}
static N_INLINE(NIM_BOOL, eqeq___idents_229)(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* a, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* b) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (a == 0);
		if (T3_) goto LA4_;
		T3_ = (b == 0);
		LA4_: ;
		if (!T3_) goto LA5_;
		result = (a == b);
	}
	goto LA1_;
	LA5_: ;
	{
		result = ((*a).id == (*b).id);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, qualifiedLookUp__lookups_2598)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TLookupFlag__ns0lQuhi2aWBQ9bXAfDCqaA flags) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	result = NIM_NIL;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 53):
	{
		NIM_BOOL amb;
		tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
		amb = NIM_FALSE;
		ident = considerQuotedIdent__lookups_29(c, n, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T6_;
			if (!((flags &((NU8)1<<((NU)(((tyEnum_TLookupFlag__ns0lQuhi2aWBQ9bXAfDCqaA) 2))&7U)))!=0)) goto LA4_;
			T6_ = NIM_NIL;
			T6_ = searchInScopes__lookups_603(c, ident, (&amb));
			result = skipAlias__lookups_125(T6_, n, (*(*c).graph).config);
		}
		goto LA2_;
		LA4_: ;
		{
			tySequence__ed0C0uAUZPhvw3RAc5hfYg* candidates;
			candidates = searchInScopesFilterBy__lookups_644(c, ident, 50331583);
			{
				NI T10_;
				NI T13_;
				T10_ = (candidates ? candidates->Sup.len : 0);
				if (!(((NI) 0) < T10_)) goto LA11_;
				result = candidates->data[((NI) 0)];
				T13_ = (candidates ? candidates->Sup.len : 0);
				amb = (((NI) 1) < T13_);
				{
					NIM_BOOL T16_;
					T16_ = (NIM_BOOL)0;
					T16_ = amb;
					if (!(T16_)) goto LA17_;
					T16_ = ((flags &((NU8)1<<((NU)(((tyEnum_TLookupFlag__ns0lQuhi2aWBQ9bXAfDCqaA) 0))&7U)))!=0);
					LA17_: ;
					if (!T16_) goto LA18_;
					errorUseQualifier__lookups_2521(c, (*n).info, candidates, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_37));
				}
				LA18_: ;
			}
			LA11_: ;
		}
		LA2_: ;
		{
			tySequence__ed0C0uAUZPhvw3RAc5hfYg* candidates_2;
			if (!(result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA22_;
			candidates_2 = allPureEnumFields__lookups_495(c, ident);
			{
				NI T26_;
				NI T29_;
				T26_ = (candidates_2 ? candidates_2->Sup.len : 0);
				if (!(((NI) 0) < T26_)) goto LA27_;
				result = candidates_2->data[((NI) 0)];
				T29_ = (candidates_2 ? candidates_2->Sup.len : 0);
				amb = (((NI) 1) < T29_);
				{
					NIM_BOOL T32_;
					T32_ = (NIM_BOOL)0;
					T32_ = amb;
					if (!(T32_)) goto LA33_;
					T32_ = ((flags &((NU8)1<<((NU)(((tyEnum_TLookupFlag__ns0lQuhi2aWBQ9bXAfDCqaA) 0))&7U)))!=0);
					LA33_: ;
					if (!T32_) goto LA34_;
					errorUseQualifier__lookups_2521(c, (*n).info, candidates_2, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_37));
				}
				LA34_: ;
			}
			LA27_: ;
		}
		LA22_: ;
		{
			NIM_BOOL T38_;
			T38_ = (NIM_BOOL)0;
			T38_ = (result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
			if (!(T38_)) goto LA39_;
			T38_ = ((flags &((NU8)1<<((NU)(((tyEnum_TLookupFlag__ns0lQuhi2aWBQ9bXAfDCqaA) 1))&7U)))!=0);
			LA39_: ;
			if (!T38_) goto LA40_;
			result = errorUndeclaredIdentifierHint__lookups_2570(c, n, ident);
		}
		goto LA36_;
		LA40_: ;
		{
			NIM_BOOL T43_;
			NIM_BOOL T44_;
			T43_ = (NIM_BOOL)0;
			T44_ = (NIM_BOOL)0;
			T44_ = ((flags &((NU8)1<<((NU)(((tyEnum_TLookupFlag__ns0lQuhi2aWBQ9bXAfDCqaA) 0))&7U)))!=0);
			if (!(T44_)) goto LA45_;
			T44_ = !((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
			LA45_: ;
			T43_ = T44_;
			if (!(T43_)) goto LA46_;
			T43_ = amb;
			LA46_: ;
			if (!T43_) goto LA47_;
			result = errorUseQualifier__lookups_2494(c, (*n).info, result, (&amb));
		}
		goto LA36_;
		LA47_: ;
		LA36_: ;
		(*c).isAmbiguous = amb;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		result = (*n)._kind_4.sym;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45):
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m;
		result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
		m = qualifiedLookUp__lookups_2598(c, (*n)._kind_6.sons->data[((NI) 0)], ((flags & 2) | 4));
		{
			NIM_BOOL T53_;
			tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident_2;
			T53_ = (NIM_BOOL)0;
			T53_ = !((m == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
			if (!(T53_)) goto LA54_;
			T53_ = ((*m).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6));
			LA54_: ;
			if (!T53_) goto LA55_;
			ident_2 = ((tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*) NIM_NIL);
			{
				if (!((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2))) goto LA59_;
				ident_2 = (*(*n)._kind_6.sons->data[((NI) 1)])._kind_5.ident;
			}
			goto LA57_;
			LA59_: ;
			{
				if (!((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 53))) goto LA62_;
				ident_2 = considerQuotedIdent__lookups_29(c, (*n)._kind_6.sons->data[((NI) 1)], ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
			}
			goto LA57_;
			LA62_: ;
			LA57_: ;
			{
				NIM_BOOL T66_;
				T66_ = (NIM_BOOL)0;
				T66_ = eqeq___idents_229(ident_2, ((tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*) NIM_NIL));
				if (!!(T66_)) goto LA67_;
				{
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T73_;
					if (!(m == (*c).module)) goto LA71_;
					T73_ = NIM_NIL;
					T73_ = strTableGet__astalgo_3383((*(*c).topLevelScope).symbols, ident_2);
					result = skipAlias__lookups_125(T73_, n, (*(*c).graph).config);
				}
				goto LA69_;
				LA71_: ;
				{
					{
						tySequence__qwqHTkRvwhrRyENtudHQ7g* T77_;
						NI T78_;
						NIM_BOOL amb_2;
						T77_ = NIM_NIL;
						T77_ = getOrDefault__lookups_2769((*c).importModuleLookup, (*(*m).name).id);
						T78_ = (T77_ ? T77_->Sup.len : 0);
						if (!(((NI) 1) < T78_)) goto LA79_;
						amb_2 = (NIM_BOOL)0;
						result = errorUseQualifier__lookups_2494(c, (*n).info, m, (&amb_2));
					}
					goto LA75_;
					LA79_: ;
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T82_;
						T82_ = NIM_NIL;
						T82_ = someSym__modulegraphs_2849((*c).graph, m, ident_2);
						result = skipAlias__lookups_125(T82_, n, (*(*c).graph).config);
					}
					LA75_: ;
				}
				LA69_: ;
				{
					NIM_BOOL T85_;
					T85_ = (NIM_BOOL)0;
					T85_ = (result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
					if (!(T85_)) goto LA86_;
					T85_ = ((flags &((NU8)1<<((NU)(((tyEnum_TLookupFlag__ns0lQuhi2aWBQ9bXAfDCqaA) 1))&7U)))!=0);
					LA86_: ;
					if (!T85_) goto LA87_;
					result = errorUndeclaredIdentifierHint__lookups_2570(c, (*n)._kind_6.sons->data[((NI) 1)], ident_2);
				}
				LA87_: ;
			}
			goto LA64_;
			LA67_: ;
			{
				if (!((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA90_;
				result = (*(*n)._kind_6.sons->data[((NI) 1)])._kind_4.sym;
			}
			goto LA64_;
			LA90_: ;
			{
				NIM_BOOL T93_;
				NimStringDesc* T97_;
				NimStringDesc* T98_;
				T93_ = (NIM_BOOL)0;
				T93_ = ((flags &((NU8)1<<((NU)(((tyEnum_TLookupFlag__ns0lQuhi2aWBQ9bXAfDCqaA) 1))&7U)))!=0);
				if (!(T93_)) goto LA94_;
				T93_ = !(((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 57) || (*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 56)));
				LA94_: ;
				if (!T93_) goto LA95_;
				T97_ = NIM_NIL;
				T98_ = NIM_NIL;
				T98_ = renderTree__renderer_46((*n)._kind_6.sons->data[((NI) 1)], 0);
				T97_ = rawNewString((T98_ ? T98_->Sup.len : 0) + 30);
appendString(T97_, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_47));
appendString(T97_, T98_);
				liMessage__msgs_1128((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 1)]).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T97_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__lKFMSIMkJc3WyNochLWXNg_48, NIM_FALSE);
				result = errorSym__lookups_686(c, (*n)._kind_6.sons->data[((NI) 1)]);
			}
			goto LA64_;
			LA95_: ;
			LA64_: ;
		}
		LA55_: ;
	}
	break;
	default:
	{
		result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, initOverloadIter__lookups_3120)(tyObject_TOverloadIter__CvTtbgSac6VxMVCfhzIzkg* o, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
{	result = NIM_NIL;
	(*o).importIdx = ((NI) -1);
	initIntSet__pureZcollectionsZintsets_238((&(*o).marked));
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 53):
	{
		tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
		tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope;
		ident = considerQuotedIdent__lookups_29(c, n, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
		scope = (*c).currentScope;
		(*o).mode = ((tyEnum_TOverloadIterMode__XQIFODuBaxbYxvlbAsr1Ng) 1);
		{
			while (1) {
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T4_;
				T4_ = NIM_NIL;
				T4_ = initIdentIter__astalgo_3420((&(*o).it), (*scope).symbols, ident);
				result = skipAlias__lookups_125(T4_, n, (*(*c).graph).config);
				{
					if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA7_;
					unsureAsgnRef((void**) (&(*o).currentScope), scope);
					goto LA2;
				}
				goto LA5_;
				LA7_: ;
				{
					scope = (*scope).parent;
					{
						if (!(scope == ((tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ*) NIM_NIL))) goto LA12_;
						{
							NI i;
							NI colontmp_;
							NI T15_;
							NI res;
							i = (NI)0;
							colontmp_ = (NI)0;
							T15_ = (((*c).imports ? (*c).imports->Sup.len : 0)-1);
							colontmp_ = T15_;
							res = ((NI) 0);
							{
								while (1) {
									tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T18_;
									if (!(res <= colontmp_)) goto LA17;
									i = res;
									T18_ = NIM_NIL;
									T18_ = initIdentIter__lookups_158((&(*o).mit), (&(*o).marked), (&(*c).imports->data[i]), ident, (*c).graph);
									result = skipAlias__lookups_125(T18_, n, (*(*c).graph).config);
									{
										if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA21_;
										unsureAsgnRef((void**) (&(*o).currentScope), ((tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ*) NIM_NIL));
										(*o).importIdx = i;
										goto BeforeRet_;
									}
									LA21_: ;
									res += ((NI) 1);
								} LA17: ;
							}
						}
						result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
						goto BeforeRet_;
					}
					LA12_: ;
				}
				LA5_: ;
			}
		} LA2: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		result = (*n)._kind_4.sym;
		(*o).mode = ((tyEnum_TOverloadIterMode__XQIFODuBaxbYxvlbAsr1Ng) 0);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45):
	{
		(*o).mode = ((tyEnum_TOverloadIterMode__XQIFODuBaxbYxvlbAsr1Ng) 3);
		unsureAsgnRef((void**) (&(*o).m), qualifiedLookUp__lookups_2598(c, (*n)._kind_6.sons->data[((NI) 0)], 6));
		{
			NIM_BOOL T27_;
			tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident_2;
			T27_ = (NIM_BOOL)0;
			T27_ = !(((*o).m == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
			if (!(T27_)) goto LA28_;
			T27_ = ((*(*o).m).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6));
			LA28_: ;
			if (!T27_) goto LA29_;
			ident_2 = ((tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*) NIM_NIL);
			{
				if (!((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2))) goto LA33_;
				ident_2 = (*(*n)._kind_6.sons->data[((NI) 1)])._kind_5.ident;
			}
			goto LA31_;
			LA33_: ;
			{
				if (!((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 53))) goto LA36_;
				ident_2 = considerQuotedIdent__lookups_29(c, (*n)._kind_6.sons->data[((NI) 1)], n);
			}
			goto LA31_;
			LA36_: ;
			LA31_: ;
			{
				NIM_BOOL T40_;
				T40_ = (NIM_BOOL)0;
				T40_ = eqeq___idents_229(ident_2, ((tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*) NIM_NIL));
				if (!!(T40_)) goto LA41_;
				{
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T47_;
					if (!((*o).m == (*c).module)) goto LA45_;
					T47_ = NIM_NIL;
					T47_ = initIdentIter__astalgo_3420((&(*o).it), (*(*c).topLevelScope).symbols, ident_2);
					result = skipAlias__lookups_125(T47_, n, (*(*c).graph).config);
					(*o).mode = ((tyEnum_TOverloadIterMode__XQIFODuBaxbYxvlbAsr1Ng) 2);
				}
				goto LA43_;
				LA45_: ;
				{
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T49_;
					T49_ = NIM_NIL;
					T49_ = initModuleIter__modulegraphs_2748((&(*o).mit), (*c).graph, (*o).m, ident_2);
					result = skipAlias__lookups_125(T49_, n, (*(*c).graph).config);
				}
				LA43_: ;
			}
			goto LA38_;
			LA41_: ;
			{
				noidentError__lookups_20((*(*c).graph).config, (*n)._kind_6.sons->data[((NI) 1)], n);
				result = errorSym__lookups_686(c, (*n)._kind_6.sons->data[((NI) 1)]);
			}
			LA38_: ;
		}
		LA29_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 56):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 57):
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym195_;
		(*o).mode = ((tyEnum_TOverloadIterMode__XQIFODuBaxbYxvlbAsr1Ng) 4);
		{
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA54_;
			result = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		}
		goto LA52_;
		LA54_: ;
		{
			(*o).mode = ((tyEnum_TOverloadIterMode__XQIFODuBaxbYxvlbAsr1Ng) 0);
			result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
			goto BeforeRet_;
		}
		LA52_: ;
		(*o).symChoiceIndex = ((NI) 1);
		initIntSet__pureZcollectionsZintsets_238((&(*o).marked));
		xX60gensym195_ = result;
		incl__pureZcollectionsZintsets_55((&(*o).marked), (NI)((NI)((NU64)(((NI) ((*xX60gensym195_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym195_).Sup.itemId.item))));
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, nextOverloadIterImports__lookups_3224)(tyObject_TOverloadIter__CvTtbgSac6VxMVCfhzIzkg* o, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	NI idx;
	NI T1_;
	result = NIM_NIL;
	idx = (NI)((*o).importIdx + ((NI) 1));
	T1_ = ((*c).imports ? (*c).imports->Sup.len : 0);
	(*o).importIdx = T1_;
	{
		while (1) {
			NI T4_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T5_;
			T4_ = ((*c).imports ? (*c).imports->Sup.len : 0);
			if (!(idx < T4_)) goto LA3;
			T5_ = NIM_NIL;
			T5_ = initIdentIter__lookups_158((&(*o).mit), (&(*o).marked), (&(*c).imports->data[idx]), (*o).it.name, (*c).graph);
			result = skipAlias__lookups_125(T5_, n, (*(*c).graph).config);
			{
				if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA8_;
				(*o).importIdx = idx;
				goto LA2;
			}
			LA8_: ;
			idx += ((NI) 1);
		} LA3: ;
	} LA2: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, symChoiceExtension__lookups_3251)(tyObject_TOverloadIter__CvTtbgSac6VxMVCfhzIzkg* o, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
{	result = NIM_NIL;
	{
		while (1) {
			NI T3_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T4_;
			T3_ = ((*c).imports ? (*c).imports->Sup.len : 0);
			if (!((*o).importIdx < T3_)) goto LA2;
			T4_ = NIM_NIL;
			T4_ = initIdentIter__lookups_158((&(*o).mit), (&(*o).marked), (&(*c).imports->data[(*o).importIdx]), (*o).it.name, (*c).graph);
			result = skipAlias__lookups_125(T4_, n, (*(*c).graph).config);
			{
				if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA7_;
				goto BeforeRet_;
			}
			LA7_: ;
			(*o).importIdx += ((NI) 1);
		} LA2: ;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, nextOverloadIter__lookups_3274)(tyObject_TOverloadIter__CvTtbgSac6VxMVCfhzIzkg* o, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	result = NIM_NIL;
	switch ((*o).mode) {
	case ((tyEnum_TOverloadIterMode__XQIFODuBaxbYxvlbAsr1Ng) 0):
	{
		result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
	}
	break;
	case ((tyEnum_TOverloadIterMode__XQIFODuBaxbYxvlbAsr1Ng) 1):
	{
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T7_;
			if (!!(((*o).currentScope == ((tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ*) NIM_NIL)))) goto LA5_;
			T7_ = NIM_NIL;
			T7_ = nextIdentIter__astalgo_3401((&(*o).it), (*(*o).currentScope).symbols);
			result = skipAlias__lookups_125(T7_, n, (*(*c).graph).config);
			{
				while (1) {
					if (!(result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA9;
					unsureAsgnRef((void**) (&(*o).currentScope), (*(*o).currentScope).parent);
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T14_;
						if (!!(((*o).currentScope == ((tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ*) NIM_NIL)))) goto LA12_;
						T14_ = NIM_NIL;
						T14_ = initIdentIter__astalgo_3420((&(*o).it), (*(*o).currentScope).symbols, (*o).it.name);
						result = skipAlias__lookups_125(T14_, n, (*(*c).graph).config);
					}
					goto LA10_;
					LA12_: ;
					{
						(*o).importIdx = ((NI) 0);
						{
							NI T18_;
							tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T21_;
							T18_ = ((*c).imports ? (*c).imports->Sup.len : 0);
							if (!(((NI) 0) < T18_)) goto LA19_;
							T21_ = NIM_NIL;
							T21_ = initIdentIter__lookups_158((&(*o).mit), (&(*o).marked), (&(*c).imports->data[(*o).importIdx]), (*o).it.name, (*c).graph);
							result = skipAlias__lookups_125(T21_, n, (*(*c).graph).config);
							{
								if (!(result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA24_;
								result = nextOverloadIterImports__lookups_3224(o, c, n);
							}
							LA24_: ;
						}
						LA19_: ;
						goto LA8;
					}
					LA10_: ;
				} LA9: ;
			} LA8: ;
		}
		goto LA3_;
		LA5_: ;
		{
			NI T27_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T30_;
			T27_ = ((*c).imports ? (*c).imports->Sup.len : 0);
			if (!((*o).importIdx < T27_)) goto LA28_;
			T30_ = NIM_NIL;
			T30_ = nextIdentIter__lookups_278((&(*o).mit), (&(*o).marked), (&(*c).imports->data[(*o).importIdx]), (*c).graph);
			result = skipAlias__lookups_125(T30_, n, (*(*c).graph).config);
			{
				if (!(result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA33_;
				result = nextOverloadIterImports__lookups_3224(o, c, n);
			}
			LA33_: ;
		}
		goto LA3_;
		LA28_: ;
		{
			result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
		}
		LA3_: ;
	}
	break;
	case ((tyEnum_TOverloadIterMode__XQIFODuBaxbYxvlbAsr1Ng) 2):
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T37_;
		T37_ = NIM_NIL;
		T37_ = nextIdentIter__astalgo_3401((&(*o).it), (*(*c).topLevelScope).symbols);
		result = skipAlias__lookups_125(T37_, n, (*(*c).graph).config);
	}
	break;
	case ((tyEnum_TOverloadIterMode__XQIFODuBaxbYxvlbAsr1Ng) 3):
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T39_;
		T39_ = NIM_NIL;
		T39_ = nextModuleIter__modulegraphs_2783((&(*o).mit), (*c).graph);
		result = skipAlias__lookups_125(T39_, n, (*(*c).graph).config);
	}
	break;
	case ((tyEnum_TOverloadIterMode__XQIFODuBaxbYxvlbAsr1Ng) 4):
	{
		{
			NI T43_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym217_;
			T43_ = (NI)0;
			T43_ = len__ast_3155(n);
			if (!((*o).symChoiceIndex < T43_)) goto LA44_;
			result = (*(*n)._kind_6.sons->data[(*o).symChoiceIndex])._kind_4.sym;
			xX60gensym217_ = result;
			incl__pureZcollectionsZintsets_55((&(*o).marked), (NI)((NI)((NU64)(((NI) ((*xX60gensym217_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym217_).Sup.itemId.item))));
			(*o).symChoiceIndex += ((NI) 1);
		}
		goto LA41_;
		LA44_: ;
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T49_;
			if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 57))) goto LA47_;
			(*o).mode = ((tyEnum_TOverloadIterMode__XQIFODuBaxbYxvlbAsr1Ng) 5);
			unsureAsgnRef((void**) (&(*o).currentScope), (*c).currentScope);
			T49_ = NIM_NIL;
			T49_ = firstIdentExcluding__astalgo_3747((&(*o).it), (*(*o).currentScope).symbols, (*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name, (&(*o).marked));
			result = skipAlias__lookups_125(T49_, n, (*(*c).graph).config);
			{
				while (1) {
					if (!(result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA51;
					unsureAsgnRef((void**) (&(*o).currentScope), (*(*o).currentScope).parent);
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T56_;
						if (!!(((*o).currentScope == ((tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ*) NIM_NIL)))) goto LA54_;
						T56_ = NIM_NIL;
						T56_ = firstIdentExcluding__astalgo_3747((&(*o).it), (*(*o).currentScope).symbols, (*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name, (&(*o).marked));
						result = skipAlias__lookups_125(T56_, n, (*(*c).graph).config);
					}
					goto LA52_;
					LA54_: ;
					{
						(*o).importIdx = ((NI) 0);
						result = symChoiceExtension__lookups_3251(o, c, n);
						goto LA50;
					}
					LA52_: ;
				} LA51: ;
			} LA50: ;
			{
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym224_;
				if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA60_;
				xX60gensym224_ = result;
				incl__pureZcollectionsZintsets_55((&(*o).marked), (NI)((NI)((NU64)(((NI) ((*xX60gensym224_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym224_).Sup.itemId.item))));
			}
			LA60_: ;
		}
		goto LA41_;
		LA47_: ;
		LA41_: ;
	}
	break;
	case ((tyEnum_TOverloadIterMode__XQIFODuBaxbYxvlbAsr1Ng) 5):
	{
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T67_;
			if (!!(((*o).currentScope == ((tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ*) NIM_NIL)))) goto LA65_;
			T67_ = NIM_NIL;
			T67_ = nextIdentExcluding__astalgo_3425((&(*o).it), (*(*o).currentScope).symbols, (&(*o).marked));
			result = skipAlias__lookups_125(T67_, n, (*(*c).graph).config);
			{
				while (1) {
					if (!(result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA69;
					unsureAsgnRef((void**) (&(*o).currentScope), (*(*o).currentScope).parent);
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T74_;
						if (!!(((*o).currentScope == ((tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ*) NIM_NIL)))) goto LA72_;
						T74_ = NIM_NIL;
						T74_ = firstIdentExcluding__astalgo_3747((&(*o).it), (*(*o).currentScope).symbols, (*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name, (&(*o).marked));
						result = skipAlias__lookups_125(T74_, n, (*(*c).graph).config);
					}
					goto LA70_;
					LA72_: ;
					{
						(*o).importIdx = ((NI) 0);
						result = symChoiceExtension__lookups_3251(o, c, n);
						goto LA68;
					}
					LA70_: ;
				} LA69: ;
			} LA68: ;
			{
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym231_;
				if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA78_;
				xX60gensym231_ = result;
				incl__pureZcollectionsZintsets_55((&(*o).marked), (NI)((NI)((NU64)(((NI) ((*xX60gensym231_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym231_).Sup.itemId.item))));
			}
			LA78_: ;
		}
		goto LA63_;
		LA65_: ;
		{
			NI T81_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T84_;
			T81_ = ((*c).imports ? (*c).imports->Sup.len : 0);
			if (!((*o).importIdx < T81_)) goto LA82_;
			T84_ = NIM_NIL;
			T84_ = nextIdentIter__lookups_278((&(*o).mit), (&(*o).marked), (&(*c).imports->data[(*o).importIdx]), (*c).graph);
			result = skipAlias__lookups_125(T84_, n, (*(*c).graph).config);
			{
				if (!(result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA87_;
				(*o).importIdx += ((NI) 1);
				result = symChoiceExtension__lookups_3251(o, c, n);
			}
			LA87_: ;
		}
		goto LA63_;
		LA82_: ;
		LA63_: ;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, lastOverloadScope__lookups_3218)(tyObject_TOverloadIter__CvTtbgSac6VxMVCfhzIzkg* o) {
	NI result;
	result = (NI)0;
	switch ((*o).mode) {
	case ((tyEnum_TOverloadIterMode__XQIFODuBaxbYxvlbAsr1Ng) 1):
	{
		{
			if (!(((NI) 0) <= (*o).importIdx)) goto LA4_;
			result = ((NI) 0);
		}
		goto LA2_;
		LA4_: ;
		{
			if (!((*o).currentScope == 0)) goto LA7_;
			result = ((NI) -1);
		}
		goto LA2_;
		LA7_: ;
		{
			result = (*(*o).currentScope).depthLevel;
		}
		LA2_: ;
	}
	break;
	case ((tyEnum_TOverloadIterMode__XQIFODuBaxbYxvlbAsr1Ng) 2):
	{
		result = ((NI) 1);
	}
	break;
	case ((tyEnum_TOverloadIterMode__XQIFODuBaxbYxvlbAsr1Ng) 3):
	{
		result = ((NI) 0);
	}
	break;
	default:
	{
		result = ((NI) -1);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addPrelimDecl__lookups_1520)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T1_;
	T1_ = NIM_NIL;
	T1_ = addUniqueSym__lookups_72((*c).currentScope, sym);
	(void)(T1_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, lookUp__lookups_2576)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	NIM_BOOL amb;
{	result = NIM_NIL;
	amb = NIM_FALSE;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T2_;
		T2_ = NIM_NIL;
		T2_ = searchInScopes__lookups_603(c, (*n)._kind_5.ident, (&amb));
		result = skipAlias__lookups_125(T2_, n, (*(*c).graph).config);
		{
			if (!(result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA5_;
			result = errorUndeclaredIdentifierHint__lookups_2570(c, n, (*n)._kind_5.ident);
		}
		LA5_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		result = (*n)._kind_4.sym;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 53):
	{
		tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T9_;
		ident = considerQuotedIdent__lookups_29(c, n, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
		T9_ = NIM_NIL;
		T9_ = searchInScopes__lookups_603(c, ident, (&amb));
		result = skipAlias__lookups_125(T9_, n, (*(*c).graph).config);
		{
			if (!(result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA12_;
			result = errorUndeclaredIdentifierHint__lookups_2570(c, n, ident);
		}
		LA12_: ;
	}
	break;
	default:
	{
		internalErrorImpl__msgs_1441((*(*c).graph).config, (*n).info, ((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_49), TM__lKFMSIMkJc3WyNochLWXNg_50);
		goto BeforeRet_;
	}
	break;
	}
	{
		if (!amb) goto LA17_;
		result = errorUseQualifier__lookups_2494(c, (*n).info, result, (&amb));
	}
	LA17_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, pickSym__lookups_3392)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kinds, tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyObject_TOverloadIter__CvTtbgSac6VxMVCfhzIzkg o;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* a;
{	result = NIM_NIL;
	nimZeroMem((void*)(&o), sizeof(tyObject_TOverloadIter__CvTtbgSac6VxMVCfhzIzkg));
	a = initOverloadIter__lookups_3120((&o), c, n);
	{
		while (1) {
			if (!!((a == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA2;
			{
				NIM_BOOL T5_;
				T5_ = (NIM_BOOL)0;
				T5_ = ((kinds &((NU32)1<<((NU)((*a).kind)&31U)))!=0);
				if (!(T5_)) goto LA6_;
				T5_ = ((flags & ~ (*a).flags)==0);
				LA6_: ;
				if (!T5_) goto LA7_;
				{
					if (!(result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA11_;
					result = a;
				}
				goto LA9_;
				LA11_: ;
				{
					result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
					goto BeforeRet_;
				}
				LA9_: ;
			}
			LA7_: ;
			a = nextOverloadIter__lookups_3274((&o), c, n);
		} LA2: ;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, errorUseQualifier__lookups_2516)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NIM_BOOL amb;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T1_;
	amb = (NIM_BOOL)0;
	T1_ = NIM_NIL;
	T1_ = errorUseQualifier__lookups_2494(c, info, s, (&amb));
	(void)(T1_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, localSearchInScope__lookups_149)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* s) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope;
	result = NIM_NIL;
	scope = (*c).currentScope;
	result = strTableGet__astalgo_3383((*scope).symbols, s);
	{
		while (1) {
			NIM_BOOL T3_;
			T3_ = (NIM_BOOL)0;
			T3_ = (result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
			if (!(T3_)) goto LA4_;
			T3_ = isShadowScope__lookups_142(scope);
			LA4_: ;
			if (!T3_) goto LA2;
			scope = (*scope).parent;
			result = strTableGet__astalgo_3383((*scope).symbols, s);
		} LA2: ;
	}
	return result;
}
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__ast_3155(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, errorUseQualifier__lookups_2536)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* choices) {
	tySequence__ed0C0uAUZPhvw3RAc5hfYg* candidates;
	NI T1_;
	NimStringDesc* prefix;
	T1_ = (NI)0;
	T1_ = len__ast_3155(choices);
	candidates = newSeq__lookups_2544(((NI) (T1_)));
	{
		if (!!(((*(*(*choices)._kind_6.sons->data[((NI) 0)]).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25)))) goto LA4_;
		prefix = copyString(((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_37));
	}
	goto LA2_;
	LA4_: ;
	{
		prefix = copyString(((NimStringDesc*) &TM__lKFMSIMkJc3WyNochLWXNg_51));
	}
	LA2_: ;
	{
		NI i;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
		i = (NI)0;
		n = NIM_NIL;
		{
			NI i_2;
			NI colontmp_;
			NI i_3;
			i_2 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148(choices);
			i_3 = ((NI) 0);
			{
				while (1) {
					if (!(i_3 < colontmp_)) goto LA10;
					i_2 = i_3;
					i = i_2;
					n = (*choices)._kind_6.sons->data[i_2];
					asgnRef((void**) (&candidates->data[i]), (*n)._kind_4.sym);
					i_3 += ((NI) 1);
				} LA10: ;
			}
		}
	}
	errorUseQualifier__lookups_2521(c, info, candidates, prefix);
}
N_LIB_PRIVATE N_NIMCALL(void, atmlookupsdotnim_DatInit000)(void) {
static TNimNode* TM__lKFMSIMkJc3WyNochLWXNg_19_2[2];
static TNimNode* TM__lKFMSIMkJc3WyNochLWXNg_39_4[4];
static TNimNode TM__lKFMSIMkJc3WyNochLWXNg_0[8];
NTItupleLsym58psym_key58stringT__Ztb9b8BdGY9bQ5Qd69ajoC2fQ_.size = sizeof(tyTuple__Ztb9b8BdGY9bQ5Qd69ajoC2fQ);
NTItupleLsym58psym_key58stringT__Ztb9b8BdGY9bQ5Qd69ajoC2fQ_.align = NIM_ALIGNOF(tyTuple__Ztb9b8BdGY9bQ5Qd69ajoC2fQ);
NTItupleLsym58psym_key58stringT__Ztb9b8BdGY9bQ5Qd69ajoC2fQ_.kind = 18;
NTItupleLsym58psym_key58stringT__Ztb9b8BdGY9bQ5Qd69ajoC2fQ_.base = 0;
NTItupleLsym58psym_key58stringT__Ztb9b8BdGY9bQ5Qd69ajoC2fQ_.flags = 2;
TM__lKFMSIMkJc3WyNochLWXNg_19_2[0] = &TM__lKFMSIMkJc3WyNochLWXNg_0[1];
TM__lKFMSIMkJc3WyNochLWXNg_0[1].kind = 1;
TM__lKFMSIMkJc3WyNochLWXNg_0[1].offset = offsetof(tyTuple__Ztb9b8BdGY9bQ5Qd69ajoC2fQ, Field0);
TM__lKFMSIMkJc3WyNochLWXNg_0[1].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__lKFMSIMkJc3WyNochLWXNg_0[1].name = "Field0";
TM__lKFMSIMkJc3WyNochLWXNg_19_2[1] = &TM__lKFMSIMkJc3WyNochLWXNg_0[2];
TM__lKFMSIMkJc3WyNochLWXNg_0[2].kind = 1;
TM__lKFMSIMkJc3WyNochLWXNg_0[2].offset = offsetof(tyTuple__Ztb9b8BdGY9bQ5Qd69ajoC2fQ, Field1);
TM__lKFMSIMkJc3WyNochLWXNg_0[2].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__lKFMSIMkJc3WyNochLWXNg_0[2].name = "Field1";
TM__lKFMSIMkJc3WyNochLWXNg_0[0].len = 2; TM__lKFMSIMkJc3WyNochLWXNg_0[0].kind = 2; TM__lKFMSIMkJc3WyNochLWXNg_0[0].sons = &TM__lKFMSIMkJc3WyNochLWXNg_19_2[0];
NTItupleLsym58psym_key58stringT__Ztb9b8BdGY9bQ5Qd69ajoC2fQ_.node = &TM__lKFMSIMkJc3WyNochLWXNg_0[0];
NTIseqLtupleLsym58psym_key58stringTT__EK3kb9a029axOL6ZINxWj1hw_.size = sizeof(tySequence__EK3kb9a029axOL6ZINxWj1hw*);
NTIseqLtupleLsym58psym_key58stringTT__EK3kb9a029axOL6ZINxWj1hw_.align = NIM_ALIGNOF(tySequence__EK3kb9a029axOL6ZINxWj1hw*);
NTIseqLtupleLsym58psym_key58stringTT__EK3kb9a029axOL6ZINxWj1hw_.kind = 24;
NTIseqLtupleLsym58psym_key58stringTT__EK3kb9a029axOL6ZINxWj1hw_.base = (&NTItupleLsym58psym_key58stringT__Ztb9b8BdGY9bQ5Qd69ajoC2fQ_);
NTIseqLtupleLsym58psym_key58stringTT__EK3kb9a029axOL6ZINxWj1hw_.flags = 2;
NTIseqLtupleLsym58psym_key58stringTT__EK3kb9a029axOL6ZINxWj1hw_.marker = Marker_tySequence__EK3kb9a029axOL6ZINxWj1hw;
NTIspellcandidate__ZxujMy1bsXT9c9b7Yfb24WoA_.size = sizeof(tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA);
NTIspellcandidate__ZxujMy1bsXT9c9b7Yfb24WoA_.align = NIM_ALIGNOF(tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA);
NTIspellcandidate__ZxujMy1bsXT9c9b7Yfb24WoA_.kind = 18;
NTIspellcandidate__ZxujMy1bsXT9c9b7Yfb24WoA_.base = 0;
NTIspellcandidate__ZxujMy1bsXT9c9b7Yfb24WoA_.flags = 2;
TM__lKFMSIMkJc3WyNochLWXNg_39_4[0] = &TM__lKFMSIMkJc3WyNochLWXNg_0[4];
TM__lKFMSIMkJc3WyNochLWXNg_0[4].kind = 1;
TM__lKFMSIMkJc3WyNochLWXNg_0[4].offset = offsetof(tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA, dist);
TM__lKFMSIMkJc3WyNochLWXNg_0[4].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__lKFMSIMkJc3WyNochLWXNg_0[4].name = "dist";
TM__lKFMSIMkJc3WyNochLWXNg_39_4[1] = &TM__lKFMSIMkJc3WyNochLWXNg_0[5];
TM__lKFMSIMkJc3WyNochLWXNg_0[5].kind = 1;
TM__lKFMSIMkJc3WyNochLWXNg_0[5].offset = offsetof(tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA, depth);
TM__lKFMSIMkJc3WyNochLWXNg_0[5].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__lKFMSIMkJc3WyNochLWXNg_0[5].name = "depth";
TM__lKFMSIMkJc3WyNochLWXNg_39_4[2] = &TM__lKFMSIMkJc3WyNochLWXNg_0[6];
TM__lKFMSIMkJc3WyNochLWXNg_0[6].kind = 1;
TM__lKFMSIMkJc3WyNochLWXNg_0[6].offset = offsetof(tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA, msg);
TM__lKFMSIMkJc3WyNochLWXNg_0[6].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__lKFMSIMkJc3WyNochLWXNg_0[6].name = "msg";
TM__lKFMSIMkJc3WyNochLWXNg_39_4[3] = &TM__lKFMSIMkJc3WyNochLWXNg_0[7];
TM__lKFMSIMkJc3WyNochLWXNg_0[7].kind = 1;
TM__lKFMSIMkJc3WyNochLWXNg_0[7].offset = offsetof(tyObject_SpellCandidate__ZxujMy1bsXT9c9b7Yfb24WoA, sym);
TM__lKFMSIMkJc3WyNochLWXNg_0[7].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__lKFMSIMkJc3WyNochLWXNg_0[7].name = "sym";
TM__lKFMSIMkJc3WyNochLWXNg_0[3].len = 4; TM__lKFMSIMkJc3WyNochLWXNg_0[3].kind = 2; TM__lKFMSIMkJc3WyNochLWXNg_0[3].sons = &TM__lKFMSIMkJc3WyNochLWXNg_39_4[0];
NTIspellcandidate__ZxujMy1bsXT9c9b7Yfb24WoA_.node = &TM__lKFMSIMkJc3WyNochLWXNg_0[3];
NTIseqLspellcandidateT__wDFGR0GrXEVcAPtPuTlVAA_.size = sizeof(tySequence__wDFGR0GrXEVcAPtPuTlVAA*);
NTIseqLspellcandidateT__wDFGR0GrXEVcAPtPuTlVAA_.align = NIM_ALIGNOF(tySequence__wDFGR0GrXEVcAPtPuTlVAA*);
NTIseqLspellcandidateT__wDFGR0GrXEVcAPtPuTlVAA_.kind = 24;
NTIseqLspellcandidateT__wDFGR0GrXEVcAPtPuTlVAA_.base = (&NTIspellcandidate__ZxujMy1bsXT9c9b7Yfb24WoA_);
NTIseqLspellcandidateT__wDFGR0GrXEVcAPtPuTlVAA_.flags = 2;
NTIseqLspellcandidateT__wDFGR0GrXEVcAPtPuTlVAA_.marker = Marker_tySequence__wDFGR0GrXEVcAPtPuTlVAA;
}

