/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 32

#include "nimbase.h"
#include <string.h>
#include <setjmp.h>
#include <glob.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw;
typedef struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ;
typedef struct tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA;
typedef struct tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA;
typedef struct tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw;
typedef struct tySequence__ed0C0uAUZPhvw3RAc5hfYg tySequence__ed0C0uAUZPhvw3RAc5hfYg;
typedef struct tySequence__vvBerF0axaNtu9aMA2gnsrA tySequence__vvBerF0axaNtu9aMA2gnsrA;
typedef struct tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ;
typedef struct tySequence__ZQPym9bf1jM5qaSn7LUXMKA tySequence__ZQPym9bf1jM5qaSn7LUXMKA;
typedef struct tySequence__9c3OY0aBmSBgwdsnBAPf4Ag tySequence__9c3OY0aBmSBgwdsnBAPf4Ag;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw;
typedef struct tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ;
typedef struct tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg;
typedef struct tySequence__Jhh6ks9carRtwV9aOuM8yMNw tySequence__Jhh6ks9carRtwV9aOuM8yMNw;
typedef struct tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw tySequence__Bis5AbpONWcIRrPyPJS8Yw;
typedef struct tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg;
typedef struct tySequence__E8pi9b5QNahsURYzXMjh3qw tySequence__E8pi9b5QNahsURYzXMjh3qw;
typedef struct tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg;
typedef struct tySequence__XDpbjnuseLNZDGLBQ2Qzow tySequence__XDpbjnuseLNZDGLBQ2Qzow;
typedef struct tyObject_Table__cBohObSCAwRxvYFXQHv2wA tyObject_Table__cBohObSCAwRxvYFXQHv2wA;
typedef struct tySequence__QqvaCqCpEE1QmQZbcZLi5A tySequence__QqvaCqCpEE1QmQZbcZLi5A;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tySequence__RNhZxf20g9beyq5VBOGxhDg tySequence__RNhZxf20g9beyq5VBOGxhDg;
typedef struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ;
typedef struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ tySequence__lFbCtu5P2Kf7YDYtGjkxAQ;
typedef struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA;
typedef struct tySequence__ijtae5OneaLys0hN9alAicA tySequence__ijtae5OneaLys0hN9alAicA;
typedef struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w;
typedef struct tySequence__SerjNoUujW2dUouVBrJiCw tySequence__SerjNoUujW2dUouVBrJiCw;
typedef struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyObject_Table__r0v8BdcBPKhl73K8p2VMUA;
typedef struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g tySequence__K9agbtcb0qPZuSJFXB9cTe6g;
typedef struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg;
typedef struct tySequence__m88qdML9cQOuqGAQn6XWL1A tySequence__m88qdML9cQOuqGAQn6XWL1A;
typedef struct tyObject_Table__1hIWbTQWYT4BmhdESze57A tyObject_Table__1hIWbTQWYT4BmhdESze57A;
typedef struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ tySequence__naEbXEp9b9aiW1zXJorqf9cXQ;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA;
typedef struct tyObject_Table__imojfg883tkWsWJwyshGqQ tyObject_Table__imojfg883tkWsWJwyshGqQ;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg tyObject_Table__BCPh85PHtwxox9bv7NLFrlg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA;
typedef struct tySequence__KgiZ29chkJAD01p9aLRB32qw tySequence__KgiZ29chkJAD01p9aLRB32qw;
typedef struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A tyObject_Table__LM44poVdVEn4Mo4N4L8c3A;
typedef struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw tySequence__rkYRZrbHVYL3nhXlQW3K9bw;
typedef struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ tySequence__IRFEb1e9bxgbJLuB5xrdZsQ;
typedef struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ;
typedef struct tySequence__YmPd0eWfcTfrVYrthlXPYA tySequence__YmPd0eWfcTfrVYrthlXPYA;
typedef struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q;
typedef struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg tySequence__Hz5SYwQU29b9aFLt09blvVQPg;
typedef struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg tyObject_Table__R7JnJQEipxxOlJWXQz7jWg;
typedef struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ tySequence__3G9aA9cLXaPxuRxMKm3anacQ;
typedef struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q tySequence__bPFv6ypvvCX2A9a9al8utL2Q;
typedef struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw;
typedef struct Exception Exception;
typedef struct tySequence__QbmGqFaLnb1IWWToREeaIA tySequence__QbmGqFaLnb1IWWToREeaIA;
typedef struct TSafePoint TSafePoint;
typedef struct tyObject_Env_pragmasdotnim_processEffectsOf___F9btrMvLhz9bF8kBdjzuAcww tyObject_Env_pragmasdotnim_processEffectsOf___F9btrMvLhz9bF8kBdjzuAcww;
typedef struct tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q;
typedef struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ;
typedef struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag;
typedef struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg;
typedef struct tySequence__4Murtwnm0Fyc7F9acrytEXw tySequence__4Murtwnm0Fyc7F9acrytEXw;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw;
typedef struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg tySequence__QnmOtn1Iv4LvxOXoMn8Rbg;
typedef struct tySequence__oKtVqsc9bQVCNyrijELM4OQ tySequence__oKtVqsc9bQVCNyrijELM4OQ;
typedef struct tySequence__qy6Iwdy00wN560qud54HTg tySequence__qy6Iwdy00wN560qud54HTg;
typedef struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ tySequence__k67v9bwvvQDmS1ynyGGUbeQ;
typedef struct tySequence__cLsClAAfd0MKkoBQVyvdvw tySequence__cLsClAAfd0MKkoBQVyvdvw;
typedef struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg tySequence__q9bTuOB0JXh1iZ3CSGdRLbg;
typedef struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw;
typedef struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ;
typedef struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ;
typedef struct tySequence__C3r8jsj9chA4sIlYfDN5aDw tySequence__C3r8jsj9chA4sIlYfDN5aDw;
typedef struct tyObject_Env_pragmasdotnim_processCompile___K1pKiI8SQrNLP9ccgE49bWPQ tyObject_Env_pragmasdotnim_processCompile___K1pKiI8SQrNLP9ccgE49bWPQ;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
typedef struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tyTuple__7q7q3E6Oj24ZNVJb9aonhAg;
typedef struct tyTuple__EU9a9btT9bDanvLpyt3NNw3KA tyTuple__EU9a9btT9bDanvLpyt3NNw3KA;
typedef struct tySequence__cvxuM2UjDv0O3Q6FcDEAnw tySequence__cvxuM2UjDv0O3Q6FcDEAnw;
typedef struct tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg;
typedef struct tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA;
typedef struct tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w;
typedef struct tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA;
typedef struct tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg;
typedef struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ tyTuple__NAaJgGVgNmlGoqmiWxdOHQ;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct tyTuple__VbApVidEWCFLq9a29bPtaS7A tyTuple__VbApVidEWCFLq9a29bPtaS7A;
typedef struct tySequence__k7EQb9bN3Uhl608xoPGMRJA tySequence__k7EQb9bN3Uhl608xoPGMRJA;
typedef struct tyTuple__toqrUPSdp8zSxOdlxMJj9cA tyTuple__toqrUPSdp8zSxOdlxMJj9cA;
typedef struct tyTuple__EbsafWGli8bW2GRJQ9apsjA tyTuple__EbsafWGli8bW2GRJQ9apsjA;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
typedef struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ;
typedef struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g tySequence__qeAsXh2i1GAL5Nl0g3OP8g;
typedef struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg tyTuple__UluY8x0Nj6cp9b0o88wJ0lg;
typedef struct tySequence__dlD6tEGzYLLpKVq3XwuFlA tySequence__dlD6tEGzYLLpKVq3XwuFlA;
typedef struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ;
typedef struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg;
typedef struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ;
typedef struct tyTuple__rZZA0skon1OsHdiEvT8RZQ tyTuple__rZZA0skon1OsHdiEvT8RZQ;
typedef struct tySequence__6OFCSvqRaxyEgUqWtnZSlw tySequence__6OFCSvqRaxyEgUqWtnZSlw;
typedef struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q;
typedef struct tySequence__UnGSk9aaLosDroi2QDrlOfQ tySequence__UnGSk9aaLosDroi2QDrlOfQ;
typedef struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA tyTuple__q13Zt16VkCqu6Zg5jWqwHA;
typedef struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA tyTuple__aWN9bNzF9bubXNJV9ciomgpfA;
typedef struct tySequence__m4PVWjcAAjfxlwJxLkKn8A tySequence__m4PVWjcAAjfxlwJxLkKn8A;
typedef struct tyTuple__RWXAsQlFoGYyEQZp1G65sg tyTuple__RWXAsQlFoGYyEQZp1G65sg;
typedef struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg;
typedef struct tyTuple__RmGJuqOgEaHckHndh0LEsw tyTuple__RmGJuqOgEaHckHndh0LEsw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__J4cxakKjhKxTIJR9bojMmXw tyTuple__J4cxakKjhKxTIJR9bojMmXw;
typedef struct tySequence__i89c5kdtWKzK3OEiI81pkkw tySequence__i89c5kdtWKzK3OEiI81pkkw;
typedef struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A;
typedef struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ;
typedef struct tySequence__GR8qmV1kNRcoQ2g76VFy3A tySequence__GR8qmV1kNRcoQ2g76VFy3A;
typedef struct tyTuple__a7QginWFapakKbWJBJ2vfA tyTuple__a7QginWFapakKbWJBJ2vfA;
typedef struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__kbX6x85REySUrk9auORL0vw tyTuple__kbX6x85REySUrk9auORL0vw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g;
typedef struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q;
typedef struct tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A;
typedef struct tyTuple__nF9cH4hinXgGEUwO4G2bshw tyTuple__nF9cH4hinXgGEUwO4G2bshw;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA;
typedef struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__PsEhl3dzznmmJiLAuIXZOg tyTuple__PsEhl3dzznmmJiLAuIXZOg;
typedef struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w;
typedef struct tyTuple__Db8CrQifKGIsKc3w71w7Lw tyTuple__Db8CrQifKGIsKc3w71w7Lw;
typedef struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg;
typedef struct tySequence__lo3S1lKyiPLhGGB9cBawd6A tySequence__lo3S1lKyiPLhGGB9cBawd6A;
typedef struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ;
typedef struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw tyTuple__FEYH9alRJhHD0uTKF2vnIqw;
typedef struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA;
typedef struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA;
typedef struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw;
typedef struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg tyTuple__VUJ5Hjm4tKAResBsRHJvYg;
typedef struct tyTuple__2E9aYKv1U4zUZsR6wkNRkPg tyTuple__2E9aYKv1U4zUZsR6wkNRkPg;
typedef NU16 tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw;
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg {
NI id;
NimStringDesc* s;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* next;
NI h;
};
typedef NU8 tySet_tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw[37];
typedef NU8 tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA;
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw {
  RootObj Sup;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__aaEwD7wUZoIxDUprFEbfMQ[38];
struct tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ {
NI counter;
tySequence__ZQPym9bf1jM5qaSn7LUXMKA* data;
};
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__q9caIJqxIEVMlKzDKc7PN3A) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* expectedType);
typedef NU32 tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__Kiet6YwcQwPvcQYHHEqqqQ) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* expectedType);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__PSlVV9bxpH9avY5YrjCD5uqA) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__8k9afYvvfaH1tjWAwlISb0A) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, void* ClE_0);
void* ClE_0;
} tyProc__9bnYcX9avusKBraL3FJXBwJw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__uojbiMfaKLMuGW9bbomtTBg) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
typedef NU32 tySet_tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__bqRyngJC8bSPcUqqn9bn73w) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nOrig, tySet_tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw filter, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags);
typedef N_NIMCALL_PTR(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, tyProc__F6LocU8y66ng5Ra4XoVWJA) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* prev);
typedef struct {
N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, void* ClE_0);
void* ClE_0;
} tyProc__Nc9aAsBDTkr61wP9a9cnds8Og;
typedef struct {
N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fn, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, void* ClE_0);
void* ClE_0;
} tyProc__z8FaSv6eEIc72FZ9c9cBcaGg;
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw {
NI counter;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* data;
};
typedef NU8 tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ;
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__9aa59awckKpa9areOQSBOwSeQ) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* dc, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ op, NI col);
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
struct tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ {
tySequence__Bis5AbpONWcIRrPyPJS8Yw* data;
NI counter;
};
struct tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg {
tySequence__E8pi9b5QNahsURYzXMjh3qw* data;
NI counter;
};
struct tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg {
tySequence__XDpbjnuseLNZDGLBQ2Qzow* data;
NI counter;
};
struct tyObject_Table__cBohObSCAwRxvYFXQHv2wA {
tySequence__QqvaCqCpEE1QmQZbcZLi5A* data;
NI counter;
};
struct tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw {
  tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw Sup;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* enforceVoidContext;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* voidType;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* currentScope;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* moduleScope;
tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA* imports;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* topLevelScope;
tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA* p;
tyArray__aaEwD7wUZoIxDUprFEbfMQ intTypeCache;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* nilTypeCache;
tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw* matchedConcept;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* friendModules;
NI instCounter;
NI* templInstCounter;
NI inGenericContext;
NI inStaticContext;
NI inUnrolledContext;
NI compilesContextId;
NI compilesContextIdGenerator;
NI inGenericInst;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* converters;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* patterns;
tySequence__vvBerF0axaNtu9aMA2gnsrA* optionStack;
tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ symMapping;
tySequence__9c3OY0aBmSBgwdsnBAPf4Ag* libs;
tyProc__q9caIJqxIEVMlKzDKc7PN3A semConstExpr;
tyProc__Kiet6YwcQwPvcQYHHEqqqQ semExpr;
tyProc__PSlVV9bxpH9avY5YrjCD5uqA semTryExpr;
tyProc__q9caIJqxIEVMlKzDKc7PN3A semTryConstExpr;
tyProc__8k9afYvvfaH1tjWAwlISb0A computeRequiresInit;
tyProc__9bnYcX9avusKBraL3FJXBwJw hasUnresolvedArgs;
tyProc__PSlVV9bxpH9avY5YrjCD5uqA semOperand;
tyProc__uojbiMfaKLMuGW9bbomtTBg semConstBoolExpr;
tyProc__bqRyngJC8bSPcUqqn9bn73w semOverloadedCall;
tyProc__F6LocU8y66ng5Ra4XoVWJA semTypeNode;
tyProc__Nc9aAsBDTkr61wP9a9cnds8Og semInferredLambda;
tyProc__z8FaSv6eEIc72FZ9c9cBcaGg semGenerateInstance;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw includedFiles;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw pureEnumFields;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw userPragmas;
tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ* evalContext;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw unknownIdents;
tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ* generics;
NI topStmts;
NI lastGenericIdx;
NI hloLoopDetector;
NI inParallelStmt;
tyProc__9aa59awckKpa9areOQSBOwSeQ instTypeBoundOp;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* selfName;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw signatures;
NimStringDesc* recursiveDep;
NIM_BOOL suggestionsMade;
NIM_BOOL isAmbiguous;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
NI inTypeContext;
NI inConceptDecl;
tySequence__Jhh6ks9carRtwV9aOuM8yMNw* unusedImports;
tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ exportIndirections;
tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg importModuleMap;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastTLineInfo;
tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg sideEffects;
NI inUncheckedAssignSection;
tyObject_Table__cBohObSCAwRxvYFXQHv2wA importModuleLookup;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA {
tySequence__ijtae5OneaLys0hN9alAicA* data;
NI counter;
};
struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w {
tySequence__SerjNoUujW2dUouVBrJiCw* data;
NI counter;
};
struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA {
tySequence__K9agbtcb0qPZuSJFXB9cTe6g* data;
NI counter;
};
typedef tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyArray__46hjIasL27aUz9c7kgtWooQ[5];
struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg {
tySequence__m88qdML9cQOuqGAQn6XWL1A* data;
NI counter;
};
struct tyObject_Table__1hIWbTQWYT4BmhdESze57A {
tySequence__naEbXEp9b9aiW1zXJorqf9cXQ* data;
NI counter;
};
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
};
struct tyObject_Table__imojfg883tkWsWJwyshGqQ {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA {
tySequence__KgiZ29chkJAD01p9aLRB32qw* data;
NI counter;
};
struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A {
tySequence__rkYRZrbHVYL3nhXlQW3K9bw* data;
NI counter;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg[65];
struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ {
tySequence__YmPd0eWfcTfrVYrthlXPYA* data;
NI counter;
};
struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__I6rzVhdiYtUh7jwWJQoeyw) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__EQOAUyRkp9c3eeiGlHvCThA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q {
tySequence__Hz5SYwQU29b9aFLt09blvVQPg* data;
NI counter;
};
struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg {
tySequence__3G9aA9cLXaPxuRxMKm3anacQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__1CO5eEh25fBKUWGagpikwg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
typedef N_NIMCALL_PTR(void, tyProc__VcUg5jOhttLagdxUmVN8Tg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__XOkru1xuh2bHzmkw1UYzLA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formal, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* actual);
struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opNot;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opContains;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLe;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLt;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAnd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opOr;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opIsNil;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opEq;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAdd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opSub;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opMul;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opDiv;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg {
tySequence__RNhZxf20g9beyq5VBOGxhDg* ifaces;
tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* packed_0;
tySequence__lFbCtu5P2Kf7YDYtGjkxAQ* encoders;
tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA typeInstCache;
tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w procInstCache;
tyArray__46hjIasL27aUz9c7kgtWooQ attachedOps;
tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg methodsPerType;
tyObject_Table__1hIWbTQWYT4BmhdESze57A enumToStringProcs;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw emittedTypeInfo;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA startupPackedConfig;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw deps;
tyObject_Table__imojfg883tkWsWJwyshGqQ importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__BCPh85PHtwxox9bv7NLFrlg inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* usageSym;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* owners;
tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA suggestSymbols;
tyObject_Table__LM44poVdVEn4Mo4N4L8c3A suggestErrors;
tySequence__IRFEb1e9bxgbJLuB5xrdZsQ* methods;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* systemModule;
tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg sysTypes;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw compilerprocs;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw exposed;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageTypes;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* emptyNode;
tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ canonTypes;
tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw symBodyHashes;
tyProc__I6rzVhdiYtUh7jwWJQoeyw importModuleCallback;
tyProc__EQOAUyRkp9c3eeiGlHvCThA includeFileCallback;
tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q cacheSeqs;
tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g cacheCounters;
tyObject_Table__R7JnJQEipxxOlJWXQz7jWg cacheTables;
tySequence__bPFv6ypvvCX2A9a9al8utL2Q* passes;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinition;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinitionResolveForward;
tyProc__1CO5eEh25fBKUWGagpikwg onUsage;
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* globalDestructors;
tyProc__VcUg5jOhttLagdxUmVN8Tg strongSemCheck;
tyProc__XOkru1xuh2bHzmkw1UYzLA compatibleProps;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg operators;
};
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU16 tySet_tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA;
typedef N_CLOSURE_PTR(NIM_BOOL, TM__an3LHxrAv8p724x7H8KxOw_9) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInst;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg uniqueId;
};
typedef NU8 tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg[9];
typedef tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* tyArray__iegsN9bf6GqRiWprrJjTAoA[1];
typedef tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* tyArray__Nfk9cOEzg2bRz9c1V8fGzONg[2];
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
typedef NU8 tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU8 tyEnum_TNodeKind__jsmc0lvQl44MLrOvpRmgJQ;
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
struct tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw {
NI a;
NI b;
};
struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ {
  RootObj Sup;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* left;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* right;
NI L;
NimStringDesc* data;
};
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__QbmGqFaLnb1IWWToREeaIA* trace;
Exception* up;
};
struct TSafePoint {
TSafePoint* prev;
NI status;
jmp_buf context;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
typedef NimStringDesc* tyArray__Re75IspeoxXy2oCZHwcRrA[2];
typedef NU8 tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_Env_pragmasdotnim_processEffectsOf___F9btrMvLhz9bF8kBdjzuAcww {
  RootObj Sup;
NI colonstate_;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner1;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, void* ClE_0);
void* ClE_0;
} tyProc__rAG9bRqKCVVAugN9aRtDwP8g;
typedef N_CLOSURE_PTR(void, TM__an3LHxrAv8p724x7H8KxOw_44) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
typedef N_CLOSURE_PTR(void, TM__an3LHxrAv8p724x7H8KxOw_45) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
typedef NU8 tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ;
struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg {
tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* path;
};
typedef NU8 tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q {
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg defaultCC;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* dynlib;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* otherPragmas;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
};
struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ {
tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* data;
NI counter;
};
struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ {
NI32 thisModule;
NI32 lastFile;
NU32 lastLit;
tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ filenames;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* pendingTypes;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* pendingSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw typeMarker;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw symMarker;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
};
typedef NU8 tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg;
struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg {
tySequence__4Murtwnm0Fyc7F9acrytEXw* nodes;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ;
struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ {
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw {
tySequence__IHUFRsFxZNv7YydiUO2esQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag {
NimStringDesc* definedSymbols;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA moduleFlags;
tySequence__PXIzfWocnrafGz5p3CP5LA* includes;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* imports;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg toReplay;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg topLevel;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg bodies;
tySequence__b89aLriiJnVTD186H6zNIgg* exports;
tySequence__b89aLriiJnVTD186H6zNIgg* hidden;
tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw* reexports;
tySequence__b89aLriiJnVTD186H6zNIgg* compilerProcs;
tySequence__48JTohSgTy339bRxHzUD8KA* converters;
tySequence__48JTohSgTy339bRxHzUD8KA* methods;
tySequence__48JTohSgTy339bRxHzUD8KA* trmacros;
tySequence__48JTohSgTy339bRxHzUD8KA* pureEnums;
tySequence__QnmOtn1Iv4LvxOXoMn8Rbg* macroUsages;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* typeInstCache;
tySequence__qy6Iwdy00wN560qud54HTg* procInstCache;
tySequence__k67v9bwvvQDmS1ynyGGUbeQ* attachedOps;
tySequence__cLsClAAfd0MKkoBQVyvdvw* methodsPerType;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* enumToStringProcs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* emittedTypeInfo;
tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ backendFlags;
tySequence__q9bTuOB0JXh1iZ3CSGdRLbg* syms;
tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw* types;
tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ strings;
tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw numbers;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA cfg;
};
struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ {
tySequence__C3r8jsj9chA4sIlYfDN5aDw* data;
NI counter;
};
struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg {
tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg status;
NIM_BOOL symsInit;
NIM_BOOL typesInit;
NIM_BOOL loadedButAliveSetChanged;
tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag fromDisk;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* syms;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* types;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ iface;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ ifaceHidden;
};
typedef NU8 tySet_tyEnum_TLookupFlag__ns0lQuhi2aWBQ9bXAfDCqaA;
struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg {
NI32 module;
NI32 symId;
NI32 typeId_0;
NIM_BOOL sealed;
};
struct tyObject_Env_pragmasdotnim_processCompile___K1pKiI8SQrNLP9ccgE49bWPQ {
  RootObj Sup;
NI colonstate_;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n1;
};
typedef NCSTRING tyUncheckedArray__nvS6J9clHMUMHfoZd8Ad2zg[1];
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
};
typedef NimStringDesc* tyArray__sMpvt1sOxOJ3LFGulnbeMQ[4];
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it, NimStringDesc* src, NimStringDesc* dest, NimStringDesc* customArgs, void* ClE_0);
void* ClE_0;
} tyProc__POo83lI9a0E0qOvqORpi4yw;
typedef N_CLOSURE_PTR(void, TM__an3LHxrAv8p724x7H8KxOw_84) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it, NimStringDesc* src, NimStringDesc* dest, NimStringDesc* customArgs);
typedef N_CLOSURE_PTR(void, TM__an3LHxrAv8p724x7H8KxOw_87) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it, NimStringDesc* src, NimStringDesc* dest, NimStringDesc* customArgs);
typedef NU8 tySet_tyEnum_TInfoCCProp__9biNtFPzjM9c2i62RuZ9c19biA;
struct tyTuple__EU9a9btT9bDanvLpyt3NNw3KA {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
NimStringDesc* Field3;
NimStringDesc* Field4;
NimStringDesc* Field5;
NimStringDesc* Field6;
NimStringDesc* Field7;
NimStringDesc* Field8;
NimStringDesc* Field9;
NimStringDesc* Field10;
NimStringDesc* Field11;
NimStringDesc* Field12;
NimStringDesc* Field13;
NimStringDesc* Field14;
NimStringDesc* Field15;
NimStringDesc* Field16;
NimStringDesc* Field17;
NimStringDesc* Field18;
NimStringDesc* Field19;
NimStringDesc* Field20;
tySet_tyEnum_TInfoCCProp__9biNtFPzjM9c2i62RuZ9c19biA Field21;
};
typedef tyTuple__EU9a9btT9bDanvLpyt3NNw3KA tyArray__BZ5uScSUO7j9awRS7LrncpQ[11];
struct tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ {
NI depthLevel;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw symbols;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* parent;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* allowPrivateAccess;
};
typedef NU8 tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
struct tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* resultSym;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* selfSym;
NI nestedLoopCounter;
NI nestedBlockCounter;
tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA* next;
NIM_BOOL mappingExists;
tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ mapping;
tySequence__cvxuM2UjDv0O3Q6FcDEAnw* caseContext;
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* localBindStmts;
};
typedef NU8 tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ;
struct tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m;
tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ mode;
union{
struct {tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw imported;
} _mode_2;
struct {tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw exceptSet;
} _mode_3;
};
};
struct tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA {
tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* key;
RootObj* val;
};
struct tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* genericSym;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field0;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field1;
};
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
NI Field0;
NI Field1;
};
struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ {
NI Field0;
tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ Field1;
};
struct tyTuple__toqrUPSdp8zSxOdlxMJj9cA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
struct tyTuple__VbApVidEWCFLq9a29bPtaS7A {
NI Field0;
NI Field1;
tySequence__k7EQb9bN3Uhl608xoPGMRJA* Field2;
};
struct tyTuple__EbsafWGli8bW2GRJQ9apsjA {
NI Field0;
NI Field1;
tySequence__qwqHTkRvwhrRyENtudHQ7g* Field2;
};
struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* converters;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* patterns;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* pureEnums;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interf;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interfHidden;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* uniqueName;
};
struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ {
NU32 module;
NI32 item;
};
struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg {
NI module;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ packed_0;
};
struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
};
struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__dlD6tEGzYLLpKVq3XwuFlA* Field2;
};
struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q {
NI module;
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg sym;
tySequence__UnGSk9aaLosDroi2QDrlOfQ* concreteTypes;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__rZZA0skon1OsHdiEvT8RZQ {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__6OFCSvqRaxyEgUqWtnZSlw* Field2;
};
struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field2;
};
struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
};
struct tyTuple__RWXAsQlFoGYyEQZp1G65sg {
NI Field0;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field1;
};
struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__m4PVWjcAAjfxlwJxLkKn8A* Field2;
};
struct tyTuple__RmGJuqOgEaHckHndh0LEsw {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field2;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
};
struct tyTuple__J4cxakKjhKxTIJR9bojMmXw {
NI Field0;
NI32 Field1;
tySequence__i89c5kdtWKzK3OEiI81pkkw* Field2;
};
struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ {
NI Field0;
NI32 Field1;
tySequence__GR8qmV1kNRcoQ2g76VFy3A* Field2;
};
struct tyTuple__a7QginWFapakKbWJBJ2vfA {
tySequence__ed0C0uAUZPhvw3RAc5hfYg* Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__kbX6x85REySUrk9auORL0vw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q {
tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A* root;
NI entries;
};
struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, tyProc__kqPx9c4py2HW6KcFMhNvxtg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__9c6qRjwy7Es8UkDTIUwAfFA) (tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__mv4BsRs5VEnhcxzV6pQU5w) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
struct tyTuple__nF9cH4hinXgGEUwO4G2bshw {
tyProc__kqPx9c4py2HW6KcFMhNvxtg Field0;
tyProc__9c6qRjwy7Es8UkDTIUwAfFA Field1;
tyProc__mv4BsRs5VEnhcxzV6pQU5w Field2;
NIM_BOOL Field3;
};
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA {
NCSTRING procname;
NI line;
NCSTRING filename;
};
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
NI Field0;
NI32 Field1;
NU32 Field2;
};
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
NU32 Field0;
NimStringDesc* Field1;
};
struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA {
NU16 line;
NI16 col;
NU32 file;
};
struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA {
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
NI32 operand;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeId_0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
};
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
NU32 Field0;
NI32 Field1;
};
struct tyTuple__PsEhl3dzznmmJiLAuIXZOg {
NU32 Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA Field1;
};
struct tyTuple__Db8CrQifKGIsKc3w71w7Lw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ key;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* concreteTypes;
};
struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ {
tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
NI Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA {
tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
NU32 name;
NI32 path;
};
struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA {
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
NU32 name;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typ;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
NI32 ast;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ guard;
NI bitsize;
NI alignment;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
NU32 externalName;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw locFlags;
tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA annex;
NI32 constraint;
};
struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw {
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* types;
NI32 n;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeInst;
NI32 nonUniqueId;
};
struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg {
NI Field0;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* Field1;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* Field2;
};
struct tyTuple__2E9aYKv1U4zUZsR6wkNRkPg {
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field0;
NI Field1;
};
struct tySequence__9c3OY0aBmSBgwdsnBAPf4Ag {
  TGenericSeq Sup;
  tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* data[SEQ_DECL_SIZE];
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA {
  TGenericSeq Sup;
  tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg data[SEQ_DECL_SIZE];
};
struct tySequence__ed0C0uAUZPhvw3RAc5hfYg {
  TGenericSeq Sup;
  tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* data[SEQ_DECL_SIZE];
};
struct tySequence__vvBerF0axaNtu9aMA2gnsrA {
  TGenericSeq Sup;
  tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q* data[SEQ_DECL_SIZE];
};
struct tySequence__ZQPym9bf1jM5qaSn7LUXMKA {
  TGenericSeq Sup;
  tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ {
  TGenericSeq Sup;
  tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w data[SEQ_DECL_SIZE];
};
struct tySequence__Jhh6ks9carRtwV9aOuM8yMNw {
  TGenericSeq Sup;
  tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg data[SEQ_DECL_SIZE];
};
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw {
  TGenericSeq Sup;
  tyTuple__NAaJgGVgNmlGoqmiWxdOHQ data[SEQ_DECL_SIZE];
};
struct tySequence__E8pi9b5QNahsURYzXMjh3qw {
  TGenericSeq Sup;
  tyTuple__47w2DboNEPf69aPgubZdd7Q data[SEQ_DECL_SIZE];
};
struct tySequence__k7EQb9bN3Uhl608xoPGMRJA {
  TGenericSeq Sup;
  tyTuple__toqrUPSdp8zSxOdlxMJj9cA data[SEQ_DECL_SIZE];
};
struct tySequence__XDpbjnuseLNZDGLBQ2Qzow {
  TGenericSeq Sup;
  tyTuple__VbApVidEWCFLq9a29bPtaS7A data[SEQ_DECL_SIZE];
};
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  TGenericSeq Sup;
  NI data[SEQ_DECL_SIZE];
};
struct tySequence__QqvaCqCpEE1QmQZbcZLi5A {
  TGenericSeq Sup;
  tyTuple__EbsafWGli8bW2GRJQ9apsjA data[SEQ_DECL_SIZE];
};
struct tySequence__RNhZxf20g9beyq5VBOGxhDg {
  TGenericSeq Sup;
  tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ data[SEQ_DECL_SIZE];
};
struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ {
  TGenericSeq Sup;
  tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg data[SEQ_DECL_SIZE];
};
struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ {
  TGenericSeq Sup;
  tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ data[SEQ_DECL_SIZE];
};
struct tySequence__dlD6tEGzYLLpKVq3XwuFlA {
  TGenericSeq Sup;
  tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ data[SEQ_DECL_SIZE];
};
struct tySequence__ijtae5OneaLys0hN9alAicA {
  TGenericSeq Sup;
  tyTuple__UluY8x0Nj6cp9b0o88wJ0lg data[SEQ_DECL_SIZE];
};
struct tySequence__6OFCSvqRaxyEgUqWtnZSlw {
  TGenericSeq Sup;
  tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q data[SEQ_DECL_SIZE];
};
struct tySequence__SerjNoUujW2dUouVBrJiCw {
  TGenericSeq Sup;
  tyTuple__rZZA0skon1OsHdiEvT8RZQ data[SEQ_DECL_SIZE];
};
struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g {
  TGenericSeq Sup;
  tyTuple__q13Zt16VkCqu6Zg5jWqwHA data[SEQ_DECL_SIZE];
};
struct tySequence__m4PVWjcAAjfxlwJxLkKn8A {
  TGenericSeq Sup;
  tyTuple__RWXAsQlFoGYyEQZp1G65sg data[SEQ_DECL_SIZE];
};
struct tySequence__m88qdML9cQOuqGAQn6XWL1A {
  TGenericSeq Sup;
  tyTuple__aWN9bNzF9bubXNJV9ciomgpfA data[SEQ_DECL_SIZE];
};
struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ {
  TGenericSeq Sup;
  tyTuple__RmGJuqOgEaHckHndh0LEsw data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__i89c5kdtWKzK3OEiI81pkkw {
  TGenericSeq Sup;
  tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A data[SEQ_DECL_SIZE];
};
struct tySequence__KgiZ29chkJAD01p9aLRB32qw {
  TGenericSeq Sup;
  tyTuple__J4cxakKjhKxTIJR9bojMmXw data[SEQ_DECL_SIZE];
};
struct tySequence__GR8qmV1kNRcoQ2g76VFy3A {
  TGenericSeq Sup;
  tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* data[SEQ_DECL_SIZE];
};
struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw {
  TGenericSeq Sup;
  tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ data[SEQ_DECL_SIZE];
};
struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ {
  TGenericSeq Sup;
  tyTuple__a7QginWFapakKbWJBJ2vfA data[SEQ_DECL_SIZE];
};
struct tySequence__YmPd0eWfcTfrVYrthlXPYA {
  TGenericSeq Sup;
  tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg {
  TGenericSeq Sup;
  tyTuple__kbX6x85REySUrk9auORL0vw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ {
  TGenericSeq Sup;
  tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g data[SEQ_DECL_SIZE];
};
struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q {
  TGenericSeq Sup;
  tyTuple__nF9cH4hinXgGEUwO4G2bshw data[SEQ_DECL_SIZE];
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
struct tySequence__QbmGqFaLnb1IWWToREeaIA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA data[SEQ_DECL_SIZE];
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  TGenericSeq Sup;
  tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE];
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  TGenericSeq Sup;
  tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE];
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  TGenericSeq Sup;
  NU32 data[SEQ_DECL_SIZE];
};
struct tySequence__4Murtwnm0Fyc7F9acrytEXw {
  TGenericSeq Sup;
  tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA data[SEQ_DECL_SIZE];
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  TGenericSeq Sup;
  tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE];
};
struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw {
  TGenericSeq Sup;
  tyTuple__PsEhl3dzznmmJiLAuIXZOg data[SEQ_DECL_SIZE];
};
struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg {
  TGenericSeq Sup;
  tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w data[SEQ_DECL_SIZE];
};
struct tySequence__oKtVqsc9bQVCNyrijELM4OQ {
  TGenericSeq Sup;
  tyTuple__Db8CrQifKGIsKc3w71w7Lw data[SEQ_DECL_SIZE];
};
struct tySequence__qy6Iwdy00wN560qud54HTg {
  TGenericSeq Sup;
  tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg data[SEQ_DECL_SIZE];
};
struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ {
  TGenericSeq Sup;
  tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ data[SEQ_DECL_SIZE];
};
struct tySequence__cLsClAAfd0MKkoBQVyvdvw {
  TGenericSeq Sup;
  tyTuple__FEYH9alRJhHD0uTKF2vnIqw data[SEQ_DECL_SIZE];
};
struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg {
  TGenericSeq Sup;
  tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA data[SEQ_DECL_SIZE];
};
struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw {
  TGenericSeq Sup;
  tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw data[SEQ_DECL_SIZE];
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  TGenericSeq Sup;
  NI64 data[SEQ_DECL_SIZE];
};
struct tySequence__lo3S1lKyiPLhGGB9cBawd6A {
  TGenericSeq Sup;
  tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ data[SEQ_DECL_SIZE];
};
struct tySequence__C3r8jsj9chA4sIlYfDN5aDw {
  TGenericSeq Sup;
  tyTuple__VUJ5Hjm4tKAResBsRHJvYg data[SEQ_DECL_SIZE];
};
struct tySequence__cvxuM2UjDv0O3Q6FcDEAnw {
  TGenericSeq Sup;
  tyTuple__2E9aYKv1U4zUZsR6wkNRkPg data[SEQ_DECL_SIZE];
};
struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g {
  TGenericSeq Sup;
  tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg data[SEQ_DECL_SIZE];
};
struct tySequence__UnGSk9aaLosDroi2QDrlOfQ {
  TGenericSeq Sup;
  tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg data[SEQ_DECL_SIZE];
};
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, pragmaRec__pragmas_2611)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw validPragmas, NIM_BOOL isStatement);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, singlePragma__pragmas_1669)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI* i, tySet_tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw validPragmas, NIM_BOOL comesFromPush, NIM_BOOL isStatement);
N_LIB_PRIVATE N_NIMCALL(void, processNote__pragmas_665)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw, whichKeyword__idents_223)(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* id);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ, findStr__commands_321)(NimStringDesc* s, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ default_0);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5302)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5264)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5309)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5307)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5258)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(void, invalidPragma__pragmas_150)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderTree__renderer_46)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA renderFlags);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ, findStr__commands_352)(NimStringDesc* s, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ default_0);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw, whichPragma__trees_244)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, pragmaRaisesOrTags__pragmas_1390)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, processExc__pragmas_1393)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, makeTypeFromExpr__semdata_834)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, skipTypes__ast_3723)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kinds);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, semCustomPragma__pragmas_1584)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newTree__ast_3356)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** children, NI childrenLen_0);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void, transitionSonsKind__ast_4347)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyEnum_TNodeKind__jsmc0lvQl44MLrOvpRmgJQ kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*, considerQuotedIdent__lookups_29)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* origin);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, strTableGet__astalgo_3383)(tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw t, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, belongsToProjectPackage__packages_50)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(void, styleCheckUseImpl__linter_158)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, pragma__pragmas_125)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw validPragmas, NIM_BOOL isStatement);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___pragmas_1747)(tySequence__IeU9azYSNIK3V9b36Ir6NZcw** s, tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw x, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** b, NI bLen_0);
static N_INLINE(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw, dotdot___pureZunicode_840)(NI a, NI b);
N_LIB_PRIVATE N_NIMCALL(void, checkPragmaUseImpl__linter_197)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw w, NimStringDesc* pragmaName);
N_LIB_PRIVATE N_NIMCALL(void, makeExternExport__pragmas_274)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NimStringDesc* extname, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, setExternName__pragmas_240)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NimStringDesc* extname, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, rope__ropes_109)(NimStringDesc* s);
static N_INLINE(NIM_BOOL, contains__pureZos_660)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item);
static N_INLINE(NI, find__pureZos_665)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item);
static N_INLINE(void, pushSafePoint)(TSafePoint* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatSingleElem)(NimStringDesc* formatstr, NimStringDesc* a);
static N_INLINE(void, popSafePoint)(void);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isObj)(TNimType* obj, TNimType* subclass);
static N_INLINE(Exception*, nimBorrowCurrentException)(void);
static N_INLINE(void, popCurrentException)(void);
N_LIB_PRIVATE N_NIMCALL(void, reraiseException)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getOptionalStr__pragmas_394)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NimStringDesc* defaultStr);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, expectStrLit__pragmas_373)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, getStrLitNode__pragmas_356)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NOINLINE(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newEmptyStrNode__pragmas_352)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeIT__ast_3342)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, getSysType__magicsys_60)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, cppDefine__options_2530)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* c, NimStringDesc* define);
N_LIB_PRIVATE N_NIMCALL(void, recordPragma__pragmas_131)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NimStringDesc** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeI__ast_3320)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_4798)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newStrNode__ast_3805)(NimStringDesc* strVal, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, addPragmaComputation__semdata_648)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, makeExternImport__pragmas_261)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NimStringDesc* extname, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, processImportCompilerProc__pragmas_283)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NimStringDesc* extname, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, processImportCpp__pragmas_300)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NimStringDesc* extname, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getModule__astalgo_216)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__pureZstrutils_1631)(NimStringDesc* s, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars);
N_LIB_PRIVATE N_NIMCALL(void, processImportObjC__pragmas_330)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NimStringDesc* extname, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(NI, expectIntLit__pragmas_377)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NI16, floatInt64Align__options_4705)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isPowerOfTwo__pureZmath_174)(NI x);
N_LIB_PRIVATE N_NIMCALL(void, noVal__pragmas_1216)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, processEffectsOf__pragmas_1629)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tyRef__Njrz9auiUyrJUnAKd5dk8Gw)(void* p, NI op);
N_LIB_PRIVATE N_NOINLINE(void*, newObj)(TNimType* typ, NI size);
N_LIB_PRIVATE N_CLOSURE(void, processParam__pragmas_1633)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, pragmaNoForward__pragmas_504)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flag);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isTurnedOn__pragmas_469)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, processMagic__pragmas_407)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__system_7726)(NimStringDesc* s, NI first);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg*, getLib__pragmas_546)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* path);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, exprStructuralEquivalent__trees_56)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b, NIM_BOOL strictSymEquality);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg*, newLib__semdata_754)(tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDynlibOverride__options_4674)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* lib);
N_LIB_PRIVATE N_NIMCALL(void, addToLib__semdata_760)(tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* lib, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(void, processDynLib__pragmas_623)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, expectDynlibNode__pragmas_593)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q**, X5BX5D___semdata_356)(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q** s, NI sLen_0, NI i);
N_LIB_PRIVATE N_NIMCALL(void, markCompilerProc__pragmas_1484)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, registerCompilerProc__magicsys_154)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, addCompilerProc__icZic_2413)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, deprecatedStmt__pragmas_1503)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* outerPragma);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, qualifiedLookUp__lookups_2598)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TLookupFlag__ns0lQuhi2aWBQ9bXAfDCqaA flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, newSym__ast_3409)(tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw symKind, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg id, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options);
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextSymId__ast_3103)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x);
static N_INLINE(void, addInterfaceDecl__lookups_1551)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(void, addInterfaceDeclAt__lookups_1547)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newSymNode__ast_3704)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(void, typeBorrow__pragmas_1463)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NIM_BOOL, isRoutine__ast_4677)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, processDefine__pragmas_1034)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, defineSymbol__condsyms_4)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols, NimStringDesc* symbol, NimStringDesc* value);
N_LIB_PRIVATE N_NIMCALL(void, processUndef__pragmas_1050)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, undefSymbol__condsyms_8)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols, NimStringDesc* symbol);
N_LIB_PRIVATE N_NIMCALL(void, processCompile__pragmas_1075)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_NIMCALL(void, Marker_tyRef__a9aYNs9bZrafnBGGjcbxGzNQ)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getStrLit__pragmas_1085)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI i);
static N_INLINE(NimStringDesc*, slash___pureZos_121)(NimStringDesc* head, NimStringDesc* tail);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosjoinPath)(NimStringDesc* head, NimStringDesc* tail);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosparentDir)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPath__msgs_548)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, cstrToNimstr)(NCSTRING str);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosfileExists)(NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, completeCfilePath__extccomp_715)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* cfile, NIM_BOOL createSubDir);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosextractFilename)(NimStringDesc* path);
N_LIB_PRIVATE N_CLOSURE(void, docompile__pragmas_1078)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it, NimStringDesc* src, NimStringDesc* dest, NimStringDesc* customArgs, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, splitFile__pathutils_27)(NimStringDesc* x, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
N_LIB_PRIVATE N_NIMCALL(void, addExternalFileToCompile__extccomp_1071)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw* c);
N_LIB_PRIVATE N_NIMCALL(void, nimLeaveFinally)(void);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosisAbsolute)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, findFile__options_4487)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* f, NIM_BOOL suppressStdlib);
static N_INLINE(NIM_BOOL, isEmpty__options_4492)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, mangleModuleName__modulepaths_32)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toObjFile__extccomp_720)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(void, processLink__pragmas_1132)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, relativeFile__pragmas_1066)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NimStringDesc* ext);
N_LIB_PRIVATE N_NIMCALL(void, nossplitFile)(NimStringDesc* path, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosaddFileExt)(NimStringDesc* filename, NimStringDesc* ext);
N_LIB_PRIVATE N_NIMCALL(void, addExternalFileToLink__extccomp_756)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(void, addLinkOption__extccomp_692)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* option);
N_LIB_PRIVATE N_NIMCALL(void, addCompileOption__extccomp_695)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* option);
N_LIB_PRIVATE N_NIMCALL(void, addLocalCompileOption__extccomp_740)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* option, NimStringDesc* nimfile);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPathConsiderDirty__msgs_581)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(void, processPush__pragmas_993)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI start);
N_LIB_PRIVATE N_NIMCALL(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q*, pushOptionEntry__semdata_474)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, tryProcessOption__pragmas_926)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ* resOptions);
N_LIB_PRIVATE N_NIMCALL(void, processExperimental__pragmas_883)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw, parseEnum__commands_1298)(NimStringDesc* s);
static N_INLINE(NIM_BOOL, isTopLevel__semdata_1121)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
static N_INLINE(tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ, pragmaToOptions__pragmas_880)(tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw w);
N_LIB_PRIVATE N_NIMCALL(void, onOff__pragmas_489)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ op, tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ* resOptions);
N_LIB_PRIVATE N_NIMCALL(void, processCallConv__pragmas_525)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg, wordToCallConv__pragmas_456)(tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw sw);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuNormalize)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(void, processPop__pragmas_1028)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, popOptionEntry__semdata_489)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
N_LIB_PRIVATE N_NIMCALL(void, processPragma__pragmas_1280)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI i);
N_LIB_PRIVATE N_NIMCALL(void, nep1CheckDefImpl__linter_112)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw k);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newTreeI__ast_3384)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** children, NI childrenLen_0);
N_LIB_PRIVATE N_NIMCALL(tySequence__IeU9azYSNIK3V9b36Ir6NZcw*, X5BX5D___pragmas_1367)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** s, NI sLen_0, tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw x);
static N_INLINE(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw, dotdot___stdZenumutils_90)(NI a, NI b);
N_LIB_PRIVATE N_NIMCALL(void, strTableAdd__astalgo_3325)(tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* t, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* n);
N_LIB_PRIVATE N_NIMCALL(void, processCodegenDecl__pragmas_403)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(void, processOption__pragmas_989)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ* resOptions);
N_LIB_PRIVATE N_NIMCALL(void, pragmaEmit__pragmas_1178)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeI__ast_3324)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NI children);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, semAsmOrEmit__pragmas_1136)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* con, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_CHAR marker);
N_LIB_PRIVATE N_NIMCALL(NI, nsuFindChar)(NimStringDesc* s, NIM_CHAR sub, NI start, NI last);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__system_7714)(NimStringDesc* s, NI first, NI last);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newStrNode__ast_3801)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, NimStringDesc* strVal);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, searchInScopes__lookups_603)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* s, NIM_BOOL* ambiguous);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*, getIdent__idents_152)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* ic, NimStringDesc* identifier);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimCharToStr)(NIM_CHAR x);
N_LIB_PRIVATE N_NIMCALL(void, illFormedAstLocal__semdata_1104)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, pragmaUnroll__pragmas_1226)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newIntNode__ast_3711)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, NI64 intVal);
N_LIB_PRIVATE N_NIMCALL(void, pragmaLine__pragmas_1238)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NI32, fileInfoIdx__msgs_376)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw, getInfoContext__msgs_526)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI index);
N_LIB_PRIVATE N_NIMCALL(void, pragmaLockStmt__pragmas_1419)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it);
N_LIB_PRIVATE N_NIMCALL(NI16, pragmaLocks__pragmas_1447)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, pragmaGuard__pragmas_1551)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind);
N_LIB_PRIVATE N_NIMCALL(void, registerNimScriptSymbol__magicsys_157)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, pragmaProposition__pragmas_157)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, pragmaEnsures__pragmas_171)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ*, openScope__lookups_76)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getCurrOwner__semdata_327)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
static N_INLINE(void, addDecl__lookups_1517)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
static N_INLINE(void, addDeclAt__lookups_1509)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(void, addDeclAt__lookups_995)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, closeScope__lookups_108)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
N_LIB_PRIVATE N_NIMCALL(void, illegalCustomPragma__pragmas_153)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, implicitPragmas__pragmas_2481)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tySet_tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw validPragmas);
N_LIB_PRIVATE N_NIMCALL(void, pushInfoContext__msgs_500)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* detail);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_1441)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
N_LIB_PRIVATE N_NIMCALL(void, popInfoContext__msgs_517)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, mergePragmas__pragmas_2465)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pragmas);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, copyTree__ast_4432)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* src);
N_LIB_PRIVATE N_NIMCALL(void, overwriteLineInfo__pragmas_2456)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_2, "invalid pragma: ", 16);
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_4, "/home/runner/work/nightlies/nightlies/nim/compiler/pragmas.nim", 62);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_3 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 113),
((NI) 12)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_5, "a \'cast\' pragma cannot be pushed", 32);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_6 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 825),
((NI) 16)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_7, "\'cast\' pragma only allowed in a statement context", 49);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_8 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 827),
((NI) 16)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__an3LHxrAv8p724x7H8KxOw_10 = {
0x10, 0x09, 0xe0, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_11, "invalid type for raises/tags list", 33);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_12 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 667),
((NI) 18)}
;
extern NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw Letters__linter_12;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_13, "recursive dependency: ", 22);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_14 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 843),
((NI) 17)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_15, "$1", 2);
extern TNimType NTIvalueerror__5lcTdgqMq62cNGRwBb0thA_;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_17, "invalid extern name: \'", 22);
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_18, "\'. (Forgot to escape \'$\'\?)", 26);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_19 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 161),
((NI) 16)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_20, "string literal expected", 23);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_21 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 207),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_22 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 215),
((NI) 16)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_23, "exportcpp requires `cpp` backend, got: ", 39);
extern TNimType NTItbackend__zoooocqvga73vZuhGAAy6A_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_24 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 858),
((NI) 22)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_25, "cppdefine", 9);
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_26, "`importjs` pragma requires the JavaScript target", 48);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_27 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 882),
((NI) 20)}
;
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__an3LHxrAv8p724x7H8KxOw_28 = {
0x00, 0x00, 0x00, 0x00, 0x08, 0x01, 0x00, 0x00,
0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_29, "`importjs` for routines requires a pattern", 42);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_30 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 887),
((NI) 20)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_31, "integer literal expected", 24);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_32 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 224),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_33 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 229),
((NI) 20)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_34, "size may only be 1, 2, 4 or 8", 29);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_35 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 902),
((NI) 20)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_36, "power of two expected", 21);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_37 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 908),
((NI) 20)}
;
extern TNimType NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_;
N_LIB_PRIVATE TNimType NTIobject__F9btrMvLhz9bF8kBdjzuAcww_;
extern TNimType NTIint__xHTZrq9aYs6boc9bCba0JbpQ_;
extern TNimType NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_;
N_LIB_PRIVATE TNimType NTIrefobject__Njrz9auiUyrJUnAKd5dk8Gw_;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_39, "parameter name expected", 23);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_40 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 807),
((NI) 14)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_41, "parameter cannot be declared as .effectsOf", 42);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_42 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 802),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_43 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 804),
((NI) 16)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_46, "\'on\' or \'off\' expected", 22);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_47 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 263),
((NI) 12)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_48, "use {.experimental: \"codeReordering\".} instead; ", 48);
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_49, "{.noForward.}", 13);
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_50, "{.reorder.}", 11);
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_51, " is deprecated", 14);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_52 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 278),
((NI) 9)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_53 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 242),
((NI) 14)}
;
extern TNimType NTItmagic__3qAy6bDUDlF8Fc2RR6pF9ag_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_54 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 251),
((NI) 30)}
;
extern TNimType NTIseqLplibT__9c3OY0aBmSBgwdsnBAPf4Ag_;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_55, ".noreturn with return type not allowed", 38);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_56 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 978),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_57 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 305),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_58 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 315),
((NI) 16)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_59, "FlowVar", 7);
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_60, "annotation to deprecated not supported here", 43);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_61 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 1007),
((NI) 22)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_62, "list of key:value pairs expected", 32);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_63 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 732),
((NI) 14)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_64, "the .deprecated pragma is unreliable for routines", 49);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_65 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 737),
((NI) 18)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_66, "key:value pair expected", 23);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_67 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 745),
((NI) 16)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_68, "a type can only borrow `.` for now", 34);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_69 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 711),
((NI) 16)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_70, "hint", 4);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_71 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 1065),
((NI) 15)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_72, "warning", 7);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_73 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 1069),
((NI) 15)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_74, "error", 5);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_75 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 1082),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_76 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 1083),
((NI) 22)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_77, "true", 4);
N_LIB_PRIVATE TNimType NTIobject__K1pKiI8SQrNLP9ccgE49bWPQ_;
extern TNimType NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_;
N_LIB_PRIVATE TNimType NTIrefobject__a9aYNs9bZrafnBGGjcbxGzNQ_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_79 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 520),
((NI) 16)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_81, "cannot find: ", 13);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_82 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 509),
((NI) 16)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_83, "compile", 7);
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_85, "\'.compile\' pragma takes up 2 arguments", 38);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_86 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 539),
((NI) 18)}
;
extern NIM_CONST tyArray__BZ5uScSUO7j9awRS7LrncpQ CC__extccomp_510;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_88, "link", 4);
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_89, "passl", 5);
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_90, "passc", 5);
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_91, "localpassl", 10);
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_92, "\'push\' cannot have arguments", 28);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_93 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 452),
((NI) 14)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_95, "Code reordering experimental pragma only valid at toplevel", 58);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_96 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 403),
((NI) 24)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_97, "unknown experimental feature", 28);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_98 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 407),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_99 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 409),
((NI) 16)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_100, "calling convention expected", 27);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_101 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 288),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_102 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 290),
((NI) 14)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_103, "speed", 5);
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_104, "size", 4);
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_105, "none", 4);
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_106, "\'none\', \'speed\' or \'size\' expected", 34);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_107 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 442),
((NI) 26)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_108, "{.pop.} without a corresponding {.push.}", 40);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_109 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 470),
((NI) 14)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_110, "option expected", 15);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_111 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 448),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_112 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 596),
((NI) 14)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_113, "empty \'asm\' statement", 21);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_114 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 564),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_115 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 610),
((NI) 18)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_116, "`{.union.}` is not implemented for js backend.", 46);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_117 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 1159),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_118 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 636),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_119 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 638),
((NI) 18)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_120, "tuple expected", 14);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_121 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 643),
((NI) 16)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_122, "locks pragma takes a list of expressions", 40);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_123 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 685),
((NI) 16)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_124, "unknown", 7);
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_125, "invalid string literal for locks pragma (only allowed string is \"unknown\")", 74);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_126 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 699),
((NI) 18)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_127, "integer must be within 0..1000", 30);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_128 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 703),
((NI) 18)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_129, "bitsize needs to be positive", 28);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_130 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 1204),
((NI) 22)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_131, "\'experimental\' pragma only valid as toplevel statement or in a \'push\' environment", 81);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_132 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 1220),
((NI) 20)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_133, "\"doctype\" pragma only valid as top-level statement", 50);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_134 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 1224),
((NI) 20)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_135, "doctype is not really implemented in Nim 1", 42);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_136 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 1225),
((NI) 15)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_137, "\'.this\' pragma is deprecated", 28);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_138 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 1230),
((NI) 17)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_139, "self", 4);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_140 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 1233),
((NI) 17)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_141, "\'this\' pragma is allowed to have zero or one arguments", 54);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_142 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 1235),
((NI) 20)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_143, "proposition expected", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_144 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 119),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_145 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 125),
((NI) 14)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_146, "result", 6);
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_147, "cannot attach a custom pragma to \'", 34);
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_148, "\'", 1);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_149 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 115),
((NI) 12)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_150, "implicitPragmas", 15);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_151 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 1293),
((NI) 25)}
;
STRING_LITERAL(TM__an3LHxrAv8p724x7H8KxOw_152, ".dynlib requires .exportc", 25);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__an3LHxrAv8p724x7H8KxOw_153 = {((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_4),
((NI) 1299),
((NI) 16)}
;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5211;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern Exception* currException__system_2566;
extern Exception* currException__system_2566;
extern Exception* currException__system_2566;
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__ast_3155(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, getPragmaVal__pragmas_97)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* procAst, tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw name) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p;
{	result = NIM_NIL;
	p = (*procAst)._kind_6.sons->data[((NI) 4)];
	{
		if (!((*p).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1))) goto LA3_;
		result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
		goto BeforeRet_;
	}
	LA3_: ;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
		it = NIM_NIL;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148(p);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA8;
					i = i_2;
					it = (*p)._kind_6.sons->data[i];
					{
						NIM_BOOL T11_;
						NIM_BOOL T12_;
						NIM_BOOL T13_;
						NI T15_;
						T11_ = (NIM_BOOL)0;
						T12_ = (NIM_BOOL)0;
						T13_ = (NIM_BOOL)0;
						T13_ = ((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28));
						if (!(T13_)) goto LA14_;
						T15_ = (NI)0;
						T15_ = len__ast_3155(it);
						T13_ = (T15_ == ((NI) 2));
						LA14_: ;
						T12_ = T13_;
						if (!(T12_)) goto LA16_;
						T12_ = ((*(*it)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2));
						LA16_: ;
						T11_ = T12_;
						if (!(T11_)) goto LA17_;
						T11_ = ((*(*(*it)._kind_6.sons->data[((NI) 0)])._kind_5.ident).id == name);
						LA17_: ;
						if (!T11_) goto LA18_;
						result = (*it)._kind_6.sons->data[((NI) 1)];
						goto BeforeRet_;
					}
					LA18_: ;
					i_2 += ((NI) 1);
				} LA8: ;
			}
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5302)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5264)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5307)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5258((&gch__system_5211.zct), c);
}
static N_INLINE(void, decRef__system_5309)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5307(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5264(src);
		incRef__system_5302(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5264((*dest));
		decRef__system_5309(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, invalidPragma__pragmas_150)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	T1_ = NIM_NIL;
	T2_ = NIM_NIL;
	T2_ = renderTree__renderer_46(n, 4);
	T1_ = rawNewString((T2_ ? T2_->Sup.len : 0) + 16);
appendString(T1_, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_2));
appendString(T1_, T2_);
	liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T1_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_3, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(void, processNote__pragmas_665)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		NIM_BOOL T6_;
		NIM_BOOL T7_;
		NI T9_;
		NI T12_;
		tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA nk;
		tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw T17_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T6_ = (NIM_BOOL)0;
		T7_ = (NIM_BOOL)0;
		T7_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28));
		if (!(T7_)) goto LA8_;
		T9_ = (NI)0;
		T9_ = len__ast_3155(n);
		T7_ = (T9_ == ((NI) 2));
		LA8_: ;
		T6_ = T7_;
		if (!(T6_)) goto LA10_;
		T6_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42));
		LA10_: ;
		T5_ = T6_;
		if (!(T5_)) goto LA11_;
		T12_ = (NI)0;
		T12_ = len__ast_3155((*n)._kind_6.sons->data[((NI) 0)]);
		T5_ = (T12_ == ((NI) 2));
		LA11_: ;
		T4_ = T5_;
		if (!(T4_)) goto LA13_;
		T4_ = ((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2));
		LA13_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA14_;
		T3_ = ((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2));
		LA14_: ;
		if (!T3_) goto LA15_;
		nk = (tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA)0;
		T17_ = (tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw)0;
		T17_ = whichKeyword__idents_223((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)])._kind_5.ident);
		switch (T17_) {
		case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 124):
		{
			tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ xX60gensym128_;
			xX60gensym128_ = findStr__commands_321((*(*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)])._kind_5.ident).s, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 0));
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* xX60gensym128__2;
				if (!!((xX60gensym128_ == ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 0)))) goto LA21_;
				nk = ((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (xX60gensym128_));
				xX60gensym128__2 = (*c).semConstBoolExpr(c, (*n)._kind_6.sons->data[((NI) 1)]);
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), xX60gensym128__2);
				{
					NIM_BOOL T25_;
					T25_ = (NIM_BOOL)0;
					T25_ = ((*xX60gensym128__2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6));
					if (!(T25_)) goto LA26_;
					T25_ = !(((*xX60gensym128__2)._kind_1.intVal == IL64(0)));
					LA26_: ;
					if (!T25_) goto LA27_;
					(*(*(*c).graph).config).notes[(NU)((nk- 17))>>3] |=(1U<<((nk- 17)&7U));
				}
				goto LA23_;
				LA27_: ;
				{
					(*(*(*c).graph).config).notes[(NU)((nk- 17))>>3] &= ~(1U<<((nk- 17)&7U));
				}
				LA23_: ;
			}
			goto LA19_;
			LA21_: ;
			{
				invalidPragma__pragmas_150(c, n);
			}
			LA19_: ;
		}
		break;
		case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 123):
		{
			tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ xX60gensym137_;
			xX60gensym137_ = findStr__commands_352((*(*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)])._kind_5.ident).s, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 0));
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* xX60gensym137__2;
				if (!!((xX60gensym137_ == ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 0)))) goto LA34_;
				nk = ((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (xX60gensym137_));
				xX60gensym137__2 = (*c).semConstBoolExpr(c, (*n)._kind_6.sons->data[((NI) 1)]);
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), xX60gensym137__2);
				{
					NIM_BOOL T38_;
					T38_ = (NIM_BOOL)0;
					T38_ = ((*xX60gensym137__2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6));
					if (!(T38_)) goto LA39_;
					T38_ = !(((*xX60gensym137__2)._kind_1.intVal == IL64(0)));
					LA39_: ;
					if (!T38_) goto LA40_;
					(*(*(*c).graph).config).notes[(NU)((nk- 17))>>3] |=(1U<<((nk- 17)&7U));
				}
				goto LA36_;
				LA40_: ;
				{
					(*(*(*c).graph).config).notes[(NU)((nk- 17))>>3] &= ~(1U<<((nk- 17)&7U));
				}
				LA36_: ;
			}
			goto LA32_;
			LA34_: ;
			{
				invalidPragma__pragmas_150(c, n);
			}
			LA32_: ;
		}
		break;
		case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 125):
		{
			tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ xX60gensym146_;
			xX60gensym146_ = findStr__commands_352((*(*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)])._kind_5.ident).s, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 0));
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* xX60gensym146__2;
				if (!!((xX60gensym146_ == ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 0)))) goto LA47_;
				nk = ((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (xX60gensym146_));
				xX60gensym146__2 = (*c).semConstBoolExpr(c, (*n)._kind_6.sons->data[((NI) 1)]);
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), xX60gensym146__2);
				{
					NIM_BOOL T51_;
					T51_ = (NIM_BOOL)0;
					T51_ = ((*xX60gensym146__2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6));
					if (!(T51_)) goto LA52_;
					T51_ = !(((*xX60gensym146__2)._kind_1.intVal == IL64(0)));
					LA52_: ;
					if (!T51_) goto LA53_;
					(*(*(*c).graph).config).warningAsErrors[(NU)((nk- 17))>>3] |=(1U<<((nk- 17)&7U));
				}
				goto LA49_;
				LA53_: ;
				{
					(*(*(*c).graph).config).warningAsErrors[(NU)((nk- 17))>>3] &= ~(1U<<((nk- 17)&7U));
				}
				LA49_: ;
			}
			goto LA45_;
			LA47_: ;
			{
				invalidPragma__pragmas_150(c, n);
			}
			LA45_: ;
		}
		break;
		case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 126):
		{
			tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ xX60gensym155_;
			xX60gensym155_ = findStr__commands_321((*(*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)])._kind_5.ident).s, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 0));
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* xX60gensym155__2;
				if (!!((xX60gensym155_ == ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 0)))) goto LA60_;
				nk = ((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (xX60gensym155_));
				xX60gensym155__2 = (*c).semConstBoolExpr(c, (*n)._kind_6.sons->data[((NI) 1)]);
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), xX60gensym155__2);
				{
					NIM_BOOL T64_;
					T64_ = (NIM_BOOL)0;
					T64_ = ((*xX60gensym155__2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6));
					if (!(T64_)) goto LA65_;
					T64_ = !(((*xX60gensym155__2)._kind_1.intVal == IL64(0)));
					LA65_: ;
					if (!T64_) goto LA66_;
					(*(*(*c).graph).config).warningAsErrors[(NU)((nk- 17))>>3] |=(1U<<((nk- 17)&7U));
				}
				goto LA62_;
				LA66_: ;
				{
					(*(*(*c).graph).config).warningAsErrors[(NU)((nk- 17))>>3] &= ~(1U<<((nk- 17)&7U));
				}
				LA62_: ;
			}
			goto LA58_;
			LA60_: ;
			{
				invalidPragma__pragmas_150(c, n);
			}
			LA58_: ;
		}
		break;
		default:
		{
			invalidPragma__pragmas_150(c, n);
		}
		break;
		}
	}
	goto LA1_;
	LA15_: ;
	{
		invalidPragma__pragmas_150(c, n);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processExc__pragmas_1393)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (*c).hasUnresolvedArgs.ClE_0? (*c).hasUnresolvedArgs.ClP_0(c, x, (*c).hasUnresolvedArgs.ClE_0):((TM__an3LHxrAv8p724x7H8KxOw_9)((*c).hasUnresolvedArgs.ClP_0))(c, x);
		if (!T3_) goto LA4_;
		asgnRef((void**) (&(*x).typ), makeTypeFromExpr__semdata_834(c, x));
	}
	goto LA1_;
	LA4_: ;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T7_;
		T7_ = NIM_NIL;
		T7_ = (*c).semTypeNode(c, x, ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
		t = skipTypes__ast_3723(T7_, TM__an3LHxrAv8p724x7H8KxOw_10);
		{
			if (!!(((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 57)))) goto LA10_;
			liMessage__msgs_1128((*(*c).graph).config, (*x).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_11), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_12, NIM_FALSE);
		}
		LA10_: ;
		asgnRef((void**) (&(*x).typ), t);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaRaisesOrTags__pragmas_1390)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NIM_BOOL T3_;
		NI T5_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_3155(n);
		T3_ = (T5_ == ((NI) 2));
		LA4_: ;
		if (!T3_) goto LA6_;
		it = (*n)._kind_6.sons->data[((NI) 1)];
		{
			if (!!(((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 39) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41)))) goto LA10_;
			processExc__pragmas_1393(c, it);
		}
		goto LA8_;
		LA10_: ;
		{
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e;
				e = NIM_NIL;
				{
					NI i;
					NI colontmp_;
					NI i_2;
					i = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = safeLen__ast_3148(it);
					i_2 = ((NI) 0);
					{
						while (1) {
							if (!(i_2 < colontmp_)) goto LA16;
							i = i_2;
							e = (*it)._kind_6.sons->data[i];
							processExc__pragmas_1393(c, e);
							i_2 += ((NI) 1);
						} LA16: ;
					}
				}
			}
		}
		LA8_: ;
	}
	goto LA1_;
	LA6_: ;
	{
		invalidPragma__pragmas_150(c, n);
	}
	LA1_: ;
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, semCustomPragma__pragmas_1584)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* callNode;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* r;
{	result = NIM_NIL;
	callNode = NIM_NIL;
	{
		tyArray__iegsN9bf6GqRiWprrJjTAoA T5_;
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__iegsN9bf6GqRiWprrJjTAoA));
		T5_[0] = n;
		callNode = newTree__ast_3356(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27), T5_, 1);
	}
	goto LA1_;
	LA3_: ;
	{
		tyArray__Nfk9cOEzg2bRz9c1V8fGzONg T9_;
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34))) goto LA7_;
		nimZeroMem((void*)T9_, sizeof(tyArray__Nfk9cOEzg2bRz9c1V8fGzONg));
		T9_[0] = (*n)._kind_6.sons->data[((NI) 0)];
		T9_[1] = (*n)._kind_6.sons->data[((NI) 1)];
		callNode = newTree__ast_3356(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27), T9_, 2);
	}
	goto LA1_;
	LA7_: ;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28))) goto LA11_;
		callNode = n;
	}
	goto LA1_;
	LA11_: ;
	{
		invalidPragma__pragmas_150(c, n);
		result = n;
		goto BeforeRet_;
	}
	LA1_: ;
	r = (*c).semOverloadedCall(c, callNode, n, 262144, 262144);
	{
		NIM_BOOL T16_;
		T16_ = (NIM_BOOL)0;
		T16_ = (r == 0);
		if (T16_) goto LA17_;
		T16_ = !((((*(*(*r)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 10))&63U)))!=0));
		LA17_: ;
		if (!T16_) goto LA18_;
		invalidPragma__pragmas_150(c, n);
		result = n;
		goto BeforeRet_;
	}
	LA18_: ;
	result = r;
	{
		NIM_BOOL T22_;
		NI T24_;
		T22_ = (NIM_BOOL)0;
		T22_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2));
		if (!(T22_)) goto LA23_;
		T24_ = (NI)0;
		T24_ = len__ast_3155(r);
		T22_ = (T24_ == ((NI) 1));
		LA23_: ;
		if (!T22_) goto LA25_;
		result = (*result)._kind_6.sons->data[((NI) 0)];
	}
	goto LA20_;
	LA25_: ;
	{
		NIM_BOOL T28_;
		NI T30_;
		T28_ = (NIM_BOOL)0;
		T28_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34));
		if (!(T28_)) goto LA29_;
		T30_ = (NI)0;
		T30_ = len__ast_3155(r);
		T28_ = (T30_ == ((NI) 2));
		LA29_: ;
		if (!T28_) goto LA31_;
		transitionSonsKind__ast_4347(result, ((tyEnum_TNodeKind__jsmc0lvQl44MLrOvpRmgJQ) ((*n).kind)));
	}
	goto LA20_;
	LA31_: ;
	LA20_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw, dotdot___pureZunicode_840)(NI a, NI b) {
	tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw));
	result.a = a;
	result.b = b;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, find__pureZos_665)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item) {
	NI result;
{	result = (NI)0;
	result = ((NI) 0);
	{
		NIM_CHAR i;
		NI i_2;
		i = (NIM_CHAR)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < aLen_0)) goto LA3;
				i = a[i_2];
				{
					if (!((NU8)(i) == (NU8)(item))) goto LA6_;
					goto BeforeRet_;
				}
				LA6_: ;
				result += ((NI) 1);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__pureZos_660)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item) {
	NIM_BOOL result;
	NI T1_;
{	result = (NIM_BOOL)0;
	T1_ = (NI)0;
	T1_ = find__pureZos_665(a, aLen_0, item);
	result = (((NI) 0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, pushSafePoint)(TSafePoint* s) {
	(*s).prev = excHandler__system_2565;
	excHandler__system_2565 = s;
}
static N_INLINE(void, popSafePoint)(void) {
	excHandler__system_2565 = (*excHandler__system_2565).prev;
}
static N_INLINE(Exception*, nimBorrowCurrentException)(void) {
	Exception* result;
	result = NIM_NIL;
	result = currException__system_2566;
	return result;
}
static N_INLINE(void, popCurrentException)(void) {
	asgnRef((void**) (&currException__system_2566), (*currException__system_2566).up);
}
N_LIB_PRIVATE N_NIMCALL(void, setExternName__pragmas_240)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NimStringDesc* extname, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	{
		if (!eqStrings(extname, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_15))) goto LA3_;
		asgnRef((void**) (&(*s).loc.r), rope__ropes_109((*(*s).name).s));
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T6_;
		T6_ = (NIM_BOOL)0;
		T6_ = contains__pureZos_660((extname) ? (extname->data) : NIM_NIL, (extname ? extname->Sup.len : 0), 36);
		if (!!(T6_)) goto LA7_;
		asgnRef((void**) (&(*s).loc.r), rope__ropes_109(extname));
	}
	goto LA1_;
	LA7_: ;
	{
		TSafePoint TM__an3LHxrAv8p724x7H8KxOw_16;
		NimStringDesc* T10_;
		pushSafePoint(&TM__an3LHxrAv8p724x7H8KxOw_16);
		TM__an3LHxrAv8p724x7H8KxOw_16.status = setjmp(TM__an3LHxrAv8p724x7H8KxOw_16.context);
		if (TM__an3LHxrAv8p724x7H8KxOw_16.status == 0) {
		T10_ = NIM_NIL;
		T10_ = nsuFormatSingleElem(extname, (*(*s).name).s);
		asgnRef((void**) (&(*s).loc.r), rope__ropes_109(T10_));
		popSafePoint();
		}
		else {
			popSafePoint();
			if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIvalueerror__5lcTdgqMq62cNGRwBb0thA_))) {
				NimStringDesc* T13_;
				TM__an3LHxrAv8p724x7H8KxOw_16.status = 0;
				T13_ = NIM_NIL;
				T13_ = rawNewString((extname ? extname->Sup.len : 0) + 48);
appendString(T13_, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_17));
appendString(T13_, extname);
appendString(T13_, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_18));
				liMessage__msgs_1128((*(*c).graph).config, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T13_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_19, NIM_FALSE);
				popCurrentException();
			}
		}
		if (TM__an3LHxrAv8p724x7H8KxOw_16.status != 0) reraiseException();
	}
	LA1_: ;
	{
		NIM_BOOL T16_;
		NIM_BOOL T18_;
		T16_ = (NIM_BOOL)0;
		T16_ = ((*(*(*c).graph).config).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 27));
		if (!(T16_)) goto LA17_;
		T18_ = (NIM_BOOL)0;
		T18_ = contains__pureZos_660((extname) ? (extname->data) : NIM_NIL, (extname ? extname->Sup.len : 0), 36);
		T16_ = !(T18_);
		LA17_: ;
		if (!T16_) goto LA19_;
		(*s).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 1)) & 15);
	}
	LA19_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, makeExternExport__pragmas_274)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NimStringDesc* extname, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	setExternName__pragmas_240(c, s, extname, info);
	(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 7)) & 63);
}
N_LIB_PRIVATE N_NOINLINE(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newEmptyStrNode__pragmas_352)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = getSysType__magicsys_60((*c).graph, (*n).info, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28));
	result = newNodeIT__ast_3342(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20), (*n).info, T1_);
	asgnRef((void**) (&(*result)._kind_3.strVal), ((NimStringDesc*) NIM_NIL));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, getStrLitNode__pragmas_356)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_3155(n);
		T3_ = !((T5_ == ((NI) 2)));
		LA4_: ;
		if (!T3_) goto LA6_;
		liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_20), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_21, NIM_FALSE);
		result = newEmptyStrNode__pragmas_352(c, n);
	}
	goto LA1_;
	LA6_: ;
	{
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), (*c).semConstExpr(c, (*n)._kind_6.sons->data[((NI) 1)], ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		switch ((*(*n)._kind_6.sons->data[((NI) 1)]).kind) {
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20):
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 21):
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22):
		{
			result = (*n)._kind_6.sons->data[((NI) 1)];
		}
		break;
		default:
		{
			liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_20), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_22, NIM_FALSE);
			result = newEmptyStrNode__pragmas_352(c, n);
		}
		break;
		}
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, expectStrLit__pragmas_373)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NimStringDesc* result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = getStrLitNode__pragmas_356(c, n);
	result = copyString((*T1_)._kind_3.strVal);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getOptionalStr__pragmas_394)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NimStringDesc* defaultStr) {
	NimStringDesc* result;
	result = NIM_NIL;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28))) goto LA3_;
		result = expectStrLit__pragmas_373(c, n);
	}
	goto LA1_;
	LA3_: ;
	{
		result = copyString(defaultStr);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, recordPragma__pragmas_131)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NimStringDesc** args, NI argsLen_0) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* recorded;
	recorded = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 163), (*n).info);
	{
		NI i;
		NI colontmp_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (argsLen_0-1);
		res = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T4_;
				if (!(res <= colontmp_)) goto LA3;
				i = res;
				T4_ = NIM_NIL;
				T4_ = newStrNode__ast_3805(args[i], (*n).info);
				add__ast_4798(recorded, T4_);
				res += ((NI) 1);
			} LA3: ;
		}
	}
	addPragmaComputation__semdata_648(c, recorded);
}
N_LIB_PRIVATE N_NIMCALL(void, makeExternImport__pragmas_261)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NimStringDesc* extname, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	setExternName__pragmas_240(c, s, extname, info);
	(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 6)) & 63);
	(*s).flags &= ~(((NU64)1) << ((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 4)) & 63));
}
N_LIB_PRIVATE N_NIMCALL(void, processImportCompilerProc__pragmas_283)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NimStringDesc* extname, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	setExternName__pragmas_240(c, s, extname, info);
	(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 6)) & 63);
	(*s).flags &= ~(((NU64)1) << ((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 4)) & 63));
	(*s).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 7)) & 15);
}
N_LIB_PRIVATE N_NIMCALL(void, processImportCpp__pragmas_300)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NimStringDesc* extname, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	setExternName__pragmas_240(c, s, extname, info);
	(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 6)) & 63);
	(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32)) & 63);
	(*s).flags &= ~(((NU64)1) << ((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 4)) & 63));
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m;
		if (!((*(*(*c).graph).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 1))) goto LA3_;
		m = getModule__astalgo_216(s);
		(*m).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32)) & 63);
	}
	LA3_: ;
	(*(*(*c).graph).config).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 35)) & 63);
}
N_LIB_PRIVATE N_NIMCALL(void, processImportObjC__pragmas_330)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NimStringDesc* extname, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m;
	setExternName__pragmas_240(c, s, extname, info);
	(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 6)) & 63);
	(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 33)) & 63);
	(*s).flags &= ~(((NU64)1) << ((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 4)) & 63));
	m = getModule__astalgo_216(s);
	(*m).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 33)) & 63);
}
N_LIB_PRIVATE N_NIMCALL(NI, expectIntLit__pragmas_377)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_3155(n);
		T3_ = !((T5_ == ((NI) 2)));
		LA4_: ;
		if (!T3_) goto LA6_;
		liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_31), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_32, NIM_FALSE);
	}
	goto LA1_;
	LA6_: ;
	{
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), (*c).semConstExpr(c, (*n)._kind_6.sons->data[((NI) 1)], ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		switch ((*(*n)._kind_6.sons->data[((NI) 1)]).kind) {
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 10):
		{
			result = ((NI) ((*(*n)._kind_6.sons->data[((NI) 1)])._kind_1.intVal));
		}
		break;
		default:
		{
			liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_31), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_33, NIM_FALSE);
		}
		break;
		}
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, noVal__pragmas_1216)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_3155(n);
		T3_ = (((NI) 1) < T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		invalidPragma__pragmas_150(c, n);
	}
	LA6_: ;
}
static N_NIMCALL(void, Marker_tyRef__Njrz9auiUyrJUnAKd5dk8Gw)(void* p, NI op) {
	tyObject_Env_pragmasdotnim_processEffectsOf___F9btrMvLhz9bF8kBdjzuAcww* a;
	a = (tyObject_Env_pragmasdotnim_processEffectsOf___F9btrMvLhz9bF8kBdjzuAcww*)p;
	nimGCvisit((void*)(*a).owner1, op);
}
N_LIB_PRIVATE N_CLOSURE(void, processParam__pragmas_1633)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, void* ClE_0) {
	tyObject_Env_pragmasdotnim_processEffectsOf___F9btrMvLhz9bF8kBdjzuAcww* colonenvP_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* r;
	colonenvP_ = (tyObject_Env_pragmasdotnim_processEffectsOf___F9btrMvLhz9bF8kBdjzuAcww*) ClE_0;
	r = (*c).semExpr(c, n, 0, ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*r).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*r)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			if (!((*(*r)._kind_4.sym).owner == (*colonenvP_).owner1)) goto LA9_;
			(*(*r)._kind_4.sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 47)) & 63);
		}
		goto LA7_;
		LA9_: ;
		{
			liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_41), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_42, NIM_FALSE);
		}
		LA7_: ;
	}
	goto LA1_;
	LA5_: ;
	{
		liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_39), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_43, NIM_FALSE);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processEffectsOf__pragmas_1629)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner) {
	tyObject_Env_pragmasdotnim_processEffectsOf___F9btrMvLhz9bF8kBdjzuAcww* colonenv_;
	colonenv_ = NIM_NIL;
	colonenv_ = (tyObject_Env_pragmasdotnim_processEffectsOf___F9btrMvLhz9bF8kBdjzuAcww*) newObj((&NTIrefobject__Njrz9auiUyrJUnAKd5dk8Gw_), sizeof(tyObject_Env_pragmasdotnim_processEffectsOf___F9btrMvLhz9bF8kBdjzuAcww));
	(*colonenv_).Sup.m_type = (&NTIobject__F9btrMvLhz9bF8kBdjzuAcww_);
	asgnRef((void**) (&(*colonenv_).owner1), owner);
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_3155(n);
		T3_ = !((T5_ == ((NI) 2)));
		LA4_: ;
		if (!T3_) goto LA6_;
		liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_39), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_40, NIM_FALSE);
	}
	goto LA1_;
	LA6_: ;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
		it = (*n)._kind_6.sons->data[((NI) 1)];
		{
			if (!((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 39) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41))) goto LA11_;
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x;
				x = NIM_NIL;
				{
					NI i;
					NI colontmp_;
					NI i_2;
					i = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = safeLen__ast_3148(it);
					i_2 = ((NI) 0);
					{
						while (1) {
							tyProc__rAG9bRqKCVVAugN9aRtDwP8g T17_;
							if (!(i_2 < colontmp_)) goto LA16;
							i = i_2;
							x = (*it)._kind_6.sons->data[i];
							nimZeroMem((void*)(&T17_), sizeof(tyProc__rAG9bRqKCVVAugN9aRtDwP8g));
							T17_.ClP_0 = processParam__pragmas_1633; T17_.ClE_0 = colonenv_;
							T17_.ClE_0? T17_.ClP_0(c, x, T17_.ClE_0):((TM__an3LHxrAv8p724x7H8KxOw_44)(T17_.ClP_0))(c, x);
							i_2 += ((NI) 1);
						} LA16: ;
					}
				}
			}
		}
		goto LA9_;
		LA11_: ;
		{
			tyProc__rAG9bRqKCVVAugN9aRtDwP8g T19_;
			nimZeroMem((void*)(&T19_), sizeof(tyProc__rAG9bRqKCVVAugN9aRtDwP8g));
			T19_.ClP_0 = processParam__pragmas_1633; T19_.ClE_0 = colonenv_;
			T19_.ClE_0? T19_.ClP_0(c, it, T19_.ClE_0):((TM__an3LHxrAv8p724x7H8KxOw_45)(T19_.ClP_0))(c, it);
		}
		LA9_: ;
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isTurnedOn__pragmas_469)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		NI T5_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_3155(n);
		T3_ = (T5_ == ((NI) 2));
		LA4_: ;
		if (!T3_) goto LA6_;
		x = (*c).semConstBoolExpr(c, (*n)._kind_6.sons->data[((NI) 1)]);
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), x);
		{
			if (!((*x).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6))) goto LA10_;
			result = !(((*x)._kind_1.intVal == IL64(0)));
			goto BeforeRet_;
		}
		LA10_: ;
	}
	LA6_: ;
	liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_46), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_47, NIM_FALSE);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaNoForward__pragmas_504)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flag) {
	NimStringDesc* T7_;
	NimStringDesc* T8_;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isTurnedOn__pragmas_469(c, n);
		if (!T3_) goto LA4_;
		(*(*c).module).flags |= ((NU64)1)<<((flag) & 63);
		(*c).features |= ((NU32)1)<<((((tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw) 9)) & 31);
	}
	goto LA1_;
	LA4_: ;
	{
		(*(*c).module).flags &= ~(((NU64)1) << ((flag) & 63));
	}
	LA1_: ;
	T7_ = NIM_NIL;
	T8_ = NIM_NIL;
	{
		if (!(flag == ((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 10))) goto LA11_;
		T8_ = copyString(((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_49));
	}
	goto LA9_;
	LA11_: ;
	{
		T8_ = copyString(((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_50));
	}
	LA9_: ;
	T7_ = rawNewString((T8_ ? T8_->Sup.len : 0) + 62);
appendString(T7_, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_48));
appendString(T7_, T8_);
appendString(T7_, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_51));
	liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 21), T7_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_52, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(void, processMagic__pragmas_407)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NimStringDesc* v;
{	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_3155(n);
		T3_ = !((T5_ == ((NI) 2)));
		LA4_: ;
		if (!T3_) goto LA6_;
		liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_20), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_53, NIM_FALSE);
		goto BeforeRet_;
	}
	LA6_: ;
	v = NIM_NIL;
	{
		if (!((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2))) goto LA10_;
		v = copyString((*(*(*n)._kind_6.sons->data[((NI) 1)])._kind_5.ident).s);
	}
	goto LA8_;
	LA10_: ;
	{
		v = expectStrLit__pragmas_373(c, n);
	}
	LA8_: ;
	{
		tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag m;
		m = (tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag)0;
		{
			tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag v_2;
			NI res;
			v_2 = (tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag)0;
			res = ((NI) 0);
			{
				while (1) {
					if (!(res <= ((NI) 276))) goto LA16;
					v_2 = ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) (res));
					m = v_2;
					{
						NimStringDesc* T19_;
						T19_ = NIM_NIL;
						T19_ = substr__system_7726(reprEnum((NI)m, (&NTItmagic__3qAy6bDUDlF8Fc2RR6pF9ag_)), ((NI) 1));
						if (!eqStrings(T19_, v)) goto LA20_;
						(*s).magic = m;
						goto LA13;
					}
					LA20_: ;
					res += ((NI) 1);
				} LA16: ;
			}
		}
	} LA13: ;
	{
		if (!((*s).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 0))) goto LA24_;
		liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 25), v, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_54, NIM_FALSE);
	}
	LA24_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg*, getLib__pragmas_546)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* path) {
	tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* result;
	NI T11_;
{	result = NIM_NIL;
	{
		tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg** it;
		NI i;
		NI L;
		NI T2_;
		it = (tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg**)0;
		i = ((NI) 0);
		T2_ = ((*c).libs ? (*c).libs->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				it = &(*c).libs->data[i];
				{
					NIM_BOOL T7_;
					T7_ = (NIM_BOOL)0;
					T7_ = ((*(*it)).kind == kind);
					if (!(T7_)) goto LA8_;
					T7_ = exprStructuralEquivalent__trees_56((*(*it)).path, path, NIM_FALSE);
					LA8_: ;
					if (!T7_) goto LA9_;
					result = (*it);
					goto BeforeRet_;
				}
				LA9_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
	result = newLib__semdata_754(kind);
	asgnRef((void**) (&(*result).path), path);
	asgnRef((void**) (&(*c).libs), (tySequence__9c3OY0aBmSBgwdsnBAPf4Ag*) incrSeqV3((TGenericSeq*)((*c).libs), (&NTIseqLplibT__9c3OY0aBmSBgwdsnBAPf4Ag_)));
	T11_ = (*c).libs->Sup.len++;
	asgnRef((void**) (&(*c).libs->data[T11_]), result);
	{
		if (!((*path).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) && (*path).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22))) goto LA14_;
		(*result).isOverriden = isDynlibOverride__options_4674((*(*c).graph).config, (*path)._kind_3.strVal);
	}
	LA14_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, expectDynlibNode__pragmas_593)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_3155(n);
		T3_ = !((T5_ == ((NI) 2)));
		LA4_: ;
		if (!T3_) goto LA6_;
		liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_20), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_57, NIM_FALSE);
		result = newEmptyStrNode__pragmas_352(c, n);
	}
	goto LA1_;
	LA6_: ;
	{
		result = (*c).semExpr(c, (*n)._kind_6.sons->data[((NI) 1)], 0, ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = ((*result).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
			if (!(T11_)) goto LA12_;
			T11_ = ((*(*result)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 10));
			LA12_: ;
			if (!T11_) goto LA13_;
			result = (*(*result)._kind_4.sym).ast;
		}
		LA13_: ;
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = ((*result).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
			if (T17_) goto LA18_;
			T17_ = !(((*(*result).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 26) || (*(*result).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28) || (*(*result).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25)));
			LA18_: ;
			if (!T17_) goto LA19_;
			liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_20), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_58, NIM_FALSE);
			result = newEmptyStrNode__pragmas_352(c, n);
		}
		LA19_: ;
	}
	LA1_: ;
	return result;
}
static N_INLINE(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q**, X5BX5D___semdata_356)(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q** s, NI sLen_0, NI i) {
	tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q** result;
	result = (tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q**)0;
	result = &s[(NI)(sLen_0 - i)];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processDynLib__pragmas_623)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	{
		NIM_BOOL T3_;
		tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* lib;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = (sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = ((*sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6));
		LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = NIM_NIL;
		T7_ = expectDynlibNode__pragmas_593(c, n);
		lib = getLib__pragmas_546(c, ((tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ) 1), T7_);
		{
			tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q** T12_;
			if (!!((*lib).isOverriden)) goto LA10_;
			T12_ = (tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q**)0;
			T12_ = X5BX5D___semdata_356(((*c).optionStack) ? ((*c).optionStack->data) : NIM_NIL, ((*c).optionStack ? (*c).optionStack->Sup.len : 0), ((NI) 1));
			asgnRef((void**) (&(*(*T12_)).dynlib), lib);
		}
		LA10_: ;
	}
	goto LA1_;
	LA5_: ;
	{
		{
			tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* lib_2;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T18_;
			if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28))) goto LA16_;
			T18_ = NIM_NIL;
			T18_ = expectDynlibNode__pragmas_593(c, n);
			lib_2 = getLib__pragmas_546(c, ((tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ) 1), T18_);
			{
				if (!!((*lib_2).isOverriden)) goto LA21_;
				addToLib__semdata_760(lib_2, sym);
				(*sym).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 4)) & 15);
			}
			LA21_: ;
		}
		goto LA14_;
		LA16_: ;
		{
			(*sym).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 5)) & 15);
		}
		LA14_: ;
		{
			NIM_BOOL T26_;
			NIM_BOOL T27_;
			T26_ = (NIM_BOOL)0;
			T27_ = (NIM_BOOL)0;
			T27_ = ((520192 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0);
			if (!(T27_)) goto LA28_;
			T27_ = !(((*sym).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
			LA28_: ;
			T26_ = T27_;
			if (!(T26_)) goto LA29_;
			T26_ = !((((*(*sym).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 42))&63U)))!=0));
			LA29_: ;
			if (!T26_) goto LA30_;
			(*(*sym).typ).callConv = ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 2);
		}
		LA30_: ;
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, markCompilerProc__pragmas_1484)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 7)));
		if (T3_) goto LA4_;
		T3_ = !(eqStrings((*(*s).name).s, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_59)));
		LA4_: ;
		if (!T3_) goto LA5_;
		makeExternExport__pragmas_274(c, s, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_15), (*s).info);
	}
	LA5_: ;
	(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 18)) & 63);
	(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 0)) & 63);
	registerCompilerProc__magicsys_154((*c).graph, s);
	{
		if (!!(((*(*(*c).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0)))) goto LA9_;
		addCompilerProc__icZic_2413((&(*(*c).graph).encoders->data[(*(*c).module).position]), (&(*(*c).graph).packed_0->data[(*(*c).module).position].fromDisk), s);
	}
	LA9_: ;
}
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextSymId__ast_3103)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x) {
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*x).symId += ((NI) 1);
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	result.module = (*x).module;
	result.item = (*x).symId;
	return result;
}
static N_INLINE(void, addInterfaceDecl__lookups_1551)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	addInterfaceDeclAt__lookups_1547(c, (*c).currentScope, sym);
}
N_LIB_PRIVATE N_NIMCALL(void, deprecatedStmt__pragmas_1503)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* outerPragma) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pragma;
{	pragma = (*outerPragma)._kind_6.sons->data[((NI) 1)];
	{
		if (!((*pragma).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) && (*pragma).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22))) goto LA3_;
		(*(*c).module).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 22)) & 63);
		asgnRef((void**) (&(*(*c).module).constraint), getStrLitNode__pragmas_356(c, outerPragma));
		goto BeforeRet_;
	}
	LA3_: ;
	{
		if (!!(((*pragma).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41)))) goto LA7_;
		liMessage__msgs_1128((*(*c).graph).config, (*pragma).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_62), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_63, NIM_FALSE);
		goto BeforeRet_;
	}
	LA7_: ;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
		n = NIM_NIL;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148(pragma);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA12;
					i = i_2;
					n = (*pragma)._kind_6.sons->data[i];
					{
						NIM_BOOL T15_;
						NI T17_;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* dest;
						tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* src;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* alias;
						tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T26_;
						T15_ = (NIM_BOOL)0;
						T15_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28));
						if (!(T15_)) goto LA16_;
						T17_ = (NI)0;
						T17_ = len__ast_3155(n);
						T15_ = (T17_ == ((NI) 2));
						LA16_: ;
						if (!T15_) goto LA18_;
						dest = qualifiedLookUp__lookups_2598(c, (*n)._kind_6.sons->data[((NI) 1)], 2);
						{
							NIM_BOOL T22_;
							T22_ = (NIM_BOOL)0;
							T22_ = (dest == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
							if (T22_) goto LA23_;
							T22_ = ((520192 &((NU32)1<<((NU)((*dest).kind)&31U)))!=0);
							LA23_: ;
							if (!T22_) goto LA24_;
							liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 71), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_64), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_65, NIM_FALSE);
						}
						LA24_: ;
						src = considerQuotedIdent__lookups_29(c, (*n)._kind_6.sons->data[((NI) 0)], ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
						T26_ = nextSymId__ast_3103((*c).Sup.idgen);
						alias = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 25), src, T26_, dest, (*(*n)._kind_6.sons->data[((NI) 0)]).info, (*(*(*c).graph).config).options);
						(*alias).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 1)) & 63);
						{
							if (!(((*dest).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 18))&63U)))!=0)) goto LA29_;
							markCompilerProc__pragmas_1484(c, alias);
						}
						LA29_: ;
						addInterfaceDecl__lookups_1551(c, alias);
						asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), newSymNode__ast_3704(dest));
					}
					goto LA13_;
					LA18_: ;
					{
						liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_66), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_67, NIM_FALSE);
					}
					LA13_: ;
					i_2 += ((NI) 1);
				} LA12: ;
			}
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, typeBorrow__pragmas_1463)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NIM_BOOL T3_;
		NI T5_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_3155(n);
		T3_ = (T5_ == ((NI) 2));
		LA4_: ;
		if (!T3_) goto LA6_;
		it = (*n)._kind_6.sons->data[((NI) 1)];
		{
			if (!!(((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 53)))) goto LA10_;
			liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_68), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_69, NIM_FALSE);
		}
		LA10_: ;
	}
	LA6_: ;
	(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 32)) & 63);
}
static N_INLINE(NIM_BOOL, isRoutine__ast_4677)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((520192 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processDefine__pragmas_1034)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T6_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28));
		if (!(T4_)) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__ast_3155(n);
		T4_ = (T6_ == ((NI) 2));
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA7_;
		T3_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2));
		LA7_: ;
		if (!T3_) goto LA8_;
		defineSymbol__condsyms_4((*(*(*c).graph).config).symbols, (*(*(*n)._kind_6.sons->data[((NI) 1)])._kind_5.ident).s, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_77));
	}
	goto LA1_;
	LA8_: ;
	{
		invalidPragma__pragmas_150(c, n);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processUndef__pragmas_1050)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T6_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28));
		if (!(T4_)) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__ast_3155(n);
		T4_ = (T6_ == ((NI) 2));
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA7_;
		T3_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2));
		LA7_: ;
		if (!T3_) goto LA8_;
		undefSymbol__condsyms_8((*(*(*c).graph).config).symbols, (*(*(*n)._kind_6.sons->data[((NI) 1)])._kind_5.ident).s);
	}
	goto LA1_;
	LA8_: ;
	{
		invalidPragma__pragmas_150(c, n);
	}
	LA1_: ;
}
static N_NIMCALL(void, Marker_tyRef__a9aYNs9bZrafnBGGjcbxGzNQ)(void* p, NI op) {
	tyObject_Env_pragmasdotnim_processCompile___K1pKiI8SQrNLP9ccgE49bWPQ* a;
	a = (tyObject_Env_pragmasdotnim_processCompile___K1pKiI8SQrNLP9ccgE49bWPQ*)p;
	nimGCvisit((void*)(*a).n1, op);
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getStrLit__pragmas_1085)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI i) {
	NimStringDesc* result;
	result = NIM_NIL;
	asgnRef((void**) (&(*n)._kind_6.sons->data[i]), (*c).semConstExpr(c, (*n)._kind_6.sons->data[i], ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
	switch ((*(*n)._kind_6.sons->data[i]).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 21):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22):
	{
		result = (*(*n)._kind_6.sons->data[i])._kind_3.strVal;
	}
	break;
	default:
	{
		liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_20), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_79, NIM_FALSE);
		result = ((NimStringDesc*) NIM_NIL);
	}
	break;
	}
	return result;
}
static N_INLINE(NimStringDesc*, slash___pureZos_121)(NimStringDesc* head, NimStringDesc* tail) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = nosjoinPath(head, tail);
	return result;
}
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringDesc* s) {
	NCSTRING result;
	result = (NCSTRING)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (s == ((NimStringDesc*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = ((*s).Sup.len == ((NI) 0));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = "";
	}
	goto LA1_;
	LA5_: ;
	{
		result = ((NCSTRING) ((*s).data));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_CLOSURE(void, docompile__pragmas_1078)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it, NimStringDesc* src, NimStringDesc* dest, NimStringDesc* customArgs, void* ClE_0) {
	tyObject_Env_pragmasdotnim_processCompile___K1pKiI8SQrNLP9ccgE49bWPQ* colonenvP_;
	tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw cf;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T1_;
	colonenvP_ = (tyObject_Env_pragmasdotnim_processCompile___K1pKiI8SQrNLP9ccgE49bWPQ*) ClE_0;
	nimZeroMem((void*)(&cf), sizeof(tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw));
	nimZeroMem((void*)(&cf), sizeof(tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw));
	nimZeroMem((void*)(&T1_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	splitFile__pathutils_27(src, (&T1_));
	cf.nimname = copyString(T1_.Field1);
	cf.cname = copyString(src);
	cf.obj = copyString(dest);
	cf.flags = 2;
	cf.customArgs = copyString(customArgs);
	{
		NIM_BOOL T4_;
		NimStringDesc* T7_;
		T4_ = (NIM_BOOL)0;
		T4_ = nosfileExists(src);
		if (!!(T4_)) goto LA5_;
		T7_ = NIM_NIL;
		T7_ = rawNewString((src ? src->Sup.len : 0) + 13);
appendString(T7_, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_81));
appendString(T7_, src);
		liMessage__msgs_1128((*(*c).graph).config, (*(*colonenvP_).n1).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T7_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_82, NIM_FALSE);
	}
	goto LA2_;
	LA5_: ;
	{
		tyArray__sMpvt1sOxOJ3LFGulnbeMQ T9_;
		addExternalFileToCompile__extccomp_1071((*(*c).graph).config, (&cf));
		nimZeroMem((void*)T9_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
		T9_[0] = copyString(((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_83));
		T9_[1] = copyString(src);
		T9_[2] = copyString(dest);
		T9_[3] = copyString(customArgs);
		recordPragma__pragmas_131(c, it, T9_, 4);
	}
	LA2_: ;
}
static N_INLINE(NIM_BOOL, isEmpty__options_4492)(NimStringDesc* x) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((x ? x->Sup.len : 0) == ((NI) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processCompile__pragmas_1075)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_Env_pragmasdotnim_processCompile___K1pKiI8SQrNLP9ccgE49bWPQ* colonenv_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
	colonenv_ = NIM_NIL;
	colonenv_ = (tyObject_Env_pragmasdotnim_processCompile___K1pKiI8SQrNLP9ccgE49bWPQ*) newObj((&NTIrefobject__a9aYNs9bZrafnBGGjcbxGzNQ_), sizeof(tyObject_Env_pragmasdotnim_processCompile___K1pKiI8SQrNLP9ccgE49bWPQ));
	(*colonenv_).Sup.m_type = (&NTIobject__K1pKiI8SQrNLP9ccgE49bWPQ_);
	asgnRef((void**) (&(*colonenv_).n1), n);
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*(*colonenv_).n1).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*(*colonenv_).n1).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*(*colonenv_).n1).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_3155((*colonenv_).n1);
		T3_ = (T5_ == ((NI) 2));
		LA4_: ;
		if (!T3_) goto LA6_;
		it = (*(*colonenv_).n1)._kind_6.sons->data[((NI) 1)];
	}
	goto LA1_;
	LA6_: ;
	{
		it = (*colonenv_).n1;
	}
	LA1_: ;
	{
		NIM_BOOL T11_;
		NI T13_;
		NimStringDesc* s;
		NimStringDesc* dest;
		NimStringDesc* found;
		NimStringDesc* T16_;
		NimStringDesc* T17_;
		T11_ = (NIM_BOOL)0;
		T11_ = ((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 37) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 160));
		if (!(T11_)) goto LA12_;
		T13_ = (NI)0;
		T13_ = len__ast_3155(it);
		T11_ = (T13_ == ((NI) 2));
		LA12_: ;
		if (!T11_) goto LA14_;
		s = getStrLit__pragmas_1085(c, it, ((NI) 0));
		dest = getStrLit__pragmas_1085(c, it, ((NI) 1));
		T16_ = NIM_NIL;
		T16_ = toFullPath__msgs_548((*(*c).graph).config, (*(*colonenv_).n1).info.fileIndex);
		T17_ = NIM_NIL;
		T17_ = nosparentDir(T16_);
		found = slash___pureZos_121(T17_, s);
		{
			NimStringDesc* f;
			glob_t fX60gensym137_;
			NI resX60gensym137_;
			int T19_;
			TSafePoint TM__an3LHxrAv8p724x7H8KxOw_80;
			f = NIM_NIL;
			nimZeroMem((void*)(&fX60gensym137_), sizeof(glob_t));
			resX60gensym137_ = (NI)0;
			fX60gensym137_.gl_offs = ((NI) 0);
			fX60gensym137_.gl_pathc = ((NI) 0);
			fX60gensym137_.gl_pathv = ((NCSTRING*) NIM_NIL);
			T19_ = (int)0;
			T19_ = glob(nimToCStringConv(found), ((int) 0), NIM_NIL, (&fX60gensym137_));
			resX60gensym137_ = ((NI) (T19_));
			pushSafePoint(&TM__an3LHxrAv8p724x7H8KxOw_80);
			TM__an3LHxrAv8p724x7H8KxOw_80.status = setjmp(TM__an3LHxrAv8p724x7H8KxOw_80.context);
			if (TM__an3LHxrAv8p724x7H8KxOw_80.status == 0) {
			{
				if (!(resX60gensym137_ == ((NI) 0))) goto LA22_;
				{
					NI iX60gensym137_;
					NI colontmp_;
					NI res;
					iX60gensym137_ = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = (NI)(fX60gensym137_.gl_pathc - ((NI) 1));
					res = ((NI) 0);
					{
						while (1) {
							NimStringDesc* pathX60gensym137_;
							if (!(res <= colontmp_)) goto LA26;
							iX60gensym137_ = res;
							pathX60gensym137_ = cstrToNimstr(fX60gensym137_.gl_pathv[iX60gensym137_]);
							{
								NIM_BOOL T29_;
								NimStringDesc* obj;
								NimStringDesc* T32_;
								NimStringDesc* T33_;
								tyProc__POo83lI9a0E0qOvqORpi4yw T34_;
								T29_ = (NIM_BOOL)0;
								T29_ = nosfileExists(pathX60gensym137_);
								if (!T29_) goto LA30_;
								f = pathX60gensym137_;
								T32_ = NIM_NIL;
								T32_ = nosextractFilename(f);
								T33_ = NIM_NIL;
								T33_ = nsuFormatSingleElem(dest, T32_);
								obj = completeCfilePath__extccomp_715((*(*c).graph).config, T33_, NIM_TRUE);
								nimZeroMem((void*)(&T34_), sizeof(tyProc__POo83lI9a0E0qOvqORpi4yw));
								T34_.ClP_0 = docompile__pragmas_1078; T34_.ClE_0 = colonenv_;
								T34_.ClE_0? T34_.ClP_0(c, it, f, obj, ((NimStringDesc*) NIM_NIL), T34_.ClE_0):((TM__an3LHxrAv8p724x7H8KxOw_84)(T34_.ClP_0))(c, it, f, obj, ((NimStringDesc*) NIM_NIL));
							}
							LA30_: ;
							res += ((NI) 1);
						} LA26: ;
					}
				}
			}
			LA22_: ;
			popSafePoint();
			}
			else {
				popSafePoint();
			}
			{
				globfree((&fX60gensym137_));
				if (TM__an3LHxrAv8p724x7H8KxOw_80.status != 0) nimLeaveFinally();
			}
			if (TM__an3LHxrAv8p724x7H8KxOw_80.status != 0) reraiseException();
		}
	}
	goto LA9_;
	LA14_: ;
	{
		NimStringDesc* s_2;
		NimStringDesc* customArgs;
		NimStringDesc* found_2;
		NimStringDesc* T49_;
		NimStringDesc* T50_;
		NimStringDesc* mangled;
		NimStringDesc* T67_;
		NimStringDesc* obj_2;
		tyProc__POo83lI9a0E0qOvqORpi4yw T68_;
		s_2 = ((NimStringDesc*) NIM_NIL);
		customArgs = ((NimStringDesc*) NIM_NIL);
		{
			if (!((*(*colonenv_).n1).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*(*colonenv_).n1).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29) || (*(*colonenv_).n1).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30) || (*(*colonenv_).n1).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31) || (*(*colonenv_).n1).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) || (*(*colonenv_).n1).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28) || (*(*colonenv_).n1).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32))) goto LA40_;
			s_2 = getStrLit__pragmas_1085(c, (*colonenv_).n1, ((NI) 1));
			{
				NI T44_;
				T44_ = (NI)0;
				T44_ = len__ast_3155((*colonenv_).n1);
				if (!(T44_ <= ((NI) 3))) goto LA45_;
				customArgs = getStrLit__pragmas_1085(c, (*colonenv_).n1, ((NI) 2));
			}
			goto LA42_;
			LA45_: ;
			{
				liMessage__msgs_1128((*(*c).graph).config, (*(*colonenv_).n1).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_85), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_86, NIM_FALSE);
			}
			LA42_: ;
		}
		goto LA38_;
		LA40_: ;
		{
			s_2 = expectStrLit__pragmas_373(c, (*colonenv_).n1);
		}
		LA38_: ;
		T49_ = NIM_NIL;
		T49_ = toFullPath__msgs_548((*(*c).graph).config, (*(*colonenv_).n1).info.fileIndex);
		T50_ = NIM_NIL;
		T50_ = nosparentDir(T49_);
		found_2 = slash___pureZos_121(T50_, s_2);
		{
			NIM_BOOL T53_;
			T53_ = (NIM_BOOL)0;
			T53_ = nosfileExists(found_2);
			if (!!(T53_)) goto LA54_;
			{
				NIM_BOOL T58_;
				T58_ = (NIM_BOOL)0;
				T58_ = nosisAbsolute(s_2);
				if (!T58_) goto LA59_;
				found_2 = copyString(s_2);
			}
			goto LA56_;
			LA59_: ;
			{
				found_2 = findFile__options_4487((*(*c).graph).config, s_2, NIM_FALSE);
				{
					NIM_BOOL T64_;
					T64_ = (NIM_BOOL)0;
					T64_ = isEmpty__options_4492(found_2);
					if (!T64_) goto LA65_;
					found_2 = copyString(s_2);
				}
				LA65_: ;
			}
			LA56_: ;
		}
		LA54_: ;
		T67_ = NIM_NIL;
		T67_ = mangleModuleName__modulepaths_32((*(*c).graph).config, found_2);
		mangled = completeCfilePath__extccomp_715((*(*c).graph).config, T67_, NIM_TRUE);
		obj_2 = toObjFile__extccomp_720((*(*c).graph).config, mangled);
		nimZeroMem((void*)(&T68_), sizeof(tyProc__POo83lI9a0E0qOvqORpi4yw));
		T68_.ClP_0 = docompile__pragmas_1078; T68_.ClE_0 = colonenv_;
		T68_.ClE_0? T68_.ClP_0(c, it, found_2, obj_2, customArgs, T68_.ClE_0):((TM__an3LHxrAv8p724x7H8KxOw_87)(T68_.ClP_0))(c, it, found_2, obj_2, customArgs);
	}
	LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, relativeFile__pragmas_1066)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NimStringDesc* ext) {
	NimStringDesc* result;
	NimStringDesc* s;
	NimStringDesc* T8_;
	NimStringDesc* T9_;
	result = NIM_NIL;
	s = expectStrLit__pragmas_373(c, n);
	{
		NIM_BOOL T3_;
		tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((NI) 0) < (ext ? ext->Sup.len : 0));
		if (!(T3_)) goto LA4_;
		nimZeroMem((void*)(&T5_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
		nossplitFile(s, (&T5_));
		T3_ = ((T5_.Field2 ? T5_.Field2->Sup.len : 0) == 0);
		LA4_: ;
		if (!T3_) goto LA6_;
		s = nosaddFileExt(s, ext);
	}
	LA6_: ;
	T8_ = NIM_NIL;
	T8_ = toFullPath__msgs_548((*(*c).graph).config, (*n).info.fileIndex);
	T9_ = NIM_NIL;
	T9_ = nosparentDir(T8_);
	result = slash___pureZos_121(T9_, s);
	{
		NIM_BOOL T12_;
		T12_ = (NIM_BOOL)0;
		T12_ = nosfileExists(result);
		if (!!(T12_)) goto LA13_;
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = nosisAbsolute(s);
			if (!T17_) goto LA18_;
			result = copyString(s);
		}
		goto LA15_;
		LA18_: ;
		{
			result = findFile__options_4487((*(*c).graph).config, s, NIM_FALSE);
			{
				NIM_BOOL T23_;
				T23_ = (NIM_BOOL)0;
				T23_ = isEmpty__options_4492(result);
				if (!T23_) goto LA24_;
				result = copyString(s);
			}
			LA24_: ;
		}
		LA15_: ;
	}
	LA13_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processLink__pragmas_1132)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NimStringDesc* found;
	tyArray__Re75IspeoxXy2oCZHwcRrA T1_;
	found = relativeFile__pragmas_1066(c, n, CC__extccomp_510[((*(*(*c).graph).config).cCompiler)- 1].Field1);
	addExternalFileToLink__extccomp_756((*(*c).graph).config, found);
	nimZeroMem((void*)T1_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
	T1_[0] = copyString(((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_88));
	T1_[1] = copyString(found);
	recordPragma__pragmas_131(c, n, T1_, 2);
}
static N_INLINE(NIM_BOOL, isTopLevel__semdata_1121)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((*(*c).currentScope).depthLevel <= ((NI) 2));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processExperimental__pragmas_883)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_3155(n);
		T3_ = !((T5_ == ((NI) 2)));
		LA4_: ;
		if (!T3_) goto LA6_;
		(*c).features = ((*c).features | 15);
	}
	goto LA1_;
	LA6_: ;
	{
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), (*c).semConstExpr(c, (*n)._kind_6.sons->data[((NI) 1)], ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		switch ((*(*n)._kind_6.sons->data[((NI) 1)]).kind) {
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20):
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 21):
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22):
		{
			TSafePoint TM__an3LHxrAv8p724x7H8KxOw_94;
			tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw feature;
			pushSafePoint(&TM__an3LHxrAv8p724x7H8KxOw_94);
			TM__an3LHxrAv8p724x7H8KxOw_94.status = setjmp(TM__an3LHxrAv8p724x7H8KxOw_94.context);
			if (TM__an3LHxrAv8p724x7H8KxOw_94.status == 0) {
			feature = parseEnum__commands_1298((*(*n)._kind_6.sons->data[((NI) 1)])._kind_3.strVal);
			(*c).features |= ((NU32)1)<<((feature) & 31);
			{
				if (!(feature == ((tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw) 9))) goto LA12_;
				{
					NIM_BOOL T16_;
					T16_ = (NIM_BOOL)0;
					T16_ = isTopLevel__semdata_1121(c);
					if (!!(T16_)) goto LA17_;
					liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_95), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_96, NIM_FALSE);
				}
				LA17_: ;
				(*(*c).module).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 4)) & 63);
			}
			LA12_: ;
			popSafePoint();
			}
			else {
				popSafePoint();
				if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIvalueerror__5lcTdgqMq62cNGRwBb0thA_))) {
					TM__an3LHxrAv8p724x7H8KxOw_94.status = 0;
					liMessage__msgs_1128((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 1)]).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_97), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_98, NIM_FALSE);
					popCurrentException();
				}
			}
			if (TM__an3LHxrAv8p724x7H8KxOw_94.status != 0) reraiseException();
		}
		break;
		default:
		{
			liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_20), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_99, NIM_FALSE);
		}
		break;
		}
	}
	LA1_: ;
}
static N_INLINE(tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ, pragmaToOptions__pragmas_880)(tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw w) {
	tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ result;
	nimZeroMem((void*)(&result), sizeof(tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ));
	switch (w) {
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 155):
	{
		result = 3518;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 79):
	{
		result = 2;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 200):
	{
		result = 4;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 156):
	{
		result = 8;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 157):
	{
		result = 16;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 158):
	{
		result = 32;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 160):
	{
		result = 384;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 161):
	{
		result = 128;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 162):
	{
		result = 256;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 164):
	{
		result = 512;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 163):
	{
		result = 1024;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 167):
	{
		result = 2048;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 171):
	{
		result = 8192;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 172):
	{
		result = 16384;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 132):
	{
		result = 4096;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 133):
	{
		result = 131072;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 134):
	{
		result = 524288;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 141):
	{
		result = 1;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 77):
	{
		result = 18874368;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 78):
	{
		result = 16777216;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 291):
	{
		result = 1048576;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 217):
	{
		result = 4194304;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 168):
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 169):
	{
		result = 8388608;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 170):
	{
		result = 33554432;
	}
	break;
	default:
	{
		result = 0;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, onOff__pragmas_489)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ op, tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ* resOptions) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isTurnedOn__pragmas_469(c, n);
		if (!T3_) goto LA4_;
		(*resOptions) = ((*resOptions) | op);
	}
	goto LA1_;
	LA4_: ;
	{
		(*resOptions) = ((*resOptions) & ~ op);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg, wordToCallConv__pragmas_456)(tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw sw) {
	tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg result;
	result = (tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg)0;
	result = ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) ((NI)((NI)(((NI) 0) + sw) - ((NI) 142))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processCallConv__pragmas_525)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T6_;
		tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw sw;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28));
		if (!(T4_)) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__ast_3155(n);
		T4_ = (T6_ == ((NI) 2));
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA7_;
		T3_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2));
		LA7_: ;
		if (!T3_) goto LA8_;
		sw = whichKeyword__idents_223((*(*n)._kind_6.sons->data[((NI) 1)])._kind_5.ident);
		switch (sw) {
		case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 142) ... ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 152):
		{
			tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q** T11_;
			T11_ = (tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q**)0;
			T11_ = X5BX5D___semdata_356(((*c).optionStack) ? ((*c).optionStack->data) : NIM_NIL, ((*c).optionStack ? (*c).optionStack->Sup.len : 0), ((NI) 1));
			(*(*T11_)).defaultCC = wordToCallConv__pragmas_456(sw);
		}
		break;
		default:
		{
			liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_100), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_101, NIM_FALSE);
		}
		break;
		}
	}
	goto LA1_;
	LA8_: ;
	{
		liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_100), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_102, NIM_FALSE);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, tryProcessOption__pragmas_926)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ* resOptions) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	result = NIM_TRUE;
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_3155(n);
		T3_ = !((T5_ == ((NI) 2)));
		LA4_: ;
		if (!T3_) goto LA6_;
		result = NIM_FALSE;
	}
	goto LA1_;
	LA6_: ;
	{
		if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42))) goto LA9_;
		processNote__pragmas_665(c, n);
	}
	goto LA1_;
	LA9_: ;
	{
		if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2)))) goto LA12_;
		result = NIM_FALSE;
	}
	goto LA1_;
	LA12_: ;
	{
		tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw sw;
		tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ opts;
		sw = whichKeyword__idents_223((*(*n)._kind_6.sons->data[((NI) 0)])._kind_5.ident);
		{
			if (!(sw == ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 207))) goto LA17_;
			processExperimental__pragmas_883(c, n);
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA17_: ;
		opts = pragmaToOptions__pragmas_880(sw);
		{
			if (!!((opts == 0))) goto LA21_;
			onOff__pragmas_489(c, n, opts, resOptions);
		}
		goto LA19_;
		LA21_: ;
		{
			switch (sw) {
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 140):
			{
				processCallConv__pragmas_525(c, n);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 115):
			{
				processDynLib__pragmas_623(c, n, ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 173):
			{
				{
					if (!!(((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2)))) goto LA29_;
					invalidPragma__pragmas_150(c, n);
				}
				goto LA27_;
				LA29_: ;
				{
					NimStringDesc* T32_;
					T32_ = NIM_NIL;
					T32_ = nsuNormalize((*(*(*n)._kind_6.sons->data[((NI) 1)])._kind_5.ident).s);
					if (eqStrings(T32_, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_103))) goto LA33_;
					if (eqStrings(T32_, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_104))) goto LA34_;
					if (eqStrings(T32_, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_105))) goto LA35_;
					goto LA36_;
					LA33_: ;
					{
						(*resOptions) |= ((NU32)1)<<((((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 15)) & 31);
						(*resOptions) &= ~(((NU32)1) << ((((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 16)) & 31));
					}
					goto LA37_;
					LA34_: ;
					{
						(*resOptions) &= ~(((NU32)1) << ((((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 15)) & 31));
						(*resOptions) |= ((NU32)1)<<((((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 16)) & 31);
					}
					goto LA37_;
					LA35_: ;
					{
						(*resOptions) &= ~(((NU32)1) << ((((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 15)) & 31));
						(*resOptions) &= ~(((NU32)1) << ((((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 16)) & 31));
					}
					goto LA37_;
					LA36_: ;
					{
						liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_106), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_107, NIM_FALSE);
					}
					LA37_: ;
				}
				LA27_: ;
			}
			break;
			default:
			{
				result = NIM_FALSE;
			}
			break;
			}
		}
		LA19_: ;
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processPush__pragmas_993)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI start) {
	tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q* x;
	{
		if (!((*(*n)._kind_6.sons->data[(NI)(start - ((NI) 1))]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*(*n)._kind_6.sons->data[(NI)(start - ((NI) 1))]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*(*n)._kind_6.sons->data[(NI)(start - ((NI) 1))]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28))) goto LA3_;
		liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_92), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_93, NIM_FALSE);
	}
	LA3_: ;
	x = pushOptionEntry__semdata_474(c);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(n);
		i_2 = start;
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA7;
				i = i_2;
				{
					NIM_BOOL T10_;
					T10_ = (NIM_BOOL)0;
					T10_ = tryProcessOption__pragmas_926(c, (*n)._kind_6.sons->data[i], (&(*(*(*c).graph).config).options));
					if (!!(T10_)) goto LA11_;
					{
						if (!((*x).otherPragmas == 0)) goto LA15_;
						asgnRef((void**) (&(*x).otherPragmas), newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 90), (*n).info));
					}
					LA15_: ;
					add__ast_4798((*x).otherPragmas, (*n)._kind_6.sons->data[i]);
				}
				LA11_: ;
				i_2 += ((NI) 1);
			} LA7: ;
		}
	}
	{
		if (!!((((*(*c).optionStack->data[((NI) 0)]).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 17))&31U)))!=0))) goto LA19_;
		(*(*(*c).graph).config).options &= ~(((NU32)1) << ((((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 17)) & 31));
	}
	LA19_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processPop__pragmas_1028)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NI T3_;
		T3_ = ((*c).optionStack ? (*c).optionStack->Sup.len : 0);
		if (!(T3_ <= ((NI) 1))) goto LA4_;
		liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_108), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_109, NIM_FALSE);
	}
	goto LA1_;
	LA4_: ;
	{
		popOptionEntry__semdata_489(c);
	}
	LA1_: ;
}
static N_INLINE(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw, dotdot___stdZenumutils_90)(NI a, NI b) {
	tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw));
	result.a = a;
	result.b = b;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processPragma__pragmas_1280)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI i) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* userPragma;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T16_;
	tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw T45_;
	tySequence__IeU9azYSNIK3V9b36Ir6NZcw* T46_;
	it = (*n)._kind_6.sons->data[i];
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28)));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = safeLen__ast_3148(it);
		T3_ = (T5_ == ((NI) 2));
		LA4_: ;
		if (!T3_) goto LA6_;
		invalidPragma__pragmas_150(c, n);
	}
	goto LA1_;
	LA6_: ;
	{
		NIM_BOOL T9_;
		NIM_BOOL T10_;
		NI T11_;
		T9_ = (NIM_BOOL)0;
		T10_ = (NIM_BOOL)0;
		T11_ = (NI)0;
		T11_ = safeLen__ast_3148(it);
		T10_ = !((T11_ == ((NI) 2)));
		if (T10_) goto LA12_;
		T10_ = !(((*(*it)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2)));
		LA12_: ;
		T9_ = T10_;
		if (T9_) goto LA13_;
		T9_ = !(((*(*it)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2)));
		LA13_: ;
		if (!T9_) goto LA14_;
		invalidPragma__pragmas_150(c, n);
	}
	goto LA1_;
	LA14_: ;
	LA1_: ;
	T16_ = nextSymId__ast_3103((*c).Sup.idgen);
	userPragma = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 18), (*(*it)._kind_6.sons->data[((NI) 1)])._kind_5.ident, T16_, (*c).module, (*it).info, (*(*(*c).graph).config).options);
	{
		NIM_BOOL T19_;
		NIM_BOOL T20_;
		NIM_BOOL T21_;
		NIM_BOOL T22_;
		NIM_BOOL T23_;
		NIM_BOOL T24_;
		NIM_BOOL T25_;
		NIM_BOOL T26_;
		NIM_BOOL T27_;
		NIM_BOOL T28_;
		NIM_BOOL T29_;
		NIM_BOOL T39_;
		T19_ = (NIM_BOOL)0;
		T20_ = (NIM_BOOL)0;
		T21_ = (NIM_BOOL)0;
		T22_ = (NIM_BOOL)0;
		T23_ = (NIM_BOOL)0;
		T24_ = (NIM_BOOL)0;
		T25_ = (NIM_BOOL)0;
		T26_ = (NIM_BOOL)0;
		T27_ = (NIM_BOOL)0;
		T28_ = (NIM_BOOL)0;
		T29_ = (NIM_BOOL)0;
		T29_ = (((*(*(*c).graph).config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 10))&31U)))!=0);
		if (!(T29_)) goto LA30_;
		T29_ = !(((49152 & (*(*(*c).graph).config).globalOptions) == 0));
		LA30_: ;
		T28_ = T29_;
		if (!(T28_)) goto LA31_;
		T28_ = (((*(*(*c).graph).config).notes[(NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 91)- 17))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 91)- 17))&7U)))!=0);
		LA31_: ;
		T27_ = T28_;
		if (!(T27_)) goto LA32_;
		T27_ = belongsToProjectPackage__packages_50((*(*c).graph).config, userPragma);
		LA32_: ;
		T26_ = T27_;
		if (!(T26_)) goto LA33_;
		T26_ = !((((*(*(*c).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 16))&63U)))!=0));
		LA33_: ;
		T25_ = T26_;
		if (!(T25_)) goto LA34_;
		T25_ = !(((*userPragma).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 11)));
		LA34_: ;
		T24_ = T25_;
		if (!(T24_)) goto LA35_;
		T24_ = !(((*userPragma).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 5)));
		LA35_: ;
		T23_ = T24_;
		if (!(T23_)) goto LA36_;
		T23_ = ((Letters__linter_12[(NU)(((NU8)((*(*userPragma).name).s->data[((NI) 0)])))>>3] &(1U<<((NU)(((NU8)((*(*userPragma).name).s->data[((NI) 0)])))&7U)))!=0);
		LA36_: ;
		T22_ = T23_;
		if (!(T22_)) goto LA37_;
		T22_ = !(((144 &((NU32)1<<((NU)((*userPragma).kind)&31U)))!=0));
		LA37_: ;
		T21_ = T22_;
		if (!(T21_)) goto LA38_;
		T39_ = (NIM_BOOL)0;
		T39_ = ((*userPragma).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
		if (T39_) goto LA40_;
		T39_ = !(((*(*userPragma).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8)));
		LA40_: ;
		T21_ = T39_;
		LA38_: ;
		T20_ = T21_;
		if (!(T20_)) goto LA41_;
		T20_ = ((192 & (*userPragma).flags) == 0);
		LA41_: ;
		T19_ = T20_;
		if (!(T19_)) goto LA42_;
		T19_ = !((((*userPragma).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 34))&63U)))!=0));
		LA42_: ;
		if (!T19_) goto LA43_;
		nep1CheckDefImpl__linter_112((*(*c).graph).config, (*userPragma).info, userPragma, (*userPragma).kind);
	}
	LA43_: ;
	T45_ = dotdot___stdZenumutils_90((NI)(i + ((NI) 1)), ((NI) 1));
	T46_ = NIM_NIL;
	T46_ = X5BX5D___pragmas_1367(((*n)._kind_6.sons) ? ((*n)._kind_6.sons->data) : NIM_NIL, ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0), T45_);
	asgnRef((void**) (&(*userPragma).ast), newTreeI__ast_3384(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 90), (*n).info, (T46_) ? (T46_->data) : NIM_NIL, (T46_ ? T46_->Sup.len : 0)));
	strTableAdd__astalgo_3325((&(*c).userPragmas), userPragma);
}
N_LIB_PRIVATE N_NIMCALL(void, processCodegenDecl__pragmas_403)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	asgnRef((void**) (&(*sym).constraint), getStrLitNode__pragmas_356(c, n));
}
N_LIB_PRIVATE N_NIMCALL(void, processOption__pragmas_989)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ* resOptions) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = tryProcessOption__pragmas_926(c, n, resOptions);
		if (!!(T3_)) goto LA4_;
		liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_110), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_111, NIM_FALSE);
	}
	LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, semAsmOrEmit__pragmas_1136)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* con, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_CHAR marker) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
{	result = NIM_NIL;
	switch ((*(*n)._kind_6.sons->data[((NI) 1)]).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 21):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22):
	{
		tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw T2_;
		NimStringDesc* str;
		NI a;
		T2_ = (tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw)0;
		{
			if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 89))) goto LA5_;
			T2_ = ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 89);
		}
		goto LA3_;
		LA5_: ;
		{
			T2_ = ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152);
		}
		LA3_: ;
		result = newNodeI__ast_3320(T2_, (*n).info);
		str = copyString((*(*n)._kind_6.sons->data[((NI) 1)])._kind_3.strVal);
		{
			if (!((str ? str->Sup.len : 0) == 0)) goto LA10_;
			liMessage__msgs_1128((*(*con).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_113), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_114, NIM_FALSE);
			goto BeforeRet_;
		}
		LA10_: ;
		a = ((NI) 0);
		{
			while (1) {
				NI b;
				NimStringDesc* sub;
				NI c;
				b = nsuFindChar(str, marker, ((NI) (a)), ((NI) 0));
				{
					if (!(b < ((NI) 0))) goto LA16_;
					sub = substr__system_7726(str, a);
				}
				goto LA14_;
				LA16_: ;
				{
					sub = substr__system_7714(str, a, (NI)(b - ((NI) 1)));
				}
				LA14_: ;
				{
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T23_;
					if (!!(((sub ? sub->Sup.len : 0) == 0))) goto LA21_;
					T23_ = NIM_NIL;
					T23_ = newStrNode__ast_3801(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20), sub);
					add__ast_4798(result, T23_);
				}
				LA21_: ;
				{
					if (!(b < ((NI) 0))) goto LA26_;
					goto LA12;
				}
				LA26_: ;
				c = nsuFindChar(str, marker, ((NI) ((NI)(b + ((NI) 1)))), ((NI) 0));
				{
					if (!(c < ((NI) 0))) goto LA30_;
					sub = substr__system_7726(str, (NI)(b + ((NI) 1)));
				}
				goto LA28_;
				LA30_: ;
				{
					sub = substr__system_7714(str, (NI)(b + ((NI) 1)), (NI)(c - ((NI) 1)));
				}
				LA28_: ;
				{
					NIM_BOOL amb;
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* e;
					tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T37_;
					if (!!(((sub ? sub->Sup.len : 0) == 0))) goto LA35_;
					amb = NIM_FALSE;
					T37_ = NIM_NIL;
					T37_ = getIdent__idents_152((*con).cache, sub);
					e = searchInScopes__lookups_603(con, T37_, (&amb));
					{
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T42_;
						if (!!((e == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA40_;
						(*e).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 0)) & 63);
						T42_ = NIM_NIL;
						T42_ = newSymNode__ast_3704(e);
						add__ast_4798(result, T42_);
					}
					goto LA38_;
					LA40_: ;
					{
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T44_;
						T44_ = NIM_NIL;
						T44_ = newStrNode__ast_3801(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20), sub);
						add__ast_4798(result, T44_);
					}
					LA38_: ;
				}
				goto LA33_;
				LA35_: ;
				{
					NimStringDesc* T46_;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T47_;
					T46_ = NIM_NIL;
					T46_ = nimCharToStr(marker);
					T47_ = NIM_NIL;
					T47_ = newStrNode__ast_3801(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20), T46_);
					add__ast_4798(result, T47_);
				}
				LA33_: ;
				{
					if (!(c < ((NI) 0))) goto LA50_;
					goto LA12;
				}
				LA50_: ;
				a = (NI)(c + ((NI) 1));
			}
		} LA12: ;
	}
	break;
	default:
	{
		illFormedAstLocal__semdata_1104(n, (*(*con).graph).config);
		result = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 89), (*n).info);
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaEmit__pragmas_1178)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_3155(n);
		T3_ = !((T5_ == ((NI) 2)));
		LA4_: ;
		if (!T3_) goto LA6_;
		liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_20), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_112, NIM_FALSE);
	}
	goto LA1_;
	LA6_: ;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n1;
		n1 = (*n)._kind_6.sons->data[((NI) 1)];
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b;
			NI T13_;
			if (!((*n1).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41))) goto LA11_;
			T13_ = (NI)0;
			T13_ = len__ast_3155(n1);
			b = newNodeI__ast_3324(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41), (*n1).info, T13_);
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_3155(n1);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA16;
						i = i_2;
						asgnRef((void**) (&(*b)._kind_6.sons->data[i]), (*c).semExpr(c, (*n1)._kind_6.sons->data[i], 0, ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
						i_2 += ((NI) 1);
					} LA16: ;
				}
			}
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), b);
		}
		goto LA9_;
		LA11_: ;
		{
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), (*c).semConstExpr(c, n1, ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
			switch ((*(*n)._kind_6.sons->data[((NI) 1)]).kind) {
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 21):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22):
			{
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), semAsmOrEmit__pragmas_1136(c, n, 96));
			}
			break;
			default:
			{
				liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_20), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_115, NIM_FALSE);
			}
			break;
			}
		}
		LA9_: ;
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaUnroll__pragmas_1226)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		if (!((*(*c).p).nestedLoopCounter <= ((NI) 0))) goto LA3_;
		invalidPragma__pragmas_150(c, n);
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T6_;
		NI T8_;
		NI unrollFactor;
		T6_ = (NIM_BOOL)0;
		T6_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28));
		if (!(T6_)) goto LA7_;
		T8_ = (NI)0;
		T8_ = len__ast_3155(n);
		T6_ = (T8_ == ((NI) 2));
		LA7_: ;
		if (!T6_) goto LA9_;
		unrollFactor = expectIntLit__pragmas_377(c, n);
		{
			NIM_BOOL T13_;
			T13_ = (NIM_BOOL)0;
			T13_ = ltpercent___system_1005(unrollFactor, ((NI) 32));
			if (!T13_) goto LA14_;
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), newIntNode__ast_3711(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6), ((NI64) (unrollFactor))));
		}
		goto LA11_;
		LA14_: ;
		{
			invalidPragma__pragmas_150(c, n);
		}
		LA11_: ;
	}
	goto LA1_;
	LA9_: ;
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaLine__pragmas_1238)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NIM_BOOL T3_;
		NI T5_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_3155(n);
		T3_ = (T5_ == ((NI) 2));
		LA4_: ;
		if (!T3_) goto LA6_;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), (*c).semConstExpr(c, (*n)._kind_6.sons->data[((NI) 1)], ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		a = (*n)._kind_6.sons->data[((NI) 1)];
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* y;
			if (!((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 37) || (*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 160))) goto LA10_;
			x = (*a)._kind_6.sons->data[((NI) 0)];
			y = (*a)._kind_6.sons->data[((NI) 1)];
			{
				if (!((*x).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34))) goto LA14_;
				x = (*x)._kind_6.sons->data[((NI) 1)];
			}
			LA14_: ;
			{
				if (!((*y).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34))) goto LA18_;
				y = (*y)._kind_6.sons->data[((NI) 1)];
			}
			LA18_: ;
			{
				if (!!(((*x).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20)))) goto LA22_;
				liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_20), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_118, NIM_FALSE);
			}
			goto LA20_;
			LA22_: ;
			{
				if (!!(((*y).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6)))) goto LA25_;
				liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_31), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_119, NIM_FALSE);
			}
			goto LA20_;
			LA25_: ;
			{
				(*n).info.fileIndex = fileInfoIdx__msgs_376((*(*c).graph).config, (*x)._kind_3.strVal);
				(*n).info.line = ((NU16) ((*y)._kind_1.intVal));
			}
			LA20_: ;
		}
		goto LA8_;
		LA10_: ;
		{
			liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_120), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_121, NIM_FALSE);
		}
		LA8_: ;
	}
	goto LA1_;
	LA6_: ;
	{
		(*n).info = getInfoContext__msgs_526((*(*c).graph).config, ((NI) -1));
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaLockStmt__pragmas_1419)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it) {
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_3155(it);
		T3_ = !((T5_ == ((NI) 2)));
		LA4_: ;
		if (!T3_) goto LA6_;
		invalidPragma__pragmas_150(c, it);
	}
	goto LA1_;
	LA6_: ;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
		n = (*it)._kind_6.sons->data[((NI) 1)];
		{
			if (!!(((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41)))) goto LA11_;
			liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_122), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_123, NIM_FALSE);
		}
		goto LA9_;
		LA11_: ;
		{
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_3155(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA16;
						i = i_2;
						asgnRef((void**) (&(*n)._kind_6.sons->data[i]), (*c).semExpr(c, (*n)._kind_6.sons->data[i], 0, ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
						i_2 += ((NI) 1);
					} LA16: ;
				}
			}
		}
		LA9_: ;
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI16, pragmaLocks__pragmas_1447)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it) {
	NI16 result;
	result = (NI16)0;
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_3155(it);
		T3_ = !((T5_ == ((NI) 2)));
		LA4_: ;
		if (!T3_) goto LA6_;
		invalidPragma__pragmas_150(c, it);
	}
	goto LA1_;
	LA6_: ;
	{
		switch ((*(*it)._kind_6.sons->data[((NI) 1)]).kind) {
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20):
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 21):
		case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22):
		{
			{
				if (!eqStrings((*(*it)._kind_6.sons->data[((NI) 1)])._kind_3.strVal, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_124))) goto LA12_;
				result = ((NI16) 1001);
			}
			goto LA10_;
			LA12_: ;
			{
				liMessage__msgs_1128((*(*c).graph).config, (*(*it)._kind_6.sons->data[((NI) 1)]).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_125), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_126, NIM_FALSE);
			}
			LA10_: ;
		}
		break;
		default:
		{
			NI x;
			x = expectIntLit__pragmas_377(c, it);
			{
				NIM_BOOL T18_;
				T18_ = (NIM_BOOL)0;
				T18_ = (x < ((NI) 0));
				if (T18_) goto LA19_;
				T18_ = (((NI) 1000) < x);
				LA19_: ;
				if (!T18_) goto LA20_;
				liMessage__msgs_1128((*(*c).graph).config, (*(*it)._kind_6.sons->data[((NI) 1)]).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_127), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_128, NIM_FALSE);
			}
			goto LA16_;
			LA20_: ;
			{
				result = ((NI16) (x));
			}
			LA16_: ;
		}
		break;
		}
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, pragmaGuard__pragmas_1551)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
{	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_3155(it);
		T3_ = !((T5_ == ((NI) 2)));
		LA4_: ;
		if (!T3_) goto LA6_;
		invalidPragma__pragmas_150(c, it);
		goto BeforeRet_;
	}
	LA6_: ;
	n = (*it)._kind_6.sons->data[((NI) 1)];
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA10_;
		result = (*n)._kind_4.sym;
	}
	goto LA8_;
	LA10_: ;
	{
		if (!(kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19))) goto LA13_;
		result = qualifiedLookUp__lookups_2598(c, n, 0);
		{
			NIM_BOOL T17_;
			NIM_BOOL T18_;
			tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T23_;
			tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T24_;
			T17_ = (NIM_BOOL)0;
			T18_ = (NIM_BOOL)0;
			T18_ = (result == 0);
			if (T18_) goto LA19_;
			T18_ = !(((768 &((NU32)1<<((NU)((*result).kind)&31U)))!=0));
			LA19_: ;
			T17_ = T18_;
			if (T17_) goto LA20_;
			T17_ = !((((*result).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 3))&63U)))!=0));
			LA20_: ;
			if (!T17_) goto LA21_;
			T23_ = NIM_NIL;
			T23_ = considerQuotedIdent__lookups_29(c, n, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
			T24_ = nextSymId__ast_3103((*c).Sup.idgen);
			result = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 0), T23_, T24_, ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL), (*n).info, (*(*(*c).graph).config).options);
		}
		LA21_: ;
	}
	goto LA8_;
	LA13_: ;
	{
		result = qualifiedLookUp__lookups_2598(c, n, 2);
	}
	LA8_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaProposition__pragmas_157)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_3155(n);
		T3_ = !((T5_ == ((NI) 2)));
		LA4_: ;
		if (!T3_) goto LA6_;
		liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_143), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_144, NIM_FALSE);
	}
	goto LA1_;
	LA6_: ;
	{
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), (*c).semExpr(c, (*n)._kind_6.sons->data[((NI) 1)], 0, ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
	}
	LA1_: ;
}
static N_INLINE(void, addDeclAt__lookups_1509)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* scope, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	addDeclAt__lookups_995(c, scope, sym, (*sym).info);
}
static N_INLINE(void, addDecl__lookups_1517)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	addDeclAt__lookups_1509(c, (*c).currentScope, sym);
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaEnsures__pragmas_171)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_3155(n);
		T3_ = !((T5_ == ((NI) 2)));
		LA4_: ;
		if (!T3_) goto LA6_;
		liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_143), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_145, NIM_FALSE);
	}
	goto LA1_;
	LA6_: ;
	{
		tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* T9_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* o;
		T9_ = NIM_NIL;
		T9_ = openScope__lookups_76(c);
		o = getCurrOwner__semdata_327(c);
		{
			NIM_BOOL T12_;
			NIM_BOOL T13_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
			tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T18_;
			tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T19_;
			T12_ = (NIM_BOOL)0;
			T13_ = (NIM_BOOL)0;
			T13_ = ((520192 &((NU32)1<<((NU)((*o).kind)&31U)))!=0);
			if (!(T13_)) goto LA14_;
			T13_ = !(((*o).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
			LA14_: ;
			T12_ = T13_;
			if (!(T12_)) goto LA15_;
			T12_ = !(((*(*o).typ).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
			LA15_: ;
			if (!T12_) goto LA16_;
			T18_ = NIM_NIL;
			T18_ = getIdent__idents_152((*c).cache, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_146));
			T19_ = nextSymId__ast_3103((*c).Sup.idgen);
			s = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 11), T18_, T19_, o, (*n).info, 0);
			asgnRef((void**) (&(*s).typ), (*(*o).typ).sons->data[((NI) 0)]);
			(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 0)) & 63);
			addDecl__lookups_1517(c, s);
		}
		LA16_: ;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), (*c).semExpr(c, (*n)._kind_6.sons->data[((NI) 1)], 0, ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		closeScope__lookups_108(c);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, illegalCustomPragma__pragmas_153)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NimStringDesc* T1_;
	T1_ = NIM_NIL;
	T1_ = rawNewString(((*(*s).name).s ? (*(*s).name).s->Sup.len : 0) + 35);
appendString(T1_, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_147));
appendString(T1_, (*(*s).name).s);
appendString(T1_, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_148));
	liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T1_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_149, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, singlePragma__pragmas_1669)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI* i, tySet_tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw validPragmas, NIM_BOOL comesFromPush, NIM_BOOL isStatement) {
	NIM_BOOL result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* key;
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* userPragma;
{	result = (NIM_BOOL)0;
	it = (*n)._kind_6.sons->data[(*i)];
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_3155(it);
		T3_ = (((NI) 1) < T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		key = (*it)._kind_6.sons->data[((NI) 0)];
	}
	goto LA1_;
	LA6_: ;
	{
		key = it;
	}
	LA1_: ;
	{
		if (!((*key).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42))) goto LA11_;
		processNote__pragmas_665(c, it);
		goto BeforeRet_;
	}
	goto LA9_;
	LA11_: ;
	{
		tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw T23_;
		if (!((*key).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 61))) goto LA14_;
		{
			if (!comesFromPush) goto LA18_;
			liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_5), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_6, NIM_FALSE);
		}
		goto LA16_;
		LA18_: ;
		{
			if (!!(isStatement)) goto LA21_;
			liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_7), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_8, NIM_FALSE);
		}
		goto LA16_;
		LA21_: ;
		LA16_: ;
		T23_ = (tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw)0;
		T23_ = whichPragma__trees_244((*key)._kind_6.sons->data[((NI) 1)]);
		switch (T23_) {
		case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 174):
		case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 179):
		{
			pragmaRaisesOrTags__pragmas_1390(c, (*key)._kind_6.sons->data[((NI) 1)]);
		}
		break;
		default:
		{
		}
		break;
		}
		goto BeforeRet_;
	}
	goto LA9_;
	LA14_: ;
	{
		if (!!(((*key).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2) || (*key).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3) || (*key).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 53) || (*key).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 57) || (*key).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 56)))) goto LA27_;
		asgnRef((void**) (&(*n)._kind_6.sons->data[(*i)]), semCustomPragma__pragmas_1584(c, it));
		goto BeforeRet_;
	}
	goto LA9_;
	LA27_: ;
	LA9_: ;
	ident = considerQuotedIdent__lookups_29(c, key, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
	userPragma = strTableGet__astalgo_3383((*c).userPragmas, ident);
	{
		tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw T52_;
		NI T53_;
		if (!!((userPragma == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA31_;
		{
			NIM_BOOL T35_;
			NIM_BOOL T36_;
			NIM_BOOL T37_;
			NIM_BOOL T38_;
			NIM_BOOL T39_;
			T35_ = (NIM_BOOL)0;
			T36_ = (NIM_BOOL)0;
			T37_ = (NIM_BOOL)0;
			T38_ = (NIM_BOOL)0;
			T39_ = (NIM_BOOL)0;
			T39_ = !(((49152 & (*(*(*c).graph).config).globalOptions) == 0));
			if (!(T39_)) goto LA40_;
			T39_ = (((*(*(*c).graph).config).notes[(NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 91)- 17))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 91)- 17))&7U)))!=0);
			LA40_: ;
			T38_ = T39_;
			if (!(T38_)) goto LA41_;
			T38_ = belongsToProjectPackage__packages_50((*(*c).graph).config, userPragma);
			LA41_: ;
			T37_ = T38_;
			if (!(T37_)) goto LA42_;
			T37_ = !(((*userPragma).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 5)));
			LA42_: ;
			T36_ = T37_;
			if (!(T36_)) goto LA43_;
			T36_ = ((Letters__linter_12[(NU)(((NU8)((*(*userPragma).name).s->data[((NI) 0)])))>>3] &(1U<<((NU)(((NU8)((*(*userPragma).name).s->data[((NI) 0)])))&7U)))!=0);
			LA43_: ;
			T35_ = T36_;
			if (!(T35_)) goto LA44_;
			T35_ = !((((*userPragma).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 34))&63U)))!=0));
			LA44_: ;
			if (!T35_) goto LA45_;
			styleCheckUseImpl__linter_158((*(*c).graph).config, (*key).info, userPragma);
		}
		LA45_: ;
		(*c).instCounter += ((NI) 1);
		{
			NimStringDesc* T51_;
			if (!(((NI) 100) < (*c).instCounter)) goto LA49_;
			T51_ = NIM_NIL;
			T51_ = rawNewString(((*(*userPragma).name).s ? (*(*userPragma).name).s->Sup.len : 0) + 22);
appendString(T51_, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_13));
appendString(T51_, (*(*userPragma).name).s);
			liMessage__msgs_1128((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T51_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 2), TM__an3LHxrAv8p724x7H8KxOw_14, NIM_FALSE);
		}
		LA49_: ;
		pragma__pragmas_125(c, sym, (*userPragma).ast, validPragmas, isStatement);
		T52_ = dotdot___pureZunicode_840((*i), (*i));
		X5BX5Deq___pragmas_1747((&(*n)._kind_6.sons), T52_, ((*(*userPragma).ast)._kind_6.sons) ? ((*(*userPragma).ast)._kind_6.sons->data) : NIM_NIL, ((*(*userPragma).ast)._kind_6.sons ? (*(*userPragma).ast)._kind_6.sons->Sup.len : 0));
		T53_ = (NI)0;
		T53_ = len__ast_3155((*userPragma).ast);
		(*i) += (NI)(T53_ - ((NI) 1));
		(*c).instCounter -= ((NI) 1);
	}
	goto LA29_;
	LA31_: ;
	{
		tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw k;
		k = whichKeyword__idents_223(ident);
		{
			if (!((validPragmas[(NU)(k)>>3] &(1U<<((NU)(k)&7U)))!=0)) goto LA57_;
			{
				NIM_BOOL T61_;
				NIM_BOOL T62_;
				NIM_BOOL T65_;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T66_;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T73_;
				T61_ = (NIM_BOOL)0;
				T62_ = (NIM_BOOL)0;
				T62_ = !(((49152 & (*(*(*c).graph).config).globalOptions) == 0));
				if (!(T62_)) goto LA63_;
				T62_ = (((*(*(*c).graph).config).notes[(NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 91)- 17))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 91)- 17))&7U)))!=0);
				LA63_: ;
				T61_ = T62_;
				if (!(T61_)) goto LA64_;
				T65_ = (NIM_BOOL)0;
				T66_ = NIM_NIL;
				{
					if (!!((sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA69_;
					T66_ = sym;
				}
				goto LA67_;
				LA69_: ;
				{
					T66_ = (*c).module;
				}
				LA67_: ;
				T65_ = !((T66_ == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
				if (!(T65_)) goto LA72_;
				T73_ = NIM_NIL;
				{
					if (!!((sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA76_;
					T73_ = sym;
				}
				goto LA74_;
				LA76_: ;
				{
					T73_ = (*c).module;
				}
				LA74_: ;
				T65_ = belongsToProjectPackage__packages_50((*(*c).graph).config, T73_);
				LA72_: ;
				T61_ = T65_;
				LA64_: ;
				if (!T61_) goto LA79_;
				checkPragmaUseImpl__linter_197((*(*c).graph).config, (*key).info, k, (*ident).s);
			}
			LA79_: ;
			switch (k) {
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 98):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 99):
			{
				NimStringDesc* T82_;
				T82_ = NIM_NIL;
				T82_ = getOptionalStr__pragmas_394(c, it, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_15));
				makeExternExport__pragmas_274(c, sym, T82_, (*it).info);
				{
					if (!(k == ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 99))) goto LA85_;
					{
						NimStringDesc* T91_;
						if (!!(((*(*(*c).graph).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 2)))) goto LA89_;
						T91_ = NIM_NIL;
						T91_ = rawNewString((reprEnum((NI)(*(*(*c).graph).config).backend, (&NTItbackend__zoooocqvga73vZuhGAAy6A_)) ? reprEnum((NI)(*(*(*c).graph).config).backend, (&NTItbackend__zoooocqvga73vZuhGAAy6A_))->Sup.len : 0) + 39);
appendString(T91_, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_23));
appendString(T91_, reprEnum((NI)(*(*(*c).graph).config).backend, (&NTItbackend__zoooocqvga73vZuhGAAy6A_)));
						liMessage__msgs_1128((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T91_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_24, NIM_FALSE);
					}
					goto LA87_;
					LA89_: ;
					{
						(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 8)) & 63);
					}
					LA87_: ;
				}
				LA85_: ;
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 0)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 96):
			{
				NimStringDesc* name;
				tyArray__Re75IspeoxXy2oCZHwcRrA T94_;
				name = getOptionalStr__pragmas_394(c, it, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_15));
				cppDefine__options_2530((*(*c).graph).config, name);
				nimZeroMem((void*)T94_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T94_[0] = copyString(((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_25));
				T94_[1] = copyString(name);
				recordPragma__pragmas_131(c, it, T94_, 2);
				makeExternImport__pragmas_261(c, sym, name, (*it).info);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 95):
			{
				NimStringDesc* name_2;
				tyArray__Re75IspeoxXy2oCZHwcRrA T96_;
				name_2 = getOptionalStr__pragmas_394(c, it, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_15));
				cppDefine__options_2530((*(*c).graph).config, name_2);
				nimZeroMem((void*)T96_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T96_[0] = copyString(((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_25));
				T96_[1] = copyString(name_2);
				recordPragma__pragmas_131(c, it, T96_, 2);
				processImportCompilerProc__pragmas_283(c, sym, name_2, (*it).info);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 239):
			{
				NimStringDesc* T98_;
				T98_ = NIM_NIL;
				T98_ = expectStrLit__pragmas_373(c, it);
				setExternName__pragmas_240(c, sym, T98_, (*it).info);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 212):
			{
				{
					if (!((*sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 18))) goto LA102_;
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 11)) & 63);
				}
				goto LA100_;
				LA102_: ;
				{
					invalidPragma__pragmas_150(c, it);
				}
				LA100_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 92):
			{
				NimStringDesc* T106_;
				T106_ = NIM_NIL;
				T106_ = getOptionalStr__pragmas_394(c, it, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_15));
				processImportCpp__pragmas_300(c, sym, T106_, (*it).info);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 93):
			{
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 27)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 97):
			{
				NimStringDesc* name_3;
				{
					if (!!(((*(*(*c).graph).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 3)))) goto LA111_;
					liMessage__msgs_1128((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_26), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_27, NIM_FALSE);
				}
				LA111_: ;
				name_3 = getOptionalStr__pragmas_394(c, it, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_15));
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 6)) & 63);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 32)) & 63);
				{
					NIM_BOOL T115_;
					NIM_BOOL T117_;
					T115_ = (NIM_BOOL)0;
					T115_ = ((520192 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0);
					if (!(T115_)) goto LA116_;
					T117_ = (NIM_BOOL)0;
					T117_ = contains__pureZstrutils_1631(name_3, TM__an3LHxrAv8p724x7H8KxOw_28);
					T115_ = !(T117_);
					LA116_: ;
					if (!T115_) goto LA118_;
					liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_29), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_30, NIM_FALSE);
				}
				LA118_: ;
				setExternName__pragmas_240(c, sym, name_3, (*it).info);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 94):
			{
				NimStringDesc* T121_;
				T121_ = NIM_NIL;
				T121_ = getOptionalStr__pragmas_394(c, it, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_15));
				processImportObjC__pragmas_330(c, sym, T121_, (*it).info);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 177):
			{
				NI size;
				{
					if (!((*sym).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA125_;
					invalidPragma__pragmas_150(c, it);
				}
				LA125_: ;
				size = expectIntLit__pragmas_377(c, it);
				switch (size) {
				case ((NI) 1):
				case ((NI) 2):
				case ((NI) 4):
				{
					(*(*sym).typ).size = ((NI64) (size));
					(*(*sym).typ).align = ((NI16) (size));
				}
				break;
				case ((NI) 8):
				{
					(*(*sym).typ).size = IL64(8);
					(*(*sym).typ).align = floatInt64Align__options_4705((*(*c).graph).config);
				}
				break;
				default:
				{
					liMessage__msgs_1128((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_34), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_35, NIM_FALSE);
				}
				break;
				}
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 104):
			{
				NI alignment;
				alignment = expectIntLit__pragmas_377(c, it);
				{
					NIM_BOOL T133_;
					T133_ = (NIM_BOOL)0;
					T133_ = isPowerOfTwo__pureZmath_174(alignment);
					if (!(T133_)) goto LA134_;
					T133_ = (((NI) 0) < alignment);
					LA134_: ;
					if (!T133_) goto LA135_;
					(*sym)._kind_2.alignment = (((*sym)._kind_2.alignment >= alignment) ? (*sym)._kind_2.alignment : alignment);
				}
				goto LA131_;
				LA135_: ;
				{
					liMessage__msgs_1128((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_36), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_37, NIM_FALSE);
				}
				LA131_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 105):
			{
				noVal__pragmas_1216(c, it);
				(*sym).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 3)) & 15);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 106):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 216):
			{
				noVal__pragmas_1216(c, it);
				{
					if (!!((sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA142_;
					{
						NIM_BOOL T146_;
						T146_ = (NIM_BOOL)0;
						T146_ = (k == ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 106));
						if (!(T146_)) goto LA147_;
						T146_ = ((520192 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0);
						LA147_: ;
						if (!T146_) goto LA148_;
						invalidPragma__pragmas_150(c, it);
					}
					goto LA144_;
					LA148_: ;
					{
						(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 11)) & 63);
					}
					LA144_: ;
				}
				LA142_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 274):
			{
				noVal__pragmas_1216(c, it);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 9)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 83):
			{
				noVal__pragmas_1216(c, it);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 41)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 253):
			{
				noVal__pragmas_1216(c, it);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 10)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 84):
			{
				noVal__pragmas_1216(c, it);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 46)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 85):
			{
				processEffectsOf__pragmas_1629(c, it, sym);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 214):
			{
				noVal__pragmas_1216(c, it);
				(*sym).flags = ((*sym).flags | 67108872);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 185):
			{
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 188):
			{
				pragmaNoForward__pragmas_504(c, it, ((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 10));
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 189):
			{
				pragmaNoForward__pragmas_504(c, it, ((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 4));
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 74):
			{
				processMagic__pragmas_407(c, it, sym);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 193):
			{
				noVal__pragmas_1216(c, it);
				{
					if (!comesFromPush) goto LA164_;
					{
						if (!((12288 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0)) goto LA168_;
						(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 28)) & 63);
					}
					LA168_: ;
				}
				goto LA162_;
				LA164_: ;
				{
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 28)) & 63);
				}
				LA162_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 218):
			{
				noVal__pragmas_1216(c, it);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 3)) & 63);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 11)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 113):
			{
				noVal__pragmas_1216(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 88):
			{
				noVal__pragmas_1216(c, it);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 29)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 108):
			{
				tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* lib;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T175_;
				T175_ = NIM_NIL;
				T175_ = getStrLitNode__pragmas_356(c, it);
				lib = getLib__pragmas_546(c, ((tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ) 0), T175_);
				addToLib__semdata_760(lib, sym);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 6)) & 63);
				(*sym).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 6)) & 15);
				(*sym).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 3)) & 15);
				{
					if (!((*sym).loc.r == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA178_;
					asgnRef((void**) (&(*sym).loc.r), rope__ropes_109((*(*sym).name).s));
				}
				LA178_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 109):
			{
				noVal__pragmas_1216(c, it);
				{
					if (!!((sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA183_;
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 12)) & 63);
					{
						if (!!(((*sym).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA187_;
						(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 1)) & 63);
					}
					LA187_: ;
				}
				LA183_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 107):
			{
				noVal__pragmas_1216(c, it);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 13)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 111):
			{
				noVal__pragmas_1216(c, it);
				{
					if (!!(((*(*(*c).graph).config).exc == ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 4)))) goto LA193_;
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 16)) & 63);
				}
				LA193_: ;
				{
					if (!!(((*(*sym).typ).sons->data[((NI) 0)] == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA197_;
					liMessage__msgs_1128((*(*c).graph).config, (*(*(*(*sym).ast)._kind_6.sons->data[((NI) 3)])._kind_6.sons->data[((NI) 0)]).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_55), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_56, NIM_FALSE);
				}
				LA197_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 191):
			{
				noVal__pragmas_1216(c, it);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 39)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 112):
			{
				noVal__pragmas_1216(c, it);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 5)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 115):
			{
				processDynLib__pragmas_623(c, it, sym);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 116):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 117):
			{
				tyArray__Re75IspeoxXy2oCZHwcRrA T203_;
				noVal__pragmas_1216(c, it);
				cppDefine__options_2530((*(*c).graph).config, (*(*sym).name).s);
				nimZeroMem((void*)T203_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T203_[0] = copyString(((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_25));
				T203_[1] = copyString((*(*sym).name).s);
				recordPragma__pragmas_131(c, it, T203_, 2);
				{
					if (!!((((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 2))&63U)))!=0))) goto LA206_;
					markCompilerProc__pragmas_1484(c, sym);
				}
				LA206_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 165):
			{
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 38)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 118):
			{
				noVal__pragmas_1216(c, it);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 19)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 224):
			{
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 23)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 138):
			{
				{
					NIM_BOOL T214_;
					T214_ = (NIM_BOOL)0;
					T214_ = !((sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
					if (!(T214_)) goto LA215_;
					T214_ = ((521088 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0);
					LA215_: ;
					if (!T214_) goto LA216_;
					{
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T222_;
						if (!((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28))) goto LA220_;
						T222_ = NIM_NIL;
						T222_ = getStrLitNode__pragmas_356(c, it);
						(void)(T222_);
					}
					LA220_: ;
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 22)) & 63);
				}
				goto LA212_;
				LA216_: ;
				{
					NIM_BOOL T224_;
					T224_ = (NIM_BOOL)0;
					T224_ = !((sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
					if (!(T224_)) goto LA225_;
					T224_ = !(((*sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6)));
					LA225_: ;
					if (!T224_) goto LA226_;
					{
						if (!((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28))) goto LA230_;
						liMessage__msgs_1128((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_60), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_61, NIM_FALSE);
					}
					LA230_: ;
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 22)) & 63);
				}
				goto LA212_;
				LA226_: ;
				{
					if (!((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28))) goto LA233_;
					deprecatedStmt__pragmas_1503(c, it);
				}
				goto LA212_;
				LA233_: ;
				{
					(*(*c).module).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 22)) & 63);
				}
				LA212_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 139):
			{
				noVal__pragmas_1216(c, it);
				{
					if (!((*sym).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA239_;
					invalidPragma__pragmas_150(c, it);
				}
				goto LA237_;
				LA239_: ;
				{
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 0)) & 63);
				}
				LA237_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 198):
			{
				{
					if (!((*sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 7))) goto LA245_;
					typeBorrow__pragmas_1463(c, sym, it);
				}
				goto LA243_;
				LA245_: ;
				{
					noVal__pragmas_1216(c, it);
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 31)) & 63);
				}
				LA243_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 76):
			{
				noVal__pragmas_1216(c, it);
				{
					if (!((*sym).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA251_;
					invalidPragma__pragmas_150(c, it);
				}
				goto LA249_;
				LA251_: ;
				{
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 2)) & 63);
				}
				LA249_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 213):
			{
				noVal__pragmas_1216(c, it);
				{
					NIM_BOOL T257_;
					T257_ = (NIM_BOOL)0;
					T257_ = ((*sym).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
					if (T257_) goto LA258_;
					T257_ = (((*(*sym).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 2))&63U)))!=0);
					LA258_: ;
					if (!T257_) goto LA259_;
					invalidPragma__pragmas_150(c, it);
				}
				goto LA255_;
				LA259_: ;
				{
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 3)) & 63);
				}
				LA255_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 187):
			{
				noVal__pragmas_1216(c, it);
				{
					if (!((*sym).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA265_;
					invalidPragma__pragmas_150(c, it);
				}
				goto LA263_;
				LA265_: ;
				{
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 4)) & 63);
				}
				LA263_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 202):
			{
				noVal__pragmas_1216(c, it);
				{
					if (!((*sym).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA271_;
					invalidPragma__pragmas_150(c, it);
				}
				goto LA269_;
				LA271_: ;
				{
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 39)) & 63);
				}
				LA269_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 203):
			{
				noVal__pragmas_1216(c, it);
				{
					if (!((*sym).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA277_;
					invalidPragma__pragmas_150(c, it);
				}
				goto LA275_;
				LA277_: ;
				{
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 6)) & 63);
				}
				LA275_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 75):
			{
				noVal__pragmas_1216(c, it);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 26)) & 63);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 19)) & 63);
				{
					if (!!(((*sym).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA283_;
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 7)) & 63);
					{
						if (!((*(*sym).typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9))) goto LA287_;
						(*(*sym).typ).callConv = ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 0);
					}
					LA287_: ;
				}
				LA283_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 110):
			{
				noVal__pragmas_1216(c, it);
				{
					if (!!((sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA292_;
					{
						if (!!(((*sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 7)))) goto LA296_;
						(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 26)) & 63);
					}
					LA296_: ;
					{
						if (!!(((*sym).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA300_;
						(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 7)) & 63);
					}
					goto LA298_;
					LA300_: ;
					{
						invalidPragma__pragmas_150(c, it);
					}
					LA298_: ;
				}
				goto LA290_;
				LA292_: ;
				{
				}
				LA290_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 270):
			{
				noVal__pragmas_1216(c, it);
				{
					if (!((*sym).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA307_;
					invalidPragma__pragmas_150(c, it);
				}
				goto LA305_;
				LA307_: ;
				{
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 23)) & 63);
				}
				LA305_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 124):
			{
				NimStringDesc* s;
				tyArray__Re75IspeoxXy2oCZHwcRrA T311_;
				s = expectStrLit__pragmas_373(c, it);
				nimZeroMem((void*)T311_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T311_[0] = copyString(((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_70));
				T311_[1] = copyString(s);
				recordPragma__pragmas_131(c, it, T311_, 2);
				liMessage__msgs_1128((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 102), s, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_71, NIM_FALSE);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 123):
			{
				NimStringDesc* s_2;
				tyArray__Re75IspeoxXy2oCZHwcRrA T313_;
				s_2 = expectStrLit__pragmas_373(c, it);
				nimZeroMem((void*)T313_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T313_[0] = copyString(((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_72));
				T313_[1] = copyString(s_2);
				recordPragma__pragmas_131(c, it, T313_, 2);
				liMessage__msgs_1128((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 71), s_2, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_73, NIM_FALSE);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 122):
			{
				{
					NIM_BOOL T317_;
					NIM_BOOL T318_;
					NIM_BOOL T320_;
					T317_ = (NIM_BOOL)0;
					T318_ = (NIM_BOOL)0;
					T318_ = !((sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
					if (!(T318_)) goto LA319_;
					T320_ = (NIM_BOOL)0;
					T320_ = isRoutine__ast_4677(sym);
					if (T320_) goto LA321_;
					T320_ = ((*sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 7));
					LA321_: ;
					T318_ = T320_;
					LA319_: ;
					T317_ = T318_;
					if (!(T317_)) goto LA322_;
					T317_ = !(isStatement);
					LA322_: ;
					if (!T317_) goto LA323_;
					{
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T329_;
						if (!((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28))) goto LA327_;
						T329_ = NIM_NIL;
						T329_ = getStrLitNode__pragmas_356(c, it);
						(void)(T329_);
					}
					LA327_: ;
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 24)) & 63);
					(*sym).flags &= ~(((NU64)1) << ((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 4)) & 63));
				}
				goto LA315_;
				LA323_: ;
				{
					NimStringDesc* s_3;
					tyArray__Re75IspeoxXy2oCZHwcRrA T331_;
					s_3 = expectStrLit__pragmas_373(c, it);
					nimZeroMem((void*)T331_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
					T331_[0] = copyString(((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_74));
					T331_[1] = copyString(s_3);
					recordPragma__pragmas_131(c, it, T331_, 2);
					liMessage__msgs_1128((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 16), s_3, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_75, NIM_FALSE);
				}
				LA315_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 121):
			{
				NimStringDesc* T333_;
				T333_ = NIM_NIL;
				T333_ = expectStrLit__pragmas_373(c, it);
				liMessage__msgs_1128((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 1), T333_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), TM__an3LHxrAv8p724x7H8KxOw_76, NIM_FALSE);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 130):
			{
				processDefine__pragmas_1034(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 131):
			{
				processUndef__pragmas_1050(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 136):
			{
				processCompile__pragmas_1075(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 135):
			{
				processLink__pragmas_1132(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 196):
			{
				NimStringDesc* s_4;
				tyArray__Re75IspeoxXy2oCZHwcRrA T339_;
				s_4 = expectStrLit__pragmas_373(c, it);
				addLinkOption__extccomp_692((*(*c).graph).config, s_4);
				nimZeroMem((void*)T339_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T339_[0] = copyString(((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_89));
				T339_[1] = copyString(s_4);
				recordPragma__pragmas_131(c, it, T339_, 2);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 195):
			{
				NimStringDesc* s_5;
				tyArray__Re75IspeoxXy2oCZHwcRrA T341_;
				s_5 = expectStrLit__pragmas_373(c, it);
				addCompileOption__extccomp_695((*(*c).graph).config, s_5);
				nimZeroMem((void*)T341_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T341_[0] = copyString(((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_90));
				T341_[1] = copyString(s_5);
				recordPragma__pragmas_131(c, it, T341_, 2);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 197):
			{
				NimStringDesc* s_6;
				NimStringDesc* T343_;
				tyArray__Re75IspeoxXy2oCZHwcRrA T344_;
				s_6 = expectStrLit__pragmas_373(c, it);
				T343_ = NIM_NIL;
				T343_ = toFullPathConsiderDirty__msgs_581((*(*c).graph).config, (*sym).info.fileIndex);
				addLocalCompileOption__extccomp_740((*(*c).graph).config, s_6, T343_);
				nimZeroMem((void*)T344_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T344_[0] = copyString(((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_91));
				T344_[1] = copyString(s_6);
				recordPragma__pragmas_131(c, it, T344_, 2);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 128):
			{
				processPush__pragmas_993(c, n, (NI)((*i) + ((NI) 1)));
				result = NIM_TRUE;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 129):
			{
				processPop__pragmas_1028(c, it);
				result = NIM_TRUE;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 192):
			{
				{
					NIM_BOOL T350_;
					T350_ = (NIM_BOOL)0;
					T350_ = !((sym == 0));
					if (!(T350_)) goto LA351_;
					T350_ = ((*sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 18));
					LA351_: ;
					if (!T350_) goto LA352_;
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 10)) & 63);
				}
				goto LA348_;
				LA352_: ;
				{
					processPragma__pragmas_1280(c, n, (*i));
					result = NIM_TRUE;
				}
				LA348_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 199):
			{
				noVal__pragmas_1216(c, it);
				{
					if (!!((sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA358_;
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 34)) & 63);
				}
				LA358_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 194):
			{
				noVal__pragmas_1216(c, it);
				{
					if (!!((sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA363_;
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 14)) & 63);
				}
				LA363_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 219):
			{
				processCodegenDecl__pragmas_403(c, it, sym);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 155):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 79):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 200):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 156):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 157):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 158):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 159):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 167):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 171):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 172):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 132):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 173):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 164):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 163):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 140):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 141):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 77):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 160):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 161):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 162):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 168):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 169):
			{
				processOption__pragmas_989(c, it, (&(*(*(*c).graph).config).options));
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 133):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 134):
			{
				{
					if (!((86016 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0)) goto LA370_;
					processOption__pragmas_989(c, it, (&(*sym).options));
				}
				goto LA368_;
				LA370_: ;
				{
					processOption__pragmas_989(c, it, (&(*(*(*c).graph).config).options));
				}
				LA368_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 142) ... ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 152):
			{
				{
					if (!((*sym).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA376_;
					invalidPragma__pragmas_150(c, it);
				}
				goto LA374_;
				LA376_: ;
				{
					(*(*sym).typ).callConv = wordToCallConv__pragmas_456(k);
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 42)) & 63);
				}
				LA374_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 215):
			{
				pragmaEmit__pragmas_1178(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 204):
			{
				pragmaUnroll__pragmas_1226(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 205):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 206):
			{
				noVal__pragmas_1216(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 178):
			{
				noVal__pragmas_1216(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 101):
			{
				noVal__pragmas_1216(c, it);
				{
					if (!((*sym).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA386_;
					invalidPragma__pragmas_150(c, it);
				}
				goto LA384_;
				LA386_: ;
				{
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 40)) & 63);
				}
				LA384_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 102):
			{
				noVal__pragmas_1216(c, it);
				{
					if (!((*sym).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA392_;
					invalidPragma__pragmas_150(c, it);
				}
				goto LA390_;
				LA392_: ;
				{
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 41)) & 63);
				}
				LA390_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 220):
			{
				noVal__pragmas_1216(c, it);
				{
					NIM_BOOL T398_;
					T398_ = (NIM_BOOL)0;
					T398_ = ((*sym).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
					if (T398_) goto LA399_;
					T398_ = !(((*(*sym).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16) || (*(*sym).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 49)));
					LA399_: ;
					if (!T398_) goto LA400_;
					invalidPragma__pragmas_150(c, it);
				}
				goto LA396_;
				LA400_: ;
				{
					(*(*sym).typ).kind = ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 49);
				}
				LA396_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 269):
			{
				{
					if (!((*(*(*c).graph).config).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 3))) goto LA406_;
					liMessage__msgs_1128((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_116), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_117, NIM_FALSE);
				}
				goto LA404_;
				LA406_: ;
				{
					noVal__pragmas_1216(c, it);
					{
						if (!((*sym).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA411_;
						invalidPragma__pragmas_150(c, it);
					}
					goto LA409_;
					LA411_: ;
					{
						(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 1)) & 63);
					}
					LA409_: ;
				}
				LA404_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 103):
			{
				noVal__pragmas_1216(c, it);
				{
					if (!((*sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19))) goto LA417_;
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 21)) & 63);
				}
				goto LA415_;
				LA417_: ;
				{
					if (!!(((*sym).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA420_;
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 19)) & 63);
				}
				goto LA415_;
				LA420_: ;
				{
					invalidPragma__pragmas_150(c, it);
				}
				LA415_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 291):
			{
				noVal__pragmas_1216(c, it);
				{
					NIM_BOOL T426_;
					T426_ = (NIM_BOOL)0;
					T426_ = (sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
					if (T426_) goto LA427_;
					T426_ = ((*sym).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
					LA427_: ;
					if (!T426_) goto LA428_;
					processOption__pragmas_989(c, it, (&(*(*(*c).graph).config).options));
				}
				goto LA424_;
				LA428_: ;
				{
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 14)) & 63);
				}
				LA424_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 290):
			{
				noVal__pragmas_1216(c, it);
				{
					NIM_BOOL T434_;
					T434_ = (NIM_BOOL)0;
					T434_ = !(((*sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 7)));
					if (T434_) goto LA435_;
					T434_ = ((*sym).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
					LA435_: ;
					if (!T434_) goto LA436_;
					invalidPragma__pragmas_150(c, it);
				}
				goto LA432_;
				LA436_: ;
				{
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 13)) & 63);
				}
				LA432_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 223):
			{
				noVal__pragmas_1216(c, it);
				{
					NIM_BOOL T442_;
					T442_ = (NIM_BOOL)0;
					T442_ = !(((*sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 7)));
					if (T442_) goto LA443_;
					T442_ = ((*sym).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
					LA443_: ;
					if (!T442_) goto LA444_;
					invalidPragma__pragmas_150(c, it);
				}
				goto LA440_;
				LA444_: ;
				{
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 16)) & 63);
				}
				LA440_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 211):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 210):
			{
				noVal__pragmas_1216(c, it);
				{
					if (!(sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA450_;
					invalidPragma__pragmas_150(c, it);
				}
				LA450_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 127):
			{
				pragmaLine__pragmas_1238(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 174):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 179):
			{
				pragmaRaisesOrTags__pragmas_1390(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 222):
			{
				{
					if (!(sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA457_;
					pragmaLockStmt__pragmas_1419(c, it);
				}
				goto LA455_;
				LA457_: ;
				{
					if (!((*sym).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA460_;
					invalidPragma__pragmas_150(c, it);
				}
				goto LA455_;
				LA460_: ;
				{
					(*(*sym).typ).lockLevel = pragmaLocks__pragmas_1447(c, it);
				}
				LA455_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 293):
			{
				{
					NIM_BOOL T466_;
					T466_ = (NIM_BOOL)0;
					T466_ = (sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
					if (T466_) goto LA467_;
					T466_ = !(((*sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19)));
					LA467_: ;
					if (!T466_) goto LA468_;
					invalidPragma__pragmas_150(c, it);
				}
				goto LA464_;
				LA468_: ;
				{
					(*sym)._kind_2.bitsize = expectIntLit__pragmas_377(c, it);
					{
						if (!((*sym)._kind_2.bitsize <= ((NI) 0))) goto LA473_;
						liMessage__msgs_1128((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_129), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_130, NIM_FALSE);
					}
					LA473_: ;
				}
				LA464_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 221):
			{
				{
					NIM_BOOL T478_;
					T478_ = (NIM_BOOL)0;
					T478_ = (sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
					if (T478_) goto LA479_;
					T478_ = !(((525056 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0));
					LA479_: ;
					if (!T478_) goto LA480_;
					invalidPragma__pragmas_150(c, it);
				}
				goto LA476_;
				LA480_: ;
				{
					asgnRef((void**) (&(*sym)._kind_2.guard), pragmaGuard__pragmas_1551(c, it, (*sym).kind));
				}
				LA476_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 243):
			{
				{
					NIM_BOOL T486_;
					T486_ = (NIM_BOOL)0;
					T486_ = (sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
					if (T486_) goto LA487_;
					T486_ = !(((768 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0));
					LA487_: ;
					if (!T486_) goto LA488_;
					invalidPragma__pragmas_150(c, it);
				}
				goto LA484_;
				LA488_: ;
				{
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 35)) & 63);
				}
				LA484_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 100):
			{
				{
					if (!(sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA494_;
					invalidPragma__pragmas_150(c, it);
				}
				goto LA492_;
				LA494_: ;
				{
					registerNimScriptSymbol__magicsys_157((*c).graph, sym);
				}
				LA492_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 207):
			{
				{
					NIM_BOOL T500_;
					T500_ = (NIM_BOOL)0;
					T500_ = isTopLevel__semdata_1121(c);
					if (!!(T500_)) goto LA501_;
					liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_131), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_132, NIM_FALSE);
				}
				LA501_: ;
				processExperimental__pragmas_883(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 208):
			{
				{
					NIM_BOOL T506_;
					T506_ = (NIM_BOOL)0;
					T506_ = isTopLevel__semdata_1121(c);
					if (!!(T506_)) goto LA507_;
					liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_133), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_134, NIM_FALSE);
				}
				LA507_: ;
				liMessage__msgs_1128((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 102), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_135), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_136, NIM_FALSE);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 262):
			{
				{
					NIM_BOOL T512_;
					NI T514_;
					T512_ = (NIM_BOOL)0;
					T512_ = ((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28));
					if (!(T512_)) goto LA513_;
					T514_ = (NI)0;
					T514_ = len__ast_3155(it);
					T512_ = (T514_ == ((NI) 2));
					LA513_: ;
					if (!T512_) goto LA515_;
					asgnRef((void**) (&(*c).selfName), considerQuotedIdent__lookups_29(c, (*it)._kind_6.sons->data[((NI) 1)], ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
					liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 21), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_137), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_138, NIM_FALSE);
				}
				goto LA510_;
				LA515_: ;
				{
					NIM_BOOL T518_;
					NI T520_;
					T518_ = (NIM_BOOL)0;
					T518_ = ((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2));
					if (T518_) goto LA519_;
					T520_ = (NI)0;
					T520_ = len__ast_3155(it);
					T518_ = (T520_ == ((NI) 1));
					LA519_: ;
					if (!T518_) goto LA521_;
					asgnRef((void**) (&(*c).selfName), getIdent__idents_152((*c).cache, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_139)));
					liMessage__msgs_1128((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 21), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_137), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_140, NIM_FALSE);
				}
				goto LA510_;
				LA521_: ;
				{
					liMessage__msgs_1128((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_141), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_142, NIM_FALSE);
				}
				LA510_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 190):
			{
				noVal__pragmas_1216(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 119):
			{
				noVal__pragmas_1216(c, it);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 20)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 80):
			{
				(*sym).magic = ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 265);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 81):
			{
				(*sym).magic = ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 266);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 82):
			{
				(*sym).magic = ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 267);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 120):
			{
				noVal__pragmas_1216(c, it);
				{
					if (!(sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA532_;
					invalidPragma__pragmas_150(c, it);
				}
				goto LA530_;
				LA532_: ;
				{
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 0)) & 63);
				}
				LA530_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 225):
			{
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 180):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 182):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 183):
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 184):
			{
				pragmaProposition__pragmas_157(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 181):
			{
				pragmaEnsures__pragmas_171(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 226):
			{
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 43)) & 63);
			}
			break;
			default:
			{
				invalidPragma__pragmas_150(c, it);
			}
			break;
			}
		}
		goto LA55_;
		LA57_: ;
		{
			NIM_BOOL T541_;
			tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw T543_;
			T541_ = (NIM_BOOL)0;
			T541_ = comesFromPush;
			if (!(T541_)) goto LA542_;
			T543_ = (tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw)0;
			T543_ = whichKeyword__idents_223(ident);
			T541_ = !((T543_ == ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 0)));
			LA542_: ;
			if (!T541_) goto LA544_;
		}
		goto LA55_;
		LA544_: ;
		{
			{
				NIM_BOOL T549_;
				T549_ = (NIM_BOOL)0;
				T549_ = (sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
				if (T549_) goto LA550_;
				T549_ = ((652168 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0);
				LA550_: ;
				if (!T549_) goto LA551_;
				asgnRef((void**) (&(*n)._kind_6.sons->data[(*i)]), semCustomPragma__pragmas_1584(c, it));
			}
			goto LA547_;
			LA551_: ;
			{
				if (!!((sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA554_;
				illegalCustomPragma__pragmas_153(c, it, sym);
			}
			goto LA547_;
			LA554_: ;
			{
				invalidPragma__pragmas_150(c, it);
			}
			LA547_: ;
		}
		LA55_: ;
	}
	LA29_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaRec__pragmas_2611)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw validPragmas, NIM_BOOL isStatement) {
	NI i;
{	{
		if (!(n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	i = ((NI) 0);
	{
		while (1) {
			NI T7_;
			T7_ = (NI)0;
			T7_ = len__ast_3155(n);
			if (!(i < T7_)) goto LA6;
			{
				NIM_BOOL T10_;
				T10_ = (NIM_BOOL)0;
				T10_ = singlePragma__pragmas_1669(c, sym, n, (&i), validPragmas, NIM_FALSE, isStatement);
				if (!T10_) goto LA11_;
				goto LA5;
			}
			LA11_: ;
			i += ((NI) 1);
		} LA6: ;
	} LA5: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, overwriteLineInfo__pragmas_2456)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	(*n).info = info;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = safeLen__ast_3148(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				overwriteLineInfo__pragmas_2456((*n)._kind_6.sons->data[i], info);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, mergePragmas__pragmas_2465)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pragmas) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pragmas_2;
	pragmas_2 = copyTree__ast_4432(pragmas);
	overwriteLineInfo__pragmas_2456(pragmas_2, (*n).info);
	{
		if (!((*(*n)._kind_6.sons->data[((NI) 4)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1))) goto LA3_;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 4)]), pragmas_2);
	}
	goto LA1_;
	LA3_: ;
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p;
			p = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(pragmas_2);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA9;
						i = i_2;
						p = (*pragmas_2)._kind_6.sons->data[i];
						add__ast_4798((*n)._kind_6.sons->data[((NI) 4)], p);
						i_2 += ((NI) 1);
					} LA9: ;
				}
			}
		}
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, implicitPragmas__pragmas_2481)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tySet_tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw validPragmas) {
	{
		NIM_BOOL T3_;
		tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* lib;
		tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q** T37_;
		T3_ = (NIM_BOOL)0;
		T3_ = !((sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = !(((*sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6)));
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q** it;
			NI i;
			NI L;
			NI T8_;
			it = (tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q**)0;
			i = ((NI) 0);
			T8_ = ((*c).optionStack ? (*c).optionStack->Sup.len : 0);
			L = T8_;
			{
				while (1) {
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* o;
					if (!(i < L)) goto LA10;
					it = &(*c).optionStack->data[i];
					o = (*(*it)).otherPragmas;
					{
						NIM_BOOL T13_;
						NI i_2;
						T13_ = (NIM_BOOL)0;
						T13_ = !((o == 0));
						if (!(T13_)) goto LA14_;
						T13_ = !((((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 2))&63U)))!=0));
						LA14_: ;
						if (!T13_) goto LA15_;
						pushInfoContext__msgs_500((*(*c).graph).config, info, ((NimStringDesc*) NIM_NIL));
						i_2 = ((NI) 0);
						{
							while (1) {
								NI T19_;
								T19_ = (NI)0;
								T19_ = len__ast_3155(o);
								if (!(i_2 < T19_)) goto LA18;
								{
									NIM_BOOL T22_;
									T22_ = (NIM_BOOL)0;
									T22_ = singlePragma__pragmas_1669(c, sym, o, (&i_2), validPragmas, NIM_TRUE, NIM_FALSE);
									if (!T22_) goto LA23_;
									internalErrorImpl__msgs_1441((*(*c).graph).config, info, ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_150), TM__an3LHxrAv8p724x7H8KxOw_151);
								}
								LA23_: ;
								i_2 += ((NI) 1);
							} LA18: ;
						}
						popInfoContext__msgs_517((*(*c).graph).config);
						{
							NIM_BOOL T27_;
							T27_ = (NIM_BOOL)0;
							T27_ = ((520192 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0);
							if (!(T27_)) goto LA28_;
							T27_ = !(((*sym).ast == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
							LA28_: ;
							if (!T27_) goto LA29_;
							mergePragmas__pragmas_2465((*sym).ast, o);
						}
						LA29_: ;
					}
					LA15_: ;
					i += ((NI) 1);
				} LA10: ;
			}
		}
		{
			NIM_BOOL T33_;
			T33_ = (NIM_BOOL)0;
			T33_ = (((*sym).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 5))&15U)))!=0);
			if (!(T33_)) goto LA34_;
			T33_ = !((((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 7))&63U)))!=0));
			LA34_: ;
			if (!T33_) goto LA35_;
			liMessage__msgs_1128((*(*c).graph).config, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__an3LHxrAv8p724x7H8KxOw_152), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__an3LHxrAv8p724x7H8KxOw_153, NIM_FALSE);
		}
		LA35_: ;
		T37_ = (tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q**)0;
		T37_ = X5BX5D___semdata_356(((*c).optionStack) ? ((*c).optionStack->data) : NIM_NIL, ((*c).optionStack ? (*c).optionStack->Sup.len : 0), ((NI) 1));
		lib = (*(*T37_)).dynlib;
		{
			NIM_BOOL T40_;
			NIM_BOOL T41_;
			T40_ = (NIM_BOOL)0;
			T41_ = (NIM_BOOL)0;
			T41_ = ((80 & (*sym).loc.flags) == 0);
			if (!(T41_)) goto LA42_;
			T41_ = (((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 6))&63U)))!=0);
			LA42_: ;
			T40_ = T41_;
			if (!(T40_)) goto LA43_;
			T40_ = !((lib == ((tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg*) NIM_NIL)));
			LA43_: ;
			if (!T40_) goto LA44_;
			(*sym).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw) 4)) & 15);
			addToLib__semdata_760(lib, sym);
			{
				if (!((*sym).loc.r == ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL))) goto LA48_;
				asgnRef((void**) (&(*sym).loc.r), rope__ropes_109((*(*sym).name).s));
			}
			LA48_: ;
		}
		LA44_: ;
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, pragma__pragmas_125)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw validPragmas, NIM_BOOL isStatement) {
{	{
		if (!(n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	pragmaRec__pragmas_2611(c, sym, n, validPragmas, isStatement);
	implicitPragmas__pragmas_2481(c, sym, (*n).info, validPragmas);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasPragma__pragmas_2585)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw pragma) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		if (!(n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA3_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p;
		p = NIM_NIL;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* key;
					if (!(i_2 < colontmp_)) goto LA8;
					i = i_2;
					p = (*n)._kind_6.sons->data[i];
					{
						NIM_BOOL T11_;
						NI T13_;
						T11_ = (NIM_BOOL)0;
						T11_ = ((*p).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*p).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*p).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28));
						if (!(T11_)) goto LA12_;
						T13_ = (NI)0;
						T13_ = len__ast_3155(p);
						T11_ = (((NI) 1) < T13_);
						LA12_: ;
						if (!T11_) goto LA14_;
						key = (*p)._kind_6.sons->data[((NI) 0)];
					}
					goto LA9_;
					LA14_: ;
					{
						key = p;
					}
					LA9_: ;
					{
						NIM_BOOL T19_;
						tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw T21_;
						T19_ = (NIM_BOOL)0;
						T19_ = ((*key).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2));
						if (!(T19_)) goto LA20_;
						T21_ = (tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw)0;
						T21_ = whichKeyword__idents_223((*key)._kind_5.ident);
						T19_ = (T21_ == pragma);
						LA20_: ;
						if (!T19_) goto LA22_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA22_: ;
					i_2 += ((NI) 1);
				} LA8: ;
			}
		}
	}
	result = NIM_FALSE;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaCallable__pragmas_2639)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw validPragmas, NIM_BOOL isStatement) {
{	{
		if (!(n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		if (!!(((*(*n)._kind_6.sons->data[((NI) 4)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)))) goto LA7_;
		pragmaRec__pragmas_2611(c, sym, (*n)._kind_6.sons->data[((NI) 4)], validPragmas, isStatement);
	}
	LA7_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_CHAR, pragmaAsm__pragmas_203)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_CHAR result;
	result = (NIM_CHAR)0;
	result = 0;
	{
		if (!!((n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA3_;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
					if (!(i_2 < colontmp_)) goto LA7;
					i = i_2;
					it = (*n)._kind_6.sons->data[i];
					{
						NIM_BOOL T10_;
						NIM_BOOL T11_;
						NI T13_;
						tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw T17_;
						T10_ = (NIM_BOOL)0;
						T11_ = (NIM_BOOL)0;
						T11_ = ((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28));
						if (!(T11_)) goto LA12_;
						T13_ = (NI)0;
						T13_ = len__ast_3155(it);
						T11_ = (T13_ == ((NI) 2));
						LA12_: ;
						T10_ = T11_;
						if (!(T10_)) goto LA14_;
						T10_ = ((*(*it)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2));
						LA14_: ;
						if (!T10_) goto LA15_;
						T17_ = (tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw)0;
						T17_ = whichKeyword__idents_223((*(*it)._kind_6.sons->data[((NI) 0)])._kind_5.ident);
						switch (T17_) {
						case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 201):
						{
							{
								if (!((*(*it)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5))) goto LA21_;
								result = ((NIM_CHAR) (((NI) (((NI) ((*(*it)._kind_6.sons->data[((NI) 1)])._kind_1.intVal))))));
							}
							goto LA19_;
							LA21_: ;
							{
								invalidPragma__pragmas_150(c, it);
							}
							LA19_: ;
						}
						break;
						default:
						{
							invalidPragma__pragmas_150(c, it);
						}
						break;
						}
					}
					goto LA8_;
					LA15_: ;
					{
						invalidPragma__pragmas_150(c, it);
					}
					LA8_: ;
					i_2 += ((NI) 1);
				} LA7: ;
			}
		}
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, atmpragmasdotnim_DatInit000)(void) {
static TNimNode* TM__an3LHxrAv8p724x7H8KxOw_38_2[2];
static TNimNode* TM__an3LHxrAv8p724x7H8KxOw_78_2[2];
static TNimNode TM__an3LHxrAv8p724x7H8KxOw_0[6];
NTIobject__F9btrMvLhz9bF8kBdjzuAcww_.size = sizeof(tyObject_Env_pragmasdotnim_processEffectsOf___F9btrMvLhz9bF8kBdjzuAcww);
NTIobject__F9btrMvLhz9bF8kBdjzuAcww_.align = NIM_ALIGNOF(tyObject_Env_pragmasdotnim_processEffectsOf___F9btrMvLhz9bF8kBdjzuAcww);
NTIobject__F9btrMvLhz9bF8kBdjzuAcww_.kind = 17;
NTIobject__F9btrMvLhz9bF8kBdjzuAcww_.base = (&NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_);
TM__an3LHxrAv8p724x7H8KxOw_38_2[0] = &TM__an3LHxrAv8p724x7H8KxOw_0[1];
TM__an3LHxrAv8p724x7H8KxOw_0[1].kind = 1;
TM__an3LHxrAv8p724x7H8KxOw_0[1].offset = offsetof(tyObject_Env_pragmasdotnim_processEffectsOf___F9btrMvLhz9bF8kBdjzuAcww, colonstate_);
TM__an3LHxrAv8p724x7H8KxOw_0[1].typ = (&NTIint__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__an3LHxrAv8p724x7H8KxOw_0[1].name = ":state";
TM__an3LHxrAv8p724x7H8KxOw_38_2[1] = &TM__an3LHxrAv8p724x7H8KxOw_0[2];
TM__an3LHxrAv8p724x7H8KxOw_0[2].kind = 1;
TM__an3LHxrAv8p724x7H8KxOw_0[2].offset = offsetof(tyObject_Env_pragmasdotnim_processEffectsOf___F9btrMvLhz9bF8kBdjzuAcww, owner1);
TM__an3LHxrAv8p724x7H8KxOw_0[2].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__an3LHxrAv8p724x7H8KxOw_0[2].name = "owner1";
TM__an3LHxrAv8p724x7H8KxOw_0[0].len = 2; TM__an3LHxrAv8p724x7H8KxOw_0[0].kind = 2; TM__an3LHxrAv8p724x7H8KxOw_0[0].sons = &TM__an3LHxrAv8p724x7H8KxOw_38_2[0];
NTIobject__F9btrMvLhz9bF8kBdjzuAcww_.node = &TM__an3LHxrAv8p724x7H8KxOw_0[0];
NTIrefobject__Njrz9auiUyrJUnAKd5dk8Gw_.size = sizeof(tyObject_Env_pragmasdotnim_processEffectsOf___F9btrMvLhz9bF8kBdjzuAcww*);
NTIrefobject__Njrz9auiUyrJUnAKd5dk8Gw_.align = NIM_ALIGNOF(tyObject_Env_pragmasdotnim_processEffectsOf___F9btrMvLhz9bF8kBdjzuAcww*);
NTIrefobject__Njrz9auiUyrJUnAKd5dk8Gw_.kind = 22;
NTIrefobject__Njrz9auiUyrJUnAKd5dk8Gw_.base = (&NTIobject__F9btrMvLhz9bF8kBdjzuAcww_);
NTIrefobject__Njrz9auiUyrJUnAKd5dk8Gw_.marker = Marker_tyRef__Njrz9auiUyrJUnAKd5dk8Gw;
NTIobject__K1pKiI8SQrNLP9ccgE49bWPQ_.size = sizeof(tyObject_Env_pragmasdotnim_processCompile___K1pKiI8SQrNLP9ccgE49bWPQ);
NTIobject__K1pKiI8SQrNLP9ccgE49bWPQ_.align = NIM_ALIGNOF(tyObject_Env_pragmasdotnim_processCompile___K1pKiI8SQrNLP9ccgE49bWPQ);
NTIobject__K1pKiI8SQrNLP9ccgE49bWPQ_.kind = 17;
NTIobject__K1pKiI8SQrNLP9ccgE49bWPQ_.base = (&NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_);
TM__an3LHxrAv8p724x7H8KxOw_78_2[0] = &TM__an3LHxrAv8p724x7H8KxOw_0[4];
TM__an3LHxrAv8p724x7H8KxOw_0[4].kind = 1;
TM__an3LHxrAv8p724x7H8KxOw_0[4].offset = offsetof(tyObject_Env_pragmasdotnim_processCompile___K1pKiI8SQrNLP9ccgE49bWPQ, colonstate_);
TM__an3LHxrAv8p724x7H8KxOw_0[4].typ = (&NTIint__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__an3LHxrAv8p724x7H8KxOw_0[4].name = ":state";
TM__an3LHxrAv8p724x7H8KxOw_78_2[1] = &TM__an3LHxrAv8p724x7H8KxOw_0[5];
TM__an3LHxrAv8p724x7H8KxOw_0[5].kind = 1;
TM__an3LHxrAv8p724x7H8KxOw_0[5].offset = offsetof(tyObject_Env_pragmasdotnim_processCompile___K1pKiI8SQrNLP9ccgE49bWPQ, n1);
TM__an3LHxrAv8p724x7H8KxOw_0[5].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__an3LHxrAv8p724x7H8KxOw_0[5].name = "n1";
TM__an3LHxrAv8p724x7H8KxOw_0[3].len = 2; TM__an3LHxrAv8p724x7H8KxOw_0[3].kind = 2; TM__an3LHxrAv8p724x7H8KxOw_0[3].sons = &TM__an3LHxrAv8p724x7H8KxOw_78_2[0];
NTIobject__K1pKiI8SQrNLP9ccgE49bWPQ_.node = &TM__an3LHxrAv8p724x7H8KxOw_0[3];
NTIrefobject__a9aYNs9bZrafnBGGjcbxGzNQ_.size = sizeof(tyObject_Env_pragmasdotnim_processCompile___K1pKiI8SQrNLP9ccgE49bWPQ*);
NTIrefobject__a9aYNs9bZrafnBGGjcbxGzNQ_.align = NIM_ALIGNOF(tyObject_Env_pragmasdotnim_processCompile___K1pKiI8SQrNLP9ccgE49bWPQ*);
NTIrefobject__a9aYNs9bZrafnBGGjcbxGzNQ_.kind = 22;
NTIrefobject__a9aYNs9bZrafnBGGjcbxGzNQ_.base = (&NTIobject__K1pKiI8SQrNLP9ccgE49bWPQ_);
NTIrefobject__a9aYNs9bZrafnBGGjcbxGzNQ_.marker = Marker_tyRef__a9aYNs9bZrafnBGGjcbxGzNQ;
}

