/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw;
typedef struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ;
typedef struct tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA;
typedef struct tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA;
typedef struct tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw;
typedef struct tySequence__ed0C0uAUZPhvw3RAc5hfYg tySequence__ed0C0uAUZPhvw3RAc5hfYg;
typedef struct tySequence__vvBerF0axaNtu9aMA2gnsrA tySequence__vvBerF0axaNtu9aMA2gnsrA;
typedef struct tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ;
typedef struct tySequence__ZQPym9bf1jM5qaSn7LUXMKA tySequence__ZQPym9bf1jM5qaSn7LUXMKA;
typedef struct tySequence__9c3OY0aBmSBgwdsnBAPf4Ag tySequence__9c3OY0aBmSBgwdsnBAPf4Ag;
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw;
typedef struct tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ;
typedef struct tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tySequence__Jhh6ks9carRtwV9aOuM8yMNw tySequence__Jhh6ks9carRtwV9aOuM8yMNw;
typedef struct tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw tySequence__Bis5AbpONWcIRrPyPJS8Yw;
typedef struct tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg;
typedef struct tySequence__E8pi9b5QNahsURYzXMjh3qw tySequence__E8pi9b5QNahsURYzXMjh3qw;
typedef struct tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg;
typedef struct tySequence__XDpbjnuseLNZDGLBQ2Qzow tySequence__XDpbjnuseLNZDGLBQ2Qzow;
typedef struct tyObject_Table__cBohObSCAwRxvYFXQHv2wA tyObject_Table__cBohObSCAwRxvYFXQHv2wA;
typedef struct tySequence__QqvaCqCpEE1QmQZbcZLi5A tySequence__QqvaCqCpEE1QmQZbcZLi5A;
typedef struct tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg;
typedef struct tySequence__cvxuM2UjDv0O3Q6FcDEAnw tySequence__cvxuM2UjDv0O3Q6FcDEAnw;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyTuple__2E9aYKv1U4zUZsR6wkNRkPg tyTuple__2E9aYKv1U4zUZsR6wkNRkPg;
typedef struct tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tyTuple__JfHvHzMrhKkWAUvQKe0i1A tyTuple__JfHvHzMrhKkWAUvQKe0i1A;
typedef struct tyObject_Env_semdatadotnim_TContext___diB2NTuAIWY0FO9c5IUJRGg tyObject_Env_semdatadotnim_TContext___diB2NTuAIWY0FO9c5IUJRGg;
typedef struct tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w;
typedef struct tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA;
typedef struct tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg;
typedef struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ tyTuple__NAaJgGVgNmlGoqmiWxdOHQ;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct tyTuple__VbApVidEWCFLq9a29bPtaS7A tyTuple__VbApVidEWCFLq9a29bPtaS7A;
typedef struct tySequence__k7EQb9bN3Uhl608xoPGMRJA tySequence__k7EQb9bN3Uhl608xoPGMRJA;
typedef struct tyTuple__toqrUPSdp8zSxOdlxMJj9cA tyTuple__toqrUPSdp8zSxOdlxMJj9cA;
typedef struct tyTuple__EbsafWGli8bW2GRJQ9apsjA tyTuple__EbsafWGli8bW2GRJQ9apsjA;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tySequence__RNhZxf20g9beyq5VBOGxhDg tySequence__RNhZxf20g9beyq5VBOGxhDg;
typedef struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ;
typedef struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ tySequence__lFbCtu5P2Kf7YDYtGjkxAQ;
typedef struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA;
typedef struct tySequence__ijtae5OneaLys0hN9alAicA tySequence__ijtae5OneaLys0hN9alAicA;
typedef struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w;
typedef struct tySequence__SerjNoUujW2dUouVBrJiCw tySequence__SerjNoUujW2dUouVBrJiCw;
typedef struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyObject_Table__r0v8BdcBPKhl73K8p2VMUA;
typedef struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g tySequence__K9agbtcb0qPZuSJFXB9cTe6g;
typedef struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg;
typedef struct tySequence__m88qdML9cQOuqGAQn6XWL1A tySequence__m88qdML9cQOuqGAQn6XWL1A;
typedef struct tyObject_Table__1hIWbTQWYT4BmhdESze57A tyObject_Table__1hIWbTQWYT4BmhdESze57A;
typedef struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ tySequence__naEbXEp9b9aiW1zXJorqf9cXQ;
typedef struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA;
typedef struct tyObject_Table__imojfg883tkWsWJwyshGqQ tyObject_Table__imojfg883tkWsWJwyshGqQ;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg tyObject_Table__BCPh85PHtwxox9bv7NLFrlg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA;
typedef struct tySequence__KgiZ29chkJAD01p9aLRB32qw tySequence__KgiZ29chkJAD01p9aLRB32qw;
typedef struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A tyObject_Table__LM44poVdVEn4Mo4N4L8c3A;
typedef struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw tySequence__rkYRZrbHVYL3nhXlQW3K9bw;
typedef struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ tySequence__IRFEb1e9bxgbJLuB5xrdZsQ;
typedef struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ;
typedef struct tySequence__YmPd0eWfcTfrVYrthlXPYA tySequence__YmPd0eWfcTfrVYrthlXPYA;
typedef struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q;
typedef struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg tySequence__Hz5SYwQU29b9aFLt09blvVQPg;
typedef struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg tyObject_Table__R7JnJQEipxxOlJWXQz7jWg;
typedef struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ tySequence__3G9aA9cLXaPxuRxMKm3anacQ;
typedef struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q tySequence__bPFv6ypvvCX2A9a9al8utL2Q;
typedef struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg;
typedef struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg;
typedef struct tySequence__4Murtwnm0Fyc7F9acrytEXw tySequence__4Murtwnm0Fyc7F9acrytEXw;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw;
typedef struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg tySequence__QnmOtn1Iv4LvxOXoMn8Rbg;
typedef struct tySequence__oKtVqsc9bQVCNyrijELM4OQ tySequence__oKtVqsc9bQVCNyrijELM4OQ;
typedef struct tySequence__qy6Iwdy00wN560qud54HTg tySequence__qy6Iwdy00wN560qud54HTg;
typedef struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ tySequence__k67v9bwvvQDmS1ynyGGUbeQ;
typedef struct tySequence__cLsClAAfd0MKkoBQVyvdvw tySequence__cLsClAAfd0MKkoBQVyvdvw;
typedef struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg tySequence__q9bTuOB0JXh1iZ3CSGdRLbg;
typedef struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw;
typedef struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ;
typedef struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ;
typedef struct tySequence__C3r8jsj9chA4sIlYfDN5aDw tySequence__C3r8jsj9chA4sIlYfDN5aDw;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tySequence__dlD6tEGzYLLpKVq3XwuFlA tySequence__dlD6tEGzYLLpKVq3XwuFlA;
typedef struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ;
typedef struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg;
typedef struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ;
typedef struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ;
typedef struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tySequence__6OFCSvqRaxyEgUqWtnZSlw tySequence__6OFCSvqRaxyEgUqWtnZSlw;
typedef struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q;
typedef struct tySequence__UnGSk9aaLosDroi2QDrlOfQ tySequence__UnGSk9aaLosDroi2QDrlOfQ;
typedef struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg;
typedef struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ;
typedef struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g tySequence__qeAsXh2i1GAL5Nl0g3OP8g;
typedef struct tySequence__ztPIC2M9bqhs0KjYuE9c9cN8g tySequence__ztPIC2M9bqhs0KjYuE9c9cN8g;
typedef struct tyTuple__0y4YQo9b9byJ83c0H89bBtdRw tyTuple__0y4YQo9b9byJ83c0H89bBtdRw;
typedef struct tySequence__YdLNCDKYeipzJx3I8Xw82Q tySequence__YdLNCDKYeipzJx3I8Xw82Q;
typedef struct tySequence__Gl8s23LA3EFz4kIlya9ameg tySequence__Gl8s23LA3EFz4kIlya9ameg;
typedef struct tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw;
typedef struct tySequence__eJWcQvhuN2q0rM6THoByqQ tySequence__eJWcQvhuN2q0rM6THoByqQ;
typedef struct tyObject_Profiler__vPk6nUD8QeNW2bHH4WZfpw tyObject_Profiler__vPk6nUD8QeNW2bHH4WZfpw;
typedef struct tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ;
typedef struct tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
typedef struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg tyTuple__UluY8x0Nj6cp9b0o88wJ0lg;
typedef struct tyTuple__rZZA0skon1OsHdiEvT8RZQ tyTuple__rZZA0skon1OsHdiEvT8RZQ;
typedef struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA tyTuple__q13Zt16VkCqu6Zg5jWqwHA;
typedef struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA tyTuple__aWN9bNzF9bubXNJV9ciomgpfA;
typedef struct tySequence__m4PVWjcAAjfxlwJxLkKn8A tySequence__m4PVWjcAAjfxlwJxLkKn8A;
typedef struct tyTuple__RWXAsQlFoGYyEQZp1G65sg tyTuple__RWXAsQlFoGYyEQZp1G65sg;
typedef struct tyTuple__RmGJuqOgEaHckHndh0LEsw tyTuple__RmGJuqOgEaHckHndh0LEsw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__J4cxakKjhKxTIJR9bojMmXw tyTuple__J4cxakKjhKxTIJR9bojMmXw;
typedef struct tySequence__i89c5kdtWKzK3OEiI81pkkw tySequence__i89c5kdtWKzK3OEiI81pkkw;
typedef struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A;
typedef struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ;
typedef struct tySequence__GR8qmV1kNRcoQ2g76VFy3A tySequence__GR8qmV1kNRcoQ2g76VFy3A;
typedef struct tyTuple__a7QginWFapakKbWJBJ2vfA tyTuple__a7QginWFapakKbWJBJ2vfA;
typedef struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__kbX6x85REySUrk9auORL0vw tyTuple__kbX6x85REySUrk9auORL0vw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g;
typedef struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q;
typedef struct tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A;
typedef struct tyTuple__nF9cH4hinXgGEUwO4G2bshw tyTuple__nF9cH4hinXgGEUwO4G2bshw;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA;
typedef struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__PsEhl3dzznmmJiLAuIXZOg tyTuple__PsEhl3dzznmmJiLAuIXZOg;
typedef struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w;
typedef struct tyTuple__Db8CrQifKGIsKc3w71w7Lw tyTuple__Db8CrQifKGIsKc3w71w7Lw;
typedef struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg;
typedef struct tySequence__lo3S1lKyiPLhGGB9cBawd6A tySequence__lo3S1lKyiPLhGGB9cBawd6A;
typedef struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ;
typedef struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw tyTuple__FEYH9alRJhHD0uTKF2vnIqw;
typedef struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA;
typedef struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA;
typedef struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw;
typedef struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg tyTuple__VUJ5Hjm4tKAResBsRHJvYg;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef struct tyTuple__5pg9aIYdyrJM6GlDgyTDumg tyTuple__5pg9aIYdyrJM6GlDgyTDumg;
typedef struct tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA;
typedef struct tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA;
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw {
  RootObj Sup;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__aaEwD7wUZoIxDUprFEbfMQ[38];
struct tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ {
NI counter;
tySequence__ZQPym9bf1jM5qaSn7LUXMKA* data;
};
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__q9caIJqxIEVMlKzDKc7PN3A) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* expectedType);
typedef NU32 tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__Kiet6YwcQwPvcQYHHEqqqQ) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* expectedType);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__PSlVV9bxpH9avY5YrjCD5uqA) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__8k9afYvvfaH1tjWAwlISb0A) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, void* ClE_0);
void* ClE_0;
} tyProc__9bnYcX9avusKBraL3FJXBwJw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__uojbiMfaKLMuGW9bbomtTBg) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
typedef NU32 tySet_tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__bqRyngJC8bSPcUqqn9bn73w) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nOrig, tySet_tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw filter, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags);
typedef N_NIMCALL_PTR(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, tyProc__F6LocU8y66ng5Ra4XoVWJA) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* prev);
typedef struct {
N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, void* ClE_0);
void* ClE_0;
} tyProc__Nc9aAsBDTkr61wP9a9cnds8Og;
typedef struct {
N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fn, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, void* ClE_0);
void* ClE_0;
} tyProc__z8FaSv6eEIc72FZ9c9cBcaGg;
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw {
NI counter;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* data;
};
typedef NU8 tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ;
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__9aa59awckKpa9areOQSBOwSeQ) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* dc, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ op, NI col);
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
struct tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ {
tySequence__Bis5AbpONWcIRrPyPJS8Yw* data;
NI counter;
};
struct tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg {
tySequence__E8pi9b5QNahsURYzXMjh3qw* data;
NI counter;
};
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
struct tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg {
tySequence__XDpbjnuseLNZDGLBQ2Qzow* data;
NI counter;
};
struct tyObject_Table__cBohObSCAwRxvYFXQHv2wA {
tySequence__QqvaCqCpEE1QmQZbcZLi5A* data;
NI counter;
};
struct tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw {
  tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw Sup;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* enforceVoidContext;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* voidType;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* currentScope;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* moduleScope;
tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA* imports;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* topLevelScope;
tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA* p;
tyArray__aaEwD7wUZoIxDUprFEbfMQ intTypeCache;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* nilTypeCache;
tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw* matchedConcept;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* friendModules;
NI instCounter;
NI* templInstCounter;
NI inGenericContext;
NI inStaticContext;
NI inUnrolledContext;
NI compilesContextId;
NI compilesContextIdGenerator;
NI inGenericInst;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* converters;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* patterns;
tySequence__vvBerF0axaNtu9aMA2gnsrA* optionStack;
tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ symMapping;
tySequence__9c3OY0aBmSBgwdsnBAPf4Ag* libs;
tyProc__q9caIJqxIEVMlKzDKc7PN3A semConstExpr;
tyProc__Kiet6YwcQwPvcQYHHEqqqQ semExpr;
tyProc__PSlVV9bxpH9avY5YrjCD5uqA semTryExpr;
tyProc__q9caIJqxIEVMlKzDKc7PN3A semTryConstExpr;
tyProc__8k9afYvvfaH1tjWAwlISb0A computeRequiresInit;
tyProc__9bnYcX9avusKBraL3FJXBwJw hasUnresolvedArgs;
tyProc__PSlVV9bxpH9avY5YrjCD5uqA semOperand;
tyProc__uojbiMfaKLMuGW9bbomtTBg semConstBoolExpr;
tyProc__bqRyngJC8bSPcUqqn9bn73w semOverloadedCall;
tyProc__F6LocU8y66ng5Ra4XoVWJA semTypeNode;
tyProc__Nc9aAsBDTkr61wP9a9cnds8Og semInferredLambda;
tyProc__z8FaSv6eEIc72FZ9c9cBcaGg semGenerateInstance;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw includedFiles;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw pureEnumFields;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw userPragmas;
tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ* evalContext;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw unknownIdents;
tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ* generics;
NI topStmts;
NI lastGenericIdx;
NI hloLoopDetector;
NI inParallelStmt;
tyProc__9aa59awckKpa9areOQSBOwSeQ instTypeBoundOp;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* selfName;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw signatures;
NimStringDesc* recursiveDep;
NIM_BOOL suggestionsMade;
NIM_BOOL isAmbiguous;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
NI inTypeContext;
NI inConceptDecl;
tySequence__Jhh6ks9carRtwV9aOuM8yMNw* unusedImports;
tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ exportIndirections;
tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg importModuleMap;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastTLineInfo;
tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg sideEffects;
NI inUncheckedAssignSection;
tyObject_Table__cBohObSCAwRxvYFXQHv2wA importModuleLookup;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ;
struct tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m;
tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ mode;
union{
struct {tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw imported;
} _mode_2;
struct {tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw exceptSet;
} _mode_3;
};
};
struct tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* resultSym;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* selfSym;
NI nestedLoopCounter;
NI nestedBlockCounter;
tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA* next;
NIM_BOOL mappingExists;
tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ mapping;
tySequence__cvxuM2UjDv0O3Q6FcDEAnw* caseContext;
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* localBindStmts;
};
struct tyTuple__2E9aYKv1U4zUZsR6wkNRkPg {
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field0;
NI Field1;
};
struct tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* candidateType;
tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw* prev;
NI depth;
};
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
struct tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q {
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg defaultCC;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* dynlib;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* otherPragmas;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
};
struct tyTuple__JfHvHzMrhKkWAUvQKe0i1A {
void* Field0;
tyObject_Env_semdatadotnim_TContext___diB2NTuAIWY0FO9c5IUJRGg* Field1;
};
struct tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* genericSym;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field0;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field1;
};
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
NI Field0;
NI Field1;
};
struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ {
NI Field0;
tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ Field1;
};
struct tyTuple__toqrUPSdp8zSxOdlxMJj9cA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
struct tyTuple__VbApVidEWCFLq9a29bPtaS7A {
NI Field0;
NI Field1;
tySequence__k7EQb9bN3Uhl608xoPGMRJA* Field2;
};
struct tyTuple__EbsafWGli8bW2GRJQ9apsjA {
NI Field0;
NI Field1;
tySequence__qwqHTkRvwhrRyENtudHQ7g* Field2;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
typedef NU8 tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ;
struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg {
tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* name;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* path;
};
struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA {
tySequence__ijtae5OneaLys0hN9alAicA* data;
NI counter;
};
struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w {
tySequence__SerjNoUujW2dUouVBrJiCw* data;
NI counter;
};
struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA {
tySequence__K9agbtcb0qPZuSJFXB9cTe6g* data;
NI counter;
};
typedef tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyArray__46hjIasL27aUz9c7kgtWooQ[5];
struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg {
tySequence__m88qdML9cQOuqGAQn6XWL1A* data;
NI counter;
};
struct tyObject_Table__1hIWbTQWYT4BmhdESze57A {
tySequence__naEbXEp9b9aiW1zXJorqf9cXQ* data;
NI counter;
};
struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
};
struct tyObject_Table__imojfg883tkWsWJwyshGqQ {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA {
tySequence__KgiZ29chkJAD01p9aLRB32qw* data;
NI counter;
};
struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A {
tySequence__rkYRZrbHVYL3nhXlQW3K9bw* data;
NI counter;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg[65];
struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ {
tySequence__YmPd0eWfcTfrVYrthlXPYA* data;
NI counter;
};
struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__I6rzVhdiYtUh7jwWJQoeyw) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__EQOAUyRkp9c3eeiGlHvCThA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q {
tySequence__Hz5SYwQU29b9aFLt09blvVQPg* data;
NI counter;
};
struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg {
tySequence__3G9aA9cLXaPxuRxMKm3anacQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__1CO5eEh25fBKUWGagpikwg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
typedef N_NIMCALL_PTR(void, tyProc__VcUg5jOhttLagdxUmVN8Tg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__XOkru1xuh2bHzmkw1UYzLA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formal, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* actual);
struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opNot;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opContains;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLe;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLt;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAnd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opOr;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opIsNil;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opEq;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAdd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opSub;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opMul;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opDiv;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg {
tySequence__RNhZxf20g9beyq5VBOGxhDg* ifaces;
tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* packed_0;
tySequence__lFbCtu5P2Kf7YDYtGjkxAQ* encoders;
tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA typeInstCache;
tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w procInstCache;
tyArray__46hjIasL27aUz9c7kgtWooQ attachedOps;
tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg methodsPerType;
tyObject_Table__1hIWbTQWYT4BmhdESze57A enumToStringProcs;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw emittedTypeInfo;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA startupPackedConfig;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw deps;
tyObject_Table__imojfg883tkWsWJwyshGqQ importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__BCPh85PHtwxox9bv7NLFrlg inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* usageSym;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* owners;
tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA suggestSymbols;
tyObject_Table__LM44poVdVEn4Mo4N4L8c3A suggestErrors;
tySequence__IRFEb1e9bxgbJLuB5xrdZsQ* methods;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* systemModule;
tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg sysTypes;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw compilerprocs;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw exposed;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageTypes;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* emptyNode;
tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ canonTypes;
tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw symBodyHashes;
tyProc__I6rzVhdiYtUh7jwWJQoeyw importModuleCallback;
tyProc__EQOAUyRkp9c3eeiGlHvCThA includeFileCallback;
tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q cacheSeqs;
tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g cacheCounters;
tyObject_Table__R7JnJQEipxxOlJWXQz7jWg cacheTables;
tySequence__bPFv6ypvvCX2A9a9al8utL2Q* passes;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinition;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinitionResolveForward;
tyProc__1CO5eEh25fBKUWGagpikwg onUsage;
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* globalDestructors;
tyProc__VcUg5jOhttLagdxUmVN8Tg strongSemCheck;
tyProc__XOkru1xuh2bHzmkw1UYzLA compatibleProps;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg operators;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
typedef tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* tyArray__1iN2CWX9bK5w9bRjT9chFAABA[8192];
struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ {
tyArray__1iN2CWX9bK5w9bRjT9chFAABA buckets;
NI wordCounter;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* idAnon;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* idDelegator;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* emptyIdent;
};
typedef NU8 tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg;
struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg {
tySequence__4Murtwnm0Fyc7F9acrytEXw* nodes;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ;
struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ {
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw {
tySequence__IHUFRsFxZNv7YydiUO2esQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag {
NimStringDesc* definedSymbols;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA moduleFlags;
tySequence__PXIzfWocnrafGz5p3CP5LA* includes;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* imports;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg toReplay;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg topLevel;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg bodies;
tySequence__b89aLriiJnVTD186H6zNIgg* exports;
tySequence__b89aLriiJnVTD186H6zNIgg* hidden;
tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw* reexports;
tySequence__b89aLriiJnVTD186H6zNIgg* compilerProcs;
tySequence__48JTohSgTy339bRxHzUD8KA* converters;
tySequence__48JTohSgTy339bRxHzUD8KA* methods;
tySequence__48JTohSgTy339bRxHzUD8KA* trmacros;
tySequence__48JTohSgTy339bRxHzUD8KA* pureEnums;
tySequence__QnmOtn1Iv4LvxOXoMn8Rbg* macroUsages;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* typeInstCache;
tySequence__qy6Iwdy00wN560qud54HTg* procInstCache;
tySequence__k67v9bwvvQDmS1ynyGGUbeQ* attachedOps;
tySequence__cLsClAAfd0MKkoBQVyvdvw* methodsPerType;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* enumToStringProcs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* emittedTypeInfo;
tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ backendFlags;
tySequence__q9bTuOB0JXh1iZ3CSGdRLbg* syms;
tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw* types;
tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ strings;
tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw numbers;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA cfg;
};
struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ {
tySequence__C3r8jsj9chA4sIlYfDN5aDw* data;
NI counter;
};
struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg {
tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg status;
NIM_BOOL symsInit;
NIM_BOOL typesInit;
NIM_BOOL loadedButAliveSetChanged;
tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag fromDisk;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* syms;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* types;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ iface;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ ifaceHidden;
};
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
typedef NU16 tySet_tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA;
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInst;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg uniqueId;
};
struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg {
NI32 module;
NI32 symId;
NI32 typeId_0;
NIM_BOOL sealed;
};
typedef NU8 tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ {
NU32 module;
NI32 item;
};
struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg {
NI module;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ packed_0;
};
struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
};
struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ {
tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* data;
NI counter;
};
struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ {
NI32 thisModule;
NI32 lastFile;
NU32 lastLit;
tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ filenames;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* pendingTypes;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* pendingSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw typeMarker;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw symMarker;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
};
typedef NU8 tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q {
NI module;
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg sym;
tySequence__UnGSk9aaLosDroi2QDrlOfQ* concreteTypes;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* concreteTypes;
NI compilesId;
};
struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
};
struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* converters;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* patterns;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* pureEnums;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interf;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interfHidden;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* uniqueName;
};
typedef tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* tyArray__Nfk9cOEzg2bRz9c1V8fGzONg[2];
struct tyTuple__0y4YQo9b9byJ83c0H89bBtdRw {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field0;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field1;
};
typedef NU8 tyEnum_TEvalMode__iWSxkwmhTDY7fh9aYmp69akQ;
typedef NU8 tySet_tyEnum_TSandboxFlag__6jKj8dTCDIUGegA1P2RahA;
struct tyObject_Profiler__vPk6nUD8QeNW2bHH4WZfpw {
NF tEnter;
tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ* tos;
};
struct tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ {
  tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw Sup;
tySequence__YdLNCDKYeipzJx3I8Xw82Q* code;
tySequence__Gl8s23LA3EFz4kIlya9ameg* debug;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* globals;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constants;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* types;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* currentExceptionA;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* currentExceptionB;
NI exceptionInstr;
tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw* prc;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* callsite;
tyEnum_TEvalMode__iWSxkwmhTDY7fh9aYmp69akQ mode;
tySet_tyEnum_TSandboxFlag__6jKj8dTCDIUGegA1P2RahA features;
NIM_BOOL traceActive;
NI loopIterations;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw comesFromHeuristic;
tySequence__eJWcQvhuN2q0rM6THoByqQ* callbacks;
NimStringDesc* errorFlag;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph;
NI oldErrorCount;
tyObject_Profiler__vPk6nUD8QeNW2bHH4WZfpw profiler;
NI* templInstCounter;
tySequence__ztPIC2M9bqhs0KjYuE9c9cN8g* vmstateDiff;
tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg procToCodePos;
};
struct tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA {
tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* key;
RootObj* val;
};
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__dlD6tEGzYLLpKVq3XwuFlA* Field2;
};
struct tyTuple__rZZA0skon1OsHdiEvT8RZQ {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__6OFCSvqRaxyEgUqWtnZSlw* Field2;
};
struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field2;
};
struct tyTuple__RWXAsQlFoGYyEQZp1G65sg {
NI Field0;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field1;
};
struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__m4PVWjcAAjfxlwJxLkKn8A* Field2;
};
struct tyTuple__RmGJuqOgEaHckHndh0LEsw {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field2;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
};
struct tyTuple__J4cxakKjhKxTIJR9bojMmXw {
NI Field0;
NI32 Field1;
tySequence__i89c5kdtWKzK3OEiI81pkkw* Field2;
};
struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ {
NI Field0;
NI32 Field1;
tySequence__GR8qmV1kNRcoQ2g76VFy3A* Field2;
};
struct tyTuple__a7QginWFapakKbWJBJ2vfA {
tySequence__ed0C0uAUZPhvw3RAc5hfYg* Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__kbX6x85REySUrk9auORL0vw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q {
tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A* root;
NI entries;
};
struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, tyProc__kqPx9c4py2HW6KcFMhNvxtg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__9c6qRjwy7Es8UkDTIUwAfFA) (tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__mv4BsRs5VEnhcxzV6pQU5w) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
struct tyTuple__nF9cH4hinXgGEUwO4G2bshw {
tyProc__kqPx9c4py2HW6KcFMhNvxtg Field0;
tyProc__9c6qRjwy7Es8UkDTIUwAfFA Field1;
tyProc__mv4BsRs5VEnhcxzV6pQU5w Field2;
NIM_BOOL Field3;
};
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
NU32 Field0;
NimStringDesc* Field1;
};
struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA {
NU16 line;
NI16 col;
NU32 file;
};
struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA {
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
NI32 operand;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeId_0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
};
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
NU32 Field0;
NI32 Field1;
};
struct tyTuple__PsEhl3dzznmmJiLAuIXZOg {
NU32 Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA Field1;
};
struct tyTuple__Db8CrQifKGIsKc3w71w7Lw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ key;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* concreteTypes;
};
struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ {
tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
NI Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA {
tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
NU32 name;
NI32 path;
};
struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA {
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
NU32 name;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typ;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
NI32 ast;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ guard;
NI bitsize;
NI alignment;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
NU32 externalName;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw locFlags;
tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA annex;
NI32 constraint;
};
struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw {
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* types;
NI32 n;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeInst;
NI32 nonUniqueId;
};
struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg {
NI Field0;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* Field1;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* Field2;
};
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
NI Field0;
NI32 Field1;
NU32 Field2;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* args, void* ClE_0);
void* ClE_0;
} tyProc__vkuGXw0bPP9b9cpazTHQY9bqg;
struct tyTuple__5pg9aIYdyrJM6GlDgyTDumg {
NimStringDesc* Field0;
tyProc__vkuGXw0bPP9b9cpazTHQY9bqg Field1;
};
struct tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA {
NI ra;
NI rb;
NI rc;
tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA* slots;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* currentException;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw currentLineInfo;
};
struct tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA {
  TGenericSeq Sup;
  tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg data[SEQ_DECL_SIZE];
};
struct tySequence__cvxuM2UjDv0O3Q6FcDEAnw {
  TGenericSeq Sup;
  tyTuple__2E9aYKv1U4zUZsR6wkNRkPg data[SEQ_DECL_SIZE];
};
struct tySequence__vvBerF0axaNtu9aMA2gnsrA {
  TGenericSeq Sup;
  tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q* data[SEQ_DECL_SIZE];
};
struct tySequence__9c3OY0aBmSBgwdsnBAPf4Ag {
  TGenericSeq Sup;
  tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* data[SEQ_DECL_SIZE];
};
struct tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ {
  TGenericSeq Sup;
  tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w data[SEQ_DECL_SIZE];
};
struct tySequence__Jhh6ks9carRtwV9aOuM8yMNw {
  TGenericSeq Sup;
  tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg data[SEQ_DECL_SIZE];
};
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw {
  TGenericSeq Sup;
  tyTuple__NAaJgGVgNmlGoqmiWxdOHQ data[SEQ_DECL_SIZE];
};
struct tySequence__k7EQb9bN3Uhl608xoPGMRJA {
  TGenericSeq Sup;
  tyTuple__toqrUPSdp8zSxOdlxMJj9cA data[SEQ_DECL_SIZE];
};
struct tySequence__XDpbjnuseLNZDGLBQ2Qzow {
  TGenericSeq Sup;
  tyTuple__VbApVidEWCFLq9a29bPtaS7A data[SEQ_DECL_SIZE];
};
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  TGenericSeq Sup;
  NI data[SEQ_DECL_SIZE];
};
struct tySequence__QqvaCqCpEE1QmQZbcZLi5A {
  TGenericSeq Sup;
  tyTuple__EbsafWGli8bW2GRJQ9apsjA data[SEQ_DECL_SIZE];
};
struct tySequence__ed0C0uAUZPhvw3RAc5hfYg {
  TGenericSeq Sup;
  tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* data[SEQ_DECL_SIZE];
};
struct tySequence__dlD6tEGzYLLpKVq3XwuFlA {
  TGenericSeq Sup;
  tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__6OFCSvqRaxyEgUqWtnZSlw {
  TGenericSeq Sup;
  tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q data[SEQ_DECL_SIZE];
};
struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g {
  TGenericSeq Sup;
  tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg data[SEQ_DECL_SIZE];
};
struct tySequence__ztPIC2M9bqhs0KjYuE9c9cN8g {
  TGenericSeq Sup;
  tyTuple__0y4YQo9b9byJ83c0H89bBtdRw data[SEQ_DECL_SIZE];
};
struct tySequence__ZQPym9bf1jM5qaSn7LUXMKA {
  TGenericSeq Sup;
  tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__E8pi9b5QNahsURYzXMjh3qw {
  TGenericSeq Sup;
  tyTuple__47w2DboNEPf69aPgubZdd7Q data[SEQ_DECL_SIZE];
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
struct tySequence__RNhZxf20g9beyq5VBOGxhDg {
  TGenericSeq Sup;
  tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ data[SEQ_DECL_SIZE];
};
struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ {
  TGenericSeq Sup;
  tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg data[SEQ_DECL_SIZE];
};
struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ {
  TGenericSeq Sup;
  tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ data[SEQ_DECL_SIZE];
};
struct tySequence__ijtae5OneaLys0hN9alAicA {
  TGenericSeq Sup;
  tyTuple__UluY8x0Nj6cp9b0o88wJ0lg data[SEQ_DECL_SIZE];
};
struct tySequence__SerjNoUujW2dUouVBrJiCw {
  TGenericSeq Sup;
  tyTuple__rZZA0skon1OsHdiEvT8RZQ data[SEQ_DECL_SIZE];
};
struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g {
  TGenericSeq Sup;
  tyTuple__q13Zt16VkCqu6Zg5jWqwHA data[SEQ_DECL_SIZE];
};
struct tySequence__m4PVWjcAAjfxlwJxLkKn8A {
  TGenericSeq Sup;
  tyTuple__RWXAsQlFoGYyEQZp1G65sg data[SEQ_DECL_SIZE];
};
struct tySequence__m88qdML9cQOuqGAQn6XWL1A {
  TGenericSeq Sup;
  tyTuple__aWN9bNzF9bubXNJV9ciomgpfA data[SEQ_DECL_SIZE];
};
struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ {
  TGenericSeq Sup;
  tyTuple__RmGJuqOgEaHckHndh0LEsw data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__i89c5kdtWKzK3OEiI81pkkw {
  TGenericSeq Sup;
  tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A data[SEQ_DECL_SIZE];
};
struct tySequence__KgiZ29chkJAD01p9aLRB32qw {
  TGenericSeq Sup;
  tyTuple__J4cxakKjhKxTIJR9bojMmXw data[SEQ_DECL_SIZE];
};
struct tySequence__GR8qmV1kNRcoQ2g76VFy3A {
  TGenericSeq Sup;
  tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* data[SEQ_DECL_SIZE];
};
struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw {
  TGenericSeq Sup;
  tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ data[SEQ_DECL_SIZE];
};
struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ {
  TGenericSeq Sup;
  tyTuple__a7QginWFapakKbWJBJ2vfA data[SEQ_DECL_SIZE];
};
struct tySequence__YmPd0eWfcTfrVYrthlXPYA {
  TGenericSeq Sup;
  tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg {
  TGenericSeq Sup;
  tyTuple__kbX6x85REySUrk9auORL0vw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ {
  TGenericSeq Sup;
  tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g data[SEQ_DECL_SIZE];
};
struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q {
  TGenericSeq Sup;
  tyTuple__nF9cH4hinXgGEUwO4G2bshw data[SEQ_DECL_SIZE];
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  TGenericSeq Sup;
  tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE];
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  TGenericSeq Sup;
  NU32 data[SEQ_DECL_SIZE];
};
struct tySequence__4Murtwnm0Fyc7F9acrytEXw {
  TGenericSeq Sup;
  tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA data[SEQ_DECL_SIZE];
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  TGenericSeq Sup;
  tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE];
};
struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw {
  TGenericSeq Sup;
  tyTuple__PsEhl3dzznmmJiLAuIXZOg data[SEQ_DECL_SIZE];
};
struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg {
  TGenericSeq Sup;
  tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w data[SEQ_DECL_SIZE];
};
struct tySequence__oKtVqsc9bQVCNyrijELM4OQ {
  TGenericSeq Sup;
  tyTuple__Db8CrQifKGIsKc3w71w7Lw data[SEQ_DECL_SIZE];
};
struct tySequence__qy6Iwdy00wN560qud54HTg {
  TGenericSeq Sup;
  tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg data[SEQ_DECL_SIZE];
};
struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ {
  TGenericSeq Sup;
  tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ data[SEQ_DECL_SIZE];
};
struct tySequence__cLsClAAfd0MKkoBQVyvdvw {
  TGenericSeq Sup;
  tyTuple__FEYH9alRJhHD0uTKF2vnIqw data[SEQ_DECL_SIZE];
};
struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg {
  TGenericSeq Sup;
  tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA data[SEQ_DECL_SIZE];
};
struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw {
  TGenericSeq Sup;
  tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw data[SEQ_DECL_SIZE];
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  TGenericSeq Sup;
  NI64 data[SEQ_DECL_SIZE];
};
struct tySequence__lo3S1lKyiPLhGGB9cBawd6A {
  TGenericSeq Sup;
  tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ data[SEQ_DECL_SIZE];
};
struct tySequence__C3r8jsj9chA4sIlYfDN5aDw {
  TGenericSeq Sup;
  tyTuple__VUJ5Hjm4tKAResBsRHJvYg data[SEQ_DECL_SIZE];
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  TGenericSeq Sup;
  tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE];
};
struct tySequence__UnGSk9aaLosDroi2QDrlOfQ {
  TGenericSeq Sup;
  tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg data[SEQ_DECL_SIZE];
};
struct tySequence__YdLNCDKYeipzJx3I8Xw82Q {
  TGenericSeq Sup;
  NU64 data[SEQ_DECL_SIZE];
};
struct tySequence__Gl8s23LA3EFz4kIlya9ameg {
  TGenericSeq Sup;
  tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw data[SEQ_DECL_SIZE];
};
struct tySequence__eJWcQvhuN2q0rM6THoByqQ {
  TGenericSeq Sup;
  tyTuple__5pg9aIYdyrJM6GlDgyTDumg data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__cvxuM2UjDv0O3Q6FcDEAnw)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__10LrMeEGcZEU1Ndh5rhoUg)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__BSbNT2MZJsNcSq6BlR6KPQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__vvBerF0axaNtu9aMA2gnsrA)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__9c3OY0aBmSBgwdsnBAPf4Ag)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__Jhh6ks9carRtwV9aOuM8yMNw)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__Bis5AbpONWcIRrPyPJS8Yw)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__k7EQb9bN3Uhl608xoPGMRJA)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__XDpbjnuseLNZDGLBQ2Qzow)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__QqvaCqCpEE1QmQZbcZLi5A)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__C5LQliQ3Detta8PpLynVjQ)(void* p, NI op);
N_LIB_PRIVATE N_NOINLINE(void*, newObj)(TNimType* typ, NI size);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
static N_INLINE(void, decRef__system_5318)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5316)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5267)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5273)(void* usr);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqRC1)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q*, newOptionEntry__semdata_459)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5311)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(void, initPackedSet__pureZcollectionsZintsets_16)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(void, initStrTable__ast_4076)(tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* x);
N_LIB_PRIVATE N_NIMCALL(void, initEncoder__modulegraphs_2730)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderTree__renderer_46)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA renderFlags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, newTypeS__semdata_763)(tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, newType__ast_3884)(tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg id, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner);
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextTypeId__ast_3122)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getCurrOwner__semdata_327)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
static N_INLINE(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw**, X5BX5D___semfold_21)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw** s, NI sLen_0, NI i);
N_LIB_PRIVATE N_NIMCALL(tySequence__dlD6tEGzYLLpKVq3XwuFlA**, mgetOrPut__semdata_2458)(tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA* t, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg key, tySequence__dlD6tEGzYLLpKVq3XwuFlA* val);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(void, storeTypeInst__icZic_3012)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* inst);
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, illFormedAst__semdata_1101)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, genericSeqAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeI__ast_3320)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, newTypeWithSons__semdata_851)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind, tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons);
N_LIB_PRIVATE N_NIMCALL(void*, newSeq)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, getSysType__magicsys_60)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_4798)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newIntTypeNode__ast_3771)(NI64 intVal, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(void, addSonSkipIntLit__magicsys_136)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* father, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* son, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* id);
N_LIB_PRIVATE N_NIMCALL(void, strTableAdds__modulegraphs_2706)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, addExported__icZic_2332)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getGenSym__semdata_420)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, get__semdata_416)(tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* key);
N_LIB_PRIVATE N_NIMCALL(RootObj*, idTableGet__astalgo_64)(tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ t, tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* key);
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, considerGenSyms__semdata_437)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, storeExpansion__icZic_3134)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, propagateToOwner__ast_4207)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* owner, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* elem, NIM_BOOL propagateHasAsgn);
N_LIB_PRIVATE N_NIMCALL(void, rawAddSon__ast_4276)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* father, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* son, NIM_BOOL propagateHasAsgn);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, errorType__semdata_1032)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
N_LIB_PRIVATE N_NIMCALL(tySequence__6OFCSvqRaxyEgUqWtnZSlw**, mgetOrPut__semdata_1249)(tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w* t, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg key, tySequence__6OFCSvqRaxyEgUqWtnZSlw* val);
N_LIB_PRIVATE N_NIMCALL(void, storeInstantiation__icZic_3074)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* i);
N_LIB_PRIVATE N_NIMCALL(void, addPragmaComputation__icZic_3030)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q**, X5BX5D___semdata_356)(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q** s, NI sLen_0, NI i);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, inclSym__semdata_655)(tySequence__ed0C0uAUZPhvw3RAc5hfYg** sq, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, addTrmacro__icZic_2358)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_1441)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, makePtrType__semdata_767)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* baseType, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newTreeI__ast_3384)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** children, NI childrenLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, makeStaticExpr__semdata_856)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, nMinusOne__semdata_996)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newSymNode__ast_3704)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getSysMagic__magicsys_29)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* name, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag m);
N_LIB_PRIVATE N_NIMCALL(void, addPureEnum__icZic_2366)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, getIntLitType__semdata_229)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* literal);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, copyType__ast_4034)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg id, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner);
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_625)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_167)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, linkTo__ast_3511)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, newSym__ast_3409)(tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw symKind, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg id, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options);
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextSymId__ast_3103)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newSymNode__ast_3707)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
static N_INLINE(void, pop__semdata_1153)(tySequence__cvxuM2UjDv0O3Q6FcDEAnw** s, tyTuple__2E9aYKv1U4zUZsR6wkNRkPg* Result);
static N_INLINE(tyTuple__2E9aYKv1U4zUZsR6wkNRkPg*, X5BX5D___semdata_1169)(tyTuple__2E9aYKv1U4zUZsR6wkNRkPg* s, NI sLen_0, NI i);
N_LIB_PRIVATE N_NIMCALL(void, addConverter__semdata_683)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg conv);
N_LIB_PRIVATE N_NIMCALL(void, addConverter__icZic_2347)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, addImportFileDep__icZic_2300)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, NI32 f);
N_LIB_PRIVATE N_NIMCALL(void, addIncludeFileDep__icZic_2292)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, NI32 f);
N_LIB_PRIVATE N_NIMCALL(void, addReexport__icZic_2389)(tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* c, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, toPackedNodeTopLevel__icZic_3059)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ* encoder, tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag* m);
N_LIB_PRIVATE N_NIMCALL(void, addPragmaComputation__semdata_648)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
extern TNimType NTItpasscontext__dmp6pRpfXxJk6gIZHkm7dw_;
N_LIB_PRIVATE TNimType NTItcontext__TE0bwjD2I16QW6s9c4AgPvw_;
extern TNimType NTIptype__q1v0zzhoMWrhMLs6UEp1IA_;
extern TNimType NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_;
extern TNimType NTIpscope__1WBIpqNgZhwC9bV4356CRhQ_;
N_LIB_PRIVATE TNimType NTIimportedmodule__ABXo2nVfMtcWNYv5zEiXDg_;
N_LIB_PRIVATE TNimType NTIimportmode__4kYBzhtdX1Hkta8RDDKjrQ_;
TNimNode* NimDT___ABXo2nVfMtcWNYv5zEiXDg_mode[4];
extern TNimType NTIpackedset__THXDbzJSs2hcC9a33en2pdw_;
N_LIB_PRIVATE TNimType NTIseqLimportedmoduleT__9boKiNhY9cnRQF2k9b9a9bGKbrA_;
N_LIB_PRIVATE TNimType NTItproccon__9aK41DZ7WNm5NSRfb1CbcRA_;
extern TNimType NTIint__rR5Bzr1D5krxoo1NcNyeMA_;
extern TNimType NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_;
extern TNimType NTItidtable__Cs7vbulfMjKciTA2Uv9b6vQ_;
N_LIB_PRIVATE TNimType NTItupleLn58pnode_idx58intT__2E9aYKv1U4zUZsR6wkNRkPg_;
extern TNimType NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_;
N_LIB_PRIVATE TNimType NTIseqLtupleLn58pnode_idx58intTT__cvxuM2UjDv0O3Q6FcDEAnw_;
extern TNimType NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_;
N_LIB_PRIVATE TNimType NTIpproccon__10LrMeEGcZEU1Ndh5rhoUg_;
N_LIB_PRIVATE TNimType NTIarrayL4553OO5150_ptypeT__aaEwD7wUZoIxDUprFEbfMQ_;
N_LIB_PRIVATE TNimType NTItmatchedconcept__0kS5yo4t68pnIalDqA39crw_;
N_LIB_PRIVATE TNimType NTIptrtmatchedconcept__GVhEG2inner9bL6FQrJo9b9aA_;
extern TNimType NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_;
extern TNimType NTIrefint__9ai78kkwqt3gikTN9cpHKUVg_;
N_LIB_PRIVATE TNimType NTItoptionentry__KcSoeh10J9aas3WZevEUD7Q_;
extern TNimType NTItoptions__JyE8ULWMsetkCt18l86VRw_;
extern TNimType NTItcallingconvention__5kpSva5OFmGFHujbio7C9cg_;
extern TNimType NTIplib__cpB5Ba1r1YF5UAlBgbtl8g_;
extern TNimType NTItnotekinds__w2aCBEMcLy7t2KQe9caB9aBw_;
extern TNimType NTIsetLfeatureT__JNptLjsgi8AHY03RfiC9aTQ_;
N_LIB_PRIVATE TNimType NTIpoptionentry__BSbNT2MZJsNcSq6BlR6KPQ_;
N_LIB_PRIVATE TNimType NTIseqLpoptionentryT__vvBerF0axaNtu9aMA2gnsrA_;
N_LIB_PRIVATE TNimType NTIseqLplibT__9c3OY0aBmSBgwdsnBAPf4Ag_;
N_LIB_PRIVATE TNimType NTIprocLc58pcontext_n58pnode_expectedtype58ptypeT58pnodeLOnimcallOT__q9caIJqxIEVMlKzDKc7PN3A_;
N_LIB_PRIVATE TNimType NTIprocLc58pcontext_n58pnode_flags58texprflags_expectedtype58ptypeT58pnodeLOnimcallOT__Kiet6YwcQwPvcQYHHEqqqQ_;
N_LIB_PRIVATE TNimType NTIprocLc58pcontext_n58pnode_flags58texprflagsT58pnodeLOnimcallOT__PSlVV9bxpH9avY5YrjCD5uqA_;
N_LIB_PRIVATE TNimType NTIprocLc58pcontext_t58ptypeT58boolLOnimcallOT__8k9afYvvfaH1tjWAwlISb0A_;
N_LIB_PRIVATE TNimType NTIprocLc58pcontext_n58pnodeT58boolLOclosureOT__9bnYcX9avusKBraL3FJXBwJw_;
extern TNimType NTIpointer__vr5DoT1jILTGdRlYv1OYpw_;
extern TNimType NTIrefobject__HsJiUUcO9cHBdUCi0HwkSTA_;
N_LIB_PRIVATE TNimType NTIprocLc58pcontext_n58pnodeT58pnodeLOnimcallOT__uojbiMfaKLMuGW9bbomtTBg_;
N_LIB_PRIVATE TNimType NTIprocLc58pcontext_n58pnode_norig58pnode_filter58tsymkinds_flags58texprflagsT58pnodeLOnimcallOT__bqRyngJC8bSPcUqqn9bn73w_;
N_LIB_PRIVATE TNimType NTIprocLc58pcontext_n58pnode_prev58ptypeT58ptypeLOnimcallOT__F6LocU8y66ng5Ra4XoVWJA_;
N_LIB_PRIVATE TNimType NTIprocLc58pcontext_pt58tidtable_n58pnodeT58pnodeLOclosureOT__Nc9aAsBDTkr61wP9a9cnds8Og_;
N_LIB_PRIVATE TNimType NTIprocLc58pcontext_fn58psym_pt58tidtable_info58tlineinfoT58psymLOclosureOT__z8FaSv6eEIc72FZ9c9cBcaGg_;
extern TNimType NTItstrtable__CJQ42V2zij8fd39a9aMiwtZw_;
extern TNimType NTIpevalcontext__4IKTvAXRLrZvs9cUNEP7Z8w_;
N_LIB_PRIVATE TNimType NTItinstantiationpair__d4lcZMnmQK2Jh2jYkdgB4w_;
extern TNimType NTIpinstantiation__eg8se9cZBHdzb5ZM7CrYNVg_;
N_LIB_PRIVATE TNimType NTIseqLtinstantiationpairT__yH9bx9bpa6jqsU89cxjyTAlPQ_;
N_LIB_PRIVATE TNimType NTIprocLc58pcontext_dc58psym_t58ptype_info58tlineinfo_op58ttypeattachedop_col58intT58psymLOnimcallOT__9aa59awckKpa9areOQSBOwSeQ_;
extern TNimType NTIpident__eFRAx6MW9aaEkYtj9aZffV0A_;
extern TNimType NTIidentcache__6ZZ9cf5acLVYxUxl0ehlA1g_;
extern TNimType NTImodulegraph__AcDjMYSN0KX1UsX3HvPu2w_;
extern TNimType NTIstring__77mFvmsOLKik79ci2hXkHEg_;
N_LIB_PRIVATE TNimType NTILpsym_tlineinfoT__8vGER9aaTtt9bUk9avNQ3fEIg_;
extern TNimType NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_;
N_LIB_PRIVATE TNimType NTIseqLLpsym_tlineinfoTT__Jhh6ks9carRtwV9aOuM8yMNw_;
N_LIB_PRIVATE TNimType NTIhashset__qEsCgvAiLX6rSzzn9cFnYvQ_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__NAaJgGVgNmlGoqmiWxdOHQ_;
extern TNimType NTItupleLa58int_b58intT__1v9bKyksXWMsm0vNwmZ4EuQ_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__Bis5AbpONWcIRrPyPJS8Yw_;
extern TNimType NTItable__7ACYz5IhOEwzTBvwo6BO9bg_;
N_LIB_PRIVATE TNimType NTItable__g9cTlJykWlQLKMuaRBpUEZg_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__VbApVidEWCFLq9a29bPtaS7A_;
N_LIB_PRIVATE TNimType NTILtlineinfo_psymT__toqrUPSdp8zSxOdlxMJj9cA_;
N_LIB_PRIVATE TNimType NTIseqLLtlineinfo_psymTT__k7EQb9bN3Uhl608xoPGMRJA_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__XDpbjnuseLNZDGLBQ2Qzow_;
N_LIB_PRIVATE TNimType NTItable__cBohObSCAwRxvYFXQHv2wA_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__EbsafWGli8bW2GRJQ9apsjA_;
extern TNimType NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__QqvaCqCpEE1QmQZbcZLi5A_;
N_LIB_PRIVATE TNimType NTIpcontext__C5LQliQ3Detta8PpLynVjQ_;
STRING_LITERAL(TM__6kkF5shvTYOHG9cWBoBNLPQ_24, "/home/runner/work/nightlies/nightlies/nim/compiler/semdata.nim", 62);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__6kkF5shvTYOHG9cWBoBNLPQ_23 = {((NimStringDesc*) &TM__6kkF5shvTYOHG9cWBoBNLPQ_24),
((NI) 552),
((NI) 13)}
;
extern TNimType NTIseqLlazytypeT__dlD6tEGzYLLpKVq3XwuFlA_;
extern TNimType NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__6kkF5shvTYOHG9cWBoBNLPQ_25 = {((NimStringDesc*) &TM__6kkF5shvTYOHG9cWBoBNLPQ_24),
((NI) 555),
((NI) 12)}
;
extern TNimType NTIseqLlazyinstantiationT__6OFCSvqRaxyEgUqWtnZSlw_;
extern TNimType NTIseqLfullidT__UnGSk9aaLosDroi2QDrlOfQ_;
extern TNimType NTIseqLlazysymT__qeAsXh2i1GAL5Nl0g3OP8g_;
extern NIM_CONST tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw unknownLineInfo__lineinfos_284;
STRING_LITERAL(TM__6kkF5shvTYOHG9cWBoBNLPQ_26, "popOwner", 8);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__6kkF5shvTYOHG9cWBoBNLPQ_27 = {((NimStringDesc*) &TM__6kkF5shvTYOHG9cWBoBNLPQ_24),
((NI) 237),
((NI) 21)}
;
STRING_LITERAL(TM__6kkF5shvTYOHG9cWBoBNLPQ_28, "pred", 4);
STRING_LITERAL(TM__6kkF5shvTYOHG9cWBoBNLPQ_29, "invalid int size", 16);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__6kkF5shvTYOHG9cWBoBNLPQ_30 = {((NimStringDesc*) &TM__6kkF5shvTYOHG9cWBoBNLPQ_24),
((NI) 211),
((NI) 17)}
;
STRING_LITERAL(TM__6kkF5shvTYOHG9cWBoBNLPQ_31, "(", 1);
STRING_LITERAL(TM__6kkF5shvTYOHG9cWBoBNLPQ_32, ", ", 2);
STRING_LITERAL(TM__6kkF5shvTYOHG9cWBoBNLPQ_33, ")", 1);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__6kkF5shvTYOHG9cWBoBNLPQ_34 = {((NimStringDesc*) &TM__6kkF5shvTYOHG9cWBoBNLPQ_24),
((NI) 428),
((NI) 16)}
;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5220;
static N_NIMCALL(void, Marker_tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA)(void* p, NI op) {
	tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA* a;
	NI T1_;
	NI T2_;
	NI T3_;
	a = (tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].m, op);
	switch (a->data[T1_].mode) {
	case ((tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ) 0):
	break;
	case ((tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ) 1):
	nimGCvisit((void*)a->data[T1_]._mode_2.imported.head, op);
	nimGCvisit((void*)a->data[T1_]._mode_2.imported.data, op);
	T2_ = (NI)0;
	break;
	case ((tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ) 2):
	nimGCvisit((void*)a->data[T1_]._mode_3.exceptSet.head, op);
	nimGCvisit((void*)a->data[T1_]._mode_3.exceptSet.data, op);
	T3_ = (NI)0;
	break;
	} 
	}
}
static N_NIMCALL(void, Marker_tySequence__cvxuM2UjDv0O3Q6FcDEAnw)(void* p, NI op) {
	tySequence__cvxuM2UjDv0O3Q6FcDEAnw* a;
	NI T1_;
	a = (tySequence__cvxuM2UjDv0O3Q6FcDEAnw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field0, op);
	}
}
static N_NIMCALL(void, Marker_tyRef__10LrMeEGcZEU1Ndh5rhoUg)(void* p, NI op) {
	tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA* a;
	a = (tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA*)p;
	nimGCvisit((void*)(*a).owner, op);
	nimGCvisit((void*)(*a).resultSym, op);
	nimGCvisit((void*)(*a).selfSym, op);
	nimGCvisit((void*)(*a).next, op);
	nimGCvisit((void*)(*a).mapping.data, op);
	nimGCvisit((void*)(*a).caseContext, op);
	nimGCvisit((void*)(*a).localBindStmts, op);
}
static N_NIMCALL(void, Marker_tyRef__BSbNT2MZJsNcSq6BlR6KPQ)(void* p, NI op) {
	tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q* a;
	a = (tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q*)p;
	nimGCvisit((void*)(*a).dynlib, op);
	nimGCvisit((void*)(*a).otherPragmas, op);
}
static N_NIMCALL(void, Marker_tySequence__vvBerF0axaNtu9aMA2gnsrA)(void* p, NI op) {
	tySequence__vvBerF0axaNtu9aMA2gnsrA* a;
	NI T1_;
	a = (tySequence__vvBerF0axaNtu9aMA2gnsrA*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_], op);
	}
}
static N_NIMCALL(void, Marker_tySequence__9c3OY0aBmSBgwdsnBAPf4Ag)(void* p, NI op) {
	tySequence__9c3OY0aBmSBgwdsnBAPf4Ag* a;
	NI T1_;
	a = (tySequence__9c3OY0aBmSBgwdsnBAPf4Ag*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_], op);
	}
}
static N_NIMCALL(void, Marker_tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ)(void* p, NI op) {
	tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ* a;
	NI T1_;
	a = (tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].genericSym, op);
	nimGCvisit((void*)a->data[T1_].inst, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__Jhh6ks9carRtwV9aOuM8yMNw)(void* p, NI op) {
	tySequence__Jhh6ks9carRtwV9aOuM8yMNw* a;
	NI T1_;
	a = (tySequence__Jhh6ks9carRtwV9aOuM8yMNw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field0, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__Bis5AbpONWcIRrPyPJS8Yw)(void* p, NI op) {
	tySequence__Bis5AbpONWcIRrPyPJS8Yw* a;
	NI T1_;
	a = (tySequence__Bis5AbpONWcIRrPyPJS8Yw*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__k7EQb9bN3Uhl608xoPGMRJA)(void* p, NI op) {
	tySequence__k7EQb9bN3Uhl608xoPGMRJA* a;
	NI T1_;
	a = (tySequence__k7EQb9bN3Uhl608xoPGMRJA*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field1, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__XDpbjnuseLNZDGLBQ2Qzow)(void* p, NI op) {
	tySequence__XDpbjnuseLNZDGLBQ2Qzow* a;
	NI T1_;
	a = (tySequence__XDpbjnuseLNZDGLBQ2Qzow*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field2, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__QqvaCqCpEE1QmQZbcZLi5A)(void* p, NI op) {
	tySequence__QqvaCqCpEE1QmQZbcZLi5A* a;
	NI T1_;
	a = (tySequence__QqvaCqCpEE1QmQZbcZLi5A*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field2, op);
	}
}
static N_NIMCALL(void, Marker_tyRef__C5LQliQ3Detta8PpLynVjQ)(void* p, NI op) {
	tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* a;
	NI T1_;
	NI T2_;
	NI T3_;
	a = (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw*)p;
	nimGCvisit((void*)(*a).Sup.idgen, op);
	nimGCvisit((void*)(*a).enforceVoidContext, op);
	nimGCvisit((void*)(*a).voidType, op);
	nimGCvisit((void*)(*a).module, op);
	nimGCvisit((void*)(*a).currentScope, op);
	nimGCvisit((void*)(*a).moduleScope, op);
	nimGCvisit((void*)(*a).imports, op);
	nimGCvisit((void*)(*a).topLevelScope, op);
	nimGCvisit((void*)(*a).p, op);
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < 38; T1_++) {
	nimGCvisit((void*)(*a).intTypeCache[T1_], op);
	}
	nimGCvisit((void*)(*a).nilTypeCache, op);
	nimGCvisit((void*)(*a).friendModules, op);
	nimGCvisit((void*)(*a).templInstCounter, op);
	nimGCvisit((void*)(*a).converters, op);
	nimGCvisit((void*)(*a).patterns, op);
	nimGCvisit((void*)(*a).optionStack, op);
	nimGCvisit((void*)(*a).symMapping.data, op);
	nimGCvisit((void*)(*a).libs, op);
	nimGCvisit((void*)(*a).hasUnresolvedArgs.ClE_0, op);
	nimGCvisit((void*)(*a).semInferredLambda.ClE_0, op);
	nimGCvisit((void*)(*a).semGenerateInstance.ClE_0, op);
	nimGCvisit((void*)(*a).includedFiles.head, op);
	nimGCvisit((void*)(*a).includedFiles.data, op);
	T2_ = (NI)0;
	nimGCvisit((void*)(*a).pureEnumFields.data, op);
	nimGCvisit((void*)(*a).userPragmas.data, op);
	nimGCvisit((void*)(*a).evalContext, op);
	nimGCvisit((void*)(*a).unknownIdents.head, op);
	nimGCvisit((void*)(*a).unknownIdents.data, op);
	T3_ = (NI)0;
	nimGCvisit((void*)(*a).generics, op);
	nimGCvisit((void*)(*a).selfName, op);
	nimGCvisit((void*)(*a).cache, op);
	nimGCvisit((void*)(*a).graph, op);
	nimGCvisit((void*)(*a).signatures.data, op);
	nimGCvisit((void*)(*a).recursiveDep, op);
	nimGCvisit((void*)(*a).unusedImports, op);
	nimGCvisit((void*)(*a).exportIndirections.data, op);
	nimGCvisit((void*)(*a).importModuleMap.data, op);
	nimGCvisit((void*)(*a).sideEffects.data, op);
	nimGCvisit((void*)(*a).importModuleLookup.data, op);
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5316)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5267((&gch__system_5220.zct), c);
}
static N_INLINE(void, decRef__system_5318)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5316(c);
	}
	LA4_: ;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5273)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5273(p);
	decRef__system_5318(T1_);
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5311)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5273(src);
		incRef__system_5311(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5273((*dest));
		decRef__system_5318(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q*, newOptionEntry__semdata_459)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q* result;
	result = NIM_NIL;
	result = (tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q*) newObj((&NTIpoptionentry__BSbNT2MZJsNcSq6BlR6KPQ_), sizeof(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q));
	(*result).options = (*conf).options;
	(*result).defaultCC = ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 0);
	asgnRef((void**) (&(*result).dynlib), ((tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg*) NIM_NIL));
	nimCopyMem((void*)(*result).notes, (NIM_CONST void*)(*conf).notes, 12);
	nimCopyMem((void*)(*result).warningAsErrors, (NIM_CONST void*)(*conf).warningAsErrors, 12);
	return result;
}
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result) {
	initPackedSet__pureZcollectionsZintsets_16(Result);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw*, newContext__semdata_515)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module) {
	tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* result;
	result = NIM_NIL;
	result = (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw*) newObj((&NTIpcontext__C5LQliQ3Detta8PpLynVjQ_), sizeof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw));
	(*result).Sup.Sup.m_type = (&NTItcontext__TE0bwjD2I16QW6s9c4AgPvw_);
	if ((*result).optionStack) { nimGCunrefNoCycle((*result).optionStack); (*result).optionStack = NIM_NIL; }
	(*result).optionStack = (tySequence__vvBerF0axaNtu9aMA2gnsrA*) newSeqRC1((&NTIseqLpoptionentryT__vvBerF0axaNtu9aMA2gnsrA_), 1);
	asgnRef((void**) (&(*result).optionStack->data[0]), newOptionEntry__semdata_459((*graph).config));
	if ((*result).libs) { nimGCunrefNoCycle((*result).libs); (*result).libs = NIM_NIL; }
	asgnRef((void**) (&(*result).module), module);
	if ((*result).friendModules) { nimGCunrefNoCycle((*result).friendModules); (*result).friendModules = NIM_NIL; }
	(*result).friendModules = (tySequence__ed0C0uAUZPhvw3RAc5hfYg*) newSeqRC1((&NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_), 1);
	asgnRef((void**) (&(*result).friendModules->data[0]), module);
	if ((*result).converters) { nimGCunrefNoCycle((*result).converters); (*result).converters = NIM_NIL; }
	if ((*result).patterns) { nimGCunrefNoCycle((*result).patterns); (*result).patterns = NIM_NIL; }
	initIntSet__pureZcollectionsZintsets_238((&(*result).includedFiles));
	initStrTable__ast_4076((&(*result).pureEnumFields));
	initStrTable__ast_4076((&(*result).userPragmas));
	if ((*result).generics) { nimGCunrefNoCycle((*result).generics); (*result).generics = NIM_NIL; }
	initIntSet__pureZcollectionsZintsets_238((&(*result).unknownIdents));
	asgnRef((void**) (&(*result).cache), (*graph).cache);
	asgnRef((void**) (&(*result).graph), graph);
	initStrTable__ast_4076((&(*result).signatures));
	(*result).features = (*(*graph).config).features;
	{
		NI id;
		if (!!(((*(*graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0)))) goto LA3_;
		id = (*module).position;
		(*graph).packed_0->data[id].status = ((tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg) 1);
		asgnRef((void**) (&(*graph).packed_0->data[id].module), module);
		initEncoder__modulegraphs_2730(graph, module);
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, illFormedAst__semdata_1101)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NimStringDesc* T1_;
	T1_ = NIM_NIL;
	T1_ = renderTree__renderer_46(n, 4);
	liMessage__msgs_1128(conf, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 3), T1_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 2), TM__6kkF5shvTYOHG9cWBoBNLPQ_23, NIM_FALSE);
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextTypeId__ast_3122)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x) {
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*x).typeId_0 += ((NI) 1);
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	result.module = (*x).module;
	result.item = (*x).typeId_0;
	return result;
}
static N_INLINE(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw**, X5BX5D___semfold_21)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw** s, NI sLen_0, NI i) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw** result;
	result = (tyObject_TSym__3r34mwqcVmg5JFNmiaVncw**)0;
	result = &s[(NI)(sLen_0 - i)];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getCurrOwner__semdata_327)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw** T1_;
	result = NIM_NIL;
	T1_ = (tyObject_TSym__3r34mwqcVmg5JFNmiaVncw**)0;
	T1_ = X5BX5D___semfold_21(((*(*c).graph).owners) ? ((*(*c).graph).owners->data) : NIM_NIL, ((*(*c).graph).owners ? (*(*c).graph).owners->Sup.len : 0), ((NI) 1));
	result = (*T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, newTypeS__semdata_763)(tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T1_;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T2_;
	result = NIM_NIL;
	T1_ = nextTypeId__ast_3122((*c).Sup.idgen);
	T2_ = NIM_NIL;
	T2_ = getCurrOwner__semdata_327(c);
	result = newType__ast_3884(kind, T1_, T2_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, makeTypeFromExpr__semdata_834)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	result = NIM_NIL;
	result = newTypeS__semdata_763(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 61), c);
	asgnRef((void**) (&(*result).n), n);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, errorType__semdata_1032)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	result = NIM_NIL;
	result = newTypeS__semdata_763(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 50), c);
	(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 38)) & 63);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addToGenericCache__semdata_2424)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* inst) {
	tySequence__dlD6tEGzYLLpKVq3XwuFlA* T1_;
	tySequence__dlD6tEGzYLLpKVq3XwuFlA** T2_;
	tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ T3_;
	NI T4_;
	T1_ = NIM_NIL;
	T1_ = NIM_NIL;
	T2_ = (tySequence__dlD6tEGzYLLpKVq3XwuFlA**)0;
	T2_ = mgetOrPut__semdata_2458((&(*(*c).graph).typeInstCache), (*s).Sup.itemId, T1_);
	nimZeroMem((void*)(&T3_), sizeof(tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ));
	nimZeroMem((void*)(&T3_), sizeof(tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ));
	T3_.typ = inst;
	unsureAsgnRef((void**) (&(*T2_)), (tySequence__dlD6tEGzYLLpKVq3XwuFlA*) incrSeqV3((TGenericSeq*)((*T2_)), (&NTIseqLlazytypeT__dlD6tEGzYLLpKVq3XwuFlA_)));
	T4_ = (*T2_)->Sup.len++;
	(*T2_)->data[T4_].id = T3_.id;
	asgnRef((void**) (&(*T2_)->data[T4_].typ), T3_.typ);
	{
		if (!!(((*(*(*c).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0)))) goto LA7_;
		storeTypeInst__icZic_3012((&(*(*c).graph).encoders->data[(*(*c).module).position]), (&(*(*c).graph).packed_0->data[(*(*c).module).position].fromDisk), s, inst);
	}
	LA7_: ;
}
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkSonsLen__semdata_1107)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI length, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__ast_3155(n);
		if (!!((T3_ == length))) goto LA4_;
		illFormedAst__semdata_1101(n, conf);
	}
	LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, newTypeWithSons__semdata_851)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind, tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T1_;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T2_;
	result = NIM_NIL;
	T1_ = nextTypeId__ast_3122((*c).Sup.idgen);
	T2_ = NIM_NIL;
	T2_ = getCurrOwner__semdata_327(c);
	result = newType__ast_3884(kind, T1_, T2_);
	genericSeqAssign((&(*result).sons), sons, (&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, makeStaticExpr__semdata_856)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 62), (*n).info);
	if ((*result)._kind_6.sons) { nimGCunrefNoCycle((*result)._kind_6.sons); (*result)._kind_6.sons = NIM_NIL; }
	(*result)._kind_6.sons = (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) newSeqRC1((&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), 1);
	asgnRef((void**) (&(*result)._kind_6.sons->data[0]), n);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*n).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60));
		LA4_: ;
		if (!T3_) goto LA5_;
		asgnRef((void**) (&(*result).typ), (*n).typ);
	}
	goto LA1_;
	LA5_: ;
	{
		tySequence__vKogasEnJSPhbQmA8r4Y9aA* T8_;
		T8_ = NIM_NIL;
		T8_ = (tySequence__vKogasEnJSPhbQmA8r4Y9aA*) newSeq((&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_), 1);
		asgnRef((void**) (&T8_->data[0]), (*n).typ);
		asgnRef((void**) (&(*result).typ), newTypeWithSons__semdata_851(c, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60), T8_));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, makeRangeType__semdata_1069)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, NI64 first, NI64 last, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* intType) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* intType_2;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T6_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T7_;
	result = NIM_NIL;
	{
		if (!!((intType == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA3_;
		intType_2 = intType;
	}
	goto LA1_;
	LA3_: ;
	{
		intType_2 = getSysType__magicsys_60((*c).graph, info, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31));
	}
	LA1_: ;
	n = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 44), info);
	T6_ = NIM_NIL;
	T6_ = newIntTypeNode__ast_3771(first, intType_2);
	add__ast_4798(n, T6_);
	T7_ = NIM_NIL;
	T7_ = newIntTypeNode__ast_3771(last, intType_2);
	add__ast_4798(n, T7_);
	result = newTypeS__semdata_763(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 20), c);
	asgnRef((void**) (&(*result).n), n);
	addSonSkipIntLit__magicsys_136(result, intType_2, (*c).Sup.idgen);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, exportSym__semdata_740)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	strTableAdds__modulegraphs_2706((*c).graph, (*c).module, s);
	{
		if (!!(((*(*(*c).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0)))) goto LA3_;
		addExported__icZic_2332((&(*(*c).graph).encoders->data[(*(*c).module).position]), (&(*(*c).graph).packed_0->data[(*(*c).module).position].fromDisk), s);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, get__semdata_416)(tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA* p, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* key) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	RootObj* T5_;
{	result = NIM_NIL;
	{
		if (!!((*p).mappingExists)) goto LA3_;
		result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
		goto BeforeRet_;
	}
	LA3_: ;
	T5_ = NIM_NIL;
	T5_ = idTableGet__astalgo_64((*p).mapping, &key->Sup);
	result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) (T5_));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getGenSym__semdata_420)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA* it;
{	result = NIM_NIL;
	{
		if (!!((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 37))&63U)))!=0))) goto LA3_;
		result = s;
		goto BeforeRet_;
	}
	LA3_: ;
	it = (*c).p;
	{
		while (1) {
			if (!!((it == ((tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA*) NIM_NIL)))) goto LA6;
			result = get__semdata_416(it, s);
			{
				if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA9_;
				goto BeforeRet_;
			}
			LA9_: ;
			it = (*it).next;
		} LA6: ;
	}
	result = s;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__ast_3155(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, considerGenSyms__semdata_437)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		if (!(n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA3_;
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA6_;
		s = getGenSym__semdata_420(c, (*n)._kind_4.sym);
		{
			if (!!(((*n)._kind_4.sym == s))) goto LA10_;
			asgnRef((void**) (&(*n)._kind_4.sym), s);
		}
		LA10_: ;
	}
	goto LA1_;
	LA6_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA15;
					i = i_2;
					considerGenSyms__semdata_437(c, (*n)._kind_6.sons->data[i]);
					i_2 += ((NI) 1);
				} LA15: ;
			}
		}
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, makeVarType__semdata_796)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* baseType, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	result = NIM_NIL;
	{
		if (!((*baseType).kind == kind)) goto LA3_;
		result = baseType;
	}
	goto LA1_;
	LA3_: ;
	{
		result = newTypeS__semdata_763(kind, c);
		addSonSkipIntLit__magicsys_136(result, baseType, (*c).Sup.idgen);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rememberExpansion__semdata_3686)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* expandedSym) {
	{
		if (!!(((*(*(*c).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0)))) goto LA3_;
		storeExpansion__icZic_3134((&(*(*c).graph).encoders->data[(*(*c).module).position]), (&(*(*c).graph).packed_0->data[(*(*c).module).position].fromDisk), info, expandedSym);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, makeVarType__semdata_805)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* baseType, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	result = NIM_NIL;
	{
		if (!((*baseType).kind == kind)) goto LA3_;
		result = baseType;
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T6_;
		T6_ = nextTypeId__ast_3122(idgen);
		result = newType__ast_3884(kind, T6_, owner);
		addSonSkipIntLit__magicsys_136(result, baseType, idgen);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, makePtrType__semdata_767)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* baseType, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T1_;
	result = NIM_NIL;
	T1_ = nextTypeId__ast_3122(idgen);
	result = newType__ast_3884(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21), T1_, owner);
	addSonSkipIntLit__magicsys_136(result, baseType, idgen);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, illFormedAstLocal__semdata_1104)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NimStringDesc* T1_;
	T1_ = NIM_NIL;
	T1_ = renderTree__renderer_46(n, 4);
	liMessage__msgs_1128(conf, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 3), T1_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__6kkF5shvTYOHG9cWBoBNLPQ_25, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, makeAndType__semdata_885)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t1, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t2) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	result = NIM_NIL;
	result = newTypeS__semdata_763(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 56), c);
	if ((*result).sons) { nimGCunrefNoCycle((*result).sons); (*result).sons = NIM_NIL; }
	(*result).sons = (tySequence__vKogasEnJSPhbQmA8r4Y9aA*) newSeqRC1((&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_), 2);
	asgnRef((void**) (&(*result).sons->data[0]), t1);
	asgnRef((void**) (&(*result).sons->data[1]), t2);
	propagateToOwner__ast_4207(result, t1, NIM_TRUE);
	propagateToOwner__ast_4207(result, t2, NIM_TRUE);
	(*result).flags = ((*result).flags | (((*t1).flags | (*t2).flags) & 16777216));
	(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 21)) & 63);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, makeOrType__semdata_920)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t1, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t2) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	result = NIM_NIL;
	result = newTypeS__semdata_763(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 57), c);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*t1).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 57)));
		if (!(T3_)) goto LA4_;
		T3_ = !(((*t2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 57)));
		LA4_: ;
		if (!T3_) goto LA5_;
		if ((*result).sons) { nimGCunrefNoCycle((*result).sons); (*result).sons = NIM_NIL; }
		(*result).sons = (tySequence__vKogasEnJSPhbQmA8r4Y9aA*) newSeqRC1((&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_), 2);
		asgnRef((void**) (&(*result).sons->data[0]), t1);
		asgnRef((void**) (&(*result).sons->data[1]), t2);
	}
	goto LA1_;
	LA5_: ;
	{
		{
			if (!((*t1).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 57))) goto LA10_;
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA** xX60gensym99_;
				NI i;
				NI L;
				NI T13_;
				xX60gensym99_ = (tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA**)0;
				i = ((NI) 0);
				T13_ = ((*t1).sons ? (*t1).sons->Sup.len : 0);
				L = T13_;
				{
					while (1) {
						if (!(i < L)) goto LA15;
						xX60gensym99_ = &(*t1).sons->data[i];
						rawAddSon__ast_4276(result, (*xX60gensym99_), NIM_TRUE);
						i += ((NI) 1);
					} LA15: ;
				}
			}
		}
		goto LA8_;
		LA10_: ;
		{
			rawAddSon__ast_4276(result, t1, NIM_TRUE);
		}
		LA8_: ;
		{
			if (!((*t2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 57))) goto LA19_;
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA** xX60gensym100_;
				NI i_2;
				NI L_2;
				NI T22_;
				xX60gensym100_ = (tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA**)0;
				i_2 = ((NI) 0);
				T22_ = ((*t2).sons ? (*t2).sons->Sup.len : 0);
				L_2 = T22_;
				{
					while (1) {
						if (!(i_2 < L_2)) goto LA24;
						xX60gensym100_ = &(*t2).sons->data[i_2];
						rawAddSon__ast_4276(result, (*xX60gensym100_), NIM_TRUE);
						i_2 += ((NI) 1);
					} LA24: ;
				}
			}
		}
		goto LA17_;
		LA19_: ;
		{
			rawAddSon__ast_4276(result, t2, NIM_TRUE);
		}
		LA17_: ;
	}
	LA1_: ;
	propagateToOwner__ast_4207(result, t1, NIM_TRUE);
	propagateToOwner__ast_4207(result, t2, NIM_TRUE);
	(*result).flags = ((*result).flags | (((*t1).flags | (*t2).flags) & 16777216));
	(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 21)) & 63);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, makeNotType__semdata_975)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t1) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	result = NIM_NIL;
	result = newTypeS__semdata_763(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 58), c);
	if ((*result).sons) { nimGCunrefNoCycle((*result).sons); (*result).sons = NIM_NIL; }
	(*result).sons = (tySequence__vKogasEnJSPhbQmA8r4Y9aA*) newSeqRC1((&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_), 1);
	asgnRef((void**) (&(*result).sons->data[0]), t1);
	propagateToOwner__ast_4207(result, t1, NIM_TRUE);
	(*result).flags = ((*result).flags | ((*t1).flags & 16777216));
	(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 21)) & 63);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkMinSonsLen__semdata_1114)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI length, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__ast_3155(n);
		if (!(T3_ < length)) goto LA4_;
		illFormedAst__semdata_1101(n, conf);
	}
	LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, pushOwner__semdata_334)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner) {
	NI T1_;
	asgnRef((void**) (&(*(*c).graph).owners), (tySequence__ed0C0uAUZPhvw3RAc5hfYg*) incrSeqV3((TGenericSeq*)((*(*c).graph).owners), (&NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_)));
	T1_ = (*(*c).graph).owners->Sup.len++;
	asgnRef((void**) (&(*(*c).graph).owners->data[T1_]), owner);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, errorNode__semdata_1039)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1), (*n).info);
	asgnRef((void**) (&(*result).typ), errorType__semdata_1032(c));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addToGenericProcCache__semdata_1215)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst) {
	tySequence__6OFCSvqRaxyEgUqWtnZSlw* T1_;
	tySequence__6OFCSvqRaxyEgUqWtnZSlw** T2_;
	tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q T3_;
	NI T4_;
	T1_ = NIM_NIL;
	T1_ = NIM_NIL;
	T2_ = (tySequence__6OFCSvqRaxyEgUqWtnZSlw**)0;
	T2_ = mgetOrPut__semdata_1249((&(*(*c).graph).procInstCache), (*s).Sup.itemId, T1_);
	nimZeroMem((void*)(&T3_), sizeof(tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q));
	nimZeroMem((void*)(&T3_), sizeof(tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q));
	T3_.module = (*(*c).module).position;
	T3_.inst = inst;
	unsureAsgnRef((void**) (&(*T2_)), (tySequence__6OFCSvqRaxyEgUqWtnZSlw*) incrSeqV3((TGenericSeq*)((*T2_)), (&NTIseqLlazyinstantiationT__6OFCSvqRaxyEgUqWtnZSlw_)));
	T4_ = (*T2_)->Sup.len++;
	(*T2_)->data[T4_].module = T3_.module;
	(*T2_)->data[T4_].sym = T3_.sym;
	genericSeqAssign((&(*T2_)->data[T4_].concreteTypes), T3_.concreteTypes, (&NTIseqLfullidT__UnGSk9aaLosDroi2QDrlOfQ_));
	asgnRef((void**) (&(*T2_)->data[T4_].inst), T3_.inst);
	{
		if (!!(((*(*(*c).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0)))) goto LA7_;
		storeInstantiation__icZic_3074((&(*(*c).graph).encoders->data[(*(*c).module).position]), (&(*(*c).graph).packed_0->data[(*(*c).module).position].fromDisk), s, inst);
	}
	LA7_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, makeInstPair__semdata_309)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst, tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w* Result) {
	unsureAsgnRef((void**)&(*Result).genericSym, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).inst, NIM_NIL);
	unsureAsgnRef((void**) (&(*Result).genericSym), s);
	unsureAsgnRef((void**) (&(*Result).inst), inst);
}
N_LIB_PRIVATE N_NIMCALL(void, addPragmaComputation__semdata_648)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		if (!!(((*(*(*c).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0)))) goto LA3_;
		addPragmaComputation__icZic_3030((&(*(*c).graph).encoders->data[(*(*c).module).position]), (&(*(*c).graph).packed_0->data[(*(*c).module).position].fromDisk), n);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg*, newLib__semdata_754)(tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind) {
	tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* result;
	result = NIM_NIL;
	result = (tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg*) newObj((&NTIplib__cpB5Ba1r1YF5UAlBgbtl8g_), sizeof(tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg));
	(*result).kind = kind;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addToLib__semdata_760)(tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* lib, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym) {
	asgnRef((void**) (&(*sym).annex), lib);
}
static N_INLINE(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q**, X5BX5D___semdata_356)(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q** s, NI sLen_0, NI i) {
	tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q** result;
	result = (tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q**)0;
	result = &s[(NI)(sLen_0 - i)];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q*, pushOptionEntry__semdata_474)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c) {
	tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q* result;
	tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q* prev;
	tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q** T1_;
	NI T2_;
	result = NIM_NIL;
	result = (tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q*) newObj((&NTIpoptionentry__BSbNT2MZJsNcSq6BlR6KPQ_), sizeof(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q));
	T1_ = (tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q**)0;
	T1_ = X5BX5D___semdata_356(((*c).optionStack) ? ((*c).optionStack->data) : NIM_NIL, ((*c).optionStack ? (*c).optionStack->Sup.len : 0), ((NI) 1));
	prev = (*T1_);
	(*result).options = (*(*(*c).graph).config).options;
	(*result).defaultCC = (*prev).defaultCC;
	asgnRef((void**) (&(*result).dynlib), (*prev).dynlib);
	nimCopyMem((void*)(*result).notes, (NIM_CONST void*)(*(*(*c).graph).config).notes, 12);
	nimCopyMem((void*)(*result).warningAsErrors, (NIM_CONST void*)(*(*(*c).graph).config).warningAsErrors, 12);
	(*result).features = (*c).features;
	asgnRef((void**) (&(*c).optionStack), (tySequence__vvBerF0axaNtu9aMA2gnsrA*) incrSeqV3((TGenericSeq*)((*c).optionStack), (&NTIseqLpoptionentryT__vvBerF0axaNtu9aMA2gnsrA_)));
	T2_ = (*c).optionStack->Sup.len++;
	asgnRef((void**) (&(*c).optionStack->data[T2_]), result);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, popOptionEntry__semdata_489)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c) {
	tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q** T1_;
	tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q** T2_;
	tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q** T3_;
	tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q** T4_;
	NI T5_;
	T1_ = (tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q**)0;
	T1_ = X5BX5D___semdata_356(((*c).optionStack) ? ((*c).optionStack->data) : NIM_NIL, ((*c).optionStack ? (*c).optionStack->Sup.len : 0), ((NI) 1));
	(*(*(*c).graph).config).options = (*(*T1_)).options;
	T2_ = (tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q**)0;
	T2_ = X5BX5D___semdata_356(((*c).optionStack) ? ((*c).optionStack->data) : NIM_NIL, ((*c).optionStack ? (*c).optionStack->Sup.len : 0), ((NI) 1));
	nimCopyMem((void*)(*(*(*c).graph).config).notes, (NIM_CONST void*)(*(*T2_)).notes, 12);
	T3_ = (tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q**)0;
	T3_ = X5BX5D___semdata_356(((*c).optionStack) ? ((*c).optionStack->data) : NIM_NIL, ((*c).optionStack ? (*c).optionStack->Sup.len : 0), ((NI) 1));
	nimCopyMem((void*)(*(*(*c).graph).config).warningAsErrors, (NIM_CONST void*)(*(*T3_)).warningAsErrors, 12);
	T4_ = (tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q**)0;
	T4_ = X5BX5D___semdata_356(((*c).optionStack) ? ((*c).optionStack->data) : NIM_NIL, ((*c).optionStack ? (*c).optionStack->Sup.len : 0), ((NI) 1));
	(*c).features = (*(*T4_)).features;
	T5_ = ((*c).optionStack ? (*c).optionStack->Sup.len : 0);
	asgnRef((void**) (&(*c).optionStack), (tySequence__vvBerF0axaNtu9aMA2gnsrA*) setLengthSeqV2(((*c).optionStack)?&((*c).optionStack)->Sup:NIM_NIL, (&NTIseqLpoptionentryT__vvBerF0axaNtu9aMA2gnsrA_), ((NI) ((NI)(T5_ - ((NI) 1))))));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q*, lastOptionEntry__semdata_353)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c) {
	tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q* result;
	tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q** T1_;
	result = NIM_NIL;
	T1_ = (tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q**)0;
	T1_ = X5BX5D___semdata_356(((*c).optionStack) ? ((*c).optionStack->data) : NIM_NIL, ((*c).optionStack ? (*c).optionStack->Sup.len : 0), ((NI) 1));
	result = (*T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, inclSym__semdata_655)(tySequence__ed0C0uAUZPhvw3RAc5hfYg** sq, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NIM_BOOL result;
	NI T9_;
{	result = (NIM_BOOL)0;
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = ((*sq) ? (*sq)->Sup.len : 0);
		colontmp_ = T2_;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				{
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym52_;
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym53_;
					xX60gensym52_ = (*sq)->data[i];
					xX60gensym53_ = s;
					if (!((NI)((NI)((NU64)(((NI) ((*xX60gensym52_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym52_).Sup.itemId.item))) == (NI)((NI)((NU64)(((NI) ((*xX60gensym53_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym53_).Sup.itemId.item))))) goto LA7_;
					result = NIM_FALSE;
					goto BeforeRet_;
				}
				LA7_: ;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	unsureAsgnRef((void**) (&(*sq)), (tySequence__ed0C0uAUZPhvw3RAc5hfYg*) incrSeqV3((TGenericSeq*)((*sq)), (&NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_)));
	T9_ = (*sq)->Sup.len++;
	asgnRef((void**) (&(*sq)->data[T9_]), s);
	result = NIM_TRUE;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addPattern__semdata_722)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg p) {
	{
		NIM_BOOL T3_;
		NI T6_;
		T3_ = (NIM_BOOL)0;
		T3_ = inclSym__semdata_655((&(*c).patterns), p.sym);
		if (!T3_) goto LA4_;
		asgnRef((void**) (&(*(*c).graph).ifaces->data[(*(*c).module).position].patterns), (tySequence__qeAsXh2i1GAL5Nl0g3OP8g*) incrSeqV3((TGenericSeq*)((*(*c).graph).ifaces->data[(*(*c).module).position].patterns), (&NTIseqLlazysymT__qeAsXh2i1GAL5Nl0g3OP8g_)));
		T6_ = (*(*c).graph).ifaces->data[(*(*c).module).position].patterns->Sup.len++;
		(*(*c).graph).ifaces->data[(*(*c).module).position].patterns->data[T6_].id = p.id;
		asgnRef((void**) (&(*(*c).graph).ifaces->data[(*(*c).module).position].patterns->data[T6_].sym), p.sym);
	}
	LA4_: ;
	{
		if (!!(((*(*(*c).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0)))) goto LA9_;
		addTrmacro__icZic_2358((&(*(*c).graph).encoders->data[(*(*c).module).position]), (&(*(*c).graph).packed_0->data[(*(*c).module).position].fromDisk), p.sym);
	}
	LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, popOwner__semdata_341)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c) {
	{
		NI T3_;
		NI T6_;
		T3_ = ((*(*c).graph).owners ? (*(*c).graph).owners->Sup.len : 0);
		if (!(((NI) 0) < T3_)) goto LA4_;
		T6_ = ((*(*c).graph).owners ? (*(*c).graph).owners->Sup.len : 0);
		asgnRef((void**) (&(*(*c).graph).owners), (tySequence__ed0C0uAUZPhvw3RAc5hfYg*) setLengthSeqV2(((*(*c).graph).owners)?&((*(*c).graph).owners)->Sup:NIM_NIL, (&NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_), ((NI) ((NI)(T6_ - ((NI) 1))))));
	}
	goto LA1_;
	LA4_: ;
	{
		internalErrorImpl__msgs_1441((*(*c).graph).config, unknownLineInfo__lineinfos_284, ((NimStringDesc*) &TM__6kkF5shvTYOHG9cWBoBNLPQ_26), TM__6kkF5shvTYOHG9cWBoBNLPQ_27);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, makePtrType__semdata_772)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* baseType) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = getCurrOwner__semdata_327(c);
	result = makePtrType__semdata_767(T1_, baseType, (*c).Sup.idgen);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, newTypeWithSons__semdata_845)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind, tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T1_;
	result = NIM_NIL;
	T1_ = nextTypeId__ast_3122(idgen);
	result = newType__ast_3884(kind, T1_, owner);
	genericSeqAssign((&(*result).sons), sons, (&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, nMinusOne__semdata_996)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyArray__Nfk9cOEzg2bRz9c1V8fGzONg T1_;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T2_;
	result = NIM_NIL;
	nimZeroMem((void*)T1_, sizeof(tyArray__Nfk9cOEzg2bRz9c1V8fGzONg));
	T2_ = NIM_NIL;
	T2_ = getSysMagic__magicsys_29((*c).graph, (*n).info, ((NimStringDesc*) &TM__6kkF5shvTYOHG9cWBoBNLPQ_28), ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 52));
	T1_[0] = newSymNode__ast_3704(T2_);
	T1_[1] = n;
	result = newTreeI__ast_3384(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27), (*n).info, T1_, 2);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, makeRangeWithStaticExpr__semdata_1009)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* intType;
	tyArray__Nfk9cOEzg2bRz9c1V8fGzONg T7_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T8_;
	result = NIM_NIL;
	intType = getSysType__magicsys_60((*c).graph, (*n).info, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31));
	result = newTypeS__semdata_763(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 20), c);
	if ((*result).sons) { nimGCunrefNoCycle((*result).sons); (*result).sons = NIM_NIL; }
	(*result).sons = (tySequence__vKogasEnJSPhbQmA8r4Y9aA*) newSeqRC1((&NTIttypeseq__vKogasEnJSPhbQmA8r4Y9aA_), 1);
	asgnRef((void**) (&(*result).sons->data[0]), intType);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*n).typ).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
		LA4_: ;
		if (!T3_) goto LA5_;
		(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 9)) & 63);
	}
	LA5_: ;
	nimZeroMem((void*)T7_, sizeof(tyArray__Nfk9cOEzg2bRz9c1V8fGzONg));
	T7_[0] = newIntTypeNode__ast_3771(IL64(0), intType);
	T8_ = NIM_NIL;
	T8_ = nMinusOne__semdata_996(c, n);
	T7_[1] = makeStaticExpr__semdata_856(c, T8_);
	asgnRef((void**) (&(*result).n), newTreeI__ast_3384(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 44), (*n).info, T7_, 2));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, makeTypeWithModifier__semdata_776)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg modifier, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* baseType) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (modifier == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || modifier == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 47) || modifier == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8));
		if (!(T3_)) goto LA4_;
		T3_ = ((*baseType).kind == modifier);
		LA4_: ;
		if (!T3_) goto LA5_;
		result = baseType;
	}
	goto LA1_;
	LA5_: ;
	{
		result = newTypeS__semdata_763(modifier, c);
		addSonSkipIntLit__magicsys_136(result, baseType, (*c).Sup.idgen);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addPureEnum__semdata_704)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg e) {
	NI T1_;
	asgnRef((void**) (&(*(*c).graph).ifaces->data[(*(*c).module).position].pureEnums), (tySequence__qeAsXh2i1GAL5Nl0g3OP8g*) incrSeqV3((TGenericSeq*)((*(*c).graph).ifaces->data[(*(*c).module).position].pureEnums), (&NTIseqLlazysymT__qeAsXh2i1GAL5Nl0g3OP8g_)));
	T1_ = (*(*c).graph).ifaces->data[(*(*c).module).position].pureEnums->Sup.len++;
	(*(*c).graph).ifaces->data[(*(*c).module).position].pureEnums->data[T1_].id = e.id;
	asgnRef((void**) (&(*(*c).graph).ifaces->data[(*(*c).module).position].pureEnums->data[T1_].sym), e.sym);
	{
		if (!!(((*(*(*c).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0)))) goto LA4_;
		addPureEnum__icZic_2366((&(*(*c).graph).encoders->data[(*(*c).module).position]), (&(*(*c).graph).packed_0->data[(*(*c).module).position].fromDisk), e.sym);
	}
	LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, getIntLitType__semdata_229)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* literal) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	NI64 value;
	result = NIM_NIL;
	value = (*literal)._kind_1.intVal;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (IL64(-5) <= value);
		if (!(T3_)) goto LA4_;
		T3_ = (value <= IL64(32));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = (*c).intTypeCache[(((NI) (value)))- -5];
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ti;
			tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T11_;
			if (!(result == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA9_;
			ti = getSysType__magicsys_60((*c).graph, (*literal).info, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31));
			T11_ = nextTypeId__ast_3122((*c).Sup.idgen);
			result = copyType__ast_4034(ti, T11_, (*ti).owner);
			asgnRef((void**) (&(*result).n), literal);
			asgnRef((void**) (&(*c).intTypeCache[(((NI) (value)))- -5]), result);
		}
		LA9_: ;
	}
	goto LA1_;
	LA5_: ;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ti_2;
		tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T13_;
		ti_2 = getSysType__magicsys_60((*c).graph, (*literal).info, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31));
		T13_ = nextTypeId__ast_3122((*c).Sup.idgen);
		result = copyType__ast_4034(ti_2, T13_, (*ti_2).owner);
		asgnRef((void**) (&(*result).n), literal);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setIntLitType__semdata_257)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result) {
	NI64 i;
	i = (*result)._kind_1.intVal;
	switch ((*(*(*c).graph).config).target.intSize) {
	case ((NI) 8):
	{
		asgnRef((void**) (&(*result).typ), getIntLitType__semdata_229(c, result));
	}
	break;
	case ((NI) 4):
	{
		{
			NIM_BOOL T5_;
			T5_ = (NIM_BOOL)0;
			T5_ = (IL64(-2147483648) <= i);
			if (!(T5_)) goto LA6_;
			T5_ = (i <= IL64(2147483647));
			LA6_: ;
			if (!T5_) goto LA7_;
			asgnRef((void**) (&(*result).typ), getIntLitType__semdata_229(c, result));
		}
		goto LA3_;
		LA7_: ;
		{
			asgnRef((void**) (&(*result).typ), getSysType__magicsys_60((*c).graph, (*result).info, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35)));
		}
		LA3_: ;
	}
	break;
	case ((NI) 2):
	{
		{
			NIM_BOOL T13_;
			T13_ = (NIM_BOOL)0;
			T13_ = (IL64(-32768) <= i);
			if (!(T13_)) goto LA14_;
			T13_ = (i <= IL64(32767));
			LA14_: ;
			if (!T13_) goto LA15_;
			asgnRef((void**) (&(*result).typ), getIntLitType__semdata_229(c, result));
		}
		goto LA11_;
		LA15_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = (IL64(-2147483648) <= i);
			if (!(T18_)) goto LA19_;
			T18_ = (i <= IL64(2147483647));
			LA19_: ;
			if (!T18_) goto LA20_;
			asgnRef((void**) (&(*result).typ), getSysType__magicsys_60((*c).graph, (*result).info, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 34)));
		}
		goto LA11_;
		LA20_: ;
		{
			asgnRef((void**) (&(*result).typ), getSysType__magicsys_60((*c).graph, (*result).info, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35)));
		}
		LA11_: ;
	}
	break;
	case ((NI) 1):
	{
		{
			NIM_BOOL T26_;
			T26_ = (NIM_BOOL)0;
			T26_ = (IL64(-128) <= i);
			if (!(T26_)) goto LA27_;
			T26_ = (i <= IL64(127));
			LA27_: ;
			if (!T26_) goto LA28_;
			asgnRef((void**) (&(*result).typ), getIntLitType__semdata_229(c, result));
		}
		goto LA24_;
		LA28_: ;
		{
			NIM_BOOL T31_;
			T31_ = (NIM_BOOL)0;
			T31_ = (IL64(-32768) <= i);
			if (!(T31_)) goto LA32_;
			T31_ = (i <= IL64(32767));
			LA32_: ;
			if (!T31_) goto LA33_;
			asgnRef((void**) (&(*result).typ), getSysType__magicsys_60((*c).graph, (*result).info, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 33)));
		}
		goto LA24_;
		LA33_: ;
		{
			NIM_BOOL T36_;
			T36_ = (NIM_BOOL)0;
			T36_ = (IL64(-2147483648) <= i);
			if (!(T36_)) goto LA37_;
			T36_ = (i <= IL64(2147483647));
			LA37_: ;
			if (!T36_) goto LA38_;
			asgnRef((void**) (&(*result).typ), getSysType__magicsys_60((*c).graph, (*result).info, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 34)));
		}
		goto LA24_;
		LA38_: ;
		{
			asgnRef((void**) (&(*result).typ), getSysType__magicsys_60((*c).graph, (*result).info, ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35)));
		}
		LA24_: ;
	}
	break;
	default:
	{
		internalErrorImpl__msgs_1441((*(*c).graph).config, (*result).info, ((NimStringDesc*) &TM__6kkF5shvTYOHG9cWBoBNLPQ_29), TM__6kkF5shvTYOHG9cWBoBNLPQ_30);
	}
	break;
	}
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x) {
	addInt__stdZprivateZdigitsutils_167(result, ((NI64) (x)));
}
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_625)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = resizeString(result, (info.Field0 ? info.Field0->Sup.len : 0) + 0);
appendString(result, info.Field0);
	{
		if (!(((NI) 0) < info.Field1)) goto LA3_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__6kkF5shvTYOHG9cWBoBNLPQ_31));
		addInt__stdZprivateZdigitsutils_189((&result), info.Field1);
		{
			if (!(((NI) 0) < (NI)(info.Field2 + ((NI) 1)))) goto LA7_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__6kkF5shvTYOHG9cWBoBNLPQ_32));
			addInt__stdZprivateZdigitsutils_189((&result), (NI)(info.Field2 + ((NI) 1)));
		}
		LA7_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__6kkF5shvTYOHG9cWBoBNLPQ_33));
	}
	LA3_: ;
	return result;
}
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextSymId__ast_3103)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x) {
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*x).symId += ((NI) 1);
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	result.module = (*x).module;
	result.item = (*x).symId;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, makeTypeSymNode__semdata_815)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typedesc;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T5_;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T6_;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T7_;
	result = NIM_NIL;
	typedesc = newTypeS__semdata_763(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8), c);
	(*typedesc).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 38)) & 63);
	{
		NimStringDesc* argX60gensym89_;
		if (!!(!((typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))))) goto LA3_;
		argX60gensym89_ = toFileLineCol__msgs_625(TM__6kkF5shvTYOHG9cWBoBNLPQ_34);
		internalErrorImpl__msgs_1441((*(*c).graph).config, unknownLineInfo__lineinfos_284, argX60gensym89_, TM__6kkF5shvTYOHG9cWBoBNLPQ_34);
	}
	LA3_: ;
	addSonSkipIntLit__magicsys_136(typedesc, typ, (*c).Sup.idgen);
	T5_ = nextSymId__ast_3103((*c).Sup.idgen);
	T6_ = NIM_NIL;
	T6_ = getCurrOwner__semdata_327(c);
	T7_ = NIM_NIL;
	T7_ = newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 7), (*(*c).cache).idAnon, T5_, T6_, info, (*(*(*c).graph).config).options);
	sym = linkTo__ast_3511(T7_, typedesc);
	result = newSymNode__ast_3707(sym, info);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pushCaseContext__semdata_1135)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* caseNode) {
	tyTuple__2E9aYKv1U4zUZsR6wkNRkPg T1_;
	NI T2_;
	nimZeroMem((void*)(&T1_), sizeof(tyTuple__2E9aYKv1U4zUZsR6wkNRkPg));
	T1_.Field0 = caseNode;
	T1_.Field1 = ((NI) 0);
	asgnRef((void**) (&(*(*c).p).caseContext), (tySequence__cvxuM2UjDv0O3Q6FcDEAnw*) incrSeqV3((TGenericSeq*)((*(*c).p).caseContext), (&NTIseqLtupleLn58pnode_idx58intTT__cvxuM2UjDv0O3Q6FcDEAnw_)));
	T2_ = (*(*c).p).caseContext->Sup.len++;
	asgnRef((void**) (&(*(*c).p).caseContext->data[T2_].Field0), T1_.Field0);
	(*(*c).p).caseContext->data[T2_].Field1 = T1_.Field1;
}
static N_INLINE(void, pop__semdata_1153)(tySequence__cvxuM2UjDv0O3Q6FcDEAnw** s, tyTuple__2E9aYKv1U4zUZsR6wkNRkPg* Result) {
	NI L;
	NI T1_;
	T1_ = ((*s) ? (*s)->Sup.len : 0);
	L = (NI)(T1_ - ((NI) 1));
	unsureAsgnRef((void**) (&(*Result).Field0), (*s)->data[L].Field0);
	(*Result).Field1 = (*s)->data[L].Field1;
	unsureAsgnRef((void**) (&(*s)), (tySequence__cvxuM2UjDv0O3Q6FcDEAnw*) setLengthSeqV2(((*s))?&((*s))->Sup:NIM_NIL, (&NTIseqLtupleLn58pnode_idx58intTT__cvxuM2UjDv0O3Q6FcDEAnw_), ((NI) (L))));
}
N_LIB_PRIVATE N_NIMCALL(void, popCaseContext__semdata_1151)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c) {
	tyTuple__2E9aYKv1U4zUZsR6wkNRkPg T1_;
	nimZeroMem((void*)(&T1_), sizeof(tyTuple__2E9aYKv1U4zUZsR6wkNRkPg));
	pop__semdata_1153((&(*(*c).p).caseContext), (&T1_));
	(void)(T1_);
}
static N_INLINE(tyTuple__2E9aYKv1U4zUZsR6wkNRkPg*, X5BX5D___semdata_1169)(tyTuple__2E9aYKv1U4zUZsR6wkNRkPg* s, NI sLen_0, NI i) {
	tyTuple__2E9aYKv1U4zUZsR6wkNRkPg* result;
	result = (tyTuple__2E9aYKv1U4zUZsR6wkNRkPg*)0;
	result = (&s[(NI)(sLen_0 - i)]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setCaseContextIdx__semdata_1166)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, NI idx) {
	tyTuple__2E9aYKv1U4zUZsR6wkNRkPg* T1_;
	T1_ = (tyTuple__2E9aYKv1U4zUZsR6wkNRkPg*)0;
	T1_ = X5BX5D___semdata_1169(((*(*c).p).caseContext) ? ((*(*c).p).caseContext->data) : NIM_NIL, ((*(*c).p).caseContext ? (*(*c).p).caseContext->Sup.len : 0), ((NI) 1));
	(*T1_).Field1 = idx;
}
N_LIB_PRIVATE N_NIMCALL(void, addConverter__semdata_683)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg conv) {
	{
		NIM_BOOL T3_;
		NI T6_;
		T3_ = (NIM_BOOL)0;
		T3_ = inclSym__semdata_655((&(*c).converters), conv.sym);
		if (!T3_) goto LA4_;
		asgnRef((void**) (&(*(*c).graph).ifaces->data[(*(*c).module).position].converters), (tySequence__qeAsXh2i1GAL5Nl0g3OP8g*) incrSeqV3((TGenericSeq*)((*(*c).graph).ifaces->data[(*(*c).module).position].converters), (&NTIseqLlazysymT__qeAsXh2i1GAL5Nl0g3OP8g_)));
		T6_ = (*(*c).graph).ifaces->data[(*(*c).module).position].converters->Sup.len++;
		(*(*c).graph).ifaces->data[(*(*c).module).position].converters->data[T6_].id = conv.id;
		asgnRef((void**) (&(*(*c).graph).ifaces->data[(*(*c).module).position].converters->data[T6_].sym), conv.sym);
	}
	LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addConverterDef__semdata_697)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg conv) {
	addConverter__semdata_683(c, conv);
	{
		if (!!(((*(*(*c).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0)))) goto LA3_;
		addConverter__icZic_2347((&(*(*c).graph).encoders->data[(*(*c).module).position]), (&(*(*c).graph).packed_0->data[(*(*c).module).position].fromDisk), conv.sym);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addImportFileDep__semdata_641)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, NI32 f) {
	{
		if (!!(((*(*(*c).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0)))) goto LA3_;
		addImportFileDep__icZic_2300((&(*(*c).graph).encoders->data[(*(*c).module).position]), (&(*(*c).graph).packed_0->data[(*(*c).module).position].fromDisk), f);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addIncludeFileDep__semdata_634)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, NI32 f) {
	{
		if (!!(((*(*(*c).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0)))) goto LA3_;
		addIncludeFileDep__icZic_2292((&(*(*c).graph).encoders->data[(*(*c).module).position]), (&(*(*c).graph).packed_0->data[(*(*c).module).position].fromDisk), f);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, reexportSym__semdata_747)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	strTableAdds__modulegraphs_2706((*c).graph, (*c).module, s);
	{
		if (!!(((*(*(*c).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0)))) goto LA3_;
		addReexport__icZic_2389((&(*(*c).graph).encoders->data[(*(*c).module).position]), (&(*(*c).graph).packed_0->data[(*(*c).module).position].fromDisk), s);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeRodNode__semdata_1208)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		if (!!(((*(*(*c).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0)))) goto LA3_;
		toPackedNodeTopLevel__icZic_3059(n, (&(*(*c).graph).encoders->data[(*(*c).module).position]), (&(*(*c).graph).packed_0->data[(*(*c).module).position].fromDisk));
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, sealRodFile__semdata_3633)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c) {
	{
		if (!!(((*(*(*c).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0)))) goto LA3_;
		{
			if (!!(((*(*c).graph).vm == ((RootObj*) NIM_NIL)))) goto LA7_;
			{
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw** m;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** n;
				tySequence__ztPIC2M9bqhs0KjYuE9c9cN8g* colontmp_;
				NI i;
				NI L;
				NI T10_;
				m = (tyObject_TSym__3r34mwqcVmg5JFNmiaVncw**)0;
				n = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
				colontmp_ = NIM_NIL;
				colontmp_ = (*(*((tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ**) (&((*(*c).graph).vm))))).vmstateDiff;
				i = ((NI) 0);
				T10_ = (colontmp_ ? colontmp_->Sup.len : 0);
				L = T10_;
				{
					while (1) {
						if (!(i < L)) goto LA12;
						m = &colontmp_->data[i].Field0;
						n = &colontmp_->data[i].Field1;
						{
							if (!((*m) == (*c).module)) goto LA15_;
							addPragmaComputation__semdata_648(c, (*n));
						}
						LA15_: ;
						i += ((NI) 1);
					} LA12: ;
				}
			}
		}
		LA7_: ;
		(*(*c).Sup.idgen).sealed = NIM_TRUE;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, atmsemdatadotnim_DatInit000)(void) {
static TNimNode* TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[65];
static TNimNode* TM__6kkF5shvTYOHG9cWBoBNLPQ_3_2[2];
static TNimNode* TM__6kkF5shvTYOHG9cWBoBNLPQ_4_3[3];
NI TM__6kkF5shvTYOHG9cWBoBNLPQ_6;
static char* NIM_CONST TM__6kkF5shvTYOHG9cWBoBNLPQ_5[3] = {
"importAll", 
"importSet", 
"importExcept"};
static TNimNode* TM__6kkF5shvTYOHG9cWBoBNLPQ_7_10[10];
static TNimNode* TM__6kkF5shvTYOHG9cWBoBNLPQ_8_2[2];
static TNimNode* TM__6kkF5shvTYOHG9cWBoBNLPQ_9_3[3];
static TNimNode* TM__6kkF5shvTYOHG9cWBoBNLPQ_10_7[7];
static TNimNode* TM__6kkF5shvTYOHG9cWBoBNLPQ_11_2[2];
static TNimNode* TM__6kkF5shvTYOHG9cWBoBNLPQ_12_2[2];
static TNimNode* TM__6kkF5shvTYOHG9cWBoBNLPQ_13_2[2];
static TNimNode* TM__6kkF5shvTYOHG9cWBoBNLPQ_14_2[2];
static TNimNode* TM__6kkF5shvTYOHG9cWBoBNLPQ_15_2[2];
static TNimNode* TM__6kkF5shvTYOHG9cWBoBNLPQ_16_2[2];
static TNimNode* TM__6kkF5shvTYOHG9cWBoBNLPQ_17_2[2];
static TNimNode* TM__6kkF5shvTYOHG9cWBoBNLPQ_18_2[2];
static TNimNode* TM__6kkF5shvTYOHG9cWBoBNLPQ_19_3[3];
static TNimNode* TM__6kkF5shvTYOHG9cWBoBNLPQ_20_2[2];
static TNimNode* TM__6kkF5shvTYOHG9cWBoBNLPQ_21_2[2];
static TNimNode* TM__6kkF5shvTYOHG9cWBoBNLPQ_22_3[3];
static TNimNode TM__6kkF5shvTYOHG9cWBoBNLPQ_0[140];
NTItcontext__TE0bwjD2I16QW6s9c4AgPvw_.size = sizeof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw);
NTItcontext__TE0bwjD2I16QW6s9c4AgPvw_.align = NIM_ALIGNOF(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw);
NTItcontext__TE0bwjD2I16QW6s9c4AgPvw_.kind = 17;
NTItcontext__TE0bwjD2I16QW6s9c4AgPvw_.base = (&NTItpasscontext__dmp6pRpfXxJk6gIZHkm7dw_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[0] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[1];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[1].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[1].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, enforceVoidContext);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[1].typ = (&NTIptype__q1v0zzhoMWrhMLs6UEp1IA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[1].name = "enforceVoidContext";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[1] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[2];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[2].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[2].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, voidType);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[2].typ = (&NTIptype__q1v0zzhoMWrhMLs6UEp1IA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[2].name = "voidType";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[2] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[3];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[3].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[3].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, module);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[3].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[3].name = "module";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[3] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[4];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[4].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[4].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, currentScope);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[4].typ = (&NTIpscope__1WBIpqNgZhwC9bV4356CRhQ_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[4].name = "currentScope";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[4] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[5];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[5].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[5].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, moduleScope);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[5].typ = (&NTIpscope__1WBIpqNgZhwC9bV4356CRhQ_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[5].name = "moduleScope";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[5] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[6];
NTIimportedmodule__ABXo2nVfMtcWNYv5zEiXDg_.size = sizeof(tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg);
NTIimportedmodule__ABXo2nVfMtcWNYv5zEiXDg_.align = NIM_ALIGNOF(tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg);
NTIimportedmodule__ABXo2nVfMtcWNYv5zEiXDg_.kind = 18;
NTIimportedmodule__ABXo2nVfMtcWNYv5zEiXDg_.base = 0;
NTIimportedmodule__ABXo2nVfMtcWNYv5zEiXDg_.flags = 2;
TM__6kkF5shvTYOHG9cWBoBNLPQ_3_2[0] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[8];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[8].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[8].offset = offsetof(tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg, m);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[8].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[8].name = "m";
TM__6kkF5shvTYOHG9cWBoBNLPQ_3_2[1] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[9];
NTIimportmode__4kYBzhtdX1Hkta8RDDKjrQ_.size = sizeof(tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ);
NTIimportmode__4kYBzhtdX1Hkta8RDDKjrQ_.align = NIM_ALIGNOF(tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ);
NTIimportmode__4kYBzhtdX1Hkta8RDDKjrQ_.kind = 14;
NTIimportmode__4kYBzhtdX1Hkta8RDDKjrQ_.base = 0;
NTIimportmode__4kYBzhtdX1Hkta8RDDKjrQ_.flags = 3;
for (TM__6kkF5shvTYOHG9cWBoBNLPQ_6 = 0; TM__6kkF5shvTYOHG9cWBoBNLPQ_6 < 3; TM__6kkF5shvTYOHG9cWBoBNLPQ_6++) {
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[TM__6kkF5shvTYOHG9cWBoBNLPQ_6+10].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[TM__6kkF5shvTYOHG9cWBoBNLPQ_6+10].offset = TM__6kkF5shvTYOHG9cWBoBNLPQ_6;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[TM__6kkF5shvTYOHG9cWBoBNLPQ_6+10].name = TM__6kkF5shvTYOHG9cWBoBNLPQ_5[TM__6kkF5shvTYOHG9cWBoBNLPQ_6];
TM__6kkF5shvTYOHG9cWBoBNLPQ_4_3[TM__6kkF5shvTYOHG9cWBoBNLPQ_6] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[TM__6kkF5shvTYOHG9cWBoBNLPQ_6+10];
}
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[13].len = 3; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[13].kind = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[13].sons = &TM__6kkF5shvTYOHG9cWBoBNLPQ_4_3[0];
NTIimportmode__4kYBzhtdX1Hkta8RDDKjrQ_.node = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[13];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[9].kind = 3;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[9].offset = offsetof(tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg, mode);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[9].typ = (&NTIimportmode__4kYBzhtdX1Hkta8RDDKjrQ_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[9].name = "mode";
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[9].sons = &NimDT___ABXo2nVfMtcWNYv5zEiXDg_mode[0];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[9].len = 3;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[14].len = 0; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[14].kind = 2;
NimDT___ABXo2nVfMtcWNYv5zEiXDg_mode[0] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[14];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[15].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[15].offset = offsetof(tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg, _mode_2.imported);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[15].typ = (&NTIpackedset__THXDbzJSs2hcC9a33en2pdw_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[15].name = "imported";
NimDT___ABXo2nVfMtcWNYv5zEiXDg_mode[1] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[15];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[16].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[16].offset = offsetof(tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg, _mode_3.exceptSet);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[16].typ = (&NTIpackedset__THXDbzJSs2hcC9a33en2pdw_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[16].name = "exceptSet";
NimDT___ABXo2nVfMtcWNYv5zEiXDg_mode[2] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[16];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[7].len = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[7].kind = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[7].sons = &TM__6kkF5shvTYOHG9cWBoBNLPQ_3_2[0];
NTIimportedmodule__ABXo2nVfMtcWNYv5zEiXDg_.node = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[7];
NTIseqLimportedmoduleT__9boKiNhY9cnRQF2k9b9a9bGKbrA_.size = sizeof(tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA*);
NTIseqLimportedmoduleT__9boKiNhY9cnRQF2k9b9a9bGKbrA_.align = NIM_ALIGNOF(tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA*);
NTIseqLimportedmoduleT__9boKiNhY9cnRQF2k9b9a9bGKbrA_.kind = 24;
NTIseqLimportedmoduleT__9boKiNhY9cnRQF2k9b9a9bGKbrA_.base = (&NTIimportedmodule__ABXo2nVfMtcWNYv5zEiXDg_);
NTIseqLimportedmoduleT__9boKiNhY9cnRQF2k9b9a9bGKbrA_.flags = 2;
NTIseqLimportedmoduleT__9boKiNhY9cnRQF2k9b9a9bGKbrA_.marker = Marker_tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[6].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[6].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, imports);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[6].typ = (&NTIseqLimportedmoduleT__9boKiNhY9cnRQF2k9b9a9bGKbrA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[6].name = "imports";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[6] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[17];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[17].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[17].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, topLevelScope);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[17].typ = (&NTIpscope__1WBIpqNgZhwC9bV4356CRhQ_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[17].name = "topLevelScope";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[7] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[18];
NTItproccon__9aK41DZ7WNm5NSRfb1CbcRA_.size = sizeof(tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA);
NTItproccon__9aK41DZ7WNm5NSRfb1CbcRA_.align = NIM_ALIGNOF(tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA);
NTItproccon__9aK41DZ7WNm5NSRfb1CbcRA_.kind = 18;
NTItproccon__9aK41DZ7WNm5NSRfb1CbcRA_.base = 0;
NTItproccon__9aK41DZ7WNm5NSRfb1CbcRA_.flags = 2;
TM__6kkF5shvTYOHG9cWBoBNLPQ_7_10[0] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[20];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[20].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[20].offset = offsetof(tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA, owner);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[20].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[20].name = "owner";
TM__6kkF5shvTYOHG9cWBoBNLPQ_7_10[1] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[21];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[21].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[21].offset = offsetof(tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA, resultSym);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[21].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[21].name = "resultSym";
TM__6kkF5shvTYOHG9cWBoBNLPQ_7_10[2] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[22];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[22].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[22].offset = offsetof(tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA, selfSym);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[22].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[22].name = "selfSym";
TM__6kkF5shvTYOHG9cWBoBNLPQ_7_10[3] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[23];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[23].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[23].offset = offsetof(tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA, nestedLoopCounter);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[23].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[23].name = "nestedLoopCounter";
TM__6kkF5shvTYOHG9cWBoBNLPQ_7_10[4] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[24];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[24].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[24].offset = offsetof(tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA, nestedBlockCounter);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[24].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[24].name = "nestedBlockCounter";
TM__6kkF5shvTYOHG9cWBoBNLPQ_7_10[5] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[25];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[25].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[25].offset = offsetof(tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA, next);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[25].typ = (&NTIpproccon__10LrMeEGcZEU1Ndh5rhoUg_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[25].name = "next";
TM__6kkF5shvTYOHG9cWBoBNLPQ_7_10[6] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[26];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[26].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[26].offset = offsetof(tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA, mappingExists);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[26].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[26].name = "mappingExists";
TM__6kkF5shvTYOHG9cWBoBNLPQ_7_10[7] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[27];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[27].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[27].offset = offsetof(tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA, mapping);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[27].typ = (&NTItidtable__Cs7vbulfMjKciTA2Uv9b6vQ_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[27].name = "mapping";
TM__6kkF5shvTYOHG9cWBoBNLPQ_7_10[8] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[28];
NTItupleLn58pnode_idx58intT__2E9aYKv1U4zUZsR6wkNRkPg_.size = sizeof(tyTuple__2E9aYKv1U4zUZsR6wkNRkPg);
NTItupleLn58pnode_idx58intT__2E9aYKv1U4zUZsR6wkNRkPg_.align = NIM_ALIGNOF(tyTuple__2E9aYKv1U4zUZsR6wkNRkPg);
NTItupleLn58pnode_idx58intT__2E9aYKv1U4zUZsR6wkNRkPg_.kind = 18;
NTItupleLn58pnode_idx58intT__2E9aYKv1U4zUZsR6wkNRkPg_.base = 0;
NTItupleLn58pnode_idx58intT__2E9aYKv1U4zUZsR6wkNRkPg_.flags = 2;
TM__6kkF5shvTYOHG9cWBoBNLPQ_8_2[0] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[30];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[30].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[30].offset = offsetof(tyTuple__2E9aYKv1U4zUZsR6wkNRkPg, Field0);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[30].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[30].name = "Field0";
TM__6kkF5shvTYOHG9cWBoBNLPQ_8_2[1] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[31];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[31].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[31].offset = offsetof(tyTuple__2E9aYKv1U4zUZsR6wkNRkPg, Field1);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[31].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[31].name = "Field1";
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[29].len = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[29].kind = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[29].sons = &TM__6kkF5shvTYOHG9cWBoBNLPQ_8_2[0];
NTItupleLn58pnode_idx58intT__2E9aYKv1U4zUZsR6wkNRkPg_.node = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[29];
NTIseqLtupleLn58pnode_idx58intTT__cvxuM2UjDv0O3Q6FcDEAnw_.size = sizeof(tySequence__cvxuM2UjDv0O3Q6FcDEAnw*);
NTIseqLtupleLn58pnode_idx58intTT__cvxuM2UjDv0O3Q6FcDEAnw_.align = NIM_ALIGNOF(tySequence__cvxuM2UjDv0O3Q6FcDEAnw*);
NTIseqLtupleLn58pnode_idx58intTT__cvxuM2UjDv0O3Q6FcDEAnw_.kind = 24;
NTIseqLtupleLn58pnode_idx58intTT__cvxuM2UjDv0O3Q6FcDEAnw_.base = (&NTItupleLn58pnode_idx58intT__2E9aYKv1U4zUZsR6wkNRkPg_);
NTIseqLtupleLn58pnode_idx58intTT__cvxuM2UjDv0O3Q6FcDEAnw_.flags = 2;
NTIseqLtupleLn58pnode_idx58intTT__cvxuM2UjDv0O3Q6FcDEAnw_.marker = Marker_tySequence__cvxuM2UjDv0O3Q6FcDEAnw;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[28].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[28].offset = offsetof(tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA, caseContext);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[28].typ = (&NTIseqLtupleLn58pnode_idx58intTT__cvxuM2UjDv0O3Q6FcDEAnw_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[28].name = "caseContext";
TM__6kkF5shvTYOHG9cWBoBNLPQ_7_10[9] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[32];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[32].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[32].offset = offsetof(tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA, localBindStmts);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[32].typ = (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[32].name = "localBindStmts";
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[19].len = 10; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[19].kind = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[19].sons = &TM__6kkF5shvTYOHG9cWBoBNLPQ_7_10[0];
NTItproccon__9aK41DZ7WNm5NSRfb1CbcRA_.node = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[19];
NTIpproccon__10LrMeEGcZEU1Ndh5rhoUg_.size = sizeof(tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA*);
NTIpproccon__10LrMeEGcZEU1Ndh5rhoUg_.align = NIM_ALIGNOF(tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA*);
NTIpproccon__10LrMeEGcZEU1Ndh5rhoUg_.kind = 22;
NTIpproccon__10LrMeEGcZEU1Ndh5rhoUg_.base = (&NTItproccon__9aK41DZ7WNm5NSRfb1CbcRA_);
NTIpproccon__10LrMeEGcZEU1Ndh5rhoUg_.flags = 2;
NTIpproccon__10LrMeEGcZEU1Ndh5rhoUg_.marker = Marker_tyRef__10LrMeEGcZEU1Ndh5rhoUg;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[18].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[18].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, p);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[18].typ = (&NTIpproccon__10LrMeEGcZEU1Ndh5rhoUg_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[18].name = "p";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[8] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[33];
NTIarrayL4553OO5150_ptypeT__aaEwD7wUZoIxDUprFEbfMQ_.size = sizeof(tyArray__aaEwD7wUZoIxDUprFEbfMQ);
NTIarrayL4553OO5150_ptypeT__aaEwD7wUZoIxDUprFEbfMQ_.align = NIM_ALIGNOF(tyArray__aaEwD7wUZoIxDUprFEbfMQ);
NTIarrayL4553OO5150_ptypeT__aaEwD7wUZoIxDUprFEbfMQ_.kind = 16;
NTIarrayL4553OO5150_ptypeT__aaEwD7wUZoIxDUprFEbfMQ_.base = (&NTIptype__q1v0zzhoMWrhMLs6UEp1IA_);
NTIarrayL4553OO5150_ptypeT__aaEwD7wUZoIxDUprFEbfMQ_.flags = 2;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[33].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[33].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, intTypeCache);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[33].typ = (&NTIarrayL4553OO5150_ptypeT__aaEwD7wUZoIxDUprFEbfMQ_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[33].name = "intTypeCache";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[9] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[34];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[34].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[34].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, nilTypeCache);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[34].typ = (&NTIptype__q1v0zzhoMWrhMLs6UEp1IA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[34].name = "nilTypeCache";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[10] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[35];
NTItmatchedconcept__0kS5yo4t68pnIalDqA39crw_.size = sizeof(tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw);
NTItmatchedconcept__0kS5yo4t68pnIalDqA39crw_.align = NIM_ALIGNOF(tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw);
NTItmatchedconcept__0kS5yo4t68pnIalDqA39crw_.kind = 18;
NTItmatchedconcept__0kS5yo4t68pnIalDqA39crw_.base = 0;
NTItmatchedconcept__0kS5yo4t68pnIalDqA39crw_.flags = 2;
TM__6kkF5shvTYOHG9cWBoBNLPQ_9_3[0] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[37];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[37].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[37].offset = offsetof(tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw, candidateType);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[37].typ = (&NTIptype__q1v0zzhoMWrhMLs6UEp1IA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[37].name = "candidateType";
TM__6kkF5shvTYOHG9cWBoBNLPQ_9_3[1] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[38];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[38].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[38].offset = offsetof(tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw, prev);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[38].typ = (&NTIptrtmatchedconcept__GVhEG2inner9bL6FQrJo9b9aA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[38].name = "prev";
TM__6kkF5shvTYOHG9cWBoBNLPQ_9_3[2] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[39];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[39].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[39].offset = offsetof(tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw, depth);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[39].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[39].name = "depth";
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[36].len = 3; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[36].kind = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[36].sons = &TM__6kkF5shvTYOHG9cWBoBNLPQ_9_3[0];
NTItmatchedconcept__0kS5yo4t68pnIalDqA39crw_.node = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[36];
NTIptrtmatchedconcept__GVhEG2inner9bL6FQrJo9b9aA_.size = sizeof(tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw*);
NTIptrtmatchedconcept__GVhEG2inner9bL6FQrJo9b9aA_.align = NIM_ALIGNOF(tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw*);
NTIptrtmatchedconcept__GVhEG2inner9bL6FQrJo9b9aA_.kind = 21;
NTIptrtmatchedconcept__GVhEG2inner9bL6FQrJo9b9aA_.base = (&NTItmatchedconcept__0kS5yo4t68pnIalDqA39crw_);
NTIptrtmatchedconcept__GVhEG2inner9bL6FQrJo9b9aA_.flags = 3;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[35].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[35].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, matchedConcept);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[35].typ = (&NTIptrtmatchedconcept__GVhEG2inner9bL6FQrJo9b9aA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[35].name = "matchedConcept";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[11] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[40];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[40].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[40].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, friendModules);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[40].typ = (&NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[40].name = "friendModules";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[12] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[41];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[41].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[41].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, instCounter);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[41].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[41].name = "instCounter";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[13] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[42];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[42].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[42].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, templInstCounter);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[42].typ = (&NTIrefint__9ai78kkwqt3gikTN9cpHKUVg_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[42].name = "templInstCounter";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[14] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[43];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[43].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[43].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, inGenericContext);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[43].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[43].name = "inGenericContext";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[15] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[44];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[44].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[44].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, inStaticContext);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[44].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[44].name = "inStaticContext";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[16] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[45];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[45].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[45].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, inUnrolledContext);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[45].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[45].name = "inUnrolledContext";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[17] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[46];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[46].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[46].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, compilesContextId);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[46].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[46].name = "compilesContextId";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[18] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[47];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[47].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[47].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, compilesContextIdGenerator);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[47].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[47].name = "compilesContextIdGenerator";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[19] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[48];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[48].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[48].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, inGenericInst);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[48].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[48].name = "inGenericInst";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[20] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[49];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[49].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[49].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, converters);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[49].typ = (&NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[49].name = "converters";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[21] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[50];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[50].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[50].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, patterns);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[50].typ = (&NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[50].name = "patterns";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[22] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[51];
NTItoptionentry__KcSoeh10J9aas3WZevEUD7Q_.size = sizeof(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q);
NTItoptionentry__KcSoeh10J9aas3WZevEUD7Q_.align = NIM_ALIGNOF(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q);
NTItoptionentry__KcSoeh10J9aas3WZevEUD7Q_.kind = 18;
NTItoptionentry__KcSoeh10J9aas3WZevEUD7Q_.base = 0;
NTItoptionentry__KcSoeh10J9aas3WZevEUD7Q_.flags = 2;
TM__6kkF5shvTYOHG9cWBoBNLPQ_10_7[0] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[53];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[53].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[53].offset = offsetof(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q, options);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[53].typ = (&NTItoptions__JyE8ULWMsetkCt18l86VRw_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[53].name = "options";
TM__6kkF5shvTYOHG9cWBoBNLPQ_10_7[1] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[54];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[54].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[54].offset = offsetof(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q, defaultCC);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[54].typ = (&NTItcallingconvention__5kpSva5OFmGFHujbio7C9cg_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[54].name = "defaultCC";
TM__6kkF5shvTYOHG9cWBoBNLPQ_10_7[2] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[55];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[55].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[55].offset = offsetof(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q, dynlib);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[55].typ = (&NTIplib__cpB5Ba1r1YF5UAlBgbtl8g_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[55].name = "dynlib";
TM__6kkF5shvTYOHG9cWBoBNLPQ_10_7[3] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[56];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[56].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[56].offset = offsetof(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q, notes);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[56].typ = (&NTItnotekinds__w2aCBEMcLy7t2KQe9caB9aBw_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[56].name = "notes";
TM__6kkF5shvTYOHG9cWBoBNLPQ_10_7[4] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[57];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[57].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[57].offset = offsetof(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q, features);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[57].typ = (&NTIsetLfeatureT__JNptLjsgi8AHY03RfiC9aTQ_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[57].name = "features";
TM__6kkF5shvTYOHG9cWBoBNLPQ_10_7[5] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[58];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[58].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[58].offset = offsetof(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q, otherPragmas);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[58].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[58].name = "otherPragmas";
TM__6kkF5shvTYOHG9cWBoBNLPQ_10_7[6] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[59];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[59].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[59].offset = offsetof(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q, warningAsErrors);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[59].typ = (&NTItnotekinds__w2aCBEMcLy7t2KQe9caB9aBw_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[59].name = "warningAsErrors";
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[52].len = 7; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[52].kind = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[52].sons = &TM__6kkF5shvTYOHG9cWBoBNLPQ_10_7[0];
NTItoptionentry__KcSoeh10J9aas3WZevEUD7Q_.node = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[52];
NTIpoptionentry__BSbNT2MZJsNcSq6BlR6KPQ_.size = sizeof(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q*);
NTIpoptionentry__BSbNT2MZJsNcSq6BlR6KPQ_.align = NIM_ALIGNOF(tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q*);
NTIpoptionentry__BSbNT2MZJsNcSq6BlR6KPQ_.kind = 22;
NTIpoptionentry__BSbNT2MZJsNcSq6BlR6KPQ_.base = (&NTItoptionentry__KcSoeh10J9aas3WZevEUD7Q_);
NTIpoptionentry__BSbNT2MZJsNcSq6BlR6KPQ_.flags = 2;
NTIpoptionentry__BSbNT2MZJsNcSq6BlR6KPQ_.marker = Marker_tyRef__BSbNT2MZJsNcSq6BlR6KPQ;
NTIseqLpoptionentryT__vvBerF0axaNtu9aMA2gnsrA_.size = sizeof(tySequence__vvBerF0axaNtu9aMA2gnsrA*);
NTIseqLpoptionentryT__vvBerF0axaNtu9aMA2gnsrA_.align = NIM_ALIGNOF(tySequence__vvBerF0axaNtu9aMA2gnsrA*);
NTIseqLpoptionentryT__vvBerF0axaNtu9aMA2gnsrA_.kind = 24;
NTIseqLpoptionentryT__vvBerF0axaNtu9aMA2gnsrA_.base = (&NTIpoptionentry__BSbNT2MZJsNcSq6BlR6KPQ_);
NTIseqLpoptionentryT__vvBerF0axaNtu9aMA2gnsrA_.flags = 2;
NTIseqLpoptionentryT__vvBerF0axaNtu9aMA2gnsrA_.marker = Marker_tySequence__vvBerF0axaNtu9aMA2gnsrA;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[51].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[51].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, optionStack);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[51].typ = (&NTIseqLpoptionentryT__vvBerF0axaNtu9aMA2gnsrA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[51].name = "optionStack";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[23] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[60];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[60].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[60].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, symMapping);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[60].typ = (&NTItidtable__Cs7vbulfMjKciTA2Uv9b6vQ_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[60].name = "symMapping";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[24] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[61];
NTIseqLplibT__9c3OY0aBmSBgwdsnBAPf4Ag_.size = sizeof(tySequence__9c3OY0aBmSBgwdsnBAPf4Ag*);
NTIseqLplibT__9c3OY0aBmSBgwdsnBAPf4Ag_.align = NIM_ALIGNOF(tySequence__9c3OY0aBmSBgwdsnBAPf4Ag*);
NTIseqLplibT__9c3OY0aBmSBgwdsnBAPf4Ag_.kind = 24;
NTIseqLplibT__9c3OY0aBmSBgwdsnBAPf4Ag_.base = (&NTIplib__cpB5Ba1r1YF5UAlBgbtl8g_);
NTIseqLplibT__9c3OY0aBmSBgwdsnBAPf4Ag_.flags = 2;
NTIseqLplibT__9c3OY0aBmSBgwdsnBAPf4Ag_.marker = Marker_tySequence__9c3OY0aBmSBgwdsnBAPf4Ag;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[61].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[61].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, libs);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[61].typ = (&NTIseqLplibT__9c3OY0aBmSBgwdsnBAPf4Ag_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[61].name = "libs";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[25] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[62];
NTIprocLc58pcontext_n58pnode_expectedtype58ptypeT58pnodeLOnimcallOT__q9caIJqxIEVMlKzDKc7PN3A_.size = sizeof(tyProc__q9caIJqxIEVMlKzDKc7PN3A);
NTIprocLc58pcontext_n58pnode_expectedtype58ptypeT58pnodeLOnimcallOT__q9caIJqxIEVMlKzDKc7PN3A_.align = NIM_ALIGNOF(tyProc__q9caIJqxIEVMlKzDKc7PN3A);
NTIprocLc58pcontext_n58pnode_expectedtype58ptypeT58pnodeLOnimcallOT__q9caIJqxIEVMlKzDKc7PN3A_.kind = 25;
NTIprocLc58pcontext_n58pnode_expectedtype58ptypeT58pnodeLOnimcallOT__q9caIJqxIEVMlKzDKc7PN3A_.base = 0;
NTIprocLc58pcontext_n58pnode_expectedtype58ptypeT58pnodeLOnimcallOT__q9caIJqxIEVMlKzDKc7PN3A_.flags = 3;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[62].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[62].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, semConstExpr);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[62].typ = (&NTIprocLc58pcontext_n58pnode_expectedtype58ptypeT58pnodeLOnimcallOT__q9caIJqxIEVMlKzDKc7PN3A_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[62].name = "semConstExpr";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[26] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[63];
NTIprocLc58pcontext_n58pnode_flags58texprflags_expectedtype58ptypeT58pnodeLOnimcallOT__Kiet6YwcQwPvcQYHHEqqqQ_.size = sizeof(tyProc__Kiet6YwcQwPvcQYHHEqqqQ);
NTIprocLc58pcontext_n58pnode_flags58texprflags_expectedtype58ptypeT58pnodeLOnimcallOT__Kiet6YwcQwPvcQYHHEqqqQ_.align = NIM_ALIGNOF(tyProc__Kiet6YwcQwPvcQYHHEqqqQ);
NTIprocLc58pcontext_n58pnode_flags58texprflags_expectedtype58ptypeT58pnodeLOnimcallOT__Kiet6YwcQwPvcQYHHEqqqQ_.kind = 25;
NTIprocLc58pcontext_n58pnode_flags58texprflags_expectedtype58ptypeT58pnodeLOnimcallOT__Kiet6YwcQwPvcQYHHEqqqQ_.base = 0;
NTIprocLc58pcontext_n58pnode_flags58texprflags_expectedtype58ptypeT58pnodeLOnimcallOT__Kiet6YwcQwPvcQYHHEqqqQ_.flags = 3;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[63].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[63].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, semExpr);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[63].typ = (&NTIprocLc58pcontext_n58pnode_flags58texprflags_expectedtype58ptypeT58pnodeLOnimcallOT__Kiet6YwcQwPvcQYHHEqqqQ_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[63].name = "semExpr";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[27] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[64];
NTIprocLc58pcontext_n58pnode_flags58texprflagsT58pnodeLOnimcallOT__PSlVV9bxpH9avY5YrjCD5uqA_.size = sizeof(tyProc__PSlVV9bxpH9avY5YrjCD5uqA);
NTIprocLc58pcontext_n58pnode_flags58texprflagsT58pnodeLOnimcallOT__PSlVV9bxpH9avY5YrjCD5uqA_.align = NIM_ALIGNOF(tyProc__PSlVV9bxpH9avY5YrjCD5uqA);
NTIprocLc58pcontext_n58pnode_flags58texprflagsT58pnodeLOnimcallOT__PSlVV9bxpH9avY5YrjCD5uqA_.kind = 25;
NTIprocLc58pcontext_n58pnode_flags58texprflagsT58pnodeLOnimcallOT__PSlVV9bxpH9avY5YrjCD5uqA_.base = 0;
NTIprocLc58pcontext_n58pnode_flags58texprflagsT58pnodeLOnimcallOT__PSlVV9bxpH9avY5YrjCD5uqA_.flags = 3;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[64].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[64].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, semTryExpr);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[64].typ = (&NTIprocLc58pcontext_n58pnode_flags58texprflagsT58pnodeLOnimcallOT__PSlVV9bxpH9avY5YrjCD5uqA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[64].name = "semTryExpr";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[28] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[65];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[65].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[65].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, semTryConstExpr);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[65].typ = (&NTIprocLc58pcontext_n58pnode_expectedtype58ptypeT58pnodeLOnimcallOT__q9caIJqxIEVMlKzDKc7PN3A_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[65].name = "semTryConstExpr";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[29] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[66];
NTIprocLc58pcontext_t58ptypeT58boolLOnimcallOT__8k9afYvvfaH1tjWAwlISb0A_.size = sizeof(tyProc__8k9afYvvfaH1tjWAwlISb0A);
NTIprocLc58pcontext_t58ptypeT58boolLOnimcallOT__8k9afYvvfaH1tjWAwlISb0A_.align = NIM_ALIGNOF(tyProc__8k9afYvvfaH1tjWAwlISb0A);
NTIprocLc58pcontext_t58ptypeT58boolLOnimcallOT__8k9afYvvfaH1tjWAwlISb0A_.kind = 25;
NTIprocLc58pcontext_t58ptypeT58boolLOnimcallOT__8k9afYvvfaH1tjWAwlISb0A_.base = 0;
NTIprocLc58pcontext_t58ptypeT58boolLOnimcallOT__8k9afYvvfaH1tjWAwlISb0A_.flags = 3;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[66].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[66].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, computeRequiresInit);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[66].typ = (&NTIprocLc58pcontext_t58ptypeT58boolLOnimcallOT__8k9afYvvfaH1tjWAwlISb0A_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[66].name = "computeRequiresInit";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[30] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[67];
NTIprocLc58pcontext_n58pnodeT58boolLOclosureOT__9bnYcX9avusKBraL3FJXBwJw_.size = sizeof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTIprocLc58pcontext_n58pnodeT58boolLOclosureOT__9bnYcX9avusKBraL3FJXBwJw_.align = NIM_ALIGNOF(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTIprocLc58pcontext_n58pnodeT58boolLOclosureOT__9bnYcX9avusKBraL3FJXBwJw_.kind = 18;
NTIprocLc58pcontext_n58pnodeT58boolLOclosureOT__9bnYcX9avusKBraL3FJXBwJw_.base = 0;
TM__6kkF5shvTYOHG9cWBoBNLPQ_11_2[0] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[69];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[69].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[69].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field0);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[69].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[69].name = "Field0";
TM__6kkF5shvTYOHG9cWBoBNLPQ_11_2[1] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[70];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[70].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[70].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field1);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[70].typ = (&NTIrefobject__HsJiUUcO9cHBdUCi0HwkSTA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[70].name = "Field1";
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[68].len = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[68].kind = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[68].sons = &TM__6kkF5shvTYOHG9cWBoBNLPQ_11_2[0];
NTIprocLc58pcontext_n58pnodeT58boolLOclosureOT__9bnYcX9avusKBraL3FJXBwJw_.node = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[68];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[67].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[67].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, hasUnresolvedArgs);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[67].typ = (&NTIprocLc58pcontext_n58pnodeT58boolLOclosureOT__9bnYcX9avusKBraL3FJXBwJw_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[67].name = "hasUnresolvedArgs";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[31] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[71];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[71].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[71].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, semOperand);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[71].typ = (&NTIprocLc58pcontext_n58pnode_flags58texprflagsT58pnodeLOnimcallOT__PSlVV9bxpH9avY5YrjCD5uqA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[71].name = "semOperand";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[32] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[72];
NTIprocLc58pcontext_n58pnodeT58pnodeLOnimcallOT__uojbiMfaKLMuGW9bbomtTBg_.size = sizeof(tyProc__uojbiMfaKLMuGW9bbomtTBg);
NTIprocLc58pcontext_n58pnodeT58pnodeLOnimcallOT__uojbiMfaKLMuGW9bbomtTBg_.align = NIM_ALIGNOF(tyProc__uojbiMfaKLMuGW9bbomtTBg);
NTIprocLc58pcontext_n58pnodeT58pnodeLOnimcallOT__uojbiMfaKLMuGW9bbomtTBg_.kind = 25;
NTIprocLc58pcontext_n58pnodeT58pnodeLOnimcallOT__uojbiMfaKLMuGW9bbomtTBg_.base = 0;
NTIprocLc58pcontext_n58pnodeT58pnodeLOnimcallOT__uojbiMfaKLMuGW9bbomtTBg_.flags = 3;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[72].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[72].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, semConstBoolExpr);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[72].typ = (&NTIprocLc58pcontext_n58pnodeT58pnodeLOnimcallOT__uojbiMfaKLMuGW9bbomtTBg_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[72].name = "semConstBoolExpr";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[33] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[73];
NTIprocLc58pcontext_n58pnode_norig58pnode_filter58tsymkinds_flags58texprflagsT58pnodeLOnimcallOT__bqRyngJC8bSPcUqqn9bn73w_.size = sizeof(tyProc__bqRyngJC8bSPcUqqn9bn73w);
NTIprocLc58pcontext_n58pnode_norig58pnode_filter58tsymkinds_flags58texprflagsT58pnodeLOnimcallOT__bqRyngJC8bSPcUqqn9bn73w_.align = NIM_ALIGNOF(tyProc__bqRyngJC8bSPcUqqn9bn73w);
NTIprocLc58pcontext_n58pnode_norig58pnode_filter58tsymkinds_flags58texprflagsT58pnodeLOnimcallOT__bqRyngJC8bSPcUqqn9bn73w_.kind = 25;
NTIprocLc58pcontext_n58pnode_norig58pnode_filter58tsymkinds_flags58texprflagsT58pnodeLOnimcallOT__bqRyngJC8bSPcUqqn9bn73w_.base = 0;
NTIprocLc58pcontext_n58pnode_norig58pnode_filter58tsymkinds_flags58texprflagsT58pnodeLOnimcallOT__bqRyngJC8bSPcUqqn9bn73w_.flags = 3;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[73].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[73].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, semOverloadedCall);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[73].typ = (&NTIprocLc58pcontext_n58pnode_norig58pnode_filter58tsymkinds_flags58texprflagsT58pnodeLOnimcallOT__bqRyngJC8bSPcUqqn9bn73w_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[73].name = "semOverloadedCall";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[34] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[74];
NTIprocLc58pcontext_n58pnode_prev58ptypeT58ptypeLOnimcallOT__F6LocU8y66ng5Ra4XoVWJA_.size = sizeof(tyProc__F6LocU8y66ng5Ra4XoVWJA);
NTIprocLc58pcontext_n58pnode_prev58ptypeT58ptypeLOnimcallOT__F6LocU8y66ng5Ra4XoVWJA_.align = NIM_ALIGNOF(tyProc__F6LocU8y66ng5Ra4XoVWJA);
NTIprocLc58pcontext_n58pnode_prev58ptypeT58ptypeLOnimcallOT__F6LocU8y66ng5Ra4XoVWJA_.kind = 25;
NTIprocLc58pcontext_n58pnode_prev58ptypeT58ptypeLOnimcallOT__F6LocU8y66ng5Ra4XoVWJA_.base = 0;
NTIprocLc58pcontext_n58pnode_prev58ptypeT58ptypeLOnimcallOT__F6LocU8y66ng5Ra4XoVWJA_.flags = 3;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[74].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[74].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, semTypeNode);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[74].typ = (&NTIprocLc58pcontext_n58pnode_prev58ptypeT58ptypeLOnimcallOT__F6LocU8y66ng5Ra4XoVWJA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[74].name = "semTypeNode";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[35] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[75];
NTIprocLc58pcontext_pt58tidtable_n58pnodeT58pnodeLOclosureOT__Nc9aAsBDTkr61wP9a9cnds8Og_.size = sizeof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTIprocLc58pcontext_pt58tidtable_n58pnodeT58pnodeLOclosureOT__Nc9aAsBDTkr61wP9a9cnds8Og_.align = NIM_ALIGNOF(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTIprocLc58pcontext_pt58tidtable_n58pnodeT58pnodeLOclosureOT__Nc9aAsBDTkr61wP9a9cnds8Og_.kind = 18;
NTIprocLc58pcontext_pt58tidtable_n58pnodeT58pnodeLOclosureOT__Nc9aAsBDTkr61wP9a9cnds8Og_.base = 0;
TM__6kkF5shvTYOHG9cWBoBNLPQ_12_2[0] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[77];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[77].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[77].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field0);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[77].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[77].name = "Field0";
TM__6kkF5shvTYOHG9cWBoBNLPQ_12_2[1] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[78];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[78].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[78].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field1);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[78].typ = (&NTIrefobject__HsJiUUcO9cHBdUCi0HwkSTA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[78].name = "Field1";
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[76].len = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[76].kind = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[76].sons = &TM__6kkF5shvTYOHG9cWBoBNLPQ_12_2[0];
NTIprocLc58pcontext_pt58tidtable_n58pnodeT58pnodeLOclosureOT__Nc9aAsBDTkr61wP9a9cnds8Og_.node = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[76];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[75].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[75].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, semInferredLambda);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[75].typ = (&NTIprocLc58pcontext_pt58tidtable_n58pnodeT58pnodeLOclosureOT__Nc9aAsBDTkr61wP9a9cnds8Og_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[75].name = "semInferredLambda";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[36] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[79];
NTIprocLc58pcontext_fn58psym_pt58tidtable_info58tlineinfoT58psymLOclosureOT__z8FaSv6eEIc72FZ9c9cBcaGg_.size = sizeof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTIprocLc58pcontext_fn58psym_pt58tidtable_info58tlineinfoT58psymLOclosureOT__z8FaSv6eEIc72FZ9c9cBcaGg_.align = NIM_ALIGNOF(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTIprocLc58pcontext_fn58psym_pt58tidtable_info58tlineinfoT58psymLOclosureOT__z8FaSv6eEIc72FZ9c9cBcaGg_.kind = 18;
NTIprocLc58pcontext_fn58psym_pt58tidtable_info58tlineinfoT58psymLOclosureOT__z8FaSv6eEIc72FZ9c9cBcaGg_.base = 0;
TM__6kkF5shvTYOHG9cWBoBNLPQ_13_2[0] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[81];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[81].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[81].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field0);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[81].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[81].name = "Field0";
TM__6kkF5shvTYOHG9cWBoBNLPQ_13_2[1] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[82];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[82].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[82].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field1);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[82].typ = (&NTIrefobject__HsJiUUcO9cHBdUCi0HwkSTA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[82].name = "Field1";
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[80].len = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[80].kind = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[80].sons = &TM__6kkF5shvTYOHG9cWBoBNLPQ_13_2[0];
NTIprocLc58pcontext_fn58psym_pt58tidtable_info58tlineinfoT58psymLOclosureOT__z8FaSv6eEIc72FZ9c9cBcaGg_.node = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[80];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[79].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[79].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, semGenerateInstance);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[79].typ = (&NTIprocLc58pcontext_fn58psym_pt58tidtable_info58tlineinfoT58psymLOclosureOT__z8FaSv6eEIc72FZ9c9cBcaGg_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[79].name = "semGenerateInstance";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[37] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[83];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[83].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[83].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, includedFiles);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[83].typ = (&NTIpackedset__THXDbzJSs2hcC9a33en2pdw_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[83].name = "includedFiles";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[38] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[84];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[84].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[84].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, pureEnumFields);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[84].typ = (&NTItstrtable__CJQ42V2zij8fd39a9aMiwtZw_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[84].name = "pureEnumFields";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[39] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[85];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[85].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[85].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, userPragmas);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[85].typ = (&NTItstrtable__CJQ42V2zij8fd39a9aMiwtZw_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[85].name = "userPragmas";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[40] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[86];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[86].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[86].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, evalContext);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[86].typ = (&NTIpevalcontext__4IKTvAXRLrZvs9cUNEP7Z8w_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[86].name = "evalContext";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[41] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[87];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[87].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[87].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, unknownIdents);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[87].typ = (&NTIpackedset__THXDbzJSs2hcC9a33en2pdw_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[87].name = "unknownIdents";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[42] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[88];
NTItinstantiationpair__d4lcZMnmQK2Jh2jYkdgB4w_.size = sizeof(tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w);
NTItinstantiationpair__d4lcZMnmQK2Jh2jYkdgB4w_.align = NIM_ALIGNOF(tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w);
NTItinstantiationpair__d4lcZMnmQK2Jh2jYkdgB4w_.kind = 18;
NTItinstantiationpair__d4lcZMnmQK2Jh2jYkdgB4w_.base = 0;
NTItinstantiationpair__d4lcZMnmQK2Jh2jYkdgB4w_.flags = 2;
TM__6kkF5shvTYOHG9cWBoBNLPQ_14_2[0] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[90];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[90].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[90].offset = offsetof(tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w, genericSym);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[90].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[90].name = "genericSym";
TM__6kkF5shvTYOHG9cWBoBNLPQ_14_2[1] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[91];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[91].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[91].offset = offsetof(tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w, inst);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[91].typ = (&NTIpinstantiation__eg8se9cZBHdzb5ZM7CrYNVg_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[91].name = "inst";
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[89].len = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[89].kind = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[89].sons = &TM__6kkF5shvTYOHG9cWBoBNLPQ_14_2[0];
NTItinstantiationpair__d4lcZMnmQK2Jh2jYkdgB4w_.node = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[89];
NTIseqLtinstantiationpairT__yH9bx9bpa6jqsU89cxjyTAlPQ_.size = sizeof(tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ*);
NTIseqLtinstantiationpairT__yH9bx9bpa6jqsU89cxjyTAlPQ_.align = NIM_ALIGNOF(tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ*);
NTIseqLtinstantiationpairT__yH9bx9bpa6jqsU89cxjyTAlPQ_.kind = 24;
NTIseqLtinstantiationpairT__yH9bx9bpa6jqsU89cxjyTAlPQ_.base = (&NTItinstantiationpair__d4lcZMnmQK2Jh2jYkdgB4w_);
NTIseqLtinstantiationpairT__yH9bx9bpa6jqsU89cxjyTAlPQ_.flags = 2;
NTIseqLtinstantiationpairT__yH9bx9bpa6jqsU89cxjyTAlPQ_.marker = Marker_tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[88].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[88].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, generics);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[88].typ = (&NTIseqLtinstantiationpairT__yH9bx9bpa6jqsU89cxjyTAlPQ_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[88].name = "generics";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[43] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[92];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[92].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[92].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, topStmts);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[92].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[92].name = "topStmts";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[44] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[93];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[93].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[93].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, lastGenericIdx);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[93].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[93].name = "lastGenericIdx";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[45] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[94];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[94].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[94].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, hloLoopDetector);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[94].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[94].name = "hloLoopDetector";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[46] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[95];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[95].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[95].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, inParallelStmt);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[95].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[95].name = "inParallelStmt";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[47] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[96];
NTIprocLc58pcontext_dc58psym_t58ptype_info58tlineinfo_op58ttypeattachedop_col58intT58psymLOnimcallOT__9aa59awckKpa9areOQSBOwSeQ_.size = sizeof(tyProc__9aa59awckKpa9areOQSBOwSeQ);
NTIprocLc58pcontext_dc58psym_t58ptype_info58tlineinfo_op58ttypeattachedop_col58intT58psymLOnimcallOT__9aa59awckKpa9areOQSBOwSeQ_.align = NIM_ALIGNOF(tyProc__9aa59awckKpa9areOQSBOwSeQ);
NTIprocLc58pcontext_dc58psym_t58ptype_info58tlineinfo_op58ttypeattachedop_col58intT58psymLOnimcallOT__9aa59awckKpa9areOQSBOwSeQ_.kind = 25;
NTIprocLc58pcontext_dc58psym_t58ptype_info58tlineinfo_op58ttypeattachedop_col58intT58psymLOnimcallOT__9aa59awckKpa9areOQSBOwSeQ_.base = 0;
NTIprocLc58pcontext_dc58psym_t58ptype_info58tlineinfo_op58ttypeattachedop_col58intT58psymLOnimcallOT__9aa59awckKpa9areOQSBOwSeQ_.flags = 3;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[96].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[96].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, instTypeBoundOp);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[96].typ = (&NTIprocLc58pcontext_dc58psym_t58ptype_info58tlineinfo_op58ttypeattachedop_col58intT58psymLOnimcallOT__9aa59awckKpa9areOQSBOwSeQ_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[96].name = "instTypeBoundOp";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[48] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[97];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[97].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[97].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, selfName);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[97].typ = (&NTIpident__eFRAx6MW9aaEkYtj9aZffV0A_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[97].name = "selfName";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[49] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[98];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[98].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[98].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, cache);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[98].typ = (&NTIidentcache__6ZZ9cf5acLVYxUxl0ehlA1g_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[98].name = "cache";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[50] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[99];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[99].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[99].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, graph);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[99].typ = (&NTImodulegraph__AcDjMYSN0KX1UsX3HvPu2w_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[99].name = "graph";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[51] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[100];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[100].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[100].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, signatures);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[100].typ = (&NTItstrtable__CJQ42V2zij8fd39a9aMiwtZw_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[100].name = "signatures";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[52] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[101];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[101].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[101].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, recursiveDep);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[101].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[101].name = "recursiveDep";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[53] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[102];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[102].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[102].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, suggestionsMade);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[102].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[102].name = "suggestionsMade";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[54] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[103];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[103].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[103].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, isAmbiguous);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[103].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[103].name = "isAmbiguous";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[55] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[104];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[104].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[104].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, features);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[104].typ = (&NTIsetLfeatureT__JNptLjsgi8AHY03RfiC9aTQ_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[104].name = "features";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[56] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[105];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[105].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[105].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, inTypeContext);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[105].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[105].name = "inTypeContext";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[57] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[106];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[106].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[106].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, inConceptDecl);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[106].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[106].name = "inConceptDecl";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[58] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[107];
NTILpsym_tlineinfoT__8vGER9aaTtt9bUk9avNQ3fEIg_.size = sizeof(tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg);
NTILpsym_tlineinfoT__8vGER9aaTtt9bUk9avNQ3fEIg_.align = NIM_ALIGNOF(tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg);
NTILpsym_tlineinfoT__8vGER9aaTtt9bUk9avNQ3fEIg_.kind = 18;
NTILpsym_tlineinfoT__8vGER9aaTtt9bUk9avNQ3fEIg_.base = 0;
NTILpsym_tlineinfoT__8vGER9aaTtt9bUk9avNQ3fEIg_.flags = 2;
TM__6kkF5shvTYOHG9cWBoBNLPQ_15_2[0] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[109];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[109].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[109].offset = offsetof(tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg, Field0);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[109].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[109].name = "Field0";
TM__6kkF5shvTYOHG9cWBoBNLPQ_15_2[1] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[110];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[110].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[110].offset = offsetof(tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg, Field1);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[110].typ = (&NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[110].name = "Field1";
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[108].len = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[108].kind = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[108].sons = &TM__6kkF5shvTYOHG9cWBoBNLPQ_15_2[0];
NTILpsym_tlineinfoT__8vGER9aaTtt9bUk9avNQ3fEIg_.node = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[108];
NTIseqLLpsym_tlineinfoTT__Jhh6ks9carRtwV9aOuM8yMNw_.size = sizeof(tySequence__Jhh6ks9carRtwV9aOuM8yMNw*);
NTIseqLLpsym_tlineinfoTT__Jhh6ks9carRtwV9aOuM8yMNw_.align = NIM_ALIGNOF(tySequence__Jhh6ks9carRtwV9aOuM8yMNw*);
NTIseqLLpsym_tlineinfoTT__Jhh6ks9carRtwV9aOuM8yMNw_.kind = 24;
NTIseqLLpsym_tlineinfoTT__Jhh6ks9carRtwV9aOuM8yMNw_.base = (&NTILpsym_tlineinfoT__8vGER9aaTtt9bUk9avNQ3fEIg_);
NTIseqLLpsym_tlineinfoTT__Jhh6ks9carRtwV9aOuM8yMNw_.flags = 2;
NTIseqLLpsym_tlineinfoTT__Jhh6ks9carRtwV9aOuM8yMNw_.marker = Marker_tySequence__Jhh6ks9carRtwV9aOuM8yMNw;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[107].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[107].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, unusedImports);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[107].typ = (&NTIseqLLpsym_tlineinfoTT__Jhh6ks9carRtwV9aOuM8yMNw_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[107].name = "unusedImports";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[59] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[111];
NTIhashset__qEsCgvAiLX6rSzzn9cFnYvQ_.size = sizeof(tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ);
NTIhashset__qEsCgvAiLX6rSzzn9cFnYvQ_.align = NIM_ALIGNOF(tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ);
NTIhashset__qEsCgvAiLX6rSzzn9cFnYvQ_.kind = 18;
NTIhashset__qEsCgvAiLX6rSzzn9cFnYvQ_.base = 0;
NTIhashset__qEsCgvAiLX6rSzzn9cFnYvQ_.flags = 2;
TM__6kkF5shvTYOHG9cWBoBNLPQ_16_2[0] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[113];
NTIkeyvaluepair__NAaJgGVgNmlGoqmiWxdOHQ_.size = sizeof(tyTuple__NAaJgGVgNmlGoqmiWxdOHQ);
NTIkeyvaluepair__NAaJgGVgNmlGoqmiWxdOHQ_.align = NIM_ALIGNOF(tyTuple__NAaJgGVgNmlGoqmiWxdOHQ);
NTIkeyvaluepair__NAaJgGVgNmlGoqmiWxdOHQ_.kind = 18;
NTIkeyvaluepair__NAaJgGVgNmlGoqmiWxdOHQ_.base = 0;
NTIkeyvaluepair__NAaJgGVgNmlGoqmiWxdOHQ_.flags = 3;
TM__6kkF5shvTYOHG9cWBoBNLPQ_17_2[0] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[115];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[115].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[115].offset = offsetof(tyTuple__NAaJgGVgNmlGoqmiWxdOHQ, Field0);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[115].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[115].name = "Field0";
TM__6kkF5shvTYOHG9cWBoBNLPQ_17_2[1] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[116];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[116].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[116].offset = offsetof(tyTuple__NAaJgGVgNmlGoqmiWxdOHQ, Field1);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[116].typ = (&NTItupleLa58int_b58intT__1v9bKyksXWMsm0vNwmZ4EuQ_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[116].name = "Field1";
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[114].len = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[114].kind = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[114].sons = &TM__6kkF5shvTYOHG9cWBoBNLPQ_17_2[0];
NTIkeyvaluepair__NAaJgGVgNmlGoqmiWxdOHQ_.node = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[114];
NTIkeyvaluepairseq__Bis5AbpONWcIRrPyPJS8Yw_.size = sizeof(tySequence__Bis5AbpONWcIRrPyPJS8Yw*);
NTIkeyvaluepairseq__Bis5AbpONWcIRrPyPJS8Yw_.align = NIM_ALIGNOF(tySequence__Bis5AbpONWcIRrPyPJS8Yw*);
NTIkeyvaluepairseq__Bis5AbpONWcIRrPyPJS8Yw_.kind = 24;
NTIkeyvaluepairseq__Bis5AbpONWcIRrPyPJS8Yw_.base = (&NTIkeyvaluepair__NAaJgGVgNmlGoqmiWxdOHQ_);
NTIkeyvaluepairseq__Bis5AbpONWcIRrPyPJS8Yw_.flags = 2;
NTIkeyvaluepairseq__Bis5AbpONWcIRrPyPJS8Yw_.marker = Marker_tySequence__Bis5AbpONWcIRrPyPJS8Yw;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[113].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[113].offset = offsetof(tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ, data);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[113].typ = (&NTIkeyvaluepairseq__Bis5AbpONWcIRrPyPJS8Yw_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[113].name = "data";
TM__6kkF5shvTYOHG9cWBoBNLPQ_16_2[1] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[117];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[117].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[117].offset = offsetof(tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ, counter);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[117].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[117].name = "counter";
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[112].len = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[112].kind = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[112].sons = &TM__6kkF5shvTYOHG9cWBoBNLPQ_16_2[0];
NTIhashset__qEsCgvAiLX6rSzzn9cFnYvQ_.node = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[112];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[111].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[111].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, exportIndirections);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[111].typ = (&NTIhashset__qEsCgvAiLX6rSzzn9cFnYvQ_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[111].name = "exportIndirections";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[60] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[118];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[118].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[118].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, importModuleMap);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[118].typ = (&NTItable__7ACYz5IhOEwzTBvwo6BO9bg_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[118].name = "importModuleMap";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[61] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[119];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[119].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[119].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, lastTLineInfo);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[119].typ = (&NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[119].name = "lastTLineInfo";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[62] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[120];
NTItable__g9cTlJykWlQLKMuaRBpUEZg_.size = sizeof(tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg);
NTItable__g9cTlJykWlQLKMuaRBpUEZg_.align = NIM_ALIGNOF(tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg);
NTItable__g9cTlJykWlQLKMuaRBpUEZg_.kind = 18;
NTItable__g9cTlJykWlQLKMuaRBpUEZg_.base = 0;
NTItable__g9cTlJykWlQLKMuaRBpUEZg_.flags = 2;
TM__6kkF5shvTYOHG9cWBoBNLPQ_18_2[0] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[122];
NTIkeyvaluepair__VbApVidEWCFLq9a29bPtaS7A_.size = sizeof(tyTuple__VbApVidEWCFLq9a29bPtaS7A);
NTIkeyvaluepair__VbApVidEWCFLq9a29bPtaS7A_.align = NIM_ALIGNOF(tyTuple__VbApVidEWCFLq9a29bPtaS7A);
NTIkeyvaluepair__VbApVidEWCFLq9a29bPtaS7A_.kind = 18;
NTIkeyvaluepair__VbApVidEWCFLq9a29bPtaS7A_.base = 0;
NTIkeyvaluepair__VbApVidEWCFLq9a29bPtaS7A_.flags = 2;
TM__6kkF5shvTYOHG9cWBoBNLPQ_19_3[0] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[124];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[124].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[124].offset = offsetof(tyTuple__VbApVidEWCFLq9a29bPtaS7A, Field0);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[124].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[124].name = "Field0";
TM__6kkF5shvTYOHG9cWBoBNLPQ_19_3[1] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[125];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[125].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[125].offset = offsetof(tyTuple__VbApVidEWCFLq9a29bPtaS7A, Field1);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[125].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[125].name = "Field1";
TM__6kkF5shvTYOHG9cWBoBNLPQ_19_3[2] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[126];
NTILtlineinfo_psymT__toqrUPSdp8zSxOdlxMJj9cA_.size = sizeof(tyTuple__toqrUPSdp8zSxOdlxMJj9cA);
NTILtlineinfo_psymT__toqrUPSdp8zSxOdlxMJj9cA_.align = NIM_ALIGNOF(tyTuple__toqrUPSdp8zSxOdlxMJj9cA);
NTILtlineinfo_psymT__toqrUPSdp8zSxOdlxMJj9cA_.kind = 18;
NTILtlineinfo_psymT__toqrUPSdp8zSxOdlxMJj9cA_.base = 0;
NTILtlineinfo_psymT__toqrUPSdp8zSxOdlxMJj9cA_.flags = 2;
TM__6kkF5shvTYOHG9cWBoBNLPQ_20_2[0] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[128];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[128].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[128].offset = offsetof(tyTuple__toqrUPSdp8zSxOdlxMJj9cA, Field0);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[128].typ = (&NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[128].name = "Field0";
TM__6kkF5shvTYOHG9cWBoBNLPQ_20_2[1] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[129];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[129].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[129].offset = offsetof(tyTuple__toqrUPSdp8zSxOdlxMJj9cA, Field1);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[129].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[129].name = "Field1";
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[127].len = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[127].kind = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[127].sons = &TM__6kkF5shvTYOHG9cWBoBNLPQ_20_2[0];
NTILtlineinfo_psymT__toqrUPSdp8zSxOdlxMJj9cA_.node = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[127];
NTIseqLLtlineinfo_psymTT__k7EQb9bN3Uhl608xoPGMRJA_.size = sizeof(tySequence__k7EQb9bN3Uhl608xoPGMRJA*);
NTIseqLLtlineinfo_psymTT__k7EQb9bN3Uhl608xoPGMRJA_.align = NIM_ALIGNOF(tySequence__k7EQb9bN3Uhl608xoPGMRJA*);
NTIseqLLtlineinfo_psymTT__k7EQb9bN3Uhl608xoPGMRJA_.kind = 24;
NTIseqLLtlineinfo_psymTT__k7EQb9bN3Uhl608xoPGMRJA_.base = (&NTILtlineinfo_psymT__toqrUPSdp8zSxOdlxMJj9cA_);
NTIseqLLtlineinfo_psymTT__k7EQb9bN3Uhl608xoPGMRJA_.flags = 2;
NTIseqLLtlineinfo_psymTT__k7EQb9bN3Uhl608xoPGMRJA_.marker = Marker_tySequence__k7EQb9bN3Uhl608xoPGMRJA;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[126].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[126].offset = offsetof(tyTuple__VbApVidEWCFLq9a29bPtaS7A, Field2);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[126].typ = (&NTIseqLLtlineinfo_psymTT__k7EQb9bN3Uhl608xoPGMRJA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[126].name = "Field2";
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[123].len = 3; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[123].kind = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[123].sons = &TM__6kkF5shvTYOHG9cWBoBNLPQ_19_3[0];
NTIkeyvaluepair__VbApVidEWCFLq9a29bPtaS7A_.node = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[123];
NTIkeyvaluepairseq__XDpbjnuseLNZDGLBQ2Qzow_.size = sizeof(tySequence__XDpbjnuseLNZDGLBQ2Qzow*);
NTIkeyvaluepairseq__XDpbjnuseLNZDGLBQ2Qzow_.align = NIM_ALIGNOF(tySequence__XDpbjnuseLNZDGLBQ2Qzow*);
NTIkeyvaluepairseq__XDpbjnuseLNZDGLBQ2Qzow_.kind = 24;
NTIkeyvaluepairseq__XDpbjnuseLNZDGLBQ2Qzow_.base = (&NTIkeyvaluepair__VbApVidEWCFLq9a29bPtaS7A_);
NTIkeyvaluepairseq__XDpbjnuseLNZDGLBQ2Qzow_.flags = 2;
NTIkeyvaluepairseq__XDpbjnuseLNZDGLBQ2Qzow_.marker = Marker_tySequence__XDpbjnuseLNZDGLBQ2Qzow;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[122].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[122].offset = offsetof(tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg, data);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[122].typ = (&NTIkeyvaluepairseq__XDpbjnuseLNZDGLBQ2Qzow_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[122].name = "data";
TM__6kkF5shvTYOHG9cWBoBNLPQ_18_2[1] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[130];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[130].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[130].offset = offsetof(tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg, counter);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[130].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[130].name = "counter";
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[121].len = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[121].kind = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[121].sons = &TM__6kkF5shvTYOHG9cWBoBNLPQ_18_2[0];
NTItable__g9cTlJykWlQLKMuaRBpUEZg_.node = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[121];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[120].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[120].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, sideEffects);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[120].typ = (&NTItable__g9cTlJykWlQLKMuaRBpUEZg_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[120].name = "sideEffects";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[63] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[131];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[131].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[131].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, inUncheckedAssignSection);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[131].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[131].name = "inUncheckedAssignSection";
TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[64] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[132];
NTItable__cBohObSCAwRxvYFXQHv2wA_.size = sizeof(tyObject_Table__cBohObSCAwRxvYFXQHv2wA);
NTItable__cBohObSCAwRxvYFXQHv2wA_.align = NIM_ALIGNOF(tyObject_Table__cBohObSCAwRxvYFXQHv2wA);
NTItable__cBohObSCAwRxvYFXQHv2wA_.kind = 18;
NTItable__cBohObSCAwRxvYFXQHv2wA_.base = 0;
NTItable__cBohObSCAwRxvYFXQHv2wA_.flags = 2;
TM__6kkF5shvTYOHG9cWBoBNLPQ_21_2[0] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[134];
NTIkeyvaluepair__EbsafWGli8bW2GRJQ9apsjA_.size = sizeof(tyTuple__EbsafWGli8bW2GRJQ9apsjA);
NTIkeyvaluepair__EbsafWGli8bW2GRJQ9apsjA_.align = NIM_ALIGNOF(tyTuple__EbsafWGli8bW2GRJQ9apsjA);
NTIkeyvaluepair__EbsafWGli8bW2GRJQ9apsjA_.kind = 18;
NTIkeyvaluepair__EbsafWGli8bW2GRJQ9apsjA_.base = 0;
NTIkeyvaluepair__EbsafWGli8bW2GRJQ9apsjA_.flags = 2;
TM__6kkF5shvTYOHG9cWBoBNLPQ_22_3[0] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[136];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[136].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[136].offset = offsetof(tyTuple__EbsafWGli8bW2GRJQ9apsjA, Field0);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[136].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[136].name = "Field0";
TM__6kkF5shvTYOHG9cWBoBNLPQ_22_3[1] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[137];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[137].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[137].offset = offsetof(tyTuple__EbsafWGli8bW2GRJQ9apsjA, Field1);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[137].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[137].name = "Field1";
TM__6kkF5shvTYOHG9cWBoBNLPQ_22_3[2] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[138];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[138].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[138].offset = offsetof(tyTuple__EbsafWGli8bW2GRJQ9apsjA, Field2);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[138].typ = (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[138].name = "Field2";
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[135].len = 3; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[135].kind = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[135].sons = &TM__6kkF5shvTYOHG9cWBoBNLPQ_22_3[0];
NTIkeyvaluepair__EbsafWGli8bW2GRJQ9apsjA_.node = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[135];
NTIkeyvaluepairseq__QqvaCqCpEE1QmQZbcZLi5A_.size = sizeof(tySequence__QqvaCqCpEE1QmQZbcZLi5A*);
NTIkeyvaluepairseq__QqvaCqCpEE1QmQZbcZLi5A_.align = NIM_ALIGNOF(tySequence__QqvaCqCpEE1QmQZbcZLi5A*);
NTIkeyvaluepairseq__QqvaCqCpEE1QmQZbcZLi5A_.kind = 24;
NTIkeyvaluepairseq__QqvaCqCpEE1QmQZbcZLi5A_.base = (&NTIkeyvaluepair__EbsafWGli8bW2GRJQ9apsjA_);
NTIkeyvaluepairseq__QqvaCqCpEE1QmQZbcZLi5A_.flags = 2;
NTIkeyvaluepairseq__QqvaCqCpEE1QmQZbcZLi5A_.marker = Marker_tySequence__QqvaCqCpEE1QmQZbcZLi5A;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[134].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[134].offset = offsetof(tyObject_Table__cBohObSCAwRxvYFXQHv2wA, data);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[134].typ = (&NTIkeyvaluepairseq__QqvaCqCpEE1QmQZbcZLi5A_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[134].name = "data";
TM__6kkF5shvTYOHG9cWBoBNLPQ_21_2[1] = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[139];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[139].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[139].offset = offsetof(tyObject_Table__cBohObSCAwRxvYFXQHv2wA, counter);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[139].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[139].name = "counter";
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[133].len = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[133].kind = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[133].sons = &TM__6kkF5shvTYOHG9cWBoBNLPQ_21_2[0];
NTItable__cBohObSCAwRxvYFXQHv2wA_.node = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[133];
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[132].kind = 1;
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[132].offset = offsetof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw, importModuleLookup);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[132].typ = (&NTItable__cBohObSCAwRxvYFXQHv2wA_);
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[132].name = "importModuleLookup";
TM__6kkF5shvTYOHG9cWBoBNLPQ_0[0].len = 65; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[0].kind = 2; TM__6kkF5shvTYOHG9cWBoBNLPQ_0[0].sons = &TM__6kkF5shvTYOHG9cWBoBNLPQ_2_65[0];
NTItcontext__TE0bwjD2I16QW6s9c4AgPvw_.node = &TM__6kkF5shvTYOHG9cWBoBNLPQ_0[0];
NTIpcontext__C5LQliQ3Detta8PpLynVjQ_.size = sizeof(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw*);
NTIpcontext__C5LQliQ3Detta8PpLynVjQ_.align = NIM_ALIGNOF(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw*);
NTIpcontext__C5LQliQ3Detta8PpLynVjQ_.kind = 22;
NTIpcontext__C5LQliQ3Detta8PpLynVjQ_.base = (&NTItcontext__TE0bwjD2I16QW6s9c4AgPvw_);
NTIpcontext__C5LQliQ3Detta8PpLynVjQ_.marker = Marker_tyRef__C5LQliQ3Detta8PpLynVjQ;
}

