/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tySequence__RNhZxf20g9beyq5VBOGxhDg tySequence__RNhZxf20g9beyq5VBOGxhDg;
typedef struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ;
typedef struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ tySequence__lFbCtu5P2Kf7YDYtGjkxAQ;
typedef struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA;
typedef struct tySequence__ijtae5OneaLys0hN9alAicA tySequence__ijtae5OneaLys0hN9alAicA;
typedef struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w;
typedef struct tySequence__SerjNoUujW2dUouVBrJiCw tySequence__SerjNoUujW2dUouVBrJiCw;
typedef struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyObject_Table__r0v8BdcBPKhl73K8p2VMUA;
typedef struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g tySequence__K9agbtcb0qPZuSJFXB9cTe6g;
typedef struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg;
typedef struct tySequence__m88qdML9cQOuqGAQn6XWL1A tySequence__m88qdML9cQOuqGAQn6XWL1A;
typedef struct tyObject_Table__1hIWbTQWYT4BmhdESze57A tyObject_Table__1hIWbTQWYT4BmhdESze57A;
typedef struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ tySequence__naEbXEp9b9aiW1zXJorqf9cXQ;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA;
typedef struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw;
typedef struct tySequence__ed0C0uAUZPhvw3RAc5hfYg tySequence__ed0C0uAUZPhvw3RAc5hfYg;
typedef struct tyObject_Table__imojfg883tkWsWJwyshGqQ tyObject_Table__imojfg883tkWsWJwyshGqQ;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg tyObject_Table__BCPh85PHtwxox9bv7NLFrlg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA;
typedef struct tySequence__KgiZ29chkJAD01p9aLRB32qw tySequence__KgiZ29chkJAD01p9aLRB32qw;
typedef struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A tyObject_Table__LM44poVdVEn4Mo4N4L8c3A;
typedef struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw tySequence__rkYRZrbHVYL3nhXlQW3K9bw;
typedef struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ tySequence__IRFEb1e9bxgbJLuB5xrdZsQ;
typedef struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ;
typedef struct tySequence__YmPd0eWfcTfrVYrthlXPYA tySequence__YmPd0eWfcTfrVYrthlXPYA;
typedef struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q;
typedef struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg tySequence__Hz5SYwQU29b9aFLt09blvVQPg;
typedef struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg tyObject_Table__R7JnJQEipxxOlJWXQz7jWg;
typedef struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ tySequence__3G9aA9cLXaPxuRxMKm3anacQ;
typedef struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q tySequence__bPFv6ypvvCX2A9a9al8utL2Q;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw;
typedef struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw;
typedef struct tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ;
typedef struct tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA;
typedef struct tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA;
typedef struct tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw;
typedef struct tySequence__vvBerF0axaNtu9aMA2gnsrA tySequence__vvBerF0axaNtu9aMA2gnsrA;
typedef struct tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ;
typedef struct tySequence__ZQPym9bf1jM5qaSn7LUXMKA tySequence__ZQPym9bf1jM5qaSn7LUXMKA;
typedef struct tySequence__9c3OY0aBmSBgwdsnBAPf4Ag tySequence__9c3OY0aBmSBgwdsnBAPf4Ag;
typedef struct tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ;
typedef struct tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ;
typedef struct tySequence__Jhh6ks9carRtwV9aOuM8yMNw tySequence__Jhh6ks9carRtwV9aOuM8yMNw;
typedef struct tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw tySequence__Bis5AbpONWcIRrPyPJS8Yw;
typedef struct tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg;
typedef struct tySequence__E8pi9b5QNahsURYzXMjh3qw tySequence__E8pi9b5QNahsURYzXMjh3qw;
typedef struct tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg;
typedef struct tySequence__XDpbjnuseLNZDGLBQ2Qzow tySequence__XDpbjnuseLNZDGLBQ2Qzow;
typedef struct tyObject_Table__cBohObSCAwRxvYFXQHv2wA tyObject_Table__cBohObSCAwRxvYFXQHv2wA;
typedef struct tySequence__QqvaCqCpEE1QmQZbcZLi5A tySequence__QqvaCqCpEE1QmQZbcZLi5A;
typedef struct tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
typedef struct tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct tySequence__k7EQb9bN3Uhl608xoPGMRJA tySequence__k7EQb9bN3Uhl608xoPGMRJA;
typedef struct tyTuple__toqrUPSdp8zSxOdlxMJj9cA tyTuple__toqrUPSdp8zSxOdlxMJj9cA;
typedef struct tySequence__8Np6tlClE5az1CyqZdN19bQ tySequence__8Np6tlClE5az1CyqZdN19bQ;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct tyObject_PragmaBlockContext__KenhkbpTaL6MY9cFJ0RV2bA tyObject_PragmaBlockContext__KenhkbpTaL6MY9cFJ0RV2bA;
typedef struct tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ;
typedef struct tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA;
typedef struct tySequence__dLJ0v9cLHnWw9bA0ZQgPURgA tySequence__dLJ0v9cLHnWw9bA0ZQgPURgA;
typedef struct tySequence__zeatLyX5s1CrMAiU9c9bWBSQ tySequence__zeatLyX5s1CrMAiU9c9bWBSQ;
typedef struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ;
typedef struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g tySequence__qeAsXh2i1GAL5Nl0g3OP8g;
typedef struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg;
typedef struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg;
typedef struct tySequence__4Murtwnm0Fyc7F9acrytEXw tySequence__4Murtwnm0Fyc7F9acrytEXw;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw;
typedef struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg tySequence__QnmOtn1Iv4LvxOXoMn8Rbg;
typedef struct tySequence__oKtVqsc9bQVCNyrijELM4OQ tySequence__oKtVqsc9bQVCNyrijELM4OQ;
typedef struct tySequence__qy6Iwdy00wN560qud54HTg tySequence__qy6Iwdy00wN560qud54HTg;
typedef struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ tySequence__k67v9bwvvQDmS1ynyGGUbeQ;
typedef struct tySequence__cLsClAAfd0MKkoBQVyvdvw tySequence__cLsClAAfd0MKkoBQVyvdvw;
typedef struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg tySequence__q9bTuOB0JXh1iZ3CSGdRLbg;
typedef struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw;
typedef struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ;
typedef struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ;
typedef struct tySequence__C3r8jsj9chA4sIlYfDN5aDw tySequence__C3r8jsj9chA4sIlYfDN5aDw;
typedef struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ;
typedef struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg tyTuple__UluY8x0Nj6cp9b0o88wJ0lg;
typedef struct tySequence__dlD6tEGzYLLpKVq3XwuFlA tySequence__dlD6tEGzYLLpKVq3XwuFlA;
typedef struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ;
typedef struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg;
typedef struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ;
typedef struct tyTuple__rZZA0skon1OsHdiEvT8RZQ tyTuple__rZZA0skon1OsHdiEvT8RZQ;
typedef struct tySequence__6OFCSvqRaxyEgUqWtnZSlw tySequence__6OFCSvqRaxyEgUqWtnZSlw;
typedef struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q;
typedef struct tySequence__UnGSk9aaLosDroi2QDrlOfQ tySequence__UnGSk9aaLosDroi2QDrlOfQ;
typedef struct tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA;
typedef struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA tyTuple__q13Zt16VkCqu6Zg5jWqwHA;
typedef struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA tyTuple__aWN9bNzF9bubXNJV9ciomgpfA;
typedef struct tySequence__m4PVWjcAAjfxlwJxLkKn8A tySequence__m4PVWjcAAjfxlwJxLkKn8A;
typedef struct tyTuple__RWXAsQlFoGYyEQZp1G65sg tyTuple__RWXAsQlFoGYyEQZp1G65sg;
typedef struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg;
typedef struct tyTuple__RmGJuqOgEaHckHndh0LEsw tyTuple__RmGJuqOgEaHckHndh0LEsw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__J4cxakKjhKxTIJR9bojMmXw tyTuple__J4cxakKjhKxTIJR9bojMmXw;
typedef struct tySequence__i89c5kdtWKzK3OEiI81pkkw tySequence__i89c5kdtWKzK3OEiI81pkkw;
typedef struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A;
typedef struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ;
typedef struct tySequence__GR8qmV1kNRcoQ2g76VFy3A tySequence__GR8qmV1kNRcoQ2g76VFy3A;
typedef struct tyTuple__a7QginWFapakKbWJBJ2vfA tyTuple__a7QginWFapakKbWJBJ2vfA;
typedef struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__kbX6x85REySUrk9auORL0vw tyTuple__kbX6x85REySUrk9auORL0vw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g;
typedef struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q;
typedef struct tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A;
typedef struct tyTuple__nF9cH4hinXgGEUwO4G2bshw tyTuple__nF9cH4hinXgGEUwO4G2bshw;
typedef struct tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg;
typedef struct tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q;
typedef struct tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA;
typedef struct tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w;
typedef struct tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg;
typedef struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ tyTuple__NAaJgGVgNmlGoqmiWxdOHQ;
typedef struct tyTuple__VbApVidEWCFLq9a29bPtaS7A tyTuple__VbApVidEWCFLq9a29bPtaS7A;
typedef struct tyTuple__EbsafWGli8bW2GRJQ9apsjA tyTuple__EbsafWGli8bW2GRJQ9apsjA;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
typedef struct tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A;
typedef struct tyObject_Connection__SFxQPgR9b9aWd2frrlyFQ2mA tyObject_Connection__SFxQPgR9b9aWd2frrlyFQ2mA;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA;
typedef struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__PsEhl3dzznmmJiLAuIXZOg tyTuple__PsEhl3dzznmmJiLAuIXZOg;
typedef struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w;
typedef struct tyTuple__Db8CrQifKGIsKc3w71w7Lw tyTuple__Db8CrQifKGIsKc3w71w7Lw;
typedef struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg;
typedef struct tySequence__lo3S1lKyiPLhGGB9cBawd6A tySequence__lo3S1lKyiPLhGGB9cBawd6A;
typedef struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ;
typedef struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw tyTuple__FEYH9alRJhHD0uTKF2vnIqw;
typedef struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA;
typedef struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA;
typedef struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw;
typedef struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg tyTuple__VUJ5Hjm4tKAResBsRHJvYg;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInst;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg uniqueId;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
typedef NU16 tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw;
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__8FVNoIYL9aQTR0i9aA9cVH1sg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA {
tySequence__ijtae5OneaLys0hN9alAicA* data;
NI counter;
};
struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w {
tySequence__SerjNoUujW2dUouVBrJiCw* data;
NI counter;
};
struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA {
tySequence__K9agbtcb0qPZuSJFXB9cTe6g* data;
NI counter;
};
typedef tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyArray__46hjIasL27aUz9c7kgtWooQ[5];
struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg {
tySequence__m88qdML9cQOuqGAQn6XWL1A* data;
NI counter;
};
struct tyObject_Table__1hIWbTQWYT4BmhdESze57A {
tySequence__naEbXEp9b9aiW1zXJorqf9cXQ* data;
NI counter;
};
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
};
struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw {
NI counter;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* data;
};
struct tyObject_Table__imojfg883tkWsWJwyshGqQ {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA {
tySequence__KgiZ29chkJAD01p9aLRB32qw* data;
NI counter;
};
struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A {
tySequence__rkYRZrbHVYL3nhXlQW3K9bw* data;
NI counter;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg[65];
struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ {
tySequence__YmPd0eWfcTfrVYrthlXPYA* data;
NI counter;
};
struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__I6rzVhdiYtUh7jwWJQoeyw) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__EQOAUyRkp9c3eeiGlHvCThA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q {
tySequence__Hz5SYwQU29b9aFLt09blvVQPg* data;
NI counter;
};
struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg {
tySequence__3G9aA9cLXaPxuRxMKm3anacQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__1CO5eEh25fBKUWGagpikwg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
typedef N_NIMCALL_PTR(void, tyProc__VcUg5jOhttLagdxUmVN8Tg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__XOkru1xuh2bHzmkw1UYzLA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formal, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* actual);
struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opNot;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opContains;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLe;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLt;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAnd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opOr;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opIsNil;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opEq;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAdd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opSub;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opMul;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opDiv;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg {
tySequence__RNhZxf20g9beyq5VBOGxhDg* ifaces;
tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* packed_0;
tySequence__lFbCtu5P2Kf7YDYtGjkxAQ* encoders;
tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA typeInstCache;
tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w procInstCache;
tyArray__46hjIasL27aUz9c7kgtWooQ attachedOps;
tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg methodsPerType;
tyObject_Table__1hIWbTQWYT4BmhdESze57A enumToStringProcs;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw emittedTypeInfo;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA startupPackedConfig;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw deps;
tyObject_Table__imojfg883tkWsWJwyshGqQ importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__BCPh85PHtwxox9bv7NLFrlg inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* usageSym;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* owners;
tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA suggestSymbols;
tyObject_Table__LM44poVdVEn4Mo4N4L8c3A suggestErrors;
tySequence__IRFEb1e9bxgbJLuB5xrdZsQ* methods;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* systemModule;
tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg sysTypes;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw compilerprocs;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw exposed;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageTypes;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* emptyNode;
tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ canonTypes;
tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw symBodyHashes;
tyProc__I6rzVhdiYtUh7jwWJQoeyw importModuleCallback;
tyProc__EQOAUyRkp9c3eeiGlHvCThA includeFileCallback;
tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q cacheSeqs;
tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g cacheCounters;
tyObject_Table__R7JnJQEipxxOlJWXQz7jWg cacheTables;
tySequence__bPFv6ypvvCX2A9a9al8utL2Q* passes;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinition;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinitionResolveForward;
tyProc__1CO5eEh25fBKUWGagpikwg onUsage;
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* globalDestructors;
tyProc__VcUg5jOhttLagdxUmVN8Tg strongSemCheck;
tyProc__XOkru1xuh2bHzmkw1UYzLA compatibleProps;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg operators;
};
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU16 tySet_tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA;
typedef NU8 tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg;
typedef NimStringDesc* tyArray__Re75IspeoxXy2oCZHwcRrA[2];
typedef NU8 tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg[9];
typedef NU8 tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg {
NI id;
NimStringDesc* s;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* next;
NI h;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw {
  RootObj Sup;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__aaEwD7wUZoIxDUprFEbfMQ[38];
struct tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ {
NI counter;
tySequence__ZQPym9bf1jM5qaSn7LUXMKA* data;
};
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__q9caIJqxIEVMlKzDKc7PN3A) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* expectedType);
typedef NU32 tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__Kiet6YwcQwPvcQYHHEqqqQ) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* expectedType);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__PSlVV9bxpH9avY5YrjCD5uqA) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__8k9afYvvfaH1tjWAwlISb0A) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, void* ClE_0);
void* ClE_0;
} tyProc__9bnYcX9avusKBraL3FJXBwJw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__uojbiMfaKLMuGW9bbomtTBg) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
typedef NU32 tySet_tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__bqRyngJC8bSPcUqqn9bn73w) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nOrig, tySet_tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw filter, tySet_tyEnum_TExprFlag__r6ni9cszPdxrSgot9bYmbKjw flags);
typedef N_NIMCALL_PTR(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, tyProc__F6LocU8y66ng5Ra4XoVWJA) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* prev);
typedef struct {
N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, void* ClE_0);
void* ClE_0;
} tyProc__Nc9aAsBDTkr61wP9a9cnds8Og;
typedef struct {
N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, ClP_0) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fn, tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ pt, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, void* ClE_0);
void* ClE_0;
} tyProc__z8FaSv6eEIc72FZ9c9cBcaGg;
typedef NU8 tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ;
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__9aa59awckKpa9areOQSBOwSeQ) (tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* dc, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ op, NI col);
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
struct tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ {
tySequence__Bis5AbpONWcIRrPyPJS8Yw* data;
NI counter;
};
struct tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg {
tySequence__E8pi9b5QNahsURYzXMjh3qw* data;
NI counter;
};
struct tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg {
tySequence__XDpbjnuseLNZDGLBQ2Qzow* data;
NI counter;
};
struct tyObject_Table__cBohObSCAwRxvYFXQHv2wA {
tySequence__QqvaCqCpEE1QmQZbcZLi5A* data;
NI counter;
};
struct tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw {
  tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw Sup;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* enforceVoidContext;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* voidType;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* currentScope;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* moduleScope;
tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA* imports;
tyObject_TScope__9aTSl1tODXnq8aZe4E3GxoQ* topLevelScope;
tyObject_TProcCon__9aK41DZ7WNm5NSRfb1CbcRA* p;
tyArray__aaEwD7wUZoIxDUprFEbfMQ intTypeCache;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* nilTypeCache;
tyObject_TMatchedConcept__0kS5yo4t68pnIalDqA39crw* matchedConcept;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* friendModules;
NI instCounter;
NI* templInstCounter;
NI inGenericContext;
NI inStaticContext;
NI inUnrolledContext;
NI compilesContextId;
NI compilesContextIdGenerator;
NI inGenericInst;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* converters;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* patterns;
tySequence__vvBerF0axaNtu9aMA2gnsrA* optionStack;
tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ symMapping;
tySequence__9c3OY0aBmSBgwdsnBAPf4Ag* libs;
tyProc__q9caIJqxIEVMlKzDKc7PN3A semConstExpr;
tyProc__Kiet6YwcQwPvcQYHHEqqqQ semExpr;
tyProc__PSlVV9bxpH9avY5YrjCD5uqA semTryExpr;
tyProc__q9caIJqxIEVMlKzDKc7PN3A semTryConstExpr;
tyProc__8k9afYvvfaH1tjWAwlISb0A computeRequiresInit;
tyProc__9bnYcX9avusKBraL3FJXBwJw hasUnresolvedArgs;
tyProc__PSlVV9bxpH9avY5YrjCD5uqA semOperand;
tyProc__uojbiMfaKLMuGW9bbomtTBg semConstBoolExpr;
tyProc__bqRyngJC8bSPcUqqn9bn73w semOverloadedCall;
tyProc__F6LocU8y66ng5Ra4XoVWJA semTypeNode;
tyProc__Nc9aAsBDTkr61wP9a9cnds8Og semInferredLambda;
tyProc__z8FaSv6eEIc72FZ9c9cBcaGg semGenerateInstance;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw includedFiles;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw pureEnumFields;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw userPragmas;
tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ* evalContext;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw unknownIdents;
tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ* generics;
NI topStmts;
NI lastGenericIdx;
NI hloLoopDetector;
NI inParallelStmt;
tyProc__9aa59awckKpa9areOQSBOwSeQ instTypeBoundOp;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* selfName;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw signatures;
NimStringDesc* recursiveDep;
NIM_BOOL suggestionsMade;
NIM_BOOL isAmbiguous;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
NI inTypeContext;
NI inConceptDecl;
tySequence__Jhh6ks9carRtwV9aOuM8yMNw* unusedImports;
tyObject_HashSet__qEsCgvAiLX6rSzzn9cFnYvQ exportIndirections;
tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg importModuleMap;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastTLineInfo;
tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg sideEffects;
NI inUncheckedAssignSection;
tyObject_Table__cBohObSCAwRxvYFXQHv2wA importModuleLookup;
};
struct tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg {
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* s;
tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g;
NIM_BOOL beSmart;
};
struct tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ {
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* exc;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* tags;
NI bottom;
NI inTryStmt;
NI inExceptOrFinallyStmt;
NI leftPartOfAsgn;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* ownerModule;
tySequence__qwqHTkRvwhrRyENtudHQ7g* init;
tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg guards;
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* locked;
NIM_BOOL gcUnsafe;
NIM_BOOL isRecursive;
NIM_BOOL isTopLevel;
NIM_BOOL hasSideEffect;
NIM_BOOL inEnforcedGcSafe;
NIM_BOOL hasDangerousAssign;
NIM_BOOL isInnerProc;
NIM_BOOL inEnforcedNoSideEffects;
NI16 maxLockLevel;
NI16 currLockLevel;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ currOptions;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph;
tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw escapingParams;
};
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
typedef NU8 tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
struct tyTuple__toqrUPSdp8zSxOdlxMJj9cA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
typedef NU8 tySet_tyEnum_TTypeCmpFlag__IRq9bqtrf9ctEUyeRMyvWy4Q;
typedef NU8 tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg {
NI32 module;
NI32 symId;
NI32 typeId_0;
NIM_BOOL sealed;
};
typedef NU8 tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA;
typedef NU8 tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tySet_tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw[21];
typedef NU8 tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg;
typedef NimStringDesc* tyArray__EeEKCO7QpNg9c8wnv9c1UhNQ[5];
typedef NimStringDesc* tyArray__nHXaesL0DJZHyVS07ARPRA[1];
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
NI Field0;
NI Field1;
};
struct tyObject_PragmaBlockContext__KenhkbpTaL6MY9cFJ0RV2bA {
NI oldLocked;
NI16 oldLockLevel;
NIM_BOOL enforcedGcSafety;
NIM_BOOL enforceNoSideEffects;
NI oldExc;
NI oldTags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* exc;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* tags;
};
typedef NU8 tySet_tyEnum_SubgraphFlag__YymRBOaunI7GAAzxsJI39cA;
struct tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* param;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw mutatedHere;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw connectedVia;
tySet_tyEnum_SubgraphFlag__YymRBOaunI7GAAzxsJI39cA flags;
NI maxMutation;
NI minConnection;
tySequence__qwqHTkRvwhrRyENtudHQ7g* mutations;
};
typedef NU8 tySet_tyEnum_Goal__YflPrGhMLgZ4bbrBBVpmOA;
typedef NU8 tyEnum_Goal__YflPrGhMLgZ4bbrBBVpmOA;
struct tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA {
NI abstractTime;
tySequence__dLJ0v9cLHnWw9bA0ZQgPURgA* s;
tySequence__zeatLyX5s1CrMAiU9c9bWBSQ* graphs;
tySet_tyEnum_Goal__YflPrGhMLgZ4bbrBBVpmOA goals;
NIM_BOOL unanalysableMutation;
NI inAsgnSource;
NI inConstructor;
NI inNoSideEffectSection;
NI inConditional;
NI inLoop;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g;
};
typedef NimStringDesc* tyArray__sMpvt1sOxOJ3LFGulnbeMQ[4];
struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* converters;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* patterns;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* pureEnums;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interf;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interfHidden;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* uniqueName;
};
typedef NU8 tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg;
struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg {
tySequence__4Murtwnm0Fyc7F9acrytEXw* nodes;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ;
struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ {
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw {
tySequence__IHUFRsFxZNv7YydiUO2esQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag {
NimStringDesc* definedSymbols;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA moduleFlags;
tySequence__PXIzfWocnrafGz5p3CP5LA* includes;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* imports;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg toReplay;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg topLevel;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg bodies;
tySequence__b89aLriiJnVTD186H6zNIgg* exports;
tySequence__b89aLriiJnVTD186H6zNIgg* hidden;
tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw* reexports;
tySequence__b89aLriiJnVTD186H6zNIgg* compilerProcs;
tySequence__48JTohSgTy339bRxHzUD8KA* converters;
tySequence__48JTohSgTy339bRxHzUD8KA* methods;
tySequence__48JTohSgTy339bRxHzUD8KA* trmacros;
tySequence__48JTohSgTy339bRxHzUD8KA* pureEnums;
tySequence__QnmOtn1Iv4LvxOXoMn8Rbg* macroUsages;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* typeInstCache;
tySequence__qy6Iwdy00wN560qud54HTg* procInstCache;
tySequence__k67v9bwvvQDmS1ynyGGUbeQ* attachedOps;
tySequence__cLsClAAfd0MKkoBQVyvdvw* methodsPerType;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* enumToStringProcs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* emittedTypeInfo;
tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ backendFlags;
tySequence__q9bTuOB0JXh1iZ3CSGdRLbg* syms;
tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw* types;
tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ strings;
tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw numbers;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA cfg;
};
struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ {
tySequence__C3r8jsj9chA4sIlYfDN5aDw* data;
NI counter;
};
struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg {
tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg status;
NIM_BOOL symsInit;
NIM_BOOL typesInit;
NIM_BOOL loadedButAliveSetChanged;
tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag fromDisk;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* syms;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* types;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ iface;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ ifaceHidden;
};
struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ {
tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* data;
NI counter;
};
struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ {
NI32 thisModule;
NI32 lastFile;
NU32 lastLit;
tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ filenames;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* pendingTypes;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* pendingSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw typeMarker;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw symMarker;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
};
struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ {
NU32 module;
NI32 item;
};
struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg {
NI module;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ packed_0;
};
struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
};
struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__dlD6tEGzYLLpKVq3XwuFlA* Field2;
};
struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q {
NI module;
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg sym;
tySequence__UnGSk9aaLosDroi2QDrlOfQ* concreteTypes;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__rZZA0skon1OsHdiEvT8RZQ {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__6OFCSvqRaxyEgUqWtnZSlw* Field2;
};
struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field2;
};
struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
};
struct tyTuple__RWXAsQlFoGYyEQZp1G65sg {
NI Field0;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field1;
};
struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__m4PVWjcAAjfxlwJxLkKn8A* Field2;
};
struct tyTuple__RmGJuqOgEaHckHndh0LEsw {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field2;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
};
struct tyTuple__J4cxakKjhKxTIJR9bojMmXw {
NI Field0;
NI32 Field1;
tySequence__i89c5kdtWKzK3OEiI81pkkw* Field2;
};
struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ {
NI Field0;
NI32 Field1;
tySequence__GR8qmV1kNRcoQ2g76VFy3A* Field2;
};
struct tyTuple__a7QginWFapakKbWJBJ2vfA {
tySequence__ed0C0uAUZPhvw3RAc5hfYg* Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__kbX6x85REySUrk9auORL0vw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q {
tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A* root;
NI entries;
};
struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, tyProc__kqPx9c4py2HW6KcFMhNvxtg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__9c6qRjwy7Es8UkDTIUwAfFA) (tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__mv4BsRs5VEnhcxzV6pQU5w) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
struct tyTuple__nF9cH4hinXgGEUwO4G2bshw {
tyProc__kqPx9c4py2HW6KcFMhNvxtg Field0;
tyProc__9c6qRjwy7Es8UkDTIUwAfFA Field1;
tyProc__mv4BsRs5VEnhcxzV6pQU5w Field2;
NIM_BOOL Field3;
};
typedef NU8 tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ;
struct tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m;
tyEnum_ImportMode__4kYBzhtdX1Hkta8RDDKjrQ mode;
union{
struct {tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw imported;
} _mode_2;
struct {tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw exceptSet;
} _mode_3;
};
};
struct tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA {
tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* key;
RootObj* val;
};
struct tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* genericSym;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field0;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field1;
};
struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ {
NI Field0;
tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ Field1;
};
struct tyTuple__VbApVidEWCFLq9a29bPtaS7A {
NI Field0;
NI Field1;
tySequence__k7EQb9bN3Uhl608xoPGMRJA* Field2;
};
struct tyTuple__EbsafWGli8bW2GRJQ9apsjA {
NI Field0;
NI Field1;
tySequence__qwqHTkRvwhrRyENtudHQ7g* Field2;
};
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
typedef NU8 tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w;
struct tyObject_Connection__SFxQPgR9b9aWd2frrlyFQ2mA {
tyEnum_VarIndexKind__6gmJu6oZ1VBqh2mKO9cHZ5w kind;
union{
NI parent;
NI graphIndex;
};
};
typedef NU8 tySet_tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw;
struct tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A {
tyObject_Connection__SFxQPgR9b9aWd2frrlyFQ2mA con;
tySet_tyEnum_VarFlag__bzKsGwCSV281SrVX80B6Kw flags;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI reassignedTo;
NI aliveStart;
NI aliveEnd;
tySequence__qwqHTkRvwhrRyENtudHQ7g* borrowsFrom;
};
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
NU32 Field0;
NimStringDesc* Field1;
};
struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA {
NU16 line;
NI16 col;
NU32 file;
};
struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA {
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
NI32 operand;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeId_0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
};
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
NU32 Field0;
NI32 Field1;
};
struct tyTuple__PsEhl3dzznmmJiLAuIXZOg {
NU32 Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA Field1;
};
struct tyTuple__Db8CrQifKGIsKc3w71w7Lw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ key;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* concreteTypes;
};
struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ {
tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
NI Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
typedef NU8 tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ;
struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA {
tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
NU32 name;
NI32 path;
};
struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA {
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
NU32 name;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typ;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
NI32 ast;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ guard;
NI bitsize;
NI alignment;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
NU32 externalName;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw locFlags;
tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA annex;
NI32 constraint;
};
struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw {
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* types;
NI32 n;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeInst;
NI32 nonUniqueId;
};
struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg {
NI Field0;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* Field1;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* Field2;
};
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
NI Field0;
NI32 Field1;
NU32 Field2;
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  TGenericSeq Sup;
  NI data[SEQ_DECL_SIZE];
};
struct tySequence__k7EQb9bN3Uhl608xoPGMRJA {
  TGenericSeq Sup;
  tyTuple__toqrUPSdp8zSxOdlxMJj9cA data[SEQ_DECL_SIZE];
};
struct tySequence__8Np6tlClE5az1CyqZdN19bQ {
  TGenericSeq Sup;
  tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__RNhZxf20g9beyq5VBOGxhDg {
  TGenericSeq Sup;
  tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ data[SEQ_DECL_SIZE];
};
struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ {
  TGenericSeq Sup;
  tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg data[SEQ_DECL_SIZE];
};
struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ {
  TGenericSeq Sup;
  tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ data[SEQ_DECL_SIZE];
};
struct tySequence__dlD6tEGzYLLpKVq3XwuFlA {
  TGenericSeq Sup;
  tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ data[SEQ_DECL_SIZE];
};
struct tySequence__ijtae5OneaLys0hN9alAicA {
  TGenericSeq Sup;
  tyTuple__UluY8x0Nj6cp9b0o88wJ0lg data[SEQ_DECL_SIZE];
};
struct tySequence__6OFCSvqRaxyEgUqWtnZSlw {
  TGenericSeq Sup;
  tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q data[SEQ_DECL_SIZE];
};
struct tySequence__SerjNoUujW2dUouVBrJiCw {
  TGenericSeq Sup;
  tyTuple__rZZA0skon1OsHdiEvT8RZQ data[SEQ_DECL_SIZE];
};
struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g {
  TGenericSeq Sup;
  tyTuple__q13Zt16VkCqu6Zg5jWqwHA data[SEQ_DECL_SIZE];
};
struct tySequence__m4PVWjcAAjfxlwJxLkKn8A {
  TGenericSeq Sup;
  tyTuple__RWXAsQlFoGYyEQZp1G65sg data[SEQ_DECL_SIZE];
};
struct tySequence__m88qdML9cQOuqGAQn6XWL1A {
  TGenericSeq Sup;
  tyTuple__aWN9bNzF9bubXNJV9ciomgpfA data[SEQ_DECL_SIZE];
};
struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ {
  TGenericSeq Sup;
  tyTuple__RmGJuqOgEaHckHndh0LEsw data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__ed0C0uAUZPhvw3RAc5hfYg {
  TGenericSeq Sup;
  tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__i89c5kdtWKzK3OEiI81pkkw {
  TGenericSeq Sup;
  tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A data[SEQ_DECL_SIZE];
};
struct tySequence__KgiZ29chkJAD01p9aLRB32qw {
  TGenericSeq Sup;
  tyTuple__J4cxakKjhKxTIJR9bojMmXw data[SEQ_DECL_SIZE];
};
struct tySequence__GR8qmV1kNRcoQ2g76VFy3A {
  TGenericSeq Sup;
  tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* data[SEQ_DECL_SIZE];
};
struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw {
  TGenericSeq Sup;
  tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ data[SEQ_DECL_SIZE];
};
struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ {
  TGenericSeq Sup;
  tyTuple__a7QginWFapakKbWJBJ2vfA data[SEQ_DECL_SIZE];
};
struct tySequence__YmPd0eWfcTfrVYrthlXPYA {
  TGenericSeq Sup;
  tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg {
  TGenericSeq Sup;
  tyTuple__kbX6x85REySUrk9auORL0vw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ {
  TGenericSeq Sup;
  tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g data[SEQ_DECL_SIZE];
};
struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q {
  TGenericSeq Sup;
  tyTuple__nF9cH4hinXgGEUwO4G2bshw data[SEQ_DECL_SIZE];
};
struct tySequence__9boKiNhY9cnRQF2k9b9a9bGKbrA {
  TGenericSeq Sup;
  tyObject_ImportedModule__ABXo2nVfMtcWNYv5zEiXDg data[SEQ_DECL_SIZE];
};
struct tySequence__vvBerF0axaNtu9aMA2gnsrA {
  TGenericSeq Sup;
  tyObject_TOptionEntry__KcSoeh10J9aas3WZevEUD7Q* data[SEQ_DECL_SIZE];
};
struct tySequence__ZQPym9bf1jM5qaSn7LUXMKA {
  TGenericSeq Sup;
  tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA data[SEQ_DECL_SIZE];
};
struct tySequence__9c3OY0aBmSBgwdsnBAPf4Ag {
  TGenericSeq Sup;
  tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* data[SEQ_DECL_SIZE];
};
struct tySequence__yH9bx9bpa6jqsU89cxjyTAlPQ {
  TGenericSeq Sup;
  tyObject_TInstantiationPair__d4lcZMnmQK2Jh2jYkdgB4w data[SEQ_DECL_SIZE];
};
struct tySequence__Jhh6ks9carRtwV9aOuM8yMNw {
  TGenericSeq Sup;
  tyTuple__8vGER9aaTtt9bUk9avNQ3fEIg data[SEQ_DECL_SIZE];
};
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw {
  TGenericSeq Sup;
  tyTuple__NAaJgGVgNmlGoqmiWxdOHQ data[SEQ_DECL_SIZE];
};
struct tySequence__E8pi9b5QNahsURYzXMjh3qw {
  TGenericSeq Sup;
  tyTuple__47w2DboNEPf69aPgubZdd7Q data[SEQ_DECL_SIZE];
};
struct tySequence__XDpbjnuseLNZDGLBQ2Qzow {
  TGenericSeq Sup;
  tyTuple__VbApVidEWCFLq9a29bPtaS7A data[SEQ_DECL_SIZE];
};
struct tySequence__QqvaCqCpEE1QmQZbcZLi5A {
  TGenericSeq Sup;
  tyTuple__EbsafWGli8bW2GRJQ9apsjA data[SEQ_DECL_SIZE];
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
struct tySequence__dLJ0v9cLHnWw9bA0ZQgPURgA {
  TGenericSeq Sup;
  tyObject_VarIndex__yOk84K16nGJiOC29biRT9b4A data[SEQ_DECL_SIZE];
};
struct tySequence__zeatLyX5s1CrMAiU9c9bWBSQ {
  TGenericSeq Sup;
  tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ data[SEQ_DECL_SIZE];
};
struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g {
  TGenericSeq Sup;
  tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg data[SEQ_DECL_SIZE];
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  TGenericSeq Sup;
  tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE];
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  TGenericSeq Sup;
  NU32 data[SEQ_DECL_SIZE];
};
struct tySequence__4Murtwnm0Fyc7F9acrytEXw {
  TGenericSeq Sup;
  tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA data[SEQ_DECL_SIZE];
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  TGenericSeq Sup;
  tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE];
};
struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw {
  TGenericSeq Sup;
  tyTuple__PsEhl3dzznmmJiLAuIXZOg data[SEQ_DECL_SIZE];
};
struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg {
  TGenericSeq Sup;
  tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w data[SEQ_DECL_SIZE];
};
struct tySequence__oKtVqsc9bQVCNyrijELM4OQ {
  TGenericSeq Sup;
  tyTuple__Db8CrQifKGIsKc3w71w7Lw data[SEQ_DECL_SIZE];
};
struct tySequence__qy6Iwdy00wN560qud54HTg {
  TGenericSeq Sup;
  tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg data[SEQ_DECL_SIZE];
};
struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ {
  TGenericSeq Sup;
  tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ data[SEQ_DECL_SIZE];
};
struct tySequence__cLsClAAfd0MKkoBQVyvdvw {
  TGenericSeq Sup;
  tyTuple__FEYH9alRJhHD0uTKF2vnIqw data[SEQ_DECL_SIZE];
};
struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg {
  TGenericSeq Sup;
  tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA data[SEQ_DECL_SIZE];
};
struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw {
  TGenericSeq Sup;
  tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw data[SEQ_DECL_SIZE];
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  TGenericSeq Sup;
  NI64 data[SEQ_DECL_SIZE];
};
struct tySequence__lo3S1lKyiPLhGGB9cBawd6A {
  TGenericSeq Sup;
  tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ data[SEQ_DECL_SIZE];
};
struct tySequence__C3r8jsj9chA4sIlYfDN5aDw {
  TGenericSeq Sup;
  tyTuple__VUJ5Hjm4tKAResBsRHJvYg data[SEQ_DECL_SIZE];
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  TGenericSeq Sup;
  tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE];
};
struct tySequence__UnGSk9aaLosDroi2QDrlOfQ {
  TGenericSeq Sup;
  tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg data[SEQ_DECL_SIZE];
};
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, effectSpec__trees_284)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw effectType);
N_LIB_PRIVATE N_NIMCALL(void, checkRaisesSpec__sempass50_4423)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NIM_BOOL emitWarnings, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* spec, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* real, NimStringDesc* msg, NIM_BOOL hints, tyProc__8FVNoIYL9aQTR0i9aA9cVH1sg effectPredicate, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* hintsArg);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
N_LIB_PRIVATE N_NIMCALL(void, initPackedSet__pureZcollectionsZintsets_16)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result);
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, incl__pureZcollectionsZintsets_55)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(void, pushInfoContext__msgs_500)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* detail);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, lastSon__ast_4833)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderTree__renderer_46)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA renderFlags);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, typeToString__types_50)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg prefer);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(void, popInfoContext__msgs_517)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__astalgo_3489)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, subtypeRelation__sempass50_4410)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* spec, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* real);
N_LIB_PRIVATE N_NIMCALL(NI, safeInheritanceDiff__types_3444)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, excType__sempass50_2211)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, getEbase__sempass50_2207)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, sysTypeFromName__magicsys_55)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, skipTypes__ast_3723)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kinds);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatSingleElem)(NimStringDesc* formatstr, NimStringDesc* a);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___ast_3846)(NI16 x);
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_625)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_167)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_1441)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
static N_INLINE(void, decRef__system_5326)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5324)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5275)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5281)(void* usr);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqRC1)(TNimType* typ, NI len);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5319)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeI__ast_3320)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, propSpec__trees_316)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw effectType);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasRealBody__sempass50_4710)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, initEffects__sempass50_4673)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* effects, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* t, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c);
N_LIB_PRIVATE N_NIMCALL(void, rawInitEffects__sempass50_4661)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* effects);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getModule__astalgo_216)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, track__sempass50_2338)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, useVar__sempass50_2113)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isLocalVar__sempass50_162)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
static N_INLINE(NIM_BOOL, contains__sigmatch_4340)(NI* a, NI aLen_0, NI item);
static N_INLINE(NI, find__sigmatch_4345)(NI* a, NI aLen_0, NI item);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, requiresInit__typeallowed_593)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(void, useVarNoInitCheck__sempass50_959)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, guardGlobal__sempass50_221)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard);
static N_INLINE(NIM_BOOL, isGCedMem__ast_4191)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(void, markGcUnsafe__sempass50_361)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* reason);
N_LIB_PRIVATE N_NIMCALL(void, markSideEffect__sempass50_995)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* reason, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw useLoc);
N_LIB_PRIVATE N_NIMCALL(tySequence__k7EQb9bN3Uhl608xoPGMRJA**, mgetOrPut__sempass50_1047)(tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg* t, NI key, tySequence__k7EQb9bN3Uhl608xoPGMRJA* val);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameType__types_1886)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* a, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* b, tySet_tyEnum_TTypeCmpFlag__IRq9bqtrf9ctEUyeRMyvWy4Q flags);
N_LIB_PRIVATE N_NIMCALL(void, addRaiseEffect__sempass50_2237)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* comesFrom);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefectException__types_3466)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(void, throws__sempass50_2182)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* orig);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, copyTree__ast_4432)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* src);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_4798)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* son);
N_LIB_PRIVATE N_NIMCALL(void, createTypeBoundOps__sempass50_142)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, createTypeBoundOps__liftdestructors_47)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* orig, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, createRaise__sempass50_2223)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNode__ast_3289)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind);
N_LIB_PRIVATE N_NIMCALL(void, trackCall__sempass50_3376)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, getConstExpr__semfold_81)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
N_LIB_PRIVATE N_NIMCALL(void, mergeLockLevels__sempass50_2615)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI16 lockLevel);
N_LIB_PRIVATE N_NIMCALL(NI16, getLockLevel__sempass50_2600)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, markSideEffect__sempass50_2886)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* reason, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw useLoc);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, newSym__ast_3409)(tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw symKind, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg id, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options);
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextSymId__ast_3103)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x);
N_LIB_PRIVATE N_NIMCALL(void, propagateEffects__sempass50_2619)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(void, mergeRaises__sempass50_2273)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* comesFrom);
N_LIB_PRIVATE N_NIMCALL(void, mergeTags__sempass50_2281)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* comesFrom);
N_LIB_PRIVATE N_NIMCALL(void, addTag__sempass50_2259)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* comesFrom);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, createTag__sempass50_2230)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NIM_BOOL, hasWarn__options_570)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA note);
N_LIB_PRIVATE N_NIMCALL(void, warnAboutGcUnsafe__sempass50_358)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
static N_INLINE(NIM_BOOL, isNoEffectList__sempass50_2765)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isForwardedProc__sempass50_2558)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isIndirectCall__sempass50_2522)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, assumeTheWorst__sempass50_2736)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* op);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, importedFromC__sempass50_2589)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, markGcUnsafe__sempass50_368)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* reason);
N_LIB_PRIVATE N_NIMCALL(void, trackOperandForIndirectCall__sempass50_2799)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formals, NI argIndex, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* caller);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, skipConvCastAndClosure__astalgo_114)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NI, len__ast_3990)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, skipConv__types_3661)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NIM_BOOL, isTrival__sempass50_2788)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* caller);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isOwnedProcVar__sempass50_2741)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, invalidateFacts__guards_760)(tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(void, makeVolatile__sempass50_301)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___renderer_2116)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, notNilCheck__sempass50_2668)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* paramType);
N_LIB_PRIVATE N_NIMCALL(void, procVarCheck__sempass50_2648)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, skipTypesOrNil__ast_4173)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kinds);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isAddrNode__astalgo_4290)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsNode__ast_4546)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kinds);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg, impliesNotNil__guards_1044)(tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg);
N_LIB_PRIVATE N_NIMCALL(void, initVarViaNew__sempass50_341)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, initVar__sempass50_312)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL volatileCheck);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, lastSon__ast_3731)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n);
N_LIB_PRIVATE N_NIMCALL(void, checkBounds__sempass50_3355)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arr, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* idx);
N_LIB_PRIVATE N_NIMCALL(void, checkLe__sempass50_3351)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg, proveLe__guards_1628)(tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, lowBound__guards_261)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, highBound__guards_265)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x, tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg* o);
static N_INLINE(NI, find__sempass50_3628)(tyArray__EeEKCO7QpNg9c8wnv9c1UhNQ a, NimStringDesc* item);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuNormalize)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getAttachedOp__modulegraphs_4049)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ op);
N_LIB_PRIVATE N_NIMCALL(void, checkForSink__sempass50_24)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, newType__ast_3884)(tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind, tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg id, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner);
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextTypeId__ast_3122)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x);
N_LIB_PRIVATE N_NIMCALL(void, add__concepts_23)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* father, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* son);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
static N_INLINE(NIM_BOOL, isEmptyType__ast_4780)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(void, guardDotAccess__sempass50_237)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, lookupInRecord__astalgo_84)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* field);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeI__ast_3324)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NI children);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newSymNode__ast_3704)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameTree__guards_680)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
N_LIB_PRIVATE N_NIMCALL(void, checkFieldAccess__guards_1809)(tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, trackTryStmt__sempass50_2341)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, addToIntersection__sempass50_2160)(tySequence__8Np6tlClE5az1CyqZdN19bQ** inter, NI s);
N_LIB_PRIVATE N_NIMCALL(void, catchesAll__sempass50_2326)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInfixAs__ast_4936)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, catches__sempass50_2293)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* e);
N_LIB_PRIVATE N_NIMCALL(void, trackPragmaStmt__sempass50_2569)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw, whichPragma__trees_244)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, listEffects__sempass50_2289)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a);
N_LIB_PRIVATE N_NIMCALL(void, addAsgnFact__guards_1739)(tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* key, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* value);
N_LIB_PRIVATE N_NIMCALL(void, trackCase__sempass50_3057)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, interestingCaseExpr__guards_114)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* m);
N_LIB_PRIVATE N_NIMCALL(void, addCaseBranchFacts__guards_1764)(tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI i);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, breaksBlock__sempass50_3022)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, trackIf__sempass50_3158)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, addFact__guards_609)(tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* nn);
N_LIB_PRIVATE N_NIMCALL(void, addFactNeg__guards_632)(tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, trackBlock__sempass50_3274)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasSubnodeWith__ast_4571)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isTrue__trees_375)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NIM_BOOL, fromSystem__astalgo_238)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* op);
N_LIB_PRIVATE N_NIMCALL(void, addFactLe__guards_1643)(tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
N_LIB_PRIVATE N_NIMCALL(void, addFactLt__guards_1651)(tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
N_LIB_PRIVATE N_NIMCALL(void, addDiscriminantFact__guards_1726)(tyObject_TModel__tS0Q7dyUUn29b4OkYBwt3pg* m, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, createBlockContext__sempass50_3750)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_PragmaBlockContext__KenhkbpTaL6MY9cFJ0RV2bA* Result);
N_LIB_PRIVATE N_NIMCALL(void, lockLocations__sempass50_206)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pragma);
N_LIB_PRIVATE N_NIMCALL(NI16, getLockLevel__sempass50_182)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
N_LIB_PRIVATE N_NIMCALL(void, castBlock__sempass50_3799)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pragma, tyObject_PragmaBlockContext__KenhkbpTaL6MY9cFJ0RV2bA* bc);
N_LIB_PRIVATE N_NIMCALL(void, applyBlockContext__sempass50_3771)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_PragmaBlockContext__KenhkbpTaL6MY9cFJ0RV2bA* bc);
N_LIB_PRIVATE N_NIMCALL(void, unapplyBlockContext__sempass50_3774)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_PragmaBlockContext__KenhkbpTaL6MY9cFJ0RV2bA* bc);
N_LIB_PRIVATE N_NIMCALL(void, trackInnerProc__sempass50_3823)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, getBody__modulegraphs_13094)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, loadProcBody__icZic_8386)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ** g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, allowCStringConv__sempass50_3865)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isCharArrayPtr__types_4177)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, NIM_BOOL allowPointerToChar);
N_LIB_PRIVATE N_NIMCALL(void, checkRange__sempass50_3359)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* value, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, errorToString__errorhandling_107)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isSinkTypeForParam__types_4145)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
static N_INLINE(NIM_BOOL, isClosure__ast_5031)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ);
N_LIB_PRIVATE N_NIMCALL(void, patchResult__sempass50_3317)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, computeGraphPartitions__varpartitions_1622)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tySet_tyEnum_Goal__YflPrGhMLgZ4bbrBBVpmOA goals, tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* Result);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasSideEffect__varpartitions_131)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* c, tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ* info);
N_LIB_PRIVATE N_NIMCALL(void, checkBorrowedLocations__varpartitions_1734)(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA* par, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config);
N_LIB_PRIVATE N_NIMCALL(void, listGcUnsafety__sempass50_411)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NIM_BOOL onlyWarning, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, listGcUnsafety__sempass50_386)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NIM_BOOL onlyWarning, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* cycleCheck, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__astalgo_402)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___varpartitions_108)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ* g);
N_LIB_PRIVATE N_NIMCALL(void, listSideEffects__sempass50_953)(NimStringDesc** result, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* context);
N_LIB_PRIVATE N_NIMCALL(void, nsuAddf)(NimStringDesc** s, NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(void, listSideEffects__sempass50_416)(NimStringDesc** result, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* cycleCheck, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* context, NI indentLevel);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__sempass50_484)(tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg t, NI key);
N_LIB_PRIVATE N_NIMCALL(tySequence__k7EQb9bN3Uhl608xoPGMRJA**, X5BX5D___sempass50_821)(tyObject_Table__g9cTlJykWlQLKMuaRBpUEZg* t, NI key);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuRepeatStr)(NimStringDesc* s, NI n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___msgs_634)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, checkNil__nilcheck_9362)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_2, " ", 1);
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_4, "/home/runner/work/nightlies/nightlies/nim/compiler/sempass2.nim", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_3 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 1293),
((NI) 13)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_5, "\'$1\' cannot raise \'$2\'", 22);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_6 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 1300),
((NI) 15)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_7, "can raise an unlisted exception: ", 33);
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_8, "Exception", 9);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__O8rpA4QnF63fyis4dAzZxA_9 = {
0x10, 0x09, 0xe0, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_10, "can have an unlisted effect: ", 29);
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_11, "base method is GC-safe, but \'$1\' is not", 39);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_12 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 1318),
((NI) 14)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_13, "base method has lock level $1, but dispatcher has $2", 52);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_14 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 1327),
((NI) 13)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_15, "(", 1);
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_16, ", ", 2);
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_17, ")", 1);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_18 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 1340),
((NI) 19)}
;
extern NIM_CONST tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw unknownLineInfo__lineinfos_284;
extern TNimType NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_;
extern TNimType NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_19 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 323),
((NI) 15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_20 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 325),
((NI) 15)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_21, "unguarded access: ", 18);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_22 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 144),
((NI) 14)}
;
extern NIM_CONST tySet_tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw routineKinds__ast_469;
extern TNimType NTIseqLLtlineinfo_psymTT__k7EQb9bN3Uhl608xoPGMRJA_;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__O8rpA4QnF63fyis4dAzZxA_23 = {
0x10, 0xa9, 0x80, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_24, "expected lock level < ", 22);
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_25, " but got lock level ", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_26 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 530),
((NI) 17)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_27, "RootEffect", 10);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_28 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 209),
((NI) 9)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_29 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 618),
((NI) 19)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__O8rpA4QnF63fyis4dAzZxA_30 = {
0x10, 0xa9, 0x00, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_31, " is not GC safe", 15);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_32 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 657),
((NI) 16)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_33, "\'$1\' cannot be passed to a procvar", 34);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_34 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 554),
((NI) 14)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__O8rpA4QnF63fyis4dAzZxA_35 = {
0x00, 0x00, 0x80, 0x00, 0x00, 0xc0, 0x00, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw TM__O8rpA4QnF63fyis4dAzZxA_36 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00,
0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_37, "cannot prove \'$1\' is not nil", 28);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_38 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 577),
((NI) 15)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_39, "\'$1\' is provably nil", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_40 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 580),
((NI) 15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_41 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 875),
((NI) 17)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_42, "cannot prove: ", 14);
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_43, " <= ", 4);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_44 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 769),
((NI) 11)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_45, "can prove: ", 11);
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_46, " > ", 3);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_47 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 774),
((NI) 11)}
;
extern NIM_CONST tyArray__EeEKCO7QpNg9c8wnv9c1UhNQ AttachedOpToStr__ast_3836;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_48, "=", 1);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__O8rpA4QnF63fyis4dAzZxA_49 = {
0x10, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_50, "could not turn \'$1\' to a sink parameter", 39);
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_52, "/home/runner/work/nightlies/nightlies/nim/compiler/sinkparameter_inference.nim", 78);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_51 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_52),
((NI) 50),
((NI) 15)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__O8rpA4QnF63fyis4dAzZxA_53 = {
0x10, 0xa9, 0xe0, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_54, "invalid guard field: ", 21);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_55 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 167),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_56 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 180),
((NI) 14)}
;
extern TNimType NTIseqLtupleLa58int_b58intTT__8Np6tlClE5az1CyqZdN19bQ_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_57 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 401),
((NI) 33)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_58 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 402),
((NI) 33)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_59, "_", 1);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__O8rpA4QnF63fyis4dAzZxA_60 = {
0x10, 0xa8, 0x90, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_61, "..", 2);
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_62, "countup", 7);
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_63, "countdown", 9);
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_64, "..<", 3);
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_65, "locks pragma without argument", 29);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_66 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 115),
((NI) 14)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_67, "invalid lock level: ", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_68 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 122),
((NI) 18)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_69, "multi-lock requires the same static lock level for every operand", 64);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_70 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 125),
((NI) 18)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_71, "invalid nested locking", 22);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_72 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 131),
((NI) 16)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_73, "invalid pragma block: ", 22);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_74 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 976),
((NI) 14)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_75, "implicit conversion to \'cstring\' from a non-const location: $1; this will become a compile time error in the future", 115);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_76 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 1216),
((NI) 13)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_77 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 1221),
((NI) 13)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_78, "conversion to enum with holes is unsafe: $1", 43);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_79 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 1228),
((NI) 15)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_80, "enum conversion: $1", 19);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_81 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 1230),
((NI) 15)}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__O8rpA4QnF63fyis4dAzZxA_82 = {
0x10, 0xa9, 0x00, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_83 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 1265),
((NI) 14)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_84, "result", 6);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_85 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 1436),
((NI) 13)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_86, "=destroy", 8);
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_87, "routine has no return type, but .requires contains \'result\'", 59);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_88 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 759),
((NI) 16)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_89, "\'$#\' is not GC-safe as it calls \'$#\'", 36);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_90 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 249),
((NI) 15)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_91, "\'$#\' is not GC-safe as it accesses \'$#\' which is a global using GC\'ed memory", 76);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_92 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 253),
((NI) 15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_93 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 260),
((NI) 13)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_94, "\'$#\' is not GC-safe as it performs an indirect call via \'$#\'", 60);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_95 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 264),
((NI) 13)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_96, "\'$#\' is not GC-safe as it performs an indirect call here", 56);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_97 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 268),
((NI) 13)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_98, "\'$1\' can have side effects$2", 28);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_99 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 1490),
((NI) 18)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_100, "\'$#\' can have side effects\012", 27);
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_101, "$# $# Hint: \'$#\' $#\012", 20);
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_102, ">", 1);
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_103, "accesses global state \'$#\'", 26);
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_104, "accessed by \'$#\'", 16);
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_105, "calls `.sideEffect` \'$#\'", 24);
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_106, "called by \'$#\'", 14);
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_107, "calls routine via hidden pointer indirection", 44);
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_108, "calls routine via pointer indirection", 37);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_109 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 1494),
((NI) 15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_110 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 1496),
((NI) 18)}
;
STRING_LITERAL(TM__O8rpA4QnF63fyis4dAzZxA_111, "declared lock level is $1, but real lock level is $2", 52);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__O8rpA4QnF63fyis4dAzZxA_112 = {((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_4),
((NI) 1505),
((NI) 11)}
;
static NIM_CONST tySet_tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw TM__O8rpA4QnF63fyis4dAzZxA_113 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x80, 0x1f, 0x04, 0x04, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x80, 0x00}
;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5228;
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_238)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* Result) {
	initPackedSet__pureZcollectionsZintsets_16(Result);
}
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__ast_3155(n);
	}
	LA1_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, checkRaisesSpec__sempass50_4423)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, NIM_BOOL emitWarnings, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* spec, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* real, NimStringDesc* msg, NIM_BOOL hints, tyProc__8FVNoIYL9aQTR0i9aA9cVH1sg effectPredicate, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* hintsArg) {
	tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw used;
	nimZeroMem((void*)(&used), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
	initIntSet__pureZcollectionsZintsets_238((&used));
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* r;
		r = NIM_NIL;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148(real);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					r = (*real)._kind_6.sons->data[i];
					{
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* rr;
						tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ T24_;
						NimStringDesc* T30_;
						NimStringDesc* T31_;
						NimStringDesc* T32_;
						{
							NI s;
							NI colontmp__2;
							NI i_3;
							s = (NI)0;
							colontmp__2 = (NI)0;
							colontmp__2 = len__ast_3155(spec);
							i_3 = ((NI) 0);
							{
								while (1) {
									if (!(i_3 < colontmp__2)) goto LA8;
									s = i_3;
									{
										NIM_BOOL T11_;
										T11_ = (NIM_BOOL)0;
										T11_ = effectPredicate(g, (*spec)._kind_6.sons->data[s], r);
										if (!T11_) goto LA12_;
										incl__pureZcollectionsZintsets_55((&used), s);
										goto LA5;
									}
									LA12_: ;
									i_3 += ((NI) 1);
								} LA8: ;
							}
						}
						pushInfoContext__msgs_500((*g).config, (*spec).info, ((NimStringDesc*) NIM_NIL));
						{
							if (!((*r).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 108))) goto LA16_;
							rr = (*r)._kind_6.sons->data[((NI) 0)];
						}
						goto LA14_;
						LA16_: ;
						{
							rr = r;
						}
						LA14_: ;
						{
							while (1) {
								NIM_BOOL T21_;
								NI T23_;
								T21_ = (NIM_BOOL)0;
								T21_ = ((*rr).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115) || (*rr).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126));
								if (!(T21_)) goto LA22_;
								T23_ = (NI)0;
								T23_ = len__ast_3155(rr);
								T21_ = (((NI) 0) < T23_);
								LA22_: ;
								if (!T21_) goto LA20;
								rr = lastSon__ast_4833(rr);
							} LA20: ;
						}
						T24_ = (tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ)0;
						{
							if (!emitWarnings) goto LA27_;
							T24_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 68);
						}
						goto LA25_;
						LA27_: ;
						{
							T24_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15);
						}
						LA25_: ;
						T30_ = NIM_NIL;
						T31_ = NIM_NIL;
						T31_ = renderTree__renderer_46(rr, 0);
						T32_ = NIM_NIL;
						T32_ = typeToString__types_50((*r).typ, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
						T30_ = rawNewString((T31_ ? T31_->Sup.len : 0) + (msg ? msg->Sup.len : 0) + (T32_ ? T32_->Sup.len : 0) + 1);
appendString(T30_, T31_);
appendString(T30_, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_2));
appendString(T30_, msg);
appendString(T30_, T32_);
						liMessage__msgs_1128((*g).config, (*r).info, T24_, T30_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_3, NIM_FALSE);
						popInfoContext__msgs_517((*g).config);
					} LA5: ;
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	{
		if (!hints) goto LA35_;
		{
			NI s_2;
			NI colontmp__3;
			NI i_4;
			s_2 = (NI)0;
			colontmp__3 = (NI)0;
			colontmp__3 = len__ast_3155(spec);
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__3)) goto LA39;
					s_2 = i_4;
					{
						NIM_BOOL T42_;
						tyArray__Re75IspeoxXy2oCZHwcRrA T45_;
						NimStringDesc* T46_;
						T42_ = (NIM_BOOL)0;
						T42_ = contains__astalgo_3489((&used), s_2);
						if (!!(T42_)) goto LA43_;
						nimZeroMem((void*)T45_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
						T45_[0] = renderTree__renderer_46(hintsArg, 0);
						T45_[1] = renderTree__renderer_46((*spec)._kind_6.sons->data[s_2], 0);
						T46_ = NIM_NIL;
						T46_ = nsuFormatOpenArray(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_5), T45_, 2);
						liMessage__msgs_1128((*g).config, (*(*spec)._kind_6.sons->data[s_2]).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 78), T46_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_6, NIM_FALSE);
					}
					LA43_: ;
					i_4 += ((NI) 1);
				} LA39: ;
			}
		}
	}
	LA35_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, getEbase__sempass50_2207)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	result = NIM_NIL;
	result = sysTypeFromName__magicsys_55(g, info, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_8));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, excType__sempass50_2211)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1));
		if (T3_) goto LA4_;
		T3_ = ((*n).typ == 0);
		LA4_: ;
		if (!T3_) goto LA5_;
		t = getEbase__sempass50_2207(g, (*n).info);
	}
	goto LA1_;
	LA5_: ;
	{
		t = (*n).typ;
	}
	LA1_: ;
	result = skipTypes__ast_3723(t, TM__O8rpA4QnF63fyis4dAzZxA_9);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, subtypeRelation__sempass50_4410)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* spec, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* real) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		if (!((*(*spec).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 57))) goto LA3_;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA** t;
			NI i;
			NI L;
			NI T6_;
			t = (tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA**)0;
			i = ((NI) 0);
			T6_ = ((*(*spec).typ).sons ? (*(*spec).typ).sons->Sup.len : 0);
			L = T6_;
			{
				while (1) {
					if (!(i < L)) goto LA8;
					t = &(*(*spec).typ).sons->data[i];
					{
						tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T11_;
						NI T12_;
						T11_ = NIM_NIL;
						T11_ = excType__sempass50_2211(g, real);
						T12_ = (NI)0;
						T12_ = safeInheritanceDiff__types_3444(T11_, (*t));
						if (!(T12_ <= ((NI) 0))) goto LA13_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA13_: ;
					i += ((NI) 1);
				} LA8: ;
			}
		}
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T16_;
		NI T17_;
		T16_ = NIM_NIL;
		T16_ = excType__sempass50_2211(g, real);
		T17_ = (NI)0;
		T17_ = safeInheritanceDiff__types_3444(T16_, (*spec).typ);
		result = (T17_ <= ((NI) 0));
		goto BeforeRet_;
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkMethodEffects__sempass50_4527)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* disp, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* branch) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* actual;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* raisesSpec;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* tagsSpec;
{	actual = (*(*(*branch).typ).n)._kind_6.sons->data[((NI) 0)];
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__ast_3155(actual);
		if (!!((T3_ == ((NI) 5)))) goto LA4_;
		goto BeforeRet_;
	}
	LA4_: ;
	p = (*(*disp).ast)._kind_6.sons->data[((NI) 4)];
	raisesSpec = effectSpec__trees_284(p, ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 174));
	{
		if (!!((raisesSpec == 0))) goto LA8_;
		checkRaisesSpec__sempass50_4423(g, NIM_FALSE, raisesSpec, (*actual)._kind_6.sons->data[((NI) 0)], ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_7), NIM_FALSE, subtypeRelation__sempass50_4410, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
	}
	LA8_: ;
	tagsSpec = effectSpec__trees_284(p, ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 179));
	{
		if (!!((tagsSpec == 0))) goto LA12_;
		checkRaisesSpec__sempass50_4423(g, NIM_FALSE, tagsSpec, (*actual)._kind_6.sons->data[((NI) 3)], ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_10), NIM_FALSE, subtypeRelation__sempass50_4410, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
	}
	LA12_: ;
	{
		NIM_BOOL T16_;
		NimStringDesc* T20_;
		T16_ = (NIM_BOOL)0;
		T16_ = (((*disp).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 26))&63U)))!=0);
		if (!(T16_)) goto LA17_;
		T16_ = ((130 & (*(*branch).typ).flags) == 0);
		LA17_: ;
		if (!T16_) goto LA18_;
		T20_ = NIM_NIL;
		T20_ = nsuFormatSingleElem(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_11), (*(*branch).name).s);
		liMessage__msgs_1128((*g).config, (*branch).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T20_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_12, NIM_FALSE);
	}
	LA18_: ;
	{
		tyArray__Re75IspeoxXy2oCZHwcRrA T25_;
		NimStringDesc* T26_;
		if (!((*(*disp).typ).lockLevel < (*(*branch).typ).lockLevel)) goto LA23_;
		nimZeroMem((void*)T25_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
		T25_[0] = dollar___ast_3846((*(*branch).typ).lockLevel);
		T25_[1] = dollar___ast_3846((*(*disp).typ).lockLevel);
		T26_ = NIM_NIL;
		T26_ = nsuFormatOpenArray(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_13), T25_, 2);
		liMessage__msgs_1128((*g).config, (*branch).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 53), T26_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_14, NIM_FALSE);
	}
	LA23_: ;
	}BeforeRet_: ;
}
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x) {
	addInt__stdZprivateZdigitsutils_167(result, ((NI64) (x)));
}
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_625)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = resizeString(result, (info.Field0 ? info.Field0->Sup.len : 0) + 0);
appendString(result, info.Field0);
	{
		if (!(((NI) 0) < info.Field1)) goto LA3_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_15));
		addInt__stdZprivateZdigitsutils_189((&result), info.Field1);
		{
			if (!(((NI) 0) < (NI)(info.Field2 + ((NI) 1)))) goto LA7_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_16));
			addInt__stdZprivateZdigitsutils_189((&result), (NI)(info.Field2 + ((NI) 1)));
		}
		LA7_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_17));
	}
	LA3_: ;
	return result;
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5324)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5275((&gch__system_5228.zct), c);
}
static N_INLINE(void, decRef__system_5326)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5324(c);
	}
	LA4_: ;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5281)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5281(p);
	decRef__system_5326(T1_);
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5319)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5281(src);
		incRef__system_5319(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5281((*dest));
		decRef__system_5326(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(void, setEffectsForProcType__sempass50_4560)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* effects;
{	effects = (*(*t).n)._kind_6.sons->data[((NI) 0)];
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25)));
		if (T3_) goto LA4_;
		T3_ = !(((*effects).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152)));
		LA4_: ;
		if (!T3_) goto LA5_;
		goto BeforeRet_;
	}
	LA5_: ;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* raisesSpec;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* tagsSpec;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* requiresSpec;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ensuresSpec;
		if (!!(((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)))) goto LA9_;
		{
			NI T13_;
			NimStringDesc* argX60gensym547_;
			T13_ = (NI)0;
			T13_ = len__ast_3155(effects);
			if (!!((T13_ == ((NI) 0)))) goto LA14_;
			argX60gensym547_ = toFileLineCol__msgs_625(TM__O8rpA4QnF63fyis4dAzZxA_18);
			internalErrorImpl__msgs_1441((*g).config, unknownLineInfo__lineinfos_284, argX60gensym547_, TM__O8rpA4QnF63fyis4dAzZxA_18);
		}
		LA14_: ;
		if ((*effects)._kind_6.sons) { nimGCunrefNoCycle((*effects)._kind_6.sons); (*effects)._kind_6.sons = NIM_NIL; }
		(*effects)._kind_6.sons = (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) newSeqRC1((&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) 5));
		raisesSpec = effectSpec__trees_284(n, ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 174));
		{
			if (!!((raisesSpec == 0))) goto LA18_;
			asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 0)]), raisesSpec);
		}
		goto LA16_;
		LA18_: ;
		{
			NIM_BOOL T21_;
			NIM_BOOL T23_;
			T21_ = (NIM_BOOL)0;
			T21_ = !((s == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
			if (!(T21_)) goto LA22_;
			T23_ = (NIM_BOOL)0;
			T23_ = !(((*s).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 0)));
			if (T23_) goto LA24_;
			T23_ = ((192 & (*s).flags) == 64);
			LA24_: ;
			T21_ = T23_;
			LA22_: ;
			if (!T21_) goto LA25_;
			asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 0)]), newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152), (*effects).info));
		}
		goto LA16_;
		LA25_: ;
		LA16_: ;
		tagsSpec = effectSpec__trees_284(n, ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 179));
		{
			if (!!((tagsSpec == 0))) goto LA29_;
			asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 3)]), tagsSpec);
		}
		goto LA27_;
		LA29_: ;
		{
			NIM_BOOL T32_;
			NIM_BOOL T34_;
			T32_ = (NIM_BOOL)0;
			T32_ = !((s == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
			if (!(T32_)) goto LA33_;
			T34_ = (NIM_BOOL)0;
			T34_ = !(((*s).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 0)));
			if (T34_) goto LA35_;
			T34_ = ((192 & (*s).flags) == 64);
			LA35_: ;
			T32_ = T34_;
			LA33_: ;
			if (!T32_) goto LA36_;
			asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 3)]), newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152), (*effects).info));
		}
		goto LA27_;
		LA36_: ;
		LA27_: ;
		requiresSpec = propSpec__trees_316(n, ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 180));
		{
			if (!!((requiresSpec == 0))) goto LA40_;
			asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 1)]), requiresSpec);
		}
		LA40_: ;
		ensuresSpec = propSpec__trees_316(n, ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 181));
		{
			if (!!((ensuresSpec == 0))) goto LA44_;
			asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 2)]), ensuresSpec);
		}
		LA44_: ;
		asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 4)]), n);
	}
	LA9_: ;
	{
		NIM_BOOL T48_;
		T48_ = (NIM_BOOL)0;
		T48_ = !((s == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
		if (!(T48_)) goto LA49_;
		T48_ = !(((*s).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 0)));
		LA49_: ;
		if (!T48_) goto LA50_;
		{
			if (!!(((*s).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 20)))) goto LA54_;
			(*t).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 1)) & 63);
		}
		LA54_: ;
	}
	LA50_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasRealBody__sempass50_4710)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((80 & (*s).flags) == 0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInitEffects__sempass50_4661)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* effects) {
	if ((*effects)._kind_6.sons) { nimGCunrefNoCycle((*effects)._kind_6.sons); (*effects)._kind_6.sons = NIM_NIL; }
	(*effects)._kind_6.sons = (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) newSeqRC1((&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) 5));
	asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 0)]), newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152), (*effects).info));
	asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 3)]), newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152), (*effects).info));
	asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 1)]), (*g).emptyNode);
	asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 2)]), (*g).emptyNode);
	asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 4)]), (*g).emptyNode);
}
N_LIB_PRIVATE N_NIMCALL(void, initEffects__sempass50_4673)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* effects, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* t, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c) {
	rawInitEffects__sempass50_4661(g, effects);
	unsureAsgnRef((void**) (&(*t).exc), (*effects)._kind_6.sons->data[((NI) 0)]);
	unsureAsgnRef((void**) (&(*t).tags), (*effects)._kind_6.sons->data[((NI) 3)]);
	unsureAsgnRef((void**) (&(*t).owner), s);
	unsureAsgnRef((void**) (&(*t).ownerModule), getModule__astalgo_216(s));
	unsureAsgnRef((void**) (&(*t).init), NIM_NIL);
	unsureAsgnRef((void**) (&(*t).guards.s), NIM_NIL);
	unsureAsgnRef((void**) (&(*t).guards.g), g);
	(*t).currOptions = ((*(*g).config).options | (*s).options);
	(*t).guards.beSmart = (((*t).currOptions &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 9))&31U)))!=0);
	unsureAsgnRef((void**) (&(*t).locked), NIM_NIL);
	unsureAsgnRef((void**) (&(*t).graph), g);
	unsureAsgnRef((void**) (&(*t).config), (*g).config);
	unsureAsgnRef((void**) (&(*t).c), c);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isLocalVar__sempass50_162)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NIM_BOOL T3_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T3_ = (NIM_BOOL)0;
	T3_ = ((2304 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
	if (!(T3_)) goto LA4_;
	T3_ = !((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 3))&63U)))!=0));
	LA4_: ;
	T2_ = T3_;
	if (!(T2_)) goto LA5_;
	T2_ = ((*s).owner == (*a).owner);
	LA5_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA6_;
	T1_ = !(((*s).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
	LA6_: ;
	result = T1_;
	return result;
}
static N_INLINE(NI, find__sigmatch_4345)(NI* a, NI aLen_0, NI item) {
	NI result;
{	result = (NI)0;
	result = ((NI) 0);
	{
		NI* i;
		NI i_2;
		i = (NI*)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < aLen_0)) goto LA3;
				i = (&a[i_2]);
				{
					if (!((*i) == item)) goto LA6_;
					goto BeforeRet_;
				}
				LA6_: ;
				result += ((NI) 1);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__sigmatch_4340)(NI* a, NI aLen_0, NI item) {
	NIM_BOOL result;
	NI T1_;
{	result = (NIM_BOOL)0;
	T1_ = (NI)0;
	T1_ = find__sigmatch_4345(a, aLen_0, item);
	result = (((NI) 0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, guardGlobal__sempass50_221)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard) {
{	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** L;
		NI i;
		NI L_2;
		NI T2_;
		L = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
		i = ((NI) 0);
		T2_ = ((*a).locked ? (*a).locked->Sup.len : 0);
		L_2 = T2_;
		{
			while (1) {
				if (!(i < L_2)) goto LA4;
				L = &(*a).locked->data[i];
				{
					NIM_BOOL T7_;
					T7_ = (NIM_BOOL)0;
					T7_ = ((*(*L)).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
					if (!(T7_)) goto LA8_;
					T7_ = ((*(*L))._kind_4.sym == guard);
					LA8_: ;
					if (!T7_) goto LA9_;
					goto BeforeRet_;
				}
				LA9_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
	{
		NimStringDesc* T15_;
		NimStringDesc* T16_;
		if (!!((*a).isTopLevel)) goto LA13_;
		T15_ = NIM_NIL;
		T16_ = NIM_NIL;
		T16_ = renderTree__renderer_46(n, 0);
		T15_ = rawNewString((T16_ ? T16_->Sup.len : 0) + 18);
appendString(T15_, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_21));
appendString(T15_, T16_);
		liMessage__msgs_1128((*a).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T15_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_22, NIM_FALSE);
	}
	LA13_: ;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isGCedMem__ast_4191)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24));
	if (T1_) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25));
	if (!(T3_)) goto LA4_;
	T3_ = ((*t).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
	LA4_: ;
	T1_ = T3_;
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, markGcUnsafe__sempass50_361)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* reason) {
	{
		if (!!((*a).inEnforcedGcSafe)) goto LA3_;
		(*a).gcUnsafe = NIM_TRUE;
		{
			if (!((520192 &((NU32)1<<((NU)((*(*a).owner).kind)&31U)))!=0)) goto LA7_;
			asgnRef((void**) (&(*(*a).owner)._kind_1.gcUnsafetyReason), reason);
		}
		LA7_: ;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, markSideEffect__sempass50_995)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* reason, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw useLoc) {
	{
		if (!!((*a).inEnforcedNoSideEffects)) goto LA3_;
		(*a).hasSideEffect = NIM_TRUE;
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym93_;
			tySequence__k7EQb9bN3Uhl608xoPGMRJA* T9_;
			tySequence__k7EQb9bN3Uhl608xoPGMRJA** T10_;
			tyTuple__toqrUPSdp8zSxOdlxMJj9cA T11_;
			NI T12_;
			if (!((routineKinds__ast_469 &((NU32)1<<((NU)((*(*a).owner).kind)&31U)))!=0)) goto LA7_;
			sym = NIM_NIL;
			sym = reason;
			xX60gensym93_ = (*a).owner;
			T9_ = NIM_NIL;
			T9_ = NIM_NIL;
			T10_ = (tySequence__k7EQb9bN3Uhl608xoPGMRJA**)0;
			T10_ = mgetOrPut__sempass50_1047((&(*(*a).c).sideEffects), (NI)((NI)((NU64)(((NI) ((*xX60gensym93_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym93_).Sup.itemId.item))), T9_);
			nimZeroMem((void*)(&T11_), sizeof(tyTuple__toqrUPSdp8zSxOdlxMJj9cA));
			T11_.Field0 = useLoc;
			T11_.Field1 = sym;
			unsureAsgnRef((void**) (&(*T10_)), (tySequence__k7EQb9bN3Uhl608xoPGMRJA*) incrSeqV3((TGenericSeq*)((*T10_)), (&NTIseqLLtlineinfo_psymTT__k7EQb9bN3Uhl608xoPGMRJA_)));
			T12_ = (*T10_)->Sup.len++;
			(*T10_)->data[T12_].Field0 = T11_.Field0;
			asgnRef((void**) (&(*T10_)->data[T12_].Field1), T11_.Field1);
		}
		LA7_: ;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, useVarNoInitCheck__sempass50_959)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = !(((67108872 & (*s).flags) == 0));
		if (!(T4_)) goto LA5_;
		T4_ = ((768 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA6_;
		T3_ = !(((*s).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 264)));
		LA6_: ;
		if (!T3_) goto LA7_;
		{
			if (!!(((*s)._kind_2.guard == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA11_;
			guardGlobal__sempass50_221(a, n, (*s)._kind_2.guard);
		}
		LA11_: ;
		{
			NIM_BOOL T15_;
			NIM_BOOL T17_;
			T15_ = (NIM_BOOL)0;
			T15_ = ((67108872 & (*s).flags) == 8);
			if (!(T15_)) goto LA16_;
			T17_ = (NIM_BOOL)0;
			T17_ = (((*(*s).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 22))&63U)))!=0);
			if (T17_) goto LA18_;
			T17_ = isGCedMem__ast_4191((*s).typ);
			LA18_: ;
			T15_ = T17_;
			LA16_: ;
			if (!T15_) goto LA19_;
			markGcUnsafe__sempass50_361(a, s);
		}
		LA19_: ;
		markSideEffect__sempass50_995(a, s, (*n).info);
	}
	LA7_: ;
	{
		NIM_BOOL T23_;
		NIM_BOOL T24_;
		T23_ = (NIM_BOOL)0;
		T24_ = (NIM_BOOL)0;
		T24_ = !(((*s).owner == (*a).owner));
		if (!(T24_)) goto LA25_;
		T24_ = ((2099976 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
		LA25_: ;
		T23_ = T24_;
		if (!(T23_)) goto LA26_;
		T23_ = ((67108872 & (*s).flags) == 0);
		LA26_: ;
		if (!T23_) goto LA27_;
		(*a).isInnerProc = NIM_TRUE;
	}
	LA27_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, useVar__sempass50_2113)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
	s = (*n)._kind_4.sym;
	{
		if (!(((NI) 0) < (*a).inExceptOrFinallyStmt)) goto LA3_;
		(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 44)) & 63);
	}
	LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = isLocalVar__sempass50_162(a, s);
		if (!T7_) goto LA8_;
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym110_;
			NI T14_;
			if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 14))&63U)))!=0)) goto LA12_;
			xX60gensym110_ = s;
			unsureAsgnRef((void**) (&(*a).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)((*a).init), (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_)));
			T14_ = (*a).init->Sup.len++;
			(*a).init->data[T14_] = (NI)((NI)((NU64)(((NI) ((*xX60gensym110_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym110_).Sup.itemId.item)));
		}
		goto LA10_;
		LA12_: ;
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym112_;
			NIM_BOOL T16_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym117_;
			NI T27_;
			xX60gensym112_ = s;
			T16_ = (NIM_BOOL)0;
			T16_ = contains__sigmatch_4340(((*a).init) ? ((*a).init->data) : NIM_NIL, ((*a).init ? (*a).init->Sup.len : 0), (NI)((NI)((NU64)(((NI) ((*xX60gensym112_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym112_).Sup.itemId.item))));
			if (!!(T16_)) goto LA17_;
			{
				NIM_BOOL T21_;
				T21_ = (NIM_BOOL)0;
				T21_ = requiresInit__typeallowed_593((*s).typ);
				if (!T21_) goto LA22_;
				liMessage__msgs_1128((*a).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 42), (*(*s).name).s, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_19, NIM_FALSE);
			}
			goto LA19_;
			LA22_: ;
			{
				if (!((*a).leftPartOfAsgn <= ((NI) 0))) goto LA25_;
				liMessage__msgs_1128((*a).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 50), (*(*s).name).s, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_20, NIM_FALSE);
			}
			goto LA19_;
			LA25_: ;
			LA19_: ;
			xX60gensym117_ = s;
			unsureAsgnRef((void**) (&(*a).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)((*a).init), (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_)));
			T27_ = (*a).init->Sup.len++;
			(*a).init->data[T27_] = (NI)((NI)((NU64)(((NI) ((*xX60gensym117_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym117_).Sup.itemId.item)));
		}
		goto LA10_;
		LA17_: ;
		LA10_: ;
	}
	LA8_: ;
	useVarNoInitCheck__sempass50_959(a, n, s);
}
N_LIB_PRIVATE N_NIMCALL(void, throws__sempass50_2182)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* orig) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = !(((*(*n).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 50)));
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x;
			if (!!((orig == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA9_;
			x = copyTree__ast_4432(orig);
			asgnRef((void**) (&(*x).typ), (*n).typ);
			add__ast_4798(tracked, x);
		}
		goto LA7_;
		LA9_: ;
		{
			add__ast_4798(tracked, n);
		}
		LA7_: ;
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addRaiseEffect__sempass50_2237)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* comesFrom) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* aa;
{	aa = (*a).exc;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(aa);
		i_2 = (*a).bottom;
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T6_;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T7_;
					NIM_BOOL T8_;
					T6_ = NIM_NIL;
					T6_ = excType__sempass50_2211((*a).graph, (*aa)._kind_6.sons->data[i]);
					T7_ = NIM_NIL;
					T7_ = excType__sempass50_2211((*a).graph, e);
					T8_ = (NIM_BOOL)0;
					T8_ = sameType__types_1886(T6_, T7_, 0);
					if (!T8_) goto LA9_;
					goto BeforeRet_;
				}
				LA9_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	{
		if (!!(((*e).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA13_;
		{
			NIM_BOOL T17_;
			NIM_BOOL T19_;
			T17_ = (NIM_BOOL)0;
			T17_ = (((*(*a).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 47))&63U)))!=0);
			if (T17_) goto LA18_;
			T19_ = (NIM_BOOL)0;
			T19_ = isDefectException__types_3466((*e).typ);
			T17_ = !(T19_);
			LA18_: ;
			if (!T17_) goto LA20_;
			throws__sempass50_2182((*a).exc, e, comesFrom);
		}
		LA20_: ;
	}
	LA13_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, createTypeBoundOps__sempass50_142)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
{	{
		if (!(typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	createTypeBoundOps__liftdestructors_47((*tracked).graph, (*tracked).c, typ, info, (*(*tracked).c).Sup.idgen);
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = (((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 31))&63U)))!=0);
		if (T7_) goto LA8_;
		T7_ = (((*(*tracked).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 40))&63U)))!=0);
		LA8_: ;
		if (!T7_) goto LA9_;
		(*(*tracked).owner).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 42)) & 63);
	}
	LA9_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, createRaise__sempass50_2223)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = newNode__ast_3289(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 4));
	asgnRef((void**) (&(*result).typ), getEbase__sempass50_2207(g, (*n).info));
	{
		if (!!((n == 0))) goto LA3_;
		(*result).info = (*n).info;
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, mergeLockLevels__sempass50_2615)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI16 lockLevel) {
	{
		if (!((*tracked).currLockLevel <= lockLevel)) goto LA3_;
		{
			NimStringDesc* T9_;
			NimStringDesc* T10_;
			NimStringDesc* T11_;
			if (!(((NI16) 0) < (*tracked).currLockLevel)) goto LA7_;
			T9_ = NIM_NIL;
			T10_ = NIM_NIL;
			T10_ = dollar___ast_3846((*tracked).currLockLevel);
			T11_ = NIM_NIL;
			T11_ = dollar___ast_3846(lockLevel);
			T9_ = rawNewString((T10_ ? T10_->Sup.len : 0) + (T11_ ? T11_->Sup.len : 0) + 42);
appendString(T9_, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_24));
appendString(T9_, T10_);
appendString(T9_, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_25));
appendString(T9_, T11_);
			liMessage__msgs_1128((*tracked).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T9_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_26, NIM_FALSE);
		}
		LA7_: ;
		(*tracked).maxLockLevel = (((*tracked).maxLockLevel >= lockLevel) ? (*tracked).maxLockLevel : lockLevel);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI16, getLockLevel__sempass50_2600)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NI16 result;
	result = (NI16)0;
	result = (*(*s).typ).lockLevel;
	{
		if (!(result == ((NI16) -1))) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = !(((4160 & (*s).flags) == 0));
			if (T7_) goto LA8_;
			T7_ = (((*(*s).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 1))&63U)))!=0);
			LA8_: ;
			if (!T7_) goto LA9_;
			result = ((NI16) 0);
		}
		goto LA5_;
		LA9_: ;
		{
			result = ((NI16) 1001);
		}
		LA5_: ;
	}
	LA3_: ;
	return result;
}
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextSymId__ast_3103)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x) {
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*x).symId += ((NI) 1);
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	result.module = (*x).module;
	result.item = (*x).symId;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, markSideEffect__sempass50_2886)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* reason, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw useLoc) {
	{
		if (!!((*a).inEnforcedNoSideEffects)) goto LA3_;
		(*a).hasSideEffect = NIM_TRUE;
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym225_;
			tySequence__k7EQb9bN3Uhl608xoPGMRJA* T20_;
			tySequence__k7EQb9bN3Uhl608xoPGMRJA** T21_;
			tyTuple__toqrUPSdp8zSxOdlxMJj9cA T22_;
			NI T23_;
			if (!((routineKinds__ast_469 &((NU32)1<<((NU)((*(*a).owner).kind)&31U)))!=0)) goto LA7_;
			sym = NIM_NIL;
			{
				if (!((*reason).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA11_;
				sym = (*reason)._kind_4.sym;
			}
			goto LA9_;
			LA11_: ;
			{
				tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
				tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T19_;
				{
					if (!((*reason).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65))) goto LA16_;
					kind = ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3);
				}
				goto LA14_;
				LA16_: ;
				{
					kind = ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 0);
				}
				LA14_: ;
				T19_ = nextSymId__ast_3103((*(*a).c).Sup.idgen);
				sym = newSym__ast_3409(kind, (*(*a).owner).name, T19_, (*a).owner, (*reason).info, 0);
			}
			LA9_: ;
			xX60gensym225_ = (*a).owner;
			T20_ = NIM_NIL;
			T20_ = NIM_NIL;
			T21_ = (tySequence__k7EQb9bN3Uhl608xoPGMRJA**)0;
			T21_ = mgetOrPut__sempass50_1047((&(*(*a).c).sideEffects), (NI)((NI)((NU64)(((NI) ((*xX60gensym225_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym225_).Sup.itemId.item))), T20_);
			nimZeroMem((void*)(&T22_), sizeof(tyTuple__toqrUPSdp8zSxOdlxMJj9cA));
			T22_.Field0 = useLoc;
			T22_.Field1 = sym;
			unsureAsgnRef((void**) (&(*T21_)), (tySequence__k7EQb9bN3Uhl608xoPGMRJA*) incrSeqV3((TGenericSeq*)((*T21_)), (&NTIseqLLtlineinfo_psymTT__k7EQb9bN3Uhl608xoPGMRJA_)));
			T23_ = (*T21_)->Sup.len++;
			(*T21_)->data[T23_].Field0 = T22_.Field0;
			asgnRef((void**) (&(*T21_)->data[T23_].Field1), T22_.Field1);
		}
		LA7_: ;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, mergeRaises__sempass50_2273)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* comesFrom) {
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T5_;
		if (!(b == 0)) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = createRaise__sempass50_2223((*a).graph, comesFrom);
		addRaiseEffect__sempass50_2237(a, T5_, comesFrom);
	}
	goto LA1_;
	LA3_: ;
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* effect;
			effect = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(b);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA10;
						i = i_2;
						effect = (*b)._kind_6.sons->data[i];
						addRaiseEffect__sempass50_2237(a, effect, comesFrom);
						i_2 += ((NI) 1);
					} LA10: ;
				}
			}
		}
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addTag__sempass50_2259)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* comesFrom) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* aa;
{	aa = (*a).tags;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(aa);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T6_;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T7_;
					NIM_BOOL T8_;
					T6_ = NIM_NIL;
					T6_ = skipTypes__ast_3723((*(*aa)._kind_6.sons->data[i]).typ, TM__O8rpA4QnF63fyis4dAzZxA_9);
					T7_ = NIM_NIL;
					T7_ = skipTypes__ast_3723((*e).typ, TM__O8rpA4QnF63fyis4dAzZxA_9);
					T8_ = (NIM_BOOL)0;
					T8_ = sameType__types_1886(T6_, T7_, 0);
					if (!T8_) goto LA9_;
					goto BeforeRet_;
				}
				LA9_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	throws__sempass50_2182((*a).tags, e, comesFrom);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, createTag__sempass50_2230)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = newNode__ast_3289(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 4));
	asgnRef((void**) (&(*result).typ), sysTypeFromName__magicsys_55(g, (*n).info, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_27)));
	{
		if (!!((n == 0))) goto LA3_;
		(*result).info = (*n).info;
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, mergeTags__sempass50_2281)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* comesFrom) {
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T5_;
		if (!(b == 0)) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = createTag__sempass50_2230((*a).graph, comesFrom);
		addTag__sempass50_2259(a, T5_, comesFrom);
	}
	goto LA1_;
	LA3_: ;
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* effect;
			effect = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(b);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA10;
						i = i_2;
						effect = (*b)._kind_6.sons->data[i];
						addTag__sempass50_2259(a, effect, comesFrom);
						i_2 += ((NI) 1);
					} LA10: ;
				}
			}
		}
	}
	LA1_: ;
}
static N_INLINE(NIM_BOOL, hasWarn__options_570)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA note) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 13))&31U)))!=0);
	if (!(T1_)) goto LA2_;
	T1_ = (((*conf).notes[(NU)((note- 17))>>3] &(1U<<((NU)((note- 17))&7U)))!=0);
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, warnAboutGcUnsafe__sempass50_358)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NimStringDesc* T1_;
	T1_ = NIM_NIL;
	T1_ = renderTree__renderer_46(n, 0);
	liMessage__msgs_1128(conf, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 48), T1_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_28, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(void, propagateEffects__sempass50_2619)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pragma;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* spec;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* tagSpec;
	NI16 T16_;
	pragma = (*(*s).ast)._kind_6.sons->data[((NI) 4)];
	spec = effectSpec__trees_284(pragma, ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 174));
	mergeRaises__sempass50_2273(tracked, spec, n);
	tagSpec = effectSpec__trees_284(pragma, ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 179));
	mergeTags__sempass50_2281(tracked, tagSpec, n);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((130 & (*(*s).typ).flags) == 0);
		if (!(T3_)) goto LA4_;
		T3_ = !((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 6))&63U)))!=0));
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			NIM_BOOL T9_;
			T9_ = (NIM_BOOL)0;
			T9_ = hasWarn__options_570((*tracked).config, ((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 48));
			if (!T9_) goto LA10_;
			warnAboutGcUnsafe__sempass50_358(n, (*tracked).config);
		}
		LA10_: ;
		markGcUnsafe__sempass50_361(tracked, s);
	}
	LA5_: ;
	{
		if (!!((((*(*s).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 1))&63U)))!=0))) goto LA14_;
		markSideEffect__sempass50_995(tracked, s, (*n).info);
	}
	LA14_: ;
	T16_ = (NI16)0;
	T16_ = getLockLevel__sempass50_2600(s);
	mergeLockLevels__sempass50_2615(tracked, n, T16_);
}
static N_INLINE(NIM_BOOL, isNoEffectList__sempass50_2765)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NIM_BOOL T4_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NI)0;
	T2_ = len__ast_3155(n);
	T1_ = (T2_ == ((NI) 0));
	if (T1_) goto LA3_;
	T4_ = (NIM_BOOL)0;
	T4_ = ((*n)._kind_6.sons->data[((NI) 3)] == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
	if (!(T4_)) goto LA5_;
	T4_ = ((*n)._kind_6.sons->data[((NI) 0)] == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
	LA5_: ;
	T1_ = T4_;
	LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isForwardedProc__sempass50_2558)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
	if (!(T1_)) goto LA2_;
	T1_ = (((*(*n)._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 4))&63U)))!=0);
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isIndirectCall__sempass50_2522)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		if (!!(((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)))) goto LA3_;
		result = NIM_TRUE;
	}
	goto LA1_;
	LA3_: ;
	{
		if (!((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3))) goto LA6_;
		{
			if (!(((*(*tracked).c).features &((NU32)1<<((NU)(((tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw) 16))&31U)))!=0)) goto LA10_;
			{
				NIM_BOOL T14_;
				T14_ = (NIM_BOOL)0;
				T14_ = ((*tracked).owner == (*(*n)._kind_4.sym).owner);
				if (!(T14_)) goto LA15_;
				T14_ = (((*(*n)._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 47))&63U)))!=0);
				LA15_: ;
				if (!T14_) goto LA16_;
				result = NIM_FALSE;
			}
			goto LA12_;
			LA16_: ;
			{
				result = NIM_TRUE;
			}
			LA12_: ;
		}
		goto LA8_;
		LA10_: ;
		{
			NIM_BOOL T20_;
			T20_ = (NIM_BOOL)0;
			T20_ = !(((*tracked).owner == (*(*n)._kind_4.sym).owner));
			if (T20_) goto LA21_;
			T20_ = ((*tracked).owner == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL));
			LA21_: ;
			result = T20_;
		}
		LA8_: ;
	}
	goto LA1_;
	LA6_: ;
	{
		if (!!(((520192 &((NU32)1<<((NU)((*(*n)._kind_4.sym).kind)&31U)))!=0))) goto LA23_;
		result = NIM_TRUE;
	}
	goto LA1_;
	LA23_: ;
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, assumeTheWorst__sempass50_2736)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* op) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T1_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T2_;
	NI16 lockLevel;
	T1_ = NIM_NIL;
	T1_ = createRaise__sempass50_2223((*tracked).graph, n);
	addRaiseEffect__sempass50_2237(tracked, T1_, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
	T2_ = NIM_NIL;
	T2_ = createTag__sempass50_2230((*tracked).graph, n);
	addTag__sempass50_2259(tracked, T2_, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
	{
		if (!((*op).lockLevel == ((NI16) -1))) goto LA5_;
		lockLevel = ((NI16) 1001);
	}
	goto LA3_;
	LA5_: ;
	{
		lockLevel = (*op).lockLevel;
	}
	LA3_: ;
	mergeLockLevels__sempass50_2615(tracked, n, lockLevel);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, importedFromC__sempass50_2589)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
	if (!(T1_)) goto LA2_;
	T1_ = (((*(*n)._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 6))&63U)))!=0);
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, markGcUnsafe__sempass50_368)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* reason) {
	{
		if (!!((*a).inEnforcedGcSafe)) goto LA3_;
		(*a).gcUnsafe = NIM_TRUE;
		{
			if (!((520192 &((NU32)1<<((NU)((*(*a).owner).kind)&31U)))!=0)) goto LA7_;
			{
				if (!((*reason).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA11_;
				asgnRef((void**) (&(*(*a).owner)._kind_1.gcUnsafetyReason), (*reason)._kind_4.sym);
			}
			goto LA9_;
			LA11_: ;
			{
				tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T14_;
				T14_ = nextSymId__ast_3103((*(*a).c).Sup.idgen);
				asgnRef((void**) (&(*(*a).owner)._kind_1.gcUnsafetyReason), newSym__ast_3409(((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 0), (*(*a).owner).name, T14_, (*a).owner, (*reason).info, 0));
			}
			LA9_: ;
		}
		LA7_: ;
	}
	LA3_: ;
}
static N_INLINE(NI, len__ast_3990)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n).sons ? (*n).sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(NIM_BOOL, isTrival__sempass50_2788)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* caller) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*caller).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
	if (!(T1_)) goto LA2_;
	T1_ = ((*(*caller)._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 92) || (*(*caller)._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 143) || (*(*caller)._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 149) || (*(*caller)._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 150) || (*(*caller)._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 142));
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isOwnedProcVar__sempass50_2741)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
	if (!(T2_)) goto LA3_;
	T2_ = ((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = ((*tracked).owner == (*(*n)._kind_4.sym).owner);
	LA4_: ;
	result = T1_;
	{
		NIM_BOOL T9_;
		if (!(((*(*tracked).c).features &((NU32)1<<((NU)(((tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw) 16))&31U)))!=0)) goto LA7_;
		T9_ = (NIM_BOOL)0;
		T9_ = result;
		if (!(T9_)) goto LA10_;
		T9_ = (((*(*n)._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 47))&63U)))!=0);
		LA10_: ;
		result = T9_;
	}
	LA7_: ;
	return result;
}
static N_INLINE(void, makeVolatile__sempass50_301)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((NI) 0) < (*a).inTryStmt);
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*a).config).exc == ((tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q) 1));
		LA4_: ;
		if (!T3_) goto LA5_;
		(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 9)) & 63);
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, procVarCheck__sempass50_2648)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 56) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 57))) goto LA3_;
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x;
			x = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA8;
						i = i_2;
						x = (*n)._kind_6.sons->data[i];
						procVarCheck__sempass50_2648(x, conf);
						i_2 += ((NI) 1);
					} LA8: ;
				}
			}
		}
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T10_;
		NIM_BOOL T11_;
		NimStringDesc* T16_;
		T10_ = (NIM_BOOL)0;
		T11_ = (NIM_BOOL)0;
		T11_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		if (!(T11_)) goto LA12_;
		T11_ = !(((*(*n)._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 0)));
		LA12_: ;
		T10_ = T11_;
		if (!(T10_)) goto LA13_;
		T10_ = ((520192 &((NU32)1<<((NU)((*(*n)._kind_4.sym).kind)&31U)))!=0);
		LA13_: ;
		if (!T10_) goto LA14_;
		T16_ = NIM_NIL;
		T16_ = nsuFormatSingleElem(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_33), (*(*(*n)._kind_4.sym).name).s);
		liMessage__msgs_1128(conf, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T16_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_34, NIM_FALSE);
	}
	goto LA1_;
	LA14_: ;
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, notNilCheck__sempass50_2668)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* paramType) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n_2;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* paramType_2;
{	n_2 = skipConv__types_3661(n);
	{
		NIM_BOOL T3_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = (paramType == 0);
		if (T3_) goto LA4_;
		T3_ = !(((*paramType).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8)));
		LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = NIM_NIL;
		T7_ = skipConvCastAndClosure__astalgo_114(n_2);
		procVarCheck__sempass50_2648(T7_, (*tracked).config);
	}
	LA5_: ;
	paramType_2 = skipTypesOrNil__ast_4173(paramType, TM__O8rpA4QnF63fyis4dAzZxA_30);
	{
		NIM_BOOL T10_;
		NIM_BOOL T11_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ntyp;
		T10_ = (NIM_BOOL)0;
		T11_ = (NIM_BOOL)0;
		T11_ = !((paramType_2 == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		if (!(T11_)) goto LA12_;
		T11_ = (((*paramType_2).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 17))&63U)))!=0);
		LA12_: ;
		T10_ = T11_;
		if (!(T10_)) goto LA13_;
		T10_ = !(((*n_2).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		LA13_: ;
		if (!T10_) goto LA14_;
		ntyp = skipTypesOrNil__ast_4173((*n_2).typ, TM__O8rpA4QnF63fyis4dAzZxA_35);
		{
			NIM_BOOL T18_;
			tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg T47_;
			T18_ = (NIM_BOOL)0;
			T18_ = !((ntyp == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
			if (!(T18_)) goto LA19_;
			T18_ = !((((*ntyp).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 17))&63U)))!=0));
			LA19_: ;
			if (!T18_) goto LA20_;
			{
				NIM_BOOL T24_;
				T24_ = (NIM_BOOL)0;
				T24_ = isAddrNode__astalgo_4290(n_2);
				if (!T24_) goto LA25_;
				{
					NIM_BOOL T29_;
					T29_ = (NIM_BOOL)0;
					T29_ = containsNode__ast_4546(n_2, TM__O8rpA4QnF63fyis4dAzZxA_36);
					if (!!(T29_)) goto LA30_;
					goto BeforeRet_;
				}
				LA30_: ;
			}
			goto LA22_;
			LA25_: ;
			{
				NIM_BOOL T33_;
				NIM_BOOL T34_;
				NIM_BOOL T35_;
				NIM_BOOL T36_;
				NIM_BOOL T40_;
				NIM_BOOL T41_;
				T33_ = (NIM_BOOL)0;
				T34_ = (NIM_BOOL)0;
				T35_ = (NIM_BOOL)0;
				T36_ = (NIM_BOOL)0;
				T36_ = ((*n_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
				if (!(T36_)) goto LA37_;
				T36_ = ((520192 &((NU32)1<<((NU)((*(*n_2)._kind_4.sym).kind)&31U)))!=0);
				LA37_: ;
				T35_ = T36_;
				if (T35_) goto LA38_;
				T35_ = ((*n_2).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) && (*n_2).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22) || (*n_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 38) || (*n_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41) || (*n_2).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 51) && (*n_2).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 52) || (*n_2).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79) && (*n_2).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 81) || (*n_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84) || (*n_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 155) || (*n_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159));
				LA38_: ;
				T34_ = T35_;
				if (T34_) goto LA39_;
				T40_ = (NIM_BOOL)0;
				T41_ = (NIM_BOOL)0;
				T41_ = ((*n_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29) || (*n_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30) || (*n_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31) || (*n_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) || (*n_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28) || (*n_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32));
				if (!(T41_)) goto LA42_;
				T41_ = ((*(*n_2)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
				LA42_: ;
				T40_ = T41_;
				if (!(T40_)) goto LA43_;
				T40_ = ((*(*(*n_2)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 144));
				LA43_: ;
				T34_ = T40_;
				LA39_: ;
				T33_ = T34_;
				if (T33_) goto LA44_;
				T33_ = ((*(*n_2).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 8));
				LA44_: ;
				if (!T33_) goto LA45_;
				goto BeforeRet_;
			}
			goto LA22_;
			LA45_: ;
			LA22_: ;
			T47_ = (tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg)0;
			T47_ = impliesNotNil__guards_1044((*tracked).guards, n_2);
			switch (T47_) {
			case ((tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg) 0):
			{
				NimStringDesc* T49_;
				NimStringDesc* T50_;
				T49_ = NIM_NIL;
				T49_ = renderTree__renderer_46(n_2, 0);
				T50_ = NIM_NIL;
				T50_ = nsuFormatSingleElem(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_37), T49_);
				liMessage__msgs_1128((*tracked).config, (*n_2).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T50_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_38, NIM_FALSE);
			}
			break;
			case ((tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg) 1):
			{
				NimStringDesc* T52_;
				NimStringDesc* T53_;
				T52_ = NIM_NIL;
				T52_ = renderTree__renderer_46(n_2, 0);
				T53_ = NIM_NIL;
				T53_ = nsuFormatSingleElem(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_39), T52_);
				liMessage__msgs_1128((*tracked).config, (*n_2).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T53_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_40, NIM_FALSE);
			}
			break;
			case ((tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg) 2):
			{
			}
			break;
			}
		}
		LA20_: ;
	}
	LA14_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, trackOperandForIndirectCall__sempass50_2799)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formals, NI argIndex, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* caller) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* op;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* param;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* paramType;
	a = skipConvCastAndClosure__astalgo_114(n);
	op = (*a).typ;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T6_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = !((formals == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		if (!(T4_)) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__ast_3990(formals);
		T4_ = (argIndex < T6_);
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA7_;
		T3_ = !(((*formals).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
		LA7_: ;
		if (!T3_) goto LA8_;
		param = (*(*(*formals).n)._kind_6.sons->data[argIndex])._kind_4.sym;
	}
	goto LA1_;
	LA8_: ;
	{
		param = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
	}
	LA1_: ;
	{
		NIM_BOOL T13_;
		NIM_BOOL T14_;
		NIM_BOOL T15_;
		NIM_BOOL T16_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T19_;
		NIM_BOOL T21_;
		NIM_BOOL T23_;
		NIM_BOOL T24_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* effectList;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* s;
		T13_ = (NIM_BOOL)0;
		T14_ = (NIM_BOOL)0;
		T15_ = (NIM_BOOL)0;
		T16_ = (NIM_BOOL)0;
		T16_ = !((op == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		if (!(T16_)) goto LA17_;
		T16_ = ((*op).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25));
		LA17_: ;
		T15_ = T16_;
		if (!(T15_)) goto LA18_;
		T19_ = NIM_NIL;
		T19_ = skipConv__types_3661(n);
		T15_ = !(((*T19_).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23)));
		LA18_: ;
		T14_ = T15_;
		if (!(T14_)) goto LA20_;
		T21_ = (NIM_BOOL)0;
		T21_ = isTrival__sempass50_2788(caller);
		T14_ = !(T21_);
		LA20_: ;
		T13_ = T14_;
		if (!(T13_)) goto LA22_;
		T23_ = (NIM_BOOL)0;
		T24_ = (NIM_BOOL)0;
		T24_ = !((param == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
		if (!(T24_)) goto LA25_;
		T24_ = (((*param).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 47))&63U)))!=0);
		LA25_: ;
		T23_ = T24_;
		if (T23_) goto LA26_;
		T23_ = !((((*(*tracked).c).features &((NU32)1<<((NU)(((tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw) 16))&31U)))!=0));
		LA26_: ;
		T13_ = T23_;
		LA22_: ;
		if (!T13_) goto LA27_;
		{
			NimStringDesc* argX60gensym217_;
			if (!!(((*(*(*op).n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152)))) goto LA31_;
			argX60gensym217_ = toFileLineCol__msgs_625(TM__O8rpA4QnF63fyis4dAzZxA_29);
			internalErrorImpl__msgs_1441((*tracked).config, unknownLineInfo__lineinfos_284, argX60gensym217_, TM__O8rpA4QnF63fyis4dAzZxA_29);
		}
		LA31_: ;
		effectList = (*(*op).n)._kind_6.sons->data[((NI) 0)];
		s = skipConv__types_3661(n);
		{
			NIM_BOOL T35_;
			T35_ = (NIM_BOOL)0;
			T35_ = ((*s).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 61));
			if (!(T35_)) goto LA36_;
			T35_ = ((*(*(*s)._kind_6.sons->data[((NI) 1)]).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25));
			LA36_: ;
			if (!T35_) goto LA37_;
			s = (*s)._kind_6.sons->data[((NI) 1)];
		}
		LA37_: ;
		{
			NIM_BOOL T41_;
			NIM_BOOL T42_;
			T41_ = (NIM_BOOL)0;
			T42_ = (NIM_BOOL)0;
			T42_ = ((*s).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
			if (!(T42_)) goto LA43_;
			T42_ = ((520192 &((NU32)1<<((NU)((*(*s)._kind_4.sym).kind)&31U)))!=0);
			LA43_: ;
			T41_ = T42_;
			if (!(T41_)) goto LA44_;
			T41_ = isNoEffectList__sempass50_2765(effectList);
			LA44_: ;
			if (!T41_) goto LA45_;
			propagateEffects__sempass50_2619(tracked, n, (*s)._kind_4.sym);
		}
		goto LA39_;
		LA45_: ;
		{
			NIM_BOOL T48_;
			T48_ = (NIM_BOOL)0;
			T48_ = isNoEffectList__sempass50_2765(effectList);
			if (!T48_) goto LA49_;
			{
				NIM_BOOL T53_;
				T53_ = (NIM_BOOL)0;
				T53_ = isForwardedProc__sempass50_2558(n);
				if (!T53_) goto LA54_;
				propagateEffects__sempass50_2619(tracked, n, (*n)._kind_4.sym);
			}
			goto LA51_;
			LA54_: ;
			{
				NIM_BOOL T57_;
				T57_ = (NIM_BOOL)0;
				T57_ = isOwnedProcVar__sempass50_2741(tracked, a);
				if (!!(T57_)) goto LA58_;
				assumeTheWorst__sempass50_2736(tracked, n, op);
			}
			goto LA51_;
			LA58_: ;
			LA51_: ;
			{
				NIM_BOOL T62_;
				NIM_BOOL T64_;
				T62_ = (NIM_BOOL)0;
				T62_ = ((130 & (*op).flags) == 0);
				if (!(T62_)) goto LA63_;
				T64_ = (NIM_BOOL)0;
				T64_ = isOwnedProcVar__sempass50_2741(tracked, a);
				T62_ = !(T64_);
				LA63_: ;
				if (!T62_) goto LA65_;
				{
					NIM_BOOL T69_;
					T69_ = (NIM_BOOL)0;
					T69_ = hasWarn__options_570((*tracked).config, ((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 48));
					if (!T69_) goto LA70_;
					warnAboutGcUnsafe__sempass50_358(n, (*tracked).config);
				}
				LA70_: ;
				markGcUnsafe__sempass50_368(tracked, a);
			}
			goto LA60_;
			LA65_: ;
			{
				NIM_BOOL T73_;
				NIM_BOOL T75_;
				T73_ = (NIM_BOOL)0;
				T73_ = !((((*op).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 1))&63U)))!=0));
				if (!(T73_)) goto LA74_;
				T75_ = (NIM_BOOL)0;
				T75_ = isOwnedProcVar__sempass50_2741(tracked, a);
				T73_ = !(T75_);
				LA74_: ;
				if (!T73_) goto LA76_;
				markSideEffect__sempass50_2886(tracked, a, (*n).info);
			}
			goto LA60_;
			LA76_: ;
			LA60_: ;
		}
		goto LA39_;
		LA49_: ;
		{
			mergeRaises__sempass50_2273(tracked, (*effectList)._kind_6.sons->data[((NI) 0)], n);
			mergeTags__sempass50_2281(tracked, (*effectList)._kind_6.sons->data[((NI) 3)], n);
			{
				if (!((130 & (*op).flags) == 0)) goto LA81_;
				{
					NIM_BOOL T85_;
					T85_ = (NIM_BOOL)0;
					T85_ = hasWarn__options_570((*tracked).config, ((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 48));
					if (!T85_) goto LA86_;
					warnAboutGcUnsafe__sempass50_358(n, (*tracked).config);
				}
				LA86_: ;
				markGcUnsafe__sempass50_368(tracked, a);
			}
			goto LA79_;
			LA81_: ;
			{
				if (!!((((*op).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 1))&63U)))!=0))) goto LA89_;
				markSideEffect__sempass50_2886(tracked, a, (*n).info);
			}
			goto LA79_;
			LA89_: ;
			LA79_: ;
		}
		LA39_: ;
	}
	LA27_: ;
	{
		NIM_BOOL T93_;
		NI T95_;
		T93_ = (NIM_BOOL)0;
		T93_ = !((formals == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		if (!(T93_)) goto LA94_;
		T95_ = (NI)0;
		T95_ = len__ast_3990(formals);
		T93_ = (argIndex < T95_);
		LA94_: ;
		if (!T93_) goto LA96_;
		paramType = (*formals).sons->data[argIndex];
	}
	goto LA91_;
	LA96_: ;
	{
		paramType = ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL);
	}
	LA91_: ;
	{
		NIM_BOOL T101_;
		T101_ = (NIM_BOOL)0;
		T101_ = !((paramType == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		if (!(T101_)) goto LA102_;
		T101_ = ((*paramType).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23));
		LA102_: ;
		if (!T101_) goto LA103_;
		invalidateFacts__guards_760((&(*tracked).guards), n);
		{
			NIM_BOOL T107_;
			T107_ = (NIM_BOOL)0;
			T107_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
			if (!(T107_)) goto LA108_;
			T107_ = isLocalVar__sempass50_162(tracked, (*n)._kind_4.sym);
			LA108_: ;
			if (!T107_) goto LA109_;
			makeVolatile__sempass50_301(tracked, (*n)._kind_4.sym);
		}
		LA109_: ;
	}
	LA103_: ;
	{
		NIM_BOOL T113_;
		NIM_BOOL T114_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* argtype;
		T113_ = (NIM_BOOL)0;
		T114_ = (NIM_BOOL)0;
		T114_ = !((paramType == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		if (!(T114_)) goto LA115_;
		T114_ = ((*paramType).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25));
		LA115_: ;
		T113_ = T114_;
		if (!(T113_)) goto LA116_;
		T113_ = (((*paramType).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 7))&63U)))!=0);
		LA116_: ;
		if (!T113_) goto LA117_;
		argtype = skipTypes__ast_3723((*a).typ, TM__O8rpA4QnF63fyis4dAzZxA_30);
		{
			NIM_BOOL T121_;
			NIM_BOOL T122_;
			NimStringDesc* T127_;
			NimStringDesc* T128_;
			T121_ = (NIM_BOOL)0;
			T122_ = (NIM_BOOL)0;
			T122_ = ((*argtype).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25));
			if (!(T122_)) goto LA123_;
			T122_ = ((130 & (*argtype).flags) == 0);
			LA123_: ;
			T121_ = T122_;
			if (!(T121_)) goto LA124_;
			T121_ = !((*tracked).inEnforcedGcSafe);
			LA124_: ;
			if (!T121_) goto LA125_;
			T127_ = NIM_NIL;
			T128_ = NIM_NIL;
			T128_ = dollar___renderer_2116(n);
			T127_ = rawNewString((T128_ ? T128_->Sup.len : 0) + 15);
appendString(T127_, T128_);
appendString(T127_, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_31));
			liMessage__msgs_1128((*tracked).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T127_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_32, NIM_FALSE);
		}
		LA125_: ;
	}
	LA117_: ;
	notNilCheck__sempass50_2668(tracked, n, paramType);
}
N_LIB_PRIVATE N_NIMCALL(void, initVar__sempass50_312)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL volatileCheck) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
{	{
		if (!!(((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	s = (*n)._kind_4.sym;
	{
		NIM_BOOL T7_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym55_;
		NI T22_;
		T7_ = (NIM_BOOL)0;
		T7_ = isLocalVar__sempass50_162(a, s);
		if (!T7_) goto LA8_;
		{
			if (!volatileCheck) goto LA12_;
			makeVolatile__sempass50_301(a, s);
		}
		LA12_: ;
		{
			NI* x;
			NI i;
			NI L;
			NI T15_;
			x = (NI*)0;
			i = ((NI) 0);
			T15_ = ((*a).init ? (*a).init->Sup.len : 0);
			L = T15_;
			{
				while (1) {
					if (!(i < L)) goto LA17;
					x = (&(*a).init->data[i]);
					{
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym54_;
						xX60gensym54_ = s;
						if (!((*x) == (NI)((NI)((NU64)(((NI) ((*xX60gensym54_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym54_).Sup.itemId.item))))) goto LA20_;
						goto BeforeRet_;
					}
					LA20_: ;
					i += ((NI) 1);
				} LA17: ;
			}
		}
		xX60gensym55_ = s;
		unsureAsgnRef((void**) (&(*a).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)((*a).init), (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_)));
		T22_ = (*a).init->Sup.len++;
		(*a).init->data[T22_] = (NI)((NI)((NU64)(((NI) ((*xX60gensym55_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym55_).Sup.itemId.item)));
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, initVarViaNew__sempass50_341)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
{	{
		if (!!(((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	s = (*n)._kind_4.sym;
	{
		if (!(((393216 & (*(*s).typ).flags) & ~ 131072)==0)) goto LA7_;
		initVar__sempass50_312(a, n, NIM_TRUE);
	}
	goto LA5_;
	LA7_: ;
	{
		NIM_BOOL T10_;
		T10_ = (NIM_BOOL)0;
		T10_ = isLocalVar__sempass50_162(a, s);
		if (!T10_) goto LA11_;
		makeVolatile__sempass50_301(a, s);
	}
	goto LA5_;
	LA11_: ;
	LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, checkLe__sempass50_3351)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b) {
	tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg T1_;
	T1_ = (tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg)0;
	T1_ = proveLe__guards_1628((*c).guards, a, b);
	switch (T1_) {
	case ((tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg) 0):
	{
		NimStringDesc* T3_;
		NimStringDesc* T4_;
		NimStringDesc* T5_;
		T3_ = NIM_NIL;
		T4_ = NIM_NIL;
		T4_ = dollar___renderer_2116(a);
		T5_ = NIM_NIL;
		T5_ = dollar___renderer_2116(b);
		T3_ = rawNewString((T4_ ? T4_->Sup.len : 0) + (T5_ ? T5_->Sup.len : 0) + 18);
appendString(T3_, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_42));
appendString(T3_, T4_);
appendString(T3_, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_43));
appendString(T3_, T5_);
		liMessage__msgs_1128((*c).config, (*a).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 47), T3_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_44, NIM_FALSE);
	}
	break;
	case ((tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg) 2):
	{
	}
	break;
	case ((tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg) 1):
	{
		NimStringDesc* T8_;
		NimStringDesc* T9_;
		NimStringDesc* T10_;
		T8_ = NIM_NIL;
		T9_ = NIM_NIL;
		T9_ = dollar___renderer_2116(a);
		T10_ = NIM_NIL;
		T10_ = dollar___renderer_2116(b);
		T8_ = rawNewString((T9_ ? T9_->Sup.len : 0) + (T10_ ? T10_->Sup.len : 0) + 14);
appendString(T8_, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_45));
appendString(T8_, T9_);
appendString(T8_, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_46));
appendString(T8_, T10_);
		liMessage__msgs_1128((*c).config, (*a).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 47), T8_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_47, NIM_FALSE);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, checkBounds__sempass50_3355)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arr, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* idx) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T1_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T2_;
	T1_ = NIM_NIL;
	T1_ = lowBound__guards_261((*c).config, arr);
	checkLe__sempass50_3351(c, T1_, idx);
	T2_ = NIM_NIL;
	T2_ = highBound__guards_265((*c).config, arr, (&(*(*c).guards.g).operators));
	checkLe__sempass50_3351(c, idx, T2_);
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, find__sempass50_3628)(tyArray__EeEKCO7QpNg9c8wnv9c1UhNQ a, NimStringDesc* item) {
	NI result;
{	result = (NI)0;
	result = ((NI) 0);
	{
		NimStringDesc* i;
		tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ i_2;
		i = NIM_NIL;
		i_2 = ((tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ) 0);
		{
			while (1) {
				i = a[(i_2)- 0];
				{
					if (!eqStrings(i, item)) goto LA6_;
					goto BeforeRet_;
				}
				LA6_: ;
				result += ((NI) 1);
				{
					if (!(((tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ) 4) <= i_2)) goto LA10_;
					goto LA2;
				}
				LA10_: ;
				i_2 += ((NI) 1);
			}
		} LA2: ;
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg, nextTypeId__ast_3122)(tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* x) {
	tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	(*x).typeId_0 += ((NI) 1);
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg));
	result.module = (*x).module;
	result.item = (*x).typeId_0;
	return result;
}
static N_INLINE(NIM_BOOL, isEmptyType__ast_4780)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (t == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL));
	if (T1_) goto LA2_;
	T1_ = ((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 63) || (*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 7));
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkForSink__sempass50_24)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg) {
{	{
		if (!!((((*config).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 25))&31U)))!=0))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	switch ((*arg).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		{
			NIM_BOOL T8_;
			NIM_BOOL T9_;
			NIM_BOOL T10_;
			NIM_BOOL T11_;
			NIM_BOOL T12_;
			T8_ = (NIM_BOOL)0;
			T9_ = (NIM_BOOL)0;
			T10_ = (NIM_BOOL)0;
			T11_ = (NIM_BOOL)0;
			T12_ = (NIM_BOOL)0;
			T12_ = ((*(*arg)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			if (!(T12_)) goto LA13_;
			T12_ = ((*(*arg)._kind_4.sym).owner == owner);
			LA13_: ;
			T11_ = T12_;
			if (!(T11_)) goto LA14_;
			T11_ = !(((*owner).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
			LA14_: ;
			T10_ = T11_;
			if (!(T10_)) goto LA15_;
			T10_ = ((*(*owner).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25));
			LA15_: ;
			T9_ = T10_;
			if (!(T9_)) goto LA16_;
			T9_ = !(((IL64(2147483664) & (*(*(*arg)._kind_4.sym).typ).flags) == 0));
			LA16_: ;
			T8_ = T9_;
			if (!(T8_)) goto LA17_;
			T8_ = !(((*(*(*arg)._kind_4.sym).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23) || (*(*(*arg)._kind_4.sym).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46) || (*(*(*arg)._kind_4.sym).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45)));
			LA17_: ;
			if (!T8_) goto LA18_;
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* argType;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* sinkType;
				tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg T24_;
				if (!!((((*owner).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 5))&63U)))!=0))) goto LA22_;
				argType = (*(*arg)._kind_4.sym).typ;
				T24_ = nextTypeId__ast_3122(idgen);
				sinkType = newType__ast_3884(((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46), T24_, owner);
				(*sinkType).size = (*argType).size;
				(*sinkType).align = (*argType).align;
				(*sinkType).paddingAtEnd = (*argType).paddingAtEnd;
				add__concepts_23(sinkType, argType);
				asgnRef((void**) (&(*(*arg)._kind_4.sym).typ), sinkType);
				asgnRef((void**) (&(*(*owner).typ).sons->data[(NI)((*(*arg)._kind_4.sym).position + ((NI) 1))]), sinkType);
			}
			goto LA20_;
			LA22_: ;
			{
				tyArray__nHXaesL0DJZHyVS07ARPRA T28_;
				NimStringDesc* T29_;
				if (!!((((*(*arg)._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 5))&63U)))!=0))) goto LA26_;
				(*(*arg)._kind_4.sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 5)) & 63);
				nimZeroMem((void*)T28_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
				T28_[0] = copyString((*(*(*arg)._kind_4.sym).name).s);
				T29_ = NIM_NIL;
				T29_ = nsuFormatOpenArray(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_50), T28_, 1);
				liMessage__msgs_1128(config, (*arg).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 97), T29_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_51, NIM_FALSE);
			}
			goto LA20_;
			LA26_: ;
			LA20_: ;
		}
		LA18_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 112):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 127):
	{
		{
			NIM_BOOL T33_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T36_;
			T33_ = (NIM_BOOL)0;
			T33_ = isEmptyType__ast_4780((*arg).typ);
			if (!!(T33_)) goto LA34_;
			T36_ = NIM_NIL;
			T36_ = lastSon__ast_4833(arg);
			checkForSink__sempass50_24(config, idgen, owner, T36_);
		}
		LA34_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 92):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 48):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 93):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* branch;
			branch = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(arg);
				i_2 = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* value;
						if (!(i_2 < colontmp_)) goto LA41;
						i = i_2;
						branch = (*arg)._kind_6.sons->data[i];
						value = lastSon__ast_4833(branch);
						{
							NIM_BOOL T44_;
							T44_ = (NIM_BOOL)0;
							T44_ = isEmptyType__ast_4780((*value).typ);
							if (!!(T44_)) goto LA45_;
							checkForSink__sempass50_24(config, idgen, owner, value);
						}
						LA45_: ;
						i_2 += ((NI) 1);
					} LA41: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 97):
	{
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3155(arg);
			i_4 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* value_2;
					if (!(i_4 < colontmp__2)) goto LA50;
					i_3 = i_4;
					value_2 = lastSon__ast_4833((*arg)._kind_6.sons->data[i_3]);
					{
						NIM_BOOL T53_;
						T53_ = (NIM_BOOL)0;
						T53_ = isEmptyType__ast_4780((*value_2).typ);
						if (!!(T53_)) goto LA54_;
						checkForSink__sempass50_24(config, idgen, owner, value_2);
					}
					LA54_: ;
					i_4 += ((NI) 1);
				} LA50: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 106):
	{
		checkForSink__sempass50_24(config, idgen, owner, (*arg)._kind_6.sons->data[((NI) 0)]);
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, trackCall__sempass50_3376)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* op;
	a = (*n)._kind_6.sons->data[((NI) 0)];
	op = (*a).typ;
	{
		if (!!(((*n).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA3_;
		{
			NIM_BOOL T7_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T9_;
			T7_ = (NIM_BOOL)0;
			T7_ = !(((*(*tracked).owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 17)));
			if (!(T7_)) goto LA8_;
			T9_ = NIM_NIL;
			T9_ = skipTypes__ast_3723((*n).typ, TM__O8rpA4QnF63fyis4dAzZxA_23);
			T7_ = !(((*T9_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27)));
			LA8_: ;
			if (!T7_) goto LA10_;
			createTypeBoundOps__sempass50_142(tracked, (*n).typ, (*n).info);
		}
		LA10_: ;
	}
	LA3_: ;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T14_;
		T14_ = NIM_NIL;
		T14_ = getConstExpr__semfold_81((*tracked).ownerModule, n, (*(*tracked).c).Sup.idgen, (*tracked).graph);
		if (!(T14_ == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA15_;
		{
			NIM_BOOL T19_;
			T19_ = (NIM_BOOL)0;
			T19_ = ((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 61));
			if (!(T19_)) goto LA20_;
			T19_ = ((*(*(*a)._kind_6.sons->data[((NI) 1)]).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25));
			LA20_: ;
			if (!T19_) goto LA21_;
			a = (*a)._kind_6.sons->data[((NI) 1)];
		}
		LA21_: ;
		{
			NIM_BOOL T25_;
			NIM_BOOL T26_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* effectList;
			T25_ = (NIM_BOOL)0;
			T26_ = (NIM_BOOL)0;
			T26_ = !((op == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
			if (!(T26_)) goto LA27_;
			T26_ = ((*op).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25));
			LA27_: ;
			T25_ = T26_;
			if (!(T25_)) goto LA28_;
			T25_ = ((*(*(*op).n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152));
			LA28_: ;
			if (!T25_) goto LA29_;
			{
				NI16 T39_;
				if (!((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA33_;
				{
					if (!((*a)._kind_4.sym == (*tracked).owner)) goto LA37_;
					(*tracked).isRecursive = NIM_TRUE;
				}
				LA37_: ;
				T39_ = (NI16)0;
				T39_ = getLockLevel__sempass50_2600((*a)._kind_4.sym);
				mergeLockLevels__sempass50_2615(tracked, n, T39_);
				{
					if (!(((*(*a)._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 13))&63U)))!=0)) goto LA42_;
					markSideEffect__sempass50_2886(tracked, a, (*n).info);
				}
				LA42_: ;
			}
			goto LA31_;
			LA33_: ;
			{
				mergeLockLevels__sempass50_2615(tracked, n, (*op).lockLevel);
			}
			LA31_: ;
			effectList = (*(*op).n)._kind_6.sons->data[((NI) 0)];
			{
				NIM_BOOL T47_;
				T47_ = (NIM_BOOL)0;
				T47_ = ((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
				if (!(T47_)) goto LA48_;
				T47_ = ((*(*a)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 14));
				LA48_: ;
				if (!T47_) goto LA49_;
				propagateEffects__sempass50_2619(tracked, n, (*a)._kind_4.sym);
			}
			goto LA45_;
			LA49_: ;
			{
				NIM_BOOL T52_;
				T52_ = (NIM_BOOL)0;
				T52_ = isNoEffectList__sempass50_2765(effectList);
				if (!T52_) goto LA53_;
				{
					NIM_BOOL T57_;
					T57_ = (NIM_BOOL)0;
					T57_ = isForwardedProc__sempass50_2558(a);
					if (!T57_) goto LA58_;
					propagateEffects__sempass50_2619(tracked, n, (*a)._kind_4.sym);
				}
				goto LA55_;
				LA58_: ;
				{
					NIM_BOOL T61_;
					T61_ = (NIM_BOOL)0;
					T61_ = isIndirectCall__sempass50_2522(tracked, a);
					if (!T61_) goto LA62_;
					assumeTheWorst__sempass50_2736(tracked, n, op);
					{
						NIM_BOOL T66_;
						NIM_BOOL T68_;
						T66_ = (NIM_BOOL)0;
						T66_ = ((130 & (*op).flags) == 0);
						if (!(T66_)) goto LA67_;
						T68_ = (NIM_BOOL)0;
						T68_ = importedFromC__sempass50_2589(a);
						T66_ = !(T68_);
						LA67_: ;
						if (!T66_) goto LA69_;
						{
							NIM_BOOL T73_;
							T73_ = (NIM_BOOL)0;
							T73_ = ((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
							if (!(T73_)) goto LA74_;
							T73_ = ((*a)._kind_4.sym == (*tracked).owner);
							LA74_: ;
							if (!!(T73_)) goto LA75_;
							{
								NIM_BOOL T79_;
								T79_ = (NIM_BOOL)0;
								T79_ = hasWarn__options_570((*tracked).config, ((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 48));
								if (!T79_) goto LA80_;
								warnAboutGcUnsafe__sempass50_358(n, (*tracked).config);
							}
							LA80_: ;
							markGcUnsafe__sempass50_368(tracked, a);
						}
						LA75_: ;
					}
					LA69_: ;
					{
						NIM_BOOL T84_;
						NIM_BOOL T86_;
						T84_ = (NIM_BOOL)0;
						T84_ = !((((*op).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 1))&63U)))!=0));
						if (!(T84_)) goto LA85_;
						T86_ = (NIM_BOOL)0;
						T86_ = importedFromC__sempass50_2589(a);
						T84_ = !(T86_);
						LA85_: ;
						if (!T84_) goto LA87_;
						{
							NIM_BOOL T91_;
							T91_ = (NIM_BOOL)0;
							T91_ = ((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
							if (!(T91_)) goto LA92_;
							T91_ = ((*a)._kind_4.sym == (*tracked).owner);
							LA92_: ;
							if (!!(T91_)) goto LA93_;
							markSideEffect__sempass50_2886(tracked, a, (*n).info);
						}
						LA93_: ;
					}
					LA87_: ;
				}
				goto LA55_;
				LA62_: ;
				{
					{
						NIM_BOOL T98_;
						NIM_BOOL T99_;
						T98_ = (NIM_BOOL)0;
						T99_ = (NIM_BOOL)0;
						T99_ = (((*(*tracked).c).features &((NU32)1<<((NU)(((tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw) 16))&31U)))!=0);
						if (!(T99_)) goto LA100_;
						T99_ = ((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
						LA100_: ;
						T98_ = T99_;
						if (!(T98_)) goto LA101_;
						T98_ = ((520192 &((NU32)1<<((NU)((*(*a)._kind_4.sym).kind)&31U)))!=0);
						LA101_: ;
						if (!T98_) goto LA102_;
						propagateEffects__sempass50_2619(tracked, n, (*a)._kind_4.sym);
					}
					LA102_: ;
				}
				LA55_: ;
			}
			goto LA45_;
			LA53_: ;
			{
				mergeRaises__sempass50_2273(tracked, (*effectList)._kind_6.sons->data[((NI) 0)], n);
				mergeTags__sempass50_2281(tracked, (*effectList)._kind_6.sons->data[((NI) 3)], n);
				{
					NIM_BOOL T107_;
					NIM_BOOL T109_;
					T107_ = (NIM_BOOL)0;
					T107_ = ((130 & (*op).flags) == 0);
					if (!(T107_)) goto LA108_;
					T109_ = (NIM_BOOL)0;
					T109_ = importedFromC__sempass50_2589(a);
					T107_ = !(T109_);
					LA108_: ;
					if (!T107_) goto LA110_;
					{
						NIM_BOOL T114_;
						T114_ = (NIM_BOOL)0;
						T114_ = ((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
						if (!(T114_)) goto LA115_;
						T114_ = ((*a)._kind_4.sym == (*tracked).owner);
						LA115_: ;
						if (!!(T114_)) goto LA116_;
						{
							NIM_BOOL T120_;
							T120_ = (NIM_BOOL)0;
							T120_ = hasWarn__options_570((*tracked).config, ((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 48));
							if (!T120_) goto LA121_;
							warnAboutGcUnsafe__sempass50_358(n, (*tracked).config);
						}
						LA121_: ;
						markGcUnsafe__sempass50_368(tracked, a);
					}
					LA116_: ;
				}
				LA110_: ;
				{
					NIM_BOOL T125_;
					NIM_BOOL T127_;
					T125_ = (NIM_BOOL)0;
					T125_ = !((((*op).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 1))&63U)))!=0));
					if (!(T125_)) goto LA126_;
					T127_ = (NIM_BOOL)0;
					T127_ = importedFromC__sempass50_2589(a);
					T125_ = !(T127_);
					LA126_: ;
					if (!T125_) goto LA128_;
					{
						NIM_BOOL T132_;
						T132_ = (NIM_BOOL)0;
						T132_ = ((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
						if (!(T132_)) goto LA133_;
						T132_ = ((*a)._kind_4.sym == (*tracked).owner);
						LA133_: ;
						if (!!(T132_)) goto LA134_;
						markSideEffect__sempass50_2886(tracked, a, (*n).info);
					}
					LA134_: ;
				}
				LA128_: ;
			}
			LA45_: ;
		}
		LA29_: ;
		{
			NIM_BOOL T138_;
			T138_ = (NIM_BOOL)0;
			T138_ = !(((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)));
			if (T138_) goto LA139_;
			T138_ = !(((*(*a)._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 251) || (*(*a)._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 155) || (*(*a)._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 27) || (*(*a)._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 28)));
			LA139_: ;
			if (!T138_) goto LA140_;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_3155(n);
				i_2 = ((NI) 1);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA144;
						i = i_2;
						trackOperandForIndirectCall__sempass50_2799(tracked, (*n)._kind_6.sons->data[i], op, i, a);
						i_2 += ((NI) 1);
					} LA144: ;
				}
			}
		}
		LA140_: ;
		{
			NIM_BOOL T147_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* arg;
			T147_ = (NIM_BOOL)0;
			T147_ = ((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
			if (!(T147_)) goto LA148_;
			T147_ = ((*(*a)._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 32) || (*(*a)._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 33) || (*(*a)._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 34));
			LA148_: ;
			if (!T147_) goto LA149_;
			arg = (*n)._kind_6.sons->data[((NI) 1)];
			initVarViaNew__sempass50_341(tracked, arg);
			{
				NIM_BOOL T153_;
				NI T154_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T156_;
				T153_ = (NIM_BOOL)0;
				T154_ = (NI)0;
				T154_ = len__ast_3990((*arg).typ);
				T153_ = !((T154_ == ((NI) 0)));
				if (!(T153_)) goto LA155_;
				T156_ = NIM_NIL;
				T156_ = lastSon__ast_3731((*arg).typ);
				T153_ = !(((262144 & (*T156_).flags) == 0));
				LA155_: ;
				if (!T153_) goto LA157_;
				{
					NIM_BOOL T161_;
					NIM_BOOL T162_;
					T161_ = (NIM_BOOL)0;
					T162_ = (NIM_BOOL)0;
					T162_ = ((*(*a)._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 34));
					if (!(T162_)) goto LA163_;
					T162_ = ((*(*n)._kind_6.sons->data[((NI) 2)]).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) && (*(*n)._kind_6.sons->data[((NI) 2)]).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 15));
					LA163_: ;
					T161_ = T162_;
					if (!(T161_)) goto LA164_;
					T161_ = ((*(*n)._kind_6.sons->data[((NI) 2)])._kind_1.intVal == IL64(0));
					LA164_: ;
					if (!T161_) goto LA165_;
				}
				goto LA159_;
				LA165_: ;
				{
					NimStringDesc* T168_;
					T168_ = NIM_NIL;
					T168_ = dollar___renderer_2116(arg);
					liMessage__msgs_1128((*tracked).config, (*arg).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 42), T168_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_41, NIM_FALSE);
				}
				LA159_: ;
			}
			LA157_: ;
			{
				NI T171_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T174_;
				T171_ = (NI)0;
				T171_ = len__ast_3990((*(*n)._kind_6.sons->data[((NI) 1)]).typ);
				if (!(((NI) 0) < T171_)) goto LA172_;
				T174_ = NIM_NIL;
				T174_ = lastSon__ast_3731((*(*n)._kind_6.sons->data[((NI) 1)]).typ);
				createTypeBoundOps__sempass50_142(tracked, T174_, (*n).info);
				createTypeBoundOps__sempass50_142(tracked, (*(*n)._kind_6.sons->data[((NI) 1)]).typ, (*n).info);
			}
			LA172_: ;
		}
		goto LA145_;
		LA149_: ;
		{
			NIM_BOOL T176_;
			NIM_BOOL T177_;
			T176_ = (NIM_BOOL)0;
			T177_ = (NIM_BOOL)0;
			T177_ = ((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
			if (!(T177_)) goto LA178_;
			T177_ = ((*(*a)._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 5) || (*(*a)._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 6));
			LA178_: ;
			T176_ = T177_;
			if (!(T176_)) goto LA179_;
			T176_ = (((*tracked).currOptions &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 9))&31U)))!=0);
			LA179_: ;
			if (!T176_) goto LA180_;
			checkBounds__sempass50_3355(tracked, (*n)._kind_6.sons->data[((NI) 1)], (*n)._kind_6.sons->data[((NI) 2)]);
		}
		goto LA145_;
		LA180_: ;
		LA145_: ;
		{
			NIM_BOOL T184_;
			T184_ = (NIM_BOOL)0;
			T184_ = !(((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)));
			if (T184_) goto LA185_;
			T184_ = !(((*(*a)._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 268) || (*(*a)._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 251) || (*(*a)._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 27) || (*(*a)._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 28)));
			LA185_: ;
			if (!T184_) goto LA186_;
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = safeLen__ast_3148(n);
				i_4 = ((NI) 0);
				{
					while (1) {
						if (!(i_4 < colontmp__2)) goto LA190;
						i_3 = i_4;
						track__sempass50_2338(tracked, (*n)._kind_6.sons->data[i_3]);
						i_4 += ((NI) 1);
					} LA190: ;
				}
			}
		}
		LA186_: ;
	}
	LA15_: ;
	{
		NIM_BOOL T193_;
		NIM_BOOL T194_;
		NIM_BOOL T195_;
		NI opKind;
		NimStringDesc* T201_;
		T193_ = (NIM_BOOL)0;
		T194_ = (NIM_BOOL)0;
		T195_ = (NIM_BOOL)0;
		T195_ = ((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		if (!(T195_)) goto LA196_;
		T195_ = (((NI) 0) < ((*(*(*a)._kind_4.sym).name).s ? (*(*(*a)._kind_4.sym).name).s->Sup.len : 0));
		LA196_: ;
		T194_ = T195_;
		if (!(T194_)) goto LA197_;
		T194_ = ((NU8)((*(*(*a)._kind_4.sym).name).s->data[((NI) 0)]) == (NU8)(61));
		LA197_: ;
		T193_ = T194_;
		if (!(T193_)) goto LA198_;
		T193_ = !(((*(*tracked).owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 17)));
		LA198_: ;
		if (!T193_) goto LA199_;
		T201_ = NIM_NIL;
		T201_ = nsuNormalize((*(*(*a)._kind_4.sym).name).s);
		opKind = find__sempass50_3628(AttachedOpToStr__ast_3836, T201_);
		{
			if (!eqStrings((*(*(*a)._kind_4.sym).name).s, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_48))) goto LA204_;
			opKind = ((NI) 1);
		}
		LA204_: ;
		{
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
			if (!!((opKind == ((NI) -1)))) goto LA208_;
			t = skipTypes__ast_3723((*(*n)._kind_6.sons->data[((NI) 1)]).typ, TM__O8rpA4QnF63fyis4dAzZxA_49);
			{
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T212_;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* op_2;
				T212_ = NIM_NIL;
				T212_ = getAttachedOp__modulegraphs_4049((*tracked).graph, t, ((tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ) (opKind)));
				if (!!(((*a)._kind_4.sym == T212_))) goto LA213_;
				createTypeBoundOps__sempass50_142(tracked, t, (*n).info);
				op_2 = getAttachedOp__modulegraphs_4049((*tracked).graph, t, ((tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ) (opKind)));
				{
					if (!!((op_2 == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA217_;
					asgnRef((void**) (&(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym), op_2);
				}
				LA217_: ;
			}
			LA213_: ;
		}
		LA208_: ;
	}
	LA199_: ;
	{
		NIM_BOOL T221_;
		T221_ = (NIM_BOOL)0;
		T221_ = !((op == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		if (!(T221_)) goto LA222_;
		T221_ = ((*op).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25));
		LA222_: ;
		if (!T221_) goto LA223_;
		{
			NI i_5;
			NI colontmp__3;
			NI T226_;
			NI T227_;
			NI i_6;
			i_5 = (NI)0;
			colontmp__3 = (NI)0;
			T226_ = (NI)0;
			T226_ = safeLen__ast_3148(n);
			T227_ = (NI)0;
			T227_ = len__ast_3990(op);
			colontmp__3 = ((T226_ <= T227_) ? T226_ : T227_);
			i_6 = ((NI) 1);
			{
				while (1) {
					if (!(i_6 < colontmp__3)) goto LA229;
					i_5 = i_6;
					switch ((*(*op).sons->data[i_5]).kind) {
					case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46):
					{
						createTypeBoundOps__sempass50_142(tracked, (*(*op).sons->data[i_5]).sons->data[((NI) 0)], (*n).info);
						checkForSink__sempass50_24((*tracked).config, (*(*tracked).c).Sup.idgen, (*tracked).owner, (*n)._kind_6.sons->data[i_5]);
					}
					break;
					case ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23):
					{
						(*tracked).hasDangerousAssign = NIM_TRUE;
					}
					break;
					default:
					{
					}
					break;
					}
					i_6 += ((NI) 1);
				} LA229: ;
			}
		}
	}
	LA223_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, guardDotAccess__sempass50_237)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ri;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* g;
{	ri = (*n)._kind_6.sons->data[((NI) 1)];
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*ri).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)));
		if (T3_) goto LA4_;
		T3_ = !(((*(*ri)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19)));
		LA4_: ;
		if (!T3_) goto LA5_;
		goto BeforeRet_;
	}
	LA5_: ;
	g = (*(*ri)._kind_4.sym)._kind_2.guard;
	{
		NIM_BOOL T9_;
		T9_ = (NIM_BOOL)0;
		T9_ = (g == 0);
		if (T9_) goto LA10_;
		T9_ = (*a).isTopLevel;
		LA10_: ;
		if (!T9_) goto LA11_;
		goto BeforeRet_;
	}
	LA11_: ;
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* ty;
		if (!((*g).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 0))) goto LA15_;
		field = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
		ty = skipTypes__ast_3723((*(*n)._kind_6.sons->data[((NI) 0)]).typ, TM__O8rpA4QnF63fyis4dAzZxA_53);
		{
			NIM_BOOL T19_;
			T19_ = (NIM_BOOL)0;
			T19_ = ((*ty).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18));
			if (!(T19_)) goto LA20_;
			T19_ = !(((*ty).n == 0));
			LA20_: ;
			if (!T19_) goto LA21_;
			field = lookupInRecord__astalgo_84((*ty).n, (*g).name);
		}
		goto LA17_;
		LA21_: ;
		{
			{
				while (1) {
					NIM_BOOL T26_;
					T26_ = (NIM_BOOL)0;
					T26_ = !((ty == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
					if (!(T26_)) goto LA27_;
					T26_ = ((*ty).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 17));
					LA27_: ;
					if (!T26_) goto LA25;
					field = lookupInRecord__astalgo_84((*ty).n, (*g).name);
					{
						if (!!((field == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA30_;
						goto LA24;
					}
					LA30_: ;
					ty = (*ty).sons->data[((NI) 0)];
					{
						if (!(ty == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA34_;
						goto LA24;
					}
					LA34_: ;
					ty = skipTypes__ast_3723(ty, TM__O8rpA4QnF63fyis4dAzZxA_9);
				} LA25: ;
			} LA24: ;
		}
		LA17_: ;
		{
			NimStringDesc* T40_;
			if (!(field == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA38_;
			T40_ = NIM_NIL;
			T40_ = rawNewString(((*(*g).name).s ? (*(*g).name).s->Sup.len : 0) + 21);
appendString(T40_, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_54));
appendString(T40_, (*(*g).name).s);
			liMessage__msgs_1128((*a).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T40_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_55, NIM_FALSE);
			goto BeforeRet_;
		}
		LA38_: ;
		g = field;
	}
	LA15_: ;
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* dot;
		NimStringDesc* T54_;
		NimStringDesc* T55_;
		if (!((*g).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 19))) goto LA43_;
		dot = newNodeI__ast_3324(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45), (*n).info, ((NI) 2));
		asgnRef((void**) (&(*dot)._kind_6.sons->data[((NI) 0)]), (*n)._kind_6.sons->data[((NI) 0)]);
		asgnRef((void**) (&(*dot)._kind_6.sons->data[((NI) 1)]), newSymNode__ast_3704(g));
		asgnRef((void**) (&(*dot).typ), (*g).typ);
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** L;
			NI i;
			NI L_2;
			NI T46_;
			L = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
			i = ((NI) 0);
			T46_ = ((*a).locked ? (*a).locked->Sup.len : 0);
			L_2 = T46_;
			{
				while (1) {
					if (!(i < L_2)) goto LA48;
					L = &(*a).locked->data[i];
					{
						NIM_BOOL T51_;
						T51_ = (NIM_BOOL)0;
						T51_ = sameTree__guards_680(dot, (*L));
						if (!T51_) goto LA52_;
						goto BeforeRet_;
					}
					LA52_: ;
					i += ((NI) 1);
				} LA48: ;
			}
		}
		T54_ = NIM_NIL;
		T55_ = NIM_NIL;
		T55_ = renderTree__renderer_46(n, 0);
		T54_ = rawNewString((T55_ ? T55_->Sup.len : 0) + 18);
appendString(T54_, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_21));
appendString(T54_, T55_);
		liMessage__msgs_1128((*a).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T54_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_56, NIM_FALSE);
	}
	goto LA41_;
	LA43_: ;
	{
		guardGlobal__sempass50_221(a, n, g);
	}
	LA41_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addToIntersection__sempass50_2160)(tySequence__8Np6tlClE5az1CyqZdN19bQ** inter, NI s) {
	tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ T9_;
	NI T10_;
{	{
		NI j;
		NI colontmp_;
		NI T2_;
		NI i;
		j = (NI)0;
		colontmp_ = (NI)0;
		T2_ = ((*inter) ? (*inter)->Sup.len : 0);
		colontmp_ = T2_;
		i = ((NI) 0);
		{
			while (1) {
				if (!(i < colontmp_)) goto LA4;
				j = i;
				{
					if (!(s == (*inter)->data[j].Field0)) goto LA7_;
					(*inter)->data[j].Field1 += ((NI) 1);
					goto BeforeRet_;
				}
				LA7_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
	T9_.Field0 = s;
	T9_.Field1 = ((NI) 1);
	unsureAsgnRef((void**) (&(*inter)), (tySequence__8Np6tlClE5az1CyqZdN19bQ*) incrSeqV3((TGenericSeq*)((*inter)), (&NTIseqLtupleLa58int_b58intTT__8Np6tlClE5az1CyqZdN19bQ_)));
	T10_ = (*inter)->Sup.len++;
	(*inter)->data[T10_] = T9_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, catchesAll__sempass50_2326)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked) {
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__ast_3155((*tracked).exc);
		if (!(((NI) 0) < T3_)) goto LA4_;
		asgnRef((void**) (&(*(*tracked).exc)._kind_6.sons), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) setLengthSeqV2(((*(*tracked).exc)._kind_6.sons)?&((*(*tracked).exc)._kind_6.sons)->Sup:NIM_NIL, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) ((*tracked).bottom))));
	}
	LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, catches__sempass50_2293)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* e) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* e_2;
	NI L;
	NI i;
	e_2 = skipTypes__ast_3723(e, TM__O8rpA4QnF63fyis4dAzZxA_9);
	L = len__ast_3155((*tracked).exc);
	i = (*tracked).bottom;
	{
		while (1) {
			if (!(i < L)) goto LA2;
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T5_;
				NI T6_;
				T5_ = NIM_NIL;
				T5_ = excType__sempass50_2211((*tracked).graph, (*(*tracked).exc)._kind_6.sons->data[i]);
				T6_ = (NI)0;
				T6_ = safeInheritanceDiff__types_3444(T5_, e_2);
				if (!(T6_ <= ((NI) 0))) goto LA7_;
				asgnRef((void**) (&(*(*tracked).exc)._kind_6.sons->data[i]), (*(*tracked).exc)._kind_6.sons->data[(NI)(L - ((NI) 1))]);
				L -= ((NI) 1);
			}
			goto LA3_;
			LA7_: ;
			{
				i += ((NI) 1);
			}
			LA3_: ;
		} LA2: ;
	}
	{
		NI T12_;
		T12_ = (NI)0;
		T12_ = len__ast_3155((*tracked).exc);
		if (!(((NI) 0) < T12_)) goto LA13_;
		asgnRef((void**) (&(*(*tracked).exc)._kind_6.sons), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) setLengthSeqV2(((*(*tracked).exc)._kind_6.sons)?&((*(*tracked).exc)._kind_6.sons)->Sup:NIM_NIL, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) (L))));
	}
	goto LA10_;
	LA13_: ;
	{
	}
	LA10_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, trackTryStmt__sempass50_2341)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI oldBottom;
	NI oldState;
	NI T1_;
	tySequence__8Np6tlClE5az1CyqZdN19bQ* inter;
	NI branches;
	NIM_BOOL hasFinally;
	oldBottom = (*tracked).bottom;
	(*tracked).bottom = len__ast_3155((*tracked).exc);
	T1_ = ((*tracked).init ? (*tracked).init->Sup.len : 0);
	oldState = T1_;
	inter = NIM_NIL;
	(*tracked).inTryStmt += ((NI) 1);
	track__sempass50_2338(tracked, (*n)._kind_6.sons->data[((NI) 0)]);
	(*tracked).inTryStmt -= ((NI) 1);
	{
		NI i;
		NI colontmp_;
		NI T3_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T3_ = ((*tracked).init ? (*tracked).init->Sup.len : 0);
		colontmp_ = T3_;
		i_2 = oldState;
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA5;
				i = i_2;
				addToIntersection__sempass50_2160((&inter), (*tracked).init->data[i]);
				i_2 += ((NI) 1);
			} LA5: ;
		}
	}
	branches = ((NI) 1);
	hasFinally = NIM_FALSE;
	(*tracked).inExceptOrFinallyStmt += ((NI) 1);
	{
		NI i_3;
		NI colontmp__2;
		NI i_4;
		i_3 = (NI)0;
		colontmp__2 = (NI)0;
		colontmp__2 = len__ast_3155(n);
		i_4 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b;
				if (!(i_4 < colontmp__2)) goto LA8;
				i_3 = i_4;
				b = (*n)._kind_6.sons->data[i_3];
				{
					if (!((*b).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 87))) goto LA11_;
					branches += ((NI) 1);
					{
						NI T15_;
						T15_ = (NI)0;
						T15_ = len__ast_3155(b);
						if (!(T15_ == ((NI) 1))) goto LA16_;
						catchesAll__sempass50_2326(tracked);
					}
					goto LA13_;
					LA16_: ;
					{
						{
							NI j;
							NI colontmp__3;
							NI T20_;
							NI i_5;
							j = (NI)0;
							colontmp__3 = (NI)0;
							T20_ = (NI)0;
							T20_ = len__ast_3155(b);
							colontmp__3 = (NI)(T20_ - ((NI) 1));
							i_5 = ((NI) 0);
							{
								while (1) {
									if (!(i_5 < colontmp__3)) goto LA22;
									j = i_5;
									{
										NIM_BOOL T25_;
										T25_ = (NIM_BOOL)0;
										T25_ = isInfixAs__ast_4936((*b)._kind_6.sons->data[j]);
										if (!T25_) goto LA26_;
										catches__sempass50_2293(tracked, (*(*(*b)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 1)]).typ);
										createTypeBoundOps__sempass50_142(tracked, (*(*(*b)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 2)]).typ, (*(*(*b)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 2)]).info);
									}
									goto LA23_;
									LA26_: ;
									{
										catches__sempass50_2293(tracked, (*(*b)._kind_6.sons->data[j]).typ);
									}
									LA23_: ;
									i_5 += ((NI) 1);
								} LA22: ;
							}
						}
					}
					LA13_: ;
				}
				goto LA9_;
				LA11_: ;
				{
				}
				LA9_: ;
				i_4 += ((NI) 1);
			} LA8: ;
		}
	}
	{
		NI i_6;
		NI colontmp__4;
		NI i_7;
		i_6 = (NI)0;
		colontmp__4 = (NI)0;
		colontmp__4 = len__ast_3155(n);
		i_7 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b_2;
				if (!(i_7 < colontmp__4)) goto LA32;
				i_6 = i_7;
				b_2 = (*n)._kind_6.sons->data[i_6];
				{
					NI T37_;
					if (!((*b_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 87))) goto LA35_;
					unsureAsgnRef((void**) (&(*tracked).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) setLengthSeqV2(((*tracked).init)?&((*tracked).init)->Sup:NIM_NIL, (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_), ((NI) (oldState))));
					T37_ = (NI)0;
					T37_ = len__ast_3155(b_2);
					track__sempass50_2338(tracked, (*b_2)._kind_6.sons->data[(NI)(T37_ - ((NI) 1))]);
					{
						NI i_8;
						NI colontmp__5;
						NI T39_;
						NI i_9;
						i_8 = (NI)0;
						colontmp__5 = (NI)0;
						T39_ = ((*tracked).init ? (*tracked).init->Sup.len : 0);
						colontmp__5 = T39_;
						i_9 = oldState;
						{
							while (1) {
								if (!(i_9 < colontmp__5)) goto LA41;
								i_8 = i_9;
								addToIntersection__sempass50_2160((&inter), (*tracked).init->data[i_8]);
								i_9 += ((NI) 1);
							} LA41: ;
						}
					}
				}
				goto LA33_;
				LA35_: ;
				{
					NI T43_;
					unsureAsgnRef((void**) (&(*tracked).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) setLengthSeqV2(((*tracked).init)?&((*tracked).init)->Sup:NIM_NIL, (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_), ((NI) (oldState))));
					T43_ = (NI)0;
					T43_ = len__ast_3155(b_2);
					track__sempass50_2338(tracked, (*b_2)._kind_6.sons->data[(NI)(T43_ - ((NI) 1))]);
					hasFinally = NIM_TRUE;
				}
				LA33_: ;
				i_7 += ((NI) 1);
			} LA32: ;
		}
	}
	(*tracked).bottom = oldBottom;
	(*tracked).inExceptOrFinallyStmt -= ((NI) 1);
	{
		if (!!(hasFinally)) goto LA46_;
		unsureAsgnRef((void**) (&(*tracked).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) setLengthSeqV2(((*tracked).init)?&((*tracked).init)->Sup:NIM_NIL, (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_), ((NI) (oldState))));
	}
	LA46_: ;
	{
		NI* id;
		NI* count;
		NI i_10;
		NI L;
		NI T49_;
		id = (NI*)0;
		count = (NI*)0;
		i_10 = ((NI) 0);
		T49_ = (inter ? inter->Sup.len : 0);
		L = T49_;
		{
			while (1) {
				if (!(i_10 < L)) goto LA51;
				id = (&inter->data[i_10].Field0);
				count = (&inter->data[i_10].Field1);
				{
					NI T56_;
					if (!((*count) == branches)) goto LA54_;
					unsureAsgnRef((void**) (&(*tracked).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)((*tracked).init), (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_)));
					T56_ = (*tracked).init->Sup.len++;
					(*tracked).init->data[T56_] = (*id);
				}
				LA54_: ;
				i_10 += ((NI) 1);
			} LA51: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, listEffects__sempass50_2289)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a) {
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e;
		e = NIM_NIL;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148((*a).exc);
			i_2 = ((NI) 0);
			{
				while (1) {
					NimStringDesc* T5_;
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					e = (*(*a).exc)._kind_6.sons->data[i];
					T5_ = NIM_NIL;
					T5_ = typeToString__types_50((*e).typ, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
					liMessage__msgs_1128((*a).config, (*e).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 102), T5_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_57, NIM_FALSE);
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e_2;
		e_2 = NIM_NIL;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = safeLen__ast_3148((*a).tags);
			i_4 = ((NI) 0);
			{
				while (1) {
					NimStringDesc* T10_;
					if (!(i_4 < colontmp__2)) goto LA9;
					i_3 = i_4;
					e_2 = (*(*a).tags)._kind_6.sons->data[i_3];
					T10_ = NIM_NIL;
					T10_ = typeToString__types_50((*e_2).typ, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
					liMessage__msgs_1128((*a).config, (*e_2).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 102), T10_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_58, NIM_FALSE);
					i_4 += ((NI) 1);
				} LA9: ;
			}
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, trackPragmaStmt__sempass50_2569)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
				tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw pragma;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				it = (*n)._kind_6.sons->data[i];
				pragma = whichPragma__trees_244(it);
				{
					if (!(pragma == ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 178))) goto LA6_;
					listEffects__sempass50_2289(tracked);
				}
				LA6_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, breaksBlock__sempass50_3022)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
	NIM_BOOL T6_;
	NIM_BOOL T8_;
	NIM_BOOL T9_;
	result = (NIM_BOOL)0;
	it = n;
	{
		while (1) {
			NIM_BOOL T3_;
			NI T5_;
			T3_ = (NIM_BOOL)0;
			T3_ = ((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126));
			if (!(T3_)) goto LA4_;
			T5_ = (NI)0;
			T5_ = len__ast_3155(it);
			T3_ = (((NI) 0) < T5_);
			LA4_: ;
			if (!T3_) goto LA2;
			it = lastSon__ast_4833(it);
		} LA2: ;
	}
	T6_ = (NIM_BOOL)0;
	T6_ = ((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 110) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 109) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 108));
	if (T6_) goto LA7_;
	T8_ = (NIM_BOOL)0;
	T9_ = (NIM_BOOL)0;
	T9_ = ((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28) || (*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32));
	if (!(T9_)) goto LA10_;
	T9_ = ((*(*it)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
	LA10_: ;
	T8_ = T9_;
	if (!(T8_)) goto LA11_;
	T8_ = (((*(*(*it)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 16))&63U)))!=0);
	LA11_: ;
	T6_ = T8_;
	LA7_: ;
	result = T6_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, trackCase__sempass50_3057)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI oldState;
	NI T1_;
	NI oldFacts;
	NI T2_;
	NIM_BOOL stringCase;
	NIM_BOOL T3_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T5_;
	NIM_BOOL interesting;
	NIM_BOOL T6_;
	NIM_BOOL T7_;
	tySequence__8Np6tlClE5az1CyqZdN19bQ* inter;
	NI toCover;
	track__sempass50_2338(tracked, (*n)._kind_6.sons->data[((NI) 0)]);
	T1_ = ((*tracked).init ? (*tracked).init->Sup.len : 0);
	oldState = T1_;
	T2_ = ((*tracked).guards.s ? (*tracked).guards.s->Sup.len : 0);
	oldFacts = T2_;
	T3_ = (NIM_BOOL)0;
	T3_ = !(((*(*n)._kind_6.sons->data[((NI) 0)]).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
	if (!(T3_)) goto LA4_;
	T5_ = NIM_NIL;
	T5_ = skipTypes__ast_3723((*(*n)._kind_6.sons->data[((NI) 0)]).typ, TM__O8rpA4QnF63fyis4dAzZxA_60);
	T3_ = ((*T5_).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36) && (*T5_).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 39) || (*T5_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28));
	LA4_: ;
	stringCase = T3_;
	T6_ = (NIM_BOOL)0;
	T7_ = (NIM_BOOL)0;
	T7_ = !(stringCase);
	if (!(T7_)) goto LA8_;
	T7_ = interestingCaseExpr__guards_114((*n)._kind_6.sons->data[((NI) 0)]);
	LA8_: ;
	T6_ = T7_;
	if (!(T6_)) goto LA9_;
	T6_ = hasWarn__options_570((*tracked).config, ((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 43));
	LA9_: ;
	interesting = T6_;
	inter = NIM_NIL;
	toCover = ((NI) 0);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* branch;
				if (!(i_2 < colontmp_)) goto LA12;
				i = i_2;
				branch = (*n)._kind_6.sons->data[i];
				unsureAsgnRef((void**) (&(*tracked).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) setLengthSeqV2(((*tracked).init)?&((*tracked).init)->Sup:NIM_NIL, (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_), ((NI) (oldState))));
				{
					if (!interesting) goto LA15_;
					unsureAsgnRef((void**) (&(*tracked).guards.s), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) setLengthSeqV2(((*tracked).guards.s)?&((*tracked).guards.s)->Sup:NIM_NIL, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) (oldFacts))));
					addCaseBranchFacts__guards_1764((&(*tracked).guards), n, i);
				}
				LA15_: ;
				{
					NI i_3;
					NI colontmp__2;
					NI i_4;
					i_3 = (NI)0;
					colontmp__2 = (NI)0;
					colontmp__2 = len__ast_3155(branch);
					i_4 = ((NI) 0);
					{
						while (1) {
							if (!(i_4 < colontmp__2)) goto LA19;
							i_3 = i_4;
							track__sempass50_2338(tracked, (*branch)._kind_6.sons->data[i_3]);
							i_4 += ((NI) 1);
						} LA19: ;
					}
				}
				{
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T22_;
					NIM_BOOL T23_;
					T22_ = NIM_NIL;
					T22_ = lastSon__ast_4833(branch);
					T23_ = (NIM_BOOL)0;
					T23_ = breaksBlock__sempass50_3022(T22_);
					if (!!(T23_)) goto LA24_;
					toCover += ((NI) 1);
				}
				LA24_: ;
				{
					NI i_5;
					NI colontmp__3;
					NI T27_;
					NI i_6;
					i_5 = (NI)0;
					colontmp__3 = (NI)0;
					T27_ = ((*tracked).init ? (*tracked).init->Sup.len : 0);
					colontmp__3 = T27_;
					i_6 = oldState;
					{
						while (1) {
							if (!(i_6 < colontmp__3)) goto LA29;
							i_5 = i_6;
							addToIntersection__sempass50_2160((&inter), (*tracked).init->data[i_5]);
							i_6 += ((NI) 1);
						} LA29: ;
					}
				}
				i_2 += ((NI) 1);
			} LA12: ;
		}
	}
	unsureAsgnRef((void**) (&(*tracked).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) setLengthSeqV2(((*tracked).init)?&((*tracked).init)->Sup:NIM_NIL, (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_), ((NI) (oldState))));
	{
		NIM_BOOL T32_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T34_;
		T32_ = (NIM_BOOL)0;
		T32_ = !(stringCase);
		if (T32_) goto LA33_;
		T34_ = NIM_NIL;
		T34_ = lastSon__ast_4833(n);
		T32_ = ((*T34_).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 88));
		LA33_: ;
		if (!T32_) goto LA35_;
		{
			NI* id;
			NI* count;
			NI i_7;
			NI L;
			NI T38_;
			id = (NI*)0;
			count = (NI*)0;
			i_7 = ((NI) 0);
			T38_ = (inter ? inter->Sup.len : 0);
			L = T38_;
			{
				while (1) {
					if (!(i_7 < L)) goto LA40;
					id = (&inter->data[i_7].Field0);
					count = (&inter->data[i_7].Field1);
					{
						NI T45_;
						if (!(toCover <= (*count))) goto LA43_;
						unsureAsgnRef((void**) (&(*tracked).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)((*tracked).init), (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_)));
						T45_ = (*tracked).init->Sup.len++;
						(*tracked).init->data[T45_] = (*id);
					}
					LA43_: ;
					i_7 += ((NI) 1);
				} LA40: ;
			}
		}
	}
	LA35_: ;
	unsureAsgnRef((void**) (&(*tracked).guards.s), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) setLengthSeqV2(((*tracked).guards.s)?&((*tracked).guards.s)->Sup:NIM_NIL, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) (oldFacts))));
}
N_LIB_PRIVATE N_NIMCALL(void, trackIf__sempass50_3158)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI oldFacts;
	NI T1_;
	NI oldState;
	NI T2_;
	tySequence__8Np6tlClE5az1CyqZdN19bQ* inter;
	NI toCover;
	track__sempass50_2338(tracked, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)]);
	T1_ = ((*tracked).guards.s ? (*tracked).guards.s->Sup.len : 0);
	oldFacts = T1_;
	addFact__guards_609((&(*tracked).guards), (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)]);
	T2_ = ((*tracked).init ? (*tracked).init->Sup.len : 0);
	oldState = T2_;
	inter = NIM_NIL;
	toCover = ((NI) 0);
	track__sempass50_2338(tracked, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)]);
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = breaksBlock__sempass50_3022((*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)]);
		if (!!(T5_)) goto LA6_;
		toCover += ((NI) 1);
	}
	LA6_: ;
	{
		NI i;
		NI colontmp_;
		NI T9_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T9_ = ((*tracked).init ? (*tracked).init->Sup.len : 0);
		colontmp_ = T9_;
		i_2 = oldState;
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA11;
				i = i_2;
				addToIntersection__sempass50_2160((&inter), (*tracked).init->data[i]);
				i_2 += ((NI) 1);
			} LA11: ;
		}
	}
	{
		NI i_3;
		NI colontmp__2;
		NI i_4;
		i_3 = (NI)0;
		colontmp__2 = (NI)0;
		colontmp__2 = len__ast_3155(n);
		i_4 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* branch;
				if (!(i_4 < colontmp__2)) goto LA14;
				i_3 = i_4;
				branch = (*n)._kind_6.sons->data[i_3];
				unsureAsgnRef((void**) (&(*tracked).guards.s), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) setLengthSeqV2(((*tracked).guards.s)?&((*tracked).guards.s)->Sup:NIM_NIL, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) (oldFacts))));
				{
					NI j;
					NI colontmp__3;
					NI res;
					j = (NI)0;
					colontmp__3 = (NI)0;
					colontmp__3 = (NI)(i_3 - ((NI) 1));
					res = ((NI) 0);
					{
						while (1) {
							if (!(res <= colontmp__3)) goto LA17;
							j = res;
							addFactNeg__guards_632((&(*tracked).guards), (*(*n)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 0)]);
							res += ((NI) 1);
						} LA17: ;
					}
				}
				{
					NI T20_;
					T20_ = (NI)0;
					T20_ = len__ast_3155(branch);
					if (!(((NI) 1) < T20_)) goto LA21_;
					addFact__guards_609((&(*tracked).guards), (*branch)._kind_6.sons->data[((NI) 0)]);
				}
				LA21_: ;
				unsureAsgnRef((void**) (&(*tracked).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) setLengthSeqV2(((*tracked).init)?&((*tracked).init)->Sup:NIM_NIL, (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_), ((NI) (oldState))));
				{
					NI i_5;
					NI colontmp__4;
					NI i_6;
					i_5 = (NI)0;
					colontmp__4 = (NI)0;
					colontmp__4 = len__ast_3155(branch);
					i_6 = ((NI) 0);
					{
						while (1) {
							if (!(i_6 < colontmp__4)) goto LA25;
							i_5 = i_6;
							track__sempass50_2338(tracked, (*branch)._kind_6.sons->data[i_5]);
							i_6 += ((NI) 1);
						} LA25: ;
					}
				}
				{
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T28_;
					NIM_BOOL T29_;
					T28_ = NIM_NIL;
					T28_ = lastSon__ast_4833(branch);
					T29_ = (NIM_BOOL)0;
					T29_ = breaksBlock__sempass50_3022(T28_);
					if (!!(T29_)) goto LA30_;
					toCover += ((NI) 1);
				}
				LA30_: ;
				{
					NI i_7;
					NI colontmp__5;
					NI T33_;
					NI i_8;
					i_7 = (NI)0;
					colontmp__5 = (NI)0;
					T33_ = ((*tracked).init ? (*tracked).init->Sup.len : 0);
					colontmp__5 = T33_;
					i_8 = oldState;
					{
						while (1) {
							if (!(i_8 < colontmp__5)) goto LA35;
							i_7 = i_8;
							addToIntersection__sempass50_2160((&inter), (*tracked).init->data[i_7]);
							i_8 += ((NI) 1);
						} LA35: ;
					}
				}
				i_4 += ((NI) 1);
			} LA14: ;
		}
	}
	unsureAsgnRef((void**) (&(*tracked).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) setLengthSeqV2(((*tracked).init)?&((*tracked).init)->Sup:NIM_NIL, (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_), ((NI) (oldState))));
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T38_;
		NI T39_;
		T38_ = NIM_NIL;
		T38_ = lastSon__ast_4833(n);
		T39_ = (NI)0;
		T39_ = len__ast_3155(T38_);
		if (!(T39_ == ((NI) 1))) goto LA40_;
		{
			NI* id;
			NI* count;
			NI i_9;
			NI L;
			NI T43_;
			id = (NI*)0;
			count = (NI*)0;
			i_9 = ((NI) 0);
			T43_ = (inter ? inter->Sup.len : 0);
			L = T43_;
			{
				while (1) {
					if (!(i_9 < L)) goto LA45;
					id = (&inter->data[i_9].Field0);
					count = (&inter->data[i_9].Field1);
					{
						NI T50_;
						if (!(toCover <= (*count))) goto LA48_;
						unsureAsgnRef((void**) (&(*tracked).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)((*tracked).init), (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_)));
						T50_ = (*tracked).init->Sup.len++;
						(*tracked).init->data[T50_] = (*id);
					}
					LA48_: ;
					i_9 += ((NI) 1);
				} LA45: ;
			}
		}
	}
	LA40_: ;
	unsureAsgnRef((void**) (&(*tracked).guards.s), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) setLengthSeqV2(((*tracked).guards.s)?&((*tracked).guards.s)->Sup:NIM_NIL, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) (oldFacts))));
}
N_LIB_PRIVATE N_NIMCALL(void, trackBlock__sempass50_3274)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NI oldState;
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126))) goto LA3_;
		oldState = ((NI) -1);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA7;
					i = i_2;
					{
						NIM_BOOL T10_;
						T10_ = (NIM_BOOL)0;
						T10_ = hasSubnodeWith__ast_4571((*n)._kind_6.sons->data[i], ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 110));
						if (!T10_) goto LA11_;
						{
							NI T17_;
							if (!(oldState < ((NI) 0))) goto LA15_;
							T17_ = ((*tracked).init ? (*tracked).init->Sup.len : 0);
							oldState = T17_;
						}
						LA15_: ;
					}
					LA11_: ;
					track__sempass50_2338(tracked, (*n)._kind_6.sons->data[i]);
					i_2 += ((NI) 1);
				} LA7: ;
			}
		}
		{
			if (!(((NI) 0) < oldState)) goto LA20_;
			unsureAsgnRef((void**) (&(*tracked).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) setLengthSeqV2(((*tracked).init)?&((*tracked).init)->Sup:NIM_NIL, (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_), ((NI) (oldState))));
		}
		LA20_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		track__sempass50_2338(tracked, n);
	}
	LA1_: ;
}
static N_INLINE(NIM_BOOL, fromSystem__astalgo_238)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* op) {
	NIM_BOOL result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T1_;
	result = (NIM_BOOL)0;
	T1_ = NIM_NIL;
	T1_ = getModule__astalgo_216(op);
	result = (((*T1_).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 15))&63U)))!=0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, createBlockContext__sempass50_3750)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_PragmaBlockContext__KenhkbpTaL6MY9cFJ0RV2bA* Result) {
	NI T1_;
	(*Result).oldLocked = 0;
	(*Result).oldLockLevel = 0;
	(*Result).enforcedGcSafety = 0;
	(*Result).enforceNoSideEffects = 0;
	(*Result).oldExc = 0;
	(*Result).oldTags = 0;
	unsureAsgnRef((void**)&(*Result).exc, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).tags, NIM_NIL);
	T1_ = ((*tracked).locked ? (*tracked).locked->Sup.len : 0);
	(*Result).oldLocked = T1_;
	(*Result).oldLockLevel = (*tracked).currLockLevel;
	(*Result).enforcedGcSafety = NIM_FALSE;
	(*Result).enforceNoSideEffects = NIM_FALSE;
	(*Result).oldExc = len__ast_3155((*tracked).exc);
	(*Result).oldTags = len__ast_3155((*tracked).tags);
}
N_LIB_PRIVATE N_NIMCALL(NI16, getLockLevel__sempass50_182)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t) {
	NI16 result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t_2;
	result = (NI16)0;
	t_2 = t;
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*t_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 11));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_3990(t_2);
		T3_ = (T5_ == ((NI) 3));
		LA4_: ;
		if (!T3_) goto LA6_;
		t_2 = (*t_2).sons->data[((NI) 1)];
	}
	LA6_: ;
	{
		NIM_BOOL T10_;
		NIM_BOOL T11_;
		T10_ = (NIM_BOOL)0;
		T11_ = (NIM_BOOL)0;
		T11_ = ((*t_2).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 60));
		if (!(T11_)) goto LA12_;
		T11_ = !(((*t_2).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
		LA12_: ;
		T10_ = T11_;
		if (!(T10_)) goto LA13_;
		T10_ = ((*(*t_2).n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) && (*(*t_2).n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 10));
		LA13_: ;
		if (!T10_) goto LA14_;
		result = ((NI16) ((*(*t_2).n)._kind_1.intVal));
	}
	LA14_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, lockLocations__sempass50_206)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pragma) {
	NI16 firstLL;
{	{
		if (!!(((*pragma).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34)))) goto LA3_;
		liMessage__msgs_1128((*a).config, (*pragma).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_65), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_66, NIM_FALSE);
		goto BeforeRet_;
	}
	LA3_: ;
	firstLL = ((NI16) -1);
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* colontmp_;
		x = NIM_NIL;
		colontmp_ = NIM_NIL;
		colontmp_ = (*pragma)._kind_6.sons->data[((NI) 1)];
		{
			NI i;
			NI colontmp__2;
			NI i_2;
			i = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = safeLen__ast_3148(colontmp_);
			i_2 = ((NI) 0);
			{
				while (1) {
					NI16 thisLL;
					NI T27_;
					if (!(i_2 < colontmp__2)) goto LA8;
					i = i_2;
					x = (*colontmp_)._kind_6.sons->data[i];
					thisLL = getLockLevel__sempass50_182((*x).typ);
					{
						if (!!((thisLL == ((NI16) 0)))) goto LA11_;
						{
							NIM_BOOL T15_;
							NimStringDesc* T19_;
							NimStringDesc* T20_;
							T15_ = (NIM_BOOL)0;
							T15_ = (thisLL < ((NI16) 0));
							if (T15_) goto LA16_;
							T15_ = (((NI16) 1000) < thisLL);
							LA16_: ;
							if (!T15_) goto LA17_;
							T19_ = NIM_NIL;
							T20_ = NIM_NIL;
							T20_ = dollar___ast_3846(thisLL);
							T19_ = rawNewString((T20_ ? T20_->Sup.len : 0) + 20);
appendString(T19_, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_67));
appendString(T19_, T20_);
							liMessage__msgs_1128((*a).config, (*x).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T19_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_68, NIM_FALSE);
						}
						goto LA13_;
						LA17_: ;
						{
							if (!(firstLL < ((NI16) 0))) goto LA22_;
							firstLL = thisLL;
						}
						goto LA13_;
						LA22_: ;
						{
							if (!!((firstLL == thisLL))) goto LA25_;
							liMessage__msgs_1128((*a).config, (*x).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_69), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_70, NIM_FALSE);
						}
						goto LA13_;
						LA25_: ;
						LA13_: ;
						(*a).maxLockLevel = (((*a).maxLockLevel >= firstLL) ? (*a).maxLockLevel : firstLL);
					}
					LA11_: ;
					unsureAsgnRef((void**) (&(*a).locked), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) incrSeqV3((TGenericSeq*)((*a).locked), (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_)));
					T27_ = (*a).locked->Sup.len++;
					asgnRef((void**) (&(*a).locked->data[T27_]), x);
					i_2 += ((NI) 1);
				} LA8: ;
			}
		}
	}
	{
		NIM_BOOL T30_;
		T30_ = (NIM_BOOL)0;
		T30_ = (((NI16) 0) <= firstLL);
		if (!(T30_)) goto LA31_;
		T30_ = !((firstLL == (*a).currLockLevel));
		LA31_: ;
		if (!T30_) goto LA32_;
		{
			NIM_BOOL T36_;
			T36_ = (NIM_BOOL)0;
			T36_ = (((NI16) 0) < (*a).currLockLevel);
			if (!(T36_)) goto LA37_;
			T36_ = ((*a).currLockLevel <= firstLL);
			LA37_: ;
			if (!T36_) goto LA38_;
			liMessage__msgs_1128((*a).config, (*pragma).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_71), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_72, NIM_FALSE);
		}
		LA38_: ;
		(*a).currLockLevel = firstLL;
	}
	LA32_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, castBlock__sempass50_3799)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pragma, tyObject_PragmaBlockContext__KenhkbpTaL6MY9cFJ0RV2bA* bc) {
	tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw T1_;
	T1_ = (tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw)0;
	T1_ = whichPragma__trees_244(pragma);
	switch (T1_) {
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 110):
	{
		(*bc).enforcedGcSafety = NIM_TRUE;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 109):
	{
		(*bc).enforceNoSideEffects = NIM_TRUE;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 179):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
		n = (*pragma)._kind_6.sons->data[((NI) 1)];
		{
			if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 39) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41))) goto LA7_;
			unsureAsgnRef((void**) (&(*bc).tags), n);
		}
		goto LA5_;
		LA7_: ;
		{
			unsureAsgnRef((void**) (&(*bc).tags), newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152), (*pragma).info));
			add__ast_4798((*bc).tags, n);
		}
		LA5_: ;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 174):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n_2;
		n_2 = (*pragma)._kind_6.sons->data[((NI) 1)];
		{
			if (!((*n_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 39) || (*n_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41))) goto LA13_;
			unsureAsgnRef((void**) (&(*bc).exc), n_2);
		}
		goto LA11_;
		LA13_: ;
		{
			unsureAsgnRef((void**) (&(*bc).exc), newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152), (*pragma).info));
			add__ast_4798((*bc).exc, n_2);
		}
		LA11_: ;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 86):
	{
	}
	break;
	default:
	{
		NimStringDesc* T18_;
		NimStringDesc* T19_;
		T18_ = NIM_NIL;
		T19_ = NIM_NIL;
		T19_ = dollar___renderer_2116(pragma);
		T18_ = rawNewString((T19_ ? T19_->Sup.len : 0) + 22);
appendString(T18_, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_73));
appendString(T18_, T19_);
		liMessage__msgs_1128((*tracked).config, (*pragma).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T18_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_74, NIM_FALSE);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, applyBlockContext__sempass50_3771)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_PragmaBlockContext__KenhkbpTaL6MY9cFJ0RV2bA* bc) {
	{
		if (!(*bc).enforcedGcSafety) goto LA3_;
		(*tracked).inEnforcedGcSafe = NIM_TRUE;
	}
	LA3_: ;
	{
		if (!(*bc).enforceNoSideEffects) goto LA7_;
		(*tracked).inEnforcedNoSideEffects = NIM_TRUE;
	}
	LA7_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, unapplyBlockContext__sempass50_3774)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_PragmaBlockContext__KenhkbpTaL6MY9cFJ0RV2bA* bc) {
	{
		if (!(*bc).enforcedGcSafety) goto LA3_;
		(*tracked).inEnforcedGcSafe = NIM_FALSE;
	}
	LA3_: ;
	{
		if (!(*bc).enforceNoSideEffects) goto LA7_;
		(*tracked).inEnforcedNoSideEffects = NIM_FALSE;
	}
	LA7_: ;
	unsureAsgnRef((void**) (&(*tracked).locked), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) setLengthSeqV2(((*tracked).locked)?&((*tracked).locked)->Sup:NIM_NIL, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) ((*bc).oldLocked))));
	(*tracked).currLockLevel = (*bc).oldLockLevel;
	{
		if (!!(((*bc).exc == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA11_;
		asgnRef((void**) (&(*(*tracked).exc)._kind_6.sons), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) setLengthSeqV2(((*(*tracked).exc)._kind_6.sons)?&((*(*tracked).exc)._kind_6.sons)->Sup:NIM_NIL, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) ((*bc).oldExc))));
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* e;
			e = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148((*bc).exc);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA16;
						i = i_2;
						e = (*(*bc).exc)._kind_6.sons->data[i];
						addRaiseEffect__sempass50_2237(tracked, e, e);
						i_2 += ((NI) 1);
					} LA16: ;
				}
			}
		}
	}
	LA11_: ;
	{
		if (!!(((*bc).tags == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA19_;
		asgnRef((void**) (&(*(*tracked).tags)._kind_6.sons), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) setLengthSeqV2(((*(*tracked).tags)._kind_6.sons)?&((*(*tracked).tags)._kind_6.sons)->Sup:NIM_NIL, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) ((*bc).oldTags))));
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* t;
			t = NIM_NIL;
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = safeLen__ast_3148((*bc).tags);
				i_4 = ((NI) 0);
				{
					while (1) {
						if (!(i_4 < colontmp__2)) goto LA24;
						i_3 = i_4;
						t = (*(*bc).tags)._kind_6.sons->data[i_3];
						addTag__sempass50_2259(tracked, t, t);
						i_4 += ((NI) 1);
					} LA24: ;
				}
			}
		}
	}
	LA19_: ;
}
static N_INLINE(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, getBody__modulegraphs_13094)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = (*(*s).ast)._kind_6.sons->data[((NI) 6)];
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (result == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
		if (!(T3_)) goto LA4_;
		T3_ = ((28 &((NU8)1<<((NU)((*(*g).config).symbolFiles)&7U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		result = loadProcBody__icZic_8386((*g).config, (*g).cache, (&(*g).packed_0), s);
		asgnRef((void**) (&(*(*s).ast)._kind_6.sons->data[((NI) 6)]), result);
	}
	LA5_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, trackInnerProc__sempass50_3823)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
		s = (*n)._kind_4.sym;
		{
			NIM_BOOL T4_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym355_;
			T4_ = (NIM_BOOL)0;
			T4_ = ((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
			if (!(T4_)) goto LA5_;
			T4_ = ((*s).owner == (*tracked).owner);
			LA5_: ;
			if (!T4_) goto LA6_;
			xX60gensym355_ = s;
			incl__pureZcollectionsZintsets_55((&(*tracked).escapingParams), (NI)((NI)((NU64)(((NI) ((*xX60gensym355_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym355_).Sup.itemId.item))));
		}
		LA6_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 4) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
	{
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 81):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 80):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 51):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 52):
	{
		{
			NIM_BOOL T12_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T16_;
			T12_ = (NIM_BOOL)0;
			T12_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
			if (!(T12_)) goto LA13_;
			T12_ = !(((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).ast == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
			LA13_: ;
			if (!T12_) goto LA14_;
			T16_ = NIM_NIL;
			T16_ = getBody__modulegraphs_13094((*tracked).graph, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
			trackInnerProc__sempass50_3823(tracked, T16_);
		}
		LA14_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 98):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 82):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 83):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 161):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 101):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 102):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 121):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 116):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 118):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 90):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 125):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 158):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 132):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 123):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 122):
	{
	}
	break;
	default:
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ch;
			ch = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA22;
						i = i_2;
						ch = (*n)._kind_6.sons->data[i];
						trackInnerProc__sempass50_3823(tracked, ch);
						i_2 += ((NI) 1);
					} LA22: ;
				}
			}
		}
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, allowCStringConv__sempass50_3865)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22):
	{
		result = NIM_TRUE;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		result = ((1032 &((NU32)1<<((NU)((*(*n)._kind_4.sym).kind)&31U)))!=0);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63):
	{
		result = isCharArrayPtr__types_4177((*n).typ, NIM_TRUE);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		if (!(T5_)) goto LA6_;
		T5_ = ((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 16));
		LA6_: ;
		result = isCharArrayPtr__types_4177((*n).typ, T5_);
	}
	break;
	default:
	{
		result = isCharArrayPtr__types_4177((*n).typ, NIM_FALSE);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkRange__sempass50_3359)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* value, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	t = skipTypes__ast_3723(typ, TM__O8rpA4QnF63fyis4dAzZxA_82);
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lowBound;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* highBound;
		if (!((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 20))) goto LA3_;
		lowBound = copyTree__ast_4432((*(*t).n)._kind_6.sons->data[((NI) 0)]);
		(*lowBound).info = (*value).info;
		highBound = copyTree__ast_4432((*(*t).n)._kind_6.sons->data[((NI) 1)]);
		(*highBound).info = (*value).info;
		checkLe__sempass50_3351(c, lowBound, value);
		checkLe__sempass50_3351(c, value, highBound);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, track__sempass50_2338)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* tracked, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		useVar__sempass50_2113(tracked, n);
		{
			NIM_BOOL T4_;
			T4_ = (NIM_BOOL)0;
			T4_ = !(((*(*n)._kind_4.sym).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
			if (!(T4_)) goto LA5_;
			T4_ = (((*(*(*n)._kind_4.sym).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 31))&63U)))!=0);
			LA5_: ;
			if (!T4_) goto LA6_;
			(*(*tracked).owner).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 42)) & 63);
			{
				NIM_BOOL T10_;
				T10_ = (NIM_BOOL)0;
				T10_ = !(!(((IL64(2147483664) & (*(*n).typ).flags) == 0)));
				if (!(T10_)) goto LA11_;
				T10_ = sameType__types_1886((*n).typ, (*(*n)._kind_4.sym).typ, 0);
				LA11_: ;
				if (!T10_) goto LA12_;
				asgnRef((void**) (&(*n).typ), (*(*n)._kind_4.sym).typ);
			}
			LA12_: ;
		}
		LA6_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63):
	{
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
			if (!(T17_)) goto LA18_;
			T17_ = isLocalVar__sempass50_162(tracked, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
			LA18_: ;
			if (!T17_) goto LA19_;
			useVarNoInitCheck__sempass50_959(tracked, (*n)._kind_6.sons->data[((NI) 0)], (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
		}
		goto LA15_;
		LA19_: ;
		{
			track__sempass50_2338(tracked, (*n)._kind_6.sons->data[((NI) 0)]);
		}
		LA15_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 108):
	{
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)))) goto LA25_;
			(*(*n)._kind_6.sons->data[((NI) 0)]).info = (*n).info;
			addRaiseEffect__sempass50_2237(tracked, (*n)._kind_6.sons->data[((NI) 0)], n);
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA29;
						i = i_2;
						track__sempass50_2338(tracked, (*n)._kind_6.sons->data[i]);
						i_2 += ((NI) 1);
					} LA29: ;
				}
			}
			createTypeBoundOps__sempass50_142(tracked, (*(*n)._kind_6.sons->data[((NI) 0)]).typ, (*n).info);
		}
		goto LA23_;
		LA25_: ;
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T31_;
			T31_ = NIM_NIL;
			T31_ = createRaise__sempass50_2223((*tracked).graph, n);
			addRaiseEffect__sempass50_2237(tracked, T31_, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
		}
		LA23_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
	{
		trackCall__sempass50_3376(tracked, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45):
	{
		guardDotAccess__sempass50_237(tracked, n);
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3155(n);
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA36;
					i_3 = i_4;
					track__sempass50_2338(tracked, (*n)._kind_6.sons->data[i_3]);
					i_4 += ((NI) 1);
				} LA36: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 46):
	{
		track__sempass50_2338(tracked, (*n)._kind_6.sons->data[((NI) 0)]);
		{
			NIM_BOOL T40_;
			T40_ = (NIM_BOOL)0;
			T40_ = hasWarn__options_570((*tracked).config, ((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 43));
			if (!T40_) goto LA41_;
			checkFieldAccess__guards_1809((*tracked).guards, n, (*tracked).config);
		}
		LA41_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 106):
	{
		trackTryStmt__sempass50_2341(tracked, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 90):
	{
		trackPragmaStmt__sempass50_2569(tracked, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 73):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 74):
	{
		track__sempass50_2338(tracked, (*n)._kind_6.sons->data[((NI) 1)]);
		initVar__sempass50_312(tracked, (*n)._kind_6.sons->data[((NI) 0)], NIM_TRUE);
		invalidateFacts__guards_760((&(*tracked).guards), (*n)._kind_6.sons->data[((NI) 0)]);
		(*tracked).leftPartOfAsgn += ((NI) 1);
		track__sempass50_2338(tracked, (*n)._kind_6.sons->data[((NI) 0)]);
		(*tracked).leftPartOfAsgn -= ((NI) 1);
		addAsgnFact__guards_1739((&(*tracked).guards), (*n)._kind_6.sons->data[((NI) 0)], (*n)._kind_6.sons->data[((NI) 1)]);
		notNilCheck__sempass50_2668(tracked, (*n)._kind_6.sons->data[((NI) 1)], (*(*n)._kind_6.sons->data[((NI) 0)]).typ);
		{
			NIM_BOOL T48_;
			T48_ = (NIM_BOOL)0;
			T48_ = !(((*(*tracked).owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 17)));
			if (!(T48_)) goto LA49_;
			T48_ = !(((*(*(*n)._kind_6.sons->data[((NI) 0)]).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27) || (*(*(*n)._kind_6.sons->data[((NI) 0)]).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48)));
			LA49_: ;
			if (!T48_) goto LA50_;
			createTypeBoundOps__sempass50_142(tracked, (*(*n)._kind_6.sons->data[((NI) 0)]).typ, (*n).info);
		}
		LA50_: ;
		{
			NIM_BOOL T54_;
			NIM_BOOL T56_;
			T54_ = (NIM_BOOL)0;
			T54_ = !(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)));
			if (T54_) goto LA55_;
			T56_ = (NIM_BOOL)0;
			T56_ = isLocalVar__sempass50_162(tracked, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
			T54_ = !(T56_);
			LA55_: ;
			if (!T54_) goto LA57_;
			checkForSink__sempass50_24((*tracked).config, (*(*tracked).c).Sup.idgen, (*tracked).owner, (*n)._kind_6.sons->data[((NI) 1)]);
			{
				NIM_BOOL T61_;
				T61_ = (NIM_BOOL)0;
				T61_ = !((*tracked).hasDangerousAssign);
				if (!(T61_)) goto LA62_;
				T61_ = !(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)));
				LA62_: ;
				if (!T61_) goto LA63_;
				(*tracked).hasDangerousAssign = NIM_TRUE;
			}
			LA63_: ;
		}
		LA57_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 99):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 100):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child;
			child = NIM_NIL;
			{
				NI i_5;
				NI colontmp__3;
				NI i_6;
				i_5 = (NI)0;
				colontmp__3 = (NI)0;
				colontmp__3 = safeLen__ast_3148(n);
				i_6 = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* last;
						if (!(i_6 < colontmp__3)) goto LA69;
						i_5 = i_6;
						child = (*n)._kind_6.sons->data[i_5];
						last = lastSon__ast_4833(child);
						{
							if (!!(((*last).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)))) goto LA72_;
							track__sempass50_2338(tracked, last);
						}
						LA72_: ;
						{
							if (!!(((*(*tracked).owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 17)))) goto LA76_;
							{
								NI T82_;
								if (!((*child).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 36))) goto LA80_;
								T82_ = (NI)0;
								T82_ = len__ast_3155(child);
								createTypeBoundOps__sempass50_142(tracked, (*(*child)._kind_6.sons->data[(NI)(T82_ - ((NI) 1))]).typ, (*child).info);
								{
									NI i_7;
									NI colontmp__4;
									NI T84_;
									NI i_8;
									i_7 = (NI)0;
									colontmp__4 = (NI)0;
									T84_ = (NI)0;
									T84_ = len__ast_3155(child);
									colontmp__4 = (NI)(T84_ - ((NI) 2));
									i_8 = ((NI) 0);
									{
										while (1) {
											if (!(i_8 < colontmp__4)) goto LA86;
											i_7 = i_8;
											createTypeBoundOps__sempass50_142(tracked, (*(*child)._kind_6.sons->data[i_7]).typ, (*child).info);
											i_8 += ((NI) 1);
										} LA86: ;
									}
								}
							}
							goto LA78_;
							LA80_: ;
							{
								createTypeBoundOps__sempass50_142(tracked, (*(*child)._kind_6.sons->data[((NI) 0)]).typ, (*child).info);
							}
							LA78_: ;
						}
						LA76_: ;
						{
							NIM_BOOL T90_;
							T90_ = (NIM_BOOL)0;
							T90_ = ((*child).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 35));
							if (!(T90_)) goto LA91_;
							T90_ = !(((*last).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)));
							LA91_: ;
							if (!T90_) goto LA92_;
							{
								NI i_9;
								NI colontmp__5;
								NI T95_;
								NI i_10;
								i_9 = (NI)0;
								colontmp__5 = (NI)0;
								T95_ = (NI)0;
								T95_ = len__ast_3155(child);
								colontmp__5 = (NI)(T95_ - ((NI) 2));
								i_10 = ((NI) 0);
								{
									while (1) {
										if (!(i_10 < colontmp__5)) goto LA97;
										i_9 = i_10;
										initVar__sempass50_312(tracked, (*child)._kind_6.sons->data[i_9], NIM_FALSE);
										addAsgnFact__guards_1739((&(*tracked).guards), (*child)._kind_6.sons->data[i_9], last);
										notNilCheck__sempass50_2668(tracked, last, (*(*child)._kind_6.sons->data[i_9]).typ);
										i_10 += ((NI) 1);
									} LA97: ;
								}
							}
						}
						goto LA88_;
						LA92_: ;
						{
							NIM_BOOL T99_;
							T99_ = (NIM_BOOL)0;
							T99_ = ((*child).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 36));
							if (!(T99_)) goto LA100_;
							T99_ = !(((*last).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)));
							LA100_: ;
							if (!T99_) goto LA101_;
							{
								NI i_11;
								NI colontmp__6;
								NI T104_;
								NI i_12;
								i_11 = (NI)0;
								colontmp__6 = (NI)0;
								T104_ = (NI)0;
								T104_ = len__ast_3155(child);
								colontmp__6 = (NI)(T104_ - ((NI) 1));
								i_12 = ((NI) 0);
								{
									while (1) {
										if (!(i_12 < colontmp__6)) goto LA106;
										i_11 = i_12;
										{
											{
												NIM_BOOL T110_;
												NIM_BOOL T112_;
												T110_ = (NIM_BOOL)0;
												T110_ = ((*(*child)._kind_6.sons->data[i_11]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1));
												if (T110_) goto LA111_;
												T112_ = (NIM_BOOL)0;
												T112_ = ((*(*child)._kind_6.sons->data[i_11]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
												if (!(T112_)) goto LA113_;
												T112_ = eqStrings((*(*(*(*child)._kind_6.sons->data[i_11])._kind_4.sym).name).s, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_59));
												LA113_: ;
												T110_ = T112_;
												LA111_: ;
												if (!T110_) goto LA114_;
												goto LA107;
											}
											LA114_: ;
											initVar__sempass50_312(tracked, (*child)._kind_6.sons->data[i_11], NIM_FALSE);
											{
												if (!((*last).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 37) || (*last).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 160))) goto LA118_;
												addAsgnFact__guards_1739((&(*tracked).guards), (*child)._kind_6.sons->data[i_11], (*last)._kind_6.sons->data[i_11]);
												notNilCheck__sempass50_2668(tracked, (*last)._kind_6.sons->data[i_11], (*(*child)._kind_6.sons->data[i_11]).typ);
											}
											LA118_: ;
										} LA107: ;
										i_12 += ((NI) 1);
									} LA106: ;
								}
							}
						}
						goto LA88_;
						LA101_: ;
						LA88_: ;
						i_6 += ((NI) 1);
					} LA69: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 101):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* child_2;
			child_2 = NIM_NIL;
			{
				NI i_13;
				NI colontmp__7;
				NI i_14;
				i_13 = (NI)0;
				colontmp__7 = (NI)0;
				colontmp__7 = safeLen__ast_3148(n);
				i_14 = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* last_2;
						if (!(i_14 < colontmp__7)) goto LA124;
						i_13 = i_14;
						child_2 = (*n)._kind_6.sons->data[i_13];
						last_2 = lastSon__ast_4833(child_2);
						track__sempass50_2338(tracked, last_2);
						i_14 += ((NI) 1);
					} LA124: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 97):
	{
		trackCase__sempass50_3057(tracked, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 93):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 92):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 48):
	{
		trackIf__sempass50_3158(tracked, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 112):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 127):
	{
		trackBlock__sempass50_3274(tracked, (*n)._kind_6.sons->data[((NI) 1)]);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 96):
	{
		{
			NIM_BOOL T131_;
			T131_ = (NIM_BOOL)0;
			T131_ = isTrue__trees_375((*n)._kind_6.sons->data[((NI) 0)]);
			if (!T131_) goto LA132_;
			trackBlock__sempass50_3274(tracked, (*n)._kind_6.sons->data[((NI) 1)]);
		}
		goto LA129_;
		LA132_: ;
		{
			NI oldState;
			NI T135_;
			NI oldFacts;
			NI T136_;
			T135_ = ((*tracked).init ? (*tracked).init->Sup.len : 0);
			oldState = T135_;
			T136_ = ((*tracked).guards.s ? (*tracked).guards.s->Sup.len : 0);
			oldFacts = T136_;
			addFact__guards_609((&(*tracked).guards), (*n)._kind_6.sons->data[((NI) 0)]);
			track__sempass50_2338(tracked, (*n)._kind_6.sons->data[((NI) 0)]);
			track__sempass50_2338(tracked, (*n)._kind_6.sons->data[((NI) 1)]);
			unsureAsgnRef((void**) (&(*tracked).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) setLengthSeqV2(((*tracked).init)?&((*tracked).init)->Sup:NIM_NIL, (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_), ((NI) (oldState))));
			unsureAsgnRef((void**) (&(*tracked).guards.s), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) setLengthSeqV2(((*tracked).guards.s)?&((*tracked).guards.s)->Sup:NIM_NIL, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) (oldFacts))));
		}
		LA129_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 94):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 95):
	{
		NI oldState_2;
		NI T138_;
		NI oldFacts_2;
		NI T139_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* iterCall;
		NI T140_;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* loopBody;
		NI T177_;
		T138_ = ((*tracked).init ? (*tracked).init->Sup.len : 0);
		oldState_2 = T138_;
		T139_ = ((*tracked).guards.s ? (*tracked).guards.s->Sup.len : 0);
		oldFacts_2 = T139_;
		T140_ = (NI)0;
		T140_ = len__ast_3155(n);
		iterCall = (*n)._kind_6.sons->data[(NI)(T140_ - ((NI) 2))];
		{
			NIM_BOOL T143_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* op;
			T143_ = (NIM_BOOL)0;
			T143_ = (((*tracked).currOptions &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 9))&31U)))!=0);
			if (!(T143_)) goto LA144_;
			T143_ = ((*iterCall).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*iterCall).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29) || (*iterCall).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30) || (*iterCall).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31) || (*iterCall).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) || (*iterCall).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28) || (*iterCall).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32));
			LA144_: ;
			if (!T143_) goto LA145_;
			op = (*iterCall)._kind_6.sons->data[((NI) 0)];
			{
				NIM_BOOL T149_;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* iterVar;
				T149_ = (NIM_BOOL)0;
				T149_ = ((*op).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
				if (!(T149_)) goto LA150_;
				T149_ = fromSystem__astalgo_238((*op)._kind_4.sym);
				LA150_: ;
				if (!T149_) goto LA151_;
				iterVar = (*n)._kind_6.sons->data[((NI) 0)];
				if (eqStrings((*(*(*op)._kind_4.sym).name).s, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_61))) goto LA153_;
				if (eqStrings((*(*(*op)._kind_4.sym).name).s, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_62))) goto LA153_;
				if (eqStrings((*(*(*op)._kind_4.sym).name).s, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_63))) goto LA153_;
				if (eqStrings((*(*(*op)._kind_4.sym).name).s, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_64))) goto LA154_;
				goto LA155_;
				LA153_: ;
				{
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lower;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* upper;
					lower = (*iterCall)._kind_6.sons->data[((NI) 1)];
					upper = (*iterCall)._kind_6.sons->data[((NI) 2)];
					addFactLe__guards_1643((&(*tracked).guards), lower, iterVar);
					addFactLe__guards_1643((&(*tracked).guards), iterVar, upper);
				}
				goto LA156_;
				LA154_: ;
				{
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lower_2;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* upper_2;
					lower_2 = (*iterCall)._kind_6.sons->data[((NI) 1)];
					upper_2 = (*iterCall)._kind_6.sons->data[((NI) 2)];
					addFactLe__guards_1643((&(*tracked).guards), lower_2, iterVar);
					addFactLt__guards_1651((&(*tracked).guards), iterVar, upper_2);
				}
				goto LA156_;
				LA155_: ;
				{
				}
				LA156_: ;
			}
			LA151_: ;
		}
		LA145_: ;
		{
			NI i_15;
			NI colontmp__8;
			NI T161_;
			NI i_16;
			i_15 = (NI)0;
			colontmp__8 = (NI)0;
			T161_ = (NI)0;
			T161_ = len__ast_3155(n);
			colontmp__8 = (NI)(T161_ - ((NI) 2));
			i_16 = ((NI) 0);
			{
				while (1) {
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
					if (!(i_16 < colontmp__8)) goto LA163;
					i_15 = i_16;
					it = (*n)._kind_6.sons->data[i_15];
					track__sempass50_2338(tracked, it);
					{
						if (!!(((*(*tracked).owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 17)))) goto LA166_;
						{
							if (!((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 36))) goto LA170_;
							{
								tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x;
								x = NIM_NIL;
								{
									NI i_17;
									NI colontmp__9;
									NI i_18;
									i_17 = (NI)0;
									colontmp__9 = (NI)0;
									colontmp__9 = safeLen__ast_3148(it);
									i_18 = ((NI) 0);
									{
										while (1) {
											if (!(i_18 < colontmp__9)) goto LA175;
											i_17 = i_18;
											x = (*it)._kind_6.sons->data[i_17];
											createTypeBoundOps__sempass50_142(tracked, (*x).typ, (*x).info);
											i_18 += ((NI) 1);
										} LA175: ;
									}
								}
							}
						}
						goto LA168_;
						LA170_: ;
						{
							createTypeBoundOps__sempass50_142(tracked, (*it).typ, (*it).info);
						}
						LA168_: ;
					}
					LA166_: ;
					i_16 += ((NI) 1);
				} LA163: ;
			}
		}
		T177_ = (NI)0;
		T177_ = len__ast_3155(n);
		loopBody = (*n)._kind_6.sons->data[(NI)(T177_ - ((NI) 1))];
		{
			NIM_BOOL T180_;
			NI T182_;
			T180_ = (NIM_BOOL)0;
			T180_ = !(((*(*tracked).owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 17)));
			if (!(T180_)) goto LA181_;
			T182_ = (NI)0;
			T182_ = safeLen__ast_3148(iterCall);
			T180_ = (((NI) 1) < T182_);
			LA181_: ;
			if (!T180_) goto LA183_;
			{
				NIM_BOOL T187_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T189_;
				T187_ = (NIM_BOOL)0;
				T187_ = !(((*(*iterCall)._kind_6.sons->data[((NI) 1)]).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
				if (!(T187_)) goto LA188_;
				T189_ = NIM_NIL;
				T189_ = skipTypes__ast_3723((*(*iterCall)._kind_6.sons->data[((NI) 1)]).typ, TM__O8rpA4QnF63fyis4dAzZxA_23);
				T187_ = !(((*T189_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 48) || (*T189_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27)));
				LA188_: ;
				if (!T187_) goto LA190_;
				createTypeBoundOps__sempass50_142(tracked, (*(*iterCall)._kind_6.sons->data[((NI) 1)]).typ, (*(*iterCall)._kind_6.sons->data[((NI) 1)]).info);
			}
			LA190_: ;
		}
		LA183_: ;
		track__sempass50_2338(tracked, iterCall);
		track__sempass50_2338(tracked, loopBody);
		unsureAsgnRef((void**) (&(*tracked).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) setLengthSeqV2(((*tracked).init)?&((*tracked).init)->Sup:NIM_NIL, (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_), ((NI) (oldState_2))));
		unsureAsgnRef((void**) (&(*tracked).guards.s), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) setLengthSeqV2(((*tracked).guards.s)?&((*tracked).guards.s)->Sup:NIM_NIL, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) (oldFacts_2))));
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 38):
	{
		NI oldFacts_3;
		NI T193_;
		T193_ = ((*tracked).guards.s ? (*tracked).guards.s->Sup.len : 0);
		oldFacts_3 = T193_;
		{
			NI i_19;
			NI colontmp__10;
			NI i_20;
			i_19 = (NI)0;
			colontmp__10 = (NI)0;
			colontmp__10 = len__ast_3155(n);
			i_20 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x_2;
					if (!(i_20 < colontmp__10)) goto LA196;
					i_19 = i_20;
					x_2 = (*n)._kind_6.sons->data[i_19];
					track__sempass50_2338(tracked, x_2);
					{
						NIM_BOOL T199_;
						T199_ = (NIM_BOOL)0;
						T199_ = ((*(*x_2)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
						if (!(T199_)) goto LA200_;
						T199_ = (((*(*(*x_2)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 20))&63U)))!=0);
						LA200_: ;
						if (!T199_) goto LA201_;
						addDiscriminantFact__guards_1726((&(*tracked).guards), x_2);
					}
					LA201_: ;
					{
						if (!!(((*(*tracked).owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 17)))) goto LA205_;
						createTypeBoundOps__sempass50_142(tracked, (*(*x_2)._kind_6.sons->data[((NI) 1)]).typ, (*n).info);
					}
					LA205_: ;
					{
						if (!((*x_2).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34))) goto LA209_;
						{
							if (!((*(*x_2)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA213_;
							notNilCheck__sempass50_2668(tracked, (*x_2)._kind_6.sons->data[((NI) 1)], (*(*(*x_2)._kind_6.sons->data[((NI) 0)])._kind_4.sym).typ);
						}
						LA213_: ;
						checkForSink__sempass50_24((*tracked).config, (*(*tracked).c).Sup.idgen, (*tracked).owner, (*x_2)._kind_6.sons->data[((NI) 1)]);
					}
					goto LA207_;
					LA209_: ;
					{
						checkForSink__sempass50_24((*tracked).config, (*(*tracked).c).Sup.idgen, (*tracked).owner, x_2);
					}
					LA207_: ;
					i_20 += ((NI) 1);
				} LA196: ;
			}
		}
		unsureAsgnRef((void**) (&(*tracked).guards.s), (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) setLengthSeqV2(((*tracked).guards.s)?&((*tracked).guards.s)->Sup:NIM_NIL, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_), ((NI) (oldFacts_3))));
		{
			if (!!(((*(*tracked).owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 17)))) goto LA218_;
			{
				NIM_BOOL T222_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T224_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T227_;
				T222_ = (NIM_BOOL)0;
				T222_ = !(((*n).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
				if (!(T222_)) goto LA223_;
				T224_ = NIM_NIL;
				T224_ = skipTypes__ast_3723((*n).typ, TM__O8rpA4QnF63fyis4dAzZxA_30);
				T222_ = ((*T224_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22));
				LA223_: ;
				if (!T222_) goto LA225_;
				T227_ = NIM_NIL;
				T227_ = lastSon__ast_3731((*n).typ);
				createTypeBoundOps__sempass50_142(tracked, T227_, (*n).info);
			}
			LA225_: ;
			createTypeBoundOps__sempass50_142(tracked, (*n).typ, (*n).info);
		}
		LA218_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 160):
	{
		{
			NI i_21;
			NI colontmp__11;
			NI i_22;
			i_21 = (NI)0;
			colontmp__11 = (NI)0;
			colontmp__11 = len__ast_3155(n);
			i_22 = ((NI) 0);
			{
				while (1) {
					if (!(i_22 < colontmp__11)) goto LA231;
					i_21 = i_22;
					track__sempass50_2338(tracked, (*n)._kind_6.sons->data[i_21]);
					{
						if (!!(((*(*tracked).owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 17)))) goto LA234_;
						{
							if (!((*(*n)._kind_6.sons->data[i_21]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34))) goto LA238_;
							createTypeBoundOps__sempass50_142(tracked, (*(*(*n)._kind_6.sons->data[i_21])._kind_6.sons->data[((NI) 0)]).typ, (*n).info);
						}
						goto LA236_;
						LA238_: ;
						{
							createTypeBoundOps__sempass50_142(tracked, (*(*n)._kind_6.sons->data[i_21]).typ, (*n).info);
						}
						LA236_: ;
					}
					LA234_: ;
					checkForSink__sempass50_24((*tracked).config, (*(*tracked).c).Sup.idgen, (*tracked).owner, (*n)._kind_6.sons->data[i_21]);
					i_22 += ((NI) 1);
				} LA231: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 91):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pragmaList;
		tyObject_PragmaBlockContext__KenhkbpTaL6MY9cFJ0RV2bA bc;
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T250_;
		pragmaList = (*n)._kind_6.sons->data[((NI) 0)];
		nimZeroMem((void*)(&bc), sizeof(tyObject_PragmaBlockContext__KenhkbpTaL6MY9cFJ0RV2bA));
		createBlockContext__sempass50_3750(tracked, (&bc));
		{
			NI i_23;
			NI colontmp__12;
			NI i_24;
			i_23 = (NI)0;
			colontmp__12 = (NI)0;
			colontmp__12 = len__ast_3155(pragmaList);
			i_24 = ((NI) 0);
			{
				while (1) {
					tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw pragma;
					if (!(i_24 < colontmp__12)) goto LA244;
					i_23 = i_24;
					pragma = whichPragma__trees_244((*pragmaList)._kind_6.sons->data[i_23]);
					switch (pragma) {
					case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 222):
					{
						lockLocations__sempass50_206(tracked, (*pragmaList)._kind_6.sons->data[i_23]);
					}
					break;
					case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 110):
					{
						bc.enforcedGcSafety = NIM_TRUE;
					}
					break;
					case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 109):
					{
						bc.enforceNoSideEffects = NIM_TRUE;
					}
					break;
					case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 9):
					{
						castBlock__sempass50_3799(tracked, (*(*pragmaList)._kind_6.sons->data[i_23])._kind_6.sons->data[((NI) 1)], (&bc));
					}
					break;
					default:
					{
					}
					break;
					}
					i_24 += ((NI) 1);
				} LA244: ;
			}
		}
		applyBlockContext__sempass50_3771(tracked, (&bc));
		T250_ = NIM_NIL;
		T250_ = lastSon__ast_4833(n);
		track__sempass50_2338(tracked, T250_);
		unapplyBlockContext__sempass50_3774(tracked, (&bc));
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 79):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 81):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 80):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 84):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 51):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 159):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 52):
	{
		{
			NIM_BOOL T254_;
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T258_;
			T254_ = (NIM_BOOL)0;
			T254_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
			if (!(T254_)) goto LA255_;
			T254_ = !(((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).ast == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
			LA255_: ;
			if (!T254_) goto LA256_;
			T258_ = NIM_NIL;
			T258_ = getBody__modulegraphs_13094((*tracked).graph, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
			trackInnerProc__sempass50_3823(tracked, T258_);
		}
		LA256_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 98):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 82):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 83):
	{
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 61):
	{
		{
			NI T263_;
			T263_ = (NI)0;
			T263_ = len__ast_3155(n);
			if (!(T263_ == ((NI) 2))) goto LA264_;
			track__sempass50_2338(tracked, (*n)._kind_6.sons->data[((NI) 1)]);
			{
				if (!!(((*(*tracked).owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 17)))) goto LA268_;
				createTypeBoundOps__sempass50_142(tracked, (*n).typ, (*n).info);
			}
			LA268_: ;
		}
		LA264_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 60):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
		{
			NIM_BOOL T273_;
			NIM_BOOL T274_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T276_;
			NIM_BOOL T278_;
			NimStringDesc* T281_;
			NimStringDesc* T282_;
			T273_ = (NIM_BOOL)0;
			T274_ = (NIM_BOOL)0;
			T274_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59));
			if (!(T274_)) goto LA275_;
			T276_ = NIM_NIL;
			T276_ = skipTypes__ast_3723((*n).typ, TM__O8rpA4QnF63fyis4dAzZxA_30);
			T274_ = ((*T276_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29));
			LA275_: ;
			T273_ = T274_;
			if (!(T273_)) goto LA277_;
			T278_ = (NIM_BOOL)0;
			T278_ = allowCStringConv__sempass50_3865((*n)._kind_6.sons->data[((NI) 1)]);
			T273_ = !(T278_);
			LA277_: ;
			if (!T273_) goto LA279_;
			T281_ = NIM_NIL;
			T281_ = dollar___renderer_2116((*n)._kind_6.sons->data[((NI) 1)]);
			T282_ = NIM_NIL;
			T282_ = nsuFormatSingleElem(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_75), T281_);
			liMessage__msgs_1128((*tracked).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 66), T282_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_76, NIM_FALSE);
		}
		LA279_: ;
		{
			NIM_BOOL T285_;
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T286_;
			NimStringDesc* T290_;
			T285_ = (NIM_BOOL)0;
			T286_ = NIM_NIL;
			T286_ = skipTypes__ast_3723((*n).typ, TM__O8rpA4QnF63fyis4dAzZxA_30);
			T285_ = ((*T286_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29));
			if (!(T285_)) goto LA287_;
			T285_ = isCharArrayPtr__types_4177((*(*n)._kind_6.sons->data[((NI) 1)]).typ, NIM_TRUE);
			LA287_: ;
			if (!T285_) goto LA288_;
			T290_ = NIM_NIL;
			T290_ = typeToString__types_50((*(*n)._kind_6.sons->data[((NI) 1)]).typ, ((tyEnum_TPreferedDesc__lx9aDnWjKktcSUo0yfjOvMg) 0));
			liMessage__msgs_1128((*tracked).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 67), T290_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_77, NIM_FALSE);
		}
		LA288_: ;
		t = skipTypes__ast_3723((*n).typ, TM__O8rpA4QnF63fyis4dAzZxA_30);
		{
			if (!((*t).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14))) goto LA293_;
			{
				NimStringDesc* T299_;
				NimStringDesc* T300_;
				if (!(((*t).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 5))&63U)))!=0)) goto LA297_;
				T299_ = NIM_NIL;
				T299_ = dollar___renderer_2116(n);
				T300_ = NIM_NIL;
				T300_ = nsuFormatSingleElem(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_78), T299_);
				liMessage__msgs_1128((*tracked).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 65), T300_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_79, NIM_FALSE);
			}
			goto LA295_;
			LA297_: ;
			{
				NimStringDesc* T302_;
				NimStringDesc* T303_;
				T302_ = NIM_NIL;
				T302_ = dollar___renderer_2116(n);
				T303_ = NIM_NIL;
				T303_ = nsuFormatSingleElem(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_80), T302_);
				liMessage__msgs_1128((*tracked).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 64), T303_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_81, NIM_FALSE);
			}
			LA295_: ;
		}
		LA293_: ;
		{
			NI T306_;
			T306_ = (NI)0;
			T306_ = len__ast_3155(n);
			if (!(T306_ == ((NI) 2))) goto LA307_;
			track__sempass50_2338(tracked, (*n)._kind_6.sons->data[((NI) 1)]);
			{
				if (!!(((*(*tracked).owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 17)))) goto LA311_;
				createTypeBoundOps__sempass50_142(tracked, (*n).typ, (*n).info);
				{
					if (!!(((*(*(*n)._kind_6.sons->data[((NI) 1)]).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28)))) goto LA315_;
					createTypeBoundOps__sempass50_142(tracked, (*(*n)._kind_6.sons->data[((NI) 1)]).typ, (*(*n)._kind_6.sons->data[((NI) 1)]).info);
				}
				LA315_: ;
			}
			LA311_: ;
			{
				if (!(((*tracked).currOptions &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 9))&31U)))!=0)) goto LA319_;
				checkRange__sempass50_3359(tracked, (*n)._kind_6.sons->data[((NI) 1)], (*n).typ);
			}
			LA319_: ;
		}
		LA307_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 67):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 66):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 70):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 68):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 69):
	{
		{
			NI T324_;
			T324_ = (NI)0;
			T324_ = len__ast_3155(n);
			if (!(T324_ == ((NI) 1))) goto LA325_;
			track__sempass50_2338(tracked, (*n)._kind_6.sons->data[((NI) 0)]);
			{
				if (!!(((*(*tracked).owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 17)))) goto LA329_;
				createTypeBoundOps__sempass50_142(tracked, (*n).typ, (*n).info);
				createTypeBoundOps__sempass50_142(tracked, (*(*n)._kind_6.sons->data[((NI) 0)]).typ, (*(*n)._kind_6.sons->data[((NI) 0)]).info);
			}
			LA329_: ;
			{
				if (!(((*tracked).currOptions &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 9))&31U)))!=0)) goto LA333_;
				checkRange__sempass50_3359(tracked, (*n)._kind_6.sons->data[((NI) 0)], (*n).typ);
			}
			LA333_: ;
		}
		LA325_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41):
	{
		{
			NI i_25;
			NI colontmp__13;
			NI i_26;
			i_25 = (NI)0;
			colontmp__13 = (NI)0;
			colontmp__13 = safeLen__ast_3148(n);
			i_26 = ((NI) 0);
			{
				while (1) {
					if (!(i_26 < colontmp__13)) goto LA338;
					i_25 = i_26;
					track__sempass50_2338(tracked, (*n)._kind_6.sons->data[i_25]);
					checkForSink__sempass50_24((*tracked).config, (*(*tracked).c).Sup.idgen, (*tracked).owner, (*n)._kind_6.sons->data[i_25]);
					i_26 += ((NI) 1);
				} LA338: ;
			}
		}
		{
			if (!!(((*(*tracked).owner).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 17)))) goto LA341_;
			createTypeBoundOps__sempass50_142(tracked, (*n).typ, (*n).info);
		}
		LA341_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42):
	{
		{
			NIM_BOOL T346_;
			NI T348_;
			T346_ = (NIM_BOOL)0;
			T346_ = (((*tracked).currOptions &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 9))&31U)))!=0);
			if (!(T346_)) goto LA347_;
			T348_ = (NI)0;
			T348_ = len__ast_3155(n);
			T346_ = (T348_ == ((NI) 2));
			LA347_: ;
			if (!T346_) goto LA349_;
			{
				NIM_BOOL T353_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T355_;
				T353_ = (NIM_BOOL)0;
				T353_ = !(((*(*n)._kind_6.sons->data[((NI) 0)]).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
				if (!(T353_)) goto LA354_;
				T355_ = NIM_NIL;
				T355_ = skipTypes__ast_3723((*(*n)._kind_6.sons->data[((NI) 0)]).typ, TM__O8rpA4QnF63fyis4dAzZxA_23);
				T353_ = !(((*T355_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18)));
				LA354_: ;
				if (!T353_) goto LA356_;
				checkBounds__sempass50_3355(tracked, (*n)._kind_6.sons->data[((NI) 0)], (*n)._kind_6.sons->data[((NI) 1)]);
			}
			LA356_: ;
		}
		LA349_: ;
		track__sempass50_2338(tracked, (*n)._kind_6.sons->data[((NI) 0)]);
		(*tracked).leftPartOfAsgn -= ((NI) 1);
		{
			NI i_27;
			NI colontmp__14;
			NI i_28;
			i_27 = (NI)0;
			colontmp__14 = (NI)0;
			colontmp__14 = len__ast_3155(n);
			i_28 = ((NI) 1);
			{
				while (1) {
					if (!(i_28 < colontmp__14)) goto LA360;
					i_27 = i_28;
					track__sempass50_2338(tracked, (*n)._kind_6.sons->data[i_27]);
					i_28 += ((NI) 1);
				} LA360: ;
			}
		}
		(*tracked).leftPartOfAsgn += ((NI) 1);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 161):
	{
		NimStringDesc* T362_;
		T362_ = NIM_NIL;
		T362_ = errorToString__errorhandling_107((*tracked).config, n);
		liMessage__msgs_1128((*tracked).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T362_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_83, NIM_FALSE);
	}
	break;
	default:
	{
		{
			NI i_29;
			NI colontmp__15;
			NI i_30;
			i_29 = (NI)0;
			colontmp__15 = (NI)0;
			colontmp__15 = safeLen__ast_3148(n);
			i_30 = ((NI) 0);
			{
				while (1) {
					if (!(i_30 < colontmp__15)) goto LA366;
					i_29 = i_30;
					track__sempass50_2338(tracked, (*n)._kind_6.sons->data[i_29]);
					i_30 += ((NI) 1);
				} LA366: ;
			}
		}
	}
	break;
	}
}
static N_INLINE(NIM_BOOL, isClosure__ast_5031)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25));
	if (!(T1_)) goto LA2_;
	T1_ = ((*typ).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, patchResult__sempass50_3317)(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NIM_BOOL T3_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* fn;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 11));
		LA4_: ;
		if (!T3_) goto LA5_;
		fn = (*c).owner;
		{
			NIM_BOOL T9_;
			NIM_BOOL T10_;
			NIM_BOOL T11_;
			NI T15_;
			T9_ = (NIM_BOOL)0;
			T10_ = (NIM_BOOL)0;
			T11_ = (NIM_BOOL)0;
			T11_ = !((fn == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
			if (!(T11_)) goto LA12_;
			T11_ = ((520192 &((NU32)1<<((NU)((*fn).kind)&31U)))!=0);
			LA12_: ;
			T10_ = T11_;
			if (!(T10_)) goto LA13_;
			T10_ = !(((*fn).ast == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
			LA13_: ;
			T9_ = T10_;
			if (!(T9_)) goto LA14_;
			T15_ = (NI)0;
			T15_ = len__ast_3155((*fn).ast);
			T9_ = (((NI) 7) < T15_);
			LA14_: ;
			if (!T9_) goto LA16_;
			asgnRef((void**) (&(*n)._kind_4.sym), (*(*(*fn).ast)._kind_6.sons->data[((NI) 7)])._kind_4.sym);
		}
		goto LA7_;
		LA16_: ;
		{
			liMessage__msgs_1128((*c).config, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_87), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_88, NIM_FALSE);
		}
		LA7_: ;
	}
	goto LA1_;
	LA5_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA22;
					i = i_2;
					patchResult__sempass50_3317(c, (*n)._kind_6.sons->data[i]);
					i_2 += ((NI) 1);
				} LA22: ;
			}
		}
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, listGcUnsafety__sempass50_386)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NIM_BOOL onlyWarning, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* cycleCheck, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* u;
	u = (*s)._kind_1.gcUnsafetyReason;
	{
		NIM_BOOL T3_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym63_;
		NIM_BOOL T5_;
		tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msgKind;
		T3_ = (NIM_BOOL)0;
		T3_ = !((u == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		xX60gensym63_ = u;
		T5_ = (NIM_BOOL)0;
		T5_ = containsOrIncl__astalgo_402(cycleCheck, (NI)((NI)((NU64)(((NI) ((*xX60gensym63_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym63_).Sup.itemId.item))));
		T3_ = !(T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		{
			if (!onlyWarning) goto LA10_;
			msgKind = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 49);
		}
		goto LA8_;
		LA10_: ;
		{
			msgKind = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15);
		}
		LA8_: ;
		switch ((*u).kind) {
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 9):
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8):
		{
			{
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T16_;
				tyArray__Re75IspeoxXy2oCZHwcRrA T19_;
				NimStringDesc* T20_;
				T16_ = NIM_NIL;
				T16_ = skipTypes__ast_3723((*u).typ, TM__O8rpA4QnF63fyis4dAzZxA_30);
				if (!((*T16_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25))) goto LA17_;
				nimZeroMem((void*)T19_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T19_[0] = copyString((*(*s).name).s);
				T19_[1] = copyString((*(*u).name).s);
				T20_ = NIM_NIL;
				T20_ = nsuFormatOpenArray(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_89), T19_, 2);
				liMessage__msgs_1128(conf, (*s).info, msgKind, T20_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_90, NIM_FALSE);
			}
			goto LA14_;
			LA17_: ;
			{
				tyArray__Re75IspeoxXy2oCZHwcRrA T22_;
				NimStringDesc* T23_;
				nimZeroMem((void*)T22_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T22_[0] = copyString((*(*s).name).s);
				T22_[1] = copyString((*(*u).name).s);
				T23_ = NIM_NIL;
				T23_ = nsuFormatOpenArray(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_91), T22_, 2);
				liMessage__msgs_1128(conf, (*s).info, msgKind, T23_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_92, NIM_FALSE);
			}
			LA14_: ;
		}
		break;
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 12) ... ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 18):
		{
			tyArray__Re75IspeoxXy2oCZHwcRrA T25_;
			NimStringDesc* T26_;
			listGcUnsafety__sempass50_386(u, NIM_TRUE, cycleCheck, conf);
			nimZeroMem((void*)T25_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T25_[0] = copyString((*(*s).name).s);
			T25_[1] = copyString((*(*u).name).s);
			T26_ = NIM_NIL;
			T26_ = nsuFormatOpenArray(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_89), T25_, 2);
			liMessage__msgs_1128(conf, (*s).info, msgKind, T26_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_93, NIM_FALSE);
		}
		break;
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3):
		case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 21):
		{
			tyArray__Re75IspeoxXy2oCZHwcRrA T28_;
			NimStringDesc* T29_;
			nimZeroMem((void*)T28_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T28_[0] = copyString((*(*s).name).s);
			T28_[1] = copyString((*(*u).name).s);
			T29_ = NIM_NIL;
			T29_ = nsuFormatOpenArray(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_94), T28_, 2);
			liMessage__msgs_1128(conf, (*s).info, msgKind, T29_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_95, NIM_FALSE);
		}
		break;
		default:
		{
			NimStringDesc* T31_;
			T31_ = NIM_NIL;
			T31_ = nsuFormatSingleElem(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_96), (*(*s).name).s);
			liMessage__msgs_1128(conf, (*u).info, msgKind, T31_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_97, NIM_FALSE);
		}
		break;
		}
	}
	LA6_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, listGcUnsafety__sempass50_411)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, NIM_BOOL onlyWarning, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw cycleCheck;
	nimZeroMem((void*)(&cycleCheck), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
	initIntSet__pureZcollectionsZintsets_238((&cycleCheck));
	listGcUnsafety__sempass50_386(s, onlyWarning, (&cycleCheck), conf);
}
N_LIB_PRIVATE N_NIMCALL(void, listSideEffects__sempass50_416)(NimStringDesc** result, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* cycleCheck, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* context, NI indentLevel) {
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym74_;
		NIM_BOOL T3_;
		xX60gensym74_ = s;
		T3_ = (NIM_BOOL)0;
		T3_ = hasKey__sempass50_484((*context).sideEffects, (NI)((NI)((NU64)(((NI) ((*xX60gensym74_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym74_).Sup.itemId.item))));
		if (!T3_) goto LA4_;
		{
			tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw* useLineInfo;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw** u;
			tySequence__k7EQb9bN3Uhl608xoPGMRJA* colontmp_;
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym77_;
			tySequence__k7EQb9bN3Uhl608xoPGMRJA** T7_;
			NI i;
			NI L;
			NI T8_;
			useLineInfo = (tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw*)0;
			u = (tyObject_TSym__3r34mwqcVmg5JFNmiaVncw**)0;
			colontmp_ = NIM_NIL;
			xX60gensym77_ = s;
			T7_ = (tySequence__k7EQb9bN3Uhl608xoPGMRJA**)0;
			T7_ = X5BX5D___sempass50_821((&(*context).sideEffects), (NI)((NI)((NU64)(((NI) ((*xX60gensym77_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym77_).Sup.itemId.item))));
			colontmp_ = (*T7_);
			i = ((NI) 0);
			T8_ = (colontmp_ ? colontmp_->Sup.len : 0);
			L = T8_;
			{
				while (1) {
					if (!(i < L)) goto LA10;
					useLineInfo = (&colontmp_->data[i].Field0);
					u = &colontmp_->data[i].Field1;
					{
						NIM_BOOL T13_;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym81_;
						NIM_BOOL T15_;
						T13_ = (NIM_BOOL)0;
						T13_ = !(((*u) == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
						if (!(T13_)) goto LA14_;
						xX60gensym81_ = (*u);
						T15_ = (NIM_BOOL)0;
						T15_ = containsOrIncl__astalgo_402(cycleCheck, (NI)((NI)((NU64)(((NI) ((*xX60gensym81_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym81_).Sup.itemId.item))));
						T13_ = !(T15_);
						LA14_: ;
						if (!T13_) goto LA16_;
						switch ((*(*u)).kind) {
						case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 9):
						case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 8):
						{
							tyArray__sMpvt1sOxOJ3LFGulnbeMQ T19_;
							tyArray__sMpvt1sOxOJ3LFGulnbeMQ T20_;
							nimZeroMem((void*)T19_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
							T19_[0] = nsuRepeatStr(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_102), ((NI) (indentLevel)));
							T19_[1] = dollar___msgs_634(conf, (*useLineInfo));
							T19_[2] = copyString((*(*s).name).s);
							T19_[3] = nsuFormatSingleElem(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_103), (*(*(*u)).name).s);
							nsuAddf(result, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_101), T19_, 4);
							nimZeroMem((void*)T20_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
							T20_[0] = nsuRepeatStr(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_102), ((NI) ((NI)(indentLevel + ((NI) 1)))));
							T20_[1] = dollar___msgs_634(conf, (*(*u)).info);
							T20_[2] = copyString((*(*(*u)).name).s);
							T20_[3] = nsuFormatSingleElem(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_104), (*(*s).name).s);
							nsuAddf(result, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_101), T20_, 4);
						}
						break;
						case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 12) ... ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 18):
						{
							tyArray__sMpvt1sOxOJ3LFGulnbeMQ T22_;
							tyArray__sMpvt1sOxOJ3LFGulnbeMQ T23_;
							nimZeroMem((void*)T22_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
							T22_[0] = nsuRepeatStr(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_102), ((NI) (indentLevel)));
							T22_[1] = dollar___msgs_634(conf, (*useLineInfo));
							T22_[2] = copyString((*(*s).name).s);
							T22_[3] = nsuFormatSingleElem(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_105), (*(*(*u)).name).s);
							nsuAddf(result, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_101), T22_, 4);
							nimZeroMem((void*)T23_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
							T23_[0] = nsuRepeatStr(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_102), ((NI) ((NI)(indentLevel + ((NI) 1)))));
							T23_[1] = dollar___msgs_634(conf, (*(*u)).info);
							T23_[2] = copyString((*(*(*u)).name).s);
							T23_[3] = nsuFormatSingleElem(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_106), (*(*s).name).s);
							nsuAddf(result, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_101), T23_, 4);
							listSideEffects__sempass50_416(result, (*u), cycleCheck, conf, context, (NI)(indentLevel + ((NI) 2)));
						}
						break;
						case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3):
						case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 21):
						{
							tyArray__sMpvt1sOxOJ3LFGulnbeMQ T25_;
							nimZeroMem((void*)T25_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
							T25_[0] = nsuRepeatStr(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_102), ((NI) (indentLevel)));
							T25_[1] = dollar___msgs_634(conf, (*useLineInfo));
							T25_[2] = copyString((*(*s).name).s);
							T25_[3] = copyString(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_107));
							nsuAddf(result, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_101), T25_, 4);
						}
						break;
						default:
						{
							tyArray__sMpvt1sOxOJ3LFGulnbeMQ T27_;
							nimZeroMem((void*)T27_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
							T27_[0] = nsuRepeatStr(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_102), ((NI) (indentLevel)));
							T27_[1] = dollar___msgs_634(conf, (*useLineInfo));
							T27_[2] = copyString((*(*s).name).s);
							T27_[3] = copyString(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_108));
							nsuAddf(result, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_101), T27_, 4);
						}
						break;
						}
					}
					LA16_: ;
					i += ((NI) 1);
				} LA10: ;
			}
		}
	}
	LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, listSideEffects__sempass50_953)(NimStringDesc** result, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* context) {
	tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw cycleCheck;
	tyArray__nHXaesL0DJZHyVS07ARPRA T1_;
	nimZeroMem((void*)(&cycleCheck), sizeof(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw));
	initIntSet__pureZcollectionsZintsets_238((&cycleCheck));
	nimZeroMem((void*)T1_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
	T1_[0] = copyString((*(*s).name).s);
	nsuAddf(result, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_100), T1_, 1);
	listSideEffects__sempass50_416(result, s, (&cycleCheck), conf, context, ((NI) 1));
}
N_LIB_PRIVATE N_NIMCALL(void, trackProc__sempass50_4721)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body) {
	tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* effects;
	NIM_BOOL emitWarnings;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* inferredEffects;
	tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ t;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* p;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* raisesSpec;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* tagsSpec;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* requiresSpec;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ensuresSpec;
	tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ mutationInfo;
	NIM_BOOL hasMutationSideEffect;
{	g = (*c).graph;
	effects = (*(*(*s).typ).n)._kind_6.sons->data[((NI) 0)];
	{
		if (!!(((*effects).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = hasRealBody__sempass50_4710(s);
		if (!!(T7_)) goto LA8_;
		goto BeforeRet_;
	}
	LA8_: ;
	emitWarnings = (((*(*s).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 44))&63U)))!=0);
	{
		NIM_BOOL T12_;
		NI T13_;
		T12_ = (NIM_BOOL)0;
		T13_ = (NI)0;
		T13_ = len__ast_3155(effects);
		T12_ = (T13_ == ((NI) 5));
		if (!(T12_)) goto LA14_;
		T12_ = !(emitWarnings);
		LA14_: ;
		if (!T12_) goto LA15_;
		goto BeforeRet_;
	}
	LA15_: ;
	inferredEffects = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152), (*s).info);
	nimZeroMem((void*)(&t), sizeof(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ));
	initEffects__sempass50_4673(g, inferredEffects, s, (&t), c);
	rawInitEffects__sempass50_4661(g, effects);
	track__sempass50_2338((&t), body);
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* params;
		if (!!(((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 17)))) goto LA19_;
		params = (*(*s).typ).n;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(params);
			i_2 = ((NI) 1);
			{
				while (1) {
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* param;
					tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
					if (!(i_2 < colontmp_)) goto LA23;
					i = i_2;
					param = (*(*params)._kind_6.sons->data[i])._kind_4.sym;
					typ = (*param).typ;
					{
						NIM_BOOL T26_;
						NIM_BOOL T28_;
						NIM_BOOL T30_;
						tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T31_;
						tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym578_;
						T26_ = (NIM_BOOL)0;
						T26_ = isSinkTypeForParam__types_4145(typ);
						if (T26_) goto LA27_;
						T28_ = (NIM_BOOL)0;
						T28_ = ((48 &((NU16)1<<((NU)((*t.config).selectedGC)&15U)))!=0);
						if (!(T28_)) goto LA29_;
						T30_ = (NIM_BOOL)0;
						T31_ = NIM_NIL;
						T31_ = skipTypes__ast_3723(typ, TM__O8rpA4QnF63fyis4dAzZxA_30);
						T30_ = isClosure__ast_5031(T31_);
						if (T30_) goto LA32_;
						xX60gensym578_ = param;
						T30_ = contains__astalgo_3489((&t.escapingParams), (NI)((NI)((NU64)(((NI) ((*xX60gensym578_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym578_).Sup.itemId.item))));
						LA32_: ;
						T28_ = T30_;
						LA29_: ;
						T26_ = T28_;
						LA27_: ;
						if (!T26_) goto LA33_;
						createTypeBoundOps__sempass50_142((&t), typ, (*param).info);
					}
					LA33_: ;
					i_2 += ((NI) 1);
				} LA23: ;
			}
		}
	}
	LA19_: ;
	{
		NIM_BOOL T37_;
		NIM_BOOL T38_;
		NIM_BOOL T39_;
		NIM_BOOL T41_;
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T43_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* res;
		T37_ = (NIM_BOOL)0;
		T38_ = (NIM_BOOL)0;
		T39_ = (NIM_BOOL)0;
		T39_ = isEmptyType__ast_4780((*(*s).typ).sons->data[((NI) 0)]);
		T38_ = !(T39_);
		if (!(T38_)) goto LA40_;
		T41_ = (NIM_BOOL)0;
		T41_ = requiresInit__typeallowed_593((*(*s).typ).sons->data[((NI) 0)]);
		if (T41_) goto LA42_;
		T43_ = NIM_NIL;
		T43_ = skipTypes__ast_3723((*(*s).typ).sons->data[((NI) 0)], TM__O8rpA4QnF63fyis4dAzZxA_30);
		T41_ = ((*T43_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 23));
		LA42_: ;
		T38_ = T41_;
		LA40_: ;
		T37_ = T38_;
		if (!(T37_)) goto LA44_;
		T37_ = ((94208 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
		LA44_: ;
		if (!T37_) goto LA45_;
		res = (*(*(*s).ast)._kind_6.sons->data[((NI) 7)])._kind_4.sym;
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym585_;
			NIM_BOOL T49_;
			xX60gensym585_ = res;
			T49_ = (NIM_BOOL)0;
			T49_ = contains__sigmatch_4340((t.init) ? (t.init->data) : NIM_NIL, (t.init ? t.init->Sup.len : 0), (NI)((NI)((NU64)(((NI) ((*xX60gensym585_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym585_).Sup.itemId.item))));
			if (!!(T49_)) goto LA50_;
			liMessage__msgs_1128((*g).config, (*body).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 42), ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_84), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_85, NIM_FALSE);
		}
		LA50_: ;
	}
	LA45_: ;
	p = (*(*s).ast)._kind_6.sons->data[((NI) 4)];
	raisesSpec = effectSpec__trees_284(p, ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 174));
	{
		NIM_BOOL useWarning;
		if (!!((raisesSpec == 0))) goto LA54_;
		useWarning = eqStrings((*(*s).name).s, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_86));
		checkRaisesSpec__sempass50_4423(g, useWarning, raisesSpec, t.exc, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_7), NIM_TRUE, subtypeRelation__sempass50_4410, (*(*s).ast)._kind_6.sons->data[((NI) 0)]);
		asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 0)]), raisesSpec);
	}
	goto LA52_;
	LA54_: ;
	{
		asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 0)]), t.exc);
	}
	LA52_: ;
	tagsSpec = effectSpec__trees_284(p, ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 179));
	{
		if (!!((tagsSpec == 0))) goto LA59_;
		checkRaisesSpec__sempass50_4423(g, NIM_FALSE, tagsSpec, t.tags, ((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_10), NIM_FALSE, subtypeRelation__sempass50_4410, ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL));
		asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 3)]), tagsSpec);
	}
	goto LA57_;
	LA59_: ;
	{
		asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 3)]), t.tags);
	}
	LA57_: ;
	requiresSpec = propSpec__trees_316(p, ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 180));
	{
		if (!!((requiresSpec == 0))) goto LA64_;
		asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 1)]), requiresSpec);
	}
	LA64_: ;
	ensuresSpec = propSpec__trees_316(p, ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 181));
	{
		if (!!((ensuresSpec == 0))) goto LA68_;
		patchResult__sempass50_3317((&t), ensuresSpec);
		asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 2)]), ensuresSpec);
	}
	LA68_: ;
	nimZeroMem((void*)(&mutationInfo), sizeof(tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ));
	nimZeroMem((void*)(&mutationInfo), sizeof(tyObject_MutationInfo__gL2XNL3vfSXoqvlltP0JhQ));
	hasMutationSideEffect = NIM_FALSE;
	{
		tySet_tyEnum_Goal__YflPrGhMLgZ4bbrBBVpmOA goals;
		tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA partitions;
		if (!!(((12288 & (*c).features) == 0))) goto LA72_;
		goals = 0;
		{
			if (!(((*c).features &((NU32)1<<((NU)(((tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw) 12))&31U)))!=0)) goto LA76_;
			goals |= ((NU8)1)<<((((tyEnum_Goal__YflPrGhMLgZ4bbrBBVpmOA) 0)) & 7);
		}
		LA76_: ;
		{
			if (!(((*c).features &((NU32)1<<((NU)(((tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw) 13))&31U)))!=0)) goto LA80_;
			goals |= ((NU8)1)<<((((tyEnum_Goal__YflPrGhMLgZ4bbrBBVpmOA) 1)) & 7);
		}
		LA80_: ;
		nimZeroMem((void*)(&partitions), sizeof(tyObject_Partitions__dMkIy3kCXAfGJcQvBNQefA));
		computeGraphPartitions__varpartitions_1622(s, body, g, goals, (&partitions));
		{
			NIM_BOOL T84_;
			T84_ = (NIM_BOOL)0;
			T84_ = !(t.hasSideEffect);
			if (!(T84_)) goto LA85_;
			T84_ = t.hasDangerousAssign;
			LA85_: ;
			if (!T84_) goto LA86_;
			t.hasSideEffect = hasSideEffect__varpartitions_131((&partitions), (&mutationInfo));
			hasMutationSideEffect = t.hasSideEffect;
		}
		LA86_: ;
		{
			if (!(((*c).features &((NU32)1<<((NU)(((tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw) 13))&31U)))!=0)) goto LA90_;
			checkBorrowedLocations__varpartitions_1734((&partitions), body, (*g).config);
		}
		LA90_: ;
	}
	LA72_: ;
	{
		NIM_BOOL T94_;
		T94_ = (NIM_BOOL)0;
		T94_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 26))&63U)))!=0);
		if (!(T94_)) goto LA95_;
		T94_ = t.gcUnsafe;
		LA95_: ;
		if (!T94_) goto LA96_;
		{
			NIM_BOOL T100_;
			T100_ = (NIM_BOOL)0;
			T100_ = (((*(*g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 23))&63U)))!=0);
			if (!(T100_)) goto LA101_;
			T100_ = (((*(*g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 25))&63U)))!=0);
			LA101_: ;
			if (!T100_) goto LA102_;
			listGcUnsafety__sempass50_411(s, NIM_FALSE, (*g).config);
		}
		goto LA98_;
		LA102_: ;
		{
			listGcUnsafety__sempass50_411(s, NIM_TRUE, (*g).config);
		}
		LA98_: ;
	}
	LA96_: ;
	{
		NIM_BOOL T107_;
		T107_ = (NIM_BOOL)0;
		T107_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 12))&63U)))!=0);
		if (!(T107_)) goto LA108_;
		T107_ = t.hasSideEffect;
		LA108_: ;
		if (!T107_) goto LA109_;
		{
			tyArray__Re75IspeoxXy2oCZHwcRrA T115_;
			NimStringDesc* T116_;
			if (!hasMutationSideEffect) goto LA113_;
			nimZeroMem((void*)T115_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T115_[0] = copyString((*(*s).name).s);
			T115_[1] = dollar___varpartitions_108((*g).config, (&mutationInfo));
			T116_ = NIM_NIL;
			T116_ = nsuFormatOpenArray(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_98), T115_, 2);
			liMessage__msgs_1128((*g).config, (*s).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T116_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_99, NIM_FALSE);
		}
		goto LA111_;
		LA113_: ;
		{
			NimStringDesc* msg;
			if (!((*c).compilesContextId == ((NI) 0))) goto LA118_;
			msg = ((NimStringDesc*) NIM_NIL);
			listSideEffects__sempass50_953((&msg), s, (*g).config, t.c);
			liMessage__msgs_1128((*g).config, (*s).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), msg, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_109, NIM_FALSE);
		}
		goto LA111_;
		LA118_: ;
		{
			liMessage__msgs_1128((*g).config, (*s).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) NIM_NIL), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_110, NIM_FALSE);
		}
		LA111_: ;
	}
	LA109_: ;
	{
		if (!!(t.gcUnsafe)) goto LA123_;
		(*(*s).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 7)) & 63);
	}
	LA123_: ;
	{
		NIM_BOOL T127_;
		T127_ = (NIM_BOOL)0;
		T127_ = !(t.hasSideEffect);
		if (!(T127_)) goto LA128_;
		T127_ = !((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 13))&63U)))!=0));
		LA128_: ;
		if (!T127_) goto LA129_;
		(*(*s).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 1)) & 63);
	}
	LA129_: ;
	{
		if (!((*(*s).typ).lockLevel == ((NI16) -1))) goto LA133_;
		(*(*s).typ).lockLevel = t.maxLockLevel;
	}
	goto LA131_;
	LA133_: ;
	{
		tyArray__Re75IspeoxXy2oCZHwcRrA T138_;
		NimStringDesc* T139_;
		if (!((*(*s).typ).lockLevel < t.maxLockLevel)) goto LA136_;
		nimZeroMem((void*)T138_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
		T138_[0] = dollar___ast_3846((*(*s).typ).lockLevel);
		T138_[1] = dollar___ast_3846(t.maxLockLevel);
		T139_ = NIM_NIL;
		T139_ = nsuFormatOpenArray(((NimStringDesc*) &TM__O8rpA4QnF63fyis4dAzZxA_111), T138_, 2);
		liMessage__msgs_1128((*g).config, (*s).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 53), T139_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__O8rpA4QnF63fyis4dAzZxA_112, NIM_FALSE);
	}
	goto LA131_;
	LA136_: ;
	LA131_: ;
	{
		NIM_BOOL T142_;
		T142_ = (NIM_BOOL)0;
		T142_ = (((*c).features &((NU32)1<<((NU)(((tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw) 14))&31U)))!=0);
		if (!(T142_)) goto LA143_;
		T142_ = ((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 12));
		LA143_: ;
		if (!T142_) goto LA144_;
		checkNil__nilcheck_9362(s, body, (*g).config, (*c).Sup.idgen);
	}
	LA144_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, trackStmt__sempass50_4945)(tyObject_TContext__TE0bwjD2I16QW6s9c4AgPvw* c, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NIM_BOOL isTopLevel) {
	tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* effects;
	tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ t;
{	{
		if (!((TM__O8rpA4QnF63fyis4dAzZxA_113[(NU)((*n).kind)>>3] &(1U<<((NU)((*n).kind)&7U)))!=0)) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	g = (*c).graph;
	effects = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 152), (*n).info);
	nimZeroMem((void*)(&t), sizeof(tyObject_TEffects__f2BmEbnvQqnQmcZd5pn9apQ));
	initEffects__sempass50_4673(g, effects, module, (&t), c);
	t.isTopLevel = isTopLevel;
	track__sempass50_2338((&t), n);
	}BeforeRet_: ;
}
