/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#include <stdio.h>
#include <glob.h>
#include <setjmp.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
typedef struct tyTuple__JfHvHzMrhKkWAUvQKe0i1A tyTuple__JfHvHzMrhKkWAUvQKe0i1A;
typedef struct tyObject_Env_optionsdotnim_ConfigRef___diB2NTuAIWY0FO9c5IUJRGg tyObject_Env_optionsdotnim_ConfigRef___diB2NTuAIWY0FO9c5IUJRGg;
typedef struct tyObject_Table__aP9cMXsPundL60Bltc8zw8Q tyObject_Table__aP9cMXsPundL60Bltc8zw8Q;
typedef struct tySequence__Ou09axLmOh3clXcvEh9agsPw tySequence__Ou09axLmOh3clXcvEh9agsPw;
typedef struct tyTuple__tqJ79cmISx6IHad2jnF54pA tyTuple__tqJ79cmISx6IHad2jnF54pA;
typedef struct tyObject_ProfileInfo__xU9aXXjWWQtDqNY2yZecQYw tyObject_ProfileInfo__xU9aXXjWWQtDqNY2yZecQYw;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tyTuple__7q7q3E6Oj24ZNVJb9aonhAg;
typedef struct Exception Exception;
typedef struct RootObj RootObj;
typedef struct tySequence__QbmGqFaLnb1IWWToREeaIA tySequence__QbmGqFaLnb1IWWToREeaIA;
typedef struct TSafePoint TSafePoint;
typedef struct tyTuple__cyyQdcuoDUp88Doe6rM7kA tyTuple__cyyQdcuoDUp88Doe6rM7kA;
typedef struct tyTuple__oa1dFn55BmC688WoXKTtUg tyTuple__oa1dFn55BmC688WoXKTtUg;
typedef struct tyTuple__UV3llMMYFckfui8YMBuUZA tyTuple__UV3llMMYFckfui8YMBuUZA;
typedef struct tyObject_DateTime__8A9b0ni9bk9cgtdWJfdrY5WiA tyObject_DateTime__8A9b0ni9bk9cgtdWJfdrY5WiA;
typedef struct tyObject_TimezonecolonObjectType___40S8LCObTslEcgbC9bHcDmA tyObject_TimezonecolonObjectType___40S8LCObTslEcgbC9bHcDmA;
typedef struct tyObject_Time__4nyPibhNA9bJ9a0FBX1dYOaA tyObject_Time__4nyPibhNA9bJ9a0FBX1dYOaA;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA;
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU8 tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
typedef NU8 tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyTuple__JfHvHzMrhKkWAUvQKe0i1A {
void* Field0;
tyObject_Env_optionsdotnim_ConfigRef___diB2NTuAIWY0FO9c5IUJRGg* Field1;
};
struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg {
tyObject_Table__aP9cMXsPundL60Bltc8zw8Q* data;
};
struct tyObject_Table__aP9cMXsPundL60Bltc8zw8Q {
tySequence__Ou09axLmOh3clXcvEh9agsPw* data;
NI counter;
};
struct tyObject_ProfileInfo__xU9aXXjWWQtDqNY2yZecQYw {
NF time;
NI count;
};
struct tyTuple__tqJ79cmISx6IHad2jnF54pA {
NI Field0;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field1;
tyObject_ProfileInfo__xU9aXXjWWQtDqNY2yZecQYw Field2;
};
typedef NU8 tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA;
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
typedef tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA tyArray__aKb7f3tXhAVVrqA9c1fkI9aQ[4];
typedef NimStringDesc* tyArray__ucDUDWdKfioXQrN9bCbG29bg[12];
struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
};
typedef NCSTRING tyUncheckedArray__nvS6J9clHMUMHfoZd8Ad2zg[1];
struct RootObj {
TNimType* m_type;
};
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__QbmGqFaLnb1IWWToREeaIA* trace;
Exception* up;
};
struct TSafePoint {
TSafePoint* prev;
NI status;
jmp_buf context;
};
typedef NU8 tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA;
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tyEnum_Endianness__IxIU7d9c8Q9csHQviYDQM13A;
struct tyTuple__cyyQdcuoDUp88Doe6rM7kA {
NimStringDesc* Field0;
NI Field1;
tyEnum_Endianness__IxIU7d9c8Q9csHQviYDQM13A Field2;
NI Field3;
NI Field4;
};
typedef tyTuple__cyyQdcuoDUp88Doe6rM7kA tyArray__O7sksHvn7BNpHcBD2dBmog[26];
typedef NU8 tySet_tyEnum_TInfoOSProp__zwoAJqKVL5t9aBqjgBrDcAA;
struct tyTuple__oa1dFn55BmC688WoXKTtUg {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
NimStringDesc* Field3;
NimStringDesc* Field4;
NimStringDesc* Field5;
NimStringDesc* Field6;
NimStringDesc* Field7;
NimStringDesc* Field8;
NimStringDesc* Field9;
NimStringDesc* Field10;
NimStringDesc* Field11;
tySet_tyEnum_TInfoOSProp__zwoAJqKVL5t9aBqjgBrDcAA Field12;
};
typedef tyTuple__oa1dFn55BmC688WoXKTtUg tyArray__zAjcTh151RgaydpulQUcEQ[33];
typedef NU8 tyEnum_TInfoOSProp__zwoAJqKVL5t9aBqjgBrDcAA;
typedef NimStringDesc* tyArray__rmMMhDIqORJzUU5zqeitSQ[16];
struct tyTuple__UV3llMMYFckfui8YMBuUZA {
NimStringDesc* Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
typedef NU8 tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ;
struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg {
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg section;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* qualifiedPath;
NimStringDesc** name;
NimStringDesc* filePath;
NI line;
NI column;
NimStringDesc* doc;
NimStringDesc* forth;
NI quality;
NIM_BOOL isGlobal;
NIM_BOOL contextFits;
tyEnum_PrefixMatch__Y9cGLq2K6rNefjjqfIC9bauQ prefix;
NU8 symkind;
NI scope;
NI localUsages;
NI globalUsages;
NI tokenLen;
NI version;
NU16 endLine;
NI endCol;
};
typedef NimStringDesc* tyArray__nHXaesL0DJZHyVS07ARPRA[1];
typedef NU8 tyEnum_WeekDay__pAkr5g2DTr5wSHEdlL9aklQ;
struct tyObject_DateTime__8A9b0ni9bk9cgtdWJfdrY5WiA {
  RootObj Sup;
NI nanosecond;
NI second;
NI minute;
NI hour;
NI monthdayZero;
NI monthZero;
NI year;
tyEnum_WeekDay__pAkr5g2DTr5wSHEdlL9aklQ weekday;
NI yearday;
NIM_BOOL isDst;
tyObject_TimezonecolonObjectType___40S8LCObTslEcgbC9bHcDmA* timezone;
NI utcOffset;
};
struct tyObject_Time__4nyPibhNA9bJ9a0FBX1dYOaA {
NI64 seconds;
NI nanosecond;
};
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA {
NCSTRING procname;
NI line;
NCSTRING filename;
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
struct tySequence__Ou09axLmOh3clXcvEh9agsPw {
  TGenericSeq Sup;
  tyTuple__tqJ79cmISx6IHad2jnF54pA data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__QbmGqFaLnb1IWWToREeaIA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__4eRCaZmrYLLw2k30GPTiMw)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__KLItBKQec3LJzPmfiYYfQA)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__Ou09axLmOh3clXcvEh9agsPw)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__vKCGqnu0UyqZI18SWjvLlg)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__yHN9cW05nEsauqTlU5H52dA)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__9af1bTLFo0lbM2Q5seW0UFA)(void* p, NI op);
N_LIB_PRIVATE N_NOINLINE(void*, newObj)(TNimType* typ, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA*, nstnewStringTable)(tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA mode);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5311)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5273)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5318)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5316)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5267)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(void, initMsgConfig__lineinfos_321)(tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA* Result);
N_LIB_PRIVATE N_NIMCALL(void, initHashSet__options_2335)(NI initialSize, tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw* Result);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
N_LIB_PRIVATE N_NIMCALL(tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg*, newProfileData__options_613)(void);
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__aP9cMXsPundL60Bltc8zw8Q*, newTable__options_615)(NI initialSize);
N_LIB_PRIVATE N_NIMCALL(void, initConfigRefCommon__options_2295)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(void, setTargetFromSystem__platform_898)(tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isatty__pureZterminal_502)(FILE* f);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getRelativePathFromConfigPath__options_4365)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* f, NIM_BOOL isTitle);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___options_4370)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
static N_INLINE(NimStringDesc*, slash___pureZos_121)(NimStringDesc* head, NimStringDesc* tail);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosjoinPath)(NimStringDesc* head, NimStringDesc* tail);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, noslastPathPart)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NI, noscmpPaths)(NimStringDesc* pathA, NimStringDesc* pathB);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(void, nossplitFile)(NimStringDesc* path, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___options_4472)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isRelativeTo__pureZos_188)(NimStringDesc* path, NimStringDesc* base);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosrelativePath)(NimStringDesc* path, NimStringDesc* base, NIM_CHAR sep);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosparentDir)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getNimbleFile__options_4161)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsthasKey)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc**, nstTake)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, NimStringDesc* key);
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringDesc* s);
static N_INLINE(void, pushSafePoint)(TSafePoint* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, cstrToNimstr)(NCSTRING str);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosfileExists)(NimStringDesc* filename);
static N_INLINE(void, popSafePoint)(void);
N_LIB_PRIVATE N_NIMCALL(void, nimLeaveFinally)(void);
N_LIB_PRIVATE N_NIMCALL(void, reraiseException)(void);
N_LIB_PRIVATE N_NIMCALL(void, nstPut)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, NimStringDesc* key, NimStringDesc* val);
static N_INLINE(NIM_BOOL, isEmpty__pathutils_94)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, relativeTo__pathutils_133)(NimStringDesc* fullPath, NimStringDesc* baseFilename, NIM_CHAR sep);
static N_INLINE(NIM_BOOL, isEmpty__options_4084)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreStyle)(NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuNormalize)(NimStringDesc* s);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(NI, hashString)(NimStringDesc* s);
static N_INLINE(NIM_CHAR, X5BX5D___system_7330)(NimStringDesc* s, NI i);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__system_7745)(NimStringDesc* s, NI first, NI last);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, removeTrailingDirSep__options_4131)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosgetHomeDir)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, expandTilde__pureZos_576)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosunixToNativePath)(NimStringDesc* path, NimStringDesc* drive);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getPrefixDir__options_4096)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, nossplitPath)(NimStringDesc* path, tyTuple__UV3llMMYFckfui8YMBuUZA* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosgetAppDir)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getNimcacheDir__options_4185)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, slash___pathutils_112)(NimStringDesc* base, NimStringDesc* f);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getOsCacheDir__options_4183)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getEnv__pureZos_418)(NimStringDesc* key, NimStringDesc* default_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimcacheSuffix__options_4188)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefined__options_2292)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* symbol);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosisAbsolute)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawFindFile__options_4253)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* f, NIM_BOOL suppressStdlib);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuStartsWith)(NimStringDesc* s, NimStringDesc* prefix);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, slash___pathutils_90)(NimStringDesc* base, NimStringDesc* f);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, canonicalizePath__options_4119)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosexpandFilename)(NimStringDesc* filename);
static N_INLINE(NIM_BOOL, isEmpty__options_4492)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuToLowerAsciiStr)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawFindFile2__options_4286)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* f);
N_LIB_PRIVATE N_NIMCALL(NI, nstlen)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getPackageName__options_4178)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(void, splitFile__pathutils_27)(NimStringDesc* x, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
N_LIB_PRIVATE N_NIMCALL(void, noscreateDir)(NimStringDesc* dir);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isObj)(TNimType* obj, TNimType* subclass);
static N_INLINE(Exception*, nimBorrowCurrentException)(void);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__systemZassertions_56)(NimStringDesc* msg);
N_LIB_PRIVATE N_NIMCALL(void, quit__system_7175)(NimStringDesc* errormsg, NI errorcode) __attribute__((noreturn));
static N_INLINE(void, popCurrentException)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, noschangeFileExt)(NimStringDesc* filename, NimStringDesc* ext);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getOrDefault__pureZstrtabs_173)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, NimStringDesc* key, NimStringDesc* default_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosaddFileExt)(NimStringDesc* filename, NimStringDesc* ext);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, findFile__options_4487)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* f, NIM_BOOL suppressStdlib);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__system_7757)(NimStringDesc* s, NI first);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, canonDynlibName__options_4666)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NI, nsuFindCharSet)(NimStringDesc* s, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars, NI start, NI last);
N_LIB_PRIVATE N_NIMCALL(void, incl__options_2552)(tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw* s, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosgetCurrentDir)(void);
static N_NIMCALL(void, Marker_tyRef__vIaEYib9am0Aa2d8J2uMYdQ)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___options_4108)(NimStringDesc* x, NimStringDesc* y);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, findExe__pureZos_644)(NimStringDesc* exe, NIM_BOOL followSymlinks, NimStringDesc** extensions, NI extensionsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, format__options_598)(tyObject_DateTime__8A9b0ni9bk9cgtdWJfdrY5WiA* dt);
N_LIB_PRIVATE N_NIMCALL(void, getSrcTimestamp__options_594)(tyObject_DateTime__8A9b0ni9bk9cgtdWJfdrY5WiA* Result);
N_LIB_PRIVATE N_NIMCALL(void, utc__pureZtimes_1461)(tyObject_Time__4nyPibhNA9bJ9a0FBX1dYOaA t, tyObject_DateTime__8A9b0ni9bk9cgtdWJfdrY5WiA* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_Time__4nyPibhNA9bJ9a0FBX1dYOaA, fromUnix__pureZtimes_902)(NI64 unix_0);
N_LIB_PRIVATE N_NIMCALL(NI, nsuParseInt)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_Time__4nyPibhNA9bJ9a0FBX1dYOaA, getTime__pureZtimes_961)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, format__options_606)(tyObject_DateTime__8A9b0ni9bk9cgtdWJfdrY5WiA* dt);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___options_3923)(tyTuple__47w2DboNEPf69aPgubZdd7Q x, tyTuple__47w2DboNEPf69aPgubZdd7Q y);
N_LIB_PRIVATE N_NIMCALL(tyTuple__47w2DboNEPf69aPgubZdd7Q, parseNimVersion__options_464)(NimStringDesc* a);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ*, nsuSplitString)(NimStringDesc* s, NimStringDesc* sep, NI maxsplit);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosdirExists)(NimStringDesc* dir);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, absOutFile__options_4073)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, canonicalImportAux__options_4639)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* file);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nativeToUnixPath__stdZprivateZglobs_50)(NimStringDesc* path);
N_LIB_PRIVATE TNimType NTIconfigref58objecttype__XoIrMAjHi4NOQu4oAkNfVQ_;
N_LIB_PRIVATE TNimType NTItbackend__zoooocqvga73vZuhGAAy6A_;
extern TNimType NTItarget__tpQT7iEuCtUPNwog9cc3VgA_;
extern TNimType NTIint__rR5Bzr1D5krxoo1NcNyeMA_;
N_LIB_PRIVATE TNimType NTItoption__HPX9bEWraE8wyYLoP9bHbKYQ_;
N_LIB_PRIVATE TNimType NTItoptions__JyE8ULWMsetkCt18l86VRw_;
N_LIB_PRIVATE TNimType NTItglobaloption__WCvlY9b2UxZ4Fz8D59cE3YSg_;
N_LIB_PRIVATE TNimType NTItglobaloptions__5mooI84kzWQJDnWciD7sQA_;
extern TNimType NTIstringtableref__frXcOWngaP9adxeuIUa3iBg_;
extern TNimType NTImsgconfig__whxq1VkHUSUyso71rqeLKA_;
N_LIB_PRIVATE TNimType NTIfilenameoption__CPbjHbMoELnjs1sUwb4U6w_;
extern TNimType NTIstring__77mFvmsOLKik79ci2hXkHEg_;
extern TNimType NTIint56__chXunH2dwinSkhpA6JnsXw_;
N_LIB_PRIVATE TNimType NTIcommand__9bV9cjzU2RVpin7yQI1gAZgg_;
extern TNimType NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_;
N_LIB_PRIVATE TNimType NTItgcmode__yHeclYqeKaCEfMHNbcWn4w_;
N_LIB_PRIVATE TNimType NTIexceptionsystem__B9agvczdQhYbOz39atZ7Ap3Q_;
extern TNimType NTIfloat__w9bl9a1ul9ctRJWiMl9cNnIMvg_;
N_LIB_PRIVATE TNimType NTIsymbolfilesoption__qvBr4umnK8GxeSOSEgbmLg_;
N_LIB_PRIVATE TNimType NTIhashset__LVIAeIp9cp9c81do0NZpv6Sw_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__QeWl6B6ffS4pU6WWrtcrDw_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__4eRCaZmrYLLw2k30GPTiMw_;
N_LIB_PRIVATE TNimType NTIfeature__T2jOg7rgtA4lKTKRASHfHw_;
N_LIB_PRIVATE TNimType NTIsetLfeatureT__JNptLjsgi8AHY03RfiC9aTQ_;
N_LIB_PRIVATE TNimType NTIlegacyfeature__YfzcW9bRC8xGYaRkFXliJ2g_;
N_LIB_PRIVATE TNimType NTIsetLlegacyfeatureT__Y0qlh9bqTxcHQL08b9bKCLEw_;
N_LIB_PRIVATE TNimType NTIidecmd__p9ct5yRAwVUwh1wTpKTgABg_;
N_LIB_PRIVATE TNimType NTItsystemcc__DqbWIQj9a2XvtXkztox3VFQ_;
extern TNimType NTItnotekinds__w2aCBEMcLy7t2KQe9caB9aBw_;
extern TNimType NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_;
N_LIB_PRIVATE TNimType NTInimver__47w2DboNEPf69aPgubZdd7Q_;
N_LIB_PRIVATE TNimType NTIstdorrkind__iRAzj081qUCWECwmGroJoA_;
N_LIB_PRIVATE TNimType NTIsetLstdorrkindT__5SYuK9awXoPhHwBiML6ftcw_;
extern TNimType NTIint5150__sVg18TP9cLifHyygRe9cro9aA_;
N_LIB_PRIVATE TNimType NTIcfile__n9b2nVKiXbLpHsfkan9c3Rkw_;
N_LIB_PRIVATE TNimType NTIcfileflag__S5Qo9byZG8QnIQnJQ0ZDWrA_;
N_LIB_PRIVATE TNimType NTIsetLcfileflagT__BqZ7GosT8lX9alvQ9c2savjQ_;
N_LIB_PRIVATE TNimType NTIcfilelist__KLItBKQec3LJzPmfiYYfQA_;
N_LIB_PRIVATE TNimType NTIprocLresult58suggestTLOclosureOT__Ox1WDSaSyO73VnvAC2a4UA_;
extern TNimType NTIpointer__vr5DoT1jILTGdRlYv1OYpw_;
extern TNimType NTIrefobject__HsJiUUcO9cHBdUCi0HwkSTA_;
extern TNimType NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_;
N_LIB_PRIVATE TNimType NTIprocLoutput58stringTLOclosureOT__k2HFjxisIgDALbEUFojxaQ_;
N_LIB_PRIVATE TNimType NTIprocLconfig58configref_info58tlineinfo_msg58string_severity58severityTLOclosure_gcsafeOT__2bM7rNPFiQD9bOvwFI49bKLQ_;
N_LIB_PRIVATE TNimType NTIprofiledata58objecttype__EiZfxxvPWlUmMsSkx8Qffg_;
N_LIB_PRIVATE TNimType NTItable__aP9cMXsPundL60Bltc8zw8Q_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__tqJ79cmISx6IHad2jnF54pA_;
N_LIB_PRIVATE TNimType NTIprofileinfo__xU9aXXjWWQtDqNY2yZecQYw_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__Ou09axLmOh3clXcvEh9agsPw_;
N_LIB_PRIVATE TNimType NTItableref__vKCGqnu0UyqZI18SWjvLlg_;
N_LIB_PRIVATE TNimType NTIprofiledata__yHN9cW05nEsauqTlU5H52dA_;
N_LIB_PRIVATE TNimType NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_;
static NIM_CONST tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA TM__ZKkDwQBiNCxtzosUAsGM2Q_55 = {
0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00,
0x06, 0x10, 0x20, 0x00}
;
extern NIM_CONST tyArray__aKb7f3tXhAVVrqA9c1fkI9aQ NotesVerbosity__lineinfos_194;
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_56, "pure", 4);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_57, "core", 4);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_58, "arch", 4);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_59, "pure/collections", 16);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_60, "pure/concurrency", 16);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_61, "pure/unidecode", 14);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_62, "impure", 6);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_63, "wrappers", 8);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_64, "wrappers/linenoise", 18);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_65, "windows", 7);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_66, "posix", 5);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_67, "js", 2);
N_LIB_PRIVATE NIM_CONST tyArray__ucDUDWdKfioXQrN9bCbG29bg stdlibDirs__options_4353 = {((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_56),
((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_57),
((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_58),
((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_59),
((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_60),
((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_61),
((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_62),
((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_63),
((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_64),
((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_65),
((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_66),
((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_67)}
;
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_68, "std/", 4);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_69, "*.nimble", 8);
extern NIM_CONST tyArray__O7sksHvn7BNpHcBD2dBmog CPU__platform_705;
extern NIM_CONST tyArray__zAjcTh151RgaydpulQUcEQ OS__platform_518;
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_71, "x86", 3);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_72, "itanium", 7);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_73, "x8664", 5);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_74, "unix", 4);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_75, "linux", 5);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_76, "bsd", 3);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_77, "freebsd", 7);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_78, "emulatedthreadvars", 18);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_79, "msdos", 5);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_80, "mswindows", 9);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_81, "win32", 5);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_82, "macintosh", 9);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_83, "osx", 3);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_84, "macosx", 6);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_85, "sunos", 5);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_86, "nintendoswitch", 14);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_87, "freertos", 8);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_88, "lwip", 4);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_89, "zephyr", 6);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_90, "littleendian", 12);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_91, "bigendian", 9);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_92, "cpu8", 4);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_93, "cpu16", 5);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_94, "cpu32", 5);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_95, "cpu64", 5);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_96, "nimrawsetjmp", 12);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_97, "nim", 3);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_98, "lib", 3);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_99, "home", 4);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_100, "config", 6);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_101, "projectname", 11);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_102, "projectpath", 11);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_103, "projectdir", 10);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_104, "nimcache", 8);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_105, "nimcache", 8);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_106, "XDG_CACHE_HOME", 14);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_107, ".cache", 6);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_108, "_check", 6);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_109, "release", 7);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_110, "danger", 6);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_111, "_r", 2);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_112, "_d", 2);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_113, "unknown", 7);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_114, "_", 1);
extern TNimType NTIoserror__THeHlGxHorUQ17FON5jY0g_;
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_116, "nimDebug", 8);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_117, "options.nim(645, 14) `false` cannot create directory: ", 54);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_118, "cannot create directory: ", 25);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_119, "pkg/", 4);
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__ZKkDwQBiNCxtzosUAsGM2Q_120 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x43, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_121, "true", 4);
N_LIB_PRIVATE TNimType NTIsuggest58objecttype__VUPO9alfTq2Ar9a7ZtY9cSPDg_;
extern TNimType NTIptrstring__Y36n7l9b7WX4rcaAYCe6LWw_;
N_LIB_PRIVATE TNimType NTIint__13aFwjKaWlqhwUBjDHvkIw_;
extern TNimType NTIprefixmatch__Y9cGLq2K6rNefjjqfIC9bauQ_;
extern TNimType NTIbyte__k3HXouOuhqAKq0dx450lXQ_;
extern TNimType NTIuint4954__M4na42GvebBMnI5wV9cYMxg_;
N_LIB_PRIVATE TNimType NTIsuggest__vIaEYib9am0Aa2d8J2uMYdQ_;
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_124, "/usr", 4);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_125, "/usr/lib/nim", 12);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_126, "/usr/local", 10);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_127, "/usr/local/lib/nim", 18);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_128, "lib", 3);
extern NIM_CONST tyArray__nHXaesL0DJZHyVS07ARPRA ExeExts__pureZos_643;
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_129, "system.nim", 10);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_130, "sug", 3);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_131, "con", 3);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_132, "def", 3);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_133, "use", 3);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_134, "dus", 3);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_135, "chk", 3);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_136, "chkFile", 7);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_137, "mod", 3);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_138, "none", 4);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_139, "highlight", 9);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_140, "outline", 7);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_141, "known", 5);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_142, "msg", 3);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_143, "project", 7);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_144, "globalSymbols", 13);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_145, "declaration", 11);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_146, "expand", 6);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_147, "recompile", 9);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_148, "changed", 7);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_149, "type", 4);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_151, "SOURCE_DATE_EPOCH", 17);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_152, "not a number", 12);
extern TNimType NTIvalueerror__5lcTdgqMq62cNGRwBb0thA_;
extern TNimType NTIdatetime__8A9b0ni9bk9cgtdWJfdrY5WiA_;
static NIM_CONST tyTuple__47w2DboNEPf69aPgubZdd7Q TM__ZKkDwQBiNCxtzosUAsGM2Q_153 = {((NI) 0),
((NI) 0),
((NI) 0)}
;
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_154, "nimVersion", 10);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_155, ".", 1);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_156, "options.nim(685, 3) `not conf.outDir.isEmpty` ", 46);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_157, "options.nim(686, 3) `not conf.outFile.isEmpty` ", 47);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_158, ".out", 4);
STRING_LITERAL(TM__ZKkDwQBiNCxtzosUAsGM2Q_159, "options.nim(681, 12) `conf.outDir.string.len > 0` ", 50);
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5220;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern Exception* currException__system_2566;
extern Exception* currException__system_2566;
extern Exception* currException__system_2566;
static N_NIMCALL(void, Marker_tySequence__4eRCaZmrYLLw2k30GPTiMw)(void* p, NI op) {
	tySequence__4eRCaZmrYLLw2k30GPTiMw* a;
	NI T1_;
	a = (tySequence__4eRCaZmrYLLw2k30GPTiMw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field1, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__KLItBKQec3LJzPmfiYYfQA)(void* p, NI op) {
	tySequence__KLItBKQec3LJzPmfiYYfQA* a;
	NI T1_;
	a = (tySequence__KLItBKQec3LJzPmfiYYfQA*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].nimname, op);
	nimGCvisit((void*)a->data[T1_].cname, op);
	nimGCvisit((void*)a->data[T1_].obj, op);
	nimGCvisit((void*)a->data[T1_].customArgs, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__Ou09axLmOh3clXcvEh9agsPw)(void* p, NI op) {
	tySequence__Ou09axLmOh3clXcvEh9agsPw* a;
	NI T1_;
	a = (tySequence__Ou09axLmOh3clXcvEh9agsPw*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tyRef__vKCGqnu0UyqZI18SWjvLlg)(void* p, NI op) {
	tyObject_Table__aP9cMXsPundL60Bltc8zw8Q* a;
	a = (tyObject_Table__aP9cMXsPundL60Bltc8zw8Q*)p;
	nimGCvisit((void*)(*a).data, op);
}
static N_NIMCALL(void, Marker_tyRef__yHN9cW05nEsauqTlU5H52dA)(void* p, NI op) {
	tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* a;
	a = (tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg*)p;
	nimGCvisit((void*)(*a).data, op);
}
static N_NIMCALL(void, Marker_tyRef__9af1bTLFo0lbM2Q5seW0UFA)(void* p, NI op) {
	tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* a;
	a = (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*)p;
	nimGCvisit((void*)(*a).target.tnl, op);
	nimGCvisit((void*)(*a).macrosToExpand, op);
	nimGCvisit((void*)(*a).arcToExpand, op);
	nimGCvisit((void*)(*a).m.msgContext, op);
	nimGCvisit((void*)(*a).m.filenameToIndexTbl.data, op);
	nimGCvisit((void*)(*a).m.fileInfos, op);
	nimGCvisit((void*)(*a).unitSep, op);
	nimGCvisit((void*)(*a).cmdInput, op);
	nimGCvisit((void*)(*a).cppDefines.data, op);
	nimGCvisit((void*)(*a).headerFile, op);
	nimGCvisit((void*)(*a).arguments, op);
	nimGCvisit((void*)(*a).configVars, op);
	nimGCvisit((void*)(*a).symbols, op);
	nimGCvisit((void*)(*a).packageCache, op);
	nimGCvisit((void*)(*a).nimblePaths, op);
	nimGCvisit((void*)(*a).searchPaths, op);
	nimGCvisit((void*)(*a).lazyPaths, op);
	nimGCvisit((void*)(*a).outFile, op);
	nimGCvisit((void*)(*a).outDir, op);
	nimGCvisit((void*)(*a).jsonBuildFile, op);
	nimGCvisit((void*)(*a).prefixDir, op);
	nimGCvisit((void*)(*a).libpath, op);
	nimGCvisit((void*)(*a).nimcacheDir, op);
	nimGCvisit((void*)(*a).dllOverrides, op);
	nimGCvisit((void*)(*a).moduleOverrides, op);
	nimGCvisit((void*)(*a).cfileSpecificOptions, op);
	nimGCvisit((void*)(*a).projectName, op);
	nimGCvisit((void*)(*a).projectPath, op);
	nimGCvisit((void*)(*a).projectFull, op);
	nimGCvisit((void*)(*a).command, op);
	nimGCvisit((void*)(*a).commandArgs, op);
	nimGCvisit((void*)(*a).commandLine, op);
	nimGCvisit((void*)(*a).extraCmds, op);
	nimGCvisit((void*)(*a).implicitImports, op);
	nimGCvisit((void*)(*a).implicitIncludes, op);
	nimGCvisit((void*)(*a).docSeeSrcUrl, op);
	nimGCvisit((void*)(*a).docRoot, op);
	nimGCvisit((void*)(*a).docCmd, op);
	nimGCvisit((void*)(*a).configFiles, op);
	nimGCvisit((void*)(*a).cIncludes, op);
	nimGCvisit((void*)(*a).cLibs, op);
	nimGCvisit((void*)(*a).cLinkedLibs, op);
	nimGCvisit((void*)(*a).externalToLink, op);
	nimGCvisit((void*)(*a).linkOptionsCmd, op);
	nimGCvisit((void*)(*a).compileOptionsCmd, op);
	nimGCvisit((void*)(*a).linkOptions, op);
	nimGCvisit((void*)(*a).compileOptions, op);
	nimGCvisit((void*)(*a).cCompilerPath, op);
	nimGCvisit((void*)(*a).toCompile, op);
	nimGCvisit((void*)(*a).suggestionResultHook.ClE_0, op);
	nimGCvisit((void*)(*a).writelnHook.ClE_0, op);
	nimGCvisit((void*)(*a).structuredErrorHook.ClE_0, op);
	nimGCvisit((void*)(*a).cppCustomNamespace, op);
	nimGCvisit((void*)(*a).nimMainPrefix, op);
	nimGCvisit((void*)(*a).vmProfileData, op);
	nimGCvisit((void*)(*a).expandNodeResult, op);
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5311)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5273)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5316)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5267((&gch__system_5220.zct), c);
}
static N_INLINE(void, decRef__system_5318)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5316(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5273(src);
		incRef__system_5311(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5273((*dest));
		decRef__system_5318(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5273(p);
	decRef__system_5318(T1_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg*, newProfileData__options_613)(void) {
	tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* result;
	tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg*) newObj((&NTIprofiledata__yHN9cW05nEsauqTlU5H52dA_), sizeof(tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg));
	asgnRef((void**) (&(*T1_).data), newTable__options_615(((NI) 32)));
	result = T1_;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
N_LIB_PRIVATE N_NIMCALL(void, initConfigRefCommon__options_2295)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	(*conf).selectedGC = ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 8);
	(*conf).verbosity = ((NI) 1);
	(*conf).hintProcessingDots = NIM_TRUE;
	(*conf).options = 76180606;
	(*conf).globalOptions = IL64(2181038080);
	(*conf).filenameOption = ((tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w) 0);
	nimCopyMem((void*)(*conf).foreignPackageNotes, (NIM_CONST void*)TM__ZKkDwQBiNCxtzosUAsGM2Q_55, 12);
	nimCopyMem((void*)(*conf).notes, (NIM_CONST void*)NotesVerbosity__lineinfos_194[(((NI) 1))- 0], 12);
	nimCopyMem((void*)(*conf).mainPackageNotes, (NIM_CONST void*)NotesVerbosity__lineinfos_194[(((NI) 1))- 0], 12);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*, newConfigRef__options_2333)(void) {
	tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* result;
	tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) newObj((&NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_), sizeof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ));
	(*T1_).cCompiler = ((tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ) 1);
	asgnRef((void**) (&(*T1_).macrosToExpand), nstnewStringTable(((tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA) 2)));
	asgnRef((void**) (&(*T1_).arcToExpand), nstnewStringTable(((tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA) 2)));
	initMsgConfig__lineinfos_321((&(*T1_).m));
	initHashSet__options_2335(((NI) 64), (&(*T1_).cppDefines));
	asgnRef((void**) (&(*T1_).headerFile), ((NimStringDesc*) NIM_NIL));
	(*T1_).features = 0;
	(*T1_).legacyFeatures = 0;
	asgnRef((void**) (&(*T1_).configVars), nstnewStringTable(((tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA) 2)));
	asgnRef((void**) (&(*T1_).symbols), nstnewStringTable(((tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA) 2)));
	asgnRef((void**) (&(*T1_).packageCache), nstnewStringTable(((tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA) 1)));
	if ((*T1_).searchPaths) { nimGCunrefNoCycle((*T1_).searchPaths); (*T1_).searchPaths = NIM_NIL; }
	if ((*T1_).lazyPaths) { nimGCunrefNoCycle((*T1_).lazyPaths); (*T1_).lazyPaths = NIM_NIL; }
	asgnRef((void**) (&(*T1_).outFile), ((NimStringDesc*) NIM_NIL));
	asgnRef((void**) (&(*T1_).outDir), ((NimStringDesc*) NIM_NIL));
	asgnRef((void**) (&(*T1_).prefixDir), ((NimStringDesc*) NIM_NIL));
	asgnRef((void**) (&(*T1_).libpath), ((NimStringDesc*) NIM_NIL));
	asgnRef((void**) (&(*T1_).nimcacheDir), ((NimStringDesc*) NIM_NIL));
	asgnRef((void**) (&(*T1_).dllOverrides), nstnewStringTable(((tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA) 1)));
	asgnRef((void**) (&(*T1_).moduleOverrides), nstnewStringTable(((tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA) 2)));
	asgnRef((void**) (&(*T1_).cfileSpecificOptions), nstnewStringTable(((tyEnum_StringTableMode__aFE1syNIcJw6kweUNHC9cQA) 0)));
	asgnRef((void**) (&(*T1_).projectName), ((NimStringDesc*) NIM_NIL));
	asgnRef((void**) (&(*T1_).projectPath), ((NimStringDesc*) NIM_NIL));
	asgnRef((void**) (&(*T1_).projectFull), ((NimStringDesc*) NIM_NIL));
	(*T1_).projectIsStdin = NIM_FALSE;
	(*T1_).projectMainIdx = ((NI32) 0);
	asgnRef((void**) (&(*T1_).command), ((NimStringDesc*) NIM_NIL));
	if ((*T1_).commandArgs) { nimGCunrefNoCycle((*T1_).commandArgs); (*T1_).commandArgs = NIM_NIL; }
	asgnRef((void**) (&(*T1_).commandLine), ((NimStringDesc*) NIM_NIL));
	(*T1_).keepComments = NIM_TRUE;
	if ((*T1_).implicitImports) { nimGCunrefNoCycle((*T1_).implicitImports); (*T1_).implicitImports = NIM_NIL; }
	if ((*T1_).implicitIncludes) { nimGCunrefNoCycle((*T1_).implicitIncludes); (*T1_).implicitIncludes = NIM_NIL; }
	asgnRef((void**) (&(*T1_).docSeeSrcUrl), ((NimStringDesc*) NIM_NIL));
	if ((*T1_).cIncludes) { nimGCunrefNoCycle((*T1_).cIncludes); (*T1_).cIncludes = NIM_NIL; }
	if ((*T1_).cLibs) { nimGCunrefNoCycle((*T1_).cLibs); (*T1_).cLibs = NIM_NIL; }
	if ((*T1_).cLinkedLibs) { nimGCunrefNoCycle((*T1_).cLinkedLibs); (*T1_).cLinkedLibs = NIM_NIL; }
	(*T1_).backend = ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 0);
	if ((*T1_).externalToLink) { nimGCunrefNoCycle((*T1_).externalToLink); (*T1_).externalToLink = NIM_NIL; }
	asgnRef((void**) (&(*T1_).linkOptionsCmd), ((NimStringDesc*) NIM_NIL));
	if ((*T1_).compileOptionsCmd) { nimGCunrefNoCycle((*T1_).compileOptionsCmd); (*T1_).compileOptionsCmd = NIM_NIL; }
	asgnRef((void**) (&(*T1_).linkOptions), ((NimStringDesc*) NIM_NIL));
	asgnRef((void**) (&(*T1_).compileOptions), ((NimStringDesc*) NIM_NIL));
	asgnRef((void**) (&(*T1_).cCompilerPath), ((NimStringDesc*) NIM_NIL));
	if ((*T1_).toCompile) { nimGCunrefNoCycle((*T1_).toCompile); (*T1_).toCompile = NIM_NIL; }
	asgnRef((void**) (&(*T1_).arguments), ((NimStringDesc*) NIM_NIL));
	(*T1_).suggestMaxResults = ((NI) 10000);
	(*T1_).maxLoopIterationsVM = ((NI) 10000000);
	asgnRef((void**) (&(*T1_).vmProfileData), newProfileData__options_613());
	(*T1_).spellSuggestMax = ((NI) -1);
	result = T1_;
	initConfigRefCommon__options_2295(result);
	setTargetFromSystem__platform_898((&(*result).target));
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = isatty__pureZterminal_502(stderr);
		if (!T4_) goto LA5_;
		(*result).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 22)) & 63);
	}
	LA5_: ;
	return result;
}
static N_INLINE(NimStringDesc*, slash___pureZos_121)(NimStringDesc* head, NimStringDesc* tail) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = nosjoinPath(head, tail);
	return result;
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getRelativePathFromConfigPath__options_4365)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* f, NIM_BOOL isTitle) {
	NimStringDesc* result;
	NimStringDesc* f_2;
{	result = NIM_NIL;
	f_2 = dollar___options_4370(f);
	{
		if (!isTitle) goto LA3_;
		{
			NimStringDesc* dir;
			NI i;
			dir = NIM_NIL;
			i = ((NI) 0);
			{
				while (1) {
					NimStringDesc* path;
					NimStringDesc* T8_;
					NimStringDesc* T9_;
					dir = copyString(stdlibDirs__options_4353[(i)- 0]);
					T8_ = NIM_NIL;
					T8_ = slash___pureZos_121((*conf).libpath, dir);
					T9_ = NIM_NIL;
					T9_ = noslastPathPart(f_2);
					path = slash___pureZos_121(T8_, T9_);
					{
						NI T12_;
						NimStringDesc* T15_;
						tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T16_;
						T12_ = (NI)0;
						T12_ = noscmpPaths(path, f_2);
						if (!(T12_ == ((NI) 0))) goto LA13_;
						T15_ = NIM_NIL;
						nimZeroMem((void*)(&T16_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
						nossplitFile(f_2, (&T16_));
						T15_ = rawNewString((T16_.Field1 ? T16_.Field1->Sup.len : 0) + 4);
appendString(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_68));
appendString(T15_, T16_.Field1);
						result = T15_;
						goto BeforeRet_;
					}
					LA13_: ;
					{
						if (!(((NI) 11) <= ((NI) (i)))) goto LA19_;
						goto LA6;
					}
					LA19_: ;
					i += ((NI) 1);
				}
			} LA6: ;
		}
	}
	LA3_: ;
	{
		NimStringDesc** itX60gensym73_;
		NI i_2;
		NI L;
		NI T22_;
		itX60gensym73_ = (NimStringDesc**)0;
		i_2 = ((NI) 0);
		T22_ = ((*conf).searchPaths ? (*conf).searchPaths->Sup.len : 0);
		L = T22_;
		{
			while (1) {
				NimStringDesc* itX60gensym73__2;
				if (!(i_2 < L)) goto LA24;
				itX60gensym73_ = (&(*conf).searchPaths->data[i_2]);
				itX60gensym73__2 = dollar___options_4472((*itX60gensym73_));
				{
					NIM_BOOL T27_;
					T27_ = (NIM_BOOL)0;
					T27_ = isRelativeTo__pureZos_188(f_2, itX60gensym73__2);
					if (!T27_) goto LA28_;
					result = nosrelativePath(f_2, itX60gensym73__2, 47);
					goto BeforeRet_;
				}
				LA28_: ;
				i_2 += ((NI) 1);
			} LA24: ;
		}
	}
	{
		NimStringDesc** itX60gensym74_;
		NI i_3;
		NI L_2;
		NI T31_;
		itX60gensym74_ = (NimStringDesc**)0;
		i_3 = ((NI) 0);
		T31_ = ((*conf).lazyPaths ? (*conf).lazyPaths->Sup.len : 0);
		L_2 = T31_;
		{
			while (1) {
				NimStringDesc* itX60gensym74__2;
				if (!(i_3 < L_2)) goto LA33;
				itX60gensym74_ = (&(*conf).lazyPaths->data[i_3]);
				itX60gensym74__2 = dollar___options_4472((*itX60gensym74_));
				{
					NIM_BOOL T36_;
					T36_ = (NIM_BOOL)0;
					T36_ = isRelativeTo__pureZos_188(f_2, itX60gensym74__2);
					if (!T36_) goto LA37_;
					result = nosrelativePath(f_2, itX60gensym74__2, 47);
					goto BeforeRet_;
				}
				LA37_: ;
				i_3 += ((NI) 1);
			} LA33: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringDesc* s) {
	NCSTRING result;
	result = (NCSTRING)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (s == ((NimStringDesc*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = ((*s).Sup.len == ((NI) 0));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = "";
	}
	goto LA1_;
	LA5_: ;
	{
		result = ((NCSTRING) ((*s).data));
	}
	LA1_: ;
	return result;
}
static N_INLINE(void, pushSafePoint)(TSafePoint* s) {
	(*s).prev = excHandler__system_2565;
	excHandler__system_2565 = s;
}
static N_INLINE(void, popSafePoint)(void) {
	excHandler__system_2565 = (*excHandler__system_2565).prev;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getNimbleFile__options_4161)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* path) {
	NimStringDesc* result;
	NI parents;
{	result = NIM_NIL;
	parents = ((NI) 0);
	{
		{
			NimStringDesc* d;
			NimStringDesc* current;
			d = NIM_NIL;
			current = copyString(path);
			{
				while (1) {
					current = nosparentDir(current);
					{
						if (!((current ? current->Sup.len : 0) == ((NI) 0))) goto LA7_;
						goto LA3;
					}
					LA7_: ;
					d = current;
					{
						NIM_BOOL T11_;
						NimStringDesc** T14_;
						T11_ = (NIM_BOOL)0;
						T11_ = nsthasKey((*conf).packageCache, d);
						if (!T11_) goto LA12_;
						T14_ = (NimStringDesc**)0;
						T14_ = nstTake((*conf).packageCache, d);
						result = copyString((*T14_));
						goto BeforeRet_;
					}
					LA12_: ;
					parents += ((NI) 1);
					{
						NimStringDesc* file;
						NimStringDesc* colontmp_;
						glob_t fX60gensym137_;
						NI resX60gensym137_;
						int T16_;
						TSafePoint TM__ZKkDwQBiNCxtzosUAsGM2Q_70;
						file = NIM_NIL;
						colontmp_ = NIM_NIL;
						colontmp_ = slash___pureZos_121(d, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_69));
						nimZeroMem((void*)(&fX60gensym137_), sizeof(glob_t));
						resX60gensym137_ = (NI)0;
						fX60gensym137_.gl_offs = ((NI) 0);
						fX60gensym137_.gl_pathc = ((NI) 0);
						fX60gensym137_.gl_pathv = ((NCSTRING*) NIM_NIL);
						T16_ = (int)0;
						T16_ = glob(nimToCStringConv(colontmp_), ((int) 0), NIM_NIL, (&fX60gensym137_));
						resX60gensym137_ = ((NI) (T16_));
						pushSafePoint(&TM__ZKkDwQBiNCxtzosUAsGM2Q_70);
						TM__ZKkDwQBiNCxtzosUAsGM2Q_70.status = setjmp(TM__ZKkDwQBiNCxtzosUAsGM2Q_70.context);
						if (TM__ZKkDwQBiNCxtzosUAsGM2Q_70.status == 0) {
						{
							if (!(resX60gensym137_ == ((NI) 0))) goto LA19_;
							{
								NI iX60gensym137_;
								NI colontmp__2;
								NI res;
								iX60gensym137_ = (NI)0;
								colontmp__2 = (NI)0;
								colontmp__2 = (NI)(fX60gensym137_.gl_pathc - ((NI) 1));
								res = ((NI) 0);
								{
									while (1) {
										NimStringDesc* pathX60gensym137_;
										if (!(res <= colontmp__2)) goto LA23;
										iX60gensym137_ = res;
										pathX60gensym137_ = cstrToNimstr(fX60gensym137_.gl_pathv[iX60gensym137_]);
										{
											NIM_BOOL T26_;
											T26_ = (NIM_BOOL)0;
											T26_ = nosfileExists(pathX60gensym137_);
											if (!T26_) goto LA27_;
											file = pathX60gensym137_;
											result = copyString(file);
											popSafePoint();
											globfree((&fX60gensym137_));
											goto LA1;
										}
										LA27_: ;
										res += ((NI) 1);
									} LA23: ;
								}
							}
						}
						LA19_: ;
						popSafePoint();
						}
						else {
							popSafePoint();
						}
						{
							globfree((&fX60gensym137_));
							if (TM__ZKkDwQBiNCxtzosUAsGM2Q_70.status != 0) nimLeaveFinally();
						}
						if (TM__ZKkDwQBiNCxtzosUAsGM2Q_70.status != 0) reraiseException();
					}
				}
			} LA3: ;
		}
	} LA1: ;
	{
		NimStringDesc* d_2;
		NimStringDesc* current_2;
		d_2 = NIM_NIL;
		current_2 = copyString(path);
		{
			while (1) {
				current_2 = nosparentDir(current_2);
				{
					if (!((current_2 ? current_2->Sup.len : 0) == ((NI) 0))) goto LA36_;
					goto LA32;
				}
				LA36_: ;
				d_2 = current_2;
				nstPut((*conf).packageCache, d_2, result);
				parents -= ((NI) 1);
				{
					if (!(parents <= ((NI) 0))) goto LA40_;
					goto LA31;
				}
				LA40_: ;
			}
		} LA32: ;
	} LA31: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isEmpty__pathutils_94)(NimStringDesc* x) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((x ? x->Sup.len : 0) == ((NI) 0));
	return result;
}
static N_INLINE(NIM_BOOL, isEmpty__options_4084)(NimStringDesc* x) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((x ? x->Sup.len : 0) == ((NI) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, canonicalImportAux__options_4639)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* file) {
	NimStringDesc* result;
	NimStringDesc* ret;
	NimStringDesc* dir;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	result = NIM_NIL;
	ret = getRelativePathFromConfigPath__options_4365(conf, file, NIM_TRUE);
	T1_ = NIM_NIL;
	T1_ = dollar___options_4370(file);
	T2_ = NIM_NIL;
	T2_ = getNimbleFile__options_4161(conf, T1_);
	dir = nosparentDir(T2_);
	{
		NIM_BOOL T5_;
		NimStringDesc* relPath;
		T5_ = (NIM_BOOL)0;
		T5_ = isEmpty__pathutils_94(dir);
		if (!!(T5_)) goto LA6_;
		relPath = relativeTo__pathutils_133(file, dir, 47);
		{
			NIM_BOOL T10_;
			NIM_BOOL T11_;
			NIM_BOOL T13_;
			T10_ = (NIM_BOOL)0;
			T11_ = (NIM_BOOL)0;
			T11_ = isEmpty__options_4084(relPath);
			T10_ = !(T11_);
			if (!(T10_)) goto LA12_;
			T13_ = (NIM_BOOL)0;
			T13_ = isEmpty__options_4084(ret);
			if (T13_) goto LA14_;
			T13_ = ((relPath ? relPath->Sup.len : 0) < (ret ? ret->Sup.len : 0));
			LA14_: ;
			T10_ = T13_;
			LA12_: ;
			if (!T10_) goto LA15_;
			ret = copyString(relPath);
		}
		LA15_: ;
	}
	LA6_: ;
	{
		NIM_BOOL T19_;
		T19_ = (NIM_BOOL)0;
		T19_ = isEmpty__options_4084(ret);
		if (!T19_) goto LA20_;
		ret = relativeTo__pathutils_133(file, (*conf).projectPath, 47);
	}
	LA20_: ;
	result = copyString(ret);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasHint__options_530)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA note) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		if (!!((((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 14))&31U)))!=0))) goto LA3_;
		result = NIM_FALSE;
	}
	goto LA1_;
	LA3_: ;
	{
		if (!(((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) (note)) == ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 87) || ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) (note)) == ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 83))) goto LA6_;
		result = (((*conf).mainPackageNotes[(NU)((note- 17))>>3] &(1U<<((NU)((note- 17))&7U)))!=0);
	}
	goto LA1_;
	LA6_: ;
	{
		result = (((*conf).notes[(NU)((note- 17))>>3] &(1U<<((NU)((note- 17))&7U)))!=0);
	}
	LA1_: ;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefined__options_2292)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* symbol) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nsthasKey((*conf).symbols, symbol);
		if (!T3_) goto LA4_;
		result = NIM_TRUE;
	}
	goto LA1_;
	LA4_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = nsuCmpIgnoreStyle(symbol, CPU__platform_705[((*conf).target.targetCPU)- 1].Field0);
		if (!(T7_ == ((NI) 0))) goto LA8_;
		result = NIM_TRUE;
	}
	goto LA1_;
	LA8_: ;
	{
		NI T11_;
		T11_ = (NI)0;
		T11_ = nsuCmpIgnoreStyle(symbol, OS__platform_518[((*conf).target.targetOS)- 1].Field0);
		if (!(T11_ == ((NI) 0))) goto LA12_;
		result = NIM_TRUE;
	}
	goto LA1_;
	LA12_: ;
	{
		NimStringDesc* T15_;
		T15_ = NIM_NIL;
		T15_ = nsuNormalize(symbol);
		switch (hashString(T15_) & 31) {
		case 0: 
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_81))) goto LA25_;
break;
		case 1: 
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_80))) goto LA25_;
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_96))) goto LA38_;
break;
		case 2: 
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_94))) goto LA36_;
break;
		case 3: 
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_79))) goto LA24_;
break;
		case 6: 
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_76))) goto LA21_;
break;
		case 7: 
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_89))) goto LA31_;
break;
		case 13: 
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_85))) goto LA28_;
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_87))) goto LA30_;
break;
		case 15: 
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_71))) goto LA16_;
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_72))) goto LA17_;
break;
		case 19: 
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_74))) goto LA19_;
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_78))) goto LA23_;
break;
		case 20: 
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_91))) goto LA33_;
break;
		case 21: 
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_88))) goto LA30_;
break;
		case 22: 
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_92))) goto LA34_;
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_93))) goto LA35_;
break;
		case 23: 
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_73))) goto LA18_;
break;
		case 24: 
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_83))) goto LA27_;
break;
		case 25: 
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_86))) goto LA29_;
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_95))) goto LA37_;
break;
		case 26: 
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_84))) goto LA27_;
break;
		case 27: 
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_90))) goto LA32_;
break;
		case 30: 
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_66))) goto LA19_;
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_75))) goto LA20_;
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_77))) goto LA22_;
if (eqStrings(T15_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_82))) goto LA26_;
break;
		}
		goto LA39_;
		LA16_: ;
		{
			result = ((*conf).target.targetCPU == ((tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ) 1));
		}
		goto LA40_;
		LA17_: ;
		{
			result = ((*conf).target.targetCPU == ((tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ) 10));
		}
		goto LA40_;
		LA18_: ;
		{
			result = ((*conf).target.targetCPU == ((tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ) 11));
		}
		goto LA40_;
		LA19_: ;
		{
			result = ((IL64(7581597680) &((NU64)1<<((NU)((*conf).target.targetOS)&63U)))!=0);
		}
		goto LA40_;
		LA20_: ;
		{
			result = ((16777232 &((NU64)1<<((NU)((*conf).target.targetOS)&63U)))!=0);
		}
		goto LA40_;
		LA21_: ;
		{
			result = ((15872 &((NU64)1<<((NU)((*conf).target.targetOS)&63U)))!=0);
		}
		goto LA40_;
		LA22_: ;
		{
			result = ((9216 &((NU64)1<<((NU)((*conf).target.targetOS)&63U)))!=0);
		}
		goto LA40_;
		LA23_: ;
		{
			result = ((OS__platform_518[((*conf).target.targetOS)- 1].Field12 &((NU8)1<<((NU)(((tyEnum_TInfoOSProp__zwoAJqKVL5t9aBqjgBrDcAA) 3))&7U)))!=0);
		}
		goto LA40_;
		LA24_: ;
		{
			result = ((*conf).target.targetOS == ((tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw) 1));
		}
		goto LA40_;
		LA25_: ;
		{
			result = ((*conf).target.targetOS == ((tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw) 2));
		}
		goto LA40_;
		LA26_: ;
		{
			result = ((7340032 &((NU64)1<<((NU)((*conf).target.targetOS)&63U)))!=0);
		}
		goto LA40_;
		LA27_: ;
		{
			result = ((6291456 &((NU64)1<<((NU)((*conf).target.targetOS)&63U)))!=0);
		}
		goto LA40_;
		LA28_: ;
		{
			result = ((*conf).target.targetOS == ((tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw) 7));
		}
		goto LA40_;
		LA29_: ;
		{
			result = ((*conf).target.targetOS == ((tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw) 30));
		}
		goto LA40_;
		LA30_: ;
		{
			result = ((*conf).target.targetOS == ((tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw) 31));
		}
		goto LA40_;
		LA31_: ;
		{
			result = ((*conf).target.targetOS == ((tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw) 32));
		}
		goto LA40_;
		LA32_: ;
		{
			result = (CPU__platform_705[((*conf).target.targetCPU)- 1].Field2 == ((tyEnum_Endianness__IxIU7d9c8Q9csHQviYDQM13A) 0));
		}
		goto LA40_;
		LA33_: ;
		{
			result = (CPU__platform_705[((*conf).target.targetCPU)- 1].Field2 == ((tyEnum_Endianness__IxIU7d9c8Q9csHQviYDQM13A) 1));
		}
		goto LA40_;
		LA34_: ;
		{
			result = (CPU__platform_705[((*conf).target.targetCPU)- 1].Field4 == ((NI) 8));
		}
		goto LA40_;
		LA35_: ;
		{
			result = (CPU__platform_705[((*conf).target.targetCPU)- 1].Field4 == ((NI) 16));
		}
		goto LA40_;
		LA36_: ;
		{
			result = (CPU__platform_705[((*conf).target.targetCPU)- 1].Field4 == ((NI) 32));
		}
		goto LA40_;
		LA37_: ;
		{
			result = (CPU__platform_705[((*conf).target.targetCPU)- 1].Field4 == ((NI) 64));
		}
		goto LA40_;
		LA38_: ;
		{
			result = ((2104960 &((NU64)1<<((NU)((*conf).target.targetOS)&63U)))!=0);
		}
		goto LA40_;
		LA39_: ;
		{
		}
		LA40_: ;
	}
	LA1_: ;
	return result;
}
static N_INLINE(NIM_CHAR, X5BX5D___system_7330)(NimStringDesc* s, NI i) {
	NIM_CHAR result;
	result = (NIM_CHAR)0;
	result = s->data[(NI)((s ? s->Sup.len : 0) - i)];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, removeTrailingDirSep__options_4131)(NimStringDesc* path) {
	NimStringDesc* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		NIM_CHAR T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((NI) 0) < (path ? path->Sup.len : 0));
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_CHAR)0;
		T5_ = X5BX5D___system_7330(path, ((NI) 1));
		T3_ = ((NU8)(T5_) == (NU8)(47));
		LA4_: ;
		if (!T3_) goto LA6_;
		result = substr__system_7745(path, ((NI) 0), (NI)((path ? path->Sup.len : 0) - ((NI) 2)));
	}
	goto LA1_;
	LA6_: ;
	{
		result = copyString(path);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getPrefixDir__options_4096)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NimStringDesc* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isEmpty__pathutils_94((*conf).prefixDir);
		if (!!(T3_)) goto LA4_;
		result = copyString((*conf).prefixDir);
	}
	goto LA1_;
	LA4_: ;
	{
		NimStringDesc* T7_;
		tyTuple__UV3llMMYFckfui8YMBuUZA T8_;
		T7_ = NIM_NIL;
		T7_ = nosgetAppDir();
		nimZeroMem((void*)(&T8_), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
		nossplitPath(T7_, (&T8_));
		result = copyString(T8_.Field0);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getOsCacheDir__options_4183)(void) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	NimStringDesc* T3_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = nosgetHomeDir();
	T2_ = NIM_NIL;
	T2_ = slash___pureZos_121(T1_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_107));
	T3_ = NIM_NIL;
	T3_ = getEnv__pureZos_418(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_106), T2_);
	result = slash___pureZos_121(T3_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_97));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimcacheSuffix__options_4188)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NimStringDesc* result;
	result = NIM_NIL;
	{
		if (!((*conf).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 8))) goto LA3_;
		result = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_108));
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T6_;
		T6_ = (NIM_BOOL)0;
		T6_ = isDefined__options_2292(conf, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_109));
		if (T6_) goto LA7_;
		T6_ = isDefined__options_2292(conf, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_110));
		LA7_: ;
		if (!T6_) goto LA8_;
		result = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_111));
	}
	goto LA1_;
	LA8_: ;
	{
		result = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_112));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getNimcacheDir__options_4185)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NimStringDesc* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isEmpty__pathutils_94((*conf).nimcacheDir);
		if (!!(T3_)) goto LA4_;
		result = copyString((*conf).nimcacheDir);
	}
	goto LA1_;
	LA4_: ;
	{
		if (!((*conf).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 3))) goto LA7_;
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = isEmpty__pathutils_94((*conf).outDir);
			if (!T11_) goto LA12_;
			result = slash___pathutils_112((*conf).projectPath, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_105));
		}
		goto LA9_;
		LA12_: ;
		{
			result = slash___pathutils_112((*conf).outDir, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_105));
		}
		LA9_: ;
	}
	goto LA1_;
	LA7_: ;
	{
		NimStringDesc* T16_;
		NimStringDesc* T17_;
		tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T18_;
		NimStringDesc* T19_;
		NimStringDesc* T20_;
		T16_ = NIM_NIL;
		T17_ = NIM_NIL;
		T17_ = getOsCacheDir__options_4183();
		nimZeroMem((void*)(&T18_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
		nossplitFile((*conf).projectName, (&T18_));
		T19_ = NIM_NIL;
		T19_ = slash___pureZos_121(T17_, T18_.Field1);
		T20_ = NIM_NIL;
		T20_ = nimcacheSuffix__options_4188(conf);
		T16_ = rawNewString((T19_ ? T19_->Sup.len : 0) + (T20_ ? T20_->Sup.len : 0) + 0);
appendString(T16_, T19_);
appendString(T16_, T20_);
		result = T16_;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, pathSubs__options_4207)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* p, NimStringDesc* config) {
	NimStringDesc* result;
	NimStringDesc* home;
	NimStringDesc* T1_;
	tyArray__rmMMhDIqORJzUU5zqeitSQ T2_;
	NimStringDesc* T3_;
	NimStringDesc* T4_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = nosgetHomeDir();
	home = removeTrailingDirSep__options_4131(T1_);
	nimZeroMem((void*)T2_, sizeof(tyArray__rmMMhDIqORJzUU5zqeitSQ));
	T2_[0] = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_97));
	T2_[1] = getPrefixDir__options_4096(conf);
	T2_[2] = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_98));
	T2_[3] = copyString((*conf).libpath);
	T2_[4] = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_99));
	T2_[5] = copyString(home);
	T2_[6] = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_100));
	T2_[7] = copyString(config);
	T2_[8] = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_101));
	T2_[9] = copyString((*conf).projectName);
	T2_[10] = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_102));
	T2_[11] = copyString((*conf).projectPath);
	T2_[12] = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_103));
	T2_[13] = copyString((*conf).projectPath);
	T2_[14] = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_104));
	T2_[15] = getNimcacheDir__options_4185(conf);
	T3_ = NIM_NIL;
	T3_ = nsuFormatOpenArray(p, T2_, 16);
	T4_ = NIM_NIL;
	T4_ = nosunixToNativePath(T3_, ((NimStringDesc*) NIM_NIL));
	result = expandTilde__pureZos_576(T4_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, disableNimblePath__options_4134)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 37)) & 63);
	asgnRef((void**) (&(*conf).lazyPaths), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) setLengthSeqV2(((*conf).lazyPaths)?&((*conf).lazyPaths)->Sup:NIM_NIL, (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_), ((NI) 0)));
	asgnRef((void**) (&(*conf).nimblePaths), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) setLengthSeqV2(((*conf).nimblePaths)?&((*conf).nimblePaths)->Sup:NIM_NIL, (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_), ((NI) 0)));
}
N_LIB_PRIVATE N_NIMCALL(void, clearNimblePath__options_4148)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	asgnRef((void**) (&(*conf).lazyPaths), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) setLengthSeqV2(((*conf).lazyPaths)?&((*conf).lazyPaths)->Sup:NIM_NIL, (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_), ((NI) 0)));
	asgnRef((void**) (&(*conf).nimblePaths), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) setLengthSeqV2(((*conf).nimblePaths)?&((*conf).nimblePaths)->Sup:NIM_NIL, (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_), ((NI) 0)));
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, canonicalizePath__options_4119)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* path) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = nosexpandFilename(path);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawFindFile__options_4253)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* f, NIM_BOOL suppressStdlib) {
	NimStringDesc* result;
{	result = NIM_NIL;
	{
		NimStringDesc** it;
		NI i;
		NI L;
		NI T2_;
		it = (NimStringDesc**)0;
		i = ((NI) 0);
		T2_ = ((*conf).searchPaths ? (*conf).searchPaths->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				it = (&(*conf).searchPaths->data[i]);
				{
					{
						NIM_BOOL T8_;
						T8_ = (NIM_BOOL)0;
						T8_ = suppressStdlib;
						if (!(T8_)) goto LA9_;
						T8_ = nsuStartsWith((*it), (*conf).libpath);
						LA9_: ;
						if (!T8_) goto LA10_;
						goto LA5;
					}
					LA10_: ;
					result = slash___pathutils_90((*it), f);
					{
						NIM_BOOL T14_;
						T14_ = (NIM_BOOL)0;
						T14_ = nosfileExists(result);
						if (!T14_) goto LA15_;
						result = canonicalizePath__options_4119(conf, result);
						goto BeforeRet_;
					}
					LA15_: ;
				} LA5: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
	result = ((NimStringDesc*) NIM_NIL);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isEmpty__options_4492)(NimStringDesc* x) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((x ? x->Sup.len : 0) == ((NI) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawFindFile2__options_4286)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* f) {
	NimStringDesc* result;
{	result = NIM_NIL;
	{
		NI i;
		NimStringDesc* it;
		NI i_2;
		NI L;
		NI T2_;
		i = (NI)0;
		it = NIM_NIL;
		i_2 = ((NI) 0);
		T2_ = ((*conf).lazyPaths ? (*conf).lazyPaths->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i_2 < L)) goto LA4;
				i = i_2;
				it = (*conf).lazyPaths->data[i_2];
				result = slash___pathutils_90(it, f);
				{
					NIM_BOOL T7_;
					T7_ = (NIM_BOOL)0;
					T7_ = nosfileExists(result);
					if (!T7_) goto LA8_;
					{
						NI j;
						NI res;
						j = (NI)0;
						res = i;
						{
							while (1) {
								NimStringDesc* T13_;
								if (!(((NI) 1) <= res)) goto LA12;
								j = res;
								T13_ = NIM_NIL;
								T13_ = (*conf).lazyPaths->data[j];
								asgnRef((void**) (&(*conf).lazyPaths->data[j]), (*conf).lazyPaths->data[(NI)(j - ((NI) 1))]);
								asgnRef((void**) (&(*conf).lazyPaths->data[(NI)(j - ((NI) 1))]), T13_);
								res -= ((NI) 1);
							} LA12: ;
						}
					}
					result = canonicalizePath__options_4119(conf, result);
					goto BeforeRet_;
				}
				LA8_: ;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	result = ((NimStringDesc*) NIM_NIL);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getPackageName__options_4178)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* path) {
	NimStringDesc* result;
	NimStringDesc* path_2;
{	result = NIM_NIL;
	path_2 = getNimbleFile__options_4161(conf, path);
	{
		tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T5_;
		if (!(((NI) 0) < (path_2 ? path_2->Sup.len : 0))) goto LA3_;
		nimZeroMem((void*)(&T5_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
		nossplitFile(path_2, (&T5_));
		result = copyString(T5_.Field1);
		goto BeforeRet_;
	}
	goto LA1_;
	LA3_: ;
	{
		result = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_113));
		goto BeforeRet_;
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, findFile__options_4487)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* f, NIM_BOOL suppressStdlib) {
	NimStringDesc* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nosisAbsolute(f);
		if (!T3_) goto LA4_;
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = nosfileExists(f);
			if (!T8_) goto LA9_;
			result = copyString(f);
		}
		goto LA6_;
		LA9_: ;
		{
			result = ((NimStringDesc*) NIM_NIL);
		}
		LA6_: ;
	}
	goto LA1_;
	LA4_: ;
	{
		result = rawFindFile__options_4253(conf, f, suppressStdlib);
		{
			NIM_BOOL T15_;
			NimStringDesc* T18_;
			T15_ = (NIM_BOOL)0;
			T15_ = isEmpty__options_4492(result);
			if (!T15_) goto LA16_;
			T18_ = NIM_NIL;
			T18_ = nsuToLowerAsciiStr(f);
			result = rawFindFile__options_4253(conf, T18_, suppressStdlib);
			{
				NIM_BOOL T21_;
				T21_ = (NIM_BOOL)0;
				T21_ = isEmpty__options_4492(result);
				if (!T21_) goto LA22_;
				result = rawFindFile2__options_4286(conf, f);
				{
					NIM_BOOL T26_;
					NimStringDesc* T29_;
					T26_ = (NIM_BOOL)0;
					T26_ = isEmpty__options_4492(result);
					if (!T26_) goto LA27_;
					T29_ = NIM_NIL;
					T29_ = nsuToLowerAsciiStr(f);
					result = rawFindFile2__options_4286(conf, T29_);
				}
				LA27_: ;
			}
			LA22_: ;
		}
		LA16_: ;
	}
	LA1_: ;
	{
		NIM_BOOL T32_;
		NIM_BOOL T33_;
		NI T35_;
		NimStringDesc* key;
		NimStringDesc* T38_;
		NimStringDesc* T39_;
		tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T40_;
		T32_ = (NIM_BOOL)0;
		T33_ = (NIM_BOOL)0;
		T33_ = isEmpty__options_4492(result);
		T32_ = !(T33_);
		if (!(T32_)) goto LA34_;
		T35_ = (NI)0;
		T35_ = nstlen((*conf).moduleOverrides);
		T32_ = (((NI) 0) < T35_);
		LA34_: ;
		if (!T32_) goto LA36_;
		T38_ = NIM_NIL;
		T39_ = NIM_NIL;
		T39_ = getPackageName__options_4178(conf, result);
		nimZeroMem((void*)(&T40_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
		splitFile__pathutils_27(result, (&T40_));
		T38_ = rawNewString((T39_ ? T39_->Sup.len : 0) + (T40_.Field1 ? T40_.Field1->Sup.len : 0) + 1);
appendString(T38_, T39_);
appendString(T38_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_114));
appendString(T38_, T40_.Field1);
		key = T38_;
		{
			NIM_BOOL T43_;
			NimStringDesc* ov;
			NimStringDesc** T46_;
			T43_ = (NIM_BOOL)0;
			T43_ = nsthasKey((*conf).moduleOverrides, key);
			if (!T43_) goto LA44_;
			T46_ = (NimStringDesc**)0;
			T46_ = nstTake((*conf).moduleOverrides, key);
			ov = (*T46_);
			{
				if (!(((NI) 0) < (ov ? ov->Sup.len : 0))) goto LA49_;
				result = copyString(ov);
			}
			LA49_: ;
		}
		LA44_: ;
	}
	LA36_: ;
	return result;
}
static N_INLINE(Exception*, nimBorrowCurrentException)(void) {
	Exception* result;
	result = NIM_NIL;
	result = currException__system_2566;
	return result;
}
static N_INLINE(void, popCurrentException)(void) {
	asgnRef((void**) (&currException__system_2566), (*currException__system_2566).up);
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, completeGeneratedFilePath__options_4242)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* f, NIM_BOOL createSubDir) {
	NimStringDesc* result;
	NimStringDesc* subdir;
	tyTuple__UV3llMMYFckfui8YMBuUZA T19_;
	result = NIM_NIL;
	subdir = getNimcacheDir__options_4185(conf);
	{
		TSafePoint TM__ZKkDwQBiNCxtzosUAsGM2Q_115;
		if (!createSubDir) goto LA3_;
		pushSafePoint(&TM__ZKkDwQBiNCxtzosUAsGM2Q_115);
		TM__ZKkDwQBiNCxtzosUAsGM2Q_115.status = setjmp(TM__ZKkDwQBiNCxtzosUAsGM2Q_115.context);
		if (TM__ZKkDwQBiNCxtzosUAsGM2Q_115.status == 0) {
		noscreateDir(subdir);
		popSafePoint();
		}
		else {
			popSafePoint();
			if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIoserror__THeHlGxHorUQ17FON5jY0g_))) {
				TM__ZKkDwQBiNCxtzosUAsGM2Q_115.status = 0;
				{
					NIM_BOOL T9_;
					T9_ = (NIM_BOOL)0;
					T9_ = isDefined__options_2292(conf, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_116));
					if (!T9_) goto LA10_;
					{
						NimStringDesc* T16_;
						if (!NIM_TRUE) goto LA14_;
						T16_ = NIM_NIL;
						T16_ = rawNewString((subdir ? subdir->Sup.len : 0) + 54);
appendString(T16_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_117));
appendString(T16_, subdir);
						failedAssertImpl__systemZassertions_56(T16_);
					}
					LA14_: ;
				}
				goto LA7_;
				LA10_: ;
				{
					NimStringDesc* T18_;
					T18_ = NIM_NIL;
					T18_ = rawNewString((subdir ? subdir->Sup.len : 0) + 25);
appendString(T18_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_118));
appendString(T18_, subdir);
					quit__system_7175(T18_, ((NI) 1));
				}
				LA7_: ;
				popCurrentException();
			}
		}
		if (TM__ZKkDwQBiNCxtzosUAsGM2Q_115.status != 0) reraiseException();
	}
	LA3_: ;
	nimZeroMem((void*)(&T19_), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
	nossplitPath(f, (&T19_));
	result = slash___pathutils_90(subdir, T19_.Field1);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toGeneratedFile__options_4237)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* path, NimStringDesc* ext) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	tyTuple__UV3llMMYFckfui8YMBuUZA T2_;
	NimStringDesc* T3_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = getNimcacheDir__options_4185(conf);
	nimZeroMem((void*)(&T2_), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
	nossplitPath(path, (&T2_));
	T3_ = NIM_NIL;
	T3_ = noschangeFileExt(T2_.Field1, ext);
	result = slash___pathutils_90(T1_, T3_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, existsConfigVar__options_4050)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* key) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = nsthasKey((*conf).configVars, key);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getConfigVar__options_4054)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* key, NimStringDesc* default_0) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = getOrDefault__pureZstrtabs_173((*conf).configVars, key, default_0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hcrOn__options_582)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 38))&63U)))!=0);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, findModule__options_4507)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* modulename, NimStringDesc* currentModule) {
	NimStringDesc* result;
	NimStringDesc* m;
	result = NIM_NIL;
	m = nosaddFileExt(modulename, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_97));
	{
		NIM_BOOL T3_;
		NimStringDesc* T6_;
		T3_ = (NIM_BOOL)0;
		T3_ = nsuStartsWith(m, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_119));
		if (!T3_) goto LA4_;
		T6_ = NIM_NIL;
		T6_ = substr__system_7757(m, ((NI) 4));
		result = findFile__options_4487(conf, T6_, NIM_TRUE);
	}
	goto LA1_;
	LA4_: ;
	{
		{
			NIM_BOOL T10_;
			NimStringDesc* stripped;
			T10_ = (NIM_BOOL)0;
			T10_ = nsuStartsWith(m, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_68));
			if (!T10_) goto LA11_;
			stripped = substr__system_7757(m, ((NI) 4));
			{
				NimStringDesc* candidate;
				NI i;
				candidate = NIM_NIL;
				i = ((NI) 0);
				{
					while (1) {
						NimStringDesc* path;
						NimStringDesc* T16_;
						candidate = copyString(stdlibDirs__options_4353[(i)- 0]);
						T16_ = NIM_NIL;
						T16_ = slash___pureZos_121((*conf).libpath, candidate);
						path = slash___pureZos_121(T16_, stripped);
						{
							NIM_BOOL T19_;
							T19_ = (NIM_BOOL)0;
							T19_ = nosfileExists(path);
							if (!T19_) goto LA20_;
							result = copyString(path);
							goto LA13;
						}
						LA20_: ;
						{
							if (!(((NI) 11) <= ((NI) (i)))) goto LA24_;
							goto LA14;
						}
						LA24_: ;
						i += ((NI) 1);
					}
				} LA14: ;
			} LA13: ;
		}
		goto LA8_;
		LA11_: ;
		{
			NimStringDesc* currentPath;
			tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T27_;
			nimZeroMem((void*)(&T27_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
			nossplitFile(currentModule, (&T27_));
			currentPath = T27_.Field0;
			result = slash___pureZos_121(currentPath, m);
		}
		LA8_: ;
		{
			NIM_BOOL T30_;
			T30_ = (NIM_BOOL)0;
			T30_ = nosfileExists(result);
			if (!!(T30_)) goto LA31_;
			result = findFile__options_4487(conf, m, NIM_FALSE);
		}
		LA31_: ;
	}
	LA1_: ;
	{
		NIM_BOOL T35_;
		NIM_BOOL T36_;
		NI T38_;
		NimStringDesc* key;
		NimStringDesc* T41_;
		NimStringDesc* T42_;
		tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T43_;
		T35_ = (NIM_BOOL)0;
		T36_ = (NIM_BOOL)0;
		T36_ = isEmpty__options_4492(result);
		T35_ = !(T36_);
		if (!(T35_)) goto LA37_;
		T38_ = (NI)0;
		T38_ = nstlen((*conf).moduleOverrides);
		T35_ = (((NI) 0) < T38_);
		LA37_: ;
		if (!T35_) goto LA39_;
		T41_ = NIM_NIL;
		T42_ = NIM_NIL;
		T42_ = getPackageName__options_4178(conf, result);
		nimZeroMem((void*)(&T43_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
		splitFile__pathutils_27(result, (&T43_));
		T41_ = rawNewString((T42_ ? T42_->Sup.len : 0) + (T43_.Field1 ? T43_.Field1->Sup.len : 0) + 1);
appendString(T41_, T42_);
appendString(T41_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_114));
appendString(T41_, T43_.Field1);
		key = T41_;
		{
			NIM_BOOL T46_;
			NimStringDesc* ov;
			NimStringDesc** T49_;
			T46_ = (NIM_BOOL)0;
			T46_ = nsthasKey((*conf).moduleOverrides, key);
			if (!T46_) goto LA47_;
			T49_ = (NimStringDesc**)0;
			T49_ = nstTake((*conf).moduleOverrides, key);
			ov = (*T49_);
			{
				if (!(((NI) 0) < (ov ? ov->Sup.len : 0))) goto LA52_;
				result = copyString(ov);
			}
			LA52_: ;
		}
		LA47_: ;
	}
	LA39_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, canonDynlibName__options_4666)(NimStringDesc* s) {
	NimStringDesc* result;
	NI start;
	NI ende;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nsuStartsWith(s, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_98));
		if (!T3_) goto LA4_;
		start = ((NI) 3);
	}
	goto LA1_;
	LA4_: ;
	{
		start = ((NI) 0);
	}
	LA1_: ;
	ende = nsuFindCharSet(s, TM__ZKkDwQBiNCxtzosUAsGM2Q_120, ((NI) 0), ((NI) 0));
	{
		if (!(((NI) 0) <= ende)) goto LA9_;
		result = substr__system_7745(s, start, (NI)(ende - ((NI) 1)));
	}
	goto LA7_;
	LA9_: ;
	{
		result = substr__system_7757(s, start);
	}
	LA7_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, inclDynlibOverride__options_4671)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* lib) {
	NimStringDesc* T1_;
	T1_ = NIM_NIL;
	T1_ = canonDynlibName__options_4666(lib);
	nstPut((*conf).dllOverrides, T1_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_121));
}
N_LIB_PRIVATE N_NIMCALL(void, cppDefine__options_2530)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* c, NimStringDesc* define) {
	incl__options_2552((&(*c).cppDefines), define);
}
N_LIB_PRIVATE N_NIMCALL(void, setConfigVar__options_4059)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* key, NimStringDesc* val) {
	nstPut((*conf).configVars, key, val);
}
N_LIB_PRIVATE N_NIMCALL(void, setFromProjectName__options_4123)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* projectName) {
	TSafePoint TM__ZKkDwQBiNCxtzosUAsGM2Q_122;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg p;
	NimStringDesc* dir;
	NimStringDesc* T10_;
	pushSafePoint(&TM__ZKkDwQBiNCxtzosUAsGM2Q_122);
	TM__ZKkDwQBiNCxtzosUAsGM2Q_122.status = setjmp(TM__ZKkDwQBiNCxtzosUAsGM2Q_122.context);
	if (TM__ZKkDwQBiNCxtzosUAsGM2Q_122.status == 0) {
	asgnRef((void**) (&(*conf).projectFull), canonicalizePath__options_4119(conf, projectName));
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIoserror__THeHlGxHorUQ17FON5jY0g_))) {
			NimStringDesc* T3_;
			TM__ZKkDwQBiNCxtzosUAsGM2Q_122.status = 0;
			T3_ = NIM_NIL;
			T3_ = (*conf).projectFull; (*conf).projectFull = copyStringRC1(projectName);
			if (T3_) nimGCunrefNoCycle(T3_);
			popCurrentException();
		}
	}
	if (TM__ZKkDwQBiNCxtzosUAsGM2Q_122.status != 0) reraiseException();
	nimZeroMem((void*)(&p), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	splitFile__pathutils_27((*conf).projectFull, (&p));
	{
		NIM_BOOL T6_;
		T6_ = (NIM_BOOL)0;
		T6_ = isEmpty__pathutils_94(p.Field0);
		if (!T6_) goto LA7_;
		dir = nosgetCurrentDir();
	}
	goto LA4_;
	LA7_: ;
	{
		dir = p.Field0;
	}
	LA4_: ;
	asgnRef((void**) (&(*conf).projectPath), canonicalizePath__options_4119(conf, dir));
	T10_ = NIM_NIL;
	T10_ = (*conf).projectName; (*conf).projectName = copyStringRC1(p.Field1);
	if (T10_) nimGCunrefNoCycle(T10_);
}
static N_NIMCALL(void, Marker_tyRef__vIaEYib9am0Aa2d8J2uMYdQ)(void* p, NI op) {
	tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* a;
	a = (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg*)p;
	nimGCvisit((void*)(*a).qualifiedPath, op);
	nimGCvisit((void*)(*a).filePath, op);
	nimGCvisit((void*)(*a).doc, op);
	nimGCvisit((void*)(*a).forth, op);
}
N_LIB_PRIVATE N_NIMCALL(void, setDefaultLibpath__options_4102)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	{
		NIM_BOOL T3_;
		NimStringDesc* prefix;
		NimStringDesc* realNimPath;
		NimStringDesc* parentNimLibPath;
		NimStringDesc* T18_;
		NimStringDesc* T19_;
		T3_ = (NIM_BOOL)0;
		T3_ = isEmpty__pathutils_94((*conf).libpath);
		if (!T3_) goto LA4_;
		prefix = getPrefixDir__options_4096(conf);
		{
			NIM_BOOL T8_;
			NimStringDesc* T11_;
			T8_ = (NIM_BOOL)0;
			T8_ = eqeq___options_4108(prefix, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_124));
			if (!T8_) goto LA9_;
			T11_ = NIM_NIL;
			T11_ = (*conf).libpath; (*conf).libpath = copyStringRC1(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_125));
			if (T11_) nimGCunrefNoCycle(T11_);
		}
		goto LA6_;
		LA9_: ;
		{
			NIM_BOOL T13_;
			NimStringDesc* T16_;
			T13_ = (NIM_BOOL)0;
			T13_ = eqeq___options_4108(prefix, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_126));
			if (!T13_) goto LA14_;
			T16_ = NIM_NIL;
			T16_ = (*conf).libpath; (*conf).libpath = copyStringRC1(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_127));
			if (T16_) nimGCunrefNoCycle(T16_);
		}
		goto LA6_;
		LA14_: ;
		{
			asgnRef((void**) (&(*conf).libpath), slash___pathutils_112(prefix, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_128)));
		}
		LA6_: ;
		realNimPath = findExe__pureZos_644(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_97), NIM_TRUE, ExeExts__pureZos_643, 1);
		T18_ = NIM_NIL;
		T18_ = nosparentDir(realNimPath);
		T19_ = NIM_NIL;
		T19_ = nosparentDir(T18_);
		parentNimLibPath = slash___pureZos_121(T19_, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_98));
		{
			NIM_BOOL T22_;
			NimStringDesc* T23_;
			NIM_BOOL T24_;
			NimStringDesc* T26_;
			NimStringDesc* T29_;
			T22_ = (NIM_BOOL)0;
			T23_ = NIM_NIL;
			T23_ = slash___pureZos_121((*conf).libpath, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_129));
			T24_ = (NIM_BOOL)0;
			T24_ = nosfileExists(T23_);
			T22_ = !(T24_);
			if (!(T22_)) goto LA25_;
			T26_ = NIM_NIL;
			T26_ = slash___pureZos_121(parentNimLibPath, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_129));
			T22_ = nosfileExists(T26_);
			LA25_: ;
			if (!T22_) goto LA27_;
			T29_ = NIM_NIL;
			T29_ = (*conf).libpath; (*conf).libpath = copyStringRC1(parentNimLibPath);
			if (T29_) nimGCunrefNoCycle(T29_);
		}
		LA27_: ;
	}
	LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*, newPartialConfigRef__options_2528)(void) {
	tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* result;
	tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) newObj((&NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_), sizeof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ));
	result = T1_;
	initConfigRefCommon__options_2295(result);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___options_4702)(tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg c) {
	NimStringDesc* result;
	result = NIM_NIL;
	switch (c) {
	case ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 1):
	{
		result = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_130));
	}
	break;
	case ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 2):
	{
		result = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_131));
	}
	break;
	case ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 3):
	{
		result = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_132));
	}
	break;
	case ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 4):
	{
		result = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_133));
	}
	break;
	case ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 5):
	{
		result = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_134));
	}
	break;
	case ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 6):
	{
		result = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_135));
	}
	break;
	case ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 7):
	{
		result = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_136));
	}
	break;
	case ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 8):
	{
		result = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_137));
	}
	break;
	case ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 0):
	{
		result = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_138));
	}
	break;
	case ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 9):
	{
		result = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_139));
	}
	break;
	case ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 10):
	{
		result = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_140));
	}
	break;
	case ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 11):
	{
		result = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_141));
	}
	break;
	case ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 12):
	{
		result = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_142));
	}
	break;
	case ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 13):
	{
		result = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_143));
	}
	break;
	case ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 14):
	{
		result = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_144));
	}
	break;
	case ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 18):
	{
		result = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_145));
	}
	break;
	case ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 19):
	{
		result = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_146));
	}
	break;
	case ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 15):
	{
		result = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_147));
	}
	break;
	case ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 16):
	{
		result = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_148));
	}
	break;
	case ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 17):
	{
		result = copyString(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_149));
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI16, floatInt64Align__options_4705)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NI16 result;
{	result = (NI16)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !((conf == ((tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((*conf).target.targetCPU == ((tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ) 1));
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			if (!!(((*conf).target.targetOS == ((tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw) 2)))) goto LA9_;
			result = ((NI16) 4);
			goto BeforeRet_;
		}
		LA9_: ;
	}
	LA5_: ;
	result = ((NI16) 8);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDynlibOverride__options_4674)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* lib) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NimStringDesc* T3_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 39))&63U)))!=0);
	if (T1_) goto LA2_;
	T3_ = NIM_NIL;
	T3_ = canonDynlibName__options_4666(lib);
	T1_ = nsthasKey((*conf).dllOverrides, T3_);
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, getSrcTimestamp__options_594)(tyObject_DateTime__8A9b0ni9bk9cgtdWJfdrY5WiA* Result) {
	TSafePoint TM__ZKkDwQBiNCxtzosUAsGM2Q_150;
	NimStringDesc* T1_;
	NI T2_;
	tyObject_Time__4nyPibhNA9bJ9a0FBX1dYOaA T3_;
	pushSafePoint(&TM__ZKkDwQBiNCxtzosUAsGM2Q_150);
	TM__ZKkDwQBiNCxtzosUAsGM2Q_150.status = setjmp(TM__ZKkDwQBiNCxtzosUAsGM2Q_150.context);
	if (TM__ZKkDwQBiNCxtzosUAsGM2Q_150.status == 0) {
	T1_ = NIM_NIL;
	T1_ = getEnv__pureZos_418(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_151), ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_152));
	T2_ = (NI)0;
	T2_ = nsuParseInt(T1_);
	T3_ = fromUnix__pureZtimes_902(((NI64) (T2_)));
	utc__pureZtimes_1461(T3_, Result);
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIvalueerror__5lcTdgqMq62cNGRwBb0thA_))) {
			tyObject_Time__4nyPibhNA9bJ9a0FBX1dYOaA T6_;
			TM__ZKkDwQBiNCxtzosUAsGM2Q_150.status = 0;
			T6_ = getTime__pureZtimes_961();
			utc__pureZtimes_1461(T6_, Result);
			popCurrentException();
		}
	}
	if (TM__ZKkDwQBiNCxtzosUAsGM2Q_150.status != 0) reraiseException();
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getDateStr__options_596)(void) {
	NimStringDesc* result;
	tyObject_DateTime__8A9b0ni9bk9cgtdWJfdrY5WiA T1_;
	result = NIM_NIL;
	nimZeroMem((void*)(&T1_), sizeof(tyObject_DateTime__8A9b0ni9bk9cgtdWJfdrY5WiA));
	T1_.Sup.m_type = (&NTIdatetime__8A9b0ni9bk9cgtdWJfdrY5WiA_);
	getSrcTimestamp__options_594((&T1_));
	result = format__options_598((&T1_));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getClockStr__options_604)(void) {
	NimStringDesc* result;
	tyObject_DateTime__8A9b0ni9bk9cgtdWJfdrY5WiA T1_;
	result = NIM_NIL;
	nimZeroMem((void*)(&T1_), sizeof(tyObject_DateTime__8A9b0ni9bk9cgtdWJfdrY5WiA));
	T1_.Sup.m_type = (&NTIdatetime__8A9b0ni9bk9cgtdWJfdrY5WiA_);
	getSrcTimestamp__options_594((&T1_));
	result = format__options_606((&T1_));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyTuple__47w2DboNEPf69aPgubZdd7Q, parseNimVersion__options_464)(NimStringDesc* a) {
	tyTuple__47w2DboNEPf69aPgubZdd7Q result;
	nimZeroMem((void*)(&result), sizeof(tyTuple__47w2DboNEPf69aPgubZdd7Q));
	{
		tySequence__sM4lkSb7zS6F7OVMvW9cffQ* b;
		if (!(((NI) 0) < (a ? a->Sup.len : 0))) goto LA3_;
		b = nsuSplitString(a, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_155), ((NI) -1));
		result.Field0 = nsuParseInt(b->data[((NI) 0)]);
		result.Field1 = nsuParseInt(b->data[((NI) 1)]);
		result.Field2 = nsuParseInt(b->data[((NI) 2)]);
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyTuple__47w2DboNEPf69aPgubZdd7Q, getStdlibVersion__options_3920)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	tyTuple__47w2DboNEPf69aPgubZdd7Q result;
	nimZeroMem((void*)(&result), sizeof(tyTuple__47w2DboNEPf69aPgubZdd7Q));
	{
		NIM_BOOL T3_;
		NimStringDesc* s;
		T3_ = (NIM_BOOL)0;
		T3_ = eqeq___options_3923((*conf).nimStdlibVersion, TM__ZKkDwQBiNCxtzosUAsGM2Q_153);
		if (!T3_) goto LA4_;
		s = getOrDefault__pureZstrtabs_173((*conf).symbols, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_154), ((NimStringDesc*) NIM_NIL));
		(*conf).nimStdlibVersion = parseNimVersion__options_464(s);
	}
	LA4_: ;
	result = (*conf).nimStdlibVersion;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, absOutFile__options_4073)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NimStringDesc* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isEmpty__pathutils_94((*conf).outDir);
		if (!!(!(T3_))) goto LA4_;
		failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_156));
	}
	LA4_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = isEmpty__options_4084((*conf).outFile);
		if (!!(!(T8_))) goto LA9_;
		failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_157));
	}
	LA9_: ;
	result = slash___pathutils_90((*conf).outDir, (*conf).outFile);
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = nosdirExists(result);
		if (!T13_) goto LA14_;
		result = resizeString(result, 4);
appendString(result, ((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_158));
	}
	LA14_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, prepareToWriteOutput__options_4093)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	result = NIM_NIL;
	result = absOutFile__options_4073(conf);
	T1_ = NIM_NIL;
	T1_ = nosparentDir(result);
	noscreateDir(T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getOutFile__options_4063)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename, NimStringDesc* ext) {
	NimStringDesc* result;
	NimStringDesc* T5_;
	result = NIM_NIL;
	{
		if (!!((((NI) 0) < ((*conf).outDir ? (*conf).outDir->Sup.len : 0)))) goto LA3_;
		failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__ZKkDwQBiNCxtzosUAsGM2Q_159));
	}
	LA3_: ;
	T5_ = NIM_NIL;
	T5_ = noschangeFileExt(filename, ext);
	result = slash___pathutils_90((*conf).outDir, T5_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, canonicalImport__options_4661)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* file) {
	NimStringDesc* result;
	NimStringDesc* ret;
	NimStringDesc* T1_;
	result = NIM_NIL;
	ret = canonicalImportAux__options_4639(conf, file);
	T1_ = NIM_NIL;
	T1_ = nativeToUnixPath__stdZprivateZglobs_50(ret);
	result = noschangeFileExt(T1_, ((NimStringDesc*) NIM_NIL));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setNoteDefaults__options_483)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA note, NIM_BOOL enabled) {
	{
		if (!enabled) goto LA3_;
		(*conf).notes[(NU)((note- 17))>>3] |=(1U<<((note- 17)&7U));
		(*conf).mainPackageNotes[(NU)((note- 17))>>3] |=(1U<<((note- 17)&7U));
		(*conf).foreignPackageNotes[(NU)((note- 17))>>3] |=(1U<<((note- 17)&7U));
	}
	goto LA1_;
	LA3_: ;
	{
		(*conf).notes[(NU)((note- 17))>>3] &= ~(1U<<((note- 17)&7U));
		(*conf).mainPackageNotes[(NU)((note- 17))>>3] &= ~(1U<<((note- 17)&7U));
		(*conf).foreignPackageNotes[(NU)((note- 17))>>3] &= ~(1U<<((note- 17)&7U));
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, assignIfDefault__main_317)(NI* result, NI val, NI def) {
	{
		if (!((*result) == def)) goto LA3_;
		(*result) = val;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, mainCommandArg__options_4044)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NimStringDesc* result;
	result = NIM_NIL;
	{
		NI T3_;
		T3_ = ((*conf).commandArgs ? (*conf).commandArgs->Sup.len : 0);
		if (!(((NI) 0) < T3_)) goto LA4_;
		result = copyString((*conf).commandArgs->data[((NI) 0)]);
	}
	goto LA1_;
	LA4_: ;
	{
		result = copyString((*conf).projectName);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, atmoptionsdotnim_DatInit000)(void) {
static TNimNode* TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[103];
static TNimNode* TM__ZKkDwQBiNCxtzosUAsGM2Q_3_5[5];
NI TM__ZKkDwQBiNCxtzosUAsGM2Q_5;
static char* NIM_CONST TM__ZKkDwQBiNCxtzosUAsGM2Q_4[5] = {
"", 
"c", 
"cpp", 
"js", 
"objc"};
static TNimNode* TM__ZKkDwQBiNCxtzosUAsGM2Q_6_28[28];
NI TM__ZKkDwQBiNCxtzosUAsGM2Q_8;
static char* NIM_CONST TM__ZKkDwQBiNCxtzosUAsGM2Q_7[28] = {
"optNone", 
"optObjCheck", 
"optFieldCheck", 
"optRangeCheck", 
"optBoundsCheck", 
"optOverflowCheck", 
"optRefCheck", 
"optNaNCheck", 
"optInfCheck", 
"optStaticBoundsCheck", 
"optStyleCheck", 
"optAssert", 
"optLineDir", 
"optWarns", 
"optHints", 
"optOptimizeSpeed", 
"optOptimizeSize", 
"optStackTrace", 
"optStackTraceMsgs", 
"optLineTrace", 
"optByRef", 
"optProfiler", 
"optImplicitStatic", 
"optTrMacros", 
"optMemTracker", 
"optSinkInference", 
"optCursorInference", 
"optImportHidden"};
static TNimNode* TM__ZKkDwQBiNCxtzosUAsGM2Q_9_52[52];
NI TM__ZKkDwQBiNCxtzosUAsGM2Q_11;
static char* NIM_CONST TM__ZKkDwQBiNCxtzosUAsGM2Q_10[52] = {
"gloptNone", 
"optForceFullMake", 
"optWasNimscript", 
"optListCmd", 
"optCompileOnly", 
"optNoLinking", 
"optCDebug", 
"optGenDynLib", 
"optGenStaticLib", 
"optGenGuiApp", 
"optGenScript", 
"optGenMapping", 
"optRun", 
"optUseNimcache", 
"optStyleHint", 
"optStyleError", 
"optStyleUsages", 
"optSkipSystemConfigFile", 
"optSkipProjConfigFile", 
"optSkipUserConfigFile", 
"optSkipParentConfigFiles", 
"optNoMain", 
"optUseColors", 
"optThreads", 
"optStdout", 
"optThreadAnalysis", 
"optTlsEmulation", 
"optGenIndex", 
"optEmbedOrigSrc", 
"optIdeDebug", 
"optIdeTerse", 
"optExcessiveStackTrace", 
"optShowAllMismatches", 
"optWholeProject", 
"optDocInternal", 
"optMixedMode", 
"optDeclaredLocs", 
"optNoNimblePath", 
"optHotCodeReloading", 
"optDynlibOverrideAll", 
"optSeqDestructors", 
"optTinyRtti", 
"optOwnedRefs", 
"optMultiMethods", 
"optBenchmarkVM", 
"optProduceAsm", 
"optPanics", 
"optNimV1Emulation", 
"optNimV12Emulation", 
"optSourcemap", 
"optProfileVM", 
"optEnableDeepCopy"};
static TNimNode* TM__ZKkDwQBiNCxtzosUAsGM2Q_12_6[6];
NI TM__ZKkDwQBiNCxtzosUAsGM2Q_14;
static char* NIM_CONST TM__ZKkDwQBiNCxtzosUAsGM2Q_13[6] = {
"foAbs", 
"foRelProject", 
"foCanonical", 
"foLegacyRelProj", 
"foName", 
"foStacktrace"};
static TNimNode* TM__ZKkDwQBiNCxtzosUAsGM2Q_15_28[28];
NI TM__ZKkDwQBiNCxtzosUAsGM2Q_17;
static char* NIM_CONST TM__ZKkDwQBiNCxtzosUAsGM2Q_16[28] = {
"cmdNone", 
"cmdUnknown", 
"cmdCompileToC", 
"cmdCompileToCpp", 
"cmdCompileToOC", 
"cmdCompileToJS", 
"cmdCrun", 
"cmdTcc", 
"cmdCheck", 
"cmdParse", 
"cmdRod", 
"cmdIdeTools", 
"cmdNimscript", 
"cmdDoc0", 
"cmdDoc", 
"cmdDoc2tex", 
"cmdRst2html", 
"cmdRst2tex", 
"cmdJsondoc0", 
"cmdJsondoc", 
"cmdCtags", 
"cmdBuildindex", 
"cmdGendepend", 
"cmdDump", 
"cmdInteractive", 
"cmdNop", 
"cmdJsonscript", 
"cmdNimfix"};
static TNimNode* TM__ZKkDwQBiNCxtzosUAsGM2Q_18_11[11];
NI TM__ZKkDwQBiNCxtzosUAsGM2Q_20;
static char* NIM_CONST TM__ZKkDwQBiNCxtzosUAsGM2Q_19[11] = {
"unselected", 
"none", 
"boehm", 
"regions", 
"arc", 
"orc", 
"markAndSweep", 
"hooks", 
"refc", 
"v2", 
"go"};
static TNimNode* TM__ZKkDwQBiNCxtzosUAsGM2Q_21_5[5];
NI TM__ZKkDwQBiNCxtzosUAsGM2Q_23;
static char* NIM_CONST TM__ZKkDwQBiNCxtzosUAsGM2Q_22[5] = {
"excNone", 
"excSetjmp", 
"excCpp", 
"excGoto", 
"excQuirky"};
static TNimNode* TM__ZKkDwQBiNCxtzosUAsGM2Q_24_5[5];
NI TM__ZKkDwQBiNCxtzosUAsGM2Q_26;
static char* NIM_CONST TM__ZKkDwQBiNCxtzosUAsGM2Q_25[5] = {
"disabledSf", 
"writeOnlySf", 
"readOnlySf", 
"v2Sf", 
"stressTest"};
static TNimNode* TM__ZKkDwQBiNCxtzosUAsGM2Q_27_2[2];
static TNimNode* TM__ZKkDwQBiNCxtzosUAsGM2Q_28_2[2];
static TNimNode* TM__ZKkDwQBiNCxtzosUAsGM2Q_29_19[19];
NI TM__ZKkDwQBiNCxtzosUAsGM2Q_31;
static char* NIM_CONST TM__ZKkDwQBiNCxtzosUAsGM2Q_30[19] = {
"implicitDeref", 
"dotOperators", 
"callOperator", 
"parallel", 
"destructor", 
"notnil", 
"dynamicBindSym", 
"forLoopMacros", 
"caseStmtMacros", 
"codeReordering", 
"compiletimeFFI", 
"vmopsDanger", 
"strictFuncs", 
"views", 
"strictNotNil", 
"overloadableEnums", 
"strictEffects", 
"unicodeOperators", 
"flexibleOptionalParams"};
static TNimNode* TM__ZKkDwQBiNCxtzosUAsGM2Q_32_2[2];
NI TM__ZKkDwQBiNCxtzosUAsGM2Q_34;
static char* NIM_CONST TM__ZKkDwQBiNCxtzosUAsGM2Q_33[2] = {
"allowSemcheckedAstModification", 
"checkUnsignedConversions"};
static TNimNode* TM__ZKkDwQBiNCxtzosUAsGM2Q_35_20[20];
NI TM__ZKkDwQBiNCxtzosUAsGM2Q_37;
static char* NIM_CONST TM__ZKkDwQBiNCxtzosUAsGM2Q_36[20] = {
"ideNone", 
"ideSug", 
"ideCon", 
"ideDef", 
"ideUse", 
"ideDus", 
"ideChk", 
"ideChkFile", 
"ideMod", 
"ideHighlight", 
"ideOutline", 
"ideKnown", 
"ideMsg", 
"ideProject", 
"ideGlobalSymbols", 
"ideRecompile", 
"ideChanged", 
"ideType", 
"ideDeclaration", 
"ideExpand"};
static TNimNode* TM__ZKkDwQBiNCxtzosUAsGM2Q_38_12[12];
NI TM__ZKkDwQBiNCxtzosUAsGM2Q_40;
static char* NIM_CONST TM__ZKkDwQBiNCxtzosUAsGM2Q_39[12] = {
"ccNone", 
"ccGcc", 
"ccNintendoSwitch", 
"ccLLVM_Gcc", 
"ccCLang", 
"ccBcc", 
"ccVcc", 
"ccTcc", 
"ccEnv", 
"ccIcl", 
"ccIcc", 
"ccClangCl"};
static TNimNode* TM__ZKkDwQBiNCxtzosUAsGM2Q_41_3[3];
static TNimNode* TM__ZKkDwQBiNCxtzosUAsGM2Q_42_2[2];
NI TM__ZKkDwQBiNCxtzosUAsGM2Q_44;
static char* NIM_CONST TM__ZKkDwQBiNCxtzosUAsGM2Q_43[2] = {
"stdOrrStdout", 
"stdOrrStderr"};
static TNimNode* TM__ZKkDwQBiNCxtzosUAsGM2Q_45_5[5];
static TNimNode* TM__ZKkDwQBiNCxtzosUAsGM2Q_46_2[2];
NI TM__ZKkDwQBiNCxtzosUAsGM2Q_48;
static char* NIM_CONST TM__ZKkDwQBiNCxtzosUAsGM2Q_47[2] = {
"Cached", 
"External"};
static TNimNode* TM__ZKkDwQBiNCxtzosUAsGM2Q_49_2[2];
static TNimNode* TM__ZKkDwQBiNCxtzosUAsGM2Q_50_2[2];
static TNimNode* TM__ZKkDwQBiNCxtzosUAsGM2Q_51_2[2];
static TNimNode* TM__ZKkDwQBiNCxtzosUAsGM2Q_52_2[2];
static TNimNode* TM__ZKkDwQBiNCxtzosUAsGM2Q_53_3[3];
static TNimNode* TM__ZKkDwQBiNCxtzosUAsGM2Q_54_2[2];
static TNimNode* TM__ZKkDwQBiNCxtzosUAsGM2Q_123_20[20];
static TNimNode TM__ZKkDwQBiNCxtzosUAsGM2Q_0[378];
NTIconfigref58objecttype__XoIrMAjHi4NOQu4oAkNfVQ_.size = sizeof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ);
NTIconfigref58objecttype__XoIrMAjHi4NOQu4oAkNfVQ_.align = NIM_ALIGNOF(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ);
NTIconfigref58objecttype__XoIrMAjHi4NOQu4oAkNfVQ_.kind = 18;
NTIconfigref58objecttype__XoIrMAjHi4NOQu4oAkNfVQ_.base = 0;
NTIconfigref58objecttype__XoIrMAjHi4NOQu4oAkNfVQ_.flags = 2;
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[0] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[1];
NTItbackend__zoooocqvga73vZuhGAAy6A_.size = sizeof(tyEnum_TBackend__zoooocqvga73vZuhGAAy6A);
NTItbackend__zoooocqvga73vZuhGAAy6A_.align = NIM_ALIGNOF(tyEnum_TBackend__zoooocqvga73vZuhGAAy6A);
NTItbackend__zoooocqvga73vZuhGAAy6A_.kind = 14;
NTItbackend__zoooocqvga73vZuhGAAy6A_.base = 0;
NTItbackend__zoooocqvga73vZuhGAAy6A_.flags = 3;
for (TM__ZKkDwQBiNCxtzosUAsGM2Q_5 = 0; TM__ZKkDwQBiNCxtzosUAsGM2Q_5 < 5; TM__ZKkDwQBiNCxtzosUAsGM2Q_5++) {
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_5+2].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_5+2].offset = TM__ZKkDwQBiNCxtzosUAsGM2Q_5;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_5+2].name = TM__ZKkDwQBiNCxtzosUAsGM2Q_4[TM__ZKkDwQBiNCxtzosUAsGM2Q_5];
TM__ZKkDwQBiNCxtzosUAsGM2Q_3_5[TM__ZKkDwQBiNCxtzosUAsGM2Q_5] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_5+2];
}
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[7].len = 5; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[7].kind = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[7].sons = &TM__ZKkDwQBiNCxtzosUAsGM2Q_3_5[0];
NTItbackend__zoooocqvga73vZuhGAAy6A_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[7];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[1].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[1].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, backend);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[1].typ = (&NTItbackend__zoooocqvga73vZuhGAAy6A_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[1].name = "backend";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[1] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[8];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[8].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[8].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, target);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[8].typ = (&NTItarget__tpQT7iEuCtUPNwog9cc3VgA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[8].name = "target";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[2] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[9];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[9].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[9].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, linesCompiled);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[9].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[9].name = "linesCompiled";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[3] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[10];
NTItoption__HPX9bEWraE8wyYLoP9bHbKYQ_.size = sizeof(tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ);
NTItoption__HPX9bEWraE8wyYLoP9bHbKYQ_.align = NIM_ALIGNOF(tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ);
NTItoption__HPX9bEWraE8wyYLoP9bHbKYQ_.kind = 14;
NTItoption__HPX9bEWraE8wyYLoP9bHbKYQ_.base = 0;
NTItoption__HPX9bEWraE8wyYLoP9bHbKYQ_.flags = 3;
for (TM__ZKkDwQBiNCxtzosUAsGM2Q_8 = 0; TM__ZKkDwQBiNCxtzosUAsGM2Q_8 < 28; TM__ZKkDwQBiNCxtzosUAsGM2Q_8++) {
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_8+11].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_8+11].offset = TM__ZKkDwQBiNCxtzosUAsGM2Q_8;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_8+11].name = TM__ZKkDwQBiNCxtzosUAsGM2Q_7[TM__ZKkDwQBiNCxtzosUAsGM2Q_8];
TM__ZKkDwQBiNCxtzosUAsGM2Q_6_28[TM__ZKkDwQBiNCxtzosUAsGM2Q_8] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_8+11];
}
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[39].len = 28; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[39].kind = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[39].sons = &TM__ZKkDwQBiNCxtzosUAsGM2Q_6_28[0];
NTItoption__HPX9bEWraE8wyYLoP9bHbKYQ_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[39];
NTItoptions__JyE8ULWMsetkCt18l86VRw_.size = sizeof(tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ);
NTItoptions__JyE8ULWMsetkCt18l86VRw_.align = NIM_ALIGNOF(tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ);
NTItoptions__JyE8ULWMsetkCt18l86VRw_.kind = 19;
NTItoptions__JyE8ULWMsetkCt18l86VRw_.base = (&NTItoption__HPX9bEWraE8wyYLoP9bHbKYQ_);
NTItoptions__JyE8ULWMsetkCt18l86VRw_.flags = 3;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[40].len = 0; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[40].kind = 0;
NTItoptions__JyE8ULWMsetkCt18l86VRw_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[40];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[10].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[10].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, options);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[10].typ = (&NTItoptions__JyE8ULWMsetkCt18l86VRw_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[10].name = "options";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[4] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[41];
NTItglobaloption__WCvlY9b2UxZ4Fz8D59cE3YSg_.size = sizeof(tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg);
NTItglobaloption__WCvlY9b2UxZ4Fz8D59cE3YSg_.align = NIM_ALIGNOF(tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg);
NTItglobaloption__WCvlY9b2UxZ4Fz8D59cE3YSg_.kind = 14;
NTItglobaloption__WCvlY9b2UxZ4Fz8D59cE3YSg_.base = 0;
NTItglobaloption__WCvlY9b2UxZ4Fz8D59cE3YSg_.flags = 3;
for (TM__ZKkDwQBiNCxtzosUAsGM2Q_11 = 0; TM__ZKkDwQBiNCxtzosUAsGM2Q_11 < 52; TM__ZKkDwQBiNCxtzosUAsGM2Q_11++) {
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_11+42].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_11+42].offset = TM__ZKkDwQBiNCxtzosUAsGM2Q_11;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_11+42].name = TM__ZKkDwQBiNCxtzosUAsGM2Q_10[TM__ZKkDwQBiNCxtzosUAsGM2Q_11];
TM__ZKkDwQBiNCxtzosUAsGM2Q_9_52[TM__ZKkDwQBiNCxtzosUAsGM2Q_11] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_11+42];
}
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[94].len = 52; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[94].kind = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[94].sons = &TM__ZKkDwQBiNCxtzosUAsGM2Q_9_52[0];
NTItglobaloption__WCvlY9b2UxZ4Fz8D59cE3YSg_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[94];
NTItglobaloptions__5mooI84kzWQJDnWciD7sQA_.size = sizeof(tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg);
NTItglobaloptions__5mooI84kzWQJDnWciD7sQA_.align = NIM_ALIGNOF(tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg);
NTItglobaloptions__5mooI84kzWQJDnWciD7sQA_.kind = 19;
NTItglobaloptions__5mooI84kzWQJDnWciD7sQA_.base = (&NTItglobaloption__WCvlY9b2UxZ4Fz8D59cE3YSg_);
NTItglobaloptions__5mooI84kzWQJDnWciD7sQA_.flags = 3;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[95].len = 0; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[95].kind = 0;
NTItglobaloptions__5mooI84kzWQJDnWciD7sQA_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[95];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[41].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[41].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, globalOptions);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[41].typ = (&NTItglobaloptions__5mooI84kzWQJDnWciD7sQA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[41].name = "globalOptions";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[5] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[96];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[96].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[96].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, macrosToExpand);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[96].typ = (&NTIstringtableref__frXcOWngaP9adxeuIUa3iBg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[96].name = "macrosToExpand";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[6] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[97];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[97].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[97].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, arcToExpand);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[97].typ = (&NTIstringtableref__frXcOWngaP9adxeuIUa3iBg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[97].name = "arcToExpand";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[7] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[98];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[98].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[98].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, m);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[98].typ = (&NTImsgconfig__whxq1VkHUSUyso71rqeLKA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[98].name = "m";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[8] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[99];
NTIfilenameoption__CPbjHbMoELnjs1sUwb4U6w_.size = sizeof(tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w);
NTIfilenameoption__CPbjHbMoELnjs1sUwb4U6w_.align = NIM_ALIGNOF(tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w);
NTIfilenameoption__CPbjHbMoELnjs1sUwb4U6w_.kind = 14;
NTIfilenameoption__CPbjHbMoELnjs1sUwb4U6w_.base = 0;
NTIfilenameoption__CPbjHbMoELnjs1sUwb4U6w_.flags = 3;
for (TM__ZKkDwQBiNCxtzosUAsGM2Q_14 = 0; TM__ZKkDwQBiNCxtzosUAsGM2Q_14 < 6; TM__ZKkDwQBiNCxtzosUAsGM2Q_14++) {
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_14+100].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_14+100].offset = TM__ZKkDwQBiNCxtzosUAsGM2Q_14;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_14+100].name = TM__ZKkDwQBiNCxtzosUAsGM2Q_13[TM__ZKkDwQBiNCxtzosUAsGM2Q_14];
TM__ZKkDwQBiNCxtzosUAsGM2Q_12_6[TM__ZKkDwQBiNCxtzosUAsGM2Q_14] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_14+100];
}
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[106].len = 6; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[106].kind = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[106].sons = &TM__ZKkDwQBiNCxtzosUAsGM2Q_12_6[0];
NTIfilenameoption__CPbjHbMoELnjs1sUwb4U6w_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[106];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[99].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[99].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, filenameOption);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[99].typ = (&NTIfilenameoption__CPbjHbMoELnjs1sUwb4U6w_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[99].name = "filenameOption";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[9] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[107];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[107].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[107].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, unitSep);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[107].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[107].name = "unitSep";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[10] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[108];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[108].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[108].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, evalTemplateCounter);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[108].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[108].name = "evalTemplateCounter";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[11] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[109];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[109].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[109].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, evalMacroCounter);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[109].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[109].name = "evalMacroCounter";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[12] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[110];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[110].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[110].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, exitcode);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[110].typ = (&NTIint56__chXunH2dwinSkhpA6JnsXw_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[110].name = "exitcode";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[13] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[111];
NTIcommand__9bV9cjzU2RVpin7yQI1gAZgg_.size = sizeof(tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg);
NTIcommand__9bV9cjzU2RVpin7yQI1gAZgg_.align = NIM_ALIGNOF(tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg);
NTIcommand__9bV9cjzU2RVpin7yQI1gAZgg_.kind = 14;
NTIcommand__9bV9cjzU2RVpin7yQI1gAZgg_.base = 0;
NTIcommand__9bV9cjzU2RVpin7yQI1gAZgg_.flags = 3;
for (TM__ZKkDwQBiNCxtzosUAsGM2Q_17 = 0; TM__ZKkDwQBiNCxtzosUAsGM2Q_17 < 28; TM__ZKkDwQBiNCxtzosUAsGM2Q_17++) {
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_17+112].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_17+112].offset = TM__ZKkDwQBiNCxtzosUAsGM2Q_17;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_17+112].name = TM__ZKkDwQBiNCxtzosUAsGM2Q_16[TM__ZKkDwQBiNCxtzosUAsGM2Q_17];
TM__ZKkDwQBiNCxtzosUAsGM2Q_15_28[TM__ZKkDwQBiNCxtzosUAsGM2Q_17] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_17+112];
}
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[140].len = 28; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[140].kind = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[140].sons = &TM__ZKkDwQBiNCxtzosUAsGM2Q_15_28[0];
NTIcommand__9bV9cjzU2RVpin7yQI1gAZgg_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[140];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[111].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[111].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, cmd);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[111].typ = (&NTIcommand__9bV9cjzU2RVpin7yQI1gAZgg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[111].name = "cmd";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[14] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[141];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[141].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[141].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, cmdInput);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[141].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[141].name = "cmdInput";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[15] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[142];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[142].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[142].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, projectIsCmd);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[142].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[142].name = "projectIsCmd";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[16] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[143];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[143].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[143].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, implicitCmd);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[143].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[143].name = "implicitCmd";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[17] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[144];
NTItgcmode__yHeclYqeKaCEfMHNbcWn4w_.size = sizeof(tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w);
NTItgcmode__yHeclYqeKaCEfMHNbcWn4w_.align = NIM_ALIGNOF(tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w);
NTItgcmode__yHeclYqeKaCEfMHNbcWn4w_.kind = 14;
NTItgcmode__yHeclYqeKaCEfMHNbcWn4w_.base = 0;
NTItgcmode__yHeclYqeKaCEfMHNbcWn4w_.flags = 3;
for (TM__ZKkDwQBiNCxtzosUAsGM2Q_20 = 0; TM__ZKkDwQBiNCxtzosUAsGM2Q_20 < 11; TM__ZKkDwQBiNCxtzosUAsGM2Q_20++) {
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_20+145].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_20+145].offset = TM__ZKkDwQBiNCxtzosUAsGM2Q_20;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_20+145].name = TM__ZKkDwQBiNCxtzosUAsGM2Q_19[TM__ZKkDwQBiNCxtzosUAsGM2Q_20];
TM__ZKkDwQBiNCxtzosUAsGM2Q_18_11[TM__ZKkDwQBiNCxtzosUAsGM2Q_20] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_20+145];
}
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[156].len = 11; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[156].kind = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[156].sons = &TM__ZKkDwQBiNCxtzosUAsGM2Q_18_11[0];
NTItgcmode__yHeclYqeKaCEfMHNbcWn4w_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[156];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[144].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[144].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, selectedGC);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[144].typ = (&NTItgcmode__yHeclYqeKaCEfMHNbcWn4w_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[144].name = "selectedGC";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[18] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[157];
NTIexceptionsystem__B9agvczdQhYbOz39atZ7Ap3Q_.size = sizeof(tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q);
NTIexceptionsystem__B9agvczdQhYbOz39atZ7Ap3Q_.align = NIM_ALIGNOF(tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q);
NTIexceptionsystem__B9agvczdQhYbOz39atZ7Ap3Q_.kind = 14;
NTIexceptionsystem__B9agvczdQhYbOz39atZ7Ap3Q_.base = 0;
NTIexceptionsystem__B9agvczdQhYbOz39atZ7Ap3Q_.flags = 3;
for (TM__ZKkDwQBiNCxtzosUAsGM2Q_23 = 0; TM__ZKkDwQBiNCxtzosUAsGM2Q_23 < 5; TM__ZKkDwQBiNCxtzosUAsGM2Q_23++) {
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_23+158].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_23+158].offset = TM__ZKkDwQBiNCxtzosUAsGM2Q_23;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_23+158].name = TM__ZKkDwQBiNCxtzosUAsGM2Q_22[TM__ZKkDwQBiNCxtzosUAsGM2Q_23];
TM__ZKkDwQBiNCxtzosUAsGM2Q_21_5[TM__ZKkDwQBiNCxtzosUAsGM2Q_23] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_23+158];
}
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[163].len = 5; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[163].kind = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[163].sons = &TM__ZKkDwQBiNCxtzosUAsGM2Q_21_5[0];
NTIexceptionsystem__B9agvczdQhYbOz39atZ7Ap3Q_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[163];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[157].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[157].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, exc);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[157].typ = (&NTIexceptionsystem__B9agvczdQhYbOz39atZ7Ap3Q_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[157].name = "exc";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[19] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[164];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[164].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[164].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, hintProcessingDots);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[164].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[164].name = "hintProcessingDots";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[20] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[165];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[165].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[165].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, verbosity);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[165].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[165].name = "verbosity";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[21] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[166];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[166].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[166].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, numberOfProcessors);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[166].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[166].name = "numberOfProcessors";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[22] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[167];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[167].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[167].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, lastCmdTime);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[167].typ = (&NTIfloat__w9bl9a1ul9ctRJWiMl9cNnIMvg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[167].name = "lastCmdTime";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[23] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[168];
NTIsymbolfilesoption__qvBr4umnK8GxeSOSEgbmLg_.size = sizeof(tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg);
NTIsymbolfilesoption__qvBr4umnK8GxeSOSEgbmLg_.align = NIM_ALIGNOF(tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg);
NTIsymbolfilesoption__qvBr4umnK8GxeSOSEgbmLg_.kind = 14;
NTIsymbolfilesoption__qvBr4umnK8GxeSOSEgbmLg_.base = 0;
NTIsymbolfilesoption__qvBr4umnK8GxeSOSEgbmLg_.flags = 3;
for (TM__ZKkDwQBiNCxtzosUAsGM2Q_26 = 0; TM__ZKkDwQBiNCxtzosUAsGM2Q_26 < 5; TM__ZKkDwQBiNCxtzosUAsGM2Q_26++) {
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_26+169].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_26+169].offset = TM__ZKkDwQBiNCxtzosUAsGM2Q_26;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_26+169].name = TM__ZKkDwQBiNCxtzosUAsGM2Q_25[TM__ZKkDwQBiNCxtzosUAsGM2Q_26];
TM__ZKkDwQBiNCxtzosUAsGM2Q_24_5[TM__ZKkDwQBiNCxtzosUAsGM2Q_26] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_26+169];
}
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[174].len = 5; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[174].kind = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[174].sons = &TM__ZKkDwQBiNCxtzosUAsGM2Q_24_5[0];
NTIsymbolfilesoption__qvBr4umnK8GxeSOSEgbmLg_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[174];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[168].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[168].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, symbolFiles);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[168].typ = (&NTIsymbolfilesoption__qvBr4umnK8GxeSOSEgbmLg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[168].name = "symbolFiles";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[24] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[175];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[175].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[175].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, spellSuggestMax);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[175].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[175].name = "spellSuggestMax";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[25] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[176];
NTIhashset__LVIAeIp9cp9c81do0NZpv6Sw_.size = sizeof(tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw);
NTIhashset__LVIAeIp9cp9c81do0NZpv6Sw_.align = NIM_ALIGNOF(tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw);
NTIhashset__LVIAeIp9cp9c81do0NZpv6Sw_.kind = 18;
NTIhashset__LVIAeIp9cp9c81do0NZpv6Sw_.base = 0;
NTIhashset__LVIAeIp9cp9c81do0NZpv6Sw_.flags = 2;
TM__ZKkDwQBiNCxtzosUAsGM2Q_27_2[0] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[178];
NTIkeyvaluepair__QeWl6B6ffS4pU6WWrtcrDw_.size = sizeof(tyTuple__QeWl6B6ffS4pU6WWrtcrDw);
NTIkeyvaluepair__QeWl6B6ffS4pU6WWrtcrDw_.align = NIM_ALIGNOF(tyTuple__QeWl6B6ffS4pU6WWrtcrDw);
NTIkeyvaluepair__QeWl6B6ffS4pU6WWrtcrDw_.kind = 18;
NTIkeyvaluepair__QeWl6B6ffS4pU6WWrtcrDw_.base = 0;
NTIkeyvaluepair__QeWl6B6ffS4pU6WWrtcrDw_.flags = 2;
TM__ZKkDwQBiNCxtzosUAsGM2Q_28_2[0] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[180];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[180].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[180].offset = offsetof(tyTuple__QeWl6B6ffS4pU6WWrtcrDw, Field0);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[180].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[180].name = "Field0";
TM__ZKkDwQBiNCxtzosUAsGM2Q_28_2[1] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[181];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[181].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[181].offset = offsetof(tyTuple__QeWl6B6ffS4pU6WWrtcrDw, Field1);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[181].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[181].name = "Field1";
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[179].len = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[179].kind = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[179].sons = &TM__ZKkDwQBiNCxtzosUAsGM2Q_28_2[0];
NTIkeyvaluepair__QeWl6B6ffS4pU6WWrtcrDw_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[179];
NTIkeyvaluepairseq__4eRCaZmrYLLw2k30GPTiMw_.size = sizeof(tySequence__4eRCaZmrYLLw2k30GPTiMw*);
NTIkeyvaluepairseq__4eRCaZmrYLLw2k30GPTiMw_.align = NIM_ALIGNOF(tySequence__4eRCaZmrYLLw2k30GPTiMw*);
NTIkeyvaluepairseq__4eRCaZmrYLLw2k30GPTiMw_.kind = 24;
NTIkeyvaluepairseq__4eRCaZmrYLLw2k30GPTiMw_.base = (&NTIkeyvaluepair__QeWl6B6ffS4pU6WWrtcrDw_);
NTIkeyvaluepairseq__4eRCaZmrYLLw2k30GPTiMw_.flags = 2;
NTIkeyvaluepairseq__4eRCaZmrYLLw2k30GPTiMw_.marker = Marker_tySequence__4eRCaZmrYLLw2k30GPTiMw;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[178].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[178].offset = offsetof(tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw, data);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[178].typ = (&NTIkeyvaluepairseq__4eRCaZmrYLLw2k30GPTiMw_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[178].name = "data";
TM__ZKkDwQBiNCxtzosUAsGM2Q_27_2[1] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[182];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[182].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[182].offset = offsetof(tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw, counter);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[182].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[182].name = "counter";
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[177].len = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[177].kind = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[177].sons = &TM__ZKkDwQBiNCxtzosUAsGM2Q_27_2[0];
NTIhashset__LVIAeIp9cp9c81do0NZpv6Sw_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[177];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[176].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[176].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, cppDefines);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[176].typ = (&NTIhashset__LVIAeIp9cp9c81do0NZpv6Sw_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[176].name = "cppDefines";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[26] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[183];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[183].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[183].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, headerFile);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[183].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[183].name = "headerFile";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[27] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[184];
NTIfeature__T2jOg7rgtA4lKTKRASHfHw_.size = sizeof(tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw);
NTIfeature__T2jOg7rgtA4lKTKRASHfHw_.align = NIM_ALIGNOF(tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw);
NTIfeature__T2jOg7rgtA4lKTKRASHfHw_.kind = 14;
NTIfeature__T2jOg7rgtA4lKTKRASHfHw_.base = 0;
NTIfeature__T2jOg7rgtA4lKTKRASHfHw_.flags = 3;
for (TM__ZKkDwQBiNCxtzosUAsGM2Q_31 = 0; TM__ZKkDwQBiNCxtzosUAsGM2Q_31 < 19; TM__ZKkDwQBiNCxtzosUAsGM2Q_31++) {
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_31+185].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_31+185].offset = TM__ZKkDwQBiNCxtzosUAsGM2Q_31;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_31+185].name = TM__ZKkDwQBiNCxtzosUAsGM2Q_30[TM__ZKkDwQBiNCxtzosUAsGM2Q_31];
TM__ZKkDwQBiNCxtzosUAsGM2Q_29_19[TM__ZKkDwQBiNCxtzosUAsGM2Q_31] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_31+185];
}
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[204].len = 19; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[204].kind = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[204].sons = &TM__ZKkDwQBiNCxtzosUAsGM2Q_29_19[0];
NTIfeature__T2jOg7rgtA4lKTKRASHfHw_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[204];
NTIsetLfeatureT__JNptLjsgi8AHY03RfiC9aTQ_.size = sizeof(tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw);
NTIsetLfeatureT__JNptLjsgi8AHY03RfiC9aTQ_.align = NIM_ALIGNOF(tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw);
NTIsetLfeatureT__JNptLjsgi8AHY03RfiC9aTQ_.kind = 19;
NTIsetLfeatureT__JNptLjsgi8AHY03RfiC9aTQ_.base = (&NTIfeature__T2jOg7rgtA4lKTKRASHfHw_);
NTIsetLfeatureT__JNptLjsgi8AHY03RfiC9aTQ_.flags = 3;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[205].len = 0; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[205].kind = 0;
NTIsetLfeatureT__JNptLjsgi8AHY03RfiC9aTQ_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[205];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[184].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[184].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, features);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[184].typ = (&NTIsetLfeatureT__JNptLjsgi8AHY03RfiC9aTQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[184].name = "features";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[28] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[206];
NTIlegacyfeature__YfzcW9bRC8xGYaRkFXliJ2g_.size = sizeof(tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g);
NTIlegacyfeature__YfzcW9bRC8xGYaRkFXliJ2g_.align = NIM_ALIGNOF(tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g);
NTIlegacyfeature__YfzcW9bRC8xGYaRkFXliJ2g_.kind = 14;
NTIlegacyfeature__YfzcW9bRC8xGYaRkFXliJ2g_.base = 0;
NTIlegacyfeature__YfzcW9bRC8xGYaRkFXliJ2g_.flags = 3;
for (TM__ZKkDwQBiNCxtzosUAsGM2Q_34 = 0; TM__ZKkDwQBiNCxtzosUAsGM2Q_34 < 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_34++) {
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_34+207].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_34+207].offset = TM__ZKkDwQBiNCxtzosUAsGM2Q_34;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_34+207].name = TM__ZKkDwQBiNCxtzosUAsGM2Q_33[TM__ZKkDwQBiNCxtzosUAsGM2Q_34];
TM__ZKkDwQBiNCxtzosUAsGM2Q_32_2[TM__ZKkDwQBiNCxtzosUAsGM2Q_34] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_34+207];
}
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[209].len = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[209].kind = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[209].sons = &TM__ZKkDwQBiNCxtzosUAsGM2Q_32_2[0];
NTIlegacyfeature__YfzcW9bRC8xGYaRkFXliJ2g_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[209];
NTIsetLlegacyfeatureT__Y0qlh9bqTxcHQL08b9bKCLEw_.size = sizeof(tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g);
NTIsetLlegacyfeatureT__Y0qlh9bqTxcHQL08b9bKCLEw_.align = NIM_ALIGNOF(tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g);
NTIsetLlegacyfeatureT__Y0qlh9bqTxcHQL08b9bKCLEw_.kind = 19;
NTIsetLlegacyfeatureT__Y0qlh9bqTxcHQL08b9bKCLEw_.base = (&NTIlegacyfeature__YfzcW9bRC8xGYaRkFXliJ2g_);
NTIsetLlegacyfeatureT__Y0qlh9bqTxcHQL08b9bKCLEw_.flags = 3;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[210].len = 0; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[210].kind = 0;
NTIsetLlegacyfeatureT__Y0qlh9bqTxcHQL08b9bKCLEw_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[210];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[206].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[206].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, legacyFeatures);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[206].typ = (&NTIsetLlegacyfeatureT__Y0qlh9bqTxcHQL08b9bKCLEw_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[206].name = "legacyFeatures";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[29] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[211];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[211].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[211].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, arguments);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[211].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[211].name = "arguments";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[30] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[212];
NTIidecmd__p9ct5yRAwVUwh1wTpKTgABg_.size = sizeof(tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg);
NTIidecmd__p9ct5yRAwVUwh1wTpKTgABg_.align = NIM_ALIGNOF(tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg);
NTIidecmd__p9ct5yRAwVUwh1wTpKTgABg_.kind = 14;
NTIidecmd__p9ct5yRAwVUwh1wTpKTgABg_.base = 0;
NTIidecmd__p9ct5yRAwVUwh1wTpKTgABg_.flags = 3;
for (TM__ZKkDwQBiNCxtzosUAsGM2Q_37 = 0; TM__ZKkDwQBiNCxtzosUAsGM2Q_37 < 20; TM__ZKkDwQBiNCxtzosUAsGM2Q_37++) {
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_37+213].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_37+213].offset = TM__ZKkDwQBiNCxtzosUAsGM2Q_37;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_37+213].name = TM__ZKkDwQBiNCxtzosUAsGM2Q_36[TM__ZKkDwQBiNCxtzosUAsGM2Q_37];
TM__ZKkDwQBiNCxtzosUAsGM2Q_35_20[TM__ZKkDwQBiNCxtzosUAsGM2Q_37] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_37+213];
}
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[233].len = 20; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[233].kind = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[233].sons = &TM__ZKkDwQBiNCxtzosUAsGM2Q_35_20[0];
NTIidecmd__p9ct5yRAwVUwh1wTpKTgABg_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[233];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[212].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[212].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, ideCmd);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[212].typ = (&NTIidecmd__p9ct5yRAwVUwh1wTpKTgABg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[212].name = "ideCmd";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[31] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[234];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[234].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[234].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, oldNewlines);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[234].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[234].name = "oldNewlines";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[32] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[235];
NTItsystemcc__DqbWIQj9a2XvtXkztox3VFQ_.size = sizeof(tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ);
NTItsystemcc__DqbWIQj9a2XvtXkztox3VFQ_.align = NIM_ALIGNOF(tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ);
NTItsystemcc__DqbWIQj9a2XvtXkztox3VFQ_.kind = 14;
NTItsystemcc__DqbWIQj9a2XvtXkztox3VFQ_.base = 0;
NTItsystemcc__DqbWIQj9a2XvtXkztox3VFQ_.flags = 3;
for (TM__ZKkDwQBiNCxtzosUAsGM2Q_40 = 0; TM__ZKkDwQBiNCxtzosUAsGM2Q_40 < 12; TM__ZKkDwQBiNCxtzosUAsGM2Q_40++) {
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_40+236].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_40+236].offset = TM__ZKkDwQBiNCxtzosUAsGM2Q_40;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_40+236].name = TM__ZKkDwQBiNCxtzosUAsGM2Q_39[TM__ZKkDwQBiNCxtzosUAsGM2Q_40];
TM__ZKkDwQBiNCxtzosUAsGM2Q_38_12[TM__ZKkDwQBiNCxtzosUAsGM2Q_40] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_40+236];
}
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[248].len = 12; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[248].kind = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[248].sons = &TM__ZKkDwQBiNCxtzosUAsGM2Q_38_12[0];
NTItsystemcc__DqbWIQj9a2XvtXkztox3VFQ_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[248];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[235].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[235].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, cCompiler);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[235].typ = (&NTItsystemcc__DqbWIQj9a2XvtXkztox3VFQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[235].name = "cCompiler";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[33] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[249];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[249].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[249].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, modifiedyNotes);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[249].typ = (&NTItnotekinds__w2aCBEMcLy7t2KQe9caB9aBw_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[249].name = "modifiedyNotes";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[34] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[250];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[250].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[250].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, cmdlineNotes);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[250].typ = (&NTItnotekinds__w2aCBEMcLy7t2KQe9caB9aBw_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[250].name = "cmdlineNotes";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[35] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[251];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[251].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[251].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, foreignPackageNotes);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[251].typ = (&NTItnotekinds__w2aCBEMcLy7t2KQe9caB9aBw_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[251].name = "foreignPackageNotes";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[36] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[252];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[252].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[252].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, notes);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[252].typ = (&NTItnotekinds__w2aCBEMcLy7t2KQe9caB9aBw_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[252].name = "notes";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[37] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[253];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[253].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[253].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, warningAsErrors);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[253].typ = (&NTItnotekinds__w2aCBEMcLy7t2KQe9caB9aBw_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[253].name = "warningAsErrors";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[38] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[254];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[254].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[254].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, mainPackageNotes);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[254].typ = (&NTItnotekinds__w2aCBEMcLy7t2KQe9caB9aBw_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[254].name = "mainPackageNotes";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[39] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[255];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[255].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[255].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, mainPackageId);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[255].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[255].name = "mainPackageId";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[40] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[256];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[256].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[256].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, errorCounter);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[256].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[256].name = "errorCounter";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[41] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[257];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[257].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[257].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, hintCounter);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[257].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[257].name = "hintCounter";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[42] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[258];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[258].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[258].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, warnCounter);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[258].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[258].name = "warnCounter";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[43] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[259];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[259].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[259].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, errorMax);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[259].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[259].name = "errorMax";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[44] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[260];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[260].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[260].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, maxLoopIterationsVM);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[260].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[260].name = "maxLoopIterationsVM";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[45] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[261];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[261].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[261].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, isVmTrace);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[261].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[261].name = "isVmTrace";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[46] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[262];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[262].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[262].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, configVars);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[262].typ = (&NTIstringtableref__frXcOWngaP9adxeuIUa3iBg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[262].name = "configVars";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[47] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[263];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[263].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[263].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, symbols);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[263].typ = (&NTIstringtableref__frXcOWngaP9adxeuIUa3iBg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[263].name = "symbols";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[48] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[264];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[264].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[264].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, packageCache);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[264].typ = (&NTIstringtableref__frXcOWngaP9adxeuIUa3iBg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[264].name = "packageCache";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[49] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[265];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[265].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[265].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, nimblePaths);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[265].typ = (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[265].name = "nimblePaths";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[50] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[266];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[266].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[266].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, searchPaths);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[266].typ = (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[266].name = "searchPaths";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[51] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[267];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[267].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[267].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, lazyPaths);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[267].typ = (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[267].name = "lazyPaths";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[52] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[268];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[268].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[268].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, outFile);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[268].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[268].name = "outFile";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[53] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[269];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[269].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[269].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, outDir);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[269].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[269].name = "outDir";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[54] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[270];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[270].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[270].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, jsonBuildFile);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[270].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[270].name = "jsonBuildFile";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[55] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[271];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[271].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[271].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, prefixDir);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[271].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[271].name = "prefixDir";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[56] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[272];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[272].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[272].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, libpath);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[272].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[272].name = "libpath";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[57] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[273];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[273].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[273].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, nimcacheDir);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[273].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[273].name = "nimcacheDir";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[58] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[274];
NTInimver__47w2DboNEPf69aPgubZdd7Q_.size = sizeof(tyTuple__47w2DboNEPf69aPgubZdd7Q);
NTInimver__47w2DboNEPf69aPgubZdd7Q_.align = NIM_ALIGNOF(tyTuple__47w2DboNEPf69aPgubZdd7Q);
NTInimver__47w2DboNEPf69aPgubZdd7Q_.kind = 18;
NTInimver__47w2DboNEPf69aPgubZdd7Q_.base = 0;
NTInimver__47w2DboNEPf69aPgubZdd7Q_.flags = 3;
TM__ZKkDwQBiNCxtzosUAsGM2Q_41_3[0] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[276];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[276].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[276].offset = offsetof(tyTuple__47w2DboNEPf69aPgubZdd7Q, Field0);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[276].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[276].name = "Field0";
TM__ZKkDwQBiNCxtzosUAsGM2Q_41_3[1] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[277];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[277].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[277].offset = offsetof(tyTuple__47w2DboNEPf69aPgubZdd7Q, Field1);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[277].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[277].name = "Field1";
TM__ZKkDwQBiNCxtzosUAsGM2Q_41_3[2] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[278];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[278].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[278].offset = offsetof(tyTuple__47w2DboNEPf69aPgubZdd7Q, Field2);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[278].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[278].name = "Field2";
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[275].len = 3; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[275].kind = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[275].sons = &TM__ZKkDwQBiNCxtzosUAsGM2Q_41_3[0];
NTInimver__47w2DboNEPf69aPgubZdd7Q_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[275];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[274].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[274].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, nimStdlibVersion);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[274].typ = (&NTInimver__47w2DboNEPf69aPgubZdd7Q_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[274].name = "nimStdlibVersion";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[59] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[279];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[279].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[279].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, dllOverrides);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[279].typ = (&NTIstringtableref__frXcOWngaP9adxeuIUa3iBg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[279].name = "dllOverrides";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[60] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[280];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[280].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[280].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, moduleOverrides);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[280].typ = (&NTIstringtableref__frXcOWngaP9adxeuIUa3iBg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[280].name = "moduleOverrides";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[61] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[281];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[281].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[281].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, cfileSpecificOptions);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[281].typ = (&NTIstringtableref__frXcOWngaP9adxeuIUa3iBg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[281].name = "cfileSpecificOptions";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[62] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[282];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[282].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[282].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, projectName);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[282].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[282].name = "projectName";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[63] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[283];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[283].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[283].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, projectPath);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[283].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[283].name = "projectPath";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[64] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[284];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[284].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[284].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, projectFull);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[284].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[284].name = "projectFull";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[65] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[285];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[285].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[285].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, projectIsStdin);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[285].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[285].name = "projectIsStdin";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[66] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[286];
NTIstdorrkind__iRAzj081qUCWECwmGroJoA_.size = sizeof(tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA);
NTIstdorrkind__iRAzj081qUCWECwmGroJoA_.align = NIM_ALIGNOF(tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA);
NTIstdorrkind__iRAzj081qUCWECwmGroJoA_.kind = 14;
NTIstdorrkind__iRAzj081qUCWECwmGroJoA_.base = 0;
NTIstdorrkind__iRAzj081qUCWECwmGroJoA_.flags = 3;
for (TM__ZKkDwQBiNCxtzosUAsGM2Q_44 = 0; TM__ZKkDwQBiNCxtzosUAsGM2Q_44 < 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_44++) {
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_44+287].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_44+287].offset = TM__ZKkDwQBiNCxtzosUAsGM2Q_44;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_44+287].name = TM__ZKkDwQBiNCxtzosUAsGM2Q_43[TM__ZKkDwQBiNCxtzosUAsGM2Q_44];
TM__ZKkDwQBiNCxtzosUAsGM2Q_42_2[TM__ZKkDwQBiNCxtzosUAsGM2Q_44] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_44+287];
}
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[289].len = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[289].kind = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[289].sons = &TM__ZKkDwQBiNCxtzosUAsGM2Q_42_2[0];
NTIstdorrkind__iRAzj081qUCWECwmGroJoA_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[289];
NTIsetLstdorrkindT__5SYuK9awXoPhHwBiML6ftcw_.size = sizeof(tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA);
NTIsetLstdorrkindT__5SYuK9awXoPhHwBiML6ftcw_.align = NIM_ALIGNOF(tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA);
NTIsetLstdorrkindT__5SYuK9awXoPhHwBiML6ftcw_.kind = 19;
NTIsetLstdorrkindT__5SYuK9awXoPhHwBiML6ftcw_.base = (&NTIstdorrkind__iRAzj081qUCWECwmGroJoA_);
NTIsetLstdorrkindT__5SYuK9awXoPhHwBiML6ftcw_.flags = 3;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[290].len = 0; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[290].kind = 0;
NTIsetLstdorrkindT__5SYuK9awXoPhHwBiML6ftcw_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[290];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[286].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[286].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, lastMsgWasDot);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[286].typ = (&NTIsetLstdorrkindT__5SYuK9awXoPhHwBiML6ftcw_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[286].name = "lastMsgWasDot";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[67] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[291];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[291].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[291].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, projectMainIdx);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[291].typ = (&NTIint5150__sVg18TP9cLifHyygRe9cro9aA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[291].name = "projectMainIdx";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[68] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[292];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[292].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[292].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, projectMainIdx2);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[292].typ = (&NTIint5150__sVg18TP9cLifHyygRe9cro9aA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[292].name = "projectMainIdx2";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[69] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[293];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[293].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[293].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, command);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[293].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[293].name = "command";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[70] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[294];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[294].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[294].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, commandArgs);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[294].typ = (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[294].name = "commandArgs";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[71] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[295];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[295].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[295].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, commandLine);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[295].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[295].name = "commandLine";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[72] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[296];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[296].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[296].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, extraCmds);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[296].typ = (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[296].name = "extraCmds";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[73] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[297];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[297].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[297].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, keepComments);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[297].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[297].name = "keepComments";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[74] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[298];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[298].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[298].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, implicitImports);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[298].typ = (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[298].name = "implicitImports";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[75] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[299];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[299].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[299].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, implicitIncludes);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[299].typ = (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[299].name = "implicitIncludes";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[76] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[300];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[300].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[300].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, docSeeSrcUrl);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[300].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[300].name = "docSeeSrcUrl";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[77] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[301];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[301].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[301].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, docRoot);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[301].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[301].name = "docRoot";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[78] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[302];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[302].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[302].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, docCmd);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[302].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[302].name = "docCmd";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[79] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[303];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[303].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[303].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, configFiles);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[303].typ = (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[303].name = "configFiles";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[80] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[304];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[304].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[304].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, cIncludes);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[304].typ = (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[304].name = "cIncludes";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[81] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[305];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[305].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[305].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, cLibs);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[305].typ = (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[305].name = "cLibs";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[82] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[306];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[306].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[306].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, cLinkedLibs);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[306].typ = (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[306].name = "cLinkedLibs";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[83] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[307];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[307].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[307].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, externalToLink);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[307].typ = (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[307].name = "externalToLink";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[84] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[308];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[308].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[308].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, linkOptionsCmd);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[308].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[308].name = "linkOptionsCmd";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[85] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[309];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[309].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[309].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, compileOptionsCmd);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[309].typ = (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[309].name = "compileOptionsCmd";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[86] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[310];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[310].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[310].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, linkOptions);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[310].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[310].name = "linkOptions";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[87] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[311];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[311].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[311].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, compileOptions);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[311].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[311].name = "compileOptions";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[88] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[312];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[312].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[312].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, cCompilerPath);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[312].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[312].name = "cCompilerPath";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[89] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[313];
NTIcfile__n9b2nVKiXbLpHsfkan9c3Rkw_.size = sizeof(tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw);
NTIcfile__n9b2nVKiXbLpHsfkan9c3Rkw_.align = NIM_ALIGNOF(tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw);
NTIcfile__n9b2nVKiXbLpHsfkan9c3Rkw_.kind = 18;
NTIcfile__n9b2nVKiXbLpHsfkan9c3Rkw_.base = 0;
NTIcfile__n9b2nVKiXbLpHsfkan9c3Rkw_.flags = 2;
TM__ZKkDwQBiNCxtzosUAsGM2Q_45_5[0] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[315];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[315].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[315].offset = offsetof(tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw, nimname);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[315].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[315].name = "nimname";
TM__ZKkDwQBiNCxtzosUAsGM2Q_45_5[1] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[316];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[316].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[316].offset = offsetof(tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw, cname);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[316].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[316].name = "cname";
TM__ZKkDwQBiNCxtzosUAsGM2Q_45_5[2] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[317];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[317].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[317].offset = offsetof(tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw, obj);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[317].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[317].name = "obj";
TM__ZKkDwQBiNCxtzosUAsGM2Q_45_5[3] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[318];
NTIcfileflag__S5Qo9byZG8QnIQnJQ0ZDWrA_.size = sizeof(tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA);
NTIcfileflag__S5Qo9byZG8QnIQnJQ0ZDWrA_.align = NIM_ALIGNOF(tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA);
NTIcfileflag__S5Qo9byZG8QnIQnJQ0ZDWrA_.kind = 14;
NTIcfileflag__S5Qo9byZG8QnIQnJQ0ZDWrA_.base = 0;
NTIcfileflag__S5Qo9byZG8QnIQnJQ0ZDWrA_.flags = 3;
for (TM__ZKkDwQBiNCxtzosUAsGM2Q_48 = 0; TM__ZKkDwQBiNCxtzosUAsGM2Q_48 < 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_48++) {
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_48+319].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_48+319].offset = TM__ZKkDwQBiNCxtzosUAsGM2Q_48;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_48+319].name = TM__ZKkDwQBiNCxtzosUAsGM2Q_47[TM__ZKkDwQBiNCxtzosUAsGM2Q_48];
TM__ZKkDwQBiNCxtzosUAsGM2Q_46_2[TM__ZKkDwQBiNCxtzosUAsGM2Q_48] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[TM__ZKkDwQBiNCxtzosUAsGM2Q_48+319];
}
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[321].len = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[321].kind = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[321].sons = &TM__ZKkDwQBiNCxtzosUAsGM2Q_46_2[0];
NTIcfileflag__S5Qo9byZG8QnIQnJQ0ZDWrA_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[321];
NTIsetLcfileflagT__BqZ7GosT8lX9alvQ9c2savjQ_.size = sizeof(tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA);
NTIsetLcfileflagT__BqZ7GosT8lX9alvQ9c2savjQ_.align = NIM_ALIGNOF(tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA);
NTIsetLcfileflagT__BqZ7GosT8lX9alvQ9c2savjQ_.kind = 19;
NTIsetLcfileflagT__BqZ7GosT8lX9alvQ9c2savjQ_.base = (&NTIcfileflag__S5Qo9byZG8QnIQnJQ0ZDWrA_);
NTIsetLcfileflagT__BqZ7GosT8lX9alvQ9c2savjQ_.flags = 3;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[322].len = 0; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[322].kind = 0;
NTIsetLcfileflagT__BqZ7GosT8lX9alvQ9c2savjQ_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[322];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[318].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[318].offset = offsetof(tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw, flags);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[318].typ = (&NTIsetLcfileflagT__BqZ7GosT8lX9alvQ9c2savjQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[318].name = "flags";
TM__ZKkDwQBiNCxtzosUAsGM2Q_45_5[4] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[323];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[323].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[323].offset = offsetof(tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw, customArgs);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[323].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[323].name = "customArgs";
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[314].len = 5; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[314].kind = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[314].sons = &TM__ZKkDwQBiNCxtzosUAsGM2Q_45_5[0];
NTIcfile__n9b2nVKiXbLpHsfkan9c3Rkw_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[314];
NTIcfilelist__KLItBKQec3LJzPmfiYYfQA_.size = sizeof(tySequence__KLItBKQec3LJzPmfiYYfQA*);
NTIcfilelist__KLItBKQec3LJzPmfiYYfQA_.align = NIM_ALIGNOF(tySequence__KLItBKQec3LJzPmfiYYfQA*);
NTIcfilelist__KLItBKQec3LJzPmfiYYfQA_.kind = 24;
NTIcfilelist__KLItBKQec3LJzPmfiYYfQA_.base = (&NTIcfile__n9b2nVKiXbLpHsfkan9c3Rkw_);
NTIcfilelist__KLItBKQec3LJzPmfiYYfQA_.flags = 2;
NTIcfilelist__KLItBKQec3LJzPmfiYYfQA_.marker = Marker_tySequence__KLItBKQec3LJzPmfiYYfQA;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[313].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[313].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, toCompile);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[313].typ = (&NTIcfilelist__KLItBKQec3LJzPmfiYYfQA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[313].name = "toCompile";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[90] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[324];
NTIprocLresult58suggestTLOclosureOT__Ox1WDSaSyO73VnvAC2a4UA_.size = sizeof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTIprocLresult58suggestTLOclosureOT__Ox1WDSaSyO73VnvAC2a4UA_.align = NIM_ALIGNOF(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTIprocLresult58suggestTLOclosureOT__Ox1WDSaSyO73VnvAC2a4UA_.kind = 18;
NTIprocLresult58suggestTLOclosureOT__Ox1WDSaSyO73VnvAC2a4UA_.base = 0;
TM__ZKkDwQBiNCxtzosUAsGM2Q_49_2[0] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[326];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[326].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[326].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field0);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[326].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[326].name = "Field0";
TM__ZKkDwQBiNCxtzosUAsGM2Q_49_2[1] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[327];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[327].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[327].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field1);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[327].typ = (&NTIrefobject__HsJiUUcO9cHBdUCi0HwkSTA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[327].name = "Field1";
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[325].len = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[325].kind = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[325].sons = &TM__ZKkDwQBiNCxtzosUAsGM2Q_49_2[0];
NTIprocLresult58suggestTLOclosureOT__Ox1WDSaSyO73VnvAC2a4UA_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[325];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[324].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[324].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, suggestionResultHook);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[324].typ = (&NTIprocLresult58suggestTLOclosureOT__Ox1WDSaSyO73VnvAC2a4UA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[324].name = "suggestionResultHook";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[91] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[328];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[328].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[328].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, suggestVersion);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[328].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[328].name = "suggestVersion";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[92] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[329];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[329].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[329].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, suggestMaxResults);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[329].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[329].name = "suggestMaxResults";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[93] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[330];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[330].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[330].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, lastLineInfo);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[330].typ = (&NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[330].name = "lastLineInfo";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[94] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[331];
NTIprocLoutput58stringTLOclosureOT__k2HFjxisIgDALbEUFojxaQ_.size = sizeof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTIprocLoutput58stringTLOclosureOT__k2HFjxisIgDALbEUFojxaQ_.align = NIM_ALIGNOF(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTIprocLoutput58stringTLOclosureOT__k2HFjxisIgDALbEUFojxaQ_.kind = 18;
NTIprocLoutput58stringTLOclosureOT__k2HFjxisIgDALbEUFojxaQ_.base = 0;
TM__ZKkDwQBiNCxtzosUAsGM2Q_50_2[0] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[333];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[333].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[333].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field0);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[333].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[333].name = "Field0";
TM__ZKkDwQBiNCxtzosUAsGM2Q_50_2[1] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[334];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[334].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[334].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field1);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[334].typ = (&NTIrefobject__HsJiUUcO9cHBdUCi0HwkSTA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[334].name = "Field1";
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[332].len = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[332].kind = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[332].sons = &TM__ZKkDwQBiNCxtzosUAsGM2Q_50_2[0];
NTIprocLoutput58stringTLOclosureOT__k2HFjxisIgDALbEUFojxaQ_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[332];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[331].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[331].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, writelnHook);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[331].typ = (&NTIprocLoutput58stringTLOclosureOT__k2HFjxisIgDALbEUFojxaQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[331].name = "writelnHook";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[95] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[335];
NTIprocLconfig58configref_info58tlineinfo_msg58string_severity58severityTLOclosure_gcsafeOT__2bM7rNPFiQD9bOvwFI49bKLQ_.size = sizeof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTIprocLconfig58configref_info58tlineinfo_msg58string_severity58severityTLOclosure_gcsafeOT__2bM7rNPFiQD9bOvwFI49bKLQ_.align = NIM_ALIGNOF(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTIprocLconfig58configref_info58tlineinfo_msg58string_severity58severityTLOclosure_gcsafeOT__2bM7rNPFiQD9bOvwFI49bKLQ_.kind = 18;
NTIprocLconfig58configref_info58tlineinfo_msg58string_severity58severityTLOclosure_gcsafeOT__2bM7rNPFiQD9bOvwFI49bKLQ_.base = 0;
TM__ZKkDwQBiNCxtzosUAsGM2Q_51_2[0] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[337];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[337].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[337].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field0);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[337].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[337].name = "Field0";
TM__ZKkDwQBiNCxtzosUAsGM2Q_51_2[1] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[338];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[338].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[338].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field1);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[338].typ = (&NTIrefobject__HsJiUUcO9cHBdUCi0HwkSTA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[338].name = "Field1";
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[336].len = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[336].kind = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[336].sons = &TM__ZKkDwQBiNCxtzosUAsGM2Q_51_2[0];
NTIprocLconfig58configref_info58tlineinfo_msg58string_severity58severityTLOclosure_gcsafeOT__2bM7rNPFiQD9bOvwFI49bKLQ_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[336];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[335].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[335].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, structuredErrorHook);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[335].typ = (&NTIprocLconfig58configref_info58tlineinfo_msg58string_severity58severityTLOclosure_gcsafeOT__2bM7rNPFiQD9bOvwFI49bKLQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[335].name = "structuredErrorHook";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[96] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[339];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[339].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[339].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, cppCustomNamespace);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[339].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[339].name = "cppCustomNamespace";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[97] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[340];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[340].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[340].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, nimMainPrefix);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[340].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[340].name = "nimMainPrefix";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[98] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[341];
NTIprofiledata58objecttype__EiZfxxvPWlUmMsSkx8Qffg_.size = sizeof(tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg);
NTIprofiledata58objecttype__EiZfxxvPWlUmMsSkx8Qffg_.align = NIM_ALIGNOF(tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg);
NTIprofiledata58objecttype__EiZfxxvPWlUmMsSkx8Qffg_.kind = 18;
NTIprofiledata58objecttype__EiZfxxvPWlUmMsSkx8Qffg_.base = 0;
NTIprofiledata58objecttype__EiZfxxvPWlUmMsSkx8Qffg_.flags = 2;
NTItable__aP9cMXsPundL60Bltc8zw8Q_.size = sizeof(tyObject_Table__aP9cMXsPundL60Bltc8zw8Q);
NTItable__aP9cMXsPundL60Bltc8zw8Q_.align = NIM_ALIGNOF(tyObject_Table__aP9cMXsPundL60Bltc8zw8Q);
NTItable__aP9cMXsPundL60Bltc8zw8Q_.kind = 18;
NTItable__aP9cMXsPundL60Bltc8zw8Q_.base = 0;
NTItable__aP9cMXsPundL60Bltc8zw8Q_.flags = 2;
TM__ZKkDwQBiNCxtzosUAsGM2Q_52_2[0] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[344];
NTIkeyvaluepair__tqJ79cmISx6IHad2jnF54pA_.size = sizeof(tyTuple__tqJ79cmISx6IHad2jnF54pA);
NTIkeyvaluepair__tqJ79cmISx6IHad2jnF54pA_.align = NIM_ALIGNOF(tyTuple__tqJ79cmISx6IHad2jnF54pA);
NTIkeyvaluepair__tqJ79cmISx6IHad2jnF54pA_.kind = 18;
NTIkeyvaluepair__tqJ79cmISx6IHad2jnF54pA_.base = 0;
NTIkeyvaluepair__tqJ79cmISx6IHad2jnF54pA_.flags = 3;
TM__ZKkDwQBiNCxtzosUAsGM2Q_53_3[0] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[346];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[346].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[346].offset = offsetof(tyTuple__tqJ79cmISx6IHad2jnF54pA, Field0);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[346].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[346].name = "Field0";
TM__ZKkDwQBiNCxtzosUAsGM2Q_53_3[1] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[347];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[347].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[347].offset = offsetof(tyTuple__tqJ79cmISx6IHad2jnF54pA, Field1);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[347].typ = (&NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[347].name = "Field1";
TM__ZKkDwQBiNCxtzosUAsGM2Q_53_3[2] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[348];
NTIprofileinfo__xU9aXXjWWQtDqNY2yZecQYw_.size = sizeof(tyObject_ProfileInfo__xU9aXXjWWQtDqNY2yZecQYw);
NTIprofileinfo__xU9aXXjWWQtDqNY2yZecQYw_.align = NIM_ALIGNOF(tyObject_ProfileInfo__xU9aXXjWWQtDqNY2yZecQYw);
NTIprofileinfo__xU9aXXjWWQtDqNY2yZecQYw_.kind = 18;
NTIprofileinfo__xU9aXXjWWQtDqNY2yZecQYw_.base = 0;
NTIprofileinfo__xU9aXXjWWQtDqNY2yZecQYw_.flags = 3;
TM__ZKkDwQBiNCxtzosUAsGM2Q_54_2[0] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[350];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[350].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[350].offset = offsetof(tyObject_ProfileInfo__xU9aXXjWWQtDqNY2yZecQYw, time);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[350].typ = (&NTIfloat__w9bl9a1ul9ctRJWiMl9cNnIMvg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[350].name = "time";
TM__ZKkDwQBiNCxtzosUAsGM2Q_54_2[1] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[351];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[351].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[351].offset = offsetof(tyObject_ProfileInfo__xU9aXXjWWQtDqNY2yZecQYw, count);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[351].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[351].name = "count";
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[349].len = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[349].kind = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[349].sons = &TM__ZKkDwQBiNCxtzosUAsGM2Q_54_2[0];
NTIprofileinfo__xU9aXXjWWQtDqNY2yZecQYw_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[349];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[348].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[348].offset = offsetof(tyTuple__tqJ79cmISx6IHad2jnF54pA, Field2);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[348].typ = (&NTIprofileinfo__xU9aXXjWWQtDqNY2yZecQYw_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[348].name = "Field2";
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[345].len = 3; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[345].kind = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[345].sons = &TM__ZKkDwQBiNCxtzosUAsGM2Q_53_3[0];
NTIkeyvaluepair__tqJ79cmISx6IHad2jnF54pA_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[345];
NTIkeyvaluepairseq__Ou09axLmOh3clXcvEh9agsPw_.size = sizeof(tySequence__Ou09axLmOh3clXcvEh9agsPw*);
NTIkeyvaluepairseq__Ou09axLmOh3clXcvEh9agsPw_.align = NIM_ALIGNOF(tySequence__Ou09axLmOh3clXcvEh9agsPw*);
NTIkeyvaluepairseq__Ou09axLmOh3clXcvEh9agsPw_.kind = 24;
NTIkeyvaluepairseq__Ou09axLmOh3clXcvEh9agsPw_.base = (&NTIkeyvaluepair__tqJ79cmISx6IHad2jnF54pA_);
NTIkeyvaluepairseq__Ou09axLmOh3clXcvEh9agsPw_.flags = 2;
NTIkeyvaluepairseq__Ou09axLmOh3clXcvEh9agsPw_.marker = Marker_tySequence__Ou09axLmOh3clXcvEh9agsPw;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[344].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[344].offset = offsetof(tyObject_Table__aP9cMXsPundL60Bltc8zw8Q, data);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[344].typ = (&NTIkeyvaluepairseq__Ou09axLmOh3clXcvEh9agsPw_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[344].name = "data";
TM__ZKkDwQBiNCxtzosUAsGM2Q_52_2[1] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[352];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[352].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[352].offset = offsetof(tyObject_Table__aP9cMXsPundL60Bltc8zw8Q, counter);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[352].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[352].name = "counter";
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[343].len = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[343].kind = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[343].sons = &TM__ZKkDwQBiNCxtzosUAsGM2Q_52_2[0];
NTItable__aP9cMXsPundL60Bltc8zw8Q_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[343];
NTItableref__vKCGqnu0UyqZI18SWjvLlg_.size = sizeof(tyObject_Table__aP9cMXsPundL60Bltc8zw8Q*);
NTItableref__vKCGqnu0UyqZI18SWjvLlg_.align = NIM_ALIGNOF(tyObject_Table__aP9cMXsPundL60Bltc8zw8Q*);
NTItableref__vKCGqnu0UyqZI18SWjvLlg_.kind = 22;
NTItableref__vKCGqnu0UyqZI18SWjvLlg_.base = (&NTItable__aP9cMXsPundL60Bltc8zw8Q_);
NTItableref__vKCGqnu0UyqZI18SWjvLlg_.flags = 2;
NTItableref__vKCGqnu0UyqZI18SWjvLlg_.marker = Marker_tyRef__vKCGqnu0UyqZI18SWjvLlg;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[342].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[342].offset = offsetof(tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg, data);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[342].typ = (&NTItableref__vKCGqnu0UyqZI18SWjvLlg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[342].name = "data";
NTIprofiledata58objecttype__EiZfxxvPWlUmMsSkx8Qffg_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[342];
NTIprofiledata__yHN9cW05nEsauqTlU5H52dA_.size = sizeof(tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg*);
NTIprofiledata__yHN9cW05nEsauqTlU5H52dA_.align = NIM_ALIGNOF(tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg*);
NTIprofiledata__yHN9cW05nEsauqTlU5H52dA_.kind = 22;
NTIprofiledata__yHN9cW05nEsauqTlU5H52dA_.base = (&NTIprofiledata58objecttype__EiZfxxvPWlUmMsSkx8Qffg_);
NTIprofiledata__yHN9cW05nEsauqTlU5H52dA_.flags = 2;
NTIprofiledata__yHN9cW05nEsauqTlU5H52dA_.marker = Marker_tyRef__yHN9cW05nEsauqTlU5H52dA;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[341].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[341].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, vmProfileData);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[341].typ = (&NTIprofiledata__yHN9cW05nEsauqTlU5H52dA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[341].name = "vmProfileData";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[99] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[353];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[353].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[353].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, expandProgress);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[353].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[353].name = "expandProgress";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[100] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[354];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[354].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[354].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, expandLevels);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[354].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[354].name = "expandLevels";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[101] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[355];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[355].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[355].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, expandNodeResult);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[355].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[355].name = "expandNodeResult";
TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[102] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[356];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[356].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[356].offset = offsetof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ, expandPosition);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[356].typ = (&NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[356].name = "expandPosition";
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[0].len = 103; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[0].kind = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[0].sons = &TM__ZKkDwQBiNCxtzosUAsGM2Q_2_103[0];
NTIconfigref58objecttype__XoIrMAjHi4NOQu4oAkNfVQ_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[0];
NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_.size = sizeof(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*);
NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_.align = NIM_ALIGNOF(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*);
NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_.kind = 22;
NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_.base = (&NTIconfigref58objecttype__XoIrMAjHi4NOQu4oAkNfVQ_);
NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_.flags = 2;
NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_.marker = Marker_tyRef__9af1bTLFo0lbM2Q5seW0UFA;
NTIsuggest58objecttype__VUPO9alfTq2Ar9a7ZtY9cSPDg_.size = sizeof(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg);
NTIsuggest58objecttype__VUPO9alfTq2Ar9a7ZtY9cSPDg_.align = NIM_ALIGNOF(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg);
NTIsuggest58objecttype__VUPO9alfTq2Ar9a7ZtY9cSPDg_.kind = 18;
NTIsuggest58objecttype__VUPO9alfTq2Ar9a7ZtY9cSPDg_.base = 0;
NTIsuggest58objecttype__VUPO9alfTq2Ar9a7ZtY9cSPDg_.flags = 2;
TM__ZKkDwQBiNCxtzosUAsGM2Q_123_20[0] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[358];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[358].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[358].offset = offsetof(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg, section);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[358].typ = (&NTIidecmd__p9ct5yRAwVUwh1wTpKTgABg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[358].name = "section";
TM__ZKkDwQBiNCxtzosUAsGM2Q_123_20[1] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[359];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[359].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[359].offset = offsetof(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg, qualifiedPath);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[359].typ = (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[359].name = "qualifiedPath";
TM__ZKkDwQBiNCxtzosUAsGM2Q_123_20[2] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[360];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[360].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[360].offset = offsetof(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg, name);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[360].typ = (&NTIptrstring__Y36n7l9b7WX4rcaAYCe6LWw_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[360].name = "name";
TM__ZKkDwQBiNCxtzosUAsGM2Q_123_20[3] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[361];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[361].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[361].offset = offsetof(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg, filePath);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[361].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[361].name = "filePath";
TM__ZKkDwQBiNCxtzosUAsGM2Q_123_20[4] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[362];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[362].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[362].offset = offsetof(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg, line);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[362].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[362].name = "line";
TM__ZKkDwQBiNCxtzosUAsGM2Q_123_20[5] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[363];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[363].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[363].offset = offsetof(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg, column);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[363].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[363].name = "column";
TM__ZKkDwQBiNCxtzosUAsGM2Q_123_20[6] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[364];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[364].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[364].offset = offsetof(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg, doc);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[364].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[364].name = "doc";
TM__ZKkDwQBiNCxtzosUAsGM2Q_123_20[7] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[365];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[365].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[365].offset = offsetof(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg, forth);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[365].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[365].name = "forth";
TM__ZKkDwQBiNCxtzosUAsGM2Q_123_20[8] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[366];
NTIint__13aFwjKaWlqhwUBjDHvkIw_.size = sizeof(NI);
NTIint__13aFwjKaWlqhwUBjDHvkIw_.align = NIM_ALIGNOF(NI);
NTIint__13aFwjKaWlqhwUBjDHvkIw_.kind = 31;
NTIint__13aFwjKaWlqhwUBjDHvkIw_.base = 0;
NTIint__13aFwjKaWlqhwUBjDHvkIw_.flags = 3;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[366].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[366].offset = offsetof(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg, quality);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[366].typ = (&NTIint__13aFwjKaWlqhwUBjDHvkIw_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[366].name = "quality";
TM__ZKkDwQBiNCxtzosUAsGM2Q_123_20[9] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[367];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[367].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[367].offset = offsetof(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg, isGlobal);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[367].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[367].name = "isGlobal";
TM__ZKkDwQBiNCxtzosUAsGM2Q_123_20[10] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[368];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[368].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[368].offset = offsetof(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg, contextFits);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[368].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[368].name = "contextFits";
TM__ZKkDwQBiNCxtzosUAsGM2Q_123_20[11] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[369];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[369].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[369].offset = offsetof(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg, prefix);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[369].typ = (&NTIprefixmatch__Y9cGLq2K6rNefjjqfIC9bauQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[369].name = "prefix";
TM__ZKkDwQBiNCxtzosUAsGM2Q_123_20[12] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[370];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[370].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[370].offset = offsetof(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg, symkind);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[370].typ = (&NTIbyte__k3HXouOuhqAKq0dx450lXQ_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[370].name = "symkind";
TM__ZKkDwQBiNCxtzosUAsGM2Q_123_20[13] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[371];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[371].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[371].offset = offsetof(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg, scope);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[371].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[371].name = "scope";
TM__ZKkDwQBiNCxtzosUAsGM2Q_123_20[14] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[372];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[372].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[372].offset = offsetof(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg, localUsages);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[372].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[372].name = "localUsages";
TM__ZKkDwQBiNCxtzosUAsGM2Q_123_20[15] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[373];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[373].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[373].offset = offsetof(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg, globalUsages);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[373].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[373].name = "globalUsages";
TM__ZKkDwQBiNCxtzosUAsGM2Q_123_20[16] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[374];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[374].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[374].offset = offsetof(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg, tokenLen);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[374].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[374].name = "tokenLen";
TM__ZKkDwQBiNCxtzosUAsGM2Q_123_20[17] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[375];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[375].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[375].offset = offsetof(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg, version);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[375].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[375].name = "version";
TM__ZKkDwQBiNCxtzosUAsGM2Q_123_20[18] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[376];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[376].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[376].offset = offsetof(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg, endLine);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[376].typ = (&NTIuint4954__M4na42GvebBMnI5wV9cYMxg_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[376].name = "endLine";
TM__ZKkDwQBiNCxtzosUAsGM2Q_123_20[19] = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[377];
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[377].kind = 1;
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[377].offset = offsetof(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg, endCol);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[377].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[377].name = "endCol";
TM__ZKkDwQBiNCxtzosUAsGM2Q_0[357].len = 20; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[357].kind = 2; TM__ZKkDwQBiNCxtzosUAsGM2Q_0[357].sons = &TM__ZKkDwQBiNCxtzosUAsGM2Q_123_20[0];
NTIsuggest58objecttype__VUPO9alfTq2Ar9a7ZtY9cSPDg_.node = &TM__ZKkDwQBiNCxtzosUAsGM2Q_0[357];
NTIsuggest__vIaEYib9am0Aa2d8J2uMYdQ_.size = sizeof(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg*);
NTIsuggest__vIaEYib9am0Aa2d8J2uMYdQ_.align = NIM_ALIGNOF(tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg*);
NTIsuggest__vIaEYib9am0Aa2d8J2uMYdQ_.kind = 22;
NTIsuggest__vIaEYib9am0Aa2d8J2uMYdQ_.base = (&NTIsuggest58objecttype__VUPO9alfTq2Ar9a7ZtY9cSPDg_);
NTIsuggest__vIaEYib9am0Aa2d8J2uMYdQ_.flags = 2;
NTIsuggest__vIaEYib9am0Aa2d8J2uMYdQ_.marker = Marker_tyRef__vIaEYib9am0Aa2d8J2uMYdQ;
}

